/* -*- mode: c++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */

/*
 Copyright (C) 2003, 2004 Ferdinando Ametrano
 Copyright (C) 2006 Richard Gould
 Copyright (C) 2007 Mark Joshi
 Copyright (C) 2013 Cheng Li

 This file is part of QuantLib, a free-software/open-source library
 for financial quantitative analysts and developers - http://quantlib.org/

 QuantLib is free software: you can redistribute it and/or modify it
 under the terms of the QuantLib license.  You should have received a
 copy of the license along with this program; if not, please email
 <quantlib-dev@lists.sf.net>. The license is also available online at
 <http://quantlib.org/license.shtml>.

 This program is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 FOR A PARTICULAR PURPOSE.  See the license for more details.
*/

#include <ql/math/randomnumbers/sobolrsg.hpp>
#include <ql/math/randomnumbers/primitivepolynomials.hpp>
#include <ql/math/randomnumbers/mt19937uniformrng.hpp>
#include <ql/errors.hpp>
#include <algorithm>
#include <cmath>

namespace QuantLib {

    namespace {

        // number of dimensions in the alternative primitive polynomials
        const Size maxAltDegree = 52;

        const long AltPrimitivePolynomialDegree01[] = {0, /* x+1 (1)(1) */
                                                       -1};

        const long AltPrimitivePolynomialDegree02[] = {1, /* x^2+x+1 (1)1(1) */
                                                       -1};

        const long AltPrimitivePolynomialDegree03[] = {1, /* x^3    +x+1 (1)01(1) */
                                                       2, /* x^3+x^2  +1 (1)10(1) */
                                                       -1};

        const long AltPrimitivePolynomialDegree04[] = {1, /* x^4+       +x+1 (1)001(1) */
                                                       4, /* x^4+x^3+     +1 (1)100(1) */
                                                       -1};


        const long AltPrimitivePolynomialDegree05[] = {2,  /* x^5        +x^2  +1 (1)0010(1) */
                                                       13, /* x^5+x^4+x^3    +x+1 (1)1101(1) */
                                                       7,  /* x^5    +x^3+x^2+x+1 (1)0111(1) */
                                                       14, /* x^5+x^4+x^3+x^2  +1 (1)1110(1) */
                                                       11, /* x^5+x^4    +x^2+x+1 (1)1011(1) */
                                                       4,  /* x^5    +x^3      +1 (1)0100(1) */
                                                       -1};

        const long AltPrimitivePolynomialDegree06[] = {1,  /* x^6                +x+1 (1)00001(1) */
                                                       16, /* x^6+x^5              +1 (1)10000(1) */
                                                       13, /* x^6    +x^4+x^3    +x+1 (1)01101(1) */
                                                       22, /* x^6+x^5    +x^3+x^2  +1 (1)10110(1) */
                                                       19, /* x^6            +x^2+x+1 (1)10011(1) */
                                                       25, /* x^6+x^5+x^4        +x+1 (1)11001(1) */
                                                       -1};


        const long AltPrimitivePolynomialDegree07[] = {
            1,  /* x^7                    +x+1 (1)000001(1) */
            32, /* x^7+x^6                  +1 (1)100000(1) */
            4,  /* x^7            +x^3      +1 (1)000100(1) */
            8,  /* x^7        +x^4          +1 (1)001000(1) */
            7,  /* x^7            +x^3+x^2+x+1 (1)000111(1) */
            56, /* x^7+x^6+x^5+x^4          +1 (1)111000(1) */
            14, /* x^7        +x^4+x^3+x^2  +1 (1)001110(1) */
            28, /* x^7    +x^5+x^4+x^3      +1 (1)011100(1) */
            19, /* x^7    +x^5        +x^2+x+1 (1)010011(1) */
            50, /* x^7+x^6+x^5        +x^2  +1 (1)110010(1) */
            21, /* x^7    +x^5    +x^3    +x+1 (1)010101(1) */
            42, /* x^7+x^6    +x^4    +x^2  +1 (1)101010(1) */
            31, /* x^7    +x^5+x^4+x^3+x^2+x+1 (1)011111(1) */
            62, /* x^7+x^6+x^5+x^4+x^3+x^2  +1 (1)111110(1) */
            37, /* x^7+x^6        +x^3    +x+1 (1)100101(1) */
            41, /* x^7+x^6    +x^4        +x+1 (1)101001(1) */
            55, /* x^7+x^6+x^5    +x^3+x^2+x+1 (1)110111(1) */
            59, /* x^7+x^6+x^5+x^4    +x^2+x+1 (1)111011(1) */
            -1};

        const long AltPrimitivePolynomialDegree08[] = {14, 56, 21, 22, 38,  47,  49,  50, 52,
                                                       67, 70, 84, 97, 103, 115, 122, -1};


#define N_ALT_MAX_DEGREE 8

        const long *const AltPrimitivePolynomials[N_ALT_MAX_DEGREE]=
        {
            AltPrimitivePolynomialDegree01,
            AltPrimitivePolynomialDegree02,
            AltPrimitivePolynomialDegree03,
            AltPrimitivePolynomialDegree04,
            AltPrimitivePolynomialDegree05,
            AltPrimitivePolynomialDegree06,
            AltPrimitivePolynomialDegree07,
            AltPrimitivePolynomialDegree08
        };

        /* Sobol' Levitan coefficients of the free direction integers as given
           by Bratley, P., Fox, B.L. (1988)
        */
        const std::uint32_t dim02SLinitializers[] = {
            1UL, 0UL };
        const std::uint32_t dim03SLinitializers[] = {
            1UL, 1UL, 0UL };
        const std::uint32_t dim04SLinitializers[] = {
            1UL, 3UL, 7UL, 0UL };
        const std::uint32_t dim05SLinitializers[] = {
            1UL, 1UL, 5UL, 0UL };
        const std::uint32_t dim06SLinitializers[] = {
            1UL, 3UL, 1UL, 1UL, 0UL };
        const std::uint32_t dim07SLinitializers[] = {
            1UL, 1UL, 3UL, 7UL, 0UL };
        const std::uint32_t dim08SLinitializers[] = {
            1UL, 3UL, 3UL, 9UL, 9UL, 0UL };
        const std::uint32_t dim09SLinitializers[] = {
            1UL, 3UL, 7UL, 13UL, 3UL, 0UL };
        const std::uint32_t dim10SLinitializers[] = {
            1UL, 1UL, 5UL, 11UL, 27UL, 0UL };
        const std::uint32_t dim11SLinitializers[] = {
            1UL, 3UL, 5UL, 1UL, 15UL, 0UL };
        const std::uint32_t dim12SLinitializers[] = {
            1UL, 1UL, 7UL, 3UL, 29UL, 0UL };
        const std::uint32_t dim13SLinitializers[] = {
            1UL, 3UL, 7UL, 7UL, 21UL, 0UL };
        const std::uint32_t dim14SLinitializers[] = {
            1UL, 1UL, 1UL, 9UL, 23UL, 37UL, 0UL };
        const std::uint32_t dim15SLinitializers[] = {
            1UL, 3UL, 3UL, 5UL, 19UL, 33UL, 0UL };
        const std::uint32_t dim16SLinitializers[] = {
            1UL, 1UL, 3UL, 13UL, 11UL, 7UL, 0UL };
        const std::uint32_t dim17SLinitializers[] = {
            1UL, 1UL, 7UL, 13UL, 25UL, 5UL, 0UL };
        const std::uint32_t dim18SLinitializers[] = {
            1UL, 3UL, 5UL, 11UL, 7UL, 11UL, 0UL };
        const std::uint32_t dim19SLinitializers[] = {
            1UL, 1UL, 1UL, 3UL, 13UL, 39UL, 0UL };
        const std::uint32_t dim20SLinitializers[] = {
            1UL, 3UL, 1UL, 15UL, 17UL, 63UL, 13UL, 0UL };
        const std::uint32_t dim21SLinitializers[] = {
            1UL, 1UL, 5UL, 5UL, 1UL, 27UL, 33UL, 0UL };
        const std::uint32_t dim22SLinitializers[] = {
            1UL, 3UL, 3UL, 3UL, 25UL, 17UL, 115UL, 0UL };
        const std::uint32_t dim23SLinitializers[] = {
            1UL, 1UL, 3UL, 15UL, 29UL, 15UL, 41UL, 0UL };
        const std::uint32_t dim24SLinitializers[] = {
            1UL, 3UL, 1UL, 7UL, 3UL, 23UL, 79UL, 0UL };
        const std::uint32_t dim25SLinitializers[] = {
            1UL, 3UL, 7UL, 9UL, 31UL, 29UL, 17UL, 0UL };
        const std::uint32_t dim26SLinitializers[] = {
            1UL, 1UL, 5UL, 13UL, 11UL, 3UL, 29UL, 0UL };
        const std::uint32_t dim27SLinitializers[] = {
            1UL, 3UL, 1UL, 9UL, 5UL, 21UL, 119UL, 0UL };
        const std::uint32_t dim28SLinitializers[] = {
            1UL, 1UL, 3UL, 1UL, 23UL, 13UL, 75UL, 0UL };
        const std::uint32_t dim29SLinitializers[] = {
            1UL, 3UL, 3UL, 11UL, 27UL, 31UL, 73UL, 0UL };
        const std::uint32_t dim30SLinitializers[] = {
            1UL, 1UL, 7UL, 7UL, 19UL, 25UL, 105UL, 0UL };
        const std::uint32_t dim31SLinitializers[] = {
            1UL, 3UL, 5UL, 5UL, 21UL, 9UL, 7UL, 0UL };
        const std::uint32_t dim32SLinitializers[] = {
            1UL, 1UL, 1UL, 15UL, 5UL, 49UL, 59UL, 0UL };
        const std::uint32_t dim33SLinitializers[] = {
            1UL, 1UL, 1UL, 1UL, 1UL, 33UL, 65UL, 0UL };
        const std::uint32_t dim34SLinitializers[] = {
            1UL, 3UL, 5UL, 15UL, 17UL, 19UL, 21UL, 0UL };
        const std::uint32_t dim35SLinitializers[] = {
            1UL, 1UL, 7UL, 11UL, 13UL, 29UL, 3UL, 0UL };
        const std::uint32_t dim36SLinitializers[] = {
            1UL, 3UL, 7UL, 5UL, 7UL, 11UL, 113UL, 0UL };
        const std::uint32_t dim37SLinitializers[] = {
            1UL, 1UL, 5UL, 3UL, 15UL, 19UL, 61UL, 0UL };
        const std::uint32_t dim38SLinitializers[] = {
            1UL, 3UL, 1UL, 1UL, 9UL, 27UL, 89UL, 7UL, 0UL };
        const std::uint32_t dim39SLinitializers[] = {
            1UL, 1UL, 3UL, 7UL, 31UL, 15UL, 45UL, 23UL, 0UL };
        const std::uint32_t dim40SLinitializers[] = {
            1UL, 3UL, 3UL, 9UL, 9UL, 25UL, 107UL, 39UL, 0UL };

        const std::uint32_t * const SLinitializers[39] = {
            dim02SLinitializers,
            dim03SLinitializers,
            dim04SLinitializers,
            dim05SLinitializers,
            dim06SLinitializers,
            dim07SLinitializers,
            dim08SLinitializers,
            dim09SLinitializers,
            dim10SLinitializers,
            dim11SLinitializers,
            dim12SLinitializers,
            dim13SLinitializers,
            dim14SLinitializers,
            dim15SLinitializers,
            dim16SLinitializers,
            dim17SLinitializers,
            dim18SLinitializers,
            dim19SLinitializers,
            dim20SLinitializers,
            dim21SLinitializers,
            dim22SLinitializers,
            dim23SLinitializers,
            dim24SLinitializers,
            dim25SLinitializers,
            dim26SLinitializers,
            dim27SLinitializers,
            dim28SLinitializers,
            dim29SLinitializers,
            dim30SLinitializers,
            dim31SLinitializers,
            dim32SLinitializers,
            dim33SLinitializers,
            dim34SLinitializers,
            dim35SLinitializers,
            dim36SLinitializers,
            dim37SLinitializers,
            dim38SLinitializers,
            dim39SLinitializers,
            dim40SLinitializers
        };

        /* coefficients of the free direction integers as given in
           "Monte Carlo Methods in Finance", by Peter J�ckel, section 8.3
        */
        const std::uint32_t dim09initializers[] = {
            1UL, 3UL, 7UL, 7UL, 21UL, 0UL };
        const std::uint32_t dim10initializers[] = {
            1UL, 1UL, 5UL, 11UL, 27UL, 0UL };
        const std::uint32_t dim11initializers[] = {
            1UL, 1UL, 7UL, 3UL, 29UL, 0UL };
        const std::uint32_t dim12initializers[] = {
            1UL, 3UL, 7UL, 13UL, 3UL, 0UL };
        const std::uint32_t dim13initializers[] = {
            1UL, 3UL, 5UL, 1UL, 15UL, 0UL };
        const std::uint32_t dim14initializers[] = {
            1UL, 1UL, 1UL, 9UL, 23UL, 37UL, 0UL };
        const std::uint32_t dim15initializers[] = {
            1UL, 1UL, 3UL, 13UL, 11UL, 7UL, 0UL };
        const std::uint32_t dim16initializers[] = {
            1UL, 3UL, 3UL, 5UL, 19UL, 33UL, 0UL };

        const std::uint32_t dim17initializers[] = {
            1UL, 1UL, 7UL, 13UL, 25UL, 5UL, 0UL };
        const std::uint32_t dim18initializers[] = {
            1UL, 1UL, 1UL, 3UL, 13UL, 39UL, 0UL };
        const std::uint32_t dim19initializers[] = {
            1UL, 3UL, 5UL, 11UL, 7UL, 11UL, 0UL };

        const std::uint32_t dim20initializers[] = {
            1UL, 3UL, 1UL, 7UL, 3UL, 23UL, 79UL, 0UL };
        const std::uint32_t dim21initializers[] = {
            1UL, 3UL, 1UL, 15UL, 17UL, 63UL, 13UL, 0UL };
        const std::uint32_t dim22initializers[] = {
            1UL, 3UL, 3UL, 3UL, 25UL, 17UL, 115UL, 0UL };
        const std::uint32_t dim23initializers[] = {
            1UL, 3UL, 7UL, 9UL, 31UL, 29UL, 17UL, 0UL };
        const std::uint32_t dim24initializers[] = {
            1UL, 1UL, 3UL, 15UL, 29UL, 15UL, 41UL, 0UL };
        const std::uint32_t dim25initializers[] = {
            1UL, 3UL, 1UL, 9UL, 5UL, 21UL, 119UL, 0UL };
        const std::uint32_t dim26initializers[] = {
            1UL, 1UL, 5UL, 5UL, 1UL, 27UL, 33UL, 0UL };
        const std::uint32_t dim27initializers[] = {
            1UL, 1UL, 3UL, 1UL, 23UL, 13UL, 75UL, 0UL };
        const std::uint32_t dim28initializers[] = {
            1UL, 1UL, 7UL, 7UL, 19UL, 25UL, 105UL, 0UL };
        const std::uint32_t dim29initializers[] = {
            1UL, 3UL, 5UL, 5UL, 21UL, 9UL, 7UL, 0UL };
        const std::uint32_t dim30initializers[] = {
            1UL, 1UL, 1UL, 15UL, 5UL, 49UL, 59UL, 0UL };
        const std::uint32_t dim31initializers[] = {
            1UL, 3UL, 5UL, 15UL, 17UL, 19UL, 21UL, 0UL };
        const std::uint32_t dim32initializers[] = {
            1UL, 1UL, 7UL, 11UL, 13UL, 29UL, 3UL, 0UL };

        const std::uint32_t * const initializers[31] = {
            dim02SLinitializers,
            dim03SLinitializers,
            dim04SLinitializers,
            dim05SLinitializers,
            dim06SLinitializers,
            dim07SLinitializers,
            dim08SLinitializers,
            dim09initializers,
            dim10initializers,
            dim11initializers,
            dim12initializers,
            dim13initializers,
            dim14initializers,
            dim15initializers,
            dim16initializers,
            dim17initializers,
            dim18initializers,
            dim19initializers,
            dim20initializers,
            dim21initializers,
            dim22initializers,
            dim23initializers,
            dim24initializers,
            dim25initializers,
            dim26initializers,
            dim27initializers,
            dim28initializers,
            dim29initializers,
            dim30initializers,
            dim31initializers,
            dim32initializers
        };

        /* Lemieux coefficients of the free direction integers as given
           in Christiane Lemieux, private communication, September 2004
        */
        const std::uint32_t dim041Linitializers[] = {
            1UL,1UL,3UL,13UL,7UL,35UL,61UL,91UL,0UL};
        const std::uint32_t dim042Linitializers[] = {
            1UL,1UL,7UL,11UL,5UL,35UL,55UL,75UL,0UL};
        const std::uint32_t dim043Linitializers[] = {
            1UL,3UL,5UL,5UL,11UL,23UL,29UL,139UL,0UL};
        const std::uint32_t dim044Linitializers[] = {
            1UL,1UL,1UL,7UL,11UL,15UL,17UL,81UL,0UL};
        const std::uint32_t dim045Linitializers[] = {
            1UL,1UL,7UL,9UL,5UL,57UL,79UL,103UL,0UL};
        const std::uint32_t dim046Linitializers[] = {
            1UL,1UL,7UL,13UL,19UL,5UL,5UL,185UL,0UL};
        const std::uint32_t dim047Linitializers[] = {
            1UL,3UL,1UL,3UL,13UL,57UL,97UL,131UL,0UL};
        const std::uint32_t dim048Linitializers[] = {
            1UL,1UL,5UL,5UL,21UL,25UL,125UL,197UL,0UL};
        const std::uint32_t dim049Linitializers[] = {
            1UL,3UL,3UL,9UL,31UL,11UL,103UL,201UL,0UL};
        const std::uint32_t dim050Linitializers[] = {
            1UL,1UL,5UL,3UL,7UL,25UL,51UL,121UL,0UL};
        const std::uint32_t dim051Linitializers[] = {
            1UL,3UL,7UL,15UL,19UL,53UL,73UL,189UL,0UL};
        const std::uint32_t dim052Linitializers[] = {
            1UL,1UL,1UL,15UL,19UL,55UL,27UL,183UL,0UL};
        const std::uint32_t dim053Linitializers[] = {
            1UL,1UL,7UL,13UL,3UL,29UL,109UL,69UL,0UL};
        const std::uint32_t dim054Linitializers[] = {
            1UL,1UL,5UL,15UL,15UL,23UL,15UL,1UL,57UL,0UL};
        const std::uint32_t dim055Linitializers[] = {
            1UL,3UL,1UL,3UL,23UL,55UL,43UL,143UL,397UL,0UL};
        const std::uint32_t dim056Linitializers[] = {
            1UL,1UL,3UL,11UL,29UL,9UL,35UL,131UL,411UL,0UL};
        const std::uint32_t dim057Linitializers[] = {
            1UL,3UL,1UL,7UL,27UL,39UL,103UL,199UL,277UL,0UL};
        const std::uint32_t dim058Linitializers[] = {
            1UL,3UL,7UL,3UL,19UL,55UL,127UL,67UL,449UL,0UL};
        const std::uint32_t dim059Linitializers[] = {
            1UL,3UL,7UL,3UL,5UL,29UL,45UL,85UL,3UL,0UL};
        const std::uint32_t dim060Linitializers[] = {
            1UL,3UL,5UL,5UL,13UL,23UL,75UL,245UL,453UL,0UL};
        const std::uint32_t dim061Linitializers[] = {
            1UL,3UL,1UL,15UL,21UL,47UL,3UL,77UL,165UL,0UL};
        const std::uint32_t dim062Linitializers[] = {
            1UL,1UL,7UL,9UL,15UL,5UL,117UL,73UL,473UL,0UL};
        const std::uint32_t dim063Linitializers[] = {
            1UL,3UL,1UL,9UL,1UL,21UL,13UL,173UL,313UL,0UL};
        const std::uint32_t dim064Linitializers[] = {
            1UL,1UL,7UL,3UL,11UL,45UL,63UL,77UL,49UL,0UL};
        const std::uint32_t dim065Linitializers[] = {
            1UL,1UL,1UL,1UL,1UL,25UL,123UL,39UL,259UL,0UL};
        const std::uint32_t dim066Linitializers[] = {
            1UL,1UL,1UL,5UL,23UL,11UL,59UL,11UL,203UL,0UL};
        const std::uint32_t dim067Linitializers[] = {
            1UL,3UL,3UL,15UL,21UL,1UL,73UL,71UL,421UL,0UL};
        const std::uint32_t dim068Linitializers[] = {
            1UL,1UL,5UL,11UL,15UL,31UL,115UL,95UL,217UL,0UL};
        const std::uint32_t dim069Linitializers[] = {
            1UL,1UL,3UL,3UL,7UL,53UL,37UL,43UL,439UL,0UL};
        const std::uint32_t dim070Linitializers[] = {
            1UL,1UL,1UL,1UL,27UL,53UL,69UL,159UL,321UL,0UL};
        const std::uint32_t dim071Linitializers[] = {
            1UL,1UL,5UL,15UL,29UL,17UL,19UL,43UL,449UL,0UL};
        const std::uint32_t dim072Linitializers[] = {
            1UL,1UL,3UL,9UL,1UL,55UL,121UL,205UL,255UL,0UL};
        const std::uint32_t dim073Linitializers[] = {
            1UL,1UL,3UL,11UL,9UL,47UL,107UL,11UL,417UL,0UL};
        const std::uint32_t dim074Linitializers[] = {
            1UL,1UL,1UL,5UL,17UL,25UL,21UL,83UL,95UL,0UL};
        const std::uint32_t dim075Linitializers[] = {
            1UL,3UL,5UL,13UL,31UL,25UL,61UL,157UL,407UL,0UL};
        const std::uint32_t dim076Linitializers[] = {
            1UL,1UL,7UL,9UL,25UL,33UL,41UL,35UL,17UL,0UL};
        const std::uint32_t dim077Linitializers[] = {
            1UL,3UL,7UL,15UL,13UL,39UL,61UL,187UL,461UL,0UL};
        const std::uint32_t dim078Linitializers[] = {
            1UL,3UL,7UL,13UL,5UL,57UL,23UL,177UL,435UL,0UL};
        const std::uint32_t dim079Linitializers[] = {
            1UL,1UL,3UL,15UL,11UL,27UL,115UL,5UL,337UL,0UL};
        const std::uint32_t dim080Linitializers[] = {
            1UL,3UL,7UL,3UL,15UL,63UL,61UL,171UL,339UL,0UL};
        const std::uint32_t dim081Linitializers[] = {
            1UL,3UL,3UL,13UL,15UL,61UL,59UL,47UL,1UL,0UL};
        const std::uint32_t dim082Linitializers[] = {
            1UL,1UL,5UL,15UL,13UL,5UL,39UL,83UL,329UL,0UL};
        const std::uint32_t dim083Linitializers[] = {
            1UL,1UL,5UL,5UL,5UL,27UL,25UL,39UL,301UL,0UL};
        const std::uint32_t dim084Linitializers[] = {
            1UL,1UL,5UL,11UL,31UL,41UL,35UL,233UL,27UL,0UL};
        const std::uint32_t dim085Linitializers[] = {
            1UL,3UL,5UL,15UL,7UL,37UL,119UL,171UL,419UL,0UL};
        const std::uint32_t dim086Linitializers[] = {
            1UL,3UL,5UL,5UL,3UL,29UL,21UL,189UL,417UL,0UL};
        const std::uint32_t dim087Linitializers[] = {
            1UL,1UL,1UL,1UL,21UL,41UL,117UL,119UL,351UL,0UL};
        const std::uint32_t dim088Linitializers[] = {
            1UL,1UL,3UL,1UL,7UL,27UL,87UL,19UL,213UL,0UL};
        const std::uint32_t dim089Linitializers[] = {
            1UL,1UL,1UL,1UL,17UL,7UL,97UL,217UL,477UL,0UL};
        const std::uint32_t dim090Linitializers[] = {
            1UL,1UL,7UL,1UL,29UL,61UL,103UL,231UL,269UL,0UL};
        const std::uint32_t dim091Linitializers[] = {
            1UL,1UL,7UL,13UL,9UL,27UL,107UL,207UL,311UL,0UL};
        const std::uint32_t dim092Linitializers[] = {
            1UL,1UL,7UL,5UL,25UL,21UL,107UL,179UL,423UL,0UL};
        const std::uint32_t dim093Linitializers[] = {
            1UL,3UL,5UL,11UL,7UL,1UL,17UL,245UL,281UL,0UL};
        const std::uint32_t dim094Linitializers[] = {
            1UL,3UL,5UL,9UL,1UL,5UL,53UL,59UL,125UL,0UL};
        const std::uint32_t dim095Linitializers[] = {
            1UL,1UL,7UL,1UL,31UL,57UL,71UL,245UL,125UL,0UL};
        const std::uint32_t dim096Linitializers[] = {
            1UL,1UL,7UL,5UL,5UL,57UL,53UL,253UL,441UL,0UL};
        const std::uint32_t dim097Linitializers[] = {
            1UL,3UL,1UL,13UL,19UL,35UL,119UL,235UL,381UL,0UL};
        const std::uint32_t dim098Linitializers[] = {
            1UL,3UL,1UL,7UL,19UL,59UL,115UL,33UL,361UL,0UL};
        const std::uint32_t dim099Linitializers[] = {
            1UL,1UL,3UL,5UL,13UL,1UL,49UL,143UL,501UL,0UL};
        const std::uint32_t dim100Linitializers[] = {
            1UL,1UL,3UL,5UL,1UL,63UL,101UL,85UL,189UL,0UL};
        const std::uint32_t dim101Linitializers[] = {
            1UL,1UL,5UL,11UL,27UL,63UL,13UL,131UL,5UL,0UL};
        const std::uint32_t dim102Linitializers[] = {
            1UL,1UL,5UL,7UL,15UL,45UL,75UL,59UL,455UL,585UL,0UL};
        const std::uint32_t dim103Linitializers[] = {
            1UL,3UL,1UL,3UL,7UL,7UL,111UL,23UL,119UL,959UL,0UL};
        const std::uint32_t dim104Linitializers[] = {
            1UL,3UL,3UL,9UL,11UL,41UL,109UL,163UL,161UL,879UL,0UL};
        const std::uint32_t dim105Linitializers[] = {
            1UL,3UL,5UL,1UL,21UL,41UL,121UL,183UL,315UL,219UL,0UL};
        const std::uint32_t dim106Linitializers[] = {
            1UL,1UL,3UL,9UL,15UL,3UL,9UL,223UL,441UL,929UL,0UL};
        const std::uint32_t dim107Linitializers[] = {
            1UL,1UL,7UL,9UL,3UL,5UL,93UL,57UL,253UL,457UL,0UL};
        const std::uint32_t dim108Linitializers[] = {
            1UL,1UL,7UL,13UL,15UL,29UL,83UL,21UL,35UL,45UL,0UL};
        const std::uint32_t dim109Linitializers[] = {
            1UL,1UL,3UL,7UL,13UL,61UL,119UL,219UL,85UL,505UL,0UL};
        const std::uint32_t dim110Linitializers[] = {
            1UL,1UL,3UL,3UL,17UL,13UL,35UL,197UL,291UL,109UL,0UL};
        const std::uint32_t dim111Linitializers[] = {
            1UL,1UL,3UL,3UL,5UL,1UL,113UL,103UL,217UL,253UL,0UL};
        const std::uint32_t dim112Linitializers[] = {
            1UL,1UL,7UL,1UL,15UL,39UL,63UL,223UL,17UL,9UL,0UL};
        const std::uint32_t dim113Linitializers[] = {
            1UL,3UL,7UL,1UL,17UL,29UL,67UL,103UL,495UL,383UL,0UL};
        const std::uint32_t dim114Linitializers[] = {
            1UL,3UL,3UL,15UL,31UL,59UL,75UL,165UL,51UL,913UL,0UL};
        const std::uint32_t dim115Linitializers[] = {
            1UL,3UL,7UL,9UL,5UL,27UL,79UL,219UL,233UL,37UL,0UL};
        const std::uint32_t dim116Linitializers[] = {
            1UL,3UL,5UL,15UL,1UL,11UL,15UL,211UL,417UL,811UL,0UL};
        const std::uint32_t dim117Linitializers[] = {
            1UL,3UL,5UL,3UL,29UL,27UL,39UL,137UL,407UL,231UL,0UL};
        const std::uint32_t dim118Linitializers[] = {
            1UL,1UL,3UL,5UL,29UL,43UL,125UL,135UL,109UL,67UL,0UL};
        const std::uint32_t dim119Linitializers[] = {
            1UL,1UL,1UL,5UL,11UL,39UL,107UL,159UL,323UL,381UL,0UL};
        const std::uint32_t dim120Linitializers[] = {
            1UL,1UL,1UL,1UL,9UL,11UL,33UL,55UL,169UL,253UL,0UL};
        const std::uint32_t dim121Linitializers[] = {
            1UL,3UL,5UL,5UL,11UL,53UL,63UL,101UL,251UL,897UL,0UL};
        const std::uint32_t dim122Linitializers[] = {
            1UL,3UL,7UL,1UL,25UL,15UL,83UL,119UL,53UL,157UL,0UL};
        const std::uint32_t dim123Linitializers[] = {
            1UL,3UL,5UL,13UL,5UL,5UL,3UL,195UL,111UL,451UL,0UL};
        const std::uint32_t dim124Linitializers[] = {
            1UL,3UL,1UL,15UL,11UL,1UL,19UL,11UL,307UL,777UL,0UL};
        const std::uint32_t dim125Linitializers[] = {
            1UL,3UL,7UL,11UL,5UL,5UL,17UL,231UL,345UL,981UL,0UL};
        const std::uint32_t dim126Linitializers[] = {
            1UL,1UL,3UL,3UL,1UL,33UL,83UL,201UL,57UL,475UL,0UL};
        const std::uint32_t dim127Linitializers[] = {
            1UL,3UL,7UL,7UL,17UL,13UL,35UL,175UL,499UL,809UL,0UL};
        const std::uint32_t dim128Linitializers[] = {
            1UL,1UL,5UL,3UL,3UL,17UL,103UL,119UL,499UL,865UL,0UL};
        const std::uint32_t dim129Linitializers[] = {
            1UL,1UL,1UL,11UL,27UL,25UL,37UL,121UL,401UL,11UL,0UL};
        const std::uint32_t dim130Linitializers[] = {
            1UL,1UL,1UL,11UL,9UL,25UL,25UL,241UL,403UL,3UL,0UL};
        const std::uint32_t dim131Linitializers[] = {
            1UL,1UL,1UL,1UL,11UL,1UL,39UL,163UL,231UL,573UL,0UL};
        const std::uint32_t dim132Linitializers[] = {
            1UL,1UL,1UL,13UL,13UL,21UL,75UL,185UL,99UL,545UL,0UL};
        const std::uint32_t dim133Linitializers[] = {
            1UL,1UL,1UL,15UL,3UL,63UL,69UL,11UL,173UL,315UL,0UL};
        const std::uint32_t dim134Linitializers[] = {
            1UL,3UL,5UL,15UL,11UL,3UL,95UL,49UL,123UL,765UL,0UL};
        const std::uint32_t dim135Linitializers[] = {
            1UL,1UL,1UL,15UL,3UL,63UL,77UL,31UL,425UL,711UL,0UL};
        const std::uint32_t dim136Linitializers[] = {
            1UL,1UL,7UL,15UL,1UL,37UL,119UL,145UL,489UL,583UL,0UL};
        const std::uint32_t dim137Linitializers[] = {
            1UL,3UL,5UL,15UL,3UL,49UL,117UL,211UL,165UL,323UL,0UL};
        const std::uint32_t dim138Linitializers[] = {
            1UL,3UL,7UL,1UL,27UL,63UL,77UL,201UL,225UL,803UL,0UL};
        const std::uint32_t dim139Linitializers[] = {
            1UL,1UL,1UL,11UL,23UL,35UL,67UL,21UL,469UL,357UL,0UL};
        const std::uint32_t dim140Linitializers[] = {
            1UL,1UL,7UL,7UL,9UL,7UL,25UL,237UL,237UL,571UL,0UL};
        const std::uint32_t dim141Linitializers[] = {
            1UL,1UL,3UL,15UL,29UL,5UL,107UL,109UL,241UL,47UL,0UL};
        const std::uint32_t dim142Linitializers[] = {
            1UL,3UL,5UL,11UL,27UL,63UL,29UL,13UL,203UL,675UL,0UL};
        const std::uint32_t dim143Linitializers[] = {
            1UL,1UL,3UL,9UL,9UL,11UL,103UL,179UL,449UL,263UL,0UL};
        const std::uint32_t dim144Linitializers[] = {
            1UL,3UL,5UL,11UL,29UL,63UL,53UL,151UL,259UL,223UL,0UL};
        const std::uint32_t dim145Linitializers[] = {
            1UL,1UL,3UL,7UL,9UL,25UL,5UL,197UL,237UL,163UL,0UL};
        const std::uint32_t dim146Linitializers[] = {
            1UL,3UL,7UL,13UL,5UL,57UL,67UL,193UL,147UL,241UL,0UL};
        const std::uint32_t dim147Linitializers[] = {
            1UL,1UL,5UL,15UL,15UL,33UL,17UL,67UL,161UL,341UL,0UL};
        const std::uint32_t dim148Linitializers[] = {
            1UL,1UL,3UL,13UL,17UL,43UL,21UL,197UL,441UL,985UL,0UL};
        const std::uint32_t dim149Linitializers[] = {
            1UL,3UL,1UL,5UL,15UL,33UL,33UL,193UL,305UL,829UL,0UL};
        const std::uint32_t dim150Linitializers[] = {
            1UL,1UL,1UL,13UL,19UL,27UL,71UL,187UL,477UL,239UL,0UL};
        const std::uint32_t dim151Linitializers[] = {
            1UL,1UL,1UL,9UL,9UL,17UL,41UL,177UL,229UL,983UL,0UL};
        const std::uint32_t dim152Linitializers[] = {
            1UL,3UL,5UL,9UL,15UL,45UL,97UL,205UL,43UL,767UL,0UL};
        const std::uint32_t dim153Linitializers[] = {
            1UL,1UL,1UL,9UL,31UL,31UL,77UL,159UL,395UL,809UL,0UL};
        const std::uint32_t dim154Linitializers[] = {
            1UL,3UL,3UL,3UL,29UL,19UL,73UL,123UL,165UL,307UL,0UL};
        const std::uint32_t dim155Linitializers[] = {
            1UL,3UL,1UL,7UL,5UL,11UL,77UL,227UL,355UL,403UL,0UL};
        const std::uint32_t dim156Linitializers[] = {
            1UL,3UL,5UL,5UL,25UL,31UL,1UL,215UL,451UL,195UL,0UL};
        const std::uint32_t dim157Linitializers[] = {
            1UL,3UL,7UL,15UL,29UL,37UL,101UL,241UL,17UL,633UL,0UL};
        const std::uint32_t dim158Linitializers[] = {
            1UL,1UL,5UL,1UL,11UL,3UL,107UL,137UL,489UL,5UL,0UL};
        const std::uint32_t dim159Linitializers[] = {
            1UL,1UL,1UL,7UL,19UL,19UL,75UL,85UL,471UL,355UL,0UL};
        const std::uint32_t dim160Linitializers[] = {
            1UL,1UL,3UL,3UL,9UL,13UL,113UL,167UL,13UL,27UL,0UL};
        const std::uint32_t dim161Linitializers[] = {
            1UL,3UL,5UL,11UL,21UL,3UL,89UL,205UL,377UL,307UL,0UL};
        const std::uint32_t dim162Linitializers[] = {
            1UL,1UL,1UL,9UL,31UL,61UL,65UL,9UL,391UL,141UL,867UL,0UL};
        const std::uint32_t dim163Linitializers[] = {
            1UL,1UL,1UL,9UL,19UL,19UL,61UL,227UL,241UL,55UL,161UL,0UL};
        const std::uint32_t dim164Linitializers[] = {
            1UL,1UL,1UL,11UL,1UL,19UL,7UL,233UL,463UL,171UL,1941UL,0UL};
        const std::uint32_t dim165Linitializers[] = {
            1UL,1UL,5UL,7UL,25UL,13UL,103UL,75UL,19UL,1021UL,1063UL,0UL};
        const std::uint32_t dim166Linitializers[] = {
            1UL,1UL,1UL,15UL,17UL,17UL,79UL,63UL,391UL,403UL,1221UL,0UL};
        const std::uint32_t dim167Linitializers[] = {
            1UL,3UL,3UL,11UL,29UL,25UL,29UL,107UL,335UL,475UL,963UL,0UL};
        const std::uint32_t dim168Linitializers[] = {
            1UL,3UL,5UL,1UL,31UL,33UL,49UL,43UL,155UL,9UL,1285UL,0UL};
        const std::uint32_t dim169Linitializers[] = {
            1UL,1UL,5UL,5UL,15UL,47UL,39UL,161UL,357UL,863UL,1039UL,0UL};
        const std::uint32_t dim170Linitializers[] = {
            1UL,3UL,7UL,15UL,1UL,39UL,47UL,109UL,427UL,393UL,1103UL,0UL};
        const std::uint32_t dim171Linitializers[] = {
            1UL,1UL,1UL,9UL,9UL,29UL,121UL,233UL,157UL,99UL,701UL,0UL};
        const std::uint32_t dim172Linitializers[] = {
            1UL,1UL,1UL,7UL,1UL,29UL,75UL,121UL,439UL,109UL,993UL,0UL};
        const std::uint32_t dim173Linitializers[] = {
            1UL,1UL,1UL,9UL,5UL,1UL,39UL,59UL,89UL,157UL,1865UL,0UL};
        const std::uint32_t dim174Linitializers[] = {
            1UL,1UL,5UL,1UL,3UL,37UL,89UL,93UL,143UL,533UL,175UL,0UL};
        const std::uint32_t dim175Linitializers[] = {
            1UL,1UL,3UL,5UL,7UL,33UL,35UL,173UL,159UL,135UL,241UL,0UL};
        const std::uint32_t dim176Linitializers[] = {
            1UL,1UL,1UL,15UL,17UL,37UL,79UL,131UL,43UL,891UL,229UL,0UL};
        const std::uint32_t dim177Linitializers[] = {
            1UL,1UL,1UL,1UL,1UL,35UL,121UL,177UL,397UL,1017UL,583UL,0UL};
        const std::uint32_t dim178Linitializers[] = {
            1UL,1UL,3UL,15UL,31UL,21UL,43UL,67UL,467UL,923UL,1473UL,0UL};
        const std::uint32_t dim179Linitializers[] = {
            1UL,1UL,1UL,7UL,1UL,33UL,77UL,111UL,125UL,771UL,1975UL,0UL};
        const std::uint32_t dim180Linitializers[] = {
            1UL,3UL,7UL,13UL,1UL,51UL,113UL,139UL,245UL,573UL,503UL,0UL};
        const std::uint32_t dim181Linitializers[] = {
            1UL,3UL,1UL,9UL,21UL,49UL,15UL,157UL,49UL,483UL,291UL,0UL};
        const std::uint32_t dim182Linitializers[] = {
            1UL,1UL,1UL,1UL,29UL,35UL,17UL,65UL,403UL,485UL,1603UL,0UL};
        const std::uint32_t dim183Linitializers[] = {
            1UL,1UL,1UL,7UL,19UL,1UL,37UL,129UL,203UL,321UL,1809UL,0UL};
        const std::uint32_t dim184Linitializers[] = {
            1UL,3UL,7UL,15UL,15UL,9UL,5UL,77UL,29UL,485UL,581UL,0UL};
        const std::uint32_t dim185Linitializers[] = {
            1UL,1UL,3UL,5UL,15UL,49UL,97UL,105UL,309UL,875UL,1581UL,0UL};
        const std::uint32_t dim186Linitializers[] = {
            1UL,3UL,5UL,1UL,5UL,19UL,63UL,35UL,165UL,399UL,1489UL,0UL};
        const std::uint32_t dim187Linitializers[] = {
            1UL,3UL,5UL,3UL,23UL,5UL,79UL,137UL,115UL,599UL,1127UL,0UL};
        const std::uint32_t dim188Linitializers[] = {
            1UL,1UL,7UL,5UL,3UL,61UL,27UL,177UL,257UL,91UL,841UL,0UL};
        const std::uint32_t dim189Linitializers[] = {
            1UL,1UL,3UL,5UL,9UL,31UL,91UL,209UL,409UL,661UL,159UL,0UL};
        const std::uint32_t dim190Linitializers[] = {
            1UL,3UL,1UL,15UL,23UL,39UL,23UL,195UL,245UL,203UL,947UL,0UL};
        const std::uint32_t dim191Linitializers[] = {
            1UL,1UL,3UL,1UL,15UL,59UL,67UL,95UL,155UL,461UL,147UL,0UL};
        const std::uint32_t dim192Linitializers[] = {
            1UL,3UL,7UL,5UL,23UL,25UL,87UL,11UL,51UL,449UL,1631UL,0UL};
        const std::uint32_t dim193Linitializers[] = {
            1UL,1UL,1UL,1UL,17UL,57UL,7UL,197UL,409UL,609UL,135UL,0UL};
        const std::uint32_t dim194Linitializers[] = {
            1UL,1UL,1UL,9UL,1UL,61UL,115UL,113UL,495UL,895UL,1595UL,0UL};
        const std::uint32_t dim195Linitializers[] = {
            1UL,3UL,7UL,15UL,9UL,47UL,121UL,211UL,379UL,985UL,1755UL,0UL};
        const std::uint32_t dim196Linitializers[] = {
            1UL,3UL,1UL,3UL,7UL,57UL,27UL,231UL,339UL,325UL,1023UL,0UL};
        const std::uint32_t dim197Linitializers[] = {
            1UL,1UL,1UL,1UL,19UL,63UL,63UL,239UL,31UL,643UL,373UL,0UL};
        const std::uint32_t dim198Linitializers[] = {
            1UL,3UL,1UL,11UL,19UL,9UL,7UL,171UL,21UL,691UL,215UL,0UL};
        const std::uint32_t dim199Linitializers[] = {
            1UL,1UL,5UL,13UL,11UL,57UL,39UL,211UL,241UL,893UL,555UL,0UL};
        const std::uint32_t dim200Linitializers[] = {
            1UL,1UL,7UL,5UL,29UL,21UL,45UL,59UL,509UL,223UL,491UL,0UL};
        const std::uint32_t dim201Linitializers[] = {
            1UL,1UL,7UL,9UL,15UL,61UL,97UL,75UL,127UL,779UL,839UL,0UL};
        const std::uint32_t dim202Linitializers[] = {
            1UL,1UL,7UL,15UL,17UL,33UL,75UL,237UL,191UL,925UL,681UL,0UL};
        const std::uint32_t dim203Linitializers[] = {
            1UL,3UL,5UL,7UL,27UL,57UL,123UL,111UL,101UL,371UL,1129UL,0UL};
        const std::uint32_t dim204Linitializers[] = {
            1UL,3UL,5UL,5UL,29UL,45UL,59UL,127UL,229UL,967UL,2027UL,0UL};
        const std::uint32_t dim205Linitializers[] = {
            1UL,1UL,1UL,1UL,17UL,7UL,23UL,199UL,241UL,455UL,135UL,0UL};
        const std::uint32_t dim206Linitializers[] = {
            1UL,1UL,7UL,15UL,27UL,29UL,105UL,171UL,337UL,503UL,1817UL,0UL};
        const std::uint32_t dim207Linitializers[] = {
            1UL,1UL,3UL,7UL,21UL,35UL,61UL,71UL,405UL,647UL,2045UL,0UL};
        const std::uint32_t dim208Linitializers[] = {
            1UL,1UL,1UL,1UL,1UL,15UL,65UL,167UL,501UL,79UL,737UL,0UL};
        const std::uint32_t dim209Linitializers[] = {
            1UL,1UL,5UL,1UL,3UL,49UL,27UL,189UL,341UL,615UL,1287UL,0UL};
        const std::uint32_t dim210Linitializers[] = {
            1UL,1UL,1UL,9UL,1UL,7UL,31UL,159UL,503UL,327UL,1613UL,0UL};
        const std::uint32_t dim211Linitializers[] = {
            1UL,3UL,3UL,3UL,3UL,23UL,99UL,115UL,323UL,997UL,987UL,0UL};
        const std::uint32_t dim212Linitializers[] = {
            1UL,1UL,1UL,9UL,19UL,33UL,93UL,247UL,509UL,453UL,891UL,0UL};
        const std::uint32_t dim213Linitializers[] = {
            1UL,1UL,3UL,1UL,13UL,19UL,35UL,153UL,161UL,633UL,445UL,0UL};
        const std::uint32_t dim214Linitializers[] = {
            1UL,3UL,5UL,15UL,31UL,5UL,87UL,197UL,183UL,783UL,1823UL,0UL};
        const std::uint32_t dim215Linitializers[] = {
            1UL,1UL,7UL,5UL,19UL,63UL,69UL,221UL,129UL,231UL,1195UL,0UL};
        const std::uint32_t dim216Linitializers[] = {
            1UL,1UL,5UL,5UL,13UL,23UL,19UL,231UL,245UL,917UL,379UL,0UL};
        const std::uint32_t dim217Linitializers[] = {
            1UL,3UL,1UL,15UL,19UL,43UL,27UL,223UL,171UL,413UL,125UL,0UL};
        const std::uint32_t dim218Linitializers[] = {
            1UL,1UL,1UL,9UL,1UL,59UL,21UL,15UL,509UL,207UL,589UL,0UL};
        const std::uint32_t dim219Linitializers[] = {
            1UL,3UL,5UL,3UL,19UL,31UL,113UL,19UL,23UL,733UL,499UL,0UL};
        const std::uint32_t dim220Linitializers[] = {
            1UL,1UL,7UL,1UL,19UL,51UL,101UL,165UL,47UL,925UL,1093UL,0UL};
        const std::uint32_t dim221Linitializers[] = {
            1UL,3UL,3UL,9UL,15UL,21UL,43UL,243UL,237UL,461UL,1361UL,0UL};
        const std::uint32_t dim222Linitializers[] = {
            1UL,1UL,1UL,9UL,17UL,15UL,75UL,75UL,113UL,715UL,1419UL,0UL};
        const std::uint32_t dim223Linitializers[] = {
            1UL,1UL,7UL,13UL,17UL,1UL,99UL,15UL,347UL,721UL,1405UL,0UL};
        const std::uint32_t dim224Linitializers[] = {
            1UL,1UL,7UL,15UL,7UL,27UL,23UL,183UL,39UL,59UL,571UL,0UL};
        const std::uint32_t dim225Linitializers[] = {
            1UL,3UL,5UL,9UL,7UL,43UL,35UL,165UL,463UL,567UL,859UL,0UL};
        const std::uint32_t dim226Linitializers[] = {
            1UL,3UL,3UL,11UL,15UL,19UL,17UL,129UL,311UL,343UL,15UL,0UL};
        const std::uint32_t dim227Linitializers[] = {
            1UL,1UL,1UL,15UL,31UL,59UL,63UL,39UL,347UL,359UL,105UL,0UL};
        const std::uint32_t dim228Linitializers[] = {
            1UL,1UL,1UL,15UL,5UL,43UL,87UL,241UL,109UL,61UL,685UL,0UL};
        const std::uint32_t dim229Linitializers[] = {
            1UL,1UL,7UL,7UL,9UL,39UL,121UL,127UL,369UL,579UL,853UL,0UL};
        const std::uint32_t dim230Linitializers[] = {
            1UL,1UL,1UL,1UL,17UL,15UL,15UL,95UL,325UL,627UL,299UL,0UL};
        const std::uint32_t dim231Linitializers[] = {
            1UL,1UL,3UL,13UL,31UL,53UL,85UL,111UL,289UL,811UL,1635UL,0UL};
        const std::uint32_t dim232Linitializers[] = {
            1UL,3UL,7UL,1UL,19UL,29UL,75UL,185UL,153UL,573UL,653UL,0UL};
        const std::uint32_t dim233Linitializers[] = {
            1UL,3UL,7UL,1UL,29UL,31UL,55UL,91UL,249UL,247UL,1015UL,0UL};
        const std::uint32_t dim234Linitializers[] = {
            1UL,3UL,5UL,7UL,1UL,49UL,113UL,139UL,257UL,127UL,307UL,0UL};
        const std::uint32_t dim235Linitializers[] = {
            1UL,3UL,5UL,9UL,15UL,15UL,123UL,105UL,105UL,225UL,1893UL,0UL};
        const std::uint32_t dim236Linitializers[] = {
            1UL,3UL,3UL,1UL,15UL,5UL,105UL,249UL,73UL,709UL,1557UL,0UL};
        const std::uint32_t dim237Linitializers[] = {
            1UL,1UL,1UL,9UL,17UL,31UL,113UL,73UL,65UL,701UL,1439UL,0UL};
        const std::uint32_t dim238Linitializers[] = {
            1UL,3UL,5UL,15UL,13UL,21UL,117UL,131UL,243UL,859UL,323UL,0UL};
        const std::uint32_t dim239Linitializers[] = {
            1UL,1UL,1UL,9UL,19UL,15UL,69UL,149UL,89UL,681UL,515UL,0UL};
        const std::uint32_t dim240Linitializers[] = {
            1UL,1UL,1UL,5UL,29UL,13UL,21UL,97UL,301UL,27UL,967UL,0UL};
        const std::uint32_t dim241Linitializers[] = {
            1UL,1UL,3UL,3UL,15UL,45UL,107UL,227UL,495UL,769UL,1935UL,0UL};
        const std::uint32_t dim242Linitializers[] = {
            1UL,1UL,1UL,11UL,5UL,27UL,41UL,173UL,261UL,703UL,1349UL,0UL};
        const std::uint32_t dim243Linitializers[] = {
            1UL,3UL,3UL,3UL,11UL,35UL,97UL,43UL,501UL,563UL,1331UL,0UL};
        const std::uint32_t dim244Linitializers[] = {
            1UL,1UL,1UL,7UL,1UL,17UL,87UL,17UL,429UL,245UL,1941UL,0UL};
        const std::uint32_t dim245Linitializers[] = {
            1UL,1UL,7UL,15UL,29UL,13UL,1UL,175UL,425UL,233UL,797UL,0UL};
        const std::uint32_t dim246Linitializers[] = {
            1UL,1UL,3UL,11UL,21UL,57UL,49UL,49UL,163UL,685UL,701UL,0UL};
        const std::uint32_t dim247Linitializers[] = {
            1UL,3UL,3UL,7UL,11UL,45UL,107UL,111UL,379UL,703UL,1403UL,0UL};
        const std::uint32_t dim248Linitializers[] = {
            1UL,1UL,7UL,3UL,21UL,7UL,117UL,49UL,469UL,37UL,775UL,0UL};
        const std::uint32_t dim249Linitializers[] = {
            1UL,1UL,5UL,15UL,31UL,63UL,101UL,77UL,507UL,489UL,1955UL,0UL};
        const std::uint32_t dim250Linitializers[] = {
            1UL,3UL,3UL,11UL,19UL,21UL,101UL,255UL,203UL,673UL,665UL,0UL};
        const std::uint32_t dim251Linitializers[] = {
            1UL,3UL,3UL,15UL,17UL,47UL,125UL,187UL,271UL,899UL,2003UL,0UL};
        const std::uint32_t dim252Linitializers[] = {
            1UL,1UL,7UL,7UL,1UL,35UL,13UL,235UL,5UL,337UL,905UL,0UL};
        const std::uint32_t dim253Linitializers[] = {
            1UL,3UL,1UL,15UL,1UL,43UL,1UL,27UL,37UL,695UL,1429UL,0UL};
        const std::uint32_t dim254Linitializers[] = {
            1UL,3UL,1UL,11UL,21UL,27UL,93UL,161UL,299UL,665UL,495UL,0UL};
        const std::uint32_t dim255Linitializers[] = {
            1UL,3UL,3UL,15UL,3UL,1UL,81UL,111UL,105UL,547UL,897UL,0UL};
        const std::uint32_t dim256Linitializers[] = {
            1UL,3UL,5UL,1UL,3UL,53UL,97UL,253UL,401UL,827UL,1467UL,0UL};
        const std::uint32_t dim257Linitializers[] = {
            1UL,1UL,1UL,5UL,19UL,59UL,105UL,125UL,271UL,351UL,719UL,0UL};
        const std::uint32_t dim258Linitializers[] = {
            1UL,3UL,5UL,13UL,7UL,11UL,91UL,41UL,441UL,759UL,1827UL,0UL};
        const std::uint32_t dim259Linitializers[] = {
            1UL,3UL,7UL,11UL,29UL,61UL,61UL,23UL,307UL,863UL,363UL,0UL};
        const std::uint32_t dim260Linitializers[] = {
            1UL,1UL,7UL,1UL,15UL,35UL,29UL,133UL,415UL,473UL,1737UL,0UL};
        const std::uint32_t dim261Linitializers[] = {
            1UL,1UL,1UL,13UL,7UL,33UL,35UL,225UL,117UL,681UL,1545UL,0UL};
        const std::uint32_t dim262Linitializers[] = {
            1UL,1UL,1UL,3UL,5UL,41UL,83UL,247UL,13UL,373UL,1091UL,0UL};
        const std::uint32_t dim263Linitializers[] = {
            1UL,3UL,1UL,13UL,25UL,61UL,71UL,217UL,233UL,313UL,547UL,0UL};
        const std::uint32_t dim264Linitializers[] = {
            1UL,3UL,1UL,7UL,3UL,29UL,3UL,49UL,93UL,465UL,15UL,0UL};
        const std::uint32_t dim265Linitializers[] = {
            1UL,1UL,1UL,9UL,17UL,61UL,99UL,163UL,129UL,485UL,1087UL,0UL};
        const std::uint32_t dim266Linitializers[] = {
            1UL,1UL,1UL,9UL,9UL,33UL,31UL,163UL,145UL,649UL,253UL,0UL};
        const std::uint32_t dim267Linitializers[] = {
            1UL,1UL,1UL,1UL,17UL,63UL,43UL,235UL,287UL,111UL,567UL,0UL};
        const std::uint32_t dim268Linitializers[] = {
            1UL,3UL,5UL,13UL,29UL,7UL,11UL,69UL,153UL,127UL,449UL,0UL};
        const std::uint32_t dim269Linitializers[] = {
            1UL,1UL,5UL,9UL,11UL,21UL,15UL,189UL,431UL,493UL,1219UL,0UL};
        const std::uint32_t dim270Linitializers[] = {
            1UL,1UL,1UL,15UL,19UL,5UL,47UL,91UL,399UL,293UL,1743UL,0UL};
        const std::uint32_t dim271Linitializers[] = {
            1UL,3UL,3UL,11UL,29UL,53UL,53UL,225UL,409UL,303UL,333UL,0UL};
        const std::uint32_t dim272Linitializers[] = {
            1UL,1UL,1UL,15UL,31UL,31UL,21UL,81UL,147UL,287UL,1753UL,0UL};
        const std::uint32_t dim273Linitializers[] = {
            1UL,3UL,5UL,5UL,5UL,63UL,35UL,125UL,41UL,687UL,1793UL,0UL};
        const std::uint32_t dim274Linitializers[] = {
            1UL,1UL,1UL,9UL,19UL,59UL,107UL,219UL,455UL,971UL,297UL,0UL};
        const std::uint32_t dim275Linitializers[] = {
            1UL,1UL,3UL,5UL,3UL,51UL,121UL,31UL,245UL,105UL,1311UL,0UL};
        const std::uint32_t dim276Linitializers[] = {
            1UL,3UL,1UL,5UL,5UL,57UL,75UL,107UL,161UL,431UL,1693UL,0UL};
        const std::uint32_t dim277Linitializers[] = {
            1UL,3UL,1UL,3UL,19UL,53UL,27UL,31UL,191UL,565UL,1015UL,0UL};
        const std::uint32_t dim278Linitializers[] = {
            1UL,3UL,5UL,13UL,9UL,41UL,35UL,249UL,287UL,49UL,123UL,0UL};
        const std::uint32_t dim279Linitializers[] = {
            1UL,1UL,5UL,7UL,27UL,17UL,21UL,3UL,151UL,885UL,1165UL,0UL};
        const std::uint32_t dim280Linitializers[] = {
            1UL,1UL,7UL,1UL,15UL,17UL,65UL,139UL,427UL,339UL,1171UL,0UL};
        const std::uint32_t dim281Linitializers[] = {
            1UL,1UL,1UL,5UL,23UL,5UL,9UL,89UL,321UL,907UL,391UL,0UL};
        const std::uint32_t dim282Linitializers[] = {
            1UL,1UL,7UL,9UL,15UL,1UL,77UL,71UL,87UL,701UL,917UL,0UL};
        const std::uint32_t dim283Linitializers[] = {
            1UL,1UL,7UL,1UL,17UL,37UL,115UL,127UL,469UL,779UL,1543UL,0UL};
        const std::uint32_t dim284Linitializers[] = {
            1UL,3UL,7UL,3UL,5UL,61UL,15UL,37UL,301UL,951UL,1437UL,0UL};
        const std::uint32_t dim285Linitializers[] = {
            1UL,1UL,1UL,13UL,9UL,51UL,127UL,145UL,229UL,55UL,1567UL,0UL};
        const std::uint32_t dim286Linitializers[] = {
            1UL,3UL,7UL,15UL,19UL,47UL,53UL,153UL,295UL,47UL,1337UL,0UL};
        const std::uint32_t dim287Linitializers[] = {
            1UL,3UL,3UL,5UL,11UL,31UL,29UL,133UL,327UL,287UL,507UL,0UL};
        const std::uint32_t dim288Linitializers[] = {
            1UL,1UL,7UL,7UL,25UL,31UL,37UL,199UL,25UL,927UL,1317UL,0UL};
        const std::uint32_t dim289Linitializers[] = {
            1UL,1UL,7UL,9UL,3UL,39UL,127UL,167UL,345UL,467UL,759UL,0UL};
        const std::uint32_t dim290Linitializers[] = {
            1UL,1UL,1UL,1UL,31UL,21UL,15UL,101UL,293UL,787UL,1025UL,0UL};
        const std::uint32_t dim291Linitializers[] = {
            1UL,1UL,5UL,3UL,11UL,41UL,105UL,109UL,149UL,837UL,1813UL,0UL};
        const std::uint32_t dim292Linitializers[] = {
            1UL,1UL,3UL,5UL,29UL,13UL,19UL,97UL,309UL,901UL,753UL,0UL};
        const std::uint32_t dim293Linitializers[] = {
            1UL,1UL,7UL,1UL,19UL,17UL,31UL,39UL,173UL,361UL,1177UL,0UL};
        const std::uint32_t dim294Linitializers[] = {
            1UL,3UL,3UL,3UL,3UL,41UL,81UL,7UL,341UL,491UL,43UL,0UL};
        const std::uint32_t dim295Linitializers[] = {
            1UL,1UL,7UL,7UL,31UL,35UL,29UL,77UL,11UL,335UL,1275UL,0UL};
        const std::uint32_t dim296Linitializers[] = {
            1UL,3UL,3UL,15UL,17UL,45UL,19UL,63UL,151UL,849UL,129UL,0UL};
        const std::uint32_t dim297Linitializers[] = {
            1UL,1UL,7UL,5UL,7UL,13UL,47UL,73UL,79UL,31UL,499UL,0UL};
        const std::uint32_t dim298Linitializers[] = {
            1UL,3UL,1UL,11UL,1UL,41UL,59UL,151UL,247UL,115UL,1295UL,0UL};
        const std::uint32_t dim299Linitializers[] = {
            1UL,1UL,1UL,9UL,31UL,37UL,73UL,23UL,295UL,483UL,179UL,0UL};
        const std::uint32_t dim300Linitializers[] = {
            1UL,3UL,1UL,15UL,13UL,63UL,81UL,27UL,169UL,825UL,2037UL,0UL};
        const std::uint32_t dim301Linitializers[] = {
            1UL,3UL,5UL,15UL,7UL,11UL,73UL,1UL,451UL,101UL,2039UL,0UL};
        const std::uint32_t dim302Linitializers[] = {
            1UL,3UL,5UL,3UL,13UL,53UL,31UL,137UL,173UL,319UL,1521UL,0UL};
        const std::uint32_t dim303Linitializers[] = {
            1UL,3UL,1UL,3UL,29UL,1UL,73UL,227UL,377UL,337UL,1189UL,0UL};
        const std::uint32_t dim304Linitializers[] = {
            1UL,3UL,3UL,13UL,27UL,9UL,31UL,101UL,229UL,165UL,1983UL,0UL};
        const std::uint32_t dim305Linitializers[] = {
            1UL,3UL,1UL,13UL,13UL,19UL,19UL,111UL,319UL,421UL,223UL,0UL};
        const std::uint32_t dim306Linitializers[] = {
            1UL,1UL,7UL,15UL,25UL,37UL,61UL,55UL,359UL,255UL,1955UL,0UL};
        const std::uint32_t dim307Linitializers[] = {
            1UL,1UL,5UL,13UL,17UL,43UL,49UL,215UL,383UL,915UL,51UL,0UL};
        const std::uint32_t dim308Linitializers[] = {
            1UL,1UL,3UL,1UL,3UL,7UL,13UL,119UL,155UL,585UL,967UL,0UL};
        const std::uint32_t dim309Linitializers[] = {
            1UL,3UL,1UL,13UL,1UL,63UL,125UL,21UL,103UL,287UL,457UL,0UL};
        const std::uint32_t dim310Linitializers[] = {
            1UL,1UL,7UL,1UL,31UL,17UL,125UL,137UL,345UL,379UL,1925UL,0UL};
        const std::uint32_t dim311Linitializers[] = {
            1UL,1UL,3UL,5UL,5UL,25UL,119UL,153UL,455UL,271UL,2023UL,0UL};
        const std::uint32_t dim312Linitializers[] = {
            1UL,1UL,7UL,9UL,9UL,37UL,115UL,47UL,5UL,255UL,917UL,0UL};
        const std::uint32_t dim313Linitializers[] = {
            1UL,3UL,5UL,3UL,31UL,21UL,75UL,203UL,489UL,593UL,1UL,0UL};
        const std::uint32_t dim314Linitializers[] = {
            1UL,3UL,7UL,15UL,19UL,63UL,123UL,153UL,135UL,977UL,1875UL,0UL};
        const std::uint32_t dim315Linitializers[] = {
            1UL,1UL,1UL,1UL,5UL,59UL,31UL,25UL,127UL,209UL,745UL,0UL};
        const std::uint32_t dim316Linitializers[] = {
            1UL,1UL,1UL,1UL,19UL,45UL,67UL,159UL,301UL,199UL,535UL,0UL};
        const std::uint32_t dim317Linitializers[] = {
            1UL,1UL,7UL,1UL,31UL,17UL,19UL,225UL,369UL,125UL,421UL,0UL};
        const std::uint32_t dim318Linitializers[] = {
            1UL,3UL,3UL,11UL,7UL,59UL,115UL,197UL,459UL,469UL,1055UL,0UL};
        const std::uint32_t dim319Linitializers[] = {
            1UL,3UL,1UL,3UL,27UL,45UL,35UL,131UL,349UL,101UL,411UL,0UL};
        const std::uint32_t dim320Linitializers[] = {
            1UL,3UL,7UL,11UL,9UL,3UL,67UL,145UL,299UL,253UL,1339UL,0UL};
        const std::uint32_t dim321Linitializers[] = {
            1UL,3UL,3UL,11UL,9UL,37UL,123UL,229UL,273UL,269UL,515UL,0UL};
        const std::uint32_t dim322Linitializers[] = {
            1UL,3UL,7UL,15UL,11UL,25UL,75UL,5UL,367UL,217UL,951UL,0UL};
        const std::uint32_t dim323Linitializers[] = {
            1UL,1UL,3UL,7UL,9UL,23UL,63UL,237UL,385UL,159UL,1273UL,0UL};
        const std::uint32_t dim324Linitializers[] = {
            1UL,1UL,5UL,11UL,23UL,5UL,55UL,193UL,109UL,865UL,663UL,0UL};
        const std::uint32_t dim325Linitializers[] = {
            1UL,1UL,7UL,15UL,1UL,57UL,17UL,141UL,51UL,217UL,1259UL,0UL};
        const std::uint32_t dim326Linitializers[] = {
            1UL,1UL,3UL,3UL,15UL,7UL,89UL,233UL,71UL,329UL,203UL,0UL};
        const std::uint32_t dim327Linitializers[] = {
            1UL,3UL,7UL,11UL,11UL,1UL,19UL,155UL,89UL,437UL,573UL,0UL};
        const std::uint32_t dim328Linitializers[] = {
            1UL,3UL,1UL,9UL,27UL,61UL,47UL,109UL,161UL,913UL,1681UL,0UL};
        const std::uint32_t dim329Linitializers[] = {
            1UL,1UL,7UL,15UL,1UL,33UL,19UL,15UL,23UL,913UL,989UL,0UL};
        const std::uint32_t dim330Linitializers[] = {
            1UL,3UL,1UL,1UL,25UL,39UL,119UL,193UL,13UL,571UL,157UL,0UL};
        const std::uint32_t dim331Linitializers[] = {
            1UL,1UL,7UL,13UL,9UL,55UL,59UL,147UL,361UL,935UL,515UL,0UL};
        const std::uint32_t dim332Linitializers[] = {
            1UL,1UL,1UL,9UL,7UL,59UL,67UL,117UL,71UL,855UL,1493UL,0UL};
        const std::uint32_t dim333Linitializers[] = {
            1UL,3UL,1UL,3UL,13UL,19UL,57UL,141UL,305UL,275UL,1079UL,0UL};
        const std::uint32_t dim334Linitializers[] = {
            1UL,1UL,1UL,9UL,17UL,61UL,33UL,7UL,43UL,931UL,781UL,0UL};
        const std::uint32_t dim335Linitializers[] = {
            1UL,1UL,3UL,1UL,11UL,17UL,21UL,97UL,295UL,277UL,1721UL,0UL};
        const std::uint32_t dim336Linitializers[] = {
            1UL,3UL,1UL,13UL,15UL,43UL,11UL,241UL,147UL,391UL,1641UL,0UL};
        const std::uint32_t dim337Linitializers[] = {
            1UL,1UL,1UL,1UL,1UL,19UL,37UL,21UL,255UL,263UL,1571UL,0UL};
        const std::uint32_t dim338Linitializers[] = {
            1UL,1UL,3UL,3UL,23UL,59UL,89UL,17UL,475UL,303UL,757UL,543UL,0UL};
        const std::uint32_t dim339Linitializers[] = {
           1UL,3UL,3UL,9UL,11UL,55UL,35UL,159UL,139UL,203UL,1531UL,1825UL,0UL};
        const std::uint32_t dim340Linitializers[] = {
            1UL,1UL,5UL,3UL,17UL,53UL,51UL,241UL,269UL,949UL,1373UL,325UL,0UL};
        const std::uint32_t dim341Linitializers[] = {
            1UL,3UL,7UL,7UL,5UL,29UL,91UL,149UL,239UL,193UL,1951UL,2675UL,0UL};
        const std::uint32_t dim342Linitializers[] = {
            1UL,3UL,5UL,1UL,27UL,33UL,69UL,11UL,51UL,371UL,833UL,2685UL,0UL};
        const std::uint32_t dim343Linitializers[] = {
            1UL,1UL,1UL,15UL,1UL,17UL,35UL,57UL,171UL,1007UL,449UL,367UL,0UL};
        const std::uint32_t dim344Linitializers[] = {
            1UL,1UL,1UL,7UL,25UL,61UL,73UL,219UL,379UL,53UL,589UL,4065UL,0UL};
        const std::uint32_t dim345Linitializers[] = {
            1UL,3UL,5UL,13UL,21UL,29UL,45UL,19UL,163UL,169UL,147UL,597UL,0UL};
        const std::uint32_t dim346Linitializers[] = {
            1UL,1UL,5UL,11UL,21UL,27UL,7UL,17UL,237UL,591UL,255UL,1235UL,0UL};
        const std::uint32_t dim347Linitializers[] = {
            1UL,1UL,7UL,7UL,17UL,41UL,69UL,237UL,397UL,173UL,1229UL,2341UL,0UL};
        const std::uint32_t dim348Linitializers[] = {
            1UL,1UL,3UL,1UL,1UL,33UL,125UL,47UL,11UL,783UL,1323UL,2469UL,0UL};
        const std::uint32_t dim349Linitializers[] = {
            1UL,3UL,1UL,11UL,3UL,39UL,35UL,133UL,153UL,55UL,1171UL,3165UL,0UL};
        const std::uint32_t dim350Linitializers[] = {
           1UL,1UL,5UL,11UL,27UL,23UL,103UL,245UL,375UL,753UL,477UL,2165UL,0UL};
        const std::uint32_t dim351Linitializers[] = {
          1UL,3UL,1UL,15UL,15UL,49UL,127UL,223UL,387UL,771UL,1719UL,1465UL,0UL};
        const std::uint32_t dim352Linitializers[] = {
            1UL,1UL,1UL,9UL,11UL,9UL,17UL,185UL,239UL,899UL,1273UL,3961UL,0UL};
        const std::uint32_t dim353Linitializers[] = {
            1UL,1UL,3UL,13UL,11UL,51UL,73UL,81UL,389UL,647UL,1767UL,1215UL,0UL};
        const std::uint32_t dim354Linitializers[] = {
            1UL,3UL,5UL,15UL,19UL,9UL,69UL,35UL,349UL,977UL,1603UL,1435UL,0UL};
        const std::uint32_t dim355Linitializers[] = {
            1UL,1UL,1UL,1UL,19UL,59UL,123UL,37UL,41UL,961UL,181UL,1275UL,0UL};
        const std::uint32_t dim356Linitializers[] = {
            1UL,1UL,1UL,1UL,31UL,29UL,37UL,71UL,205UL,947UL,115UL,3017UL,0UL};
        const std::uint32_t dim357Linitializers[] = {
            1UL,1UL,7UL,15UL,5UL,37UL,101UL,169UL,221UL,245UL,687UL,195UL,0UL};
        const std::uint32_t dim358Linitializers[] = {
            1UL,1UL,1UL,1UL,19UL,9UL,125UL,157UL,119UL,283UL,1721UL,743UL,0UL};
        const std::uint32_t dim359Linitializers[] = {
            1UL,1UL,7UL,3UL,1UL,7UL,61UL,71UL,119UL,257UL,1227UL,2893UL,0UL};
        const std::uint32_t dim360Linitializers[] = {
            1UL,3UL,3UL,3UL,25UL,41UL,25UL,225UL,31UL,57UL,925UL,2139UL,0UL};


        const std::uint32_t * const Linitializers[359] = {
            dim02SLinitializers,
            dim03SLinitializers,
            dim04SLinitializers,
            dim05SLinitializers,
            dim06SLinitializers,
            dim07SLinitializers,
            dim08SLinitializers,
            dim09SLinitializers,
            dim10SLinitializers,
            dim11SLinitializers,
            dim12SLinitializers,
            dim13SLinitializers,
            dim14SLinitializers,
            dim15SLinitializers,
            dim16SLinitializers,
            dim17SLinitializers,
            dim18SLinitializers,
            dim19SLinitializers,
            dim20SLinitializers,
            dim21SLinitializers,
            dim22SLinitializers,
            dim23SLinitializers,
            dim24SLinitializers,
            dim25SLinitializers,
            dim26SLinitializers,
            dim27SLinitializers,
            dim28SLinitializers,
            dim29SLinitializers,
            dim30SLinitializers,
            dim31SLinitializers,
            dim32SLinitializers,
            dim33SLinitializers,
            dim34SLinitializers,
            dim35SLinitializers,
            dim36SLinitializers,
            dim37SLinitializers,
            dim38SLinitializers,
            dim39SLinitializers,
            dim40SLinitializers,
            dim041Linitializers,
            dim042Linitializers,
            dim043Linitializers,
            dim044Linitializers,
            dim045Linitializers,
            dim046Linitializers,
            dim047Linitializers,
            dim048Linitializers,
            dim049Linitializers,
            dim050Linitializers,
            dim051Linitializers,
            dim052Linitializers,
            dim053Linitializers,
            dim054Linitializers,
            dim055Linitializers,
            dim056Linitializers,
            dim057Linitializers,
            dim058Linitializers,
            dim059Linitializers,
            dim060Linitializers,
            dim061Linitializers,
            dim062Linitializers,
            dim063Linitializers,
            dim064Linitializers,
            dim065Linitializers,
            dim066Linitializers,
            dim067Linitializers,
            dim068Linitializers,
            dim069Linitializers,
            dim070Linitializers,
            dim071Linitializers,
            dim072Linitializers,
            dim073Linitializers,
            dim074Linitializers,
            dim075Linitializers,
            dim076Linitializers,
            dim077Linitializers,
            dim078Linitializers,
            dim079Linitializers,
            dim080Linitializers,
            dim081Linitializers,
            dim082Linitializers,
            dim083Linitializers,
            dim084Linitializers,
            dim085Linitializers,
            dim086Linitializers,
            dim087Linitializers,
            dim088Linitializers,
            dim089Linitializers,
            dim090Linitializers,
            dim091Linitializers,
            dim092Linitializers,
            dim093Linitializers,
            dim094Linitializers,
            dim095Linitializers,
            dim096Linitializers,
            dim097Linitializers,
            dim098Linitializers,
            dim099Linitializers,
            dim100Linitializers,
            dim101Linitializers,
            dim102Linitializers,
            dim103Linitializers,
            dim104Linitializers,
            dim105Linitializers,
            dim106Linitializers,
            dim107Linitializers,
            dim108Linitializers,
            dim109Linitializers,
            dim110Linitializers,
            dim111Linitializers,
            dim112Linitializers,
            dim113Linitializers,
            dim114Linitializers,
            dim115Linitializers,
            dim116Linitializers,
            dim117Linitializers,
            dim118Linitializers,
            dim119Linitializers,
            dim120Linitializers,
            dim121Linitializers,
            dim122Linitializers,
            dim123Linitializers,
            dim124Linitializers,
            dim125Linitializers,
            dim126Linitializers,
            dim127Linitializers,
            dim128Linitializers,
            dim129Linitializers,
            dim130Linitializers,
            dim131Linitializers,
            dim132Linitializers,
            dim133Linitializers,
            dim134Linitializers,
            dim135Linitializers,
            dim136Linitializers,
            dim137Linitializers,
            dim138Linitializers,
            dim139Linitializers,
            dim140Linitializers,
            dim141Linitializers,
            dim142Linitializers,
            dim143Linitializers,
            dim144Linitializers,
            dim145Linitializers,
            dim146Linitializers,
            dim147Linitializers,
            dim148Linitializers,
            dim149Linitializers,
            dim150Linitializers,
            dim151Linitializers,
            dim152Linitializers,
            dim153Linitializers,
            dim154Linitializers,
            dim155Linitializers,
            dim156Linitializers,
            dim157Linitializers,
            dim158Linitializers,
            dim159Linitializers,
            dim160Linitializers,
            dim161Linitializers,
            dim162Linitializers,
            dim163Linitializers,
            dim164Linitializers,
            dim165Linitializers,
            dim166Linitializers,
            dim167Linitializers,
            dim168Linitializers,
            dim169Linitializers,
            dim170Linitializers,
            dim171Linitializers,
            dim172Linitializers,
            dim173Linitializers,
            dim174Linitializers,
            dim175Linitializers,
            dim176Linitializers,
            dim177Linitializers,
            dim178Linitializers,
            dim179Linitializers,
            dim180Linitializers,
            dim181Linitializers,
            dim182Linitializers,
            dim183Linitializers,
            dim184Linitializers,
            dim185Linitializers,
            dim186Linitializers,
            dim187Linitializers,
            dim188Linitializers,
            dim189Linitializers,
            dim190Linitializers,
            dim191Linitializers,
            dim192Linitializers,
            dim193Linitializers,
            dim194Linitializers,
            dim195Linitializers,
            dim196Linitializers,
            dim197Linitializers,
            dim198Linitializers,
            dim199Linitializers,
            dim200Linitializers,
            dim201Linitializers,
            dim202Linitializers,
            dim203Linitializers,
            dim204Linitializers,
            dim205Linitializers,
            dim206Linitializers,
            dim207Linitializers,
            dim208Linitializers,
            dim209Linitializers,
            dim210Linitializers,
            dim211Linitializers,
            dim212Linitializers,
            dim213Linitializers,
            dim214Linitializers,
            dim215Linitializers,
            dim216Linitializers,
            dim217Linitializers,
            dim218Linitializers,
            dim219Linitializers,
            dim220Linitializers,
            dim221Linitializers,
            dim222Linitializers,
            dim223Linitializers,
            dim224Linitializers,
            dim225Linitializers,
            dim226Linitializers,
            dim227Linitializers,
            dim228Linitializers,
            dim229Linitializers,
            dim230Linitializers,
            dim231Linitializers,
            dim232Linitializers,
            dim233Linitializers,
            dim234Linitializers,
            dim235Linitializers,
            dim236Linitializers,
            dim237Linitializers,
            dim238Linitializers,
            dim239Linitializers,
            dim240Linitializers,
            dim241Linitializers,
            dim242Linitializers,
            dim243Linitializers,
            dim244Linitializers,
            dim245Linitializers,
            dim246Linitializers,
            dim247Linitializers,
            dim248Linitializers,
            dim249Linitializers,
            dim250Linitializers,
            dim251Linitializers,
            dim252Linitializers,
            dim253Linitializers,
            dim254Linitializers,
            dim255Linitializers,
            dim256Linitializers,
            dim257Linitializers,
            dim258Linitializers,
            dim259Linitializers,
            dim260Linitializers,
            dim261Linitializers,
            dim262Linitializers,
            dim263Linitializers,
            dim264Linitializers,
            dim265Linitializers,
            dim266Linitializers,
            dim267Linitializers,
            dim268Linitializers,
            dim269Linitializers,
            dim270Linitializers,
            dim271Linitializers,
            dim272Linitializers,
            dim273Linitializers,
            dim274Linitializers,
            dim275Linitializers,
            dim276Linitializers,
            dim277Linitializers,
            dim278Linitializers,
            dim279Linitializers,
            dim280Linitializers,
            dim281Linitializers,
            dim282Linitializers,
            dim283Linitializers,
            dim284Linitializers,
            dim285Linitializers,
            dim286Linitializers,
            dim287Linitializers,
            dim288Linitializers,
            dim289Linitializers,
            dim290Linitializers,
            dim291Linitializers,
            dim292Linitializers,
            dim293Linitializers,
            dim294Linitializers,
            dim295Linitializers,
            dim296Linitializers,
            dim297Linitializers,
            dim298Linitializers,
            dim299Linitializers,
            dim300Linitializers,
            dim301Linitializers,
            dim302Linitializers,
            dim303Linitializers,
            dim304Linitializers,
            dim305Linitializers,
            dim306Linitializers,
            dim307Linitializers,
            dim308Linitializers,
            dim309Linitializers,
            dim310Linitializers,
            dim311Linitializers,
            dim312Linitializers,
            dim313Linitializers,
            dim314Linitializers,
            dim315Linitializers,
            dim316Linitializers,
            dim317Linitializers,
            dim318Linitializers,
            dim319Linitializers,
            dim320Linitializers,
            dim321Linitializers,
            dim322Linitializers,
            dim323Linitializers,
            dim324Linitializers,
            dim325Linitializers,
            dim326Linitializers,
            dim327Linitializers,
            dim328Linitializers,
            dim329Linitializers,
            dim330Linitializers,
            dim331Linitializers,
            dim332Linitializers,
            dim333Linitializers,
            dim334Linitializers,
            dim335Linitializers,
            dim336Linitializers,
            dim337Linitializers,
            dim338Linitializers,
            dim339Linitializers,
            dim340Linitializers,
            dim341Linitializers,
            dim342Linitializers,
            dim343Linitializers,
            dim344Linitializers,
            dim345Linitializers,
            dim346Linitializers,
            dim347Linitializers,
            dim348Linitializers,
            dim349Linitializers,
            dim350Linitializers,
            dim351Linitializers,
            dim352Linitializers,
            dim353Linitializers,
            dim354Linitializers,
            dim355Linitializers,
            dim356Linitializers,
            dim357Linitializers,
            dim358Linitializers,
            dim359Linitializers,
            dim360Linitializers
        };

            const std::uint32_t dim1KuoInit[]   =   {   1   ,0 };
            const std::uint32_t dim2KuoInit[]   =   {   1   ,   1   ,0 };
            const std::uint32_t dim3KuoInit[]   =   {   1   ,   1   ,   1   ,0 };
            const std::uint32_t dim4KuoInit[]   =   {   1   ,   3   ,   1   ,0 };
            const std::uint32_t dim5KuoInit[]   =   {   1   ,   1   ,   7   ,   13  ,0 };
            const std::uint32_t dim6KuoInit[]   =   {   1   ,   1   ,   3   ,   7   ,0 };
            const std::uint32_t dim7KuoInit[]   =   {   1   ,   3   ,   1   ,   7   ,   21  ,0 };
            const std::uint32_t dim8KuoInit[]   =   {   1   ,   3   ,   1   ,   3   ,   9   ,0 };
            const std::uint32_t dim9KuoInit[]   =   {   1   ,   1   ,   5   ,   9   ,   13  ,0 };
            const std::uint32_t dim10KuoInit[]  =   {   1   ,   1   ,   3   ,   9   ,   13  ,0 };
            const std::uint32_t dim11KuoInit[]  =   {   1   ,   1   ,   5   ,   3   ,   7   ,0 };
            const std::uint32_t dim12KuoInit[]  =   {   1   ,   1   ,   5   ,   7   ,   11  ,0 };
            const std::uint32_t dim13KuoInit[]  =   {   1   ,   3   ,   3   ,   13  ,   15  ,   43  ,0 };
            const std::uint32_t dim14KuoInit[]  =   {   1   ,   3   ,   5   ,   11  ,   25  ,   45  ,0 };
            const std::uint32_t dim15KuoInit[]  =   {   1   ,   1   ,   3   ,   11  ,   3   ,   45  ,0 };
            const std::uint32_t dim16KuoInit[]  =   {   1   ,   3   ,   5   ,   1   ,   9   ,   21  ,0 };
            const std::uint32_t dim17KuoInit[]  =   {   1   ,   1   ,   3   ,   13  ,   9   ,   9   ,0 };
            const std::uint32_t dim18KuoInit[]  =   {   1   ,   3   ,   5   ,   7   ,   17  ,   53  ,0 };
            const std::uint32_t dim19KuoInit[]  =   {   1   ,   3   ,   1   ,   7   ,   11  ,   51  ,   115 ,0 };
            const std::uint32_t dim20KuoInit[]  =   {   1   ,   1   ,   7   ,   9   ,   25  ,   35  ,   11  ,0 };
            const std::uint32_t dim21KuoInit[]  =   {   1   ,   3   ,   1   ,   1   ,   31  ,   5   ,   1   ,0 };
            const std::uint32_t dim22KuoInit[]  =   {   1   ,   1   ,   5   ,   9   ,   11  ,   1   ,   121 ,0 };
            const std::uint32_t dim23KuoInit[]  =   {   1   ,   1   ,   1   ,   15  ,   11  ,   59  ,   21  ,0 };
            const std::uint32_t dim24KuoInit[]  =   {   1   ,   3   ,   1   ,   3   ,   17  ,   49  ,   51  ,0 };
            const std::uint32_t dim25KuoInit[]  =   {   1   ,   1   ,   5   ,   7   ,   15  ,   25  ,   13  ,0 };
            const std::uint32_t dim26KuoInit[]  =   {   1   ,   3   ,   7   ,   7   ,   1   ,   45  ,   7   ,0 };
            const std::uint32_t dim27KuoInit[]  =   {   1   ,   1   ,   5   ,   7   ,   21  ,   21  ,   37  ,0 };
            const std::uint32_t dim28KuoInit[]  =   {   1   ,   3   ,   1   ,   13  ,   9   ,   49  ,   23  ,0 };
            const std::uint32_t dim29KuoInit[]  =   {   1   ,   1   ,   1   ,   3   ,   3   ,   35  ,   123 ,0 };
            const std::uint32_t dim30KuoInit[]  =   {   1   ,   1   ,   7   ,   5   ,   15  ,   47  ,   117 ,0 };
            const std::uint32_t dim31KuoInit[]  =   {   1   ,   1   ,   3   ,   13  ,   9   ,   23  ,   33  ,0 };
            const std::uint32_t dim32KuoInit[]  =   {   1   ,   1   ,   1   ,   13  ,   25  ,   23  ,   63  ,0 };
            const std::uint32_t dim33KuoInit[]  =   {   1   ,   1   ,   5   ,   3   ,   5   ,   13  ,   91  ,0 };
            const std::uint32_t dim34KuoInit[]  =   {   1   ,   1   ,   5   ,   5   ,   23  ,   7   ,   101 ,0 };
            const std::uint32_t dim35KuoInit[]  =   {   1   ,   3   ,   1   ,   11  ,   9   ,   61  ,   127 ,0 };
            const std::uint32_t dim36KuoInit[]  =   {   1   ,   3   ,   1   ,   9   ,   1   ,   57  ,   93  ,0 };
            const std::uint32_t dim37KuoInit[]  =   {   1   ,   1   ,   1   ,   1   ,   31  ,   31  ,   25  ,   231 ,0 };
            const std::uint32_t dim38KuoInit[]  =   {   1   ,   3   ,   7   ,   7   ,   29  ,   17  ,   59  ,   215 ,0 };
            const std::uint32_t dim39KuoInit[]  =   {   1   ,   1   ,   3   ,   15  ,   5   ,   63  ,   117 ,   217 ,0 };
            const std::uint32_t dim40KuoInit[]  =   {   1   ,   3   ,   1   ,   1   ,   29  ,   5   ,   111 ,   51  ,0 };
            const std::uint32_t dim41KuoInit[]  =   {   1   ,   1   ,   7   ,   1   ,   17  ,   37  ,   11  ,   53  ,0 };
            const std::uint32_t dim42KuoInit[]  =   {   1   ,   3   ,   7   ,   15  ,   29  ,   5   ,   3   ,   67  ,0 };
            const std::uint32_t dim43KuoInit[]  =   {   1   ,   3   ,   7   ,   11  ,   23  ,   27  ,   35  ,   143 ,0 };
            const std::uint32_t dim44KuoInit[]  =   {   1   ,   1   ,   5   ,   11  ,   11  ,   33  ,   103 ,   179 ,0 };
            const std::uint32_t dim45KuoInit[]  =   {   1   ,   3   ,   5   ,   7   ,   13  ,   45  ,   87  ,   143 ,0 };
            const std::uint32_t dim46KuoInit[]  =   {   1   ,   3   ,   1   ,   13  ,   17  ,   17  ,   49  ,   249 ,0 };
            const std::uint32_t dim47KuoInit[]  =   {   1   ,   1   ,   1   ,   3   ,   17  ,   29  ,   75  ,   143 ,0 };
            const std::uint32_t dim48KuoInit[]  =   {   1   ,   1   ,   1   ,   3   ,   19  ,   55  ,   65  ,   109 ,0 };
            const std::uint32_t dim49KuoInit[]  =   {   1   ,   1   ,   7   ,   3   ,   21  ,   29  ,   13  ,   191 ,0 };
            const std::uint32_t dim50KuoInit[]  =   {   1   ,   1   ,   3   ,   7   ,   7   ,   5   ,   97  ,   179 ,0 };
            const std::uint32_t dim51KuoInit[]  =   {   1   ,   3   ,   5   ,   13  ,   1   ,   17  ,   113 ,   149 ,0 };
            const std::uint32_t dim52KuoInit[]  =   {   1   ,   3   ,   3   ,   11  ,   25  ,   13  ,   105 ,   75  ,0 };
            const std::uint32_t dim53KuoInit[]  =   {   1   ,   3   ,   1   ,   13  ,   29  ,   33  ,   71  ,   117 ,   77  ,0 };
            const std::uint32_t dim54KuoInit[]  =   {   1   ,   1   ,   1   ,   1   ,   31  ,   41  ,   9   ,   245 ,   205 ,0 };
            const std::uint32_t dim55KuoInit[]  =   {   1   ,   1   ,   1   ,   15  ,   25  ,   23  ,   111 ,   105 ,   95  ,0 };
            const std::uint32_t dim56KuoInit[]  =   {   1   ,   1   ,   3   ,   5   ,   3   ,   5   ,   81  ,   251 ,   221 ,0 };
            const std::uint32_t dim57KuoInit[]  =   {   1   ,   3   ,   5   ,   5   ,   9   ,   53  ,   37  ,   41  ,   509 ,0 };
            const std::uint32_t dim58KuoInit[]  =   {   1   ,   1   ,   5   ,   15  ,   21  ,   25  ,   77  ,   225 ,   333 ,0 };
            const std::uint32_t dim59KuoInit[]  =   {   1   ,   3   ,   5   ,   13  ,   3   ,   17  ,   1   ,   101 ,   397 ,0 };
            const std::uint32_t dim60KuoInit[]  =   {   1   ,   3   ,   5   ,   11  ,   27  ,   53  ,   115 ,   87  ,   47  ,0 };
            const std::uint32_t dim61KuoInit[]  =   {   1   ,   1   ,   3   ,   11  ,   31  ,   39  ,   21  ,   233 ,   9   ,0 };
            const std::uint32_t dim62KuoInit[]  =   {   1   ,   1   ,   3   ,   15  ,   17  ,   19  ,   73  ,   147 ,   351 ,0 };
            const std::uint32_t dim63KuoInit[]  =   {   1   ,   1   ,   3   ,   3   ,   29  ,   17  ,   1   ,   105 ,   293 ,0 };
            const std::uint32_t dim64KuoInit[]  =   {   1   ,   1   ,   3   ,   15  ,   9   ,   21  ,   103 ,   239 ,   433 ,0 };
            const std::uint32_t dim65KuoInit[]      =   {   1   ,   1   ,   1   ,   15  ,   17  ,   35  ,   49  ,   7   ,   435 ,0 };
            const std::uint32_t dim66KuoInit[]      =   {   1   ,   3   ,   7   ,   3   ,   9   ,   51  ,   91  ,   177 ,   255 ,0 };
            const std::uint32_t dim67KuoInit[]      =   {   1   ,   1   ,   5   ,   5   ,   31  ,   9   ,   39  ,   209 ,   511 ,0 };
            const std::uint32_t dim68KuoInit[]      =   {   1   ,   1   ,   7   ,   3   ,   11  ,   11  ,   19  ,   227 ,   343 ,0 };
            const std::uint32_t dim69KuoInit[]      =   {   1   ,   3   ,   7   ,   3   ,   17  ,   13  ,   105 ,   151 ,   225 ,0 };
            const std::uint32_t dim70KuoInit[]      =   {   1   ,   1   ,   7   ,   11  ,   29  ,   35  ,   105 ,   11  ,   497 ,0 };
            const std::uint32_t dim71KuoInit[]      =   {   1   ,   3   ,   7   ,   15  ,   5   ,   13  ,   31  ,   201 ,   63  ,0 };
            const std::uint32_t dim72KuoInit[]      =   {   1   ,   1   ,   5   ,   7   ,   17  ,   31  ,   9   ,   63  ,   167 ,0 };
            const std::uint32_t dim73KuoInit[]      =   {   1   ,   1   ,   1   ,   13  ,   1   ,   51  ,   9   ,   115 ,   217 ,0 };
            const std::uint32_t dim74KuoInit[]      =   {   1   ,   1   ,   7   ,   15  ,   23  ,   49  ,   125 ,   163 ,   39  ,0 };
            const std::uint32_t dim75KuoInit[]      =   {   1   ,   1   ,   3   ,   13  ,   11  ,   45  ,   77  ,   149 ,   173 ,0 };
            const std::uint32_t dim76KuoInit[]      =   {   1   ,   3   ,   3   ,   3   ,   7   ,   27  ,   43  ,   27  ,   361 ,0 };
            const std::uint32_t dim77KuoInit[]      =   {   1   ,   3   ,   3   ,   5   ,   5   ,   37  ,   9   ,   51  ,   149 ,0 };
            const std::uint32_t dim78KuoInit[]      =   {   1   ,   1   ,   1   ,   15  ,   13  ,   13  ,   49  ,   251 ,   385 ,0 };
            const std::uint32_t dim79KuoInit[]      =   {   1   ,   1   ,   3   ,   7   ,   1   ,   57  ,   27  ,   25  ,   335 ,0 };
            const std::uint32_t dim80KuoInit[]      =   {   1   ,   3   ,   3   ,   9   ,   31  ,   55  ,   41  ,   143 ,   97  ,0 };
            const std::uint32_t dim81KuoInit[]      =   {   1   ,   3   ,   3   ,   11  ,   31  ,   33  ,   65  ,   57  ,   113 ,0 };
            const std::uint32_t dim82KuoInit[]      =   {   1   ,   1   ,   5   ,   13  ,   19  ,   63  ,   5   ,   71  ,   317 ,0 };
            const std::uint32_t dim83KuoInit[]      =   {   1   ,   1   ,   1   ,   5   ,   29  ,   45  ,   35  ,   107 ,   113 ,0 };
            const std::uint32_t dim84KuoInit[]      =   {   1   ,   1   ,   3   ,   7   ,   3   ,   31  ,   81  ,   57  ,   439 ,0 };
            const std::uint32_t dim85KuoInit[]      =   {   1   ,   3   ,   5   ,   5   ,   1   ,   7   ,   3   ,   21  ,   319 ,0 };
            const std::uint32_t dim86KuoInit[]      =   {   1   ,   3   ,   1   ,   15  ,   27  ,   49  ,   25  ,   247 ,   455 ,0 };
            const std::uint32_t dim87KuoInit[]      =   {   1   ,   1   ,   3   ,   5   ,   5   ,   43  ,   105 ,   207 ,   271 ,0 };
            const std::uint32_t dim88KuoInit[]      =   {   1   ,   3   ,   3   ,   7   ,   29  ,   63  ,   25  ,   239 ,   165 ,0 };
            const std::uint32_t dim89KuoInit[]      =   {   1   ,   3   ,   7   ,   1   ,   19  ,   23  ,   87  ,   23  ,   161 ,0 };
            const std::uint32_t dim90KuoInit[]      =   {   1   ,   3   ,   7   ,   5   ,   27  ,   1   ,   15  ,   113 ,   85  ,0 };
            const std::uint32_t dim91KuoInit[]      =   {   1   ,   1   ,   1   ,   13  ,   23  ,   39  ,   103 ,   59  ,   105 ,0 };
            const std::uint32_t dim92KuoInit[]      =   {   1   ,   3   ,   1   ,   15  ,   9   ,   35  ,   65  ,   225 ,   385 ,0 };
            const std::uint32_t dim93KuoInit[]      =   {   1   ,   1   ,   5   ,   9   ,   5   ,   63  ,   109 ,   153 ,   25  ,0 };
            const std::uint32_t dim94KuoInit[]      =   {   1   ,   3   ,   7   ,   11  ,   5   ,   41  ,   103 ,   103 ,   245 ,0 };
            const std::uint32_t dim95KuoInit[]      =   {   1   ,   1   ,   1   ,   3   ,   25  ,   5   ,   71  ,   203 ,   351 ,0 };
            const std::uint32_t dim96KuoInit[]      =   {   1   ,   1   ,   5   ,   5   ,   27  ,   49  ,   111 ,   253 ,   265 ,0 };
            const std::uint32_t dim97KuoInit[]      =   {   1   ,   1   ,   1   ,   11  ,   31  ,   63  ,   91  ,   179 ,   359 ,0 };
            const std::uint32_t dim98KuoInit[]      =   {   1   ,   3   ,   7   ,   1   ,   9   ,   41  ,   117 ,   69  ,   141 ,0 };
            const std::uint32_t dim99KuoInit[]      =   {   1   ,   3   ,   1   ,   5   ,   11  ,   25  ,   7   ,   73  ,   477 ,0 };
            const std::uint32_t dim100KuoInit[]     =   {   1   ,   1   ,   3   ,   1   ,   31  ,   7   ,   51  ,   67  ,   97  ,0 };
            const std::uint32_t dim101KuoInit[]     =   {   1   ,   3   ,   3   ,   15  ,   31  ,   61  ,   27  ,   137 ,   319 ,   605 ,0 };
            const std::uint32_t dim102KuoInit[]     =   {   1   ,   3   ,   5   ,   7   ,   29  ,   45  ,   31  ,   211 ,   287 ,   13  ,0 };
            const std::uint32_t dim103KuoInit[]     =   {   1   ,   3   ,   1   ,   7   ,   25  ,   61  ,   121 ,   91  ,   215 ,   439 ,0 };
            const std::uint32_t dim104KuoInit[]     =   {   1   ,   1   ,   3   ,   11  ,   31  ,   51  ,   31  ,   151 ,   421 ,   195 ,0 };
            const std::uint32_t dim105KuoInit[]     =   {   1   ,   1   ,   5   ,   13  ,   17  ,   23  ,   47  ,   9   ,   33  ,   1003    ,0 };
            const std::uint32_t dim106KuoInit[]     =   {   1   ,   1   ,   1   ,   3   ,   23  ,   5   ,   109 ,   23  ,   125 ,   773 ,0 };
            const std::uint32_t dim107KuoInit[]     =   {   1   ,   3   ,   5   ,   9   ,   7   ,   41  ,   33  ,   81  ,   277 ,   623 ,0 };
            const std::uint32_t dim108KuoInit[]     =   {   1   ,   1   ,   1   ,   11  ,   9   ,   33  ,   51  ,   31  ,   181 ,   985 ,0 };
            const std::uint32_t dim109KuoInit[]     =   {   1   ,   1   ,   7   ,   11  ,   3   ,   37  ,   3   ,   107 ,   405 ,   639 ,0 };
            const std::uint32_t dim110KuoInit[]     =   {   1   ,   1   ,   5   ,   15  ,   17  ,   7   ,   35  ,   221 ,   255 ,   753 ,0 };
            const std::uint32_t dim111KuoInit[]     =   {   1   ,   1   ,   7   ,   3   ,   31  ,   11  ,   113 ,   105 ,   275 ,   683 ,0 };
            const std::uint32_t dim112KuoInit[]     =   {   1   ,   1   ,   3   ,   11  ,   3   ,   39  ,   57  ,   237 ,   189 ,   561 ,0 };
            const std::uint32_t dim113KuoInit[]     =   {   1   ,   3   ,   3   ,   7   ,   17  ,   37  ,   55  ,   97  ,   499 ,   511 ,0 };
            const std::uint32_t dim114KuoInit[]     =   {   1   ,   1   ,   7   ,   11  ,   31  ,   27  ,   21  ,   241 ,   127 ,   279 ,0 };
            const std::uint32_t dim115KuoInit[]     =   {   1   ,   3   ,   1   ,   7   ,   1   ,   19  ,   95  ,   3   ,   511 ,   143 ,0 };
            const std::uint32_t dim116KuoInit[]     =   {   1   ,   3   ,   5   ,   3   ,   21  ,   39  ,   115 ,   155 ,   67  ,   607 ,0 };
            const std::uint32_t dim117KuoInit[]     =   {   1   ,   1   ,   7   ,   7   ,   25  ,   37  ,   33  ,   149 ,   89  ,   997 ,0 };
            const std::uint32_t dim118KuoInit[]     =   {   1   ,   3   ,   1   ,   7   ,   3   ,   7   ,   113 ,   165 ,   235 ,   943 ,0 };
            const std::uint32_t dim119KuoInit[]     =   {   1   ,   3   ,   7   ,   9   ,   29  ,   5   ,   93  ,   255 ,   323 ,   555 ,0 };
            const std::uint32_t dim120KuoInit[]     =   {   1   ,   1   ,   1   ,   3   ,   13  ,   45  ,   89  ,   87  ,   29  ,   23  ,0 };
            const std::uint32_t dim121KuoInit[]     =   {   1   ,   3   ,   3   ,   11  ,   11  ,   29  ,   75  ,   91  ,   211 ,   459 ,0 };
            const std::uint32_t dim122KuoInit[]     =   {   1   ,   3   ,   5   ,   15  ,   11  ,   43  ,   105 ,   1   ,   227 ,   711 ,0 };
            const std::uint32_t dim123KuoInit[]     =   {   1   ,   1   ,   5   ,   5   ,   13  ,   33  ,   29  ,   217 ,   511 ,   241 ,0 };
            const std::uint32_t dim124KuoInit[]     =   {   1   ,   3   ,   7   ,   9   ,   1   ,   47  ,   125 ,   151 ,   375 ,   815 ,0 };
            const std::uint32_t dim125KuoInit[]     =   {   1   ,   1   ,   1   ,   3   ,   25  ,   29  ,   5   ,   39  ,   133 ,   585 ,0 };
            const std::uint32_t dim126KuoInit[]     =   {   1   ,   1   ,   5   ,   9   ,   9   ,   31  ,   79  ,   227 ,   395 ,   517 ,0 };
            const std::uint32_t dim127KuoInit[]     =   {   1   ,   3   ,   3   ,   3   ,   15  ,   3   ,   47  ,   159 ,   233 ,   339 ,0 };
            const std::uint32_t dim128KuoInit[]     =   {   1   ,   3   ,   5   ,   3   ,   15  ,   13  ,   79  ,   109 ,   187 ,   249 ,0 };
            const std::uint32_t dim129KuoInit[]     =   {   1   ,   3   ,   1   ,   15  ,   23  ,   39  ,   85  ,   157 ,   323 ,   535 ,0 };
            const std::uint32_t dim130KuoInit[]     =   {   1   ,   1   ,   1   ,   5   ,   11  ,   25  ,   5   ,   153 ,   19  ,   779 ,0 };
            const std::uint32_t dim131KuoInit[]     =   {   1   ,   3   ,   5   ,   1   ,   9   ,   43  ,   27  ,   179 ,   407 ,   167 ,0 };
            const std::uint32_t dim132KuoInit[]     =   {   1   ,   3   ,   5   ,   5   ,   25  ,   47  ,   21  ,   23  ,   57  ,   415 ,0 };
            const std::uint32_t dim133KuoInit[]     =   {   1   ,   1   ,   1   ,   7   ,   3   ,   29  ,   45  ,   195 ,   349 ,   267 ,0 };
            const std::uint32_t dim134KuoInit[]     =   {   1   ,   3   ,   5   ,   3   ,   19  ,   13  ,   61  ,   243 ,   125 ,   961 ,0 };
            const std::uint32_t dim135KuoInit[]     =   {   1   ,   3   ,   7   ,   3   ,   29  ,   49  ,   7   ,   197 ,   387 ,   747 ,0 };
            const std::uint32_t dim136KuoInit[]     =   {   1   ,   3   ,   7   ,   11  ,   31  ,   31  ,   109 ,   87  ,   345 ,   807 ,0 };
            const std::uint32_t dim137KuoInit[]     =   {   1   ,   3   ,   1   ,   3   ,   21  ,   57  ,   43  ,   207 ,   221 ,   85  ,0 };
            const std::uint32_t dim138KuoInit[]     =   {   1   ,   1   ,   3   ,   13  ,   19  ,   19  ,   41  ,   19  ,   509 ,   419 ,0 };
            const std::uint32_t dim139KuoInit[]     =   {   1   ,   1   ,   3   ,   3   ,   23  ,   17  ,   85  ,   99  ,   421 ,   875 ,0 };
            const std::uint32_t dim140KuoInit[]     =   {   1   ,   3   ,   1   ,   15  ,   27  ,   43  ,   89  ,   151 ,   39  ,   643 ,0 };
            const std::uint32_t dim141KuoInit[]     =   {   1   ,   1   ,   1   ,   5   ,   3   ,   59  ,   25  ,   79  ,   319 ,   959 ,0 };
            const std::uint32_t dim142KuoInit[]     =   {   1   ,   3   ,   5   ,   9   ,   3   ,   27  ,   71  ,   209 ,   195 ,   569 ,0 };
            const std::uint32_t dim143KuoInit[]     =   {   1   ,   3   ,   3   ,   3   ,   11  ,   47  ,   67  ,   1   ,   221 ,   119 ,0 };
            const std::uint32_t dim144KuoInit[]     =   {   1   ,   1   ,   5   ,   11  ,   11  ,   39  ,   95  ,   29  ,   7   ,   957 ,0 };
            const std::uint32_t dim145KuoInit[]     =   {   1   ,   1   ,   7   ,   13  ,   13  ,   57  ,   47  ,   71  ,   165 ,   393 ,0 };
            const std::uint32_t dim146KuoInit[]     =   {   1   ,   3   ,   5   ,   3   ,   5   ,   47  ,   127 ,   209 ,   377 ,   53  ,0 };
            const std::uint32_t dim147KuoInit[]     =   {   1   ,   3   ,   1   ,   5   ,   13  ,   51  ,   69  ,   165 ,   477 ,   961 ,0 };
            const std::uint32_t dim148KuoInit[]     =   {   1   ,   3   ,   5   ,   9   ,   25  ,   37  ,   5   ,   133 ,   117 ,   29  ,0 };
            const std::uint32_t dim149KuoInit[]     =   {   1   ,   1   ,   1   ,   9   ,   7   ,   21  ,   95  ,   53  ,   205 ,   805 ,0 };
            const std::uint32_t dim150KuoInit[]     =   {   1   ,   1   ,   5   ,   11  ,   25  ,   39  ,   25  ,   15  ,   497 ,   525 ,0 };
            const std::uint32_t dim151KuoInit[]     =   {   1   ,   3   ,   5   ,   5   ,   15  ,   37  ,   33  ,   255 ,   97  ,   341 ,0 };
            const std::uint32_t dim152KuoInit[]     =   {   1   ,   3   ,   1   ,   13  ,   31  ,   63  ,   35  ,   203 ,   415 ,   903 ,0 };
            const std::uint32_t dim153KuoInit[]     =   {   1   ,   1   ,   5   ,   7   ,   13  ,   59  ,   55  ,   17  ,   103 ,   221 ,0 };
            const std::uint32_t dim154KuoInit[]     =   {   1   ,   1   ,   5   ,   3   ,   7   ,   37  ,   113 ,   139 ,   269 ,   987 ,0 };
            const std::uint32_t dim155KuoInit[]     =   {   1   ,   3   ,   3   ,   7   ,   21  ,   3   ,   47  ,   175 ,   327 ,   633 ,0 };
            const std::uint32_t dim156KuoInit[]     =   {   1   ,   1   ,   1   ,   3   ,   13  ,   61  ,   19  ,   209 ,   39  ,   695 ,0 };
            const std::uint32_t dim157KuoInit[]     =   {   1   ,   1   ,   1   ,   9   ,   31  ,   61  ,   21  ,   75  ,   445 ,   647 ,0 };
            const std::uint32_t dim158KuoInit[]     =   {   1   ,   1   ,   5   ,   3   ,   21  ,   1   ,   65  ,   211 ,   405 ,   629 ,0 };
            const std::uint32_t dim159KuoInit[]     =   {   1   ,   3   ,   7   ,   15  ,   9   ,   25  ,   119 ,   13  ,   465 ,   865 ,0 };
            const std::uint32_t dim160KuoInit[]     =   {   1   ,   3   ,   1   ,   15  ,   29  ,   19  ,   103 ,   39  ,   37  ,   289 ,0 };
            const std::uint32_t dim161KuoInit[]     =   {   1   ,   1   ,   1   ,   5   ,   25  ,   23  ,   21  ,   111 ,   455 ,   665 ,   1609    ,0 };
            const std::uint32_t dim162KuoInit[]     =   {   1   ,   3   ,   3   ,   13  ,   27  ,   29  ,   45  ,   191 ,   385 ,   413 ,   1875    ,0 };
            const std::uint32_t dim163KuoInit[]     =   {   1   ,   3   ,   7   ,   7   ,   19  ,   17  ,   47  ,   231 ,   337 ,   781 ,   1235    ,0 };
            const std::uint32_t dim164KuoInit[]     =   {   1   ,   1   ,   5   ,   7   ,   7   ,   25  ,   99  ,   239 ,   501 ,   29  ,   159 ,0 };
            const std::uint32_t dim165KuoInit[]     =   {   1   ,   1   ,   1   ,   3   ,   5   ,   19  ,   101 ,   147 ,   225 ,   353 ,   1117    ,0 };
            const std::uint32_t dim166KuoInit[]     =   {   1   ,   3   ,   7   ,   11  ,   17  ,   57  ,   45  ,   73  ,   219 ,   853 ,   1379    ,0 };
            const std::uint32_t dim167KuoInit[]     =   {   1   ,   3   ,   3   ,   7   ,   11  ,   47  ,   23  ,   67  ,   157 ,   283 ,   867 ,0 };
            const std::uint32_t dim168KuoInit[]     =   {   1   ,   1   ,   7   ,   7   ,   23  ,   55  ,   71  ,   155 ,   237 ,   927 ,   929 ,0 };
            const std::uint32_t dim169KuoInit[]     =   {   1   ,   3   ,   3   ,   15  ,   11  ,   19  ,   59  ,   147 ,   373 ,   619 ,   53  ,0 };
            const std::uint32_t dim170KuoInit[]     =   {   1   ,   1   ,   3   ,   15  ,   13  ,   23  ,   11  ,   33  ,   45  ,   121 ,   241 ,0 };
            const std::uint32_t dim171KuoInit[]     =   {   1   ,   1   ,   1   ,   9   ,   13  ,   29  ,   3   ,   131 ,   373 ,   91  ,   1207    ,0 };
            const std::uint32_t dim172KuoInit[]     =   {   1   ,   1   ,   1   ,   15  ,   21  ,   29  ,   59  ,   197 ,   375 ,   637 ,   1275    ,0 };
            const std::uint32_t dim173KuoInit[]     =   {   1   ,   1   ,   3   ,   11  ,   27  ,   31  ,   87  ,   95  ,   119 ,   249 ,   1913    ,0 };
            const std::uint32_t dim174KuoInit[]     =   {   1   ,   3   ,   1   ,   5   ,   25  ,   51  ,   1   ,   241 ,   53  ,   883 ,   61  ,0 };
            const std::uint32_t dim175KuoInit[]     =   {   1   ,   3   ,   1   ,   5   ,   23  ,   37  ,   83  ,   45  ,   287 ,   911 ,   717 ,0 };
            const std::uint32_t dim176KuoInit[]     =   {   1   ,   3   ,   1   ,   3   ,   9   ,   39  ,   105 ,   129 ,   475 ,   399 ,   1783    ,0 };
            const std::uint32_t dim177KuoInit[]     =   {   1   ,   3   ,   5   ,   5   ,   23  ,   11  ,   119 ,   205 ,   317 ,   797 ,   605 ,0 };
            const std::uint32_t dim178KuoInit[]     =   {   1   ,   1   ,   7   ,   5   ,   13  ,   57  ,   19  ,   225 ,   53  ,   987 ,   1463    ,0 };
            const std::uint32_t dim179KuoInit[]     =   {   1   ,   3   ,   5   ,   11  ,   3   ,   59  ,   1   ,   201 ,   97  ,   1011    ,   1059    ,0 };
            const std::uint32_t dim180KuoInit[]     =   {   1   ,   3   ,   3   ,   9   ,   29  ,   51  ,   39  ,   199 ,   243 ,   877 ,   883 ,0 };
            const std::uint32_t dim181KuoInit[]     =   {   1   ,   1   ,   3   ,   5   ,   29  ,   13  ,   97  ,   15  ,   387 ,   435 ,   701 ,0 };
            const std::uint32_t dim182KuoInit[]     =   {   1   ,   3   ,   3   ,   11  ,   21  ,   41  ,   3   ,   119 ,   385 ,   503 ,   2015    ,0 };
            const std::uint32_t dim183KuoInit[]     =   {   1   ,   3   ,   3   ,   1   ,   17  ,   9   ,   49  ,   13  ,   309 ,   29  ,   1501    ,0 };
            const std::uint32_t dim184KuoInit[]     =   {   1   ,   3   ,   1   ,   3   ,   13  ,   29  ,   91  ,   51  ,   225 ,   989 ,   1701    ,0 };
            const std::uint32_t dim185KuoInit[]     =   {   1   ,   1   ,   7   ,   13  ,   1   ,   55  ,   59  ,   243 ,   399 ,   65  ,   1725    ,0 };
            const std::uint32_t dim186KuoInit[]     =   {   1   ,   3   ,   7   ,   7   ,   19  ,   29  ,   97  ,   161 ,   195 ,   257 ,   1595    ,0 };
            const std::uint32_t dim187KuoInit[]     =   {   1   ,   3   ,   7   ,   15  ,   29  ,   49  ,   49  ,   23  ,   157 ,   363 ,   1355    ,0 };
            const std::uint32_t dim188KuoInit[]     =   {   1   ,   3   ,   1   ,   13  ,   23  ,   39  ,   45  ,   73  ,   147 ,   323 ,   1965    ,0 };
            const std::uint32_t dim189KuoInit[]     =   {   1   ,   3   ,   1   ,   15  ,   17  ,   27  ,   17  ,   19  ,   371 ,   387 ,   395 ,0 };
            const std::uint32_t dim190KuoInit[]     =   {   1   ,   1   ,   1   ,   9   ,   19  ,   39  ,   31  ,   3   ,   291 ,   379 ,   605 ,0 };
            const std::uint32_t dim191KuoInit[]     =   {   1   ,   1   ,   7   ,   1   ,   15  ,   17  ,   47  ,   133 ,   485 ,   145 ,   629 ,0 };
            const std::uint32_t dim192KuoInit[]     =   {   1   ,   1   ,   1   ,   13  ,   11  ,   11  ,   117 ,   233 ,   85  ,   1   ,   1357    ,0 };
            const std::uint32_t dim193KuoInit[]     =   {   1   ,   1   ,   7   ,   15  ,   19  ,   51  ,   115 ,   19  ,   333 ,   683 ,   917 ,0 };
            const std::uint32_t dim194KuoInit[]     =   {   1   ,   3   ,   7   ,   9   ,   27  ,   47  ,   17  ,   209 ,   461 ,   261 ,   761 ,0 };
            const std::uint32_t dim195KuoInit[]     =   {   1   ,   1   ,   3   ,   1   ,   27  ,   15  ,   43  ,   141 ,   291 ,   363 ,   605 ,0 };
            const std::uint32_t dim196KuoInit[]     =   {   1   ,   3   ,   7   ,   5   ,   1   ,   3   ,   43  ,   75  ,   115 ,   653 ,   847 ,0 };
            const std::uint32_t dim197KuoInit[]     =   {   1   ,   1   ,   3   ,   1   ,   11  ,   51  ,   69  ,   119 ,   195 ,   979 ,   1543    ,0 };
            const std::uint32_t dim198KuoInit[]     =   {   1   ,   1   ,   7   ,   3   ,   11  ,   29  ,   29  ,   59  ,   339 ,   273 ,   855 ,0 };
            const std::uint32_t dim199KuoInit[]     =   {   1   ,   1   ,   1   ,   1   ,   11  ,   15  ,   59  ,   97  ,   267 ,   647 ,   2037    ,0 };
            const std::uint32_t dim200KuoInit[]     =   {   1   ,   1   ,   5   ,   3   ,   25  ,   43  ,   41  ,   195 ,   457 ,   155 ,   1707    ,0 };
            const std::uint32_t dim201KuoInit[]     =   {   1   ,   3   ,   3   ,   15  ,   11  ,   47  ,   43  ,   15  ,   505 ,   761 ,   1259    ,0 };
            const std::uint32_t dim202KuoInit[]     =   {   1   ,   3   ,   5   ,   15  ,   27  ,   29  ,   55  ,   109 ,   187 ,   545 ,   1177    ,0 };
            const std::uint32_t dim203KuoInit[]     =   {   1   ,   3   ,   1   ,   5   ,   29  ,   25  ,   89  ,   11  ,   75  ,   771 ,   1437    ,0 };
            const std::uint32_t dim204KuoInit[]     =   {   1   ,   3   ,   5   ,   11  ,   19  ,   17  ,   27  ,   59  ,   231 ,   35  ,   391 ,0 };
            const std::uint32_t dim205KuoInit[]     =   {   1   ,   1   ,   7   ,   9   ,   3   ,   17  ,   31  ,   81  ,   317 ,   973 ,   1913    ,0 };
            const std::uint32_t dim206KuoInit[]     =   {   1   ,   1   ,   1   ,   7   ,   3   ,   21  ,   113 ,   41  ,   335 ,   789 ,   1195    ,0 };
            const std::uint32_t dim207KuoInit[]     =   {   1   ,   1   ,   7   ,   1   ,   13  ,   61  ,   41  ,   117 ,   301 ,   707 ,   693 ,0 };
            const std::uint32_t dim208KuoInit[]     =   {   1   ,   1   ,   1   ,   7   ,   3   ,   1   ,   79  ,   145 ,   137 ,   307 ,   205 ,0 };
            const std::uint32_t dim209KuoInit[]     =   {   1   ,   3   ,   7   ,   1   ,   27  ,   49  ,   83  ,   127 ,   265 ,   669 ,   87  ,0 };
            const std::uint32_t dim210KuoInit[]     =   {   1   ,   1   ,   3   ,   15  ,   21  ,   31  ,   115 ,   115 ,   343 ,   55  ,   1049    ,0 };
            const std::uint32_t dim211KuoInit[]     =   {   1   ,   1   ,   5   ,   9   ,   7   ,   25  ,   43  ,   255 ,   363 ,   123 ,   299 ,0 };
            const std::uint32_t dim212KuoInit[]     =   {   1   ,   3   ,   5   ,   13  ,   1   ,   9   ,   79  ,   245 ,   91  ,   233 ,   1703    ,0 };
            const std::uint32_t dim213KuoInit[]     =   {   1   ,   3   ,   5   ,   1   ,   17  ,   39  ,   81  ,   147 ,   147 ,   335 ,   819 ,0 };
            const std::uint32_t dim214KuoInit[]     =   {   1   ,   3   ,   7   ,   3   ,   31  ,   63  ,   55  ,   53  ,   389 ,   307 ,   451 ,0 };
            const std::uint32_t dim215KuoInit[]     =   {   1   ,   1   ,   7   ,   7   ,   23  ,   41  ,   125 ,   147 ,   323 ,   7   ,   1211    ,0 };
            const std::uint32_t dim216KuoInit[]     =   {   1   ,   1   ,   1   ,   13  ,   23  ,   9   ,   35  ,   177 ,   165 ,   315 ,   1885    ,0 };
            const std::uint32_t dim217KuoInit[]     =   {   1   ,   3   ,   3   ,   7   ,   11  ,   39  ,   99  ,   197 ,   405 ,   377 ,   555 ,0 };
            const std::uint32_t dim218KuoInit[]     =   {   1   ,   3   ,   3   ,   11  ,   15  ,   39  ,   125 ,   59  ,   323 ,   377 ,   325 ,0 };
            const std::uint32_t dim219KuoInit[]     =   {   1   ,   3   ,   5   ,   9   ,   7   ,   45  ,   75  ,   143 ,   265 ,   161 ,   1701    ,0 };
            const std::uint32_t dim220KuoInit[]     =   {   1   ,   1   ,   7   ,   5   ,   31  ,   21  ,   35  ,   1   ,   511 ,   585 ,   923 ,0 };
            const std::uint32_t dim221KuoInit[]     =   {   1   ,   3   ,   1   ,   5   ,   3   ,   31  ,   65  ,   33  ,   199 ,   205 ,   1673    ,0 };
            const std::uint32_t dim222KuoInit[]     =   {   1   ,   3   ,   7   ,   9   ,   17  ,   61  ,   123 ,   33  ,   405 ,   235 ,   645 ,0 };
            const std::uint32_t dim223KuoInit[]     =   {   1   ,   3   ,   3   ,   15  ,   27  ,   1   ,   35  ,   165 ,   509 ,   681 ,   621 ,0 };
            const std::uint32_t dim224KuoInit[]     =   {   1   ,   3   ,   5   ,   15  ,   19  ,   13  ,   49  ,   85  ,   5   ,   661 ,   805 ,0 };
            const std::uint32_t dim225KuoInit[]     =   {   1   ,   3   ,   7   ,   3   ,   3   ,   51  ,   77  ,   167 ,   461 ,   731 ,   1681    ,0 };
            const std::uint32_t dim226KuoInit[]     =   {   1   ,   1   ,   3   ,   5   ,   21  ,   51  ,   125 ,   65  ,   41  ,   613 ,   1009    ,0 };
            const std::uint32_t dim227KuoInit[]     =   {   1   ,   3   ,   7   ,   11  ,   17  ,   39  ,   127 ,   31  ,   423 ,   87  ,   1413    ,0 };
            const std::uint32_t dim228KuoInit[]     =   {   1   ,   3   ,   1   ,   5   ,   11  ,   41  ,   25  ,   49  ,   169 ,   637 ,   1599    ,0 };
            const std::uint32_t dim229KuoInit[]     =   {   1   ,   3   ,   5   ,   13  ,   31  ,   27  ,   75  ,   65  ,   391 ,   857 ,   1491    ,0 };
            const std::uint32_t dim230KuoInit[]     =   {   1   ,   1   ,   1   ,   13  ,   5   ,   61  ,   65  ,   183 ,   373 ,   161 ,   235 ,0 };
            const std::uint32_t dim231KuoInit[]     =   {   1   ,   3   ,   1   ,   1   ,   27  ,   49  ,   47  ,   55  ,   503 ,   683 ,   301 ,0 };
            const std::uint32_t dim232KuoInit[]     =   {   1   ,   1   ,   7   ,   11  ,   17  ,   31  ,   113 ,   255 ,   281 ,   341 ,   2033    ,0 };
            const std::uint32_t dim233KuoInit[]     =   {   1   ,   3   ,   3   ,   13  ,   27  ,   27  ,   27  ,   225 ,   161 ,   187 ,   485 ,0 };
            const std::uint32_t dim234KuoInit[]     =   {   1   ,   1   ,   1   ,   3   ,   21  ,   27  ,   105 ,   215 ,   241 ,   211 ,   899 ,0 };
            const std::uint32_t dim235KuoInit[]     =   {   1   ,   3   ,   5   ,   5   ,   11  ,   37  ,   1   ,   7   ,   335 ,   221 ,   757 ,0 };
            const std::uint32_t dim236KuoInit[]     =   {   1   ,   1   ,   5   ,   7   ,   21  ,   55  ,   61  ,   99  ,   23  ,   957 ,   35  ,0 };
            const std::uint32_t dim237KuoInit[]     =   {   1   ,   3   ,   5   ,   5   ,   13  ,   53  ,   31  ,   121 ,   111 ,   47  ,   1491    ,0 };
            const std::uint32_t dim238KuoInit[]     =   {   1   ,   1   ,   5   ,   13  ,   17  ,   5   ,   11  ,   179 ,   357 ,   1003    ,   1179    ,0 };
            const std::uint32_t dim239KuoInit[]     =   {   1   ,   1   ,   5   ,   13  ,   29  ,   9   ,   3   ,   91  ,   471 ,   369 ,   323 ,0 };
            const std::uint32_t dim240KuoInit[]     =   {   1   ,   3   ,   7   ,   5   ,   7   ,   25  ,   109 ,   43  ,   133 ,   261 ,   1623    ,0 };
            const std::uint32_t dim241KuoInit[]     =   {   1   ,   3   ,   7   ,   15  ,   13  ,   33  ,   125 ,   81  ,   491 ,   331 ,   1243    ,0 };
            const std::uint32_t dim242KuoInit[]     =   {   1   ,   3   ,   3   ,   11  ,   15  ,   21  ,   57  ,   63  ,   55  ,   341 ,   1717    ,0 };
            const std::uint32_t dim243KuoInit[]     =   {   1   ,   3   ,   1   ,   1   ,   31  ,   13  ,   67  ,   89  ,   459 ,   879 ,   863 ,0 };
            const std::uint32_t dim244KuoInit[]     =   {   1   ,   3   ,   7   ,   15  ,   7   ,   21  ,   117 ,   229 ,   467 ,   227 ,   1463    ,0 };
            const std::uint32_t dim245KuoInit[]     =   {   1   ,   1   ,   1   ,   7   ,   23  ,   43  ,   53  ,   79  ,   3   ,   905 ,   1049    ,0 };
            const std::uint32_t dim246KuoInit[]     =   {   1   ,   3   ,   7   ,   1   ,   19  ,   1   ,   61  ,   15  ,   377 ,   579 ,   145 ,0 };
            const std::uint32_t dim247KuoInit[]     =   {   1   ,   3   ,   1   ,   15  ,   27  ,   25  ,   61  ,   171 ,   425 ,   631 ,   1343    ,0 };
            const std::uint32_t dim248KuoInit[]     =   {   1   ,   3   ,   7   ,   5   ,   15  ,   31  ,   69  ,   5   ,   217 ,   809 ,   647 ,0 };
            const std::uint32_t dim249KuoInit[]     =   {   1   ,   1   ,   5   ,   3   ,   5   ,   35  ,   101 ,   21  ,   33  ,   757 ,   559 ,0 };
            const std::uint32_t dim250KuoInit[]     =   {   1   ,   3   ,   5   ,   13  ,   3   ,   7   ,   101 ,   93  ,   31  ,   315 ,   1897    ,0 };
            const std::uint32_t dim251KuoInit[]     =   {   1   ,   1   ,   3   ,   1   ,   21  ,   31  ,   37  ,   127 ,   211 ,   429 ,   1019    ,0 };
            const std::uint32_t dim252KuoInit[]     =   {   1   ,   1   ,   3   ,   9   ,   11  ,   27  ,   113 ,   203 ,   115 ,   765 ,   759 ,0 };
            const std::uint32_t dim253KuoInit[]     =   {   1   ,   1   ,   3   ,   13  ,   7   ,   21  ,   89  ,   99  ,   469 ,   729 ,   683 ,0 };
            const std::uint32_t dim254KuoInit[]     =   {   1   ,   1   ,   1   ,   5   ,   27  ,   17  ,   43  ,   177 ,   225 ,   405 ,   1929    ,0 };
            const std::uint32_t dim255KuoInit[]     =   {   1   ,   3   ,   1   ,   7   ,   21  ,   55  ,   69  ,   41  ,   309 ,   487 ,   681 ,0 };
            const std::uint32_t dim256KuoInit[]     =   {   1   ,   3   ,   5   ,   11  ,   19  ,   21  ,   61  ,   163 ,   337 ,   61  ,   301 ,0 };
            const std::uint32_t dim257KuoInit[]     =   {   1   ,   3   ,   1   ,   7   ,   21  ,   61  ,   67  ,   219 ,   281 ,   21  ,   1271    ,0 };
            const std::uint32_t dim258KuoInit[]     =   {   1   ,   1   ,   5   ,   11  ,   5   ,   25  ,   51  ,   207 ,   235 ,   289 ,   395 ,0 };
            const std::uint32_t dim259KuoInit[]     =   {   1   ,   1   ,   3   ,   3   ,   17  ,   61  ,   5   ,   179 ,   457 ,   941 ,   1577    ,0 };
            const std::uint32_t dim260KuoInit[]     =   {   1   ,   1   ,   7   ,   7   ,   17  ,   23  ,   127 ,   35  ,   407 ,   545 ,   169 ,0 };
            const std::uint32_t dim261KuoInit[]     =   {   1   ,   3   ,   7   ,   15  ,   21  ,   19  ,   123 ,   145 ,   97  ,   263 ,   1881    ,0 };
            const std::uint32_t dim262KuoInit[]     =   {   1   ,   3   ,   7   ,   11  ,   25  ,   49  ,   117 ,   165 ,   79  ,   137 ,   1311    ,0 };
            const std::uint32_t dim263KuoInit[]     =   {   1   ,   3   ,   1   ,   11  ,   3   ,   17  ,   9   ,   177 ,   367 ,   863 ,   1255    ,0 };
            const std::uint32_t dim264KuoInit[]     =   {   1   ,   1   ,   5   ,   13  ,   9   ,   1   ,   31  ,   3   ,   69  ,   1009    ,   1091    ,0 };
            const std::uint32_t dim265KuoInit[]     =   {   1   ,   3   ,   7   ,   15  ,   25  ,   41  ,   13  ,   3   ,   319 ,   131 ,   493 ,0 };
            const std::uint32_t dim266KuoInit[]     =   {   1   ,   1   ,   1   ,   15  ,   9   ,   45  ,   25  ,   21  ,   405 ,   61  ,   1167    ,0 };
            const std::uint32_t dim267KuoInit[]     =   {   1   ,   1   ,   1   ,   1   ,   31  ,   3   ,   95  ,   113 ,   475 ,   209 ,   1473    ,0 };
            const std::uint32_t dim268KuoInit[]     =   {   1   ,   1   ,   5   ,   5   ,   27  ,   9   ,   95  ,   121 ,   193 ,   481 ,   1785    ,0 };
            const std::uint32_t dim269KuoInit[]     =   {   1   ,   1   ,   3   ,   13  ,   1   ,   13  ,   57  ,   167 ,   273 ,   491 ,   867 ,0 };
            const std::uint32_t dim270KuoInit[]     =   {   1   ,   1   ,   7   ,   1   ,   9   ,   27  ,   123 ,   65  ,   407 ,   609 ,   1979    ,0 };
            const std::uint32_t dim271KuoInit[]     =   {   1   ,   3   ,   1   ,   15  ,   5   ,   5   ,   89  ,   17  ,   207 ,   249 ,   1725    ,0 };
            const std::uint32_t dim272KuoInit[]     =   {   1   ,   3   ,   5   ,   11  ,   11  ,   15  ,   91  ,   33  ,   113 ,   531 ,   831 ,0 };
            const std::uint32_t dim273KuoInit[]     =   {   1   ,   1   ,   5   ,   9   ,   27  ,   51  ,   17  ,   141 ,   215 ,   171 ,   455 ,0 };
            const std::uint32_t dim274KuoInit[]     =   {   1   ,   1   ,   5   ,   9   ,   11  ,   25  ,   115 ,   5   ,   173 ,   209 ,   1455    ,0 };
            const std::uint32_t dim275KuoInit[]     =   {   1   ,   1   ,   7   ,   7   ,   13  ,   51  ,   21  ,   79  ,   357 ,   423 ,   1855    ,0 };
            const std::uint32_t dim276KuoInit[]     =   {   1   ,   1   ,   7   ,   1   ,   13  ,   37  ,   123 ,   27  ,   477 ,   1023    ,   1235    ,0 };
            const std::uint32_t dim277KuoInit[]     =   {   1   ,   1   ,   7   ,   13  ,   25  ,   43  ,   123 ,   41  ,   199 ,   779 ,   1691    ,0 };
            const std::uint32_t dim278KuoInit[]     =   {   1   ,   3   ,   3   ,   9   ,   7   ,   27  ,   81  ,   147 ,   465 ,   135 ,   829 ,0 };
            const std::uint32_t dim279KuoInit[]     =   {   1   ,   1   ,   7   ,   11  ,   17  ,   5   ,   25  ,   177 ,   377 ,   629 ,   915 ,0 };
            const std::uint32_t dim280KuoInit[]     =   {   1   ,   1   ,   3   ,   15  ,   11  ,   19  ,   45  ,   229 ,   409 ,   187 ,   507 ,0 };
            const std::uint32_t dim281KuoInit[]     =   {   1   ,   1   ,   7   ,   5   ,   7   ,   49  ,   21  ,   49  ,   395 ,   185 ,   391 ,0 };
            const std::uint32_t dim282KuoInit[]     =   {   1   ,   3   ,   1   ,   1   ,   1   ,   37  ,   123 ,   255 ,   223 ,   473 ,   1011    ,0 };
            const std::uint32_t dim283KuoInit[]     =   {   1   ,   3   ,   3   ,   13  ,   3   ,   7   ,   113 ,   183 ,   457 ,   561 ,   1427    ,0 };
            const std::uint32_t dim284KuoInit[]     =   {   1   ,   1   ,   1   ,   11  ,   27  ,   39  ,   125 ,   241 ,   279 ,   905 ,   1907    ,0 };
            const std::uint32_t dim285KuoInit[]     =   {   1   ,   3   ,   1   ,   15  ,   19  ,   19  ,   9   ,   233 ,   39  ,   701 ,   939 ,0 };
            const std::uint32_t dim286KuoInit[]     =   {   1   ,   3   ,   5   ,   11  ,   15  ,   51  ,   1   ,   25  ,   461 ,   671 ,   611 ,0 };
            const std::uint32_t dim287KuoInit[]     =   {   1   ,   3   ,   1   ,   3   ,   23  ,   39  ,   23  ,   191 ,   219 ,   911 ,   1247    ,0 };
            const std::uint32_t dim288KuoInit[]     =   {   1   ,   3   ,   1   ,   3   ,   1   ,   27  ,   91  ,   97  ,   55  ,   863 ,   805 ,0 };
            const std::uint32_t dim289KuoInit[]     =   {   1   ,   3   ,   7   ,   7   ,   5   ,   63  ,   81  ,   33  ,   383 ,   645 ,   841 ,0 };
            const std::uint32_t dim290KuoInit[]     =   {   1   ,   3   ,   7   ,   5   ,   27  ,   39  ,   33  ,   25  ,   185 ,   799 ,   1109    ,0 };
            const std::uint32_t dim291KuoInit[]     =   {   1   ,   3   ,   1   ,   11  ,   11  ,   61  ,   109 ,   209 ,   345 ,   465 ,   935 ,0 };
            const std::uint32_t dim292KuoInit[]     =   {   1   ,   3   ,   5   ,   13  ,   19  ,   55  ,   117 ,   237 ,   455 ,   953 ,   905 ,0 };
            const std::uint32_t dim293KuoInit[]     =   {   1   ,   3   ,   7   ,   9   ,   9   ,   25  ,   77  ,   37  ,   111 ,   357 ,   131 ,0 };
            const std::uint32_t dim294KuoInit[]     =   {   1   ,   1   ,   3   ,   13  ,   1   ,   51  ,   27  ,   235 ,   349 ,   517 ,   653 ,0 };
            const std::uint32_t dim295KuoInit[]     =   {   1   ,   3   ,   7   ,   3   ,   27  ,   43  ,   23  ,   129 ,   455 ,   431 ,   1999    ,0 };
            const std::uint32_t dim296KuoInit[]     =   {   1   ,   3   ,   7   ,   13  ,   11  ,   3   ,   19  ,   55  ,   261 ,   217 ,   535 ,0 };
            const std::uint32_t dim297KuoInit[]     =   {   1   ,   3   ,   7   ,   7   ,   23  ,   53  ,   33  ,   237 ,   73  ,   421 ,   1439    ,0 };
            const std::uint32_t dim298KuoInit[]     =   {   1   ,   1   ,   5   ,   5   ,   19  ,   7   ,   9   ,   201 ,   339 ,   33  ,   2019    ,0 };
            const std::uint32_t dim299KuoInit[]     =   {   1   ,   3   ,   5   ,   7   ,   1   ,   3   ,   9   ,   79  ,   265 ,   125 ,   1063    ,0 };
            const std::uint32_t dim300KuoInit[]     =   {   1   ,   1   ,   7   ,   11  ,   31  ,   61  ,   83  ,   71  ,   93  ,   393 ,   851 ,0 };
            const std::uint32_t dim301KuoInit[]     =   {   1   ,   3   ,   1   ,   13  ,   13  ,   45  ,   65  ,   89  ,   87  ,   657 ,   1635    ,0 };
            const std::uint32_t dim302KuoInit[]     =   {   1   ,   3   ,   5   ,   7   ,   21  ,   3   ,   27  ,   251 ,   287 ,   305 ,   1143    ,0 };
            const std::uint32_t dim303KuoInit[]     =   {   1   ,   1   ,   3   ,   13  ,   5   ,   45  ,   35  ,   89  ,   61  ,   347 ,   1349    ,0 };
            const std::uint32_t dim304KuoInit[]     =   {   1   ,   1   ,   7   ,   1   ,   7   ,   61  ,   19  ,   33  ,   11  ,   845 ,   839 ,0 };
            const std::uint32_t dim305KuoInit[]     =   {   1   ,   3   ,   5   ,   15  ,   3   ,   1   ,   127 ,   245 ,   423 ,   57  ,   865 ,0 };
            const std::uint32_t dim306KuoInit[]     =   {   1   ,   3   ,   5   ,   7   ,   31  ,   33  ,   53  ,   109 ,   397 ,   705 ,   307 ,0 };
            const std::uint32_t dim307KuoInit[]     =   {   1   ,   3   ,   7   ,   7   ,   11  ,   51  ,   53  ,   75  ,   325 ,   61  ,   2035    ,0 };
            const std::uint32_t dim308KuoInit[]     =   {   1   ,   3   ,   3   ,   9   ,   23  ,   37  ,   63  ,   115 ,   377 ,   741 ,   1181    ,0 };
            const std::uint32_t dim309KuoInit[]     =   {   1   ,   1   ,   1   ,   13  ,   13  ,   7   ,   77  ,   171 ,   129 ,   615 ,   157 ,0 };
            const std::uint32_t dim310KuoInit[]     =   {   1   ,   1   ,   5   ,   5   ,   9   ,   41  ,   59  ,   215 ,   275 ,   969 ,   31  ,0 };
            const std::uint32_t dim311KuoInit[]     =   {   1   ,   1   ,   3   ,   1   ,   27  ,   1   ,   33  ,   111 ,   459 ,   503 ,   1703    ,0 };
            const std::uint32_t dim312KuoInit[]     =   {   1   ,   3   ,   3   ,   9   ,   11  ,   41  ,   27  ,   213 ,   67  ,   203 ,   497 ,0 };
            const std::uint32_t dim313KuoInit[]     =   {   1   ,   3   ,   3   ,   3   ,   1   ,   35  ,   39  ,   69  ,   457 ,   765 ,   903 ,0 };
            const std::uint32_t dim314KuoInit[]     =   {   1   ,   3   ,   5   ,   11  ,   11  ,   31  ,   31  ,   195 ,   481 ,   831 ,   1727    ,0 };
            const std::uint32_t dim315KuoInit[]     =   {   1   ,   3   ,   1   ,   1   ,   9   ,   39  ,   11  ,   179 ,   241 ,   945 ,   439 ,0 };
            const std::uint32_t dim316KuoInit[]     =   {   1   ,   1   ,   5   ,   13  ,   1   ,   29  ,   37  ,   113 ,   193 ,   229 ,   1639    ,0 };
            const std::uint32_t dim317KuoInit[]     =   {   1   ,   3   ,   5   ,   7   ,   9   ,   27  ,   75  ,   105 ,   449 ,   631 ,   2025    ,0 };
            const std::uint32_t dim318KuoInit[]     =   {   1   ,   3   ,   7   ,   11  ,   7   ,   9   ,   73  ,   201 ,   273 ,   915 ,   729 ,0 };
            const std::uint32_t dim319KuoInit[]     =   {   1   ,   3   ,   3   ,   15  ,   3   ,   41  ,   61  ,   5   ,   475 ,   193 ,   699 ,0 };
            const std::uint32_t dim320KuoInit[]     =   {   1   ,   1   ,   3   ,   3   ,   13  ,   57  ,   51  ,   201 ,   313 ,   877 ,   507 ,0 };
            const std::uint32_t dim321KuoInit[]     =   {   1   ,   1   ,   7   ,   9   ,   7   ,   3   ,   73  ,   103 ,   113 ,   719 ,   1747    ,0 };
            const std::uint32_t dim322KuoInit[]     =   {   1   ,   1   ,   7   ,   1   ,   1   ,   25  ,   77  ,   249 ,   185 ,   583 ,   123 ,0 };
            const std::uint32_t dim323KuoInit[]     =   {   1   ,   1   ,   5   ,   11  ,   25  ,   49  ,   17  ,   45  ,   161 ,   647 ,   1685    ,0 };
            const std::uint32_t dim324KuoInit[]     =   {   1   ,   3   ,   1   ,   15  ,   15  ,   49  ,   35  ,   59  ,   47  ,   523 ,   1961    ,0 };
            const std::uint32_t dim325KuoInit[]     =   {   1   ,   1   ,   5   ,   5   ,   19  ,   11  ,   105 ,   33  ,   333 ,   451 ,   45  ,0 };
            const std::uint32_t dim326KuoInit[]     =   {   1   ,   3   ,   1   ,   7   ,   21  ,   1   ,   1   ,   15  ,   465 ,   731 ,   447 ,0 };
            const std::uint32_t dim327KuoInit[]     =   {   1   ,   3   ,   5   ,   7   ,   3   ,   9   ,   31  ,   205 ,   479 ,   921 ,   1705    ,0 };
            const std::uint32_t dim328KuoInit[]     =   {   1   ,   1   ,   7   ,   13  ,   7   ,   29  ,   55  ,   1   ,   293 ,   135 ,   1459    ,0 };
            const std::uint32_t dim329KuoInit[]     =   {   1   ,   1   ,   7   ,   5   ,   19  ,   17  ,   7   ,   217 ,   133 ,   959 ,   811 ,0 };
            const std::uint32_t dim330KuoInit[]     =   {   1   ,   1   ,   1   ,   15  ,   3   ,   37  ,   55  ,   223 ,   253 ,   535 ,   1039    ,0 };
            const std::uint32_t dim331KuoInit[]     =   {   1   ,   3   ,   7   ,   3   ,   19  ,   47  ,   125 ,   117 ,   473 ,   257 ,   1215    ,0 };
            const std::uint32_t dim332KuoInit[]     =   {   1   ,   1   ,   3   ,   5   ,   5   ,   1   ,   87  ,   95  ,   189 ,   431 ,   1355    ,0 };
            const std::uint32_t dim333KuoInit[]     =   {   1   ,   1   ,   5   ,   11  ,   17  ,   5   ,   63  ,   15  ,   153 ,   325 ,   259 ,0 };
            const std::uint32_t dim334KuoInit[]     =   {   1   ,   1   ,   3   ,   11  ,   9   ,   41  ,   101 ,   21  ,   161 ,   653 ,   1091    ,0 };
            const std::uint32_t dim335KuoInit[]     =   {   1   ,   3   ,   3   ,   13  ,   5   ,   19  ,   37  ,   223 ,   469 ,   953 ,   15  ,0 };
            const std::uint32_t dim336KuoInit[]     =   {   1   ,   1   ,   1   ,   5   ,   3   ,   33  ,   7   ,   63  ,   111 ,   685 ,   381 ,0 };
            const std::uint32_t dim337KuoInit[]     =   {   1   ,   1   ,   3   ,   11  ,   31  ,   27  ,   49  ,   119 ,   277 ,   303 ,   1719    ,   909 ,0 };
            const std::uint32_t dim338KuoInit[]     =   {   1   ,   3   ,   1   ,   11  ,   27  ,   13  ,   9   ,   107 ,   251 ,   759 ,   1641    ,   2177    ,0 };
            const std::uint32_t dim339KuoInit[]     =   {   1   ,   3   ,   3   ,   3   ,   3   ,   57  ,   33  ,   169 ,   239 ,   357 ,   1519    ,   997 ,0 };
            const std::uint32_t dim340KuoInit[]     =   {   1   ,   3   ,   3   ,   3   ,   11  ,   29  ,   53  ,   109 ,   411 ,   775 ,   1647    ,   819 ,0 };
            const std::uint32_t dim341KuoInit[]     =   {   1   ,   1   ,   5   ,   13  ,   9   ,   3   ,   15  ,   219 ,   483 ,   513 ,   1319    ,   965 ,0 };
            const std::uint32_t dim342KuoInit[]     =   {   1   ,   1   ,   1   ,   5   ,   3   ,   41  ,   9   ,   53  ,   303 ,   349 ,   1071    ,   681 ,0 };
            const std::uint32_t dim343KuoInit[]     =   {   1   ,   3   ,   5   ,   15  ,   27  ,   15  ,   107 ,   211 ,   317 ,   283 ,   1317    ,   2661    ,0 };
            const std::uint32_t dim344KuoInit[]     =   {   1   ,   3   ,   3   ,   1   ,   13  ,   41  ,   29  ,   17  ,   91  ,   985 ,   327 ,   1637    ,0 };
            const std::uint32_t dim345KuoInit[]     =   {   1   ,   1   ,   3   ,   15  ,   27  ,   3   ,   127 ,   233 ,   177 ,   877 ,   1467    ,   3951    ,0 };
            const std::uint32_t dim346KuoInit[]     =   {   1   ,   3   ,   1   ,   5   ,   1   ,   51  ,   5   ,   195 ,   501 ,   859 ,   905 ,   3163    ,0 };
            const std::uint32_t dim347KuoInit[]     =   {   1   ,   1   ,   1   ,   5   ,   1   ,   25  ,   5   ,   205 ,   65  ,   435 ,   1645    ,   4013    ,0 };
            const std::uint32_t dim348KuoInit[]     =   {   1   ,   3   ,   5   ,   13  ,   29  ,   57  ,   101 ,   59  ,   289 ,   701 ,   1363    ,   961 ,0 };
            const std::uint32_t dim349KuoInit[]     =   {   1   ,   3   ,   7   ,   5   ,   1   ,   61  ,   33  ,   117 ,   311 ,   395 ,   1531    ,   2491    ,0 };
            const std::uint32_t dim350KuoInit[]     =   {   1   ,   1   ,   1   ,   1   ,   5   ,   35  ,   15  ,   59  ,   201 ,   195 ,   1423    ,   2195    ,0 };
            const std::uint32_t dim351KuoInit[]     =   {   1   ,   1   ,   7   ,   7   ,   13  ,   29  ,   37  ,   109 ,   481 ,   573 ,   1347    ,   3335    ,0 };
            const std::uint32_t dim352KuoInit[]     =   {   1   ,   1   ,   5   ,   5   ,   25  ,   1   ,   63  ,   53  ,   419 ,   475 ,   1527    ,   3327    ,0 };
            const std::uint32_t dim353KuoInit[]     =   {   1   ,   1   ,   3   ,   1   ,   27  ,   55  ,   75  ,   225 ,   379 ,   471 ,   211 ,   1655    ,0 };
            const std::uint32_t dim354KuoInit[]     =   {   1   ,   1   ,   7   ,   15  ,   13  ,   61  ,   111 ,   95  ,   457 ,   801 ,   1865    ,   2529    ,0 };
            const std::uint32_t dim355KuoInit[]     =   {   1   ,   3   ,   5   ,   5   ,   21  ,   3   ,   31  ,   97  ,   3   ,   495 ,   1953    ,   145 ,0 };
            const std::uint32_t dim356KuoInit[]     =   {   1   ,   3   ,   3   ,   5   ,   13  ,   27  ,   31  ,   143 ,   133 ,   357 ,   1975    ,   1077    ,0 };
            const std::uint32_t dim357KuoInit[]     =   {   1   ,   3   ,   3   ,   15  ,   19  ,   19  ,   23  ,   221 ,   9   ,   783 ,   1403    ,   4003    ,0 };
            const std::uint32_t dim358KuoInit[]     =   {   1   ,   3   ,   7   ,   3   ,   5   ,   53  ,   63  ,   35  ,   209 ,   221 ,   1517    ,   1915    ,0 };
            const std::uint32_t dim359KuoInit[]     =   {   1   ,   3   ,   3   ,   11  ,   27  ,   21  ,   53  ,   95  ,   359 ,   925 ,   1035    ,   3093    ,0 };
            const std::uint32_t dim360KuoInit[]     =   {   1   ,   1   ,   3   ,   9   ,   9   ,   13  ,   25  ,   125 ,   101 ,   119 ,   1361    ,   3503    ,0 };
            const std::uint32_t dim361KuoInit[]     =   {   1   ,   3   ,   7   ,   11  ,   19  ,   43  ,   125 ,   95  ,   113 ,   373 ,   655 ,   1001    ,0 };
            const std::uint32_t dim362KuoInit[]     =   {   1   ,   1   ,   3   ,   15  ,   3   ,   29  ,   125 ,   5   ,   287 ,   859 ,   567 ,   3451    ,0 };
            const std::uint32_t dim363KuoInit[]     =   {   1   ,   3   ,   1   ,   1   ,   7   ,   21  ,   67  ,   249 ,   487 ,   663 ,   2041    ,   799 ,0 };
            const std::uint32_t dim364KuoInit[]     =   {   1   ,   1   ,   3   ,   9   ,   9   ,   29  ,   11  ,   229 ,   303 ,   821 ,   1187    ,   287 ,0 };
            const std::uint32_t dim365KuoInit[]     =   {   1   ,   1   ,   5   ,   11  ,   25  ,   19  ,   77  ,   93  ,   209 ,   155 ,   1717    ,   4085    ,0 };
            const std::uint32_t dim366KuoInit[]     =   {   1   ,   1   ,   3   ,   3   ,   23  ,   39  ,   5   ,   29  ,   295 ,   757 ,   1185    ,   817 ,0 };
            const std::uint32_t dim367KuoInit[]     =   {   1   ,   3   ,   7   ,   7   ,   27  ,   25  ,   33  ,   73  ,   489 ,   543 ,   2011    ,   447 ,0 };
            const std::uint32_t dim368KuoInit[]     =   {   1   ,   3   ,   1   ,   5   ,   21  ,   59  ,   107 ,   109 ,   415 ,   599 ,   325 ,   1457    ,0 };
            const std::uint32_t dim369KuoInit[]     =   {   1   ,   3   ,   1   ,   5   ,   27  ,   61  ,   45  ,   129 ,   37  ,   923 ,   285 ,   2077    ,0 };
            const std::uint32_t dim370KuoInit[]     =   {   1   ,   1   ,   1   ,   3   ,   11  ,   11  ,   17  ,   157 ,   289 ,   575 ,   749 ,   2463    ,0 };
            const std::uint32_t dim371KuoInit[]     =   {   1   ,   1   ,   3   ,   7   ,   25  ,   1   ,   19  ,   177 ,   361 ,   831 ,   911 ,   1833    ,0 };
            const std::uint32_t dim372KuoInit[]     =   {   1   ,   3   ,   7   ,   7   ,   25  ,   27  ,   11  ,   105 ,   489 ,   399 ,   483 ,   1287    ,0 };
            const std::uint32_t dim373KuoInit[]     =   {   1   ,   3   ,   7   ,   11  ,   3   ,   49  ,   27  ,   63  ,   33  ,   991 ,   341 ,   2239    ,0 };
            const std::uint32_t dim374KuoInit[]     =   {   1   ,   3   ,   1   ,   5   ,   3   ,   49  ,   23  ,   23  ,   157 ,   145 ,   1709    ,   1459    ,0 };
            const std::uint32_t dim375KuoInit[]     =   {   1   ,   1   ,   5   ,   9   ,   29  ,   29  ,   5   ,   239 ,   201 ,   503 ,   229 ,   1943    ,0 };
            const std::uint32_t dim376KuoInit[]     =   {   1   ,   3   ,   7   ,   3   ,   5   ,   39  ,   43  ,   127 ,   239 ,   679 ,   1225    ,   2123    ,0 };
            const std::uint32_t dim377KuoInit[]     =   {   1   ,   1   ,   7   ,   11  ,   13  ,   17  ,   125 ,   253 ,   223 ,   67  ,   1319    ,   4019    ,0 };
            const std::uint32_t dim378KuoInit[]     =   {   1   ,   3   ,   3   ,   3   ,   7   ,   57  ,   71  ,   131 ,   205 ,   953 ,   915 ,   1349    ,0 };
            const std::uint32_t dim379KuoInit[]     =   {   1   ,   1   ,   1   ,   7   ,   1   ,   59  ,   77  ,   221 ,   227 ,   67  ,   1853    ,   2577    ,0 };
            const std::uint32_t dim380KuoInit[]     =   {   1   ,   1   ,   7   ,   11  ,   31  ,   15  ,   103 ,   51  ,   505 ,   403 ,   1947    ,   1915    ,0 };
            const std::uint32_t dim381KuoInit[]     =   {   1   ,   3   ,   3   ,   3   ,   15  ,   7   ,   41  ,   179 ,   265 ,   787 ,   1249    ,   3663    ,0 };
            const std::uint32_t dim382KuoInit[]     =   {   1   ,   3   ,   1   ,   11  ,   27  ,   53  ,   123 ,   95  ,   427 ,   877 ,   471 ,   2167    ,0 };
            const std::uint32_t dim383KuoInit[]     =   {   1   ,   1   ,   1   ,   9   ,   25  ,   7   ,   31  ,   47  ,   21  ,   299 ,   1397    ,   1119    ,0 };
            const std::uint32_t dim384KuoInit[]     =   {   1   ,   3   ,   3   ,   9   ,   15  ,   49  ,   9   ,   255 ,   19  ,   995 ,   837 ,   2323    ,0 };
            const std::uint32_t dim385KuoInit[]     =   {   1   ,   1   ,   7   ,   3   ,   31  ,   45  ,   35  ,   93  ,   179 ,   561 ,   1737    ,   3969    ,0 };
            const std::uint32_t dim386KuoInit[]     =   {   1   ,   1   ,   1   ,   5   ,   7   ,   59  ,   27  ,   71  ,   9   ,   411 ,   59  ,   1783    ,0 };
            const std::uint32_t dim387KuoInit[]     =   {   1   ,   3   ,   3   ,   7   ,   27  ,   17  ,   43  ,   37  ,   505 ,   893 ,   709 ,   3163    ,0 };
            const std::uint32_t dim388KuoInit[]     =   {   1   ,   1   ,   5   ,   7   ,   7   ,   59  ,   47  ,   119 ,   39  ,   153 ,   259 ,   1409    ,0 };
            const std::uint32_t dim389KuoInit[]     =   {   1   ,   3   ,   5   ,   1   ,   21  ,   29  ,   23  ,   153 ,   309 ,   137 ,   1015    ,   1527    ,0 };
            const std::uint32_t dim390KuoInit[]     =   {   1   ,   1   ,   5   ,   15  ,   15  ,   27  ,   41  ,   15  ,   135 ,   707 ,   481 ,   2429    ,0 };
            const std::uint32_t dim391KuoInit[]     =   {   1   ,   1   ,   7   ,   13  ,   1   ,   17  ,   95  ,   131 ,   497 ,   873 ,   193 ,   1683    ,0 };
            const std::uint32_t dim392KuoInit[]     =   {   1   ,   1   ,   1   ,   13  ,   29  ,   39  ,   55  ,   51  ,   163 ,   581 ,   1867    ,   2219    ,0 };
            const std::uint32_t dim393KuoInit[]     =   {   1   ,   1   ,   7   ,   3   ,   21  ,   29  ,   9   ,   111 ,   503 ,   7   ,   89  ,   3431    ,0 };
            const std::uint32_t dim394KuoInit[]     =   {   1   ,   3   ,   7   ,   9   ,   13  ,   45  ,   61  ,   239 ,   61  ,   969 ,   77  ,   4053    ,0 };
            const std::uint32_t dim395KuoInit[]     =   {   1   ,   1   ,   7   ,   11  ,   13  ,   29  ,   79  ,   39  ,   361 ,   635 ,   1867    ,   3051    ,0 };
            const std::uint32_t dim396KuoInit[]     =   {   1   ,   3   ,   7   ,   3   ,   29  ,   11  ,   81  ,   193 ,   469 ,   365 ,   17  ,   3657    ,0 };
            const std::uint32_t dim397KuoInit[]     =   {   1   ,   3   ,   3   ,   15  ,   13  ,   45  ,   69  ,   181 ,   95  ,   315 ,   1025    ,   1935    ,0 };
            const std::uint32_t dim398KuoInit[]     =   {   1   ,   1   ,   5   ,   15  ,   31  ,   61  ,   97  ,   117 ,   207 ,   409 ,   69  ,   187 ,0 };
            const std::uint32_t dim399KuoInit[]     =   {   1   ,   1   ,   5   ,   9   ,   27  ,   59  ,   123 ,   157 ,   409 ,   999 ,   905 ,   1097    ,0 };
            const std::uint32_t dim400KuoInit[]     =   {   1   ,   1   ,   7   ,   1   ,   1   ,   51  ,   99  ,   143 ,   255 ,   817 ,   179 ,   3317    ,0 };
            const std::uint32_t dim401KuoInit[]     =   {   1   ,   1   ,   1   ,   1   ,   23  ,   15  ,   117 ,   139 ,   245 ,   865 ,   1723    ,   3501    ,0 };
            const std::uint32_t dim402KuoInit[]     =   {   1   ,   1   ,   5   ,   15  ,   25  ,   53  ,   9   ,   207 ,   291 ,   137 ,   291 ,   653 ,0 };
            const std::uint32_t dim403KuoInit[]     =   {   1   ,   1   ,   3   ,   9   ,   9   ,   63  ,   55  ,   147 ,   199 ,   455 ,   2047    ,   2903    ,0 };
            const std::uint32_t dim404KuoInit[]     =   {   1   ,   1   ,   5   ,   15  ,   29  ,   55  ,   85  ,   13  ,   117 ,   479 ,   1371    ,   2939    ,0 };
            const std::uint32_t dim405KuoInit[]     =   {   1   ,   3   ,   3   ,   5   ,   17  ,   15  ,   33  ,   83  ,   359 ,   469 ,   463 ,   491 ,0 };
            const std::uint32_t dim406KuoInit[]     =   {   1   ,   1   ,   3   ,   5   ,   23  ,   39  ,   35  ,   83  ,   387 ,   891 ,   789 ,   1469    ,0 };
            const std::uint32_t dim407KuoInit[]     =   {   1   ,   3   ,   7   ,   9   ,   27  ,   49  ,   41  ,   49  ,   207 ,   39  ,   25  ,   2355    ,0 };
            const std::uint32_t dim408KuoInit[]     =   {   1   ,   3   ,   5   ,   1   ,   5   ,   7   ,   29  ,   233 ,   169 ,   827 ,   1631    ,   2263    ,0 };
            const std::uint32_t dim409KuoInit[]     =   {   1   ,   1   ,   1   ,   1   ,   1   ,   13  ,   97  ,   109 ,   255 ,   449 ,   345 ,   2533    ,0 };
            const std::uint32_t dim410KuoInit[]     =   {   1   ,   3   ,   1   ,   5   ,   3   ,   15  ,   77  ,   217 ,   237 ,   57  ,   1711    ,   725 ,0 };
            const std::uint32_t dim411KuoInit[]     =   {   1   ,   3   ,   3   ,   7   ,   9   ,   49  ,   93  ,   213 ,   487 ,   811 ,   1659    ,   3019    ,0 };
            const std::uint32_t dim412KuoInit[]     =   {   1   ,   1   ,   1   ,   7   ,   7   ,   9   ,   57  ,   223 ,   263 ,   9   ,   443 ,   1103    ,0 };
            const std::uint32_t dim413KuoInit[]     =   {   1   ,   1   ,   5   ,   11  ,   21  ,   11  ,   83  ,   239 ,   347 ,   489 ,   983 ,   677 ,0 };
            const std::uint32_t dim414KuoInit[]     =   {   1   ,   1   ,   1   ,   11  ,   9   ,   29  ,   25  ,   105 ,   391 ,   1001    ,   1807    ,   1041    ,0 };
            const std::uint32_t dim415KuoInit[]     =   {   1   ,   3   ,   3   ,   1   ,   11  ,   21  ,   89  ,   85  ,   259 ,   237 ,   1489    ,   3825    ,0 };
            const std::uint32_t dim416KuoInit[]     =   {   1   ,   3   ,   5   ,   5   ,   1   ,   21  ,   53  ,   127 ,   269 ,   741 ,   529 ,   1649    ,0 };
            const std::uint32_t dim417KuoInit[]     =   {   1   ,   3   ,   1   ,   7   ,   3   ,   35  ,   71  ,   65  ,   21  ,   985 ,   111 ,   2199    ,0 };
            const std::uint32_t dim418KuoInit[]     =   {   1   ,   1   ,   5   ,   13  ,   3   ,   39  ,   33  ,   151 ,   95  ,   655 ,   1805    ,   1545    ,0 };
            const std::uint32_t dim419KuoInit[]     =   {   1   ,   3   ,   1   ,   11  ,   17  ,   53  ,   63  ,   171 ,   275 ,   649 ,   1791    ,   3309    ,0 };
            const std::uint32_t dim420KuoInit[]     =   {   1   ,   1   ,   7   ,   1   ,   3   ,   5   ,   63  ,   241 ,   77  ,   677 ,   1713    ,   1643    ,0 };
            const std::uint32_t dim421KuoInit[]     =   {   1   ,   3   ,   3   ,   3   ,   9   ,   25  ,   7   ,   33  ,   277 ,   837 ,   1235    ,   3289    ,0 };
            const std::uint32_t dim422KuoInit[]     =   {   1   ,   3   ,   3   ,   1   ,   27  ,   13  ,   97  ,   79  ,   145 ,   197 ,   1237    ,   1689    ,0 };
            const std::uint32_t dim423KuoInit[]     =   {   1   ,   3   ,   5   ,   7   ,   27  ,   45  ,   71  ,   165 ,   405 ,   251 ,   383 ,   737 ,0 };
            const std::uint32_t dim424KuoInit[]     =   {   1   ,   3   ,   7   ,   1   ,   13  ,   21  ,   107 ,   7   ,   207 ,   329 ,   1671    ,   2053    ,0 };
            const std::uint32_t dim425KuoInit[]     =   {   1   ,   3   ,   7   ,   1   ,   31  ,   33  ,   25  ,   223 ,   37  ,   693 ,   1831    ,   2249    ,0 };
            const std::uint32_t dim426KuoInit[]     =   {   1   ,   3   ,   3   ,   15  ,   5   ,   53  ,   111 ,   11  ,   317 ,   819 ,   1345    ,   401 ,0 };
            const std::uint32_t dim427KuoInit[]     =   {   1   ,   3   ,   1   ,   9   ,   7   ,   61  ,   35  ,   127 ,   453 ,   565 ,   37  ,   17  ,0 };
            const std::uint32_t dim428KuoInit[]     =   {   1   ,   3   ,   1   ,   1   ,   15  ,   3   ,   37  ,   133 ,   339 ,   181 ,   377 ,   2339    ,0 };
            const std::uint32_t dim429KuoInit[]     =   {   1   ,   3   ,   7   ,   3   ,   27  ,   57  ,   27  ,   23  ,   45  ,   219 ,   455 ,   2821    ,0 };
            const std::uint32_t dim430KuoInit[]     =   {   1   ,   3   ,   7   ,   9   ,   3   ,   43  ,   79  ,   67  ,   15  ,   797 ,   129 ,   1233    ,0 };
            const std::uint32_t dim431KuoInit[]     =   {   1   ,   3   ,   5   ,   11  ,   5   ,   45  ,   123 ,   161 ,   355 ,   447 ,   1165    ,   2437    ,0 };
            const std::uint32_t dim432KuoInit[]     =   {   1   ,   3   ,   7   ,   1   ,   3   ,   59  ,   65  ,   109 ,   253 ,   447 ,   649 ,   379 ,0 };
            const std::uint32_t dim433KuoInit[]     =   {   1   ,   3   ,   1   ,   5   ,   21  ,   23  ,   45  ,   47  ,   213 ,   813 ,   1475    ,   1271    ,0 };
            const std::uint32_t dim434KuoInit[]     =   {   1   ,   1   ,   1   ,   7   ,   9   ,   31  ,   91  ,   47  ,   161 ,   535 ,   1529    ,   881 ,0 };
            const std::uint32_t dim435KuoInit[]     =   {   1   ,   1   ,   5   ,   13  ,   1   ,   25  ,   85  ,   107 ,   59  ,   487 ,   221 ,   51  ,0 };
            const std::uint32_t dim436KuoInit[]     =   {   1   ,   1   ,   1   ,   1   ,   1   ,   55  ,   93  ,   95  ,   267 ,   157 ,   1255    ,   2115    ,0 };
            const std::uint32_t dim437KuoInit[]     =   {   1   ,   3   ,   1   ,   11  ,   23  ,   55  ,   29  ,   187 ,   261 ,   139 ,   515 ,   2627    ,0 };
            const std::uint32_t dim438KuoInit[]     =   {   1   ,   3   ,   3   ,   13  ,   31  ,   3   ,   121 ,   245 ,   475 ,   67  ,   195 ,   979 ,0 };
            const std::uint32_t dim439KuoInit[]     =   {   1   ,   1   ,   3   ,   7   ,   25  ,   13  ,   79  ,   129 ,   475 ,   177 ,   1519    ,   1069    ,0 };
            const std::uint32_t dim440KuoInit[]     =   {   1   ,   3   ,   3   ,   9   ,   17  ,   23  ,   83  ,   191 ,   133 ,   901 ,   1161    ,   1657    ,0 };
            const std::uint32_t dim441KuoInit[]     =   {   1   ,   3   ,   7   ,   15  ,   23  ,   61  ,   111 ,   135 ,   107 ,   27  ,   583 ,   225 ,0 };
            const std::uint32_t dim442KuoInit[]     =   {   1   ,   1   ,   5   ,   1   ,   17  ,   11  ,   31  ,   197 ,   111 ,   953 ,   1227    ,   3737    ,0 };
            const std::uint32_t dim443KuoInit[]     =   {   1   ,   1   ,   3   ,   9   ,   19  ,   25  ,   83  ,   97  ,   489 ,   781 ,   1591    ,   2061    ,0 };
            const std::uint32_t dim444KuoInit[]     =   {   1   ,   1   ,   1   ,   1   ,   9   ,   61  ,   31  ,   93  ,   39  ,   53  ,   1613    ,   3371    ,0 };
            const std::uint32_t dim445KuoInit[]     =   {   1   ,   1   ,   1   ,   7   ,   3   ,   5   ,   103 ,   247 ,   255 ,   333 ,   31  ,   3087    ,0 };
            const std::uint32_t dim446KuoInit[]     =   {   1   ,   1   ,   7   ,   7   ,   17  ,   35  ,   51  ,   153 ,   363 ,   897 ,   395 ,   1153    ,0 };
            const std::uint32_t dim447KuoInit[]     =   {   1   ,   3   ,   7   ,   9   ,   3   ,   59  ,   127 ,   177 ,   191 ,   255 ,   1543    ,   503 ,0 };
            const std::uint32_t dim448KuoInit[]     =   {   1   ,   1   ,   7   ,   3   ,   1   ,   7   ,   81  ,   199 ,   411 ,   565 ,   1717    ,   615 ,0 };
            const std::uint32_t dim449KuoInit[]     =   {   1   ,   1   ,   1   ,   11  ,   17  ,   35  ,   35  ,   245 ,   507 ,   439 ,   523 ,   2343    ,0 };
            const std::uint32_t dim450KuoInit[]     =   {   1   ,   1   ,   7   ,   15  ,   13  ,   61  ,   31  ,   99  ,   241 ,   605 ,   1575    ,   1321    ,0 };
            const std::uint32_t dim451KuoInit[]     =   {   1   ,   3   ,   1   ,   5   ,   15  ,   31  ,   45  ,   89  ,   193 ,   905 ,   691 ,   3917    ,0 };
            const std::uint32_t dim452KuoInit[]     =   {   1   ,   3   ,   3   ,   9   ,   29  ,   31  ,   101 ,   151 ,   187 ,   199 ,   1543    ,   3951    ,0 };
            const std::uint32_t dim453KuoInit[]     =   {   1   ,   1   ,   7   ,   9   ,   21  ,   45  ,   71  ,   19  ,   395 ,   175 ,   503 ,   3759    ,0 };
            const std::uint32_t dim454KuoInit[]     =   {   1   ,   3   ,   7   ,   7   ,   17  ,   31  ,   47  ,   7   ,   135 ,   719 ,   567 ,   1447    ,0 };
            const std::uint32_t dim455KuoInit[]     =   {   1   ,   3   ,   3   ,   9   ,   1   ,   39  ,   1   ,   53  ,   5   ,   553 ,   371 ,   3833    ,0 };
            const std::uint32_t dim456KuoInit[]     =   {   1   ,   1   ,   1   ,   11  ,   1   ,   33  ,   97  ,   209 ,   377 ,   187 ,   1683    ,   143 ,0 };
            const std::uint32_t dim457KuoInit[]     =   {   1   ,   1   ,   1   ,   3   ,   29  ,   33  ,   111 ,   35  ,   343 ,   511 ,   273 ,   445 ,0 };
            const std::uint32_t dim458KuoInit[]     =   {   1   ,   1   ,   1   ,   15  ,   15  ,   63  ,   73  ,   1   ,   111 ,   775 ,   665 ,   2737    ,0 };
            const std::uint32_t dim459KuoInit[]     =   {   1   ,   1   ,   1   ,   9   ,   29  ,   23  ,   127 ,   77  ,   33  ,   131 ,   1055    ,   2351    ,0 };
            const std::uint32_t dim460KuoInit[]     =   {   1   ,   3   ,   5   ,   7   ,   31  ,   53  ,   117 ,   57  ,   287 ,   221 ,   1099    ,   1147    ,0 };
            const std::uint32_t dim461KuoInit[]     =   {   1   ,   3   ,   7   ,   15  ,   3   ,   17  ,   15  ,   177 ,   189 ,   379 ,   179 ,   1095    ,0 };
            const std::uint32_t dim462KuoInit[]     =   {   1   ,   3   ,   1   ,   15  ,   25  ,   19  ,   43  ,   113 ,   123 ,   123 ,   877 ,   1869    ,0 };
            const std::uint32_t dim463KuoInit[]     =   {   1   ,   3   ,   1   ,   1   ,   13  ,   63  ,   1   ,   83  ,   197 ,   215 ,   1005    ,   3531    ,0 };
            const std::uint32_t dim464KuoInit[]     =   {   1   ,   3   ,   7   ,   1   ,   27  ,   25  ,   111 ,   199 ,   239 ,   909 ,   485 ,   3399    ,0 };
            const std::uint32_t dim465KuoInit[]     =   {   1   ,   1   ,   7   ,   3   ,   19  ,   57  ,   43  ,   75  ,   163 ,   111 ,   359 ,   1987    ,0 };
            const std::uint32_t dim466KuoInit[]     =   {   1   ,   1   ,   3   ,   7   ,   11  ,   63  ,   79  ,   235 ,   197 ,   757 ,   293 ,   3795    ,0 };
            const std::uint32_t dim467KuoInit[]     =   {   1   ,   3   ,   5   ,   9   ,   13  ,   55  ,   49  ,   29  ,   133 ,   949 ,   1185    ,   905 ,0 };
            const std::uint32_t dim468KuoInit[]     =   {   1   ,   1   ,   7   ,   1   ,   15  ,   51  ,   13  ,   223 ,   243 ,   831 ,   845 ,   2663    ,0 };
            const std::uint32_t dim469KuoInit[]     =   {   1   ,   1   ,   3   ,   11  ,   25  ,   21  ,   65  ,   57  ,   483 ,   665 ,   741 ,   2713    ,0 };
            const std::uint32_t dim470KuoInit[]     =   {   1   ,   3   ,   5   ,   3   ,   21  ,   3   ,   81  ,   57  ,   133 ,   553 ,   683 ,   425 ,0 };
            const std::uint32_t dim471KuoInit[]     =   {   1   ,   1   ,   5   ,   11  ,   31  ,   29  ,   59  ,   189 ,   399 ,   751 ,   651 ,   4093    ,0 };
            const std::uint32_t dim472KuoInit[]     =   {   1   ,   3   ,   3   ,   7   ,   13  ,   59  ,   19  ,   217 ,   267 ,   355 ,   173 ,   4051    ,0 };
            const std::uint32_t dim473KuoInit[]     =   {   1   ,   1   ,   5   ,   9   ,   23  ,   49  ,   57  ,   145 ,   77  ,   591 ,   1913    ,   779 ,0 };
            const std::uint32_t dim474KuoInit[]     =   {   1   ,   3   ,   7   ,   3   ,   25  ,   1   ,   83  ,   103 ,   393 ,   121 ,   1415    ,   1503    ,0 };
            const std::uint32_t dim475KuoInit[]     =   {   1   ,   1   ,   7   ,   9   ,   23  ,   41  ,   35  ,   157 ,   63  ,   293 ,   1911    ,   2303    ,0 };
            const std::uint32_t dim476KuoInit[]     =   {   1   ,   3   ,   5   ,   15  ,   7   ,   3   ,   9   ,   1   ,   201 ,   913 ,   1275    ,   3495    ,0 };
            const std::uint32_t dim477KuoInit[]     =   {   1   ,   1   ,   7   ,   11  ,   15  ,   5   ,   107 ,   57  ,   53  ,   451 ,   351 ,   2621    ,0 };
            const std::uint32_t dim478KuoInit[]     =   {   1   ,   3   ,   7   ,   15  ,   23  ,   25  ,   97  ,   29  ,   111 ,   531 ,   1979    ,   2115    ,0 };
            const std::uint32_t dim479KuoInit[]     =   {   1   ,   1   ,   1   ,   1   ,   19  ,   11  ,   49  ,   229 ,   355 ,   195 ,   2033    ,   1701    ,0 };
            const std::uint32_t dim480KuoInit[]     =   {   1   ,   3   ,   3   ,   3   ,   15  ,   35  ,   17  ,   13  ,   425 ,   285 ,   965 ,   159 ,0 };
            const std::uint32_t dim481KuoInit[]     =   {   1   ,   3   ,   1   ,   11  ,   11  ,   11  ,   1   ,   145 ,   365 ,   471 ,   1527    ,   2309    ,   5863    ,0 };
            const std::uint32_t dim482KuoInit[]     =   {   1   ,   1   ,   3   ,   9   ,   21  ,   59  ,   35  ,   123 ,   91  ,   741 ,   527 ,   2061    ,   5505    ,0 };
            const std::uint32_t dim483KuoInit[]     =   {   1   ,   3   ,   7   ,   9   ,   9   ,   37  ,   75  ,   171 ,   75  ,   943 ,   443 ,   201 ,   4861    ,0 };
            const std::uint32_t dim484KuoInit[]     =   {   1   ,   1   ,   7   ,   13  ,   23  ,   49  ,   67  ,   103 ,   453 ,   643 ,   1117    ,   1621    ,   7135    ,0 };
            const std::uint32_t dim485KuoInit[]     =   {   1   ,   3   ,   1   ,   7   ,   15  ,   43  ,   113 ,   17  ,   277 ,   301 ,   349 ,   1155    ,   5285    ,0 };
            const std::uint32_t dim486KuoInit[]     =   {   1   ,   3   ,   5   ,   1   ,   25  ,   61  ,   103 ,   81  ,   141 ,   347 ,   1467    ,   1535    ,   421 ,0 };
            const std::uint32_t dim487KuoInit[]     =   {   1   ,   3   ,   5   ,   13  ,   29  ,   45  ,   43  ,   31  ,   403 ,   711 ,   455 ,   3387    ,   3521    ,0 };
            const std::uint32_t dim488KuoInit[]     =   {   1   ,   3   ,   3   ,   7   ,   7   ,   41  ,   71  ,   251 ,   147 ,   241 ,   1129    ,   2093    ,   7683    ,0 };
            const std::uint32_t dim489KuoInit[]     =   {   1   ,   1   ,   1   ,   5   ,   23  ,   61  ,   57  ,   97  ,   177 ,   387 ,   1557    ,   3587    ,   751 ,0 };
            const std::uint32_t dim490KuoInit[]     =   {   1   ,   3   ,   1   ,   13  ,   11  ,   33  ,   47  ,   147 ,   321 ,   661 ,   53  ,   2437    ,   3087    ,0 };
            const std::uint32_t dim491KuoInit[]     =   {   1   ,   3   ,   1   ,   3   ,   17  ,   21  ,   79  ,   91  ,   77  ,   1011    ,   745 ,   3551    ,   1857    ,0 };
            const std::uint32_t dim492KuoInit[]     =   {   1   ,   1   ,   3   ,   15  ,   19  ,   27  ,   63  ,   231 ,   267 ,   879 ,   1959    ,   3019    ,   1655    ,0 };
            const std::uint32_t dim493KuoInit[]     =   {   1   ,   1   ,   7   ,   15  ,   27  ,   55  ,   21  ,   37  ,   417 ,   69  ,   327 ,   2709    ,   6335    ,0 };
            const std::uint32_t dim494KuoInit[]     =   {   1   ,   3   ,   1   ,   15  ,   1   ,   9   ,   27  ,   89  ,   205 ,   355 ,   373 ,   2191    ,   311 ,0 };
            const std::uint32_t dim495KuoInit[]     =   {   1   ,   1   ,   3   ,   5   ,   15  ,   51  ,   85  ,   233 ,   21  ,   971 ,   1823    ,   1843    ,   1417    ,0 };
            const std::uint32_t dim496KuoInit[]     =   {   1   ,   3   ,   5   ,   13  ,   31  ,   57  ,   3   ,   199 ,   211 ,   401 ,   1559    ,   3601    ,   4569    ,0 };
            const std::uint32_t dim497KuoInit[]     =   {   1   ,   3   ,   3   ,   1   ,   27  ,   63  ,   93  ,   123 ,   223 ,   601 ,   1023    ,   2501    ,   7105    ,0 };
            const std::uint32_t dim498KuoInit[]     =   {   1   ,   1   ,   1   ,   7   ,   3   ,   31  ,   5   ,   51  ,   453 ,   535 ,   255 ,   735 ,   749 ,0 };
            const std::uint32_t dim499KuoInit[]     =   {   1   ,   3   ,   5   ,   9   ,   23  ,   63  ,   109 ,   163 ,   221 ,   845 ,   911 ,   933 ,   361 ,0 };
            const std::uint32_t dim500KuoInit[]     =   {   1   ,   1   ,   1   ,   13  ,   13  ,   17  ,   19  ,   191 ,   227 ,   711 ,   1523    ,   1635    ,   6397    ,0 };
            const std::uint32_t dim501KuoInit[]     =   {   1   ,   3   ,   7   ,   7   ,   21  ,   21  ,   23  ,   91  ,   439 ,   227 ,   1831    ,   1475    ,   705 ,0 };
            const std::uint32_t dim502KuoInit[]     =   {   1   ,   3   ,   7   ,   7   ,   13  ,   39  ,   99  ,   199 ,   149 ,   1005    ,   149 ,   445 ,   3367    ,0 };
            const std::uint32_t dim503KuoInit[]     =   {   1   ,   3   ,   1   ,   5   ,   25  ,   61  ,   99  ,   187 ,   33  ,   619 ,   1833    ,   2177    ,   7631    ,0 };
            const std::uint32_t dim504KuoInit[]     =   {   1   ,   1   ,   1   ,   13  ,   15  ,   45  ,   1   ,   225 ,   129 ,   113 ,   2009    ,   1223    ,   49  ,0 };
            const std::uint32_t dim505KuoInit[]     =   {   1   ,   3   ,   1   ,   9   ,   7   ,   43  ,   57  ,   193 ,   409 ,   265 ,   1151    ,   2635    ,   6005    ,0 };
            const std::uint32_t dim506KuoInit[]     =   {   1   ,   3   ,   5   ,   5   ,   13  ,   13  ,   99  ,   163 ,   1   ,   629 ,   87  ,   925 ,   137 ,0 };
            const std::uint32_t dim507KuoInit[]     =   {   1   ,   3   ,   7   ,   9   ,   23  ,   43  ,   43  ,   1   ,   505 ,   179 ,   335 ,   2033    ,   8065    ,0 };
            const std::uint32_t dim508KuoInit[]     =   {   1   ,   3   ,   5   ,   1   ,   7   ,   55  ,   99  ,   159 ,   19  ,   883 ,   1503    ,   801 ,   1433    ,0 };
            const std::uint32_t dim509KuoInit[]     =   {   1   ,   3   ,   7   ,   1   ,   1   ,   55  ,   53  ,   241 ,   95  ,   315 ,   723 ,   3571    ,   4685    ,0 };
            const std::uint32_t dim510KuoInit[]     =   {   1   ,   3   ,   5   ,   15  ,   29  ,   43  ,   97  ,   159 ,   427 ,   87  ,   1995    ,   1849    ,   6771    ,0 };
            const std::uint32_t dim511KuoInit[]     =   {   1   ,   1   ,   1   ,   7   ,   5   ,   55  ,   55  ,   203 ,   119 ,   185 ,   1333    ,   2107    ,   4271    ,0 };
            const std::uint32_t dim512KuoInit[]     =   {   1   ,   1   ,   3   ,   15  ,   5   ,   7   ,   19  ,   185 ,   75  ,   601 ,   2015    ,   2175    ,   4259    ,0 };
            const std::uint32_t dim513KuoInit[]     =   {   1   ,   3   ,   3   ,   15  ,   3   ,   49  ,   33  ,   115 ,   413 ,   321 ,   1787    ,   469 ,   3721    ,0 };
            const std::uint32_t dim514KuoInit[]     =   {   1   ,   3   ,   1   ,   9   ,   25  ,   63  ,   123 ,   17  ,   355 ,   903 ,   1269    ,   3737    ,   5333    ,0 };
            const std::uint32_t dim515KuoInit[]     =   {   1   ,   1   ,   3   ,   7   ,   25  ,   41  ,   113 ,   239 ,   373 ,   533 ,   1823    ,   3513    ,   7745    ,0 };
            const std::uint32_t dim516KuoInit[]     =   {   1   ,   1   ,   1   ,   11  ,   13  ,   7   ,   7   ,   43  ,   145 ,   607 ,   2043    ,   2397    ,   4051    ,0 };
            const std::uint32_t dim517KuoInit[]     =   {   1   ,   1   ,   3   ,   3   ,   9   ,   49  ,   5   ,   173 ,   63  ,   157 ,   637 ,   2307    ,   6603    ,0 };
            const std::uint32_t dim518KuoInit[]     =   {   1   ,   3   ,   1   ,   3   ,   23  ,   33  ,   89  ,   139 ,   207 ,   389 ,   1389    ,   3385    ,   2169    ,0 };
            const std::uint32_t dim519KuoInit[]     =   {   1   ,   1   ,   7   ,   3   ,   7   ,   7   ,   19  ,   7   ,   217 ,   189 ,   739 ,   2475    ,   7925    ,0 };
            const std::uint32_t dim520KuoInit[]     =   {   1   ,   1   ,   7   ,   5   ,   23  ,   37  ,   71  ,   31  ,   145 ,   29  ,   537 ,   959 ,   2227    ,0 };
            const std::uint32_t dim521KuoInit[]     =   {   1   ,   1   ,   7   ,   11  ,   7   ,   55  ,   39  ,   167 ,   347 ,   293 ,   577 ,   3077    ,   531 ,0 };
            const std::uint32_t dim522KuoInit[]     =   {   1   ,   3   ,   1   ,   5   ,   19  ,   1   ,   119 ,   133 ,   487 ,   867 ,   1331    ,   1759    ,   3683    ,0 };
            const std::uint32_t dim523KuoInit[]     =   {   1   ,   3   ,   5   ,   13  ,   27  ,   31  ,   77  ,   71  ,   465 ,   133 ,   105 ,   477 ,   6301    ,0 };
            const std::uint32_t dim524KuoInit[]     =   {   1   ,   3   ,   5   ,   15  ,   25  ,   49  ,   35  ,   75  ,   57  ,   663 ,   195 ,   1041    ,   5697    ,0 };
            const std::uint32_t dim525KuoInit[]     =   {   1   ,   3   ,   7   ,   9   ,   9   ,   7   ,   47  ,   233 ,   397 ,   155 ,   439 ,   2487    ,   4697    ,0 };
            const std::uint32_t dim526KuoInit[]     =   {   1   ,   1   ,   5   ,   9   ,   5   ,   41  ,   125 ,   9   ,   477 ,   567 ,   2033    ,   769 ,   1553    ,0 };
            const std::uint32_t dim527KuoInit[]     =   {   1   ,   1   ,   3   ,   7   ,   7   ,   25  ,   95  ,   45  ,   211 ,   453 ,   483 ,   3965    ,   1865    ,0 };
            const std::uint32_t dim528KuoInit[]     =   {   1   ,   3   ,   7   ,   5   ,   17  ,   41  ,   109 ,   59  ,   385 ,   1023    ,   1527    ,   2445    ,   6303    ,0 };
            const std::uint32_t dim529KuoInit[]     =   {   1   ,   3   ,   3   ,   9   ,   7   ,   29  ,   91  ,   245 ,   189 ,   251 ,   1237    ,   2825    ,   7919    ,0 };
            const std::uint32_t dim530KuoInit[]     =   {   1   ,   3   ,   7   ,   1   ,   25  ,   43  ,   27  ,   11  ,   63  ,   641 ,   1765    ,   1683    ,   2445    ,0 };
            const std::uint32_t dim531KuoInit[]     =   {   1   ,   1   ,   1   ,   7   ,   3   ,   59  ,   19  ,   81  ,   387 ,   207 ,   31  ,   1583    ,   607 ,0 };
            const std::uint32_t dim532KuoInit[]     =   {   1   ,   1   ,   3   ,   1   ,   3   ,   33  ,   99  ,   135 ,   267 ,   355 ,   585 ,   4017    ,   2385    ,0 };
            const std::uint32_t dim533KuoInit[]     =   {   1   ,   1   ,   7   ,   15  ,   1   ,   49  ,   35  ,   211 ,   359 ,   379 ,   1173    ,   2709    ,   3945    ,0 };
            const std::uint32_t dim534KuoInit[]     =   {   1   ,   1   ,   5   ,   7   ,   29  ,   23  ,   99  ,   219 ,   269 ,   977 ,   1175    ,   2305    ,   5633    ,0 };
            const std::uint32_t dim535KuoInit[]     =   {   1   ,   3   ,   3   ,   15  ,   17  ,   9   ,   115 ,   21  ,   503 ,   329 ,   1725    ,   289 ,   4667    ,0 };
            const std::uint32_t dim536KuoInit[]     =   {   1   ,   1   ,   7   ,   1   ,   9   ,   1   ,   31  ,   145 ,   209 ,   833 ,   1527    ,   4021    ,   2177    ,0 };
            const std::uint32_t dim537KuoInit[]     =   {   1   ,   3   ,   3   ,   1   ,   25  ,   13  ,   37  ,   143 ,   217 ,   891 ,   1289    ,   3635    ,   6931    ,0 };
            const std::uint32_t dim538KuoInit[]     =   {   1   ,   1   ,   3   ,   9   ,   9   ,   49  ,   33  ,   123 ,   435 ,   993 ,   389 ,   2491    ,   2097    ,0 };
            const std::uint32_t dim539KuoInit[]     =   {   1   ,   3   ,   5   ,   9   ,   11  ,   53  ,   121 ,   25  ,   31  ,   589 ,   1939    ,   3981    ,   621 ,0 };
            const std::uint32_t dim540KuoInit[]     =   {   1   ,   1   ,   1   ,   1   ,   27  ,   53  ,   9   ,   217 ,   135 ,   605 ,   1779    ,   3053    ,   2865    ,0 };
            const std::uint32_t dim541KuoInit[]     =   {   1   ,   1   ,   7   ,   5   ,   3   ,   53  ,   9   ,   15  ,   275 ,   613 ,   1395    ,   2287    ,   1111    ,0 };
            const std::uint32_t dim542KuoInit[]     =   {   1   ,   1   ,   3   ,   1   ,   13  ,   17  ,   3   ,   103 ,   195 ,   509 ,   493 ,   2395    ,   4669    ,0 };
            const std::uint32_t dim543KuoInit[]     =   {   1   ,   3   ,   5   ,   1   ,   13  ,   17  ,   59  ,   3   ,   117 ,   39  ,   1699    ,   2339    ,   5203    ,0 };
            const std::uint32_t dim544KuoInit[]     =   {   1   ,   3   ,   5   ,   3   ,   29  ,   23  ,   59  ,   251 ,   139 ,   625 ,   935 ,   785 ,   7547    ,0 };
            const std::uint32_t dim545KuoInit[]     =   {   1   ,   3   ,   1   ,   13  ,   23  ,   47  ,   5   ,   91  ,   283 ,   59  ,   919 ,   2427    ,   1631    ,0 };
            const std::uint32_t dim546KuoInit[]     =   {   1   ,   1   ,   3   ,   9   ,   15  ,   35  ,   67  ,   131 ,   183 ,   891 ,   345 ,   3741    ,   3175    ,0 };
            const std::uint32_t dim547KuoInit[]     =   {   1   ,   3   ,   1   ,   3   ,   23  ,   11  ,   85  ,   135 ,   269 ,   347 ,   713 ,   2947    ,   1617    ,0 };
            const std::uint32_t dim548KuoInit[]     =   {   1   ,   3   ,   1   ,   3   ,   27  ,   33  ,   77  ,   189 ,   243 ,   893 ,   283 ,   885 ,   1999    ,0 };
            const std::uint32_t dim549KuoInit[]     =   {   1   ,   1   ,   5   ,   1   ,   31  ,   39  ,   99  ,   21  ,   437 ,   979 ,   919 ,   3663    ,   6689    ,0 };
            const std::uint32_t dim550KuoInit[]     =   {   1   ,   1   ,   1   ,   1   ,   17  ,   27  ,   55  ,   161 ,   205 ,   583 ,   383 ,   1681    ,   6445    ,0 };
            const std::uint32_t dim551KuoInit[]     =   {   1   ,   3   ,   7   ,   1   ,   31  ,   59  ,   111 ,   129 ,   121 ,   555 ,   653 ,   2787    ,   3899    ,0 };
            const std::uint32_t dim552KuoInit[]     =   {   1   ,   3   ,   1   ,   9   ,   11  ,   59  ,   51  ,   115 ,   349 ,   809 ,   513 ,   1585    ,   31  ,0 };
            const std::uint32_t dim553KuoInit[]     =   {   1   ,   1   ,   1   ,   3   ,   29  ,   17  ,   3   ,   173 ,   111 ,   671 ,   1289    ,   397 ,   799 ,0 };
            const std::uint32_t dim554KuoInit[]     =   {   1   ,   3   ,   1   ,   7   ,   17  ,   55  ,   85  ,   49  ,   23  ,   915 ,   1929    ,   685 ,   7021    ,0 };
            const std::uint32_t dim555KuoInit[]     =   {   1   ,   3   ,   7   ,   11  ,   3   ,   41  ,   123 ,   227 ,   111 ,   805 ,   1567    ,   751 ,   7927    ,0 };
            const std::uint32_t dim556KuoInit[]     =   {   1   ,   1   ,   7   ,   3   ,   15  ,   45  ,   117 ,   39  ,   491 ,   401 ,   1775    ,   2197    ,   4303    ,0 };
            const std::uint32_t dim557KuoInit[]     =   {   1   ,   1   ,   7   ,   9   ,   13  ,   23  ,   63  ,   245 ,   163 ,   595 ,   1271    ,   2143    ,   8105    ,0 };
            const std::uint32_t dim558KuoInit[]     =   {   1   ,   1   ,   3   ,   1   ,   31  ,   57  ,   45  ,   35  ,   327 ,   89  ,   1845    ,   1075    ,   4649    ,0 };
            const std::uint32_t dim559KuoInit[]     =   {   1   ,   3   ,   7   ,   7   ,   11  ,   31  ,   51  ,   209 ,   103 ,   215 ,   1693    ,   3427    ,   677 ,0 };
            const std::uint32_t dim560KuoInit[]     =   {   1   ,   1   ,   5   ,   13  ,   3   ,   7   ,   83  ,   199 ,   325 ,   461 ,   1185    ,   1997    ,   2327    ,0 };
            const std::uint32_t dim561KuoInit[]     =   {   1   ,   1   ,   3   ,   15  ,   23  ,   13  ,   23  ,   39  ,   209 ,   267 ,   1995    ,   3999    ,   6277    ,0 };
            const std::uint32_t dim562KuoInit[]     =   {   1   ,   1   ,   7   ,   1   ,   5   ,   37  ,   99  ,   117 ,   509 ,   303 ,   655 ,   935 ,   6321    ,0 };
            const std::uint32_t dim563KuoInit[]     =   {   1   ,   1   ,   1   ,   15  ,   23  ,   39  ,   123 ,   11  ,   445 ,   897 ,   1327    ,   2819    ,   1899    ,0 };
            const std::uint32_t dim564KuoInit[]     =   {   1   ,   1   ,   5   ,   5   ,   7   ,   7   ,   7   ,   61  ,   349 ,   865 ,   707 ,   2097    ,   1217    ,0 };
            const std::uint32_t dim565KuoInit[]     =   {   1   ,   1   ,   5   ,   9   ,   1   ,   63  ,   35  ,   187 ,   207 ,   53  ,   1917    ,   621 ,   2113    ,0 };
            const std::uint32_t dim566KuoInit[]     =   {   1   ,   1   ,   1   ,   15  ,   21  ,   61  ,   101 ,   169 ,   129 ,   813 ,   453 ,   323 ,   7283    ,0 };
            const std::uint32_t dim567KuoInit[]     =   {   1   ,   1   ,   7   ,   7   ,   27  ,   1   ,   27  ,   141 ,   33  ,   307 ,   2023    ,   2561    ,   8111    ,0 };
            const std::uint32_t dim568KuoInit[]     =   {   1   ,   1   ,   5   ,   13  ,   3   ,   9   ,   3   ,   87  ,   451 ,   691 ,   973 ,   539 ,   4393    ,0 };
            const std::uint32_t dim569KuoInit[]     =   {   1   ,   1   ,   5   ,   1   ,   23  ,   23  ,   9   ,   101 ,   349 ,   299 ,   583 ,   2037    ,   5247    ,0 };
            const std::uint32_t dim570KuoInit[]     =   {   1   ,   1   ,   5   ,   11  ,   15  ,   39  ,   99  ,   163 ,   395 ,   123 ,   1067    ,   2735    ,   4407    ,0 };
            const std::uint32_t dim571KuoInit[]     =   {   1   ,   3   ,   5   ,   11  ,   9   ,   61  ,   51  ,   237 ,   483 ,   501 ,   1767    ,   1419    ,   5047    ,0 };
            const std::uint32_t dim572KuoInit[]     =   {   1   ,   1   ,   7   ,   9   ,   27  ,   31  ,   57  ,   103 ,   291 ,   537 ,   1759    ,   1861    ,   3815    ,0 };
            const std::uint32_t dim573KuoInit[]     =   {   1   ,   1   ,   5   ,   15  ,   31  ,   5   ,   107 ,   103 ,   159 ,   939 ,   1331    ,   1219    ,   2045    ,0 };
            const std::uint32_t dim574KuoInit[]     =   {   1   ,   3   ,   5   ,   15  ,   7   ,   45  ,   99  ,   175 ,   131 ,   967 ,   593 ,   3191    ,   5403    ,0 };
            const std::uint32_t dim575KuoInit[]     =   {   1   ,   3   ,   7   ,   11  ,   19  ,   43  ,   57  ,   129 ,   285 ,   943 ,   1507    ,   3979    ,   2807    ,0 };
            const std::uint32_t dim576KuoInit[]     =   {   1   ,   1   ,   5   ,   3   ,   11  ,   7   ,   117 ,   241 ,   393 ,   1023    ,   95  ,   535 ,   7235    ,0 };
            const std::uint32_t dim577KuoInit[]     =   {   1   ,   3   ,   1   ,   5   ,   17  ,   5   ,   111 ,   165 ,   343 ,   65  ,   1393    ,   2855    ,   3801    ,0 };
            const std::uint32_t dim578KuoInit[]     =   {   1   ,   1   ,   5   ,   5   ,   27  ,   1   ,   87  ,   9   ,   177 ,   455 ,   1915    ,   1557    ,   7175    ,0 };
            const std::uint32_t dim579KuoInit[]     =   {   1   ,   1   ,   5   ,   11  ,   31  ,   33  ,   105 ,   255 ,   281 ,   303 ,   1831    ,   1575    ,   1179    ,0 };
            const std::uint32_t dim580KuoInit[]     =   {   1   ,   3   ,   3   ,   9   ,   7   ,   37  ,   3   ,   85  ,   161 ,   491 ,   299 ,   4003    ,   7429    ,0 };
            const std::uint32_t dim581KuoInit[]     =   {   1   ,   1   ,   5   ,   9   ,   1   ,   19  ,   23  ,   175 ,   497 ,   613 ,   2043    ,   1467    ,   2379    ,0 };
            const std::uint32_t dim582KuoInit[]     =   {   1   ,   3   ,   7   ,   13  ,   5   ,   57  ,   93  ,   17  ,   383 ,   801 ,   1465    ,   3151    ,   4717    ,0 };
            const std::uint32_t dim583KuoInit[]     =   {   1   ,   3   ,   7   ,   5   ,   3   ,   19  ,   87  ,   25  ,   95  ,   643 ,   79  ,   123 ,   7175    ,0 };
            const std::uint32_t dim584KuoInit[]     =   {   1   ,   1   ,   1   ,   5   ,   3   ,   27  ,   49  ,   155 ,   45  ,   655 ,   1079    ,   3243    ,   8147    ,0 };
            const std::uint32_t dim585KuoInit[]     =   {   1   ,   3   ,   1   ,   11  ,   13  ,   57  ,   107 ,   37  ,   147 ,   119 ,   887 ,   1317    ,   6687    ,0 };
            const std::uint32_t dim586KuoInit[]     =   {   1   ,   3   ,   3   ,   13  ,   29  ,   23  ,   105 ,   137 ,   339 ,   509 ,   1543    ,   2339    ,   2167    ,0 };
            const std::uint32_t dim587KuoInit[]     =   {   1   ,   1   ,   5   ,   3   ,   29  ,   5   ,   89  ,   65  ,   191 ,   33  ,   755 ,   737 ,   3495    ,0 };
            const std::uint32_t dim588KuoInit[]     =   {   1   ,   1   ,   5   ,   1   ,   19  ,   27  ,   123 ,   67  ,   323 ,   731 ,   1753    ,   1773    ,   1731    ,0 };
            const std::uint32_t dim589KuoInit[]     =   {   1   ,   1   ,   5   ,   11  ,   23  ,   35  ,   21  ,   1   ,   107 ,   509 ,   1617    ,   1565    ,   1617    ,0 };
            const std::uint32_t dim590KuoInit[]     =   {   1   ,   1   ,   7   ,   15  ,   31  ,   7   ,   31  ,   241 ,   479 ,   457 ,   1353    ,   1531    ,   5939    ,0 };
            const std::uint32_t dim591KuoInit[]     =   {   1   ,   3   ,   1   ,   1   ,   31  ,   19  ,   71  ,   127 ,   379 ,   151 ,   739 ,   893 ,   7857    ,0 };
            const std::uint32_t dim592KuoInit[]     =   {   1   ,   1   ,   1   ,   3   ,   31  ,   41  ,   99  ,   55  ,   229 ,   585 ,   1881    ,   2267    ,   3555    ,0 };
            const std::uint32_t dim593KuoInit[]     =   {   1   ,   3   ,   3   ,   1   ,   25  ,   3   ,   55  ,   95  ,   409 ,   429 ,   527 ,   611 ,   6551    ,0 };
            const std::uint32_t dim594KuoInit[]     =   {   1   ,   3   ,   5   ,   3   ,   3   ,   59  ,   81  ,   83  ,   131 ,   981 ,   67  ,   295 ,   3313    ,0 };
            const std::uint32_t dim595KuoInit[]     =   {   1   ,   1   ,   1   ,   13  ,   23  ,   57  ,   47  ,   127 ,   307 ,   621 ,   865 ,   2589    ,   4033    ,0 };
            const std::uint32_t dim596KuoInit[]     =   {   1   ,   1   ,   7   ,   11  ,   7   ,   17  ,   15  ,   207 ,   89  ,   77  ,   1923    ,   3649    ,   119 ,0 };
            const std::uint32_t dim597KuoInit[]     =   {   1   ,   3   ,   5   ,   3   ,   23  ,   5   ,   87  ,   247 ,   233 ,   43  ,   475 ,   999 ,   6999    ,0 };
            const std::uint32_t dim598KuoInit[]     =   {   1   ,   1   ,   7   ,   13  ,   19  ,   49  ,   53  ,   21  ,   105 ,   181 ,   1569    ,   3151    ,   5089    ,0 };
            const std::uint32_t dim599KuoInit[]     =   {   1   ,   1   ,   5   ,   7   ,   11  ,   53  ,   119 ,   11  ,   301 ,   647 ,   759 ,   2849    ,   4541    ,0 };
            const std::uint32_t dim600KuoInit[]     =   {   1   ,   1   ,   7   ,   11  ,   31  ,   31  ,   83  ,   107 ,   373 ,   41  ,   921 ,   3935    ,   2859    ,0 };
            const std::uint32_t dim601KuoInit[]     =   {   1   ,   3   ,   5   ,   13  ,   13  ,   57  ,   121 ,   133 ,   355 ,   153 ,   607 ,   3199    ,   8097    ,0 };
            const std::uint32_t dim602KuoInit[]     =   {   1   ,   1   ,   5   ,   9   ,   5   ,   25  ,   113 ,   21  ,   17  ,   643 ,   415 ,   2705    ,   903 ,0 };
            const std::uint32_t dim603KuoInit[]     =   {   1   ,   1   ,   5   ,   1   ,   19  ,   3   ,   119 ,   199 ,   241 ,   957 ,   1203    ,   1291    ,   6355    ,0 };
            const std::uint32_t dim604KuoInit[]     =   {   1   ,   1   ,   3   ,   13  ,   19  ,   1   ,   11  ,   73  ,   387 ,   97  ,   783 ,   3875    ,   4573    ,0 };
            const std::uint32_t dim605KuoInit[]     =   {   1   ,   1   ,   7   ,   3   ,   27  ,   11  ,   99  ,   193 ,   311 ,   889 ,   535 ,   801 ,   4467    ,0 };
            const std::uint32_t dim606KuoInit[]     =   {   1   ,   1   ,   1   ,   1   ,   3   ,   53  ,   61  ,   245 ,   497 ,   127 ,   1213    ,   1147    ,   2225    ,0 };
            const std::uint32_t dim607KuoInit[]     =   {   1   ,   3   ,   5   ,   1   ,   9   ,   49  ,   21  ,   229 ,   481 ,   23  ,   47  ,   3959    ,   2991    ,0 };
            const std::uint32_t dim608KuoInit[]     =   {   1   ,   1   ,   5   ,   1   ,   9   ,   21  ,   123 ,   107 ,   359 ,   759 ,   993 ,   695 ,   5609    ,0 };
            const std::uint32_t dim609KuoInit[]     =   {   1   ,   3   ,   5   ,   11  ,   25  ,   55  ,   73  ,   245 ,   373 ,   525 ,   1399    ,   1727    ,   1763    ,0 };
            const std::uint32_t dim610KuoInit[]     =   {   1   ,   1   ,   5   ,   3   ,   21  ,   41  ,   83  ,   161 ,   43  ,   563 ,   1655    ,   3539    ,   7941    ,0 };
            const std::uint32_t dim611KuoInit[]     =   {   1   ,   3   ,   1   ,   13  ,   29  ,   59  ,   25  ,   119 ,   199 ,   375 ,   1507    ,   2095    ,   3281    ,0 };
            const std::uint32_t dim612KuoInit[]     =   {   1   ,   3   ,   3   ,   5   ,   21  ,   23  ,   63  ,   85  ,   115 ,   77  ,   745 ,   771 ,   3319    ,0 };
            const std::uint32_t dim613KuoInit[]     =   {   1   ,   1   ,   7   ,   3   ,   3   ,   37  ,   11  ,   233 ,   173 ,   51  ,   1723    ,   1441    ,   6529    ,0 };
            const std::uint32_t dim614KuoInit[]     =   {   1   ,   1   ,   1   ,   11  ,   1   ,   55  ,   113 ,   25  ,   369 ,   1023    ,   1691    ,   1797    ,   159 ,0 };
            const std::uint32_t dim615KuoInit[]     =   {   1   ,   3   ,   1   ,   15  ,   13  ,   43  ,   63  ,   113 ,   55  ,   351 ,   1459    ,   3117    ,   3499    ,0 };
            const std::uint32_t dim616KuoInit[]     =   {   1   ,   3   ,   7   ,   1   ,   19  ,   61  ,   17  ,   243 ,   203 ,   349 ,   1069    ,   105 ,   6015    ,0 };
            const std::uint32_t dim617KuoInit[]     =   {   1   ,   1   ,   5   ,   1   ,   23  ,   49  ,   7   ,   129 ,   99  ,   377 ,   1989    ,   531 ,   6315    ,0 };
            const std::uint32_t dim618KuoInit[]     =   {   1   ,   1   ,   7   ,   7   ,   11  ,   23  ,   107 ,   63  ,   163 ,   351 ,   1385    ,   127 ,   7439    ,0 };
            const std::uint32_t dim619KuoInit[]     =   {   1   ,   3   ,   5   ,   15  ,   15  ,   43  ,   81  ,   229 ,   21  ,   179 ,   1357    ,   3813    ,   7345    ,0 };
            const std::uint32_t dim620KuoInit[]     =   {   1   ,   1   ,   1   ,   15  ,   23  ,   19  ,   89  ,   251 ,   161 ,   443 ,   983 ,   1059    ,   1241    ,0 };
            const std::uint32_t dim621KuoInit[]     =   {   1   ,   3   ,   3   ,   9   ,   7   ,   17  ,   11  ,   239 ,   325 ,   117 ,   893 ,   917 ,   6327    ,0 };
            const std::uint32_t dim622KuoInit[]     =   {   1   ,   1   ,   7   ,   1   ,   31  ,   33  ,   23  ,   241 ,   255 ,   991 ,   903 ,   3973    ,   3935    ,0 };
            const std::uint32_t dim623KuoInit[]     =   {   1   ,   3   ,   7   ,   3   ,   11  ,   17  ,   61  ,   219 ,   461 ,   437 ,   1843    ,   1845    ,   771 ,0 };
            const std::uint32_t dim624KuoInit[]     =   {   1   ,   3   ,   7   ,   5   ,   7   ,   61  ,   79  ,   225 ,   215 ,   411 ,   885 ,   3949    ,   2757    ,0 };
            const std::uint32_t dim625KuoInit[]     =   {   1   ,   3   ,   7   ,   3   ,   3   ,   15  ,   25  ,   49  ,   351 ,   671 ,   1573    ,   3643    ,   2383    ,0 };
            const std::uint32_t dim626KuoInit[]     =   {   1   ,   1   ,   7   ,   1   ,   29  ,   1   ,   121 ,   61  ,   49  ,   833 ,   1363    ,   427 ,   3237    ,0 };
            const std::uint32_t dim627KuoInit[]     =   {   1   ,   3   ,   3   ,   5   ,   11  ,   9   ,   79  ,   113 ,   341 ,   25  ,   1797    ,   1641    ,   6899    ,0 };
            const std::uint32_t dim628KuoInit[]     =   {   1   ,   1   ,   5   ,   9   ,   11  ,   15  ,   71  ,   169 ,   269 ,   359 ,   1991    ,   3673    ,   601 ,0 };
            const std::uint32_t dim629KuoInit[]     =   {   1   ,   1   ,   1   ,   11  ,   31  ,   7   ,   5   ,   165 ,   23  ,   917 ,   617 ,   4059    ,   2599    ,0 };
            const std::uint32_t dim630KuoInit[]     =   {   1   ,   1   ,   7   ,   9   ,   19  ,   25  ,   119 ,   103 ,   115 ,   247 ,   1265    ,   859 ,   5543    ,0 };
            const std::uint32_t dim631KuoInit[]     =   {   1   ,   1   ,   7   ,   7   ,   15  ,   27  ,   45  ,   29  ,   67  ,   989 ,   753 ,   3215    ,   6281    ,0 };
            const std::uint32_t dim632KuoInit[]     =   {   1   ,   3   ,   1   ,   7   ,   11  ,   15  ,   35  ,   39  ,   61  ,   483 ,   1427    ,   193 ,   3469    ,0 };
            const std::uint32_t dim633KuoInit[]     =   {   1   ,   3   ,   5   ,   9   ,   21  ,   41  ,   21  ,   223 ,   233 ,   341 ,   177 ,   1167    ,   3101    ,0 };
            const std::uint32_t dim634KuoInit[]     =   {   1   ,   3   ,   3   ,   5   ,   19  ,   25  ,   53  ,   247 ,   29  ,   909 ,   2047    ,   1683    ,   4433    ,0 };
            const std::uint32_t dim635KuoInit[]     =   {   1   ,   3   ,   3   ,   9   ,   31  ,   7   ,   71  ,   85  ,   501 ,   447 ,   113 ,   3465    ,   3445    ,0 };
            const std::uint32_t dim636KuoInit[]     =   {   1   ,   1   ,   3   ,   15  ,   19  ,   9   ,   127 ,   69  ,   429 ,   451 ,   531 ,   1319    ,   507 ,0 };
            const std::uint32_t dim637KuoInit[]     =   {   1   ,   3   ,   1   ,   3   ,   29  ,   1   ,   53  ,   63  ,   267 ,   293 ,   333 ,   2749    ,   1785    ,0 };
            const std::uint32_t dim638KuoInit[]     =   {   1   ,   3   ,   1   ,   7   ,   5   ,   43  ,   71  ,   165 ,   325 ,   309 ,   921 ,   2277    ,   6423    ,0 };
            const std::uint32_t dim639KuoInit[]     =   {   1   ,   1   ,   7   ,   5   ,   23  ,   31  ,   63  ,   35  ,   221 ,   733 ,   1901    ,   153 ,   3577    ,0 };
            const std::uint32_t dim640KuoInit[]     =   {   1   ,   3   ,   7   ,   11  ,   7   ,   5   ,   39  ,   141 ,   293 ,   237 ,   501 ,   1759    ,   7763    ,0 };
            const std::uint32_t dim641KuoInit[]     =   {   1   ,   1   ,   3   ,   15  ,   1   ,   49  ,   5   ,   7   ,   239 ,   1021    ,   1215    ,   3857    ,   4637    ,0 };
            const std::uint32_t dim642KuoInit[]     =   {   1   ,   1   ,   5   ,   1   ,   1   ,   31  ,   77  ,   243 ,   155 ,   505 ,   855 ,   3117    ,   815 ,0 };
            const std::uint32_t dim643KuoInit[]     =   {   1   ,   1   ,   7   ,   3   ,   3   ,   33  ,   55  ,   249 ,   185 ,   443 ,   543 ,   1333    ,   5041    ,0 };
            const std::uint32_t dim644KuoInit[]     =   {   1   ,   3   ,   5   ,   11  ,   13  ,   13  ,   83  ,   55  ,   443 ,   723 ,   135 ,   3073    ,   4215    ,0 };
            const std::uint32_t dim645KuoInit[]     =   {   1   ,   3   ,   5   ,   9   ,   15  ,   5   ,   13  ,   209 ,   313 ,   891 ,   431 ,   4009    ,   7531    ,0 };
            const std::uint32_t dim646KuoInit[]     =   {   1   ,   1   ,   5   ,   15  ,   13  ,   37  ,   91  ,   117 ,   321 ,   791 ,   2045    ,   4073    ,   6787    ,0 };
            const std::uint32_t dim647KuoInit[]     =   {   1   ,   1   ,   3   ,   7   ,   1   ,   43  ,   61  ,   121 ,   393 ,   797 ,   1347    ,   491 ,   341 ,0 };
            const std::uint32_t dim648KuoInit[]     =   {   1   ,   1   ,   7   ,   3   ,   1   ,   31  ,   63  ,   205 ,   43  ,   359 ,   325 ,   3329    ,   4961    ,0 };
            const std::uint32_t dim649KuoInit[]     =   {   1   ,   1   ,   7   ,   11  ,   27  ,   21  ,   83  ,   151 ,   97  ,   45  ,   1839    ,   3221    ,   2575    ,0 };
            const std::uint32_t dim650KuoInit[]     =   {   1   ,   3   ,   7   ,   3   ,   13  ,   7   ,   97  ,   89  ,   277 ,   351 ,   1493    ,   1161    ,   6629    ,0 };
            const std::uint32_t dim651KuoInit[]     =   {   1   ,   3   ,   7   ,   11  ,   27  ,   17  ,   19  ,   211 ,   373 ,   73  ,   1325    ,   183 ,   1073    ,0 };
            const std::uint32_t dim652KuoInit[]     =   {   1   ,   3   ,   3   ,   13  ,   9   ,   23  ,   111 ,   235 ,   153 ,   857 ,   1669    ,   3423    ,   3817    ,0 };
            const std::uint32_t dim653KuoInit[]     =   {   1   ,   1   ,   1   ,   5   ,   25  ,   63  ,   99  ,   11  ,   283 ,   755 ,   999 ,   2795    ,   7795    ,0 };
            const std::uint32_t dim654KuoInit[]     =   {   1   ,   1   ,   5   ,   11  ,   3   ,   53  ,   127 ,   73  ,   61  ,   91  ,   1099    ,   921 ,   1787    ,0 };
            const std::uint32_t dim655KuoInit[]     =   {   1   ,   3   ,   5   ,   1   ,   9   ,   39  ,   9   ,   181 ,   287 ,   545 ,   1343    ,   2587    ,   961 ,0 };
            const std::uint32_t dim656KuoInit[]     =   {   1   ,   3   ,   7   ,   5   ,   9   ,   47  ,   7   ,   113 ,   69  ,   531 ,   753 ,   2225    ,   5705    ,0 };
            const std::uint32_t dim657KuoInit[]     =   {   1   ,   1   ,   3   ,   13  ,   29  ,   39  ,   71  ,   223 ,   179 ,   871 ,   1743    ,   2645    ,   7355    ,0 };
            const std::uint32_t dim658KuoInit[]     =   {   1   ,   1   ,   7   ,   5   ,   1   ,   41  ,   87  ,   251 ,   303 ,   271 ,   791 ,   2825    ,   2723    ,0 };
            const std::uint32_t dim659KuoInit[]     =   {   1   ,   3   ,   1   ,   11  ,   31  ,   15  ,   119 ,   127 ,   451 ,   161 ,   1909    ,   3591    ,   2811    ,0 };
            const std::uint32_t dim660KuoInit[]     =   {   1   ,   1   ,   3   ,   13  ,   31  ,   27  ,   111 ,   119 ,   423 ,   419 ,   1659    ,   941 ,   6123    ,0 };
            const std::uint32_t dim661KuoInit[]     =   {   1   ,   1   ,   1   ,   7   ,   27  ,   39  ,   27  ,   61  ,   417 ,   629 ,   1411    ,   1489    ,   5915    ,0 };
            const std::uint32_t dim662KuoInit[]     =   {   1   ,   3   ,   3   ,   1   ,   29  ,   37  ,   111 ,   13  ,   129 ,   831 ,   1423    ,   3859    ,   7009    ,0 };
            const std::uint32_t dim663KuoInit[]     =   {   1   ,   1   ,   1   ,   3   ,   3   ,   51  ,   67  ,   45  ,   289 ,   715 ,   183 ,   357 ,   3661    ,0 };
            const std::uint32_t dim664KuoInit[]     =   {   1   ,   3   ,   3   ,   1   ,   23  ,   49  ,   55  ,   99  ,   77  ,   795 ,   429 ,   1815    ,   1867    ,0 };
            const std::uint32_t dim665KuoInit[]     =   {   1   ,   1   ,   5   ,   7   ,   1   ,   37  ,   45  ,   27  ,   57  ,   937 ,   1583    ,   899 ,   819 ,0 };
            const std::uint32_t dim666KuoInit[]     =   {   1   ,   3   ,   5   ,   7   ,   7   ,   37  ,   1   ,   109 ,   217 ,   203 ,   207 ,   2243    ,   2337    ,0 };
            const std::uint32_t dim667KuoInit[]     =   {   1   ,   1   ,   3   ,   15  ,   27  ,   51  ,   119 ,   45  ,   289 ,   395 ,   95  ,   2425    ,   7421    ,0 };
            const std::uint32_t dim668KuoInit[]     =   {   1   ,   3   ,   1   ,   9   ,   27  ,   61  ,   41  ,   227 ,   279 ,   31  ,   1105    ,   153 ,   5045    ,0 };
            const std::uint32_t dim669KuoInit[]     =   {   1   ,   1   ,   7   ,   15  ,   31  ,   43  ,   109 ,   67  ,   347 ,   611 ,   1811    ,   2969    ,   3545    ,0 };
            const std::uint32_t dim670KuoInit[]     =   {   1   ,   3   ,   1   ,   7   ,   17  ,   15  ,   103 ,   35  ,   407 ,   935 ,   1159    ,   2357    ,   6559    ,0 };
            const std::uint32_t dim671KuoInit[]     =   {   1   ,   1   ,   1   ,   7   ,   5   ,   7   ,   101 ,   43  ,   301 ,   189 ,   641 ,   3015    ,   6955    ,0 };
            const std::uint32_t dim672KuoInit[]     =   {   1   ,   3   ,   1   ,   1   ,   3   ,   41  ,   61  ,   43  ,   213 ,   595 ,   955 ,   377 ,   7527    ,0 };
            const std::uint32_t dim673KuoInit[]     =   {   1   ,   3   ,   3   ,   15  ,   19  ,   45  ,   59  ,   57  ,   425 ,   683 ,   1187    ,   221 ,   4265    ,0 };
            const std::uint32_t dim674KuoInit[]     =   {   1   ,   3   ,   5   ,   3   ,   27  ,   47  ,   85  ,   73  ,   67  ,   509 ,   555 ,   3887    ,   1883    ,0 };
            const std::uint32_t dim675KuoInit[]     =   {   1   ,   3   ,   5   ,   13  ,   19  ,   45  ,   83  ,   191 ,   117 ,   723 ,   701 ,   2783    ,   389 ,0 };
            const std::uint32_t dim676KuoInit[]     =   {   1   ,   1   ,   1   ,   3   ,   17  ,   21  ,   125 ,   13  ,   387 ,   613 ,   1647    ,   2555    ,   2435    ,0 };
            const std::uint32_t dim677KuoInit[]     =   {   1   ,   3   ,   3   ,   11  ,   21  ,   53  ,   105 ,   5   ,   493 ,   167 ,   1195    ,   2815    ,   5761    ,0 };
            const std::uint32_t dim678KuoInit[]     =   {   1   ,   1   ,   1   ,   7   ,   27  ,   17  ,   107 ,   83  ,   31  ,   787 ,   1541    ,   3761    ,   4083    ,0 };
            const std::uint32_t dim679KuoInit[]     =   {   1   ,   3   ,   5   ,   11  ,   5   ,   15  ,   17  ,   219 ,   273 ,   207 ,   119 ,   1693    ,   373 ,0 };
            const std::uint32_t dim680KuoInit[]     =   {   1   ,   1   ,   5   ,   15  ,   7   ,   11  ,   9   ,   103 ,   253 ,   377 ,   1667    ,   1159    ,   5669    ,0 };
            const std::uint32_t dim681KuoInit[]     =   {   1   ,   3   ,   7   ,   5   ,   17  ,   55  ,   23  ,   77  ,   341 ,   419 ,   1165    ,   1625    ,   6609    ,0 };
            const std::uint32_t dim682KuoInit[]     =   {   1   ,   3   ,   1   ,   15  ,   29  ,   7   ,   101 ,   183 ,   181 ,   111 ,   751 ,   247 ,   4205    ,0 };
            const std::uint32_t dim683KuoInit[]     =   {   1   ,   1   ,   1   ,   11  ,   3   ,   5   ,   91  ,   43  ,   247 ,   661 ,   621 ,   2791    ,   4245    ,0 };
            const std::uint32_t dim684KuoInit[]     =   {   1   ,   1   ,   1   ,   11  ,   11  ,   63  ,   25  ,   239 ,   39  ,   311 ,   1603    ,   1179    ,   4959    ,0 };
            const std::uint32_t dim685KuoInit[]     =   {   1   ,   3   ,   1   ,   7   ,   23  ,   61  ,   49  ,   99  ,   287 ,   251 ,   1053    ,   3819    ,   5575    ,0 };
            const std::uint32_t dim686KuoInit[]     =   {   1   ,   1   ,   1   ,   7   ,   21  ,   17  ,   33  ,   163 ,   503 ,   537 ,   1159    ,   2473    ,   8113    ,0 };
            const std::uint32_t dim687KuoInit[]     =   {   1   ,   1   ,   5   ,   13  ,   23  ,   57  ,   57  ,   89  ,   503 ,   299 ,   1319    ,   2177    ,   8155    ,0 };
            const std::uint32_t dim688KuoInit[]     =   {   1   ,   3   ,   3   ,   5   ,   5   ,   5   ,   61  ,   103 ,   247 ,   339 ,   1137    ,   3717    ,   747 ,0 };
            const std::uint32_t dim689KuoInit[]     =   {   1   ,   3   ,   1   ,   7   ,   17  ,   55  ,   41  ,   155 ,   363 ,   873 ,   59  ,   2093    ,   4255    ,0 };
            const std::uint32_t dim690KuoInit[]     =   {   1   ,   3   ,   3   ,   7   ,   9   ,   25  ,   93  ,   87  ,   479 ,   477 ,   2047    ,   321 ,   2277    ,0 };
            const std::uint32_t dim691KuoInit[]     =   {   1   ,   1   ,   3   ,   11  ,   7   ,   37  ,   41  ,   237 ,   121 ,   187 ,   929 ,   1823    ,   313 ,0 };
            const std::uint32_t dim692KuoInit[]     =   {   1   ,   1   ,   1   ,   11  ,   29  ,   41  ,   79  ,   11  ,   295 ,   715 ,   979 ,   2649    ,   915 ,0 };
            const std::uint32_t dim693KuoInit[]     =   {   1   ,   1   ,   3   ,   13  ,   5   ,   9   ,   55  ,   159 ,   343 ,   887 ,   235 ,   53  ,   593 ,0 };
            const std::uint32_t dim694KuoInit[]     =   {   1   ,   1   ,   1   ,   3   ,   13  ,   23  ,   105 ,   125 ,   405 ,   521 ,   897 ,   559 ,   1561    ,0 };
            const std::uint32_t dim695KuoInit[]     =   {   1   ,   1   ,   3   ,   9   ,   23  ,   33  ,   121 ,   183 ,   181 ,   141 ,   1103    ,   821 ,   7193    ,0 };
            const std::uint32_t dim696KuoInit[]     =   {   1   ,   1   ,   3   ,   9   ,   23  ,   1   ,   113 ,   63  ,   59  ,   783 ,   1525    ,   115 ,   3193    ,0 };
            const std::uint32_t dim697KuoInit[]     =   {   1   ,   3   ,   1   ,   9   ,   23  ,   29  ,   83  ,   237 ,   83  ,   477 ,   1163    ,   2951    ,   3523    ,0 };
            const std::uint32_t dim698KuoInit[]     =   {   1   ,   3   ,   5   ,   1   ,   21  ,   25  ,   55  ,   79  ,   39  ,   45  ,   1509    ,   2127    ,   5259    ,0 };
            const std::uint32_t dim699KuoInit[]     =   {   1   ,   1   ,   7   ,   9   ,   31  ,   61  ,   83  ,   145 ,   89  ,   723 ,   393 ,   1543    ,   7765    ,0 };
            const std::uint32_t dim700KuoInit[]     =   {   1   ,   1   ,   5   ,   15  ,   21  ,   17  ,   73  ,   189 ,   473 ,   1023    ,   1627    ,   2305    ,   7127    ,0 };
            const std::uint32_t dim701KuoInit[]     =   {   1   ,   3   ,   1   ,   7   ,   7   ,   23  ,   61  ,   203 ,   373 ,   941 ,   975 ,   3225    ,   7659    ,0 };
            const std::uint32_t dim702KuoInit[]     =   {   1   ,   3   ,   1   ,   15  ,   31  ,   19  ,   99  ,   197 ,   113 ,   131 ,   263 ,   2427    ,   2085    ,0 };
            const std::uint32_t dim703KuoInit[]     =   {   1   ,   1   ,   1   ,   13  ,   25  ,   27  ,   3   ,   139 ,   351 ,   267 ,   1583    ,   913 ,   5497    ,0 };
            const std::uint32_t dim704KuoInit[]     =   {   1   ,   3   ,   5   ,   11  ,   7   ,   1   ,   65  ,   85  ,   271 ,   151 ,   1003    ,   889 ,   6127    ,0 };
            const std::uint32_t dim705KuoInit[]     =   {   1   ,   3   ,   7   ,   5   ,   21  ,   27  ,   39  ,   147 ,   139 ,   81  ,   1377    ,   1969    ,   6171    ,0 };
            const std::uint32_t dim706KuoInit[]     =   {   1   ,   3   ,   5   ,   13  ,   1   ,   11  ,   101 ,   27  ,   285 ,   939 ,   1055    ,   3237    ,   7063    ,0 };
            const std::uint32_t dim707KuoInit[]     =   {   1   ,   3   ,   3   ,   7   ,   23  ,   43  ,   67  ,   89  ,   201 ,   393 ,   277 ,   3531    ,   4003    ,0 };
            const std::uint32_t dim708KuoInit[]     =   {   1   ,   3   ,   7   ,   9   ,   3   ,   13  ,   103 ,   241 ,   161 ,   111 ,   61  ,   4001    ,   6291    ,0 };
            const std::uint32_t dim709KuoInit[]     =   {   1   ,   1   ,   5   ,   7   ,   5   ,   27  ,   57  ,   87  ,   313 ,   471 ,   227 ,   1395    ,   2821    ,0 };
            const std::uint32_t dim710KuoInit[]     =   {   1   ,   3   ,   1   ,   5   ,   11  ,   35  ,   11  ,   157 ,   257 ,   679 ,   245 ,   329 ,   2423    ,0 };
            const std::uint32_t dim711KuoInit[]     =   {   1   ,   1   ,   7   ,   11  ,   15  ,   5   ,   29  ,   229 ,   365 ,   911 ,   477 ,   219 ,   4851    ,0 };
            const std::uint32_t dim712KuoInit[]     =   {   1   ,   3   ,   1   ,   9   ,   5   ,   57  ,   87  ,   19  ,   93  ,   403 ,   1729    ,   1843    ,   7301    ,0 };
            const std::uint32_t dim713KuoInit[]     =   {   1   ,   1   ,   3   ,   3   ,   27  ,   29  ,   11  ,   99  ,   149 ,   917 ,   709 ,   3761    ,   6947    ,0 };
            const std::uint32_t dim714KuoInit[]     =   {   1   ,   1   ,   5   ,   1   ,   19  ,   63  ,   69  ,   71  ,   209 ,   423 ,   2015    ,   3905    ,   2077    ,0 };
            const std::uint32_t dim715KuoInit[]     =   {   1   ,   3   ,   7   ,   7   ,   7   ,   3   ,   9   ,   63  ,   137 ,   781 ,   1825    ,   1331    ,   2987    ,0 };
            const std::uint32_t dim716KuoInit[]     =   {   1   ,   3   ,   7   ,   11  ,   15  ,   23  ,   7   ,   205 ,   27  ,   619 ,   225 ,   297 ,   8179    ,0 };
            const std::uint32_t dim717KuoInit[]     =   {   1   ,   3   ,   3   ,   13  ,   11  ,   15  ,   11  ,   185 ,   343 ,   269 ,   1415    ,   843 ,   4001    ,0 };
            const std::uint32_t dim718KuoInit[]     =   {   1   ,   3   ,   3   ,   1   ,   15  ,   47  ,   101 ,   49  ,   25  ,   933 ,   903 ,   1927    ,   6641    ,0 };
            const std::uint32_t dim719KuoInit[]     =   {   1   ,   3   ,   3   ,   13  ,   7   ,   45  ,   29  ,   51  ,   143 ,   549 ,   119 ,   235 ,   7345    ,0 };
            const std::uint32_t dim720KuoInit[]     =   {   1   ,   1   ,   3   ,   9   ,   29  ,   45  ,   53  ,   133 ,   173 ,   543 ,   545 ,   2015    ,   149 ,0 };
            const std::uint32_t dim721KuoInit[]     =   {   1   ,   1   ,   3   ,   11  ,   3   ,   3   ,   109 ,   193 ,   349 ,   243 ,   1381    ,   3547    ,   4387    ,0 };
            const std::uint32_t dim722KuoInit[]     =   {   1   ,   3   ,   7   ,   9   ,   7   ,   3   ,   37  ,   121 ,   79  ,   59  ,   1453    ,   3273    ,   477 ,0 };
            const std::uint32_t dim723KuoInit[]     =   {   1   ,   3   ,   5   ,   15  ,   19  ,   15  ,   83  ,   5   ,   203 ,   603 ,   373 ,   955 ,   1587    ,0 };
            const std::uint32_t dim724KuoInit[]     =   {   1   ,   1   ,   5   ,   11  ,   25  ,   41  ,   89  ,   47  ,   313 ,   443 ,   1799    ,   1827    ,   5881    ,0 };
            const std::uint32_t dim725KuoInit[]     =   {   1   ,   1   ,   3   ,   5   ,   9   ,   7   ,   15  ,   87  ,   285 ,   509 ,   289 ,   855 ,   3131    ,0 };
            const std::uint32_t dim726KuoInit[]     =   {   1   ,   1   ,   3   ,   11  ,   13  ,   57  ,   41  ,   235 ,   357 ,   213 ,   1867    ,   1961    ,   2759    ,0 };
            const std::uint32_t dim727KuoInit[]     =   {   1   ,   3   ,   5   ,   9   ,   25  ,   15  ,   111 ,   197 ,   479 ,   539 ,   1833    ,   105 ,   7245    ,0 };
            const std::uint32_t dim728KuoInit[]     =   {   1   ,   1   ,   5   ,   5   ,   23  ,   47  ,   101 ,   97  ,   97  ,   261 ,   1301    ,   3895    ,   5425    ,0 };
            const std::uint32_t dim729KuoInit[]     =   {   1   ,   1   ,   7   ,   11  ,   13  ,   49  ,   39  ,   233 ,   7   ,   965 ,   2015    ,   1341    ,   941 ,0 };
            const std::uint32_t dim730KuoInit[]     =   {   1   ,   1   ,   5   ,   7   ,   19  ,   63  ,   91  ,   77  ,   469 ,   367 ,   1849    ,   1213    ,   7611    ,0 };
            const std::uint32_t dim731KuoInit[]     =   {   1   ,   3   ,   3   ,   15  ,   17  ,   57  ,   27  ,   107 ,   133 ,   431 ,   445 ,   2885    ,   5963    ,0 };
            const std::uint32_t dim732KuoInit[]     =   {   1   ,   1   ,   3   ,   1   ,   27  ,   37  ,   119 ,   241 ,   403 ,   239 ,   833 ,   3057    ,   5557    ,0 };
            const std::uint32_t dim733KuoInit[]     =   {   1   ,   3   ,   3   ,   13  ,   11  ,   47  ,   35  ,   41  ,   243 ,   143 ,   1923    ,   1883    ,   2543    ,0 };
            const std::uint32_t dim734KuoInit[]     =   {   1   ,   1   ,   5   ,   5   ,   3   ,   15  ,   45  ,   205 ,   179 ,   515 ,   161 ,   895 ,   3679    ,0 };
            const std::uint32_t dim735KuoInit[]     =   {   1   ,   3   ,   1   ,   1   ,   5   ,   39  ,   99  ,   221 ,   115 ,   983 ,   1913    ,   665 ,   7835    ,0 };
            const std::uint32_t dim736KuoInit[]     =   {   1   ,   3   ,   5   ,   15  ,   5   ,   5   ,   111 ,   45  ,   373 ,   143 ,   1107    ,   1413    ,   2935    ,0 };
            const std::uint32_t dim737KuoInit[]     =   {   1   ,   3   ,   7   ,   11  ,   17  ,   53  ,   77  ,   159 ,   319 ,   279 ,   835 ,   139 ,   3633    ,0 };
            const std::uint32_t dim738KuoInit[]     =   {   1   ,   1   ,   7   ,   15  ,   5   ,   57  ,   105 ,   139 ,   491 ,   409 ,   51  ,   2875    ,   427 ,0 };
            const std::uint32_t dim739KuoInit[]     =   {   1   ,   1   ,   1   ,   9   ,   9   ,   9   ,   93  ,   45  ,   265 ,   307 ,   589 ,   557 ,   3971    ,0 };
            const std::uint32_t dim740KuoInit[]     =   {   1   ,   3   ,   5   ,   3   ,   23  ,   45  ,   5   ,   9   ,   123 ,   841 ,   679 ,   2213    ,   4507    ,0 };
            const std::uint32_t dim741KuoInit[]     =   {   1   ,   3   ,   5   ,   3   ,   27  ,   55  ,   55  ,   19  ,   405 ,   43  ,   1897    ,   3515    ,   683 ,0 };
            const std::uint32_t dim742KuoInit[]     =   {   1   ,   1   ,   7   ,   15  ,   23  ,   47  ,   121 ,   105 ,   341 ,   707 ,   799 ,   1843    ,   7011    ,0 };
            const std::uint32_t dim743KuoInit[]     =   {   1   ,   1   ,   3   ,   13  ,   23  ,   51  ,   71  ,   161 ,   415 ,   819 ,   729 ,   297 ,   4461    ,0 };
            const std::uint32_t dim744KuoInit[]     =   {   1   ,   3   ,   5   ,   15  ,   13  ,   39  ,   43  ,   103 ,   251 ,   583 ,   775 ,   877 ,   4947    ,0 };
            const std::uint32_t dim745KuoInit[]     =   {   1   ,   3   ,   7   ,   5   ,   19  ,   61  ,   121 ,   49  ,   75  ,   963 ,   297 ,   3751    ,   911 ,0 };
            const std::uint32_t dim746KuoInit[]     =   {   1   ,   3   ,   5   ,   7   ,   15  ,   51  ,   23  ,   23  ,   453 ,   675 ,   1575    ,   473 ,   3763    ,0 };
            const std::uint32_t dim747KuoInit[]     =   {   1   ,   1   ,   7   ,   11  ,   9   ,   37  ,   69  ,   137 ,   251 ,   89  ,   1823    ,   1289    ,   2983    ,0 };
            const std::uint32_t dim748KuoInit[]     =   {   1   ,   3   ,   3   ,   5   ,   11  ,   39  ,   39  ,   231 ,   427 ,   633 ,   1453    ,   579 ,   5823    ,0 };
            const std::uint32_t dim749KuoInit[]     =   {   1   ,   3   ,   7   ,   11  ,   31  ,   57  ,   87  ,   81  ,   161 ,   929 ,   1293    ,   3215    ,   4803    ,0 };
            const std::uint32_t dim750KuoInit[]     =   {   1   ,   3   ,   5   ,   5   ,   27  ,   33  ,   11  ,   151 ,   25  ,   1017    ,   41  ,   61  ,   4381    ,0 };
            const std::uint32_t dim751KuoInit[]     =   {   1   ,   3   ,   1   ,   15  ,   23  ,   25  ,   7   ,   21  ,   231 ,   407 ,   817 ,   2089    ,   839 ,0 };
            const std::uint32_t dim752KuoInit[]     =   {   1   ,   1   ,   7   ,   1   ,   5   ,   51  ,   117 ,   59  ,   251 ,   861 ,   727 ,   481 ,   2207    ,0 };
            const std::uint32_t dim753KuoInit[]     =   {   1   ,   1   ,   5   ,   3   ,   21  ,   19  ,   97  ,   199 ,   135 ,   203 ,   1177    ,   2751    ,   2863    ,0 };
            const std::uint32_t dim754KuoInit[]     =   {   1   ,   3   ,   7   ,   3   ,   27  ,   3   ,   5   ,   109 ,   17  ,   933 ,   911 ,   921 ,   1173    ,0 };
            const std::uint32_t dim755KuoInit[]     =   {   1   ,   3   ,   7   ,   1   ,   7   ,   1   ,   121 ,   205 ,   381 ,   971 ,   255 ,   3313    ,   5479    ,0 };
            const std::uint32_t dim756KuoInit[]     =   {   1   ,   3   ,   1   ,   1   ,   17  ,   59  ,   3   ,   5   ,   271 ,   149 ,   111 ,   3707    ,   7893    ,0 };
            const std::uint32_t dim757KuoInit[]     =   {   1   ,   1   ,   1   ,   1   ,   17  ,   61  ,   47  ,   117 ,   187 ,   839 ,   435 ,   399 ,   3173    ,0 };
            const std::uint32_t dim758KuoInit[]     =   {   1   ,   3   ,   3   ,   7   ,   5   ,   9   ,   119 ,   191 ,   197 ,   791 ,   375 ,   3361    ,   6677    ,0 };
            const std::uint32_t dim759KuoInit[]     =   {   1   ,   1   ,   5   ,   3   ,   21  ,   49  ,   69  ,   249 ,   39  ,   69  ,   673 ,   109 ,   7051    ,0 };
            const std::uint32_t dim760KuoInit[]     =   {   1   ,   1   ,   3   ,   11  ,   21  ,   37  ,   121 ,   93  ,   261 ,   5   ,   1269    ,   767 ,   2801    ,0 };
            const std::uint32_t dim761KuoInit[]     =   {   1   ,   1   ,   5   ,   9   ,   31  ,   49  ,   9   ,   87  ,   375 ,   773 ,   1517    ,   3057    ,   2169    ,0 };
            const std::uint32_t dim762KuoInit[]     =   {   1   ,   1   ,   5   ,   3   ,   13  ,   33  ,   31  ,   87  ,   353 ,   991 ,   1809    ,   859 ,   6117    ,0 };
            const std::uint32_t dim763KuoInit[]     =   {   1   ,   1   ,   5   ,   11  ,   3   ,   21  ,   103 ,   41  ,   129 ,   137 ,   1567    ,   3483    ,   5317    ,0 };
            const std::uint32_t dim764KuoInit[]     =   {   1   ,   3   ,   5   ,   1   ,   3   ,   31  ,   5   ,   15  ,   109 ,   723 ,   1439    ,   2543    ,   2377    ,0 };
            const std::uint32_t dim765KuoInit[]     =   {   1   ,   3   ,   3   ,   13  ,   11  ,   17  ,   9   ,   243 ,   233 ,   543 ,   903 ,   2775    ,   6877    ,0 };
            const std::uint32_t dim766KuoInit[]     =   {   1   ,   1   ,   7   ,   1   ,   23  ,   45  ,   61  ,   137 ,   207 ,   457 ,   245 ,   3833    ,   6533    ,0 };
            const std::uint32_t dim767KuoInit[]     =   {   1   ,   3   ,   1   ,   1   ,   31  ,   7   ,   71  ,   153 ,   501 ,   749 ,   1477    ,   621 ,   6577    ,0 };
            const std::uint32_t dim768KuoInit[]     =   {   1   ,   3   ,   1   ,   13  ,   3   ,   45  ,   3   ,   233 ,   85  ,   847 ,   1031    ,   141 ,   5029    ,0 };
            const std::uint32_t dim769KuoInit[]     =   {   1   ,   3   ,   1   ,   13  ,   17  ,   35  ,   49  ,   157 ,   243 ,   175 ,   905 ,   539 ,   8059    ,0 };
            const std::uint32_t dim770KuoInit[]     =   {   1   ,   3   ,   1   ,   11  ,   19  ,   45  ,   31  ,   49  ,   399 ,   341 ,   2047    ,   1527    ,   5993    ,0 };
            const std::uint32_t dim771KuoInit[]     =   {   1   ,   3   ,   1   ,   3   ,   5   ,   5   ,   33  ,   163 ,   239 ,   607 ,   1367    ,   2747    ,   1513    ,0 };
            const std::uint32_t dim772KuoInit[]     =   {   1   ,   3   ,   3   ,   11  ,   9   ,   29  ,   33  ,   255 ,   29  ,   955 ,   367 ,   1709    ,   4993    ,0 };
            const std::uint32_t dim773KuoInit[]     =   {   1   ,   3   ,   7   ,   5   ,   19  ,   35  ,   11  ,   47  ,   109 ,   235 ,   1125    ,   4019    ,   5395    ,0 };
            const std::uint32_t dim774KuoInit[]     =   {   1   ,   1   ,   7   ,   1   ,   19  ,   29  ,   43  ,   1   ,   199 ,   479 ,   1025    ,   1065    ,   2203    ,0 };
            const std::uint32_t dim775KuoInit[]     =   {   1   ,   3   ,   1   ,   9   ,   17  ,   13  ,   45  ,   167 ,   125 ,   869 ,   1667    ,   1083    ,   4015    ,0 };
            const std::uint32_t dim776KuoInit[]     =   {   1   ,   1   ,   5   ,   11  ,   27  ,   45  ,   115 ,   199 ,   375 ,   761 ,   1641    ,   3761    ,   5509    ,0 };
            const std::uint32_t dim777KuoInit[]     =   {   1   ,   1   ,   7   ,   15  ,   9   ,   47  ,   47  ,   133 ,   401 ,   555 ,   1077    ,   1381    ,   1903    ,0 };
            const std::uint32_t dim778KuoInit[]     =   {   1   ,   3   ,   3   ,   15  ,   3   ,   45  ,   19  ,   49  ,   377 ,   135 ,   239 ,   3605    ,   1053    ,0 };
            const std::uint32_t dim779KuoInit[]     =   {   1   ,   3   ,   1   ,   11  ,   17  ,   5   ,   83  ,   101 ,   247 ,   267 ,   1337    ,   2649    ,   513 ,0 };
            const std::uint32_t dim780KuoInit[]     =   {   1   ,   3   ,   1   ,   11  ,   13  ,   41  ,   41  ,   113 ,   243 ,   463 ,   1077    ,   565 ,   2871    ,0 };
            const std::uint32_t dim781KuoInit[]     =   {   1   ,   3   ,   5   ,   11  ,   19  ,   63  ,   81  ,   51  ,   139 ,   921 ,   2021    ,   417 ,   1305    ,0 };
            const std::uint32_t dim782KuoInit[]     =   {   1   ,   3   ,   3   ,   1   ,   23  ,   61  ,   13  ,   123 ,   135 ,   521 ,   1963    ,   3085    ,   4395    ,0 };
            const std::uint32_t dim783KuoInit[]     =   {   1   ,   3   ,   1   ,   1   ,   15  ,   61  ,   17  ,   245 ,   479 ,   77  ,   287 ,   3043    ,   2647    ,0 };
            const std::uint32_t dim784KuoInit[]     =   {   1   ,   1   ,   7   ,   15  ,   29  ,   5   ,   125 ,   123 ,   149 ,   919 ,   1779    ,   3763    ,   1479    ,0 };
            const std::uint32_t dim785KuoInit[]     =   {   1   ,   1   ,   3   ,   1   ,   19  ,   49  ,   27  ,   127 ,   253 ,   279 ,   739 ,   147 ,   6835    ,0 };
            const std::uint32_t dim786KuoInit[]     =   {   1   ,   3   ,   5   ,   11  ,   21  ,   27  ,   33  ,   85  ,   419 ,   441 ,   1341    ,   289 ,   2759    ,0 };
            const std::uint32_t dim787KuoInit[]     =   {   1   ,   3   ,   1   ,   3   ,   3   ,   9   ,   17  ,   99  ,   375 ,   251 ,   1823    ,   2433    ,   1525    ,0 };
            const std::uint32_t dim788KuoInit[]     =   {   1   ,   3   ,   1   ,   3   ,   5   ,   55  ,   25  ,   225 ,   473 ,   825 ,   1061    ,   2987    ,   4397    ,0 };
            const std::uint32_t dim789KuoInit[]     =   {   1   ,   1   ,   7   ,   15  ,   23  ,   59  ,   9   ,   163 ,   105 ,   911 ,   905 ,   3715    ,   4917    ,0 };
            const std::uint32_t dim790KuoInit[]     =   {   1   ,   3   ,   1   ,   11  ,   21  ,   53  ,   127 ,   3   ,   507 ,   467 ,   547 ,   3003    ,   6939    ,0 };
            const std::uint32_t dim791KuoInit[]     =   {   1   ,   1   ,   1   ,   13  ,   15  ,   7   ,   1   ,   7   ,   101 ,   645 ,   1469    ,   843 ,   2843    ,0 };
            const std::uint32_t dim792KuoInit[]     =   {   1   ,   3   ,   3   ,   9   ,   11  ,   35  ,   95  ,   53  ,   291 ,   459 ,   669 ,   1163    ,   4893    ,0 };
            const std::uint32_t dim793KuoInit[]     =   {   1   ,   1   ,   3   ,   3   ,   25  ,   29  ,   29  ,   223 ,   21  ,   553 ,   177 ,   3347    ,   3575    ,0 };
            const std::uint32_t dim794KuoInit[]     =   {   1   ,   1   ,   5   ,   1   ,   23  ,   17  ,   21  ,   57  ,   383 ,   427 ,   397 ,   1947    ,   2627    ,0 };
            const std::uint32_t dim795KuoInit[]     =   {   1   ,   3   ,   7   ,   1   ,   21  ,   53  ,   79  ,   59  ,   133 ,   461 ,   1703    ,   3071    ,   4679    ,0 };
            const std::uint32_t dim796KuoInit[]     =   {   1   ,   3   ,   5   ,   1   ,   27  ,   31  ,   83  ,   159 ,   505 ,   121 ,   1969    ,   1073    ,   2117    ,0 };
            const std::uint32_t dim797KuoInit[]     =   {   1   ,   1   ,   3   ,   1   ,   19  ,   25  ,   43  ,   115 ,   191 ,   845 ,   1923    ,   903 ,   2319    ,0 };
            const std::uint32_t dim798KuoInit[]     =   {   1   ,   1   ,   3   ,   9   ,   27  ,   37  ,   31  ,   111 ,   437 ,   925 ,   501 ,   883 ,   3485    ,0 };
            const std::uint32_t dim799KuoInit[]     =   {   1   ,   3   ,   5   ,   5   ,   15  ,   25  ,   51  ,   131 ,   149 ,   811 ,   1827    ,   1519    ,   1435    ,0 };
            const std::uint32_t dim800KuoInit[]     =   {   1   ,   1   ,   7   ,   13  ,   3   ,   39  ,   103 ,   107 ,   473 ,   553 ,   1763    ,   399 ,   2137    ,0 };
            const std::uint32_t dim801KuoInit[]     =   {   1   ,   3   ,   7   ,   13  ,   27  ,   25  ,   49  ,   29  ,   497 ,   863 ,   1715    ,   99  ,   1521    ,0 };
            const std::uint32_t dim802KuoInit[]     =   {   1   ,   1   ,   1   ,   9   ,   27  ,   37  ,   67  ,   59  ,   11  ,   369 ,   893 ,   2249    ,   5303    ,0 };
            const std::uint32_t dim803KuoInit[]     =   {   1   ,   3   ,   3   ,   13  ,   19  ,   9   ,   93  ,   29  ,   247 ,   35  ,   833 ,   1037    ,   7137    ,0 };
            const std::uint32_t dim804KuoInit[]     =   {   1   ,   3   ,   7   ,   3   ,   25  ,   17  ,   63  ,   239 ,   395 ,   367 ,   1935    ,   2095    ,   5191    ,0 };
            const std::uint32_t dim805KuoInit[]     =   {   1   ,   3   ,   5   ,   15  ,   23  ,   51  ,   13  ,   101 ,   477 ,   511 ,   1951    ,   2505    ,   4155    ,0 };
            const std::uint32_t dim806KuoInit[]     =   {   1   ,   3   ,   3   ,   15  ,   3   ,   55  ,   15  ,   173 ,   21  ,   699 ,   1617    ,   1573    ,   2645    ,0 };
            const std::uint32_t dim807KuoInit[]     =   {   1   ,   1   ,   3   ,   11  ,   7   ,   55  ,   69  ,   165 ,   255 ,   397 ,   2033    ,   9   ,   843 ,0 };
            const std::uint32_t dim808KuoInit[]     =   {   1   ,   3   ,   1   ,   13  ,   5   ,   3   ,   37  ,   99  ,   165 ,   971 ,   555 ,   2379    ,   7879    ,0 };
            const std::uint32_t dim809KuoInit[]     =   {   1   ,   1   ,   5   ,   3   ,   19  ,   37  ,   23  ,   197 ,   145 ,   315 ,   981 ,   161 ,   323 ,0 };
            const std::uint32_t dim810KuoInit[]     =   {   1   ,   1   ,   7   ,   7   ,   17  ,   37  ,   27  ,   189 ,   371 ,   145 ,   1097    ,   2801    ,   5469    ,0 };
            const std::uint32_t dim811KuoInit[]     =   {   1   ,   1   ,   3   ,   9   ,   23  ,   15  ,   39  ,   7   ,   25  ,   221 ,   757 ,   1393    ,   4629    ,0 };
            const std::uint32_t dim812KuoInit[]     =   {   1   ,   1   ,   1   ,   1   ,   13  ,   31  ,   29  ,   197 ,   237 ,   173 ,   337 ,   743 ,   1459    ,0 };
            const std::uint32_t dim813KuoInit[]     =   {   1   ,   1   ,   5   ,   15  ,   17  ,   7   ,   127 ,   29  ,   307 ,   965 ,   1567    ,   2771    ,   6053    ,0 };
            const std::uint32_t dim814KuoInit[]     =   {   1   ,   3   ,   1   ,   1   ,   13  ,   57  ,   41  ,   59  ,   77  ,   67  ,   1985    ,   3443    ,   7495    ,0 };
            const std::uint32_t dim815KuoInit[]     =   {   1   ,   3   ,   7   ,   15  ,   17  ,   21  ,   57  ,   143 ,   179 ,   99  ,   217 ,   1763    ,   873 ,0 };
            const std::uint32_t dim816KuoInit[]     =   {   1   ,   1   ,   7   ,   1   ,   21  ,   17  ,   123 ,   39  ,   95  ,   775 ,   1865    ,   341 ,   6167    ,0 };
            const std::uint32_t dim817KuoInit[]     =   {   1   ,   3   ,   7   ,   3   ,   31  ,   33  ,   33  ,   163 ,   281 ,   765 ,   1809    ,   1469    ,   7011    ,0 };
            const std::uint32_t dim818KuoInit[]     =   {   1   ,   3   ,   7   ,   7   ,   25  ,   35  ,   45  ,   109 ,   221 ,   25  ,   757 ,   597 ,   3057    ,0 };
            const std::uint32_t dim819KuoInit[]     =   {   1   ,   3   ,   5   ,   3   ,   27  ,   25  ,   97  ,   21  ,   351 ,   841 ,   1339    ,   565 ,   7181    ,0 };
            const std::uint32_t dim820KuoInit[]     =   {   1   ,   1   ,   1   ,   15  ,   23  ,   61  ,   97  ,   57  ,   503 ,   379 ,   25  ,   1197    ,   6957    ,0 };
            const std::uint32_t dim821KuoInit[]     =   {   1   ,   3   ,   3   ,   3   ,   13  ,   49  ,   127 ,   89  ,   329 ,   503 ,   1957    ,   3569    ,   7013    ,0 };
            const std::uint32_t dim822KuoInit[]     =   {   1   ,   1   ,   7   ,   7   ,   7   ,   15  ,   43  ,   61  ,   227 ,   859 ,   279 ,   3309    ,   1941    ,0 };
            const std::uint32_t dim823KuoInit[]     =   {   1   ,   3   ,   1   ,   9   ,   19  ,   1   ,   111 ,   45  ,   315 ,   339 ,   1049    ,   121 ,   2711    ,0 };
            const std::uint32_t dim824KuoInit[]     =   {   1   ,   1   ,   3   ,   11  ,   7   ,   33  ,   121 ,   253 ,   267 ,   845 ,   1677    ,   569 ,   3743    ,0 };
            const std::uint32_t dim825KuoInit[]     =   {   1   ,   3   ,   7   ,   9   ,   9   ,   53  ,   113 ,   11  ,   177 ,   165 ,   1707    ,   2027    ,   2099    ,0 };
            const std::uint32_t dim826KuoInit[]     =   {   1   ,   1   ,   5   ,   7   ,   19  ,   41  ,   33  ,   129 ,   389 ,   249 ,   1945    ,   1393    ,   5941    ,0 };
            const std::uint32_t dim827KuoInit[]     =   {   1   ,   1   ,   1   ,   1   ,   27  ,   37  ,   63  ,   171 ,   301 ,   179 ,   223 ,   3775    ,   1189    ,0 };
            const std::uint32_t dim828KuoInit[]     =   {   1   ,   3   ,   3   ,   5   ,   5   ,   33  ,   101 ,   37  ,   505 ,   561 ,   1681    ,   567 ,   2197    ,0 };
            const std::uint32_t dim829KuoInit[]     =   {   1   ,   3   ,   7   ,   13  ,   25  ,   23  ,   29  ,   27  ,   325 ,   757 ,   5   ,   487 ,   3241    ,0 };
            const std::uint32_t dim830KuoInit[]     =   {   1   ,   3   ,   3   ,   7   ,   27  ,   13  ,   85  ,   35  ,   171 ,   565 ,   969 ,   773 ,   7173    ,0 };
            const std::uint32_t dim831KuoInit[]     =   {   1   ,   3   ,   5   ,   5   ,   11  ,   55  ,   33  ,   243 ,   401 ,   939 ,   73  ,   775 ,   1159    ,0 };
            const std::uint32_t dim832KuoInit[]     =   {   1   ,   1   ,   3   ,   13  ,   13  ,   63  ,   9   ,   161 ,   343 ,   547 ,   1659    ,   1005    ,   8041    ,0 };
            const std::uint32_t dim833KuoInit[]     =   {   1   ,   3   ,   5   ,   7   ,   15  ,   27  ,   27  ,   51  ,   475 ,   957 ,   445 ,   3745    ,   5113    ,0 };
            const std::uint32_t dim834KuoInit[]     =   {   1   ,   1   ,   3   ,   7   ,   15  ,   49  ,   63  ,   181 ,   15  ,   1   ,   1915    ,   633 ,   1039    ,0 };
            const std::uint32_t dim835KuoInit[]     =   {   1   ,   3   ,   7   ,   1   ,   1   ,   11  ,   15  ,   221 ,   375 ,   59  ,   1471    ,   113 ,   5661    ,0 };
            const std::uint32_t dim836KuoInit[]     =   {   1   ,   3   ,   5   ,   5   ,   11  ,   41  ,   115 ,   87  ,   263 ,   173 ,   1249    ,   2235    ,   6863    ,0 };
            const std::uint32_t dim837KuoInit[]     =   {   1   ,   1   ,   5   ,   11  ,   19  ,   1   ,   61  ,   25  ,   239 ,   5   ,   1869    ,   2269    ,   3911    ,0 };
            const std::uint32_t dim838KuoInit[]     =   {   1   ,   3   ,   5   ,   7   ,   23  ,   59  ,   99  ,   47  ,   439 ,   105 ,   455 ,   547 ,   2447    ,0 };
            const std::uint32_t dim839KuoInit[]     =   {   1   ,   1   ,   7   ,   15  ,   25  ,   15  ,   117 ,   185 ,   83  ,   243 ,   1099    ,   2613    ,   7721    ,0 };
            const std::uint32_t dim840KuoInit[]     =   {   1   ,   3   ,   1   ,   9   ,   5   ,   49  ,   27  ,   237 ,   239 ,   177 ,   1507    ,   2059    ,   1731    ,0 };
            const std::uint32_t dim841KuoInit[]     =   {   1   ,   3   ,   3   ,   11  ,   29  ,   47  ,   119 ,   243 ,   475 ,   443 ,   111 ,   787 ,   2597    ,0 };
            const std::uint32_t dim842KuoInit[]     =   {   1   ,   1   ,   7   ,   1   ,   25  ,   39  ,   95  ,   107 ,   391 ,   149 ,   397 ,   3755    ,   2735    ,0 };
            const std::uint32_t dim843KuoInit[]     =   {   1   ,   3   ,   7   ,   11  ,   13  ,   49  ,   37  ,   135 ,   99  ,   473 ,   1961    ,   1233    ,   7359    ,0 };
            const std::uint32_t dim844KuoInit[]     =   {   1   ,   3   ,   5   ,   11  ,   29  ,   59  ,   123 ,   53  ,   371 ,   573 ,   1099    ,   3035    ,   3217    ,0 };
            const std::uint32_t dim845KuoInit[]     =   {   1   ,   1   ,   1   ,   11  ,   25  ,   47  ,   105 ,   147 ,   317 ,   69  ,   1201    ,   3781    ,   2457    ,0 };
            const std::uint32_t dim846KuoInit[]     =   {   1   ,   1   ,   5   ,   9   ,   3   ,   31  ,   25  ,   127 ,   153 ,   303 ,   1367    ,   3583    ,   5229    ,0 };
            const std::uint32_t dim847KuoInit[]     =   {   1   ,   1   ,   3   ,   13  ,   25  ,   33  ,   11  ,   101 ,   85  ,   741 ,   1191    ,   1769    ,   4119    ,0 };
            const std::uint32_t dim848KuoInit[]     =   {   1   ,   1   ,   3   ,   13  ,   19  ,   59  ,   81  ,   71  ,   255 ,   277 ,   991 ,   2183    ,   3257    ,0 };
            const std::uint32_t dim849KuoInit[]     =   {   1   ,   3   ,   1   ,   3   ,   23  ,   27  ,   89  ,   237 ,   249 ,   837 ,   759 ,   43  ,   5571    ,0 };
            const std::uint32_t dim850KuoInit[]     =   {   1   ,   1   ,   1   ,   9   ,   15  ,   35  ,   45  ,   213 ,   423 ,   159 ,   353 ,   3123    ,   6399    ,0 };
            const std::uint32_t dim851KuoInit[]     =   {   1   ,   1   ,   5   ,   9   ,   15  ,   45  ,   83  ,   65  ,   115 ,   513 ,   361 ,   1877    ,   4307    ,0 };
            const std::uint32_t dim852KuoInit[]     =   {   1   ,   1   ,   7   ,   11  ,   17  ,   61  ,   15  ,   143 ,   491 ,   253 ,   443 ,   3521    ,   7611    ,0 };
            const std::uint32_t dim853KuoInit[]     =   {   1   ,   1   ,   3   ,   11  ,   11  ,   49  ,   117 ,   117 ,   279 ,   715 ,   1365    ,   689 ,   4339    ,0 };
            const std::uint32_t dim854KuoInit[]     =   {   1   ,   1   ,   3   ,   13  ,   3   ,   53  ,   123 ,   89  ,   91  ,   471 ,   1723    ,   1811    ,   1285    ,0 };
            const std::uint32_t dim855KuoInit[]     =   {   1   ,   3   ,   7   ,   13  ,   7   ,   5   ,   99  ,   235 ,   465 ,   915 ,   1813    ,   3137    ,   7645    ,0 };
            const std::uint32_t dim856KuoInit[]     =   {   1   ,   3   ,   3   ,   13  ,   5   ,   45  ,   37  ,   99  ,   459 ,   541 ,   225 ,   2417    ,   6385    ,0 };
            const std::uint32_t dim857KuoInit[]     =   {   1   ,   1   ,   1   ,   15  ,   19  ,   39  ,   109 ,   21  ,   117 ,   589 ,   1261    ,   3695    ,   4251    ,0 };
            const std::uint32_t dim858KuoInit[]     =   {   1   ,   1   ,   7   ,   11  ,   23  ,   43  ,   35  ,   43  ,   135 ,   509 ,   1331    ,   1567    ,   7085    ,0 };
            const std::uint32_t dim859KuoInit[]     =   {   1   ,   1   ,   5   ,   5   ,   23  ,   3   ,   61  ,   151 ,   171 ,   295 ,   1377    ,   2165    ,   2125    ,0 };
            const std::uint32_t dim860KuoInit[]     =   {   1   ,   3   ,   3   ,   5   ,   3   ,   57  ,   17  ,   73  ,   71  ,   55  ,   1373    ,   2067    ,   3249    ,0 };
            const std::uint32_t dim861KuoInit[]     =   {   1   ,   1   ,   5   ,   9   ,   25  ,   39  ,   65  ,   75  ,   141 ,   849 ,   237 ,   3719    ,   6705    ,0 };
            const std::uint32_t dim862KuoInit[]     =   {   1   ,   1   ,   7   ,   1   ,   17  ,   17  ,   23  ,   91  ,   333 ,   749 ,   657 ,   3267    ,   3343    ,0 };
            const std::uint32_t dim863KuoInit[]     =   {   1   ,   3   ,   1   ,   5   ,   5   ,   27  ,   15  ,   107 ,   345 ,   405 ,   111 ,   345 ,   5505    ,0 };
            const std::uint32_t dim864KuoInit[]     =   {   1   ,   3   ,   3   ,   13  ,   1   ,   9   ,   19  ,   63  ,   427 ,   995 ,   1257    ,   923 ,   267 ,0 };
            const std::uint32_t dim865KuoInit[]     =   {   1   ,   1   ,   1   ,   7   ,   21  ,   19  ,   65  ,   249 ,   401 ,   729 ,   1403    ,   1579    ,   3443    ,0 };
            const std::uint32_t dim866KuoInit[]     =   {   1   ,   3   ,   5   ,   1   ,   3   ,   43  ,   81  ,   11  ,   473 ,   1011    ,   1755    ,   117 ,   2881    ,0 };
            const std::uint32_t dim867KuoInit[]     =   {   1   ,   1   ,   7   ,   13  ,   3   ,   63  ,   95  ,   11  ,   23  ,   895 ,   1591    ,   2623    ,   6887    ,0 };
            const std::uint32_t dim868KuoInit[]     =   {   1   ,   3   ,   1   ,   3   ,   17  ,   11  ,   39  ,   165 ,   367 ,   363 ,   1207    ,   2555    ,   5437    ,0 };
            const std::uint32_t dim869KuoInit[]     =   {   1   ,   1   ,   1   ,   7   ,   17  ,   9   ,   19  ,   175 ,   7   ,   535 ,   1779    ,   3341    ,   4825    ,0 };
            const std::uint32_t dim870KuoInit[]     =   {   1   ,   1   ,   7   ,   3   ,   27  ,   7   ,   19  ,   217 ,   479 ,   143 ,   1189    ,   2809    ,   339 ,0 };
            const std::uint32_t dim871KuoInit[]     =   {   1   ,   3   ,   7   ,   9   ,   25  ,   41  ,   9   ,   39  ,   391 ,   331 ,   1427    ,   2321    ,   1673    ,0 };
            const std::uint32_t dim872KuoInit[]     =   {   1   ,   3   ,   1   ,   13  ,   7   ,   17  ,   11  ,   27  ,   125 ,   799 ,   1325    ,   517 ,   1043    ,0 };
            const std::uint32_t dim873KuoInit[]     =   {   1   ,   1   ,   3   ,   15  ,   29  ,   11  ,   73  ,   11  ,   289 ,   1   ,   839 ,   3311    ,   7535    ,0 };
            const std::uint32_t dim874KuoInit[]     =   {   1   ,   1   ,   1   ,   11  ,   11  ,   59  ,   25  ,   47  ,   153 ,   297 ,   679 ,   1441    ,   7105    ,0 };
            const std::uint32_t dim875KuoInit[]     =   {   1   ,   3   ,   5   ,   7   ,   25  ,   29  ,   13  ,   227 ,   379 ,   247 ,   449 ,   679 ,   6581    ,0 };
            const std::uint32_t dim876KuoInit[]     =   {   1   ,   1   ,   1   ,   5   ,   9   ,   59  ,   81  ,   195 ,   289 ,   705 ,   183 ,   1   ,   3703    ,0 };
            const std::uint32_t dim877KuoInit[]     =   {   1   ,   3   ,   3   ,   9   ,   31  ,   1   ,   71  ,   155 ,   307 ,   467 ,   1699    ,   269 ,   6077    ,0 };
            const std::uint32_t dim878KuoInit[]     =   {   1   ,   3   ,   1   ,   11  ,   31  ,   21  ,   59  ,   225 ,   385 ,   623 ,   117 ,   1435    ,   3195    ,0 };
            const std::uint32_t dim879KuoInit[]     =   {   1   ,   1   ,   7   ,   9   ,   3   ,   43  ,   97  ,   15  ,   145 ,   279 ,   1785    ,   545 ,   3977    ,0 };
            const std::uint32_t dim880KuoInit[]     =   {   1   ,   1   ,   5   ,   9   ,   25  ,   27  ,   113 ,   193 ,   31  ,   255 ,   691 ,   3315    ,   7005    ,0 };
            const std::uint32_t dim881KuoInit[]     =   {   1   ,   3   ,   7   ,   5   ,   9   ,   19  ,   69  ,   87  ,   379 ,   931 ,   1567    ,   1391    ,   4765    ,0 };
            const std::uint32_t dim882KuoInit[]     =   {   1   ,   1   ,   1   ,   15  ,   15  ,   23  ,   127 ,   69  ,   113 ,   801 ,   1923    ,   2847    ,   1073    ,0 };
            const std::uint32_t dim883KuoInit[]     =   {   1   ,   1   ,   1   ,   1   ,   21  ,   51  ,   65  ,   133 ,   465 ,   739 ,   2029    ,   2243    ,   4023    ,0 };
            const std::uint32_t dim884KuoInit[]     =   {   1   ,   1   ,   5   ,   11  ,   9   ,   41  ,   71  ,   217 ,   317 ,   855 ,   275 ,   1965    ,   3151    ,0 };
            const std::uint32_t dim885KuoInit[]     =   {   1   ,   1   ,   7   ,   5   ,   19  ,   3   ,   81  ,   127 ,   423 ,   415 ,   565 ,   1941    ,   5079    ,0 };
            const std::uint32_t dim886KuoInit[]     =   {   1   ,   1   ,   3   ,   1   ,   19  ,   19  ,   117 ,   169 ,   353 ,   159 ,   1235    ,   845 ,   2381    ,0 };
            const std::uint32_t dim887KuoInit[]     =   {   1   ,   3   ,   1   ,   15  ,   21  ,   27  ,   77  ,   5   ,   113 ,   201 ,   311 ,   2263    ,   7855    ,0 };
            const std::uint32_t dim888KuoInit[]     =   {   1   ,   3   ,   5   ,   9   ,   5   ,   21  ,   41  ,   119 ,   447 ,   983 ,   1703    ,   2707    ,   2789    ,0 };
            const std::uint32_t dim889KuoInit[]     =   {   1   ,   1   ,   5   ,   3   ,   5   ,   19  ,   9   ,   131 ,   269 ,   999 ,   1259    ,   3843    ,   7753    ,0 };
            const std::uint32_t dim890KuoInit[]     =   {   1   ,   3   ,   7   ,   11  ,   25  ,   27  ,   91  ,   187 ,   177 ,   921 ,   163 ,   1141    ,   4903    ,0 };
            const std::uint32_t dim891KuoInit[]     =   {   1   ,   3   ,   1   ,   7   ,   15  ,   21  ,   67  ,   155 ,   335 ,   149 ,   2011    ,   2483    ,   7015    ,0 };
            const std::uint32_t dim892KuoInit[]     =   {   1   ,   1   ,   1   ,   7   ,   3   ,   53  ,   29  ,   119 ,   21  ,   933 ,   595 ,   3141    ,   7925    ,0 };
            const std::uint32_t dim893KuoInit[]     =   {   1   ,   1   ,   1   ,   9   ,   21  ,   33  ,   55  ,   87  ,   451 ,   297 ,   1615    ,   697 ,   2299    ,0 };
            const std::uint32_t dim894KuoInit[]     =   {   1   ,   3   ,   1   ,   9   ,   9   ,   5   ,   3   ,   113 ,   197 ,   137 ,   1105    ,   1949    ,   4651    ,0 };
            const std::uint32_t dim895KuoInit[]     =   {   1   ,   1   ,   7   ,   3   ,   7   ,   27  ,   109 ,   99  ,   121 ,   463 ,   621 ,   887 ,   5847    ,0 };
            const std::uint32_t dim896KuoInit[]     =   {   1   ,   3   ,   7   ,   7   ,   31  ,   61  ,   21  ,   69  ,   443 ,   81  ,   151 ,   3601    ,   699 ,0 };
            const std::uint32_t dim897KuoInit[]     =   {   1   ,   1   ,   7   ,   11  ,   7   ,   63  ,   97  ,   241 ,   87  ,   961 ,   1279    ,   1715    ,   3183    ,0 };
            const std::uint32_t dim898KuoInit[]     =   {   1   ,   1   ,   3   ,   5   ,   7   ,   41  ,   5   ,   123 ,   189 ,   283 ,   1775    ,   49  ,   6107    ,0 };
            const std::uint32_t dim899KuoInit[]     =   {   1   ,   1   ,   7   ,   15  ,   7   ,   19  ,   71  ,   117 ,   195 ,   67  ,   1583    ,   3371    ,   777 ,0 };
            const std::uint32_t dim900KuoInit[]     =   {   1   ,   1   ,   1   ,   15  ,   19  ,   43  ,   81  ,   103 ,   173 ,   209 ,   447 ,   1735    ,   5023    ,0 };
            const std::uint32_t dim901KuoInit[]     =   {   1   ,   1   ,   5   ,   15  ,   15  ,   9   ,   99  ,   185 ,   451 ,   605 ,   1429    ,   1257    ,   6825    ,0 };
            const std::uint32_t dim902KuoInit[]     =   {   1   ,   3   ,   1   ,   11  ,   11  ,   21  ,   79  ,   13  ,   23  ,   607 ,   1601    ,   3603    ,   147 ,0 };
            const std::uint32_t dim903KuoInit[]     =   {   1   ,   1   ,   3   ,   1   ,   27  ,   51  ,   83  ,   191 ,   59  ,   281 ,   1853    ,   1441    ,   5359    ,0 };
            const std::uint32_t dim904KuoInit[]     =   {   1   ,   1   ,   1   ,   11  ,   31  ,   17  ,   117 ,   239 ,   385 ,   465 ,   1787    ,   2645    ,   6047    ,0 };
            const std::uint32_t dim905KuoInit[]     =   {   1   ,   1   ,   7   ,   5   ,   17  ,   59  ,   111 ,   143 ,   419 ,   163 ,   763 ,   2327    ,   1741    ,0 };
            const std::uint32_t dim906KuoInit[]     =   {   1   ,   1   ,   1   ,   3   ,   3   ,   43  ,   3   ,   203 ,   1   ,   373 ,   1829    ,   3493    ,   2347    ,0 };
            const std::uint32_t dim907KuoInit[]     =   {   1   ,   3   ,   7   ,   13  ,   21  ,   17  ,   89  ,   147 ,   51  ,   665 ,   397 ,   2475    ,   3393    ,0 };
            const std::uint32_t dim908KuoInit[]     =   {   1   ,   3   ,   7   ,   15  ,   19  ,   33  ,   1   ,   211 ,   155 ,   355 ,   1137    ,   1633    ,   5025    ,0 };
            const std::uint32_t dim909KuoInit[]     =   {   1   ,   3   ,   3   ,   9   ,   7   ,   63  ,   127 ,   59  ,   205 ,   645 ,   2047    ,   1187    ,   2711    ,0 };
            const std::uint32_t dim910KuoInit[]     =   {   1   ,   3   ,   3   ,   5   ,   7   ,   59  ,   125 ,   35  ,   285 ,   811 ,   1489    ,   3269    ,   2737    ,0 };
            const std::uint32_t dim911KuoInit[]     =   {   1   ,   1   ,   7   ,   3   ,   15  ,   39  ,   75  ,   229 ,   213 ,   23  ,   1825    ,   2269    ,   6739    ,0 };
            const std::uint32_t dim912KuoInit[]     =   {   1   ,   1   ,   3   ,   7   ,   1   ,   5   ,   73  ,   173 ,   305 ,   681 ,   1225    ,   2475    ,   6981    ,0 };
            const std::uint32_t dim913KuoInit[]     =   {   1   ,   1   ,   5   ,   3   ,   21  ,   3   ,   27  ,   241 ,   475 ,   543 ,   1065    ,   2731    ,   1739    ,0 };
            const std::uint32_t dim914KuoInit[]     =   {   1   ,   3   ,   7   ,   13  ,   19  ,   35  ,   57  ,   19  ,   307 ,   113 ,   451 ,   1897    ,   2135    ,0 };
            const std::uint32_t dim915KuoInit[]     =   {   1   ,   1   ,   3   ,   11  ,   31  ,   13  ,   63  ,   15  ,   477 ,   389 ,   829 ,   2167    ,   3317    ,0 };
            const std::uint32_t dim916KuoInit[]     =   {   1   ,   1   ,   7   ,   11  ,   9   ,   39  ,   1   ,   41  ,   99  ,   295 ,   1009    ,   1411    ,   3423    ,0 };
            const std::uint32_t dim917KuoInit[]     =   {   1   ,   1   ,   5   ,   9   ,   15  ,   17  ,   93  ,   171 ,   361 ,   51  ,   455 ,   2413    ,   7295    ,0 };
            const std::uint32_t dim918KuoInit[]     =   {   1   ,   1   ,   5   ,   13  ,   7   ,   27  ,   127 ,   153 ,   163 ,   635 ,   1065    ,   2243    ,   3813    ,0 };
            const std::uint32_t dim919KuoInit[]     =   {   1   ,   1   ,   7   ,   9   ,   15  ,   45  ,   7   ,   241 ,   365 ,   447 ,   1435    ,   3473    ,   715 ,0 };
            const std::uint32_t dim920KuoInit[]     =   {   1   ,   1   ,   5   ,   9   ,   9   ,   11  ,   21  ,   21  ,   255 ,   717 ,   1579    ,   217 ,   6921    ,0 };
            const std::uint32_t dim921KuoInit[]     =   {   1   ,   1   ,   5   ,   15  ,   25  ,   21  ,   31  ,   47  ,   455 ,   631 ,   971 ,   3105    ,   2219    ,0 };
            const std::uint32_t dim922KuoInit[]     =   {   1   ,   3   ,   1   ,   7   ,   9   ,   1   ,   75  ,   85  ,   351 ,   555 ,   1379    ,   1361    ,   6163    ,0 };
            const std::uint32_t dim923KuoInit[]     =   {   1   ,   3   ,   5   ,   7   ,   9   ,   63  ,   19  ,   99  ,   335 ,   173 ,   1385    ,   3011    ,   5787    ,0 };
            const std::uint32_t dim924KuoInit[]     =   {   1   ,   3   ,   5   ,   1   ,   23  ,   35  ,   79  ,   163 ,   97  ,   213 ,   1281    ,   1739    ,   477 ,0 };
            const std::uint32_t dim925KuoInit[]     =   {   1   ,   1   ,   5   ,   5   ,   9   ,   13  ,   41  ,   167 ,   349 ,   959 ,   925 ,   1383    ,   883 ,0 };
            const std::uint32_t dim926KuoInit[]     =   {   1   ,   3   ,   7   ,   7   ,   17  ,   23  ,   69  ,   241 ,   447 ,   31  ,   767 ,   2981    ,   253 ,0 };
            const std::uint32_t dim927KuoInit[]     =   {   1   ,   3   ,   7   ,   15  ,   31  ,   15  ,   3   ,   107 ,   225 ,   207 ,   429 ,   959 ,   2627    ,0 };
            const std::uint32_t dim928KuoInit[]     =   {   1   ,   3   ,   3   ,   11  ,   29  ,   25  ,   109 ,   41  ,   261 ,   585 ,   1049    ,   3013    ,   4361    ,0 };
            const std::uint32_t dim929KuoInit[]     =   {   1   ,   1   ,   7   ,   11  ,   29  ,   63  ,   117 ,   147 ,   149 ,   427 ,   1371    ,   2171    ,   7797    ,0 };
            const std::uint32_t dim930KuoInit[]     =   {   1   ,   3   ,   5   ,   3   ,   13  ,   33  ,   103 ,   33  ,   227 ,   785 ,   1277    ,   27  ,   6713    ,0 };
            const std::uint32_t dim931KuoInit[]     =   {   1   ,   3   ,   1   ,   3   ,   19  ,   3   ,   121 ,   123 ,   313 ,   283 ,   1231    ,   3331    ,   7271    ,0 };
            const std::uint32_t dim932KuoInit[]     =   {   1   ,   1   ,   7   ,   3   ,   21  ,   57  ,   53  ,   9   ,   275 ,   661 ,   1665    ,   1557    ,   3813    ,0 };
            const std::uint32_t dim933KuoInit[]     =   {   1   ,   3   ,   5   ,   1   ,   19  ,   63  ,   69  ,   149 ,   373 ,   667 ,   975 ,   3483    ,   7605    ,0 };
            const std::uint32_t dim934KuoInit[]     =   {   1   ,   3   ,   5   ,   3   ,   3   ,   53  ,   37  ,   247 ,   293 ,   491 ,   657 ,   3123    ,   1165    ,0 };
            const std::uint32_t dim935KuoInit[]     =   {   1   ,   1   ,   1   ,   13  ,   27  ,   41  ,   23  ,   185 ,   405 ,   215 ,   455 ,   433 ,   7775    ,0 };
            const std::uint32_t dim936KuoInit[]     =   {   1   ,   1   ,   3   ,   13  ,   23  ,   61  ,   63  ,   61  ,   195 ,   83  ,   33  ,   1903    ,   269 ,0 };
            const std::uint32_t dim937KuoInit[]     =   {   1   ,   1   ,   3   ,   7   ,   5   ,   7   ,   1   ,   161 ,   295 ,   539 ,   1371    ,   3911    ,   4095    ,0 };
            const std::uint32_t dim938KuoInit[]     =   {   1   ,   1   ,   7   ,   9   ,   7   ,   7   ,   63  ,   115 ,   323 ,   95  ,   1965    ,   137 ,   7147    ,0 };
            const std::uint32_t dim939KuoInit[]     =   {   1   ,   3   ,   7   ,   11  ,   19  ,   55  ,   107 ,   71  ,   169 ,   937 ,   939 ,   113 ,   6187    ,0 };
            const std::uint32_t dim940KuoInit[]     =   {   1   ,   1   ,   3   ,   7   ,   13  ,   17  ,   55  ,   5   ,   167 ,   337 ,   2043    ,   1485    ,   5069    ,0 };
            const std::uint32_t dim941KuoInit[]     =   {   1   ,   1   ,   7   ,   9   ,   21  ,   3   ,   107 ,   125 ,   253 ,   363 ,   49  ,   469 ,   2873    ,0 };
            const std::uint32_t dim942KuoInit[]     =   {   1   ,   1   ,   7   ,   9   ,   9   ,   31  ,   91  ,   65  ,   315 ,   973 ,   653 ,   1023    ,   6479    ,0 };
            const std::uint32_t dim943KuoInit[]     =   {   1   ,   3   ,   5   ,   11  ,   1   ,   5   ,   19  ,   109 ,   143 ,   335 ,   1035    ,   3893    ,   4573    ,0 };
            const std::uint32_t dim944KuoInit[]     =   {   1   ,   3   ,   3   ,   13  ,   27  ,   53  ,   37  ,   177 ,   407 ,   315 ,   1943    ,   3111    ,   1385    ,0 };
            const std::uint32_t dim945KuoInit[]     =   {   1   ,   3   ,   5   ,   15  ,   27  ,   47  ,   57  ,   105 ,   131 ,   31  ,   551 ,   3733    ,   5157    ,0 };
            const std::uint32_t dim946KuoInit[]     =   {   1   ,   3   ,   5   ,   9   ,   15  ,   31  ,   41  ,   11  ,   93  ,   895 ,   587 ,   421 ,   885 ,0 };
            const std::uint32_t dim947KuoInit[]     =   {   1   ,   3   ,   7   ,   1   ,   5   ,   35  ,   107 ,   189 ,   287 ,   457 ,   645 ,   519 ,   7459    ,0 };
            const std::uint32_t dim948KuoInit[]     =   {   1   ,   1   ,   7   ,   5   ,   23  ,   7   ,   79  ,   45  ,   73  ,   711 ,   575 ,   3571    ,   1453    ,0 };
            const std::uint32_t dim949KuoInit[]     =   {   1   ,   1   ,   3   ,   9   ,   9   ,   7   ,   89  ,   197 ,   215 ,   111 ,   1099    ,   3915    ,   3709    ,0 };
            const std::uint32_t dim950KuoInit[]     =   {   1   ,   3   ,   1   ,   7   ,   25  ,   1   ,   83  ,   55  ,   449 ,   227 ,   1563    ,   1103    ,   4129    ,0 };
            const std::uint32_t dim951KuoInit[]     =   {   1   ,   1   ,   1   ,   9   ,   23  ,   25  ,   103 ,   183 ,   379 ,   541 ,   673 ,   2711    ,   7409    ,0 };
            const std::uint32_t dim952KuoInit[]     =   {   1   ,   3   ,   1   ,   11  ,   27  ,   21  ,   83  ,   61  ,   65  ,   867 ,   1755    ,   3815    ,   7235    ,0 };
            const std::uint32_t dim953KuoInit[]     =   {   1   ,   1   ,   3   ,   15  ,   15  ,   55  ,   13  ,   185 ,   145 ,   955 ,   785 ,   189 ,   6653    ,0 };
            const std::uint32_t dim954KuoInit[]     =   {   1   ,   3   ,   5   ,   15  ,   5   ,   19  ,   83  ,   157 ,   429 ,   57  ,   1293    ,   1551    ,   581 ,0 };
            const std::uint32_t dim955KuoInit[]     =   {   1   ,   3   ,   3   ,   11  ,   25  ,   19  ,   117 ,   73  ,   503 ,   1015    ,   203 ,   2689    ,   6697    ,0 };
            const std::uint32_t dim956KuoInit[]     =   {   1   ,   1   ,   7   ,   1   ,   27  ,   31  ,   111 ,   193 ,   403 ,   267 ,   233 ,   3031    ,   5451    ,0 };
            const std::uint32_t dim957KuoInit[]     =   {   1   ,   3   ,   7   ,   5   ,   9   ,   7   ,   73  ,   221 ,   27  ,   483 ,   185 ,   1805    ,   1813    ,0 };
            const std::uint32_t dim958KuoInit[]     =   {   1   ,   3   ,   3   ,   5   ,   19  ,   27  ,   103 ,   197 ,   245 ,   191 ,   301 ,   531 ,   3677    ,0 };
            const std::uint32_t dim959KuoInit[]     =   {   1   ,   1   ,   5   ,   1   ,   9   ,   49  ,   5   ,   55  ,   81  ,   907 ,   313 ,   3379    ,   2573    ,0 };
            const std::uint32_t dim960KuoInit[]     =   {   1   ,   3   ,   5   ,   3   ,   13  ,   11  ,   75  ,   145 ,   143 ,   991 ,   201 ,   3769    ,   5041    ,0 };
            const std::uint32_t dim961KuoInit[]     =   {   1   ,   3   ,   1   ,   5   ,   15  ,   45  ,   89  ,   17  ,   209 ,   91  ,   1635    ,   3025    ,   3885    ,0 };
            const std::uint32_t dim962KuoInit[]     =   {   1   ,   3   ,   3   ,   5   ,   15  ,   37  ,   79  ,   163 ,   455 ,   477 ,   69  ,   3617    ,   1263    ,0 };
            const std::uint32_t dim963KuoInit[]     =   {   1   ,   1   ,   3   ,   11  ,   15  ,   47  ,   77  ,   73  ,   199 ,   493 ,   207 ,   2109    ,   4991    ,0 };
            const std::uint32_t dim964KuoInit[]     =   {   1   ,   1   ,   5   ,   15  ,   29  ,   23  ,   35  ,   177 ,   483 ,   151 ,   1497    ,   631 ,   1647    ,0 };
            const std::uint32_t dim965KuoInit[]     =   {   1   ,   3   ,   7   ,   5   ,   29  ,   45  ,   127 ,   199 ,   491 ,   965 ,   371 ,   3549    ,   2757    ,0 };
            const std::uint32_t dim966KuoInit[]     =   {   1   ,   1   ,   7   ,   5   ,   21  ,   11  ,   27  ,   217 ,   407 ,   493 ,   1979    ,   359 ,   6187    ,0 };
            const std::uint32_t dim967KuoInit[]     =   {   1   ,   3   ,   5   ,   7   ,   31  ,   61  ,   113 ,   197 ,   109 ,   781 ,   1859    ,   991 ,   3617    ,0 };
            const std::uint32_t dim968KuoInit[]     =   {   1   ,   3   ,   1   ,   5   ,   17  ,   43  ,   75  ,   169 ,   413 ,   257 ,   1751    ,   4047    ,   1951    ,0 };
            const std::uint32_t dim969KuoInit[]     =   {   1   ,   3   ,   1   ,   13  ,   17  ,   49  ,   95  ,   223 ,   439 ,   587 ,   427 ,   89  ,   7723    ,0 };
            const std::uint32_t dim970KuoInit[]     =   {   1   ,   3   ,   5   ,   1   ,   7   ,   53  ,   1   ,   79  ,   111 ,   721 ,   169 ,   4087    ,   5255    ,0 };
            const std::uint32_t dim971KuoInit[]     =   {   1   ,   1   ,   7   ,   15  ,   31  ,   7   ,   111 ,   163 ,   491 ,   559 ,   259 ,   3057    ,   5669    ,0 };
            const std::uint32_t dim972KuoInit[]     =   {   1   ,   3   ,   3   ,   9   ,   25  ,   41  ,   45  ,   101 ,   145 ,   769 ,   1313    ,   3101    ,   405 ,0 };
            const std::uint32_t dim973KuoInit[]     =   {   1   ,   3   ,   3   ,   11  ,   3   ,   39  ,   67  ,   201 ,   171 ,   79  ,   1727    ,   2331    ,   8161    ,0 };
            const std::uint32_t dim974KuoInit[]     =   {   1   ,   3   ,   5   ,   5   ,   31  ,   29  ,   13  ,   111 ,   449 ,   579 ,   1133    ,   1321    ,   2447    ,0 };
            const std::uint32_t dim975KuoInit[]     =   {   1   ,   3   ,   3   ,   15  ,   21  ,   39  ,   57  ,   203 ,   39  ,   733 ,   1773    ,   2867    ,   6751    ,0 };
            const std::uint32_t dim976KuoInit[]     =   {   1   ,   3   ,   5   ,   3   ,   19  ,   33  ,   73  ,   219 ,   159 ,   901 ,   919 ,   1445    ,   1387    ,0 };
            const std::uint32_t dim977KuoInit[]     =   {   1   ,   3   ,   1   ,   7   ,   9   ,   33  ,   113 ,   221 ,   315 ,   503 ,   1795    ,   577 ,   1605    ,0 };
            const std::uint32_t dim978KuoInit[]     =   {   1   ,   1   ,   7   ,   11  ,   31  ,   47  ,   51  ,   53  ,   159 ,   731 ,   1101    ,   1895    ,   2061    ,0 };
            const std::uint32_t dim979KuoInit[]     =   {   1   ,   3   ,   5   ,   7   ,   29  ,   11  ,   107 ,   39  ,   89  ,   357 ,   13  ,   805 ,   5527    ,0 };
            const std::uint32_t dim980KuoInit[]     =   {   1   ,   3   ,   1   ,   9   ,   13  ,   15  ,   59  ,   95  ,   467 ,   875 ,   217 ,   3345    ,   1579    ,0 };
            const std::uint32_t dim981KuoInit[]     =   {   1   ,   3   ,   1   ,   15  ,   29  ,   33  ,   11  ,   121 ,   243 ,   429 ,   1017    ,   1511    ,   6289    ,0 };
            const std::uint32_t dim982KuoInit[]     =   {   1   ,   3   ,   7   ,   1   ,   27  ,   41  ,   125 ,   121 ,   265 ,   695 ,   155 ,   3933    ,   661 ,0 };
            const std::uint32_t dim983KuoInit[]     =   {   1   ,   1   ,   3   ,   7   ,   5   ,   3   ,   95  ,   213 ,   385 ,   183 ,   1693    ,   2685    ,   5647    ,0 };
            const std::uint32_t dim984KuoInit[]     =   {   1   ,   1   ,   5   ,   5   ,   23  ,   29  ,   21  ,   193 ,   327 ,   965 ,   49  ,   2157    ,   1539    ,0 };
            const std::uint32_t dim985KuoInit[]     =   {   1   ,   3   ,   1   ,   7   ,   15  ,   15  ,   103 ,   191 ,   249 ,   347 ,   283 ,   2459    ,   5957    ,0 };
            const std::uint32_t dim986KuoInit[]     =   {   1   ,   1   ,   7   ,   5   ,   21  ,   43  ,   29  ,   205 ,   125 ,   63  ,   1645    ,   3357    ,   3333    ,0 };
            const std::uint32_t dim987KuoInit[]     =   {   1   ,   3   ,   1   ,   5   ,   11  ,   21  ,   109 ,   213 ,   123 ,   587 ,   2047    ,   343 ,   6669    ,0 };
            const std::uint32_t dim988KuoInit[]     =   {   1   ,   1   ,   5   ,   5   ,   25  ,   63  ,   75  ,   237 ,   421 ,   883 ,   801 ,   2403    ,   4723    ,0 };
            const std::uint32_t dim989KuoInit[]     =   {   1   ,   3   ,   5   ,   11  ,   13  ,   63  ,   87  ,   107 ,   411 ,   3   ,   139 ,   3097    ,   6109    ,0 };
            const std::uint32_t dim990KuoInit[]     =   {   1   ,   3   ,   7   ,   9   ,   19  ,   31  ,   33  ,   23  ,   499 ,   105 ,   471 ,   2311    ,   439 ,0 };
            const std::uint32_t dim991KuoInit[]     =   {   1   ,   3   ,   3   ,   13  ,   13  ,   39  ,   19  ,   253 ,   53  ,   315 ,   1381    ,   3875    ,   5741    ,0 };
            const std::uint32_t dim992KuoInit[]     =   {   1   ,   1   ,   1   ,   7   ,   19  ,   9   ,   47  ,   169 ,   265 ,   1005    ,   159 ,   2957    ,   2987    ,0 };
            const std::uint32_t dim993KuoInit[]     =   {   1   ,   3   ,   3   ,   3   ,   1   ,   35  ,   107 ,   77  ,   47  ,   89  ,   1901    ,   1719    ,   2873    ,0 };
            const std::uint32_t dim994KuoInit[]     =   {   1   ,   1   ,   5   ,   7   ,   7   ,   51  ,   87  ,   91  ,   45  ,   991 ,   1369    ,   3759    ,   3511    ,0 };
            const std::uint32_t dim995KuoInit[]     =   {   1   ,   3   ,   7   ,   15  ,   17  ,   51  ,   93  ,   43  ,   71  ,   213 ,   1637    ,   2617    ,   1767    ,0 };
            const std::uint32_t dim996KuoInit[]     =   {   1   ,   1   ,   5   ,   15  ,   29  ,   63  ,   81  ,   15  ,   409 ,   779 ,   1419    ,   497 ,   463 ,0 };
            const std::uint32_t dim997KuoInit[]     =   {   1   ,   1   ,   7   ,   1   ,   1   ,   31  ,   21  ,   167 ,   445 ,   893 ,   1687    ,   603 ,   3211    ,0 };
            const std::uint32_t dim998KuoInit[]     =   {   1   ,   3   ,   7   ,   15  ,   19  ,   3   ,   41  ,   53  ,   175 ,   971 ,   1873    ,   43  ,   4795    ,0 };
            const std::uint32_t dim999KuoInit[]     =   {   1   ,   3   ,   5   ,   15  ,   21  ,   59  ,   77  ,   67  ,   495 ,   547 ,   411 ,   2373    ,   5187    ,0 };
            const std::uint32_t dim1000KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   27  ,   45  ,   119 ,   201 ,   237 ,   499 ,   261 ,   3331    ,   3973    ,0 };
            const std::uint32_t dim1001KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   17  ,   31  ,   33  ,   15  ,   237 ,   135 ,   1751    ,   297 ,   6331    ,0 };
            const std::uint32_t dim1002KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   15  ,   1   ,   11  ,   135 ,   355 ,   617 ,   805 ,   1201    ,   457 ,0 };
            const std::uint32_t dim1003KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   19  ,   55  ,   21  ,   121 ,   205 ,   999 ,   1719    ,   2815    ,   6753    ,0 };
            const std::uint32_t dim1004KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   9   ,   5   ,   7   ,   231 ,   323 ,   953 ,   1811    ,   2847    ,   2059    ,0 };
            const std::uint32_t dim1005KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   17  ,   15  ,   85  ,   3   ,   259 ,   989 ,   287 ,   3995    ,   2677    ,0 };
            const std::uint32_t dim1006KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   13  ,   61  ,   69  ,   143 ,   167 ,   187 ,   481 ,   2359    ,   1913    ,0 };
            const std::uint32_t dim1007KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   29  ,   3   ,   29  ,   247 ,   407 ,   733 ,   677 ,   99  ,   1625    ,0 };
            const std::uint32_t dim1008KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   7   ,   17  ,   67  ,   115 ,   299 ,   765 ,   1885    ,   2769    ,   1619    ,0 };
            const std::uint32_t dim1009KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   17  ,   7   ,   27  ,   61  ,   433 ,   323 ,   1091    ,   1309    ,   7239    ,0 };
            const std::uint32_t dim1010KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   19  ,   63  ,   41  ,   157 ,   43  ,   743 ,   675 ,   2149    ,   6729    ,0 };
            const std::uint32_t dim1011KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   21  ,   35  ,   45  ,   145 ,   235 ,   185 ,   1563    ,   1117    ,   3669    ,0 };
            const std::uint32_t dim1012KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   9   ,   37  ,   105 ,   61  ,   259 ,   935 ,   793 ,   823 ,   1765    ,0 };
            const std::uint32_t dim1013KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   25  ,   41  ,   35  ,   11  ,   389 ,   399 ,   339 ,   859 ,   4299    ,0 };
            const std::uint32_t dim1014KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   7   ,   29  ,   53  ,   91  ,   185 ,   163 ,   1689    ,   983 ,   4545    ,0 };
            const std::uint32_t dim1015KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   19  ,   35  ,   45  ,   141 ,   445 ,   469 ,   1827    ,   3523    ,   377 ,0 };
            const std::uint32_t dim1016KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   27  ,   29  ,   35  ,   199 ,   73  ,   163 ,   1591    ,   1021    ,   2867    ,0 };
            const std::uint32_t dim1017KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   7   ,   61  ,   95  ,   95  ,   147 ,   959 ,   971 ,   649 ,   5047    ,0 };
            const std::uint32_t dim1018KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   11  ,   23  ,   49  ,   231 ,   359 ,   677 ,   1401    ,   2889    ,   3799    ,0 };
            const std::uint32_t dim1019KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   11  ,   15  ,   119 ,   103 ,   403 ,   983 ,   399 ,   321 ,   437 ,0 };
            const std::uint32_t dim1020KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   29  ,   13  ,   83  ,   55  ,   175 ,   835 ,   1637    ,   209 ,   1923    ,0 };
            const std::uint32_t dim1021KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   25  ,   37  ,   5   ,   239 ,   227 ,   229 ,   243 ,   1837    ,   4821    ,0 };
            const std::uint32_t dim1022KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   9   ,   59  ,   29  ,   135 ,   227 ,   473 ,   1759    ,   3711    ,   4113    ,0 };
            const std::uint32_t dim1023KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   15  ,   3   ,   53  ,   225 ,   165 ,   375 ,   537 ,   331 ,   5085    ,0 };
            const std::uint32_t dim1024KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   15  ,   41  ,   57  ,   165 ,   45  ,   137 ,   931 ,   1015    ,   6451    ,0 };
            const std::uint32_t dim1025KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   5   ,   47  ,   35  ,   249 ,   89  ,   111 ,   1275    ,   529 ,   3297    ,0 };
            const std::uint32_t dim1026KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   27  ,   21  ,   65  ,   193 ,   381 ,   861 ,   59  ,   1457    ,   2447    ,0 };
            const std::uint32_t dim1027KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   17  ,   25  ,   75  ,   171 ,   263 ,   401 ,   1369    ,   2609    ,   6265    ,0 };
            const std::uint32_t dim1028KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   17  ,   61  ,   75  ,   77  ,   487 ,   7   ,   1565    ,   527 ,   7213    ,0 };
            const std::uint32_t dim1029KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   5   ,   45  ,   47  ,   27  ,   163 ,   43  ,   219 ,   2119    ,   1793    ,0 };
            const std::uint32_t dim1030KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   27  ,   9   ,   89  ,   151 ,   487 ,   925 ,   1257    ,   1065    ,   3413    ,0 };
            const std::uint32_t dim1031KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   11  ,   27  ,   9   ,   161 ,   303 ,   457 ,   1367    ,   2319    ,   6145    ,0 };
            const std::uint32_t dim1032KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   23  ,   43  ,   115 ,   227 ,   319 ,   469 ,   1651    ,   1693    ,   2095    ,0 };
            const std::uint32_t dim1033KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   23  ,   5   ,   91  ,   103 ,   393 ,   787 ,   1557    ,   925 ,   7189    ,0 };
            const std::uint32_t dim1034KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   31  ,   5   ,   51  ,   171 ,   375 ,   309 ,   199 ,   1833    ,   2741    ,0 };
            const std::uint32_t dim1035KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   27  ,   59  ,   15  ,   255 ,   205 ,   807 ,   1407    ,   161 ,   6955    ,0 };
            const std::uint32_t dim1036KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   5   ,   35  ,   7   ,   167 ,   265 ,   67  ,   1133    ,   699 ,   6225    ,0 };
            const std::uint32_t dim1037KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   19  ,   31  ,   5   ,   243 ,   279 ,   505 ,   303 ,   2303    ,   5367    ,0 };
            const std::uint32_t dim1038KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   19  ,   47  ,   105 ,   159 ,   309 ,   783 ,   1845    ,   2603    ,   4663    ,0 };
            const std::uint32_t dim1039KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   13  ,   35  ,   101 ,   123 ,   99  ,   559 ,   1681    ,   2751    ,   1965    ,0 };
            const std::uint32_t dim1040KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   1   ,   63  ,   29  ,   245 ,   105 ,   469 ,   939 ,   721 ,   6213    ,0 };
            const std::uint32_t dim1041KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   11  ,   45  ,   13  ,   121 ,   81  ,   15  ,   1503    ,   2203    ,   7467    ,0 };
            const std::uint32_t dim1042KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   29  ,   25  ,   59  ,   93  ,   5   ,   551 ,   1799    ,   2251    ,   115 ,0 };
            const std::uint32_t dim1043KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   17  ,   37  ,   81  ,   117 ,   183 ,   301 ,   1085    ,   3925    ,   697 ,0 };
            const std::uint32_t dim1044KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   13  ,   13  ,   5   ,   207 ,   443 ,   723 ,   897 ,   3481    ,   3377    ,0 };
            const std::uint32_t dim1045KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   9   ,   41  ,   25  ,   161 ,   283 ,   3   ,   1515    ,   2445    ,   2179    ,0 };
            const std::uint32_t dim1046KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   29  ,   17  ,   73  ,   129 ,   499 ,   457 ,   103 ,   2287    ,   525 ,0 };
            const std::uint32_t dim1047KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   9   ,   13  ,   95  ,   31  ,   411 ,   185 ,   931 ,   119 ,   711 ,0 };
            const std::uint32_t dim1048KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   19  ,   53  ,   49  ,   209 ,   217 ,   593 ,   733 ,   4057    ,   2853    ,0 };
            const std::uint32_t dim1049KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   7   ,   63  ,   95  ,   45  ,   209 ,   641 ,   1767    ,   3001    ,   4089    ,0 };
            const std::uint32_t dim1050KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   9   ,   25  ,   69  ,   85  ,   345 ,   475 ,   613 ,   3975    ,   2179    ,0 };
            const std::uint32_t dim1051KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   19  ,   9   ,   47  ,   51  ,   111 ,   7   ,   627 ,   1635    ,   3857    ,0 };
            const std::uint32_t dim1052KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   25  ,   37  ,   27  ,   253 ,   111 ,   369 ,   235 ,   2887    ,   5649    ,0 };
            const std::uint32_t dim1053KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   15  ,   5   ,   13  ,   181 ,   471 ,   825 ,   121 ,   3007    ,   777 ,0 };
            const std::uint32_t dim1054KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   27  ,   41  ,   59  ,   9   ,   391 ,   779 ,   915 ,   3965    ,   4431    ,0 };
            const std::uint32_t dim1055KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   25  ,   27  ,   75  ,   123 ,   385 ,   923 ,   141 ,   3771    ,   2227    ,0 };
            const std::uint32_t dim1056KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   17  ,   29  ,   85  ,   253 ,   261 ,   517 ,   87  ,   621 ,   7947    ,0 };
            const std::uint32_t dim1057KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   13  ,   15  ,   83  ,   49  ,   399 ,   875 ,   845 ,   1731    ,   7071    ,0 };
            const std::uint32_t dim1058KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   21  ,   49  ,   93  ,   121 ,   271 ,   921 ,   183 ,   1533    ,   1609    ,0 };
            const std::uint32_t dim1059KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   9   ,   51  ,   89  ,   135 ,   389 ,   151 ,   1813    ,   3673    ,   2099    ,0 };
            const std::uint32_t dim1060KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   25  ,   63  ,   127 ,   239 ,   329 ,   455 ,   403 ,   363 ,   2689    ,0 };
            const std::uint32_t dim1061KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   1   ,   45  ,   65  ,   93  ,   371 ,   577 ,   669 ,   2433    ,   3507    ,0 };
            const std::uint32_t dim1062KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   9   ,   15  ,   13  ,   85  ,   67  ,   809 ,   1133    ,   129 ,   3869    ,0 };
            const std::uint32_t dim1063KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   3   ,   47  ,   31  ,   79  ,   395 ,   227 ,   677 ,   3399    ,   8173    ,0 };
            const std::uint32_t dim1064KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   7   ,   19  ,   81  ,   27  ,   393 ,   49  ,   299 ,   879 ,   5401    ,0 };
            const std::uint32_t dim1065KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   3   ,   25  ,   105 ,   67  ,   147 ,   23  ,   749 ,   2677    ,   2799    ,0 };
            const std::uint32_t dim1066KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   3   ,   49  ,   55  ,   131 ,   249 ,   183 ,   399 ,   4065    ,   4575    ,0 };
            const std::uint32_t dim1067KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   21  ,   1   ,   105 ,   167 ,   379 ,   567 ,   1843    ,   3019    ,   7479    ,0 };
            const std::uint32_t dim1068KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   7   ,   15  ,   65  ,   213 ,   191 ,   735 ,   1087    ,   1223    ,   7827    ,0 };
            const std::uint32_t dim1069KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   13  ,   35  ,   79  ,   55  ,   169 ,   513 ,   639 ,   1153    ,   1129    ,0 };
            const std::uint32_t dim1070KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   1   ,   37  ,   49  ,   209 ,   355 ,   533 ,   1073    ,   3249    ,   4309    ,0 };
            const std::uint32_t dim1071KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   23  ,   45  ,   69  ,   195 ,   155 ,   267 ,   291 ,   1773    ,   3575    ,0 };
            const std::uint32_t dim1072KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   25  ,   3   ,   51  ,   175 ,   505 ,   467 ,   1909    ,   1929    ,   4909    ,0 };
            const std::uint32_t dim1073KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   31  ,   51  ,   99  ,   119 ,   505 ,   57  ,   1987    ,   1303    ,   4273    ,0 };
            const std::uint32_t dim1074KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   19  ,   49  ,   61  ,   147 ,   29  ,   1001    ,   633 ,   963 ,   5601    ,0 };
            const std::uint32_t dim1075KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   1   ,   13  ,   101 ,   133 ,   31  ,   263 ,   2033    ,   575 ,   983 ,0 };
            const std::uint32_t dim1076KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   21  ,   29  ,   101 ,   143 ,   263 ,   601 ,   1239    ,   1187    ,   3045    ,0 };
            const std::uint32_t dim1077KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   5   ,   49  ,   7   ,   165 ,   411 ,   517 ,   619 ,   1517    ,   1839    ,0 };
            const std::uint32_t dim1078KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   29  ,   45  ,   71  ,   245 ,   67  ,   469 ,   1793    ,   3353    ,   7799    ,0 };
            const std::uint32_t dim1079KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   15  ,   49  ,   5   ,   183 ,   345 ,   585 ,   1877    ,   2205    ,   7963    ,0 };
            const std::uint32_t dim1080KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   7   ,   39  ,   85  ,   183 ,   131 ,   527 ,   1731    ,   1899    ,   3813    ,0 };
            const std::uint32_t dim1081KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   29  ,   23  ,   77  ,   233 ,   77  ,   699 ,   1963    ,   171 ,   6557    ,0 };
            const std::uint32_t dim1082KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   5   ,   3   ,   79  ,   199 ,   279 ,   279 ,   399 ,   769 ,   1661    ,0 };
            const std::uint32_t dim1083KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   17  ,   61  ,   61  ,   227 ,   289 ,   541 ,   379 ,   3155    ,   5791    ,0 };
            const std::uint32_t dim1084KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   31  ,   37  ,   73  ,   215 ,   47  ,   895 ,   1511    ,   305 ,   5247    ,0 };
            const std::uint32_t dim1085KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   31  ,   47  ,   123 ,   191 ,   175 ,   875 ,   501 ,   2203    ,   1781    ,0 };
            const std::uint32_t dim1086KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   13  ,   5   ,   43  ,   145 ,   183 ,   705 ,   1143    ,   3113    ,   1959    ,0 };
            const std::uint32_t dim1087KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   23  ,   53  ,   93  ,   133 ,   13  ,   987 ,   1711    ,   2241    ,   7721    ,0 };
            const std::uint32_t dim1088KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   3   ,   19  ,   123 ,   65  ,   421 ,   891 ,   159 ,   1633    ,   733 ,0 };
            const std::uint32_t dim1089KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   23  ,   59  ,   127 ,   109 ,   315 ,   939 ,   1177    ,   1237    ,   1805    ,0 };
            const std::uint32_t dim1090KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   13  ,   19  ,   39  ,   97  ,   437 ,   949 ,   539 ,   1171    ,   151 ,0 };
            const std::uint32_t dim1091KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   13  ,   45  ,   107 ,   159 ,   363 ,   727 ,   509 ,   3051    ,   4071    ,0 };
            const std::uint32_t dim1092KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   15  ,   11  ,   93  ,   199 ,   137 ,   947 ,   479 ,   2127    ,   1377    ,0 };
            const std::uint32_t dim1093KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   13  ,   5   ,   67  ,   227 ,   69  ,   795 ,   299 ,   1845    ,   4765    ,0 };
            const std::uint32_t dim1094KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   31  ,   15  ,   11  ,   255 ,   361 ,   599 ,   1235    ,   1785    ,   1611    ,0 };
            const std::uint32_t dim1095KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   29  ,   21  ,   85  ,   49  ,   101 ,   785 ,   1071    ,   1333    ,   1691    ,0 };
            const std::uint32_t dim1096KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   19  ,   11  ,   23  ,   157 ,   201 ,   67  ,   789 ,   999 ,   4281    ,0 };
            const std::uint32_t dim1097KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   7   ,   61  ,   109 ,   253 ,   455 ,   863 ,   81  ,   3185    ,   7105    ,0 };
            const std::uint32_t dim1098KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   11  ,   29  ,   51  ,   43  ,   211 ,   103 ,   1333    ,   3425    ,   6669    ,0 };
            const std::uint32_t dim1099KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   19  ,   15  ,   25  ,   21  ,   9   ,   563 ,   1737    ,   159 ,   1827    ,0 };
            const std::uint32_t dim1100KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   9   ,   35  ,   19  ,   145 ,   159 ,   345 ,   475 ,   1453    ,   7807    ,0 };
            const std::uint32_t dim1101KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   19  ,   41  ,   61  ,   63  ,   77  ,   3   ,   997 ,   223 ,   5493    ,0 };
            const std::uint32_t dim1102KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   25  ,   17  ,   87  ,   99  ,   441 ,   973 ,   713 ,   631 ,   4039    ,0 };
            const std::uint32_t dim1103KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   17  ,   19  ,   89  ,   11  ,   321 ,   143 ,   11  ,   915 ,   3359    ,0 };
            const std::uint32_t dim1104KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   11  ,   55  ,   43  ,   3   ,   1   ,   893 ,   1845    ,   1237    ,   693 ,0 };
            const std::uint32_t dim1105KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   25  ,   21  ,   93  ,   43  ,   127 ,   197 ,   1349    ,   1727    ,   1133    ,0 };
            const std::uint32_t dim1106KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   29  ,   57  ,   19  ,   35  ,   37  ,   81  ,   1599    ,   3469    ,   4327    ,0 };
            const std::uint32_t dim1107KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   15  ,   47  ,   119 ,   203 ,   301 ,   835 ,   1221    ,   2771    ,   2023    ,0 };
            const std::uint32_t dim1108KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   25  ,   43  ,   109 ,   51  ,   431 ,   189 ,   255 ,   2595    ,   2447    ,0 };
            const std::uint32_t dim1109KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   13  ,   3   ,   113 ,   109 ,   321 ,   837 ,   159 ,   2617    ,   2277    ,0 };
            const std::uint32_t dim1110KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   29  ,   43  ,   33  ,   173 ,   47  ,   395 ,   1113    ,   1711    ,   7909    ,0 };
            const std::uint32_t dim1111KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   31  ,   45  ,   37  ,   95  ,   13  ,   449 ,   1377    ,   2117    ,   6607    ,   11053   ,0 };
            const std::uint32_t dim1112KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   21  ,   7   ,   127 ,   71  ,   11  ,   271 ,   65  ,   3681    ,   4209    ,   3183    ,0 };
            const std::uint32_t dim1113KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   19  ,   27  ,   99  ,   243 ,   371 ,   77  ,   629 ,   3989    ,   3105    ,   6287    ,0 };
            const std::uint32_t dim1114KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   7   ,   35  ,   115 ,   237 ,   403 ,   273 ,   697 ,   117 ,   6887    ,   3243    ,0 };
            const std::uint32_t dim1115KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   29  ,   1   ,   117 ,   101 ,   483 ,   909 ,   867 ,   2051    ,   7081    ,   14905   ,0 };
            const std::uint32_t dim1116KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   21  ,   49  ,   107 ,   101 ,   121 ,   979 ,   309 ,   1871    ,   7339    ,   4213    ,0 };
            const std::uint32_t dim1117KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   9   ,   25  ,   13  ,   61  ,   409 ,   469 ,   411 ,   2041    ,   7685    ,   15501   ,0 };
            const std::uint32_t dim1118KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   1   ,   29  ,   109 ,   125 ,   63  ,   829 ,   175 ,   957 ,   4781    ,   12473   ,0 };
            const std::uint32_t dim1119KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   11  ,   53  ,   17  ,   171 ,   393 ,   165 ,   51  ,   737 ,   1697    ,   4137    ,0 };
            const std::uint32_t dim1120KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   15  ,   45  ,   49  ,   219 ,   105 ,   121 ,   549 ,   991 ,   1337    ,   11311   ,0 };
            const std::uint32_t dim1121KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   27  ,   9   ,   39  ,   207 ,   85  ,   185 ,   901 ,   3077    ,   5295    ,   3933    ,0 };
            const std::uint32_t dim1122KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   23  ,   29  ,   95  ,   63  ,   125 ,   447 ,   573 ,   2053    ,   4621    ,   10135   ,0 };
            const std::uint32_t dim1123KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   23  ,   45  ,   3   ,   109 ,   335 ,   339 ,   1453    ,   3121    ,   37  ,   9155    ,0 };
            const std::uint32_t dim1124KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   9   ,   25  ,   27  ,   67  ,   35  ,   573 ,   215 ,   1969    ,   7083    ,   15729   ,0 };
            const std::uint32_t dim1125KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   21  ,   3   ,   21  ,   143 ,   131 ,   613 ,   299 ,   1127    ,   5647    ,   15007   ,0 };
            const std::uint32_t dim1126KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   29  ,   47  ,   53  ,   223 ,   409 ,   633 ,   535 ,   2423    ,   5763    ,   11633   ,0 };
            const std::uint32_t dim1127KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   1   ,   21  ,   5   ,   1   ,   359 ,   547 ,   285 ,   779 ,   2091    ,   11785   ,0 };
            const std::uint32_t dim1128KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   1   ,   31  ,   61  ,   245 ,   331 ,   45  ,   1559    ,   3223    ,   7577    ,   2157    ,0 };
            const std::uint32_t dim1129KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   3   ,   27  ,   37  ,   191 ,   229 ,   205 ,   1535    ,   887 ,   701 ,   10867   ,0 };
            const std::uint32_t dim1130KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   21  ,   53  ,   61  ,   177 ,   485 ,   575 ,   681 ,   1447    ,   1427    ,   11279   ,0 };
            const std::uint32_t dim1131KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   17  ,   3   ,   5   ,   49  ,   311 ,   507 ,   995 ,   3971    ,   471 ,   3045    ,0 };
            const std::uint32_t dim1132KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   7   ,   45  ,   73  ,   183 ,   419 ,   635 ,   523 ,   1793    ,   7549    ,   9727    ,0 };
            const std::uint32_t dim1133KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   19  ,   33  ,   109 ,   91  ,   19  ,   825 ,   1629    ,   2111    ,   2673    ,   6677    ,0 };
            const std::uint32_t dim1134KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   31  ,   13  ,   71  ,   199 ,   113 ,   77  ,   371 ,   3117    ,   7799    ,   15919   ,0 };
            const std::uint32_t dim1135KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   27  ,   41  ,   91  ,   183 ,   75  ,   159 ,   911 ,   2081    ,   7065    ,   16313   ,0 };
            const std::uint32_t dim1136KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   17  ,   29  ,   65  ,   9   ,   399 ,   259 ,   671 ,   525 ,   1393    ,   13367   ,0 };
            const std::uint32_t dim1137KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   1   ,   29  ,   101 ,   187 ,   231 ,   413 ,   1245    ,   269 ,   201 ,   1673    ,0 };
            const std::uint32_t dim1138KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   27  ,   47  ,   11  ,   149 ,   49  ,   309 ,   1923    ,   1187    ,   3165    ,   7927    ,0 };
            const std::uint32_t dim1139KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   31  ,   57  ,   29  ,   203 ,   11  ,   305 ,   1771    ,   2997    ,   377 ,   5777    ,0 };
            const std::uint32_t dim1140KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   1   ,   29  ,   29  ,   205 ,   93  ,   821 ,   1583    ,   2991    ,   4137    ,   14967   ,0 };
            const std::uint32_t dim1141KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   7   ,   57  ,   13  ,   179 ,   261 ,   547 ,   219 ,   1979    ,   4951    ,   2529    ,0 };
            const std::uint32_t dim1142KuoInit[]        =   {   1   ,   3   ,   1   ,   5   ,   3   ,   51  ,   89  ,   7   ,   121 ,   611 ,   1655    ,   3639    ,   1991    ,   9911    ,0 };
            const std::uint32_t dim1143KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   1   ,   21  ,   9   ,   173 ,   93  ,   579 ,   1685    ,   767 ,   5183    ,   3965    ,0 };
            const std::uint32_t dim1144KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   15  ,   47  ,   55  ,   113 ,   27  ,   941 ,   1633    ,   3791    ,   1705    ,   16293   ,0 };
            const std::uint32_t dim1145KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   7   ,   41  ,   11  ,   229 ,   367 ,   997 ,   543 ,   933 ,   4249    ,   7049    ,0 };
            const std::uint32_t dim1146KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   7   ,   7   ,   25  ,   87  ,   213 ,   277 ,   627 ,   721 ,   6161    ,   14877   ,0 };
            const std::uint32_t dim1147KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   25  ,   61  ,   47  ,   103 ,   199 ,   983 ,   543 ,   1935    ,   4663    ,   3597    ,0 };
            const std::uint32_t dim1148KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   15  ,   49  ,   125 ,   27  ,   153 ,   521 ,   351 ,   1129    ,   5897    ,   11325   ,0 };
            const std::uint32_t dim1149KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   13  ,   35  ,   81  ,   53  ,   217 ,   739 ,   963 ,   3441    ,   6843    ,   3505    ,0 };
            const std::uint32_t dim1150KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   17  ,   35  ,   119 ,   187 ,   475 ,   919 ,   1325    ,   3269    ,   677 ,   617 ,0 };
            const std::uint32_t dim1151KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   7   ,   15  ,   91  ,   99  ,   259 ,   37  ,   1461    ,   1145    ,   6973    ,   15643   ,0 };
            const std::uint32_t dim1152KuoInit[]        =   {   1   ,   1   ,   5   ,   15  ,   13  ,   11  ,   27  ,   75  ,   9   ,   611 ,   1331    ,   2057    ,   863 ,   6245    ,0 };
            const std::uint32_t dim1153KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   3   ,   25  ,   117 ,   45  ,   141 ,   839 ,   1201    ,   629 ,   6289    ,   12231   ,0 };
            const std::uint32_t dim1154KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   17  ,   61  ,   23  ,   243 ,   349 ,   153 ,   1747    ,   3107    ,   7763    ,   10067   ,0 };
            const std::uint32_t dim1155KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   21  ,   25  ,   53  ,   67  ,   97  ,   851 ,   1921    ,   2247    ,   5769    ,   5779    ,0 };
            const std::uint32_t dim1156KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   9   ,   37  ,   93  ,   247 ,   287 ,   609 ,   1643    ,   427 ,   4269    ,   15923   ,0 };
            const std::uint32_t dim1157KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   7   ,   35  ,   111 ,   105 ,   357 ,   539 ,   319 ,   993 ,   6155    ,   6587    ,0 };
            const std::uint32_t dim1158KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   13  ,   33  ,   99  ,   73  ,   89  ,   231 ,   1537    ,   309 ,   3837    ,   6669    ,0 };
            const std::uint32_t dim1159KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   9   ,   25  ,   105 ,   197 ,   399 ,   259 ,   1381    ,   1631    ,   3551    ,   4593    ,0 };
            const std::uint32_t dim1160KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   7   ,   63  ,   113 ,   65  ,   109 ,   529 ,   1451    ,   1169    ,   3321    ,   6811    ,0 };
            const std::uint32_t dim1161KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   11  ,   55  ,   109 ,   27  ,   65  ,   199 ,   199 ,   2745    ,   2009    ,   14853   ,0 };
            const std::uint32_t dim1162KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   13  ,   31  ,   109 ,   119 ,   431 ,   363 ,   1191    ,   703 ,   2617    ,   6817    ,0 };
            const std::uint32_t dim1163KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   27  ,   1   ,   107 ,   11  ,   457 ,   495 ,   215 ,   1459    ,   4137    ,   13007   ,0 };
            const std::uint32_t dim1164KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   7   ,   29  ,   11  ,   19  ,   159 ,   821 ,   1881    ,   3277    ,   1303    ,   7145    ,0 };
            const std::uint32_t dim1165KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   25  ,   11  ,   125 ,   241 ,   197 ,   863 ,   423 ,   2107    ,   5885    ,   14279   ,0 };
            const std::uint32_t dim1166KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   7   ,   29  ,   97  ,   249 ,   333 ,   945 ,   1081    ,   2405    ,   109 ,   2869    ,0 };
            const std::uint32_t dim1167KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   27  ,   57  ,   89  ,   243 ,   481 ,   431 ,   269 ,   3371    ,   3667    ,   13293   ,0 };
            const std::uint32_t dim1168KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   23  ,   3   ,   91  ,   57  ,   79  ,   165 ,   629 ,   2771    ,   7927    ,   2689    ,0 };
            const std::uint32_t dim1169KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   17  ,   51  ,   81  ,   147 ,   19  ,   501 ,   861 ,   159 ,   2117    ,   6777    ,0 };
            const std::uint32_t dim1170KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   7   ,   9   ,   51  ,   197 ,   97  ,   983 ,   133 ,   1819    ,   4449    ,   7821    ,0 };
            const std::uint32_t dim1171KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   21  ,   55  ,   61  ,   171 ,   461 ,   741 ,   1901    ,   2195    ,   5477    ,   1681    ,0 };
            const std::uint32_t dim1172KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   13  ,   37  ,   73  ,   151 ,   479 ,   561 ,   1483    ,   2679    ,   295 ,   7325    ,0 };
            const std::uint32_t dim1173KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   11  ,   17  ,   127 ,   115 ,   371 ,   979 ,   1391    ,   2189    ,   2805    ,   7471    ,0 };
            const std::uint32_t dim1174KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   31  ,   25  ,   65  ,   249 ,   91  ,   649 ,   1103    ,   493 ,   6341    ,   10313   ,0 };
            const std::uint32_t dim1175KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   7   ,   31  ,   85  ,   201 ,   277 ,   771 ,   1007    ,   69  ,   3357    ,   15059   ,0 };
            const std::uint32_t dim1176KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   17  ,   17  ,   9   ,   229 ,   269 ,   591 ,   945 ,   3003    ,   6723    ,   16101   ,0 };
            const std::uint32_t dim1177KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   1   ,   29  ,   119 ,   181 ,   269 ,   269 ,   1781    ,   2935    ,   6265    ,   13989   ,0 };
            const std::uint32_t dim1178KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   13  ,   51  ,   117 ,   141 ,   467 ,   521 ,   449 ,   797 ,   3447    ,   11693   ,0 };
            const std::uint32_t dim1179KuoInit[]        =   {   1   ,   1   ,   5   ,   15  ,   3   ,   57  ,   61  ,   209 ,   423 ,   213 ,   1663    ,   3735    ,   5229    ,   11809   ,0 };
            const std::uint32_t dim1180KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   13  ,   51  ,   113 ,   127 ,   229 ,   793 ,   905 ,   3271    ,   7501    ,   10801   ,0 };
            const std::uint32_t dim1181KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   5   ,   19  ,   43  ,   87  ,   9   ,   981 ,   221 ,   3925    ,   2095    ,   7185    ,0 };
            const std::uint32_t dim1182KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   23  ,   35  ,   113 ,   175 ,   383 ,   699 ,   1617    ,   3771    ,   5847    ,   9097    ,0 };
            const std::uint32_t dim1183KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   25  ,   23  ,   27  ,   77  ,   491 ,   211 ,   1785    ,   199 ,   4865    ,   10147   ,0 };
            const std::uint32_t dim1184KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   25  ,   39  ,   15  ,   15  ,   191 ,   889 ,   457 ,   2647    ,   4555    ,   4799    ,0 };
            const std::uint32_t dim1185KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   15  ,   1   ,   117 ,   169 ,   245 ,   917 ,   1025    ,   3805    ,   1455    ,   3051    ,0 };
            const std::uint32_t dim1186KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   7   ,   15  ,   43  ,   13  ,   359 ,   685 ,   75  ,   271 ,   555 ,   3595    ,0 };
            const std::uint32_t dim1187KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   19  ,   9   ,   29  ,   15  ,   139 ,   13  ,   753 ,   205 ,   677 ,   5945    ,0 };
            const std::uint32_t dim1188KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   5   ,   21  ,   99  ,   77  ,   287 ,   663 ,   589 ,   229 ,   5255    ,   4177    ,0 };
            const std::uint32_t dim1189KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   15  ,   47  ,   21  ,   149 ,   461 ,   871 ,   577 ,   3393    ,   6879    ,   6353    ,0 };
            const std::uint32_t dim1190KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   21  ,   33  ,   29  ,   25  ,   195 ,   1   ,   1817    ,   3437    ,   4265    ,   16121   ,0 };
            const std::uint32_t dim1191KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   27  ,   31  ,   93  ,   141 ,   471 ,   735 ,   1737    ,   2997    ,   3529    ,   12285   ,0 };
            const std::uint32_t dim1192KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   15  ,   49  ,   105 ,   157 ,   165 ,   593 ,   651 ,   3331    ,   4333    ,   8607    ,0 };
            const std::uint32_t dim1193KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   5   ,   35  ,   73  ,   53  ,   461 ,   41  ,   1407    ,   357 ,   3537    ,   1123    ,0 };
            const std::uint32_t dim1194KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   15  ,   39  ,   83  ,   23  ,   501 ,   3   ,   743 ,   3819    ,   5491    ,   15317   ,0 };
            const std::uint32_t dim1195KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   31  ,   29  ,   125 ,   173 ,   465 ,   347 ,   1515    ,   2871    ,   3861    ,   9353    ,0 };
            const std::uint32_t dim1196KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   9   ,   31  ,   121 ,   221 ,   491 ,   579 ,   313 ,   3549    ,   711 ,   12501   ,0 };
            const std::uint32_t dim1197KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   7   ,   47  ,   15  ,   175 ,   201 ,   399 ,   609 ,   749 ,   3587    ,   10091   ,0 };
            const std::uint32_t dim1198KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   1   ,   39  ,   43  ,   69  ,   429 ,   87  ,   2017    ,   1961    ,   5679    ,   3179    ,0 };
            const std::uint32_t dim1199KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   29  ,   51  ,   27  ,   13  ,   377 ,   99  ,   1291    ,   247 ,   2657    ,   4793    ,0 };
            const std::uint32_t dim1200KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   23  ,   63  ,   119 ,   33  ,   405 ,   689 ,   517 ,   1331    ,   1047    ,   403 ,0 };
            const std::uint32_t dim1201KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   9   ,   27  ,   121 ,   49  ,   317 ,   181 ,   623 ,   1789    ,   5867    ,   11009   ,0 };
            const std::uint32_t dim1202KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   15  ,   63  ,   113 ,   129 ,   299 ,   889 ,   361 ,   2339    ,   3893    ,   3953    ,0 };
            const std::uint32_t dim1203KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   9   ,   51  ,   73  ,   77  ,   511 ,   745 ,   639 ,   1261    ,   439 ,   13409   ,0 };
            const std::uint32_t dim1204KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   29  ,   15  ,   37  ,   31  ,   47  ,   901 ,   1383    ,   1979    ,   7341    ,   13411   ,0 };
            const std::uint32_t dim1205KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   31  ,   59  ,   87  ,   35  ,   123 ,   943 ,   1181    ,   3877    ,   4821    ,   9231    ,0 };
            const std::uint32_t dim1206KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   3   ,   47  ,   123 ,   89  ,   41  ,   883 ,   241 ,   2055    ,   1723    ,   6747    ,0 };
            const std::uint32_t dim1207KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   21  ,   29  ,   89  ,   101 ,   423 ,   279 ,   29  ,   2089    ,   6233    ,   7343    ,0 };
            const std::uint32_t dim1208KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   29  ,   25  ,   23  ,   179 ,   13  ,   707 ,   1603    ,   585 ,   4159    ,   10767   ,0 };
            const std::uint32_t dim1209KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   15  ,   11  ,   55  ,   159 ,   279 ,   613 ,   1445    ,   613 ,   499 ,   7095    ,0 };
            const std::uint32_t dim1210KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   15  ,   61  ,   75  ,   171 ,   173 ,   765 ,   1763    ,   2193    ,   7897    ,   4559    ,0 };
            const std::uint32_t dim1211KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   9   ,   57  ,   127 ,   113 ,   7   ,   269 ,   791 ,   619 ,   2923    ,   6309    ,0 };
            const std::uint32_t dim1212KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   21  ,   9   ,   99  ,   1   ,   263 ,   69  ,   1879    ,   4079    ,   33  ,   7313    ,0 };
            const std::uint32_t dim1213KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   17  ,   1   ,   69  ,   93  ,   147 ,   461 ,   1777    ,   3375    ,   4067    ,   15307   ,0 };
            const std::uint32_t dim1214KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   11  ,   7   ,   77  ,   159 ,   125 ,   159 ,   625 ,   1339    ,   2301    ,   11525   ,0 };
            const std::uint32_t dim1215KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   1   ,   5   ,   23  ,   115 ,   25  ,   755 ,   1523    ,   2767    ,   7667    ,   7129    ,0 };
            const std::uint32_t dim1216KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   23  ,   31  ,   41  ,   3   ,   249 ,   69  ,   1821    ,   155 ,   585 ,   7905    ,0 };
            const std::uint32_t dim1217KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   21  ,   35  ,   7   ,   161 ,   409 ,   771 ,   967 ,   2429    ,   1   ,   5391    ,0 };
            const std::uint32_t dim1218KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   9   ,   3   ,   13  ,   125 ,   87  ,   115 ,   1013    ,   2103    ,   4769    ,   7389    ,0 };
            const std::uint32_t dim1219KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   27  ,   25  ,   85  ,   119 ,   115 ,   775 ,   189 ,   3577    ,   5369    ,   5213    ,0 };
            const std::uint32_t dim1220KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   27  ,   49  ,   81  ,   23  ,   223 ,   523 ,   1939    ,   431 ,   6247    ,   10509   ,0 };
            const std::uint32_t dim1221KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   31  ,   7   ,   119 ,   235 ,   315 ,   431 ,   1669    ,   1223    ,   5785    ,   6507    ,0 };
            const std::uint32_t dim1222KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   27  ,   23  ,   35  ,   141 ,   327 ,   395 ,   869 ,   177 ,   3997    ,   11191   ,0 };
            const std::uint32_t dim1223KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   21  ,   15  ,   35  ,   163 ,   273 ,   93  ,   835 ,   3339    ,   6109    ,   2617    ,0 };
            const std::uint32_t dim1224KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   1   ,   29  ,   107 ,   161 ,   301 ,   27  ,   1391    ,   211 ,   5263    ,   10899   ,0 };
            const std::uint32_t dim1225KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   13  ,   61  ,   91  ,   179 ,   227 ,   193 ,   1909    ,   3759    ,   5875    ,   6799    ,0 };
            const std::uint32_t dim1226KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   17  ,   23  ,   57  ,   117 ,   201 ,   459 ,   1841    ,   2371    ,   2641    ,   13927   ,0 };
            const std::uint32_t dim1227KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   1   ,   1   ,   13  ,   139 ,   313 ,   1   ,   1551    ,   2693    ,   2785    ,   6959    ,0 };
            const std::uint32_t dim1228KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   1   ,   29  ,   117 ,   67  ,   147 ,   821 ,   1935    ,   2913    ,   7911    ,   4829    ,0 };
            const std::uint32_t dim1229KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   19  ,   17  ,   57  ,   33  ,   93  ,   819 ,   1035    ,   3493    ,   1831    ,   5345    ,0 };
            const std::uint32_t dim1230KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   9   ,   13  ,   117 ,   219 ,   415 ,   743 ,   381 ,   2343    ,   3865    ,   3915    ,0 };
            const std::uint32_t dim1231KuoInit[]        =   {   1   ,   1   ,   5   ,   15  ,   3   ,   25  ,   67  ,   197 ,   59  ,   419 ,   461 ,   1951    ,   4657    ,   9263    ,0 };
            const std::uint32_t dim1232KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   31  ,   53  ,   33  ,   213 ,   169 ,   231 ,   615 ,   441 ,   7055    ,   16079   ,0 };
            const std::uint32_t dim1233KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   5   ,   27  ,   57  ,   79  ,   373 ,   713 ,   583 ,   3773    ,   4239    ,   14231   ,0 };
            const std::uint32_t dim1234KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   21  ,   55  ,   119 ,   219 ,   371 ,   321 ,   185 ,   1103    ,   7783    ,   8705    ,0 };
            const std::uint32_t dim1235KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   3   ,   11  ,   69  ,   127 ,   27  ,   223 ,   867 ,   2249    ,   597 ,   10051   ,0 };
            const std::uint32_t dim1236KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   5   ,   13  ,   99  ,   115 ,   21  ,   659 ,   1287    ,   1941    ,   6505    ,   1091    ,0 };
            const std::uint32_t dim1237KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   17  ,   57  ,   57  ,   155 ,   373 ,   729 ,   1521    ,   3741    ,   4935    ,   13867   ,0 };
            const std::uint32_t dim1238KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   19  ,   21  ,   39  ,   47  ,   451 ,   67  ,   463 ,   1849    ,   5311    ,   5831    ,0 };
            const std::uint32_t dim1239KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   29  ,   11  ,   59  ,   161 ,   29  ,   107 ,   1413    ,   3915    ,   6863    ,   5095    ,0 };
            const std::uint32_t dim1240KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   13  ,   37  ,   29  ,   91  ,   83  ,   663 ,   1629    ,   3005    ,   655 ,   7601    ,0 };
            const std::uint32_t dim1241KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   31  ,   47  ,   29  ,   31  ,   509 ,   319 ,   929 ,   1481    ,   6255    ,   14003   ,0 };
            const std::uint32_t dim1242KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   5   ,   7   ,   97  ,   253 ,   163 ,   801 ,   283 ,   813 ,   6277    ,   3201    ,0 };
            const std::uint32_t dim1243KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   5   ,   59  ,   49  ,   47  ,   259 ,   837 ,   2003    ,   1489    ,   3425    ,   6863    ,0 };
            const std::uint32_t dim1244KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   25  ,   55  ,   37  ,   139 ,   347 ,   95  ,   259 ,   3175    ,   1043    ,   1395    ,0 };
            const std::uint32_t dim1245KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   31  ,   37  ,   73  ,   7   ,   1   ,   883 ,   1641    ,   1941    ,   6885    ,   23  ,0 };
            const std::uint32_t dim1246KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   13  ,   45  ,   85  ,   67  ,   55  ,   11  ,   1717    ,   3461    ,   3189    ,   15989   ,0 };
            const std::uint32_t dim1247KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   27  ,   15  ,   93  ,   39  ,   329 ,   43  ,   175 ,   2253    ,   1193    ,   13257   ,0 };
            const std::uint32_t dim1248KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   25  ,   41  ,   111 ,   211 ,   99  ,   267 ,   965 ,   1311    ,   2661    ,   1981    ,0 };
            const std::uint32_t dim1249KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   31  ,   15  ,   37  ,   73  ,   239 ,   505 ,   983 ,   3299    ,   2891    ,   8247    ,0 };
            const std::uint32_t dim1250KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   19  ,   5   ,   45  ,   55  ,   251 ,   125 ,   977 ,   955 ,   1169    ,   8495    ,0 };
            const std::uint32_t dim1251KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   19  ,   31  ,   121 ,   119 ,   185 ,   43  ,   847 ,   3939    ,   2511    ,   10889   ,0 };
            const std::uint32_t dim1252KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   7   ,   17  ,   81  ,   37  ,   425 ,   663 ,   1715    ,   789 ,   661 ,   9089    ,0 };
            const std::uint32_t dim1253KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   1   ,   3   ,   17  ,   247 ,   311 ,   369 ,   211 ,   97  ,   6355    ,   16297   ,0 };
            const std::uint32_t dim1254KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   21  ,   53  ,   33  ,   71  ,   73  ,   629 ,   1321    ,   3181    ,   6627    ,   161 ,0 };
            const std::uint32_t dim1255KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   21  ,   25  ,   21  ,   231 ,   291 ,   585 ,   111 ,   1651    ,   1031    ,   13705   ,0 };
            const std::uint32_t dim1256KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   5   ,   31  ,   59  ,   51  ,   245 ,   465 ,   37  ,   3425    ,   4251    ,   1121    ,0 };
            const std::uint32_t dim1257KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   31  ,   45  ,   125 ,   245 ,   335 ,   973 ,   49  ,   1557    ,   4847    ,   10739   ,0 };
            const std::uint32_t dim1258KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   21  ,   39  ,   127 ,   67  ,   101 ,   9   ,   1099    ,   1159    ,   2483    ,   4283    ,0 };
            const std::uint32_t dim1259KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   29  ,   53  ,   49  ,   65  ,   5   ,   775 ,   433 ,   351 ,   493 ,   7233    ,0 };
            const std::uint32_t dim1260KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   27  ,   13  ,   73  ,   83  ,   417 ,   31  ,   1891    ,   1809    ,   1103    ,   4555    ,0 };
            const std::uint32_t dim1261KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   15  ,   1   ,   25  ,   63  ,   191 ,   251 ,   1759    ,   429 ,   2477    ,   12577   ,0 };
            const std::uint32_t dim1262KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   3   ,   21  ,   61  ,   245 ,   191 ,   217 ,   845 ,   2121    ,   2133    ,   6045    ,0 };
            const std::uint32_t dim1263KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   23  ,   33  ,   85  ,   15  ,   57  ,   645 ,   1109    ,   3411    ,   2895    ,   6885    ,0 };
            const std::uint32_t dim1264KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   13  ,   41  ,   13  ,   59  ,   45  ,   199 ,   1145    ,   2637    ,   6741    ,   1273    ,0 };
            const std::uint32_t dim1265KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   27  ,   33  ,   121 ,   21  ,   75  ,   687 ,   349 ,   2097    ,   1195    ,   4227    ,0 };
            const std::uint32_t dim1266KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   25  ,   51  ,   71  ,   85  ,   281 ,   825 ,   1335    ,   277 ,   797 ,   407 ,0 };
            const std::uint32_t dim1267KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   21  ,   31  ,   19  ,   11  ,   39  ,   821 ,   1623    ,   97  ,   1573    ,   13297   ,0 };
            const std::uint32_t dim1268KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   25  ,   39  ,   67  ,   113 ,   109 ,   719 ,   1427    ,   2539    ,   5885    ,   13537   ,0 };
            const std::uint32_t dim1269KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   15  ,   53  ,   11  ,   139 ,   393 ,   365 ,   709 ,   1603    ,   4929    ,   2651    ,0 };
            const std::uint32_t dim1270KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   3   ,   11  ,   19  ,   41  ,   123 ,   7   ,   993 ,   3627    ,   2027    ,   4009    ,0 };
            const std::uint32_t dim1271KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   3   ,   17  ,   63  ,   129 ,   323 ,   303 ,   1669    ,   1023    ,   1259    ,   289 ,0 };
            const std::uint32_t dim1272KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   15  ,   33  ,   69  ,   229 ,   291 ,   939 ,   969 ,   2497    ,   4323    ,   16299   ,0 };
            const std::uint32_t dim1273KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   17  ,   35  ,   79  ,   33  ,   471 ,   857 ,   975 ,   297 ,   7219    ,   12903   ,0 };
            const std::uint32_t dim1274KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   21  ,   5   ,   65  ,   53  ,   11  ,   265 ,   1447    ,   1405    ,   3351    ,   2661    ,0 };
            const std::uint32_t dim1275KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   1   ,   21  ,   123 ,   123 ,   361 ,   71  ,   1233    ,   2673    ,   7643    ,   9519    ,0 };
            const std::uint32_t dim1276KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   27  ,   41  ,   117 ,   239 ,   125 ,   183 ,   1375    ,   649 ,   5267    ,   1735    ,0 };
            const std::uint32_t dim1277KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   7   ,   33  ,   59  ,   7   ,   37  ,   705 ,   1055    ,   1661    ,   6213    ,   2083    ,0 };
            const std::uint32_t dim1278KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   11  ,   61  ,   91  ,   143 ,   113 ,   229 ,   809 ,   431 ,   1971    ,   12453   ,0 };
            const std::uint32_t dim1279KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   17  ,   23  ,   97  ,   249 ,   109 ,   669 ,   1643    ,   3305    ,   6141    ,   1793    ,0 };
            const std::uint32_t dim1280KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   3   ,   39  ,   37  ,   107 ,   123 ,   637 ,   869 ,   1969    ,   4195    ,   9431    ,0 };
            const std::uint32_t dim1281KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   7   ,   25  ,   97  ,   63  ,   395 ,   1011    ,   161 ,   827 ,   4001    ,   15159   ,0 };
            const std::uint32_t dim1282KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   11  ,   59  ,   11  ,   49  ,   25  ,   691 ,   73  ,   1171    ,   2937    ,   13877   ,0 };
            const std::uint32_t dim1283KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   1   ,   19  ,   119 ,   129 ,   63  ,   451 ,   1593    ,   1207    ,   67  ,   3621    ,0 };
            const std::uint32_t dim1284KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   25  ,   27  ,   45  ,   23  ,   111 ,   191 ,   1205    ,   4079    ,   1821    ,   5571    ,0 };
            const std::uint32_t dim1285KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   17  ,   37  ,   37  ,   249 ,   81  ,   909 ,   153 ,   209 ,   7919    ,   10763   ,0 };
            const std::uint32_t dim1286KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   19  ,   9   ,   101 ,   193 ,   431 ,   63  ,   1309    ,   2693    ,   2413    ,   14513   ,0 };
            const std::uint32_t dim1287KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   13  ,   5   ,   5   ,   203 ,   313 ,   723 ,   1637    ,   2725    ,   4197    ,   3767    ,0 };
            const std::uint32_t dim1288KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   1   ,   53  ,   33  ,   245 ,   181 ,   1001    ,   1057    ,   2701    ,   5861    ,   4199    ,0 };
            const std::uint32_t dim1289KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   31  ,   35  ,   19  ,   253 ,   403 ,   429 ,   1667    ,   1671    ,   7491    ,   1023    ,0 };
            const std::uint32_t dim1290KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   15  ,   51  ,   41  ,   253 ,   247 ,   883 ,   1887    ,   1067    ,   3227    ,   13259   ,0 };
            const std::uint32_t dim1291KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   5   ,   63  ,   9   ,   97  ,   87  ,   11  ,   1873    ,   2529    ,   833 ,   5583    ,0 };
            const std::uint32_t dim1292KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   17  ,   59  ,   23  ,   225 ,   91  ,   189 ,   923 ,   3177    ,   599 ,   4315    ,0 };
            const std::uint32_t dim1293KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   15  ,   59  ,   85  ,   75  ,   281 ,   935 ,   1219    ,   3121    ,   231 ,   13839   ,0 };
            const std::uint32_t dim1294KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   15  ,   61  ,   105 ,   27  ,   179 ,   145 ,   827 ,   2985    ,   6907    ,   14961   ,0 };
            const std::uint32_t dim1295KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   1   ,   63  ,   7   ,   3   ,   449 ,   387 ,   483 ,   603 ,   6607    ,   13241   ,0 };
            const std::uint32_t dim1296KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   9   ,   37  ,   73  ,   255 ,   331 ,   797 ,   679 ,   579 ,   3015    ,   2517    ,0 };
            const std::uint32_t dim1297KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   23  ,   15  ,   97  ,   159 ,   9   ,   469 ,   881 ,   1935    ,   1871    ,   7943    ,0 };
            const std::uint32_t dim1298KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   31  ,   33  ,   103 ,   247 ,   7   ,   217 ,   397 ,   3761    ,   3071    ,   15357   ,0 };
            const std::uint32_t dim1299KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   23  ,   25  ,   61  ,   61  ,   495 ,   195 ,   1615    ,   923 ,   6583    ,   11169   ,0 };
            const std::uint32_t dim1300KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   25  ,   7   ,   67  ,   105 ,   423 ,   519 ,   327 ,   2789    ,   7527    ,   13465   ,0 };
            const std::uint32_t dim1301KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   29  ,   57  ,   21  ,   47  ,   71  ,   771 ,   1255    ,   1469    ,   737 ,   11533   ,0 };
            const std::uint32_t dim1302KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   23  ,   31  ,   103 ,   145 ,   19  ,   931 ,   963 ,   2627    ,   1419    ,   14451   ,0 };
            const std::uint32_t dim1303KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   15  ,   45  ,   37  ,   57  ,   223 ,   151 ,   979 ,   2569    ,   2487    ,   2877    ,0 };
            const std::uint32_t dim1304KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   13  ,   39  ,   83  ,   127 ,   341 ,   687 ,   1575    ,   3193    ,   2845    ,   725 ,0 };
            const std::uint32_t dim1305KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   23  ,   39  ,   71  ,   205 ,   53  ,   477 ,   1961    ,   3967    ,   7169    ,   5443    ,0 };
            const std::uint32_t dim1306KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   23  ,   17  ,   107 ,   151 ,   291 ,   101 ,   1917    ,   3429    ,   6279    ,   1781    ,0 };
            const std::uint32_t dim1307KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   23  ,   45  ,   11  ,   137 ,   243 ,   257 ,   495 ,   3267    ,   1373    ,   15477   ,0 };
            const std::uint32_t dim1308KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   23  ,   13  ,   37  ,   139 ,   473 ,   215 ,   1281    ,   989 ,   2187    ,   1551    ,0 };
            const std::uint32_t dim1309KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   5   ,   21  ,   113 ,   195 ,   247 ,   493 ,   513 ,   1775    ,   1885    ,   5131    ,0 };
            const std::uint32_t dim1310KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   29  ,   31  ,   9   ,   59  ,   329 ,   11  ,   1739    ,   1657    ,   1745    ,   8969    ,0 };
            const std::uint32_t dim1311KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   19  ,   29  ,   121 ,   171 ,   33  ,   393 ,   1463    ,   1817    ,   393 ,   2509    ,0 };
            const std::uint32_t dim1312KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   23  ,   55  ,   103 ,   169 ,   313 ,   293 ,   1791    ,   2727    ,   2311    ,   14519   ,0 };
            const std::uint32_t dim1313KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   13  ,   21  ,   95  ,   205 ,   87  ,   431 ,   667 ,   367 ,   6879    ,   9843    ,0 };
            const std::uint32_t dim1314KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   3   ,   53  ,   75  ,   43  ,   115 ,   561 ,   795 ,   613 ,   4491    ,   913 ,0 };
            const std::uint32_t dim1315KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   25  ,   37  ,   71  ,   13  ,   499 ,   105 ,   9   ,   3759    ,   4997    ,   14747   ,0 };
            const std::uint32_t dim1316KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   25  ,   63  ,   27  ,   163 ,   359 ,   431 ,   5   ,   3371    ,   6051    ,   1099    ,0 };
            const std::uint32_t dim1317KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   5   ,   45  ,   19  ,   217 ,   423 ,   171 ,   933 ,   3441    ,   7451    ,   11831   ,0 };
            const std::uint32_t dim1318KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   7   ,   53  ,   81  ,   67  ,   465 ,   713 ,   1761    ,   3945    ,   3051    ,   8139    ,0 };
            const std::uint32_t dim1319KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   23  ,   55  ,   85  ,   205 ,   265 ,   99  ,   353 ,   4061    ,   3385    ,   4273    ,0 };
            const std::uint32_t dim1320KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   9   ,   19  ,   7   ,   81  ,   9   ,   373 ,   837 ,   1397    ,   3945    ,   14325   ,0 };
            const std::uint32_t dim1321KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   7   ,   47  ,   61  ,   195 ,   101 ,   931 ,   1667    ,   3277    ,   7701    ,   14697   ,0 };
            const std::uint32_t dim1322KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   11  ,   57  ,   43  ,   55  ,   399 ,   783 ,   1647    ,   269 ,   6055    ,   9935    ,0 };
            const std::uint32_t dim1323KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   5   ,   57  ,   87  ,   193 ,   15  ,   515 ,   1663    ,   495 ,   4725    ,   7221    ,0 };
            const std::uint32_t dim1324KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   23  ,   23  ,   87  ,   231 ,   133 ,   123 ,   1477    ,   1811    ,   7383    ,   16339   ,0 };
            const std::uint32_t dim1325KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   31  ,   57  ,   105 ,   237 ,   375 ,   129 ,   193 ,   1293    ,   2445    ,   13383   ,0 };
            const std::uint32_t dim1326KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   19  ,   51  ,   91  ,   27  ,   309 ,   421 ,   647 ,   3777    ,   6779    ,   2807    ,0 };
            const std::uint32_t dim1327KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   5   ,   43  ,   125 ,   37  ,   269 ,   155 ,   1733    ,   447 ,   7883    ,   6085    ,0 };
            const std::uint32_t dim1328KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   27  ,   63  ,   91  ,   7   ,   117 ,   369 ,   1019    ,   847 ,   6747    ,   5057    ,0 };
            const std::uint32_t dim1329KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   31  ,   19  ,   87  ,   125 ,   259 ,   355 ,   161 ,   1421    ,   2295    ,   9683    ,0 };
            const std::uint32_t dim1330KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   25  ,   37  ,   63  ,   169 ,   477 ,   633 ,   231 ,   2039    ,   3469    ,   2531    ,0 };
            const std::uint32_t dim1331KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   25  ,   1   ,   81  ,   211 ,   237 ,   233 ,   1743    ,   961 ,   645 ,   2605    ,0 };
            const std::uint32_t dim1332KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   3   ,   25  ,   3   ,   111 ,   123 ,   417 ,   1799    ,   1419    ,   2501    ,   5765    ,0 };
            const std::uint32_t dim1333KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   11  ,   17  ,   27  ,   95  ,   295 ,   315 ,   987 ,   481 ,   6627    ,   16171   ,0 };
            const std::uint32_t dim1334KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   15  ,   61  ,   123 ,   5   ,   369 ,   161 ,   897 ,   855 ,   625 ,   9975    ,0 };
            const std::uint32_t dim1335KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   9   ,   45  ,   59  ,   53  ,   43  ,   117 ,   789 ,   21  ,   7799    ,   11061   ,0 };
            const std::uint32_t dim1336KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   3   ,   17  ,   113 ,   159 ,   115 ,   965 ,   1541    ,   1037    ,   4723    ,   10151   ,0 };
            const std::uint32_t dim1337KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   7   ,   15  ,   19  ,   161 ,   123 ,   421 ,   109 ,   433 ,   7387    ,   6047    ,0 };
            const std::uint32_t dim1338KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   19  ,   49  ,   31  ,   215 ,   25  ,   289 ,   1995    ,   1135    ,   3719    ,   8453    ,0 };
            const std::uint32_t dim1339KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   3   ,   33  ,   15  ,   191 ,   83  ,   963 ,   199 ,   2199    ,   3273    ,   16165   ,0 };
            const std::uint32_t dim1340KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   17  ,   63  ,   71  ,   49  ,   427 ,   633 ,   735 ,   2009    ,   5049    ,   13649   ,0 };
            const std::uint32_t dim1341KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   25  ,   41  ,   79  ,   161 ,   293 ,   967 ,   969 ,   3253    ,   269 ,   6971    ,0 };
            const std::uint32_t dim1342KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   25  ,   9   ,   43  ,   237 ,   283 ,   135 ,   669 ,   2193    ,   4193    ,   4787    ,0 };
            const std::uint32_t dim1343KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   5   ,   19  ,   83  ,   89  ,   443 ,   443 ,   1511    ,   2309    ,   5483    ,   7583    ,0 };
            const std::uint32_t dim1344KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   21  ,   29  ,   113 ,   127 ,   405 ,   465 ,   1135    ,   2401    ,   7715    ,   13061   ,0 };
            const std::uint32_t dim1345KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   23  ,   19  ,   17  ,   59  ,   483 ,   519 ,   1439    ,   3839    ,   1691    ,   5   ,0 };
            const std::uint32_t dim1346KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   23  ,   43  ,   115 ,   103 ,   155 ,   769 ,   455 ,   17  ,   7791    ,   3333    ,0 };
            const std::uint32_t dim1347KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   3   ,   25  ,   31  ,   7   ,   125 ,   357 ,   759 ,   1203    ,   2107    ,   5361    ,0 };
            const std::uint32_t dim1348KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   27  ,   31  ,   23  ,   73  ,   77  ,   449 ,   661 ,   2337    ,   941 ,   9421    ,0 };
            const std::uint32_t dim1349KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   27  ,   17  ,   35  ,   15  ,   405 ,   317 ,   1977    ,   2449    ,   237 ,   7741    ,0 };
            const std::uint32_t dim1350KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   1   ,   15  ,   63  ,   251 ,   61  ,   123 ,   855 ,   773 ,   4291    ,   15581   ,0 };
            const std::uint32_t dim1351KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   15  ,   49  ,   101 ,   215 ,   239 ,   31  ,   1193    ,   3839    ,   1913    ,   15471   ,0 };
            const std::uint32_t dim1352KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   29  ,   1   ,   109 ,   211 ,   97  ,   1017    ,   1477    ,   2131    ,   6539    ,   4891    ,0 };
            const std::uint32_t dim1353KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   15  ,   63  ,   67  ,   175 ,   209 ,   105 ,   1427    ,   769 ,   7021    ,   287 ,0 };
            const std::uint32_t dim1354KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   19  ,   41  ,   109 ,   165 ,   307 ,   935 ,   379 ,   395 ,   2533    ,   6291    ,0 };
            const std::uint32_t dim1355KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   17  ,   3   ,   69  ,   79  ,   437 ,   861 ,   1115    ,   1351    ,   4951    ,   1753    ,0 };
            const std::uint32_t dim1356KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   19  ,   15  ,   83  ,   85  ,   431 ,   207 ,   481 ,   711 ,   6715    ,   13439   ,0 };
            const std::uint32_t dim1357KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   3   ,   13  ,   127 ,   27  ,   223 ,   297 ,   985 ,   227 ,   6665    ,   13587   ,0 };
            const std::uint32_t dim1358KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   7   ,   61  ,   113 ,   73  ,   443 ,   397 ,   717 ,   1151    ,   3047    ,   3247    ,0 };
            const std::uint32_t dim1359KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   1   ,   1   ,   103 ,   239 ,   351 ,   305 ,   1345    ,   3543    ,   4321    ,   9147    ,0 };
            const std::uint32_t dim1360KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   11  ,   53  ,   57  ,   85  ,   95  ,   707 ,   1817    ,   249 ,   357 ,   11769   ,0 };
            const std::uint32_t dim1361KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   15  ,   25  ,   7   ,   169 ,   499 ,   717 ,   915 ,   365 ,   3131    ,   12487   ,0 };
            const std::uint32_t dim1362KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   15  ,   47  ,   109 ,   9   ,   171 ,   67  ,   1473    ,   1779    ,   5567    ,   3799    ,0 };
            const std::uint32_t dim1363KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   23  ,   21  ,   31  ,   59  ,   1   ,   505 ,   1157    ,   1209    ,   7661    ,   11903   ,0 };
            const std::uint32_t dim1364KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   11  ,   5   ,   75  ,   53  ,   481 ,   433 ,   915 ,   2881    ,   5299    ,   2835    ,0 };
            const std::uint32_t dim1365KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   23  ,   13  ,   127 ,   229 ,   157 ,   643 ,   847 ,   3613    ,   1999    ,   3807    ,0 };
            const std::uint32_t dim1366KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   13  ,   39  ,   79  ,   11  ,   131 ,   603 ,   1013    ,   1197    ,   7583    ,   8195    ,0 };
            const std::uint32_t dim1367KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   27  ,   29  ,   99  ,   19  ,   503 ,   455 ,   1453    ,   2233    ,   2479    ,   8489    ,0 };
            const std::uint32_t dim1368KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   21  ,   37  ,   27  ,   207 ,   405 ,   87  ,   319 ,   3323    ,   4809    ,   12599   ,0 };
            const std::uint32_t dim1369KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   29  ,   3   ,   121 ,   249 ,   31  ,   601 ,   865 ,   2819    ,   2633    ,   15541   ,0 };
            const std::uint32_t dim1370KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   25  ,   53  ,   121 ,   57  ,   75  ,   327 ,   2047    ,   253 ,   7945    ,   14209   ,0 };
            const std::uint32_t dim1371KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   21  ,   3   ,   13  ,   91  ,   417 ,   825 ,   1381    ,   3653    ,   4187    ,   4685    ,0 };
            const std::uint32_t dim1372KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   11  ,   17  ,   87  ,   75  ,   333 ,   871 ,   1679    ,   2943    ,   4803    ,   8147    ,0 };
            const std::uint32_t dim1373KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   13  ,   1   ,   105 ,   95  ,   347 ,   543 ,   1435    ,   2337    ,   5971    ,   7605    ,0 };
            const std::uint32_t dim1374KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   19  ,   51  ,   35  ,   91  ,   187 ,   833 ,   1921    ,   573 ,   3605    ,   8627    ,0 };
            const std::uint32_t dim1375KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   25  ,   7   ,   115 ,   93  ,   87  ,   13  ,   1323    ,   3821    ,   587 ,   5079    ,0 };
            const std::uint32_t dim1376KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   25  ,   25  ,   89  ,   185 ,   473 ,   909 ,   1245    ,   1589    ,   63  ,   10765   ,0 };
            const std::uint32_t dim1377KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   15  ,   3   ,   9   ,   149 ,   237 ,   107 ,   879 ,   2487    ,   7995    ,   12713   ,0 };
            const std::uint32_t dim1378KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   19  ,   55  ,   43  ,   221 ,   289 ,   129 ,   1123    ,   3411    ,   703 ,   9585    ,0 };
            const std::uint32_t dim1379KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   7   ,   63  ,   13  ,   243 ,   235 ,   253 ,   357 ,   563 ,   519 ,   3471    ,0 };
            const std::uint32_t dim1380KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   9   ,   59  ,   67  ,   61  ,   321 ,   149 ,   365 ,   2645    ,   2309    ,   3303    ,0 };
            const std::uint32_t dim1381KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   13  ,   7   ,   53  ,   175 ,   207 ,   507 ,   1159    ,   3869    ,   8139    ,   13899   ,0 };
            const std::uint32_t dim1382KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   23  ,   9   ,   123 ,   37  ,   325 ,   41  ,   679 ,   513 ,   4379    ,   3493    ,0 };
            const std::uint32_t dim1383KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   29  ,   9   ,   117 ,   203 ,   461 ,   831 ,   1757    ,   2815    ,   1215    ,   1725    ,0 };
            const std::uint32_t dim1384KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   23  ,   45  ,   75  ,   159 ,   395 ,   315 ,   709 ,   887 ,   6935    ,   2307    ,0 };
            const std::uint32_t dim1385KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   5   ,   51  ,   29  ,   141 ,   215 ,   783 ,   1161    ,   3887    ,   8103    ,   7461    ,0 };
            const std::uint32_t dim1386KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   21  ,   5   ,   59  ,   123 ,   283 ,   921 ,   225 ,   453 ,   2125    ,   559 ,0 };
            const std::uint32_t dim1387KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   21  ,   19  ,   121 ,   201 ,   367 ,   215 ,   1727    ,   1743    ,   4875    ,   2819    ,0 };
            const std::uint32_t dim1388KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   15  ,   53  ,   57  ,   35  ,   419 ,   595 ,   1581    ,   2881    ,   3473    ,   7201    ,0 };
            const std::uint32_t dim1389KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   19  ,   17  ,   113 ,   175 ,   195 ,   829 ,   115 ,   491 ,   6439    ,   4085    ,0 };
            const std::uint32_t dim1390KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   7   ,   9   ,   111 ,   23  ,   459 ,   335 ,   1529    ,   1519    ,   2855    ,   11923   ,0 };
            const std::uint32_t dim1391KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   13  ,   41  ,   19  ,   229 ,   73  ,   865 ,   1379    ,   1315    ,   1403    ,   10489   ,0 };
            const std::uint32_t dim1392KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   17  ,   35  ,   71  ,   199 ,   195 ,   89  ,   855 ,   355 ,   5087    ,   13173   ,0 };
            const std::uint32_t dim1393KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   3   ,   45  ,   77  ,   109 ,   105 ,   919 ,   21  ,   2749    ,   5401    ,   11701   ,0 };
            const std::uint32_t dim1394KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   5   ,   9   ,   29  ,   213 ,   489 ,   455 ,   791 ,   215 ,   1011    ,   2501    ,0 };
            const std::uint32_t dim1395KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   17  ,   7   ,   61  ,   99  ,   381 ,   669 ,   1787    ,   1443    ,   6135    ,   3273    ,0 };
            const std::uint32_t dim1396KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   27  ,   47  ,   31  ,   153 ,   365 ,   271 ,   1499    ,   1229    ,   5791    ,   2251    ,0 };
            const std::uint32_t dim1397KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   9   ,   31  ,   109 ,   53  ,   293 ,   135 ,   1329    ,   2795    ,   4335    ,   14817   ,0 };
            const std::uint32_t dim1398KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   19  ,   7   ,   43  ,   223 ,   483 ,   237 ,   803 ,   1713    ,   7969    ,   9681    ,0 };
            const std::uint32_t dim1399KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   23  ,   45  ,   67  ,   87  ,   57  ,   261 ,   955 ,   2917    ,   549 ,   4725    ,0 };
            const std::uint32_t dim1400KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   13  ,   43  ,   63  ,   153 ,   395 ,   313 ,   1219    ,   655 ,   6489    ,   2129    ,0 };
            const std::uint32_t dim1401KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   7   ,   51  ,   35  ,   233 ,   289 ,   715 ,   1227    ,   2041    ,   3639    ,   1465    ,0 };
            const std::uint32_t dim1402KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   3   ,   37  ,   97  ,   149 ,   51  ,   313 ,   1883    ,   1411    ,   3319    ,   2599    ,0 };
            const std::uint32_t dim1403KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   25  ,   13  ,   89  ,   245 ,   251 ,   841 ,   1367    ,   4039    ,   4389    ,   7129    ,0 };
            const std::uint32_t dim1404KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   3   ,   55  ,   113 ,   97  ,   159 ,   621 ,   251 ,   2539    ,   7017    ,   1039    ,0 };
            const std::uint32_t dim1405KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   27  ,   31  ,   53  ,   61  ,   165 ,   753 ,   1733    ,   671 ,   665 ,   4893    ,0 };
            const std::uint32_t dim1406KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   25  ,   11  ,   7   ,   189 ,   457 ,   5   ,   97  ,   2399    ,   3089    ,   4811    ,0 };
            const std::uint32_t dim1407KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   29  ,   19  ,   73  ,   105 ,   187 ,   871 ,   499 ,   443 ,   6807    ,   3753    ,0 };
            const std::uint32_t dim1408KuoInit[]        =   {   1   ,   3   ,   1   ,   5   ,   9   ,   15  ,   53  ,   83  ,   91  ,   763 ,   1585    ,   1675    ,   5137    ,   10483   ,0 };
            const std::uint32_t dim1409KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   25  ,   51  ,   43  ,   47  ,   151 ,   13  ,   1117    ,   1465    ,   2497    ,   7677    ,0 };
            const std::uint32_t dim1410KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   15  ,   15  ,   43  ,   53  ,   161 ,   689 ,   2027    ,   437 ,   3599    ,   6837    ,0 };
            const std::uint32_t dim1411KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   21  ,   5   ,   81  ,   99  ,   249 ,   785 ,   763 ,   1203    ,   1541    ,   6497    ,0 };
            const std::uint32_t dim1412KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   27  ,   7   ,   121 ,   91  ,   271 ,   461 ,   1531    ,   3255    ,   847 ,   14503   ,0 };
            const std::uint32_t dim1413KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   9   ,   53  ,   125 ,   107 ,   321 ,   579 ,   813 ,   2295    ,   2521    ,   6773    ,0 };
            const std::uint32_t dim1414KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   15  ,   55  ,   71  ,   61  ,   307 ,   917 ,   217 ,   1133    ,   7255    ,   16083   ,0 };
            const std::uint32_t dim1415KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   3   ,   7   ,   57  ,   27  ,   243 ,   989 ,   223 ,   3857    ,   2357    ,   11315   ,0 };
            const std::uint32_t dim1416KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   23  ,   41  ,   55  ,   75  ,   241 ,   829 ,   1865    ,   909 ,   4509    ,   5163    ,0 };
            const std::uint32_t dim1417KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   27  ,   5   ,   117 ,   79  ,   171 ,   135 ,   623 ,   2515    ,   3661    ,   941 ,0 };
            const std::uint32_t dim1418KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   17  ,   29  ,   9   ,   147 ,   73  ,   321 ,   895 ,   3263    ,   6897    ,   8551    ,0 };
            const std::uint32_t dim1419KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   21  ,   45  ,   57  ,   153 ,   83  ,   971 ,   403 ,   617 ,   545 ,   6489    ,0 };
            const std::uint32_t dim1420KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   31  ,   37  ,   19  ,   241 ,   89  ,   583 ,   1365    ,   2649    ,   7011    ,   6183    ,0 };
            const std::uint32_t dim1421KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   3   ,   5   ,   45  ,   237 ,   351 ,   811 ,   445 ,   557 ,   4103    ,   11185   ,0 };
            const std::uint32_t dim1422KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   25  ,   23  ,   21  ,   249 ,   209 ,   775 ,   1397    ,   2501    ,   4535    ,   4957    ,0 };
            const std::uint32_t dim1423KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   7   ,   43  ,   55  ,   179 ,   239 ,   43  ,   225 ,   2827    ,   955 ,   665 ,0 };
            const std::uint32_t dim1424KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   15  ,   35  ,   77  ,   153 ,   429 ,   35  ,   539 ,   3543    ,   1971    ,   2865    ,0 };
            const std::uint32_t dim1425KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   27  ,   35  ,   87  ,   51  ,   281 ,   247 ,   547 ,   2185    ,   2593    ,   1301    ,0 };
            const std::uint32_t dim1426KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   19  ,   11  ,   79  ,   241 ,   467 ,   515 ,   531 ,   3285    ,   1575    ,   7869    ,0 };
            const std::uint32_t dim1427KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   25  ,   15  ,   109 ,   231 ,   349 ,   955 ,   2019    ,   3475    ,   2927    ,   14383   ,0 };
            const std::uint32_t dim1428KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   17  ,   43  ,   43  ,   131 ,   485 ,   179 ,   901 ,   483 ,   4879    ,   15189   ,0 };
            const std::uint32_t dim1429KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   7   ,   39  ,   111 ,   27  ,   29  ,   79  ,   261 ,   77  ,   231 ,   8577    ,0 };
            const std::uint32_t dim1430KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   25  ,   15  ,   25  ,   41  ,   457 ,   677 ,   1033    ,   161 ,   3215    ,   105 ,0 };
            const std::uint32_t dim1431KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   3   ,   57  ,   125 ,   41  ,   325 ,   467 ,   1325    ,   1287    ,   51  ,   9463    ,0 };
            const std::uint32_t dim1432KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   1   ,   33  ,   39  ,   47  ,   313 ,   305 ,   2023    ,   1131    ,   4167    ,   4519    ,0 };
            const std::uint32_t dim1433KuoInit[]        =   {   1   ,   1   ,   5   ,   15  ,   1   ,   47  ,   123 ,   151 ,   263 ,   143 ,   91  ,   1673    ,   4175    ,   4575    ,0 };
            const std::uint32_t dim1434KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   7   ,   41  ,   95  ,   27  ,   183 ,   437 ,   587 ,   3821    ,   8035    ,   7627    ,0 };
            const std::uint32_t dim1435KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   17  ,   53  ,   95  ,   73  ,   335 ,   497 ,   643 ,   3309    ,   7139    ,   10811   ,0 };
            const std::uint32_t dim1436KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   7   ,   29  ,   83  ,   15  ,   29  ,   881 ,   881 ,   1253    ,   7267    ,   4221    ,0 };
            const std::uint32_t dim1437KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   15  ,   47  ,   71  ,   63  ,   493 ,   365 ,   1209    ,   2503    ,   3963    ,   5069    ,0 };
            const std::uint32_t dim1438KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   23  ,   55  ,   107 ,   255 ,   17  ,   561 ,   1131    ,   497 ,   5731    ,   13287   ,0 };
            const std::uint32_t dim1439KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   5   ,   59  ,   25  ,   131 ,   375 ,   165 ,   1051    ,   3129    ,   6517    ,   6317    ,0 };
            const std::uint32_t dim1440KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   17  ,   29  ,   57  ,   215 ,   77  ,   197 ,   1775    ,   3959    ,   185 ,   11431   ,0 };
            const std::uint32_t dim1441KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   11  ,   45  ,   29  ,   245 ,   193 ,   747 ,   1449    ,   2185    ,   7751    ,   10009   ,0 };
            const std::uint32_t dim1442KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   27  ,   19  ,   39  ,   161 ,   355 ,   455 ,   1625    ,   1283    ,   1547    ,   8707    ,0 };
            const std::uint32_t dim1443KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   7   ,   15  ,   35  ,   193 ,   489 ,   619 ,   515 ,   199 ,   5439    ,   15711   ,0 };
            const std::uint32_t dim1444KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   29  ,   21  ,   69  ,   13  ,   343 ,   581 ,   495 ,   3963    ,   911 ,   3995    ,0 };
            const std::uint32_t dim1445KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   21  ,   5   ,   9   ,   31  ,   291 ,   825 ,   7   ,   2621    ,   1149    ,   2709    ,0 };
            const std::uint32_t dim1446KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   7   ,   35  ,   69  ,   43  ,   397 ,   641 ,   89  ,   3325    ,   5567    ,   3487    ,0 };
            const std::uint32_t dim1447KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   1   ,   17  ,   11  ,   97  ,   309 ,   371 ,   145 ,   3255    ,   5161    ,   7787    ,0 };
            const std::uint32_t dim1448KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   27  ,   1   ,   1   ,   235 ,   47  ,   251 ,   1525    ,   2661    ,   3971    ,   11319   ,0 };
            const std::uint32_t dim1449KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   11  ,   21  ,   69  ,   97  ,   13  ,   931 ,   1955    ,   3497    ,   3963    ,   519 ,0 };
            const std::uint32_t dim1450KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   21  ,   15  ,   11  ,   201 ,   175 ,   855 ,   1867    ,   3941    ,   6505    ,   3451    ,0 };
            const std::uint32_t dim1451KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   25  ,   45  ,   27  ,   91  ,   149 ,   827 ,   1791    ,   139 ,   6721    ,   9   ,0 };
            const std::uint32_t dim1452KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   19  ,   13  ,   95  ,   161 ,   91  ,   333 ,   203 ,   3195    ,   517 ,   3911    ,0 };
            const std::uint32_t dim1453KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   3   ,   7   ,   113 ,   195 ,   501 ,   203 ,   193 ,   3585    ,   3217    ,   2009    ,0 };
            const std::uint32_t dim1454KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   21  ,   29  ,   9   ,   209 ,   381 ,   245 ,   1317    ,   3577    ,   3327    ,   9253    ,0 };
            const std::uint32_t dim1455KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   1   ,   5   ,   75  ,   215 ,   349 ,   143 ,   1607    ,   2817    ,   8185    ,   13991   ,0 };
            const std::uint32_t dim1456KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   23  ,   29  ,   73  ,   15  ,   159 ,   425 ,   1169    ,   2989    ,   5835    ,   12687   ,0 };
            const std::uint32_t dim1457KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   13  ,   13  ,   79  ,   97  ,   351 ,   455 ,   1465    ,   2013    ,   5133    ,   1747    ,0 };
            const std::uint32_t dim1458KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   3   ,   29  ,   53  ,   37  ,   357 ,   55  ,   195 ,   43  ,   3903    ,   7013    ,0 };
            const std::uint32_t dim1459KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   25  ,   43  ,   19  ,   233 ,   17  ,   31  ,   1727    ,   557 ,   2581    ,   847 ,0 };
            const std::uint32_t dim1460KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   21  ,   27  ,   7   ,   27  ,   487 ,   961 ,   1095    ,   3813    ,   7967    ,   15283   ,0 };
            const std::uint32_t dim1461KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   27  ,   49  ,   15  ,   199 ,   413 ,   295 ,   441 ,   2023    ,   2453    ,   2243    ,0 };
            const std::uint32_t dim1462KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   19  ,   13  ,   99  ,   85  ,   227 ,   61  ,   933 ,   3897    ,   2399    ,   455 ,0 };
            const std::uint32_t dim1463KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   13  ,   45  ,   123 ,   13  ,   39  ,   431 ,   1573    ,   2771    ,   2273    ,   12613   ,0 };
            const std::uint32_t dim1464KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   1   ,   29  ,   127 ,   59  ,   159 ,   1005    ,   483 ,   3031    ,   5029    ,   1763    ,0 };
            const std::uint32_t dim1465KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   17  ,   27  ,   87  ,   25  ,   313 ,   305 ,   1611    ,   693 ,   3701    ,   573 ,0 };
            const std::uint32_t dim1466KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   5   ,   61  ,   93  ,   69  ,   357 ,   681 ,   291 ,   1251    ,   3889    ,   3687    ,0 };
            const std::uint32_t dim1467KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   9   ,   31  ,   121 ,   213 ,   115 ,   231 ,   349 ,   2141    ,   4443    ,   12319   ,0 };
            const std::uint32_t dim1468KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   1   ,   37  ,   59  ,   21  ,   399 ,   751 ,   841 ,   33  ,   7195    ,   8403    ,0 };
            const std::uint32_t dim1469KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   5   ,   41  ,   111 ,   21  ,   135 ,   945 ,   1915    ,   2351    ,   6429    ,   10993   ,0 };
            const std::uint32_t dim1470KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   29  ,   43  ,   45  ,   13  ,   395 ,   407 ,   47  ,   1007    ,   7525    ,   6707    ,0 };
            const std::uint32_t dim1471KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   23  ,   3   ,   49  ,   149 ,   391 ,   689 ,   147 ,   1173    ,   3793    ,   4249    ,0 };
            const std::uint32_t dim1472KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   25  ,   35  ,   109 ,   147 ,   323 ,   161 ,   257 ,   2023    ,   5693    ,   16199   ,0 };
            const std::uint32_t dim1473KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   17  ,   3   ,   9   ,   191 ,   19  ,   405 ,   1841    ,   1669    ,   4691    ,   11907   ,0 };
            const std::uint32_t dim1474KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   13  ,   35  ,   45  ,   27  ,   127 ,   329 ,   931 ,   1   ,   2521    ,   15307   ,0 };
            const std::uint32_t dim1475KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   11  ,   25  ,   31  ,   233 ,   1   ,   769 ,   433 ,   3785    ,   3631    ,   8573    ,0 };
            const std::uint32_t dim1476KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   23  ,   57  ,   67  ,   227 ,   393 ,   469 ,   1579    ,   2235    ,   493 ,   2477    ,0 };
            const std::uint32_t dim1477KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   9   ,   19  ,   69  ,   123 ,   205 ,   553 ,   1871    ,   3807    ,   1563    ,   2771    ,0 };
            const std::uint32_t dim1478KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   11  ,   33  ,   55  ,   27  ,   51  ,   903 ,   1681    ,   2613    ,   2519    ,   9529    ,0 };
            const std::uint32_t dim1479KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   29  ,   55  ,   31  ,   185 ,   85  ,   929 ,   233 ,   2619    ,   2989    ,   191 ,0 };
            const std::uint32_t dim1480KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   1   ,   47  ,   47  ,   225 ,   387 ,   717 ,   815 ,   853 ,   819 ,   5645    ,0 };
            const std::uint32_t dim1481KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   1   ,   55  ,   89  ,   59  ,   39  ,   687 ,   1395    ,   535 ,   4977    ,   8155    ,0 };
            const std::uint32_t dim1482KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   11  ,   57  ,   107 ,   137 ,   407 ,   155 ,   313 ,   2205    ,   3095    ,   15179   ,0 };
            const std::uint32_t dim1483KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   29  ,   5   ,   121 ,   173 ,   21  ,   247 ,   1663    ,   1937    ,   5113    ,   7439    ,0 };
            const std::uint32_t dim1484KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   1   ,   39  ,   31  ,   129 ,   109 ,   447 ,   1269    ,   3133    ,   4933    ,   11893   ,0 };
            const std::uint32_t dim1485KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   9   ,   7   ,   21  ,   157 ,   397 ,   465 ,   1057    ,   2355    ,   4663    ,   13955   ,0 };
            const std::uint32_t dim1486KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   1   ,   35  ,   71  ,   175 ,   439 ,   1019    ,   1479    ,   2519    ,   5119    ,   15245   ,0 };
            const std::uint32_t dim1487KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   23  ,   49  ,   55  ,   91  ,   269 ,   407 ,   393 ,   1495    ,   6153    ,   15703   ,0 };
            const std::uint32_t dim1488KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   25  ,   3   ,   45  ,   87  ,   141 ,   693 ,   555 ,   3629    ,   2723    ,   4357    ,0 };
            const std::uint32_t dim1489KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   15  ,   27  ,   103 ,   161 ,   423 ,   785 ,   1171    ,   2335    ,   1845    ,   14373   ,0 };
            const std::uint32_t dim1490KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   1   ,   31  ,   117 ,   35  ,   181 ,   263 ,   1337    ,   3239    ,   617 ,   11499   ,0 };
            const std::uint32_t dim1491KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   15  ,   17  ,   103 ,   201 ,   79  ,   211 ,   2043    ,   3733    ,   7593    ,   6523    ,0 };
            const std::uint32_t dim1492KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   3   ,   59  ,   11  ,   163 ,   155 ,   215 ,   1621    ,   2615    ,   2915    ,   2459    ,0 };
            const std::uint32_t dim1493KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   11  ,   11  ,   93  ,   239 ,   367 ,   553 ,   1341    ,   129 ,   7651    ,   2841    ,0 };
            const std::uint32_t dim1494KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   7   ,   21  ,   45  ,   99  ,   63  ,   601 ,   1877    ,   765 ,   5831    ,   1825    ,0 };
            const std::uint32_t dim1495KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   21  ,   27  ,   71  ,   53  ,   185 ,   675 ,   891 ,   657 ,   5343    ,   3583    ,0 };
            const std::uint32_t dim1496KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   17  ,   57  ,   95  ,   57  ,   427 ,   329 ,   681 ,   2663    ,   3183    ,   7429    ,0 };
            const std::uint32_t dim1497KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   17  ,   9   ,   93  ,   105 ,   409 ,   975 ,   205 ,   429 ,   4473    ,   10269   ,0 };
            const std::uint32_t dim1498KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   11  ,   51  ,   25  ,   97  ,   333 ,   71  ,   1513    ,   1273    ,   1235    ,   5023    ,0 };
            const std::uint32_t dim1499KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   17  ,   59  ,   75  ,   51  ,   277 ,   377 ,   3   ,   3357    ,   2595    ,   7939    ,0 };
            const std::uint32_t dim1500KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   7   ,   47  ,   11  ,   241 ,   235 ,   761 ,   283 ,   3277    ,   2121    ,   69  ,0 };
            const std::uint32_t dim1501KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   5   ,   5   ,   57  ,   5   ,   99  ,   869 ,   707 ,   2379    ,   5439    ,   4981    ,0 };
            const std::uint32_t dim1502KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   5   ,   9   ,   115 ,   155 ,   191 ,   905 ,   1173    ,   975 ,   6825    ,   8257    ,0 };
            const std::uint32_t dim1503KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   17  ,   13  ,   63  ,   143 ,   305 ,   577 ,   1895    ,   1943    ,   2335    ,   8957    ,0 };
            const std::uint32_t dim1504KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   15  ,   19  ,   89  ,   91  ,   497 ,   145 ,   1419    ,   1449    ,   5305    ,   1379    ,0 };
            const std::uint32_t dim1505KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   9   ,   51  ,   103 ,   169 ,   265 ,   347 ,   697 ,   3735    ,   6987    ,   2565    ,0 };
            const std::uint32_t dim1506KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   1   ,   19  ,   83  ,   211 ,   247 ,   81  ,   131 ,   2243    ,   7563    ,   14221   ,0 };
            const std::uint32_t dim1507KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   27  ,   1   ,   97  ,   85  ,   265 ,   423 ,   173 ,   1873    ,   3889    ,   1845    ,0 };
            const std::uint32_t dim1508KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   15  ,   25  ,   25  ,   155 ,   111 ,   327 ,   1089    ,   335 ,   7635    ,   6467    ,0 };
            const std::uint32_t dim1509KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   15  ,   33  ,   103 ,   231 ,   455 ,   681 ,   547 ,   3389    ,   4279    ,   6037    ,0 };
            const std::uint32_t dim1510KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   3   ,   11  ,   11  ,   165 ,   113 ,   499 ,   977 ,   3805    ,   2733    ,   15643   ,0 };
            const std::uint32_t dim1511KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   23  ,   49  ,   39  ,   165 ,   323 ,   313 ,   1731    ,   2977    ,   4795    ,   12387   ,0 };
            const std::uint32_t dim1512KuoInit[]        =   {   1   ,   1   ,   5   ,   15  ,   27  ,   15  ,   43  ,   149 ,   71  ,   19  ,   1025    ,   2585    ,   5975    ,   12473   ,0 };
            const std::uint32_t dim1513KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   15  ,   21  ,   33  ,   29  ,   351 ,   909 ,   813 ,   3901    ,   3235    ,   3719    ,0 };
            const std::uint32_t dim1514KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   29  ,   63  ,   55  ,   173 ,   405 ,   841 ,   871 ,   213 ,   4747    ,   11611   ,0 };
            const std::uint32_t dim1515KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   15  ,   11  ,   83  ,   21  ,   123 ,   929 ,   1137    ,   3843    ,   5919    ,   151 ,0 };
            const std::uint32_t dim1516KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   29  ,   53  ,   111 ,   133 ,   285 ,   499 ,   2011    ,   121 ,   2853    ,   7587    ,0 };
            const std::uint32_t dim1517KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   15  ,   33  ,   87  ,   139 ,   429 ,   97  ,   375 ,   1273    ,   2745    ,   12045   ,0 };
            const std::uint32_t dim1518KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   17  ,   55  ,   43  ,   3   ,   465 ,   1   ,   1065    ,   647 ,   2497    ,   14775   ,0 };
            const std::uint32_t dim1519KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   15  ,   41  ,   39  ,   37  ,   397 ,   621 ,   1735    ,   1009    ,   1289    ,   2375    ,0 };
            const std::uint32_t dim1520KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   1   ,   45  ,   73  ,   207 ,   375 ,   825 ,   697 ,   3765    ,   7181    ,   4953    ,0 };
            const std::uint32_t dim1521KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   23  ,   15  ,   75  ,   11  ,   137 ,   1017    ,   203 ,   1325    ,   6661    ,   8569    ,0 };
            const std::uint32_t dim1522KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   23  ,   9   ,   15  ,   157 ,   179 ,   699 ,   1493    ,   2161    ,   3159    ,   2709    ,0 };
            const std::uint32_t dim1523KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   15  ,   51  ,   95  ,   101 ,   467 ,   303 ,   1867    ,   3819    ,   7593    ,   6133    ,0 };
            const std::uint32_t dim1524KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   25  ,   27  ,   87  ,   11  ,   113 ,   861 ,   1393    ,   1521    ,   2109    ,   11899   ,0 };
            const std::uint32_t dim1525KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   25  ,   53  ,   27  ,   249 ,   193 ,   783 ,   609 ,   3069    ,   3901    ,   391 ,0 };
            const std::uint32_t dim1526KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   19  ,   13  ,   55  ,   147 ,   325 ,   131 ,   659 ,   1277    ,   6127    ,   1033    ,0 };
            const std::uint32_t dim1527KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   31  ,   13  ,   1   ,   141 ,   377 ,   159 ,   1945    ,   2031    ,   8039    ,   13851   ,0 };
            const std::uint32_t dim1528KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   27  ,   17  ,   79  ,   47  ,   421 ,   517 ,   751 ,   3049    ,   6109    ,   11027   ,0 };
            const std::uint32_t dim1529KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   23  ,   41  ,   89  ,   225 ,   367 ,   109 ,   1295    ,   2691    ,   4677    ,   9207    ,0 };
            const std::uint32_t dim1530KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   7   ,   27  ,   89  ,   221 ,   267 ,   537 ,   2003    ,   3357    ,   8113    ,   8173    ,0 };
            const std::uint32_t dim1531KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   19  ,   23  ,   21  ,   173 ,   159 ,   535 ,   1685    ,   2259    ,   6515    ,   15853   ,0 };
            const std::uint32_t dim1532KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   13  ,   21  ,   105 ,   173 ,   173 ,   13  ,   423 ,   2259    ,   4145    ,   6543    ,0 };
            const std::uint32_t dim1533KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   13  ,   41  ,   35  ,   239 ,   307 ,   893 ,   73  ,   1325    ,   7975    ,   8395    ,0 };
            const std::uint32_t dim1534KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   11  ,   11  ,   115 ,   195 ,   407 ,   543 ,   801 ,   1449    ,   8121    ,   9627    ,0 };
            const std::uint32_t dim1535KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   13  ,   33  ,   41  ,   207 ,   347 ,   49  ,   897 ,   557 ,   5917    ,   13163   ,0 };
            const std::uint32_t dim1536KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   7   ,   9   ,   51  ,   241 ,   47  ,   479 ,   1399    ,   3229    ,   5201    ,   537 ,0 };
            const std::uint32_t dim1537KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   9   ,   63  ,   31  ,   109 ,   381 ,   631 ,   521 ,   139 ,   4229    ,   1639    ,0 };
            const std::uint32_t dim1538KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   1   ,   23  ,   15  ,   99  ,   395 ,   991 ,   627 ,   571 ,   833 ,   6631    ,0 };
            const std::uint32_t dim1539KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   31  ,   9   ,   99  ,   145 ,   237 ,   181 ,   1911    ,   2985    ,   2415    ,   5363    ,0 };
            const std::uint32_t dim1540KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   27  ,   1   ,   111 ,   133 ,   307 ,   211 ,   1119    ,   2289    ,   5333    ,   14747   ,0 };
            const std::uint32_t dim1541KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   9   ,   27  ,   5   ,   101 ,   113 ,   505 ,   931 ,   677 ,   6225    ,   16279   ,0 };
            const std::uint32_t dim1542KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   19  ,   47  ,   57  ,   3   ,   281 ,   207 ,   621 ,   939 ,   839 ,   4089    ,0 };
            const std::uint32_t dim1543KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   25  ,   61  ,   117 ,   139 ,   5   ,   325 ,   745 ,   3423    ,   31  ,   1451    ,0 };
            const std::uint32_t dim1544KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   3   ,   9   ,   121 ,   185 ,   497 ,   203 ,   367 ,   3049    ,   4827    ,   3363    ,0 };
            const std::uint32_t dim1545KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   1   ,   45  ,   91  ,   199 ,   183 ,   577 ,   625 ,   3641    ,   963 ,   9379    ,0 };
            const std::uint32_t dim1546KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   5   ,   53  ,   17  ,   205 ,   331 ,   329 ,   669 ,   2403    ,   3027    ,   297 ,0 };
            const std::uint32_t dim1547KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   19  ,   31  ,   43  ,   249 ,   361 ,   923 ,   635 ,   3461    ,   3901    ,   439 ,0 };
            const std::uint32_t dim1548KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   21  ,   25  ,   115 ,   115 ,   457 ,   607 ,   699 ,   2649    ,   3003    ,   1599    ,0 };
            const std::uint32_t dim1549KuoInit[]        =   {   1   ,   1   ,   5   ,   15  ,   21  ,   35  ,   61  ,   97  ,   131 ,   521 ,   1045    ,   2401    ,   2885    ,   11795   ,0 };
            const std::uint32_t dim1550KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   19  ,   13  ,   119 ,   117 ,   31  ,   575 ,   427 ,   3689    ,   3801    ,   12267   ,0 };
            const std::uint32_t dim1551KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   27  ,   45  ,   15  ,   235 ,   281 ,   777 ,   1181    ,   2445    ,   7947    ,   2081    ,0 };
            const std::uint32_t dim1552KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   31  ,   57  ,   57  ,   219 ,   135 ,   717 ,   1369    ,   2221    ,   4397    ,   16195   ,0 };
            const std::uint32_t dim1553KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   11  ,   17  ,   7   ,   189 ,   97  ,   7   ,   397 ,   1557    ,   7181    ,   16205   ,0 };
            const std::uint32_t dim1554KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   13  ,   25  ,   79  ,   241 ,   143 ,   959 ,   529 ,   3899    ,   5411    ,   8769    ,0 };
            const std::uint32_t dim1555KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   3   ,   17  ,   109 ,   25  ,   389 ,   463 ,   1675    ,   627 ,   6383    ,   5007    ,0 };
            const std::uint32_t dim1556KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   19  ,   3   ,   13  ,   3   ,   293 ,   755 ,   1827    ,   755 ,   3325    ,   13447   ,0 };
            const std::uint32_t dim1557KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   17  ,   5   ,   87  ,   17  ,   423 ,   901 ,   777 ,   919 ,   2655    ,   1423    ,0 };
            const std::uint32_t dim1558KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   19  ,   41  ,   89  ,   9   ,   475 ,   479 ,   981 ,   1031    ,   7207    ,   3605    ,0 };
            const std::uint32_t dim1559KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   9   ,   41  ,   111 ,   201 ,   389 ,   139 ,   1853    ,   1773    ,   233 ,   3695    ,0 };
            const std::uint32_t dim1560KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   3   ,   47  ,   83  ,   15  ,   49  ,   867 ,   1513    ,   3203    ,   3081    ,   8429    ,0 };
            const std::uint32_t dim1561KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   11  ,   33  ,   67  ,   225 ,   303 ,   825 ,   1711    ,   1521    ,   1569    ,   5233    ,0 };
            const std::uint32_t dim1562KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   27  ,   41  ,   37  ,   247 ,   211 ,   143 ,   855 ,   3755    ,   569 ,   10155   ,0 };
            const std::uint32_t dim1563KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   21  ,   57  ,   7   ,   83  ,   133 ,   791 ,   565 ,   2217    ,   7621    ,   14141   ,0 };
            const std::uint32_t dim1564KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   3   ,   57  ,   7   ,   29  ,   131 ,   935 ,   1555    ,   1103    ,   7395    ,   4079    ,0 };
            const std::uint32_t dim1565KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   13  ,   9   ,   13  ,   71  ,   345 ,   1003    ,   1519    ,   1757    ,   539 ,   9207    ,0 };
            const std::uint32_t dim1566KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   1   ,   11  ,   13  ,   143 ,   365 ,   981 ,   1691    ,   2501    ,   7155    ,   4189    ,0 };
            const std::uint32_t dim1567KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   23  ,   37  ,   33  ,   229 ,   411 ,   329 ,   915 ,   2373    ,   2525    ,   12319   ,0 };
            const std::uint32_t dim1568KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   5   ,   45  ,   77  ,   23  ,   317 ,   311 ,   425 ,   1329    ,   3619    ,   11941   ,0 };
            const std::uint32_t dim1569KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   19  ,   17  ,   39  ,   37  ,   405 ,   275 ,   983 ,   995 ,   4925    ,   1005    ,0 };
            const std::uint32_t dim1570KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   31  ,   1   ,   71  ,   137 ,   481 ,   489 ,   1381    ,   3919    ,   7841    ,   14843   ,0 };
            const std::uint32_t dim1571KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   13  ,   37  ,   11  ,   201 ,   43  ,   311 ,   921 ,   2755    ,   2997    ,   4753    ,0 };
            const std::uint32_t dim1572KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   27  ,   35  ,   87  ,   203 ,   197 ,   27  ,   1839    ,   2847    ,   3261    ,   3139    ,0 };
            const std::uint32_t dim1573KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   25  ,   5   ,   9   ,   9   ,   497 ,   125 ,   1451    ,   1381    ,   1975    ,   10493   ,0 };
            const std::uint32_t dim1574KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   11  ,   25  ,   3   ,   9   ,   39  ,   989 ,   975 ,   1825    ,   7089    ,   10475   ,0 };
            const std::uint32_t dim1575KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   25  ,   33  ,   69  ,   55  ,   179 ,   163 ,   1233    ,   1601    ,   1893    ,   8225    ,0 };
            const std::uint32_t dim1576KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   23  ,   11  ,   117 ,   71  ,   151 ,   437 ,   371 ,   1543    ,   2417    ,   13195   ,0 };
            const std::uint32_t dim1577KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   25  ,   33  ,   63  ,   215 ,   193 ,   415 ,   1771    ,   715 ,   4011    ,   11739   ,0 };
            const std::uint32_t dim1578KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   17  ,   1   ,   105 ,   169 ,   5   ,   259 ,   169 ,   1207    ,   5425    ,   6091    ,0 };
            const std::uint32_t dim1579KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   29  ,   43  ,   25  ,   245 ,   33  ,   995 ,   1797    ,   279 ,   6443    ,   14507   ,0 };
            const std::uint32_t dim1580KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   5   ,   29  ,   117 ,   141 ,   409 ,   367 ,   1223    ,   1499    ,   5651    ,   3337    ,0 };
            const std::uint32_t dim1581KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   15  ,   21  ,   21  ,   27  ,   23  ,   693 ,   1431    ,   2055    ,   2959    ,   1347    ,0 };
            const std::uint32_t dim1582KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   7   ,   27  ,   67  ,   127 ,   63  ,   213 ,   763 ,   1221    ,   2319    ,   5313    ,0 };
            const std::uint32_t dim1583KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   21  ,   33  ,   43  ,   243 ,   113 ,   223 ,   1095    ,   2433    ,   1253    ,   16303   ,0 };
            const std::uint32_t dim1584KuoInit[]        =   {   1   ,   1   ,   5   ,   15  ,   21  ,   61  ,   39  ,   147 ,   263 ,   943 ,   321 ,   2599    ,   3513    ,   6595    ,0 };
            const std::uint32_t dim1585KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   9   ,   25  ,   19  ,   73  ,   253 ,   889 ,   1699    ,   1709    ,   6451    ,   2939    ,0 };
            const std::uint32_t dim1586KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   29  ,   29  ,   53  ,   133 ,   349 ,   553 ,   1677    ,   3949    ,   1701    ,   1187    ,0 };
            const std::uint32_t dim1587KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   27  ,   5   ,   17  ,   15  ,   185 ,   583 ,   1117    ,   2869    ,   6929    ,   8117    ,0 };
            const std::uint32_t dim1588KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   3   ,   15  ,   117 ,   73  ,   321 ,   245 ,   537 ,   2689    ,   4883    ,   5993    ,0 };
            const std::uint32_t dim1589KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   31  ,   57  ,   103 ,   65  ,   89  ,   323 ,   1341    ,   1951    ,   4999    ,   12663   ,0 };
            const std::uint32_t dim1590KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   7   ,   23  ,   77  ,   133 ,   413 ,   157 ,   1281    ,   3779    ,   2081    ,   12201   ,0 };
            const std::uint32_t dim1591KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   15  ,   49  ,   119 ,   45  ,   27  ,   621 ,   2017    ,   1351    ,   7647    ,   8845    ,0 };
            const std::uint32_t dim1592KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   7   ,   51  ,   77  ,   181 ,   25  ,   769 ,   1159    ,   1505    ,   5219    ,   647 ,0 };
            const std::uint32_t dim1593KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   3   ,   35  ,   69  ,   43  ,   327 ,   383 ,   755 ,   253 ,   1137    ,   16133   ,0 };
            const std::uint32_t dim1594KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   13  ,   63  ,   69  ,   215 ,   357 ,   873 ,   477 ,   1243    ,   5475    ,   5335    ,0 };
            const std::uint32_t dim1595KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   27  ,   13  ,   115 ,   197 ,   131 ,   651 ,   741 ,   2539    ,   265 ,   15757   ,0 };
            const std::uint32_t dim1596KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   13  ,   47  ,   45  ,   235 ,   103 ,   597 ,   523 ,   3129    ,   5113    ,   7031    ,0 };
            const std::uint32_t dim1597KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   31  ,   63  ,   25  ,   75  ,   343 ,   537 ,   83  ,   3165    ,   3247    ,   2589    ,0 };
            const std::uint32_t dim1598KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   11  ,   13  ,   29  ,   79  ,   233 ,   901 ,   627 ,   1691    ,   2659    ,   10251   ,0 };
            const std::uint32_t dim1599KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   11  ,   63  ,   123 ,   63  ,   441 ,   931 ,   573 ,   4083    ,   4483    ,   5685    ,0 };
            const std::uint32_t dim1600KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   23  ,   51  ,   107 ,   113 ,   233 ,   921 ,   1761    ,   207 ,   5083    ,   9165    ,0 };
            const std::uint32_t dim1601KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   13  ,   23  ,   5   ,   151 ,   487 ,   157 ,   23  ,   3967    ,   6241    ,   487 ,0 };
            const std::uint32_t dim1602KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   7   ,   39  ,   95  ,   185 ,   379 ,   225 ,   1685    ,   513 ,   2463    ,   11033   ,0 };
            const std::uint32_t dim1603KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   19  ,   43  ,   55  ,   69  ,   433 ,   933 ,   811 ,   3717    ,   5555    ,   15391   ,0 };
            const std::uint32_t dim1604KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   21  ,   17  ,   19  ,   149 ,   185 ,   475 ,   1817    ,   913 ,   4463    ,   12837   ,0 };
            const std::uint32_t dim1605KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   27  ,   63  ,   5   ,   131 ,   217 ,   271 ,   889 ,   3905    ,   2881    ,   419 ,0 };
            const std::uint32_t dim1606KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   5   ,   55  ,   103 ,   135 ,   59  ,   775 ,   1105    ,   2017    ,   493 ,   12747   ,0 };
            const std::uint32_t dim1607KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   9   ,   25  ,   65  ,   9   ,   61  ,   709 ,   1925    ,   1769    ,   3273    ,   1627    ,0 };
            const std::uint32_t dim1608KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   7   ,   35  ,   37  ,   223 ,   105 ,   55  ,   293 ,   2103    ,   7531    ,   2795    ,0 };
            const std::uint32_t dim1609KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   17  ,   23  ,   35  ,   163 ,   177 ,   797 ,   1539    ,   3843    ,   6761    ,   11817   ,0 };
            const std::uint32_t dim1610KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   11  ,   19  ,   55  ,   161 ,   33  ,   701 ,   601 ,   1055    ,   4949    ,   10741   ,0 };
            const std::uint32_t dim1611KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   11  ,   45  ,   71  ,   199 ,   233 ,   917 ,   1447    ,   3651    ,   6021    ,   4745    ,0 };
            const std::uint32_t dim1612KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   21  ,   17  ,   39  ,   141 ,   17  ,   827 ,   355 ,   3337    ,   6897    ,   9005    ,0 };
            const std::uint32_t dim1613KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   11  ,   61  ,   67  ,   103 ,   377 ,   351 ,   1863    ,   207 ,   7333    ,   4481    ,0 };
            const std::uint32_t dim1614KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   7   ,   33  ,   103 ,   121 ,   361 ,   233 ,   195 ,   985 ,   4743    ,   8715    ,0 };
            const std::uint32_t dim1615KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   17  ,   47  ,   127 ,   129 ,   93  ,   217 ,   1049    ,   689 ,   5595    ,   13625   ,0 };
            const std::uint32_t dim1616KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   13  ,   33  ,   59  ,   29  ,   439 ,   447 ,   21  ,   621 ,   3731    ,   9371    ,0 };
            const std::uint32_t dim1617KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   15  ,   31  ,   41  ,   217 ,   275 ,   97  ,   143 ,   3779    ,   5453    ,   13167   ,0 };
            const std::uint32_t dim1618KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   11  ,   31  ,   7   ,   249 ,   193 ,   907 ,   1275    ,   691 ,   5701    ,   6215    ,0 };
            const std::uint32_t dim1619KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   11  ,   63  ,   7   ,   209 ,   227 ,   959 ,   1313    ,   1107    ,   2281    ,   5567    ,0 };
            const std::uint32_t dim1620KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   25  ,   5   ,   103 ,   193 ,   137 ,   345 ,   1953    ,   369 ,   2201    ,   9435    ,0 };
            const std::uint32_t dim1621KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   5   ,   19  ,   11  ,   191 ,   101 ,   861 ,   1665    ,   1439    ,   6889    ,   2467    ,0 };
            const std::uint32_t dim1622KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   19  ,   47  ,   13  ,   123 ,   363 ,   659 ,   1011    ,   2961    ,   2231    ,   11523   ,0 };
            const std::uint32_t dim1623KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   9   ,   19  ,   7   ,   1   ,   351 ,   461 ,   1323    ,   1125    ,   3063    ,   9589    ,0 };
            const std::uint32_t dim1624KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   1   ,   25  ,   79  ,   171 ,   503 ,   319 ,   729 ,   2133    ,   1979    ,   13769   ,0 };
            const std::uint32_t dim1625KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   17  ,   45  ,   55  ,   109 ,   143 ,   541 ,   65  ,   431 ,   2949    ,   11501   ,0 };
            const std::uint32_t dim1626KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   7   ,   7   ,   85  ,   81  ,   317 ,   245 ,   1683    ,   1009    ,   3853    ,   12597   ,0 };
            const std::uint32_t dim1627KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   9   ,   25  ,   85  ,   19  ,   59  ,   5   ,   1919    ,   577 ,   7723    ,   9365    ,0 };
            const std::uint32_t dim1628KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   13  ,   27  ,   35  ,   163 ,   209 ,   491 ,   1759    ,   383 ,   5697    ,   13131   ,0 };
            const std::uint32_t dim1629KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   19  ,   57  ,   121 ,   61  ,   143 ,   735 ,   721 ,   3405    ,   6939    ,   4691    ,0 };
            const std::uint32_t dim1630KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   21  ,   23  ,   55  ,   203 ,   145 ,   673 ,   419 ,   3023    ,   6439    ,   6361    ,0 };
            const std::uint32_t dim1631KuoInit[]        =   {   1   ,   1   ,   5   ,   15  ,   5   ,   21  ,   11  ,   153 ,   223 ,   229 ,   721 ,   715 ,   7981    ,   15459   ,0 };
            const std::uint32_t dim1632KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   21  ,   59  ,   47  ,   15  ,   213 ,   549 ,   465 ,   1353    ,   2611    ,   11989   ,0 };
            const std::uint32_t dim1633KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   13  ,   51  ,   65  ,   11  ,   295 ,   63  ,   1887    ,   3347    ,   3061    ,   2219    ,0 };
            const std::uint32_t dim1634KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   29  ,   29  ,   83  ,   175 ,   507 ,   341 ,   2031    ,   3737    ,   1741    ,   7615    ,0 };
            const std::uint32_t dim1635KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   11  ,   55  ,   59  ,   213 ,   197 ,   851 ,   1723    ,   2805    ,   2461    ,   8071    ,0 };
            const std::uint32_t dim1636KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   5   ,   37  ,   55  ,   237 ,   319 ,   345 ,   1677    ,   1791    ,   5063    ,   4301    ,0 };
            const std::uint32_t dim1637KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   25  ,   13  ,   87  ,   85  ,   293 ,   97  ,   557 ,   3583    ,   7077    ,   6433    ,0 };
            const std::uint32_t dim1638KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   31  ,   9   ,   63  ,   29  ,   193 ,   351 ,   1071    ,   3587    ,   4695    ,   1771    ,0 };
            const std::uint32_t dim1639KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   11  ,   3   ,   45  ,   119 ,   215 ,   367 ,   677 ,   3405    ,   7177    ,   14607   ,0 };
            const std::uint32_t dim1640KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   3   ,   23  ,   33  ,   33  ,   223 ,   209 ,   1033    ,   3167    ,   4189    ,   2195    ,0 };
            const std::uint32_t dim1641KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   3   ,   53  ,   21  ,   151 ,   475 ,   987 ,   1671    ,   393 ,   7783    ,   2561    ,0 };
            const std::uint32_t dim1642KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   15  ,   5   ,   21  ,   247 ,   225 ,   861 ,   1707    ,   3237    ,   5793    ,   14557   ,0 };
            const std::uint32_t dim1643KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   13  ,   3   ,   37  ,   49  ,   119 ,   33  ,   805 ,   681 ,   7591    ,   1707    ,0 };
            const std::uint32_t dim1644KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   27  ,   55  ,   99  ,   17  ,   361 ,   773 ,   1415    ,   3547    ,   5427    ,   4579    ,0 };
            const std::uint32_t dim1645KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   17  ,   55  ,   89  ,   111 ,   189 ,   719 ,   1691    ,   1565    ,   941 ,   15481   ,0 };
            const std::uint32_t dim1646KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   17  ,   3   ,   77  ,   57  ,   71  ,   739 ,   869 ,   165 ,   6411    ,   1565    ,0 };
            const std::uint32_t dim1647KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   31  ,   47  ,   87  ,   105 ,   241 ,   999 ,   245 ,   3695    ,   5151    ,   9087    ,0 };
            const std::uint32_t dim1648KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   27  ,   59  ,   15  ,   45  ,   413 ,   291 ,   87  ,   1735    ,   779 ,   5977    ,0 };
            const std::uint32_t dim1649KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   9   ,   19  ,   7   ,   183 ,   133 ,   833 ,   1347    ,   3559    ,   7745    ,   11071   ,0 };
            const std::uint32_t dim1650KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   23  ,   59  ,   13  ,   227 ,   407 ,   661 ,   217 ,   299 ,   6033    ,   14519   ,0 };
            const std::uint32_t dim1651KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   27  ,   33  ,   105 ,   15  ,   141 ,   555 ,   397 ,   3287    ,   5859    ,   9553    ,0 };
            const std::uint32_t dim1652KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   27  ,   59  ,   11  ,   47  ,   379 ,   275 ,   889 ,   3069    ,   4135    ,   15735   ,0 };
            const std::uint32_t dim1653KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   27  ,   47  ,   107 ,   165 ,   487 ,   463 ,   425 ,   3949    ,   3213    ,   4161    ,0 };
            const std::uint32_t dim1654KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   27  ,   55  ,   17  ,   3   ,   159 ,   181 ,   393 ,   2441    ,   2531    ,   895 ,0 };
            const std::uint32_t dim1655KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   31  ,   3   ,   95  ,   81  ,   181 ,   367 ,   1689    ,   2351    ,   193 ,   7165    ,0 };
            const std::uint32_t dim1656KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   1   ,   17  ,   103 ,   181 ,   29  ,   851 ,   15  ,   1447    ,   435 ,   14059   ,0 };
            const std::uint32_t dim1657KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   21  ,   31  ,   83  ,   41  ,   237 ,   437 ,   509 ,   3757    ,   5609    ,   15859   ,0 };
            const std::uint32_t dim1658KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   5   ,   35  ,   101 ,   37  ,   245 ,   487 ,   449 ,   2089    ,   27  ,   13667   ,0 };
            const std::uint32_t dim1659KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   29  ,   49  ,   89  ,   161 ,   271 ,   455 ,   1599    ,   3843    ,   1673    ,   3683    ,0 };
            const std::uint32_t dim1660KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   1   ,   25  ,   37  ,   211 ,   369 ,   207 ,   243 ,   2113    ,   2707    ,   7951    ,0 };
            const std::uint32_t dim1661KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   19  ,   21  ,   25  ,   161 ,   97  ,   505 ,   273 ,   1443    ,   4461    ,   1407    ,0 };
            const std::uint32_t dim1662KuoInit[]        =   {   1   ,   1   ,   5   ,   15  ,   17  ,   57  ,   115 ,   175 ,   511 ,   389 ,   1333    ,   2459    ,   5561    ,   4409    ,0 };
            const std::uint32_t dim1663KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   29  ,   45  ,   45  ,   121 ,   159 ,   51  ,   865 ,   531 ,   1387    ,   3517    ,0 };
            const std::uint32_t dim1664KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   25  ,   17  ,   59  ,   161 ,   193 ,   495 ,   611 ,   1009    ,   5035    ,   15325   ,0 };
            const std::uint32_t dim1665KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   7   ,   53  ,   99  ,   241 ,   305 ,   989 ,   175 ,   2841    ,   2891    ,   4975    ,0 };
            const std::uint32_t dim1666KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   31  ,   45  ,   85  ,   251 ,   339 ,   731 ,   513 ,   2557    ,   3119    ,   15961   ,0 };
            const std::uint32_t dim1667KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   11  ,   37  ,   73  ,   93  ,   83  ,   931 ,   1561    ,   791 ,   3263    ,   10789   ,0 };
            const std::uint32_t dim1668KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   27  ,   25  ,   29  ,   71  ,   199 ,   673 ,   173 ,   2267    ,   1277    ,   4373    ,0 };
            const std::uint32_t dim1669KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   7   ,   19  ,   79  ,   143 ,   63  ,   139 ,   977 ,   845 ,   5125    ,   5635    ,0 };
            const std::uint32_t dim1670KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   3   ,   27  ,   117 ,   219 ,   393 ,   457 ,   1001    ,   1235    ,   6409    ,   10883   ,0 };
            const std::uint32_t dim1671KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   19  ,   31  ,   61  ,   225 ,   391 ,   719 ,   1919    ,   1843    ,   4883    ,   10499   ,0 };
            const std::uint32_t dim1672KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   13  ,   63  ,   73  ,   103 ,   15  ,   777 ,   1019    ,   2677    ,   7317    ,   4349    ,0 };
            const std::uint32_t dim1673KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   5   ,   7   ,   31  ,   33  ,   237 ,   1021    ,   2045    ,   2283    ,   7045    ,   13829   ,0 };
            const std::uint32_t dim1674KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   11  ,   43  ,   47  ,   239 ,   5   ,   293 ,   2015    ,   3613    ,   1551    ,   3203    ,0 };
            const std::uint32_t dim1675KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   11  ,   11  ,   67  ,   201 ,   287 ,   161 ,   193 ,   1815    ,   1493    ,   2863    ,0 };
            const std::uint32_t dim1676KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   11  ,   31  ,   119 ,   57  ,   305 ,   1009    ,   915 ,   2855    ,   3595    ,   11653   ,0 };
            const std::uint32_t dim1677KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   17  ,   7   ,   59  ,   27  ,   189 ,   227 ,   763 ,   2843    ,   7335    ,   13559   ,0 };
            const std::uint32_t dim1678KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   3   ,   1   ,   17  ,   129 ,   83  ,   763 ,   443 ,   895 ,   1573    ,   7343    ,0 };
            const std::uint32_t dim1679KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   5   ,   43  ,   31  ,   95  ,   503 ,   815 ,   1725    ,   2319    ,   2323    ,   12543   ,0 };
            const std::uint32_t dim1680KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   29  ,   27  ,   103 ,   43  ,   39  ,   289 ,   277 ,   453 ,   4297    ,   1009    ,0 };
            const std::uint32_t dim1681KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   31  ,   61  ,   105 ,   79  ,   259 ,   141 ,   49  ,   925 ,   2793    ,   13247   ,0 };
            const std::uint32_t dim1682KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   15  ,   23  ,   59  ,   55  ,   497 ,   561 ,   343 ,   3633    ,   2097    ,   2035    ,0 };
            const std::uint32_t dim1683KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   17  ,   23  ,   13  ,   23  ,   15  ,   519 ,   105 ,   3719    ,   3639    ,   6387    ,0 };
            const std::uint32_t dim1684KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   1   ,   43  ,   97  ,   73  ,   295 ,   841 ,   1033    ,   11  ,   3027    ,   4073    ,0 };
            const std::uint32_t dim1685KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   21  ,   15  ,   67  ,   95  ,   425 ,   979 ,   1641    ,   3059    ,   4195    ,   14291   ,0 };
            const std::uint32_t dim1686KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   9   ,   23  ,   83  ,   203 ,   479 ,   999 ,   1469    ,   2227    ,   7995    ,   4053    ,0 };
            const std::uint32_t dim1687KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   1   ,   13  ,   17  ,   191 ,   297 ,   397 ,   329 ,   1551    ,   6885    ,   2413    ,0 };
            const std::uint32_t dim1688KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   31  ,   21  ,   123 ,   59  ,   79  ,   647 ,   475 ,   347 ,   667 ,   9871    ,0 };
            const std::uint32_t dim1689KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   25  ,   43  ,   35  ,   117 ,   323 ,   805 ,   1543    ,   2631    ,   2919    ,   1377    ,0 };
            const std::uint32_t dim1690KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   17  ,   55  ,   45  ,   213 ,   507 ,   641 ,   1947    ,   2439    ,   4749    ,   6865    ,0 };
            const std::uint32_t dim1691KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   13  ,   31  ,   51  ,   31  ,   167 ,   431 ,   1999    ,   1041    ,   3613    ,   16289   ,0 };
            const std::uint32_t dim1692KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   1   ,   15  ,   19  ,   191 ,   181 ,   247 ,   11  ,   2305    ,   5451    ,   1719    ,0 };
            const std::uint32_t dim1693KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   25  ,   39  ,   13  ,   123 ,   93  ,   527 ,   1359    ,   1985    ,   6789    ,   2045    ,0 };
            const std::uint32_t dim1694KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   25  ,   57  ,   113 ,   91  ,   311 ,   661 ,   1461    ,   2801    ,   5281    ,   13423   ,0 };
            const std::uint32_t dim1695KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   31  ,   9   ,   119 ,   55  ,   91  ,   965 ,   1973    ,   2901    ,   1147    ,   9341    ,0 };
            const std::uint32_t dim1696KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   9   ,   59  ,   83  ,   21  ,   49  ,   921 ,   749 ,   1249    ,   3577    ,   14341   ,0 };
            const std::uint32_t dim1697KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   25  ,   63  ,   65  ,   135 ,   337 ,   743 ,   1669    ,   2519    ,   341 ,   16285   ,0 };
            const std::uint32_t dim1698KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   23  ,   9   ,   97  ,   205 ,   87  ,   289 ,   1195    ,   2843    ,   7419    ,   4183    ,0 };
            const std::uint32_t dim1699KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   3   ,   33  ,   117 ,   243 ,   161 ,   977 ,   109 ,   3333    ,   4639    ,   2299    ,0 };
            const std::uint32_t dim1700KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   1   ,   53  ,   79  ,   73  ,   71  ,   953 ,   349 ,   2517    ,   6281    ,   2625    ,0 };
            const std::uint32_t dim1701KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   21  ,   59  ,   31  ,   253 ,   265 ,   403 ,   603 ,   2185    ,   7277    ,   6057    ,0 };
            const std::uint32_t dim1702KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   27  ,   35  ,   63  ,   109 ,   483 ,   205 ,   1245    ,   2599    ,   1697    ,   11381   ,0 };
            const std::uint32_t dim1703KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   25  ,   29  ,   107 ,   205 ,   411 ,   627 ,   745 ,   1585    ,   1175    ,   3077    ,0 };
            const std::uint32_t dim1704KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   25  ,   15  ,   121 ,   97  ,   283 ,   809 ,   753 ,   2577    ,   1099    ,   12155   ,0 };
            const std::uint32_t dim1705KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   29  ,   21  ,   55  ,   53  ,   101 ,   69  ,   657 ,   2727    ,   931 ,   4873    ,0 };
            const std::uint32_t dim1706KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   5   ,   57  ,   9   ,   11  ,   269 ,   261 ,   1681    ,   1025    ,   4001    ,   16111   ,0 };
            const std::uint32_t dim1707KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   9   ,   51  ,   29  ,   77  ,   313 ,   199 ,   1305    ,   2665    ,   5971    ,   7525    ,0 };
            const std::uint32_t dim1708KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   3   ,   29  ,   99  ,   255 ,   331 ,   925 ,   1973    ,   3825    ,   3549    ,   8537    ,0 };
            const std::uint32_t dim1709KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   27  ,   33  ,   19  ,   225 ,   209 ,   895 ,   47  ,   4063    ,   1873    ,   15631   ,0 };
            const std::uint32_t dim1710KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   11  ,   57  ,   121 ,   205 ,   89  ,   565 ,   1387    ,   1119    ,   7375    ,   6153    ,0 };
            const std::uint32_t dim1711KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   1   ,   27  ,   9   ,   177 ,   443 ,   437 ,   1487    ,   2119    ,   5299    ,   16251   ,0 };
            const std::uint32_t dim1712KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   17  ,   33  ,   79  ,   153 ,   327 ,   719 ,   1587    ,   407 ,   1137    ,   9607    ,0 };
            const std::uint32_t dim1713KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   7   ,   31  ,   109 ,   251 ,   501 ,   553 ,   785 ,   3047    ,   8141    ,   6305    ,0 };
            const std::uint32_t dim1714KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   11  ,   63  ,   65  ,   135 ,   257 ,   313 ,   191 ,   1073    ,   6821    ,   10629   ,0 };
            const std::uint32_t dim1715KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   19  ,   55  ,   7   ,   69  ,   503 ,   131 ,   1133    ,   3325    ,   347 ,   9255    ,0 };
            const std::uint32_t dim1716KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   11  ,   55  ,   115 ,   171 ,   261 ,   581 ,   1169    ,   3609    ,   307 ,   14055   ,0 };
            const std::uint32_t dim1717KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   29  ,   3   ,   33  ,   229 ,   431 ,   969 ,   281 ,   1617    ,   3685    ,   13583   ,0 };
            const std::uint32_t dim1718KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   9   ,   23  ,   5   ,   147 ,   305 ,   651 ,   1419    ,   3225    ,   7029    ,   15331   ,0 };
            const std::uint32_t dim1719KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   23  ,   61  ,   111 ,   221 ,   145 ,   809 ,   1127    ,   2287    ,   6023    ,   6103    ,0 };
            const std::uint32_t dim1720KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   1   ,   49  ,   93  ,   251 ,   239 ,   617 ,   401 ,   3419    ,   8123    ,   4855    ,0 };
            const std::uint32_t dim1721KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   15  ,   9   ,   69  ,   5   ,   509 ,   83  ,   405 ,   3451    ,   4401    ,   3321    ,0 };
            const std::uint32_t dim1722KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   29  ,   39  ,   53  ,   155 ,   73  ,   207 ,   499 ,   3179    ,   6099    ,   1377    ,0 };
            const std::uint32_t dim1723KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   9   ,   43  ,   101 ,   211 ,   439 ,   865 ,   621 ,   3271    ,   4699    ,   5329    ,0 };
            const std::uint32_t dim1724KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   21  ,   59  ,   105 ,   89  ,   5   ,   493 ,   227 ,   1177    ,   6829    ,   8659    ,0 };
            const std::uint32_t dim1725KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   27  ,   19  ,   49  ,   209 ,   337 ,   961 ,   93  ,   81  ,   4607    ,   13579   ,0 };
            const std::uint32_t dim1726KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   31  ,   53  ,   77  ,   213 ,   3   ,   555 ,   1409    ,   3917    ,   23  ,   7837    ,0 };
            const std::uint32_t dim1727KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   21  ,   37  ,   121 ,   17  ,   295 ,   367 ,   1105    ,   3053    ,   1453    ,   8869    ,0 };
            const std::uint32_t dim1728KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   31  ,   23  ,   13  ,   145 ,   459 ,   609 ,   77  ,   197 ,   4457    ,   5145    ,0 };
            const std::uint32_t dim1729KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   27  ,   23  ,   83  ,   165 ,   25  ,   491 ,   1487    ,   2335    ,   7019    ,   499 ,0 };
            const std::uint32_t dim1730KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   29  ,   53  ,   87  ,   47  ,   21  ,   233 ,   253 ,   2529    ,   1651    ,   16091   ,0 };
            const std::uint32_t dim1731KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   7   ,   55  ,   99  ,   193 ,   395 ,   63  ,   817 ,   2109    ,   1167    ,   5739    ,0 };
            const std::uint32_t dim1732KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   13  ,   21  ,   61  ,   31  ,   45  ,   723 ,   103 ,   1347    ,   4259    ,   13185   ,0 };
            const std::uint32_t dim1733KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   7   ,   51  ,   43  ,   21  ,   411 ,   887 ,   1303    ,   3389    ,   6653    ,   9265    ,0 };
            const std::uint32_t dim1734KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   3   ,   7   ,   43  ,   197 ,   151 ,   977 ,   717 ,   2293    ,   3135    ,   5223    ,0 };
            const std::uint32_t dim1735KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   23  ,   49  ,   23  ,   105 ,   279 ,   401 ,   1309    ,   3485    ,   4305    ,   13181   ,0 };
            const std::uint32_t dim1736KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   23  ,   15  ,   89  ,   171 ,   237 ,   513 ,   369 ,   3731    ,   4753    ,   4655    ,0 };
            const std::uint32_t dim1737KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   3   ,   35  ,   49  ,   211 ,   353 ,   843 ,   705 ,   2237    ,   7843    ,   9009    ,0 };
            const std::uint32_t dim1738KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   29  ,   25  ,   63  ,   29  ,   369 ,   777 ,   477 ,   547 ,   6575    ,   13769   ,0 };
            const std::uint32_t dim1739KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   3   ,   5   ,   101 ,   107 ,   11  ,   817 ,   413 ,   3241    ,   6275    ,   4035    ,0 };
            const std::uint32_t dim1740KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   21  ,   17  ,   25  ,   113 ,   183 ,   159 ,   307 ,   447 ,   7881    ,   7399    ,0 };
            const std::uint32_t dim1741KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   7   ,   45  ,   39  ,   39  ,   111 ,   191 ,   151 ,   267 ,   7133    ,   5557    ,0 };
            const std::uint32_t dim1742KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   27  ,   39  ,   29  ,   59  ,   141 ,   835 ,   1307    ,   1007    ,   2101    ,   7675    ,0 };
            const std::uint32_t dim1743KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   9   ,   15  ,   65  ,   47  ,   371 ,   385 ,   683 ,   3495    ,   711 ,   3963    ,0 };
            const std::uint32_t dim1744KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   5   ,   59  ,   81  ,   9   ,   23  ,   885 ,   291 ,   2349    ,   5495    ,   12985   ,0 };
            const std::uint32_t dim1745KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   21  ,   49  ,   99  ,   101 ,   447 ,   289 ,   659 ,   1061    ,   5771    ,   7591    ,0 };
            const std::uint32_t dim1746KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   5   ,   11  ,   13  ,   255 ,   7   ,   775 ,   1919    ,   1965    ,   7069    ,   10379   ,0 };
            const std::uint32_t dim1747KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   29  ,   23  ,   61  ,   183 ,   117 ,   817 ,   113 ,   1665    ,   2349    ,   305 ,0 };
            const std::uint32_t dim1748KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   25  ,   9   ,   97  ,   161 ,   361 ,   33  ,   1781    ,   3717    ,   6319    ,   13199   ,0 };
            const std::uint32_t dim1749KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   21  ,   63  ,   85  ,   225 ,   447 ,   169 ,   1601    ,   2359    ,   8087    ,   2609    ,0 };
            const std::uint32_t dim1750KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   1   ,   11  ,   1   ,   173 ,   345 ,   217 ,   1131    ,   493 ,   4613    ,   9223    ,0 };
            const std::uint32_t dim1751KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   5   ,   51  ,   55  ,   235 ,   129 ,   451 ,   1191    ,   2065    ,   6781    ,   9135    ,0 };
            const std::uint32_t dim1752KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   27  ,   41  ,   123 ,   49  ,   495 ,   999 ,   1731    ,   1597    ,   7471    ,   1129    ,0 };
            const std::uint32_t dim1753KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   13  ,   3   ,   123 ,   83  ,   199 ,   325 ,   1521    ,   1023    ,   2703    ,   10915   ,0 };
            const std::uint32_t dim1754KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   15  ,   19  ,   45  ,   223 ,   17  ,   643 ,   661 ,   633 ,   6475    ,   10153   ,0 };
            const std::uint32_t dim1755KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   17  ,   21  ,   101 ,   137 ,   39  ,   975 ,   1003    ,   1419    ,   353 ,   11971   ,0 };
            const std::uint32_t dim1756KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   11  ,   37  ,   75  ,   87  ,   49  ,   535 ,   801 ,   1689    ,   8125    ,   12419   ,0 };
            const std::uint32_t dim1757KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   19  ,   11  ,   99  ,   97  ,   285 ,   641 ,   1485    ,   257 ,   5417    ,   8669    ,0 };
            const std::uint32_t dim1758KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   21  ,   53  ,   19  ,   61  ,   223 ,   917 ,   931 ,   1779    ,   5859    ,   3111    ,0 };
            const std::uint32_t dim1759KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   25  ,   17  ,   55  ,   227 ,   61  ,   953 ,   255 ,   3939    ,   2523    ,   2119    ,0 };
            const std::uint32_t dim1760KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   23  ,   43  ,   111 ,   21  ,   263 ,   399 ,   723 ,   1067    ,   3633    ,   4165    ,0 };
            const std::uint32_t dim1761KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   31  ,   29  ,   69  ,   135 ,   105 ,   839 ,   1077    ,   1479    ,   643 ,   1063    ,0 };
            const std::uint32_t dim1762KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   23  ,   29  ,   51  ,   235 ,   287 ,   941 ,   393 ,   2241    ,   1601    ,   4629    ,0 };
            const std::uint32_t dim1763KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   1   ,   7   ,   47  ,   119 ,   369 ,   789 ,   1943    ,   3417    ,   4073    ,   7495    ,0 };
            const std::uint32_t dim1764KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   21  ,   37  ,   25  ,   217 ,   267 ,   275 ,   903 ,   865 ,   6251    ,   1323    ,0 };
            const std::uint32_t dim1765KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   13  ,   61  ,   77  ,   181 ,   479 ,   1003    ,   335 ,   2917    ,   1133    ,   14321   ,0 };
            const std::uint32_t dim1766KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   9   ,   53  ,   47  ,   197 ,   257 ,   823 ,   421 ,   2465    ,   4333    ,   3841    ,0 };
            const std::uint32_t dim1767KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   23  ,   17  ,   83  ,   131 ,   427 ,   25  ,   319 ,   517 ,   4109    ,   15841   ,0 };
            const std::uint32_t dim1768KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   7   ,   25  ,   105 ,   63  ,   117 ,   173 ,   909 ,   2731    ,   877 ,   1095    ,0 };
            const std::uint32_t dim1769KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   29  ,   17  ,   125 ,   45  ,   269 ,   681 ,   1389    ,   283 ,   7217    ,   15315   ,0 };
            const std::uint32_t dim1770KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   3   ,   59  ,   29  ,   177 ,   191 ,   803 ,   809 ,   131 ,   857 ,   16213   ,0 };
            const std::uint32_t dim1771KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   15  ,   21  ,   41  ,   177 ,   245 ,   543 ,   761 ,   2423    ,   1381    ,   1125    ,0 };
            const std::uint32_t dim1772KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   31  ,   5   ,   121 ,   183 ,   477 ,   143 ,   559 ,   765 ,   703 ,   12255   ,0 };
            const std::uint32_t dim1773KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   21  ,   23  ,   127 ,   227 ,   331 ,   963 ,   333 ,   2101    ,   2215    ,   10107   ,0 };
            const std::uint32_t dim1774KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   1   ,   47  ,   53  ,   189 ,   331 ,   587 ,   1417    ,   731 ,   4317    ,   11629   ,0 };
            const std::uint32_t dim1775KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   11  ,   21  ,   45  ,   109 ,   455 ,   347 ,   1483    ,   2589    ,   6933    ,   8343    ,0 };
            const std::uint32_t dim1776KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   5   ,   31  ,   45  ,   85  ,   253 ,   729 ,   111 ,   3315    ,   3183    ,   12847   ,0 };
            const std::uint32_t dim1777KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   25  ,   5   ,   3   ,   219 ,   263 ,   517 ,   247 ,   2303    ,   2709    ,   11973   ,0 };
            const std::uint32_t dim1778KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   21  ,   39  ,   115 ,   231 ,   5   ,   451 ,   1503    ,   1527    ,   4071    ,   5879    ,0 };
            const std::uint32_t dim1779KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   23  ,   31  ,   15  ,   61  ,   313 ,   83  ,   49  ,   1377    ,   7029    ,   14187   ,0 };
            const std::uint32_t dim1780KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   29  ,   7   ,   117 ,   111 ,   493 ,   159 ,   513 ,   3841    ,   7011    ,   14723   ,0 };
            const std::uint32_t dim1781KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   21  ,   15  ,   3   ,   139 ,   463 ,   1023    ,   1301    ,   243 ,   5105    ,   2259    ,0 };
            const std::uint32_t dim1782KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   5   ,   3   ,   119 ,   111 ,   447 ,   75  ,   1161    ,   1917    ,   345 ,   557 ,0 };
            const std::uint32_t dim1783KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   25  ,   21  ,   87  ,   93  ,   237 ,   921 ,   475 ,   2555    ,   4105    ,   5691    ,0 };
            const std::uint32_t dim1784KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   29  ,   51  ,   5   ,   73  ,   471 ,   421 ,   861 ,   3833    ,   2531    ,   1059    ,0 };
            const std::uint32_t dim1785KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   3   ,   11  ,   101 ,   35  ,   271 ,   981 ,   1661    ,   1629    ,   7321    ,   1335    ,0 };
            const std::uint32_t dim1786KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   9   ,   37  ,   9   ,   127 ,   45  ,   215 ,   611 ,   1193    ,   659 ,   5975    ,0 };
            const std::uint32_t dim1787KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   31  ,   31  ,   21  ,   167 ,   415 ,   513 ,   1917    ,   829 ,   1161    ,   3585    ,0 };
            const std::uint32_t dim1788KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   19  ,   23  ,   49  ,   55  ,   169 ,   351 ,   1389    ,   3251    ,   5001    ,   13445   ,0 };
            const std::uint32_t dim1789KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   3   ,   3   ,   113 ,   193 ,   391 ,   851 ,   681 ,   2961    ,   7239    ,   12837   ,0 };
            const std::uint32_t dim1790KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   5   ,   43  ,   71  ,   1   ,   347 ,   635 ,   1123    ,   3399    ,   2087    ,   8209    ,0 };
            const std::uint32_t dim1791KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   23  ,   7   ,   59  ,   115 ,   139 ,   311 ,   893 ,   2421    ,   405 ,   6541    ,0 };
            const std::uint32_t dim1792KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   25  ,   23  ,   127 ,   135 ,   199 ,   661 ,   7   ,   3279    ,   91  ,   11879   ,0 };
            const std::uint32_t dim1793KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   19  ,   37  ,   33  ,   159 ,   3   ,   425 ,   379 ,   1321    ,   369 ,   13125   ,0 };
            const std::uint32_t dim1794KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   7   ,   17  ,   47  ,   47  ,   167 ,   909 ,   403 ,   95  ,   7861    ,   231 ,0 };
            const std::uint32_t dim1795KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   15  ,   5   ,   69  ,   179 ,   229 ,   597 ,   1743    ,   467 ,   1859    ,   2059    ,0 };
            const std::uint32_t dim1796KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   5   ,   63  ,   109 ,   191 ,   271 ,   281 ,   907 ,   489 ,   5863    ,   12697   ,0 };
            const std::uint32_t dim1797KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   31  ,   1   ,   67  ,   81  ,   3   ,   755 ,   1839    ,   1481    ,   4691    ,   14549   ,0 };
            const std::uint32_t dim1798KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   17  ,   13  ,   59  ,   23  ,   85  ,   951 ,   1259    ,   363 ,   5479    ,   10705   ,0 };
            const std::uint32_t dim1799KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   11  ,   61  ,   111 ,   109 ,   361 ,   483 ,   1691    ,   1039    ,   3777    ,   14613   ,0 };
            const std::uint32_t dim1800KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   29  ,   55  ,   101 ,   55  ,   407 ,   61  ,   607 ,   829 ,   8011    ,   14021   ,0 };
            const std::uint32_t dim1801KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   1   ,   39  ,   29  ,   19  ,   389 ,   85  ,   313 ,   1123    ,   1303    ,   11535   ,0 };
            const std::uint32_t dim1802KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   5   ,   45  ,   47  ,   139 ,   165 ,   937 ,   1677    ,   2973    ,   501 ,   4387    ,0 };
            const std::uint32_t dim1803KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   5   ,   55  ,   89  ,   235 ,   29  ,   75  ,   1839    ,   801 ,   5753    ,   4409    ,0 };
            const std::uint32_t dim1804KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   7   ,   41  ,   7   ,   185 ,   297 ,   661 ,   1955    ,   2193    ,   6001    ,   12349   ,0 };
            const std::uint32_t dim1805KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   27  ,   47  ,   7   ,   7   ,   183 ,   725 ,   1511    ,   3021    ,   6091    ,   10567   ,0 };
            const std::uint32_t dim1806KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   21  ,   7   ,   79  ,   133 ,   307 ,   759 ,   369 ,   2779    ,   7629    ,   16191   ,0 };
            const std::uint32_t dim1807KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   5   ,   47  ,   15  ,   141 ,   293 ,   339 ,   1471    ,   127 ,   5805    ,   5543    ,0 };
            const std::uint32_t dim1808KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   31  ,   7   ,   125 ,   27  ,   511 ,   549 ,   619 ,   743 ,   3471    ,   8595    ,0 };
            const std::uint32_t dim1809KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   15  ,   9   ,   25  ,   35  ,   161 ,   691 ,   659 ,   909 ,   969 ,   9285    ,0 };
            const std::uint32_t dim1810KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   31  ,   17  ,   59  ,   255 ,   281 ,   7   ,   1075    ,   2561    ,   6883    ,   8193    ,0 };
            const std::uint32_t dim1811KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   9   ,   15  ,   83  ,   253 ,   415 ,   601 ,   417 ,   3999    ,   7513    ,   3663    ,0 };
            const std::uint32_t dim1812KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   11  ,   25  ,   109 ,   135 ,   41  ,   5   ,   697 ,   1703    ,   8175    ,   11369   ,0 };
            const std::uint32_t dim1813KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   7   ,   39  ,   1   ,   253 ,   373 ,   273 ,   857 ,   401 ,   1609    ,   2391    ,0 };
            const std::uint32_t dim1814KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   1   ,   61  ,   85  ,   213 ,   183 ,   695 ,   523 ,   1237    ,   5485    ,   6843    ,0 };
            const std::uint32_t dim1815KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   17  ,   41  ,   125 ,   209 ,   285 ,   823 ,   857 ,   31  ,   839 ,   10847   ,0 };
            const std::uint32_t dim1816KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   31  ,   23  ,   65  ,   75  ,   243 ,   471 ,   669 ,   539 ,   3949    ,   14913   ,0 };
            const std::uint32_t dim1817KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   25  ,   23  ,   109 ,   19  ,   89  ,   983 ,   193 ,   1433    ,   6401    ,   663 ,0 };
            const std::uint32_t dim1818KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   25  ,   9   ,   93  ,   13  ,   133 ,   561 ,   1343    ,   4049    ,   6221    ,   3137    ,0 };
            const std::uint32_t dim1819KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   31  ,   47  ,   105 ,   225 ,   231 ,   75  ,   187 ,   963 ,   3339    ,   9705    ,0 };
            const std::uint32_t dim1820KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   9   ,   31  ,   21  ,   221 ,   309 ,   791 ,   2011    ,   241 ,   5507    ,   11579   ,0 };
            const std::uint32_t dim1821KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   1   ,   19  ,   53  ,   239 ,   305 ,   151 ,   53  ,   873 ,   5235    ,   13357   ,0 };
            const std::uint32_t dim1822KuoInit[]        =   {   1   ,   1   ,   5   ,   15  ,   13  ,   27  ,   23  ,   255 ,   75  ,   435 ,   209 ,   2001    ,   2529    ,   5363    ,0 };
            const std::uint32_t dim1823KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   25  ,   53  ,   71  ,   203 ,   259 ,   403 ,   1535    ,   3381    ,   6791    ,   16061   ,0 };
            const std::uint32_t dim1824KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   29  ,   5   ,   93  ,   5   ,   179 ,   813 ,   1569    ,   2875    ,   7855    ,   13863   ,0 };
            const std::uint32_t dim1825KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   1   ,   13  ,   97  ,   125 ,   479 ,   209 ,   1659    ,   2997    ,   3405    ,   9707    ,0 };
            const std::uint32_t dim1826KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   5   ,   43  ,   15  ,   29  ,   317 ,   317 ,   1317    ,   3177    ,   519 ,   8115    ,0 };
            const std::uint32_t dim1827KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   1   ,   55  ,   49  ,   145 ,   415 ,   785 ,   1489    ,   1217    ,   3829    ,   10207   ,0 };
            const std::uint32_t dim1828KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   17  ,   5   ,   99  ,   235 ,   277 ,   921 ,   71  ,   343 ,   2935    ,   12495   ,0 };
            const std::uint32_t dim1829KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   25  ,   11  ,   11  ,   69  ,   209 ,   543 ,   17  ,   1489    ,   8119    ,   3557    ,0 };
            const std::uint32_t dim1830KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   29  ,   43  ,   125 ,   87  ,   11  ,   947 ,   1709    ,   17  ,   3467    ,   3339    ,0 };
            const std::uint32_t dim1831KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   23  ,   47  ,   113 ,   185 ,   75  ,   523 ,   1253    ,   859 ,   6359    ,   15563   ,0 };
            const std::uint32_t dim1832KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   1   ,   25  ,   25  ,   23  ,   267 ,   275 ,   1751    ,   3237    ,   3967    ,   9943    ,0 };
            const std::uint32_t dim1833KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   7   ,   35  ,   43  ,   151 ,   489 ,   97  ,   143 ,   257 ,   771 ,   8181    ,0 };
            const std::uint32_t dim1834KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   19  ,   11  ,   17  ,   23  ,   425 ,   869 ,   525 ,   95  ,   2217    ,   3931    ,0 };
            const std::uint32_t dim1835KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   3   ,   19  ,   77  ,   219 ,   501 ,   23  ,   773 ,   2421    ,   3713    ,   6209    ,0 };
            const std::uint32_t dim1836KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   7   ,   1   ,   33  ,   35  ,   229 ,   329 ,   201 ,   291 ,   4165    ,   16059   ,0 };
            const std::uint32_t dim1837KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   17  ,   23  ,   107 ,   23  ,   3   ,   673 ,   609 ,   2931    ,   5989    ,   3133    ,0 };
            const std::uint32_t dim1838KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   17  ,   59  ,   31  ,   63  ,   111 ,   287 ,   407 ,   769 ,   2381    ,   2203    ,0 };
            const std::uint32_t dim1839KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   3   ,   51  ,   105 ,   57  ,   313 ,   847 ,   261 ,   2697    ,   749 ,   15419   ,0 };
            const std::uint32_t dim1840KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   3   ,   21  ,   65  ,   139 ,   363 ,   21  ,   1889    ,   1007    ,   6969    ,   3609    ,0 };
            const std::uint32_t dim1841KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   17  ,   51  ,   73  ,   121 ,   481 ,   339 ,   1409    ,   131 ,   2005    ,   11847   ,0 };
            const std::uint32_t dim1842KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   31  ,   13  ,   107 ,   253 ,   125 ,   973 ,   1027    ,   3473    ,   6883    ,   15061   ,0 };
            const std::uint32_t dim1843KuoInit[]        =   {   1   ,   3   ,   1   ,   5   ,   25  ,   17  ,   11  ,   255 ,   209 ,   35  ,   1987    ,   2275    ,   2327    ,   16079   ,0 };
            const std::uint32_t dim1844KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   3   ,   1   ,   25  ,   93  ,   397 ,   467 ,   1895    ,   3199    ,   1861    ,   10943   ,0 };
            const std::uint32_t dim1845KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   23  ,   27  ,   13  ,   211 ,   299 ,   117 ,   1689    ,   457 ,   6335    ,   11921   ,0 };
            const std::uint32_t dim1846KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   9   ,   59  ,   49  ,   177 ,   81  ,   913 ,   429 ,   2705    ,   339 ,   9347    ,0 };
            const std::uint32_t dim1847KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   1   ,   61  ,   81  ,   143 ,   455 ,   311 ,   381 ,   235 ,   2537    ,   12511   ,0 };
            const std::uint32_t dim1848KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   7   ,   33  ,   103 ,   137 ,   377 ,   717 ,   851 ,   2939    ,   303 ,   11175   ,0 };
            const std::uint32_t dim1849KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   25  ,   59  ,   15  ,   43  ,   71  ,   767 ,   47  ,   3425    ,   7015    ,   14431   ,0 };
            const std::uint32_t dim1850KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   25  ,   37  ,   37  ,   39  ,   279 ,   491 ,   1483    ,   2633    ,   3791    ,   14311   ,0 };
            const std::uint32_t dim1851KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   29  ,   63  ,   83  ,   89  ,   339 ,   923 ,   455 ,   965 ,   7339    ,   16383   ,0 };
            const std::uint32_t dim1852KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   9   ,   33  ,   7   ,   63  ,   385 ,   717 ,   1449    ,   2705    ,   6233    ,   10753   ,0 };
            const std::uint32_t dim1853KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   15  ,   13  ,   11  ,   181 ,   271 ,   749 ,   1825    ,   875 ,   2497    ,   12999   ,0 };
            const std::uint32_t dim1854KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   13  ,   49  ,   35  ,   65  ,   467 ,   259 ,   429 ,   549 ,   5481    ,   11343   ,0 };
            const std::uint32_t dim1855KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   17  ,   55  ,   125 ,   217 ,   91  ,   495 ,   133 ,   1985    ,   4871    ,   3415    ,0 };
            const std::uint32_t dim1856KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   11  ,   33  ,   29  ,   53  ,   253 ,   935 ,   1919    ,   2607    ,   3205    ,   819 ,0 };
            const std::uint32_t dim1857KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   25  ,   23  ,   127 ,   151 ,   39  ,   583 ,   985 ,   715 ,   765 ,   16343   ,0 };
            const std::uint32_t dim1858KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   7   ,   21  ,   127 ,   179 ,   239 ,   353 ,   221 ,   531 ,   5147    ,   6699    ,0 };
            const std::uint32_t dim1859KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   7   ,   63  ,   91  ,   99  ,   495 ,   111 ,   1295    ,   2609    ,   6389    ,   7719    ,0 };
            const std::uint32_t dim1860KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   9   ,   27  ,   123 ,   171 ,   155 ,   683 ,   1209    ,   2081    ,   2823    ,   1007    ,0 };
            const std::uint32_t dim1861KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   25  ,   45  ,   91  ,   93  ,   329 ,   961 ,   1843    ,   2637    ,   4333    ,   8359    ,0 };
            const std::uint32_t dim1862KuoInit[]        =   {   1   ,   3   ,   1   ,   5   ,   9   ,   5   ,   73  ,   221 ,   71  ,   951 ,   1175    ,   2489    ,   4565    ,   7221    ,0 };
            const std::uint32_t dim1863KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   31  ,   33  ,   67  ,   127 ,   427 ,   487 ,   239 ,   787 ,   1731    ,   11867   ,0 };
            const std::uint32_t dim1864KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   17  ,   23  ,   5   ,   201 ,   175 ,   661 ,   1381    ,   3017    ,   4237    ,   14403   ,0 };
            const std::uint32_t dim1865KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   31  ,   7   ,   39  ,   141 ,   299 ,   237 ,   281 ,   3057    ,   5553    ,   11339   ,0 };
            const std::uint32_t dim1866KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   25  ,   49  ,   51  ,   135 ,   363 ,   377 ,   1767    ,   4069    ,   3001    ,   7111    ,0 };
            const std::uint32_t dim1867KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   29  ,   7   ,   91  ,   145 ,   263 ,   581 ,   35  ,   3101    ,   6227    ,   12007   ,   30807   ,0 };
            const std::uint32_t dim1868KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   11  ,   41  ,   61  ,   135 ,   61  ,   501 ,   189 ,   1923    ,   129 ,   14563   ,   12247   ,0 };
            const std::uint32_t dim1869KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   17  ,   45  ,   53  ,   5   ,   199 ,   165 ,   859 ,   771 ,   4553    ,   14723   ,   17293   ,0 };
            const std::uint32_t dim1870KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   27  ,   57  ,   41  ,   3   ,   437 ,   543 ,   1291    ,   1083    ,   1311    ,   4407    ,   9107    ,0 };
            const std::uint32_t dim1871KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   19  ,   23  ,   17  ,   251 ,   267 ,   575 ,   1675    ,   775 ,   1281    ,   12389   ,   11781   ,0 };
            const std::uint32_t dim1872KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   19  ,   41  ,   69  ,   45  ,   113 ,   683 ,   1843    ,   1217    ,   1075    ,   7141    ,   11259   ,0 };
            const std::uint32_t dim1873KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   21  ,   45  ,   75  ,   199 ,   227 ,   717 ,   267 ,   3211    ,   5893    ,   6559    ,   16445   ,0 };
            const std::uint32_t dim1874KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   25  ,   19  ,   13  ,   3   ,   477 ,   511 ,   1607    ,   61  ,   5937    ,   6471    ,   4561    ,0 };
            const std::uint32_t dim1875KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   25  ,   9   ,   59  ,   209 ,   181 ,   671 ,   1473    ,   1863    ,   6835    ,   5915    ,   21573   ,0 };
            const std::uint32_t dim1876KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   31  ,   43  ,   91  ,   191 ,   505 ,   979 ,   1431    ,   1347    ,   1445    ,   9759    ,   31653   ,0 };
            const std::uint32_t dim1877KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   11  ,   63  ,   35  ,   1   ,   313 ,   863 ,   577 ,   3039    ,   5205    ,   5089    ,   20009   ,0 };
            const std::uint32_t dim1878KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   1   ,   27  ,   79  ,   21  ,   179 ,   187 ,   917 ,   1831    ,   1737    ,   2879    ,   5801    ,0 };
            const std::uint32_t dim1879KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   19  ,   51  ,   77  ,   201 ,   499 ,   345 ,   617 ,   33  ,   543 ,   6925    ,   5945    ,0 };
            const std::uint32_t dim1880KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   19  ,   49  ,   67  ,   51  ,   181 ,   1015    ,   1159    ,   2109    ,   879 ,   10257   ,   23207   ,0 };
            const std::uint32_t dim1881KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   19  ,   29  ,   7   ,   111 ,   365 ,   373 ,   1309    ,   3633    ,   5951    ,   2597    ,   27947   ,0 };
            const std::uint32_t dim1882KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   21  ,   27  ,   85  ,   71  ,   149 ,   665 ,   1499    ,   4025    ,   3939    ,   8947    ,   15811   ,0 };
            const std::uint32_t dim1883KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   25  ,   47  ,   77  ,   99  ,   105 ,   739 ,   1077    ,   3145    ,   7859    ,   1925    ,   16765   ,0 };
            const std::uint32_t dim1884KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   25  ,   9   ,   113 ,   105 ,   309 ,   397 ,   1687    ,   1171    ,   455 ,   3183    ,   12487   ,0 };
            const std::uint32_t dim1885KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   7   ,   9   ,   51  ,   239 ,   469 ,   415 ,   1895    ,   89  ,   4243    ,   967 ,   7113    ,0 };
            const std::uint32_t dim1886KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   23  ,   41  ,   39  ,   247 ,   115 ,   541 ,   1461    ,   2907    ,   2175    ,   3133    ,   3171    ,0 };
            const std::uint32_t dim1887KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   7   ,   53  ,   43  ,   187 ,   213 ,   549 ,   947 ,   3695    ,   3931    ,   699 ,   21299   ,0 };
            const std::uint32_t dim1888KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   15  ,   9   ,   9   ,   3   ,   175 ,   231 ,   1529    ,   337 ,   5333    ,   6945    ,   1359    ,0 };
            const std::uint32_t dim1889KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   13  ,   25  ,   123 ,   231 ,   389 ,   351 ,   1695    ,   2959    ,   1037    ,   2103    ,   327 ,0 };
            const std::uint32_t dim1890KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   9   ,   31  ,   19  ,   149 ,   1   ,   477 ,   1819    ,   3487    ,   3299    ,   8835    ,   10351   ,0 };
            const std::uint32_t dim1891KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   9   ,   37  ,   123 ,   93  ,   267 ,   481 ,   901 ,   3927    ,   7295    ,   13251   ,   22551   ,0 };
            const std::uint32_t dim1892KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   21  ,   13  ,   127 ,   173 ,   459 ,   169 ,   1511    ,   1649    ,   5431    ,   8637    ,   3601    ,0 };
            const std::uint32_t dim1893KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   29  ,   3   ,   101 ,   135 ,   159 ,   295 ,   1767    ,   3089    ,   3753    ,   4969    ,   21523   ,0 };
            const std::uint32_t dim1894KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   3   ,   9   ,   45  ,   143 ,   301 ,   307 ,   191 ,   3337    ,   6721    ,   12095   ,   7017    ,0 };
            const std::uint32_t dim1895KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   17  ,   25  ,   55  ,   37  ,   379 ,   725 ,   1079    ,   311 ,   2853    ,   15097   ,   31857   ,0 };
            const std::uint32_t dim1896KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   19  ,   57  ,   39  ,   99  ,   39  ,   283 ,   425 ,   2447    ,   2077    ,   815 ,   7639    ,0 };
            const std::uint32_t dim1897KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   11  ,   5   ,   17  ,   83  ,   231 ,   535 ,   35  ,   2773    ,   4127    ,   9951    ,   5773    ,0 };
            const std::uint32_t dim1898KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   7   ,   47  ,   87  ,   119 ,   291 ,   523 ,   1325    ,   1757    ,   2377    ,   6481    ,   7901    ,0 };
            const std::uint32_t dim1899KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   25  ,   21  ,   29  ,   87  ,   241 ,   241 ,   1273    ,   2813    ,   2011    ,   8549    ,   7253    ,0 };
            const std::uint32_t dim1900KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   19  ,   35  ,   119 ,   227 ,   483 ,   1015    ,   685 ,   1149    ,   4823    ,   4113    ,   7169    ,0 };
            const std::uint32_t dim1901KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   11  ,   59  ,   125 ,   99  ,   255 ,   149 ,   829 ,   2869    ,   7927    ,   6779    ,   31949   ,0 };
            const std::uint32_t dim1902KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   3   ,   49  ,   21  ,   111 ,   219 ,   33  ,   91  ,   1585    ,   303 ,   14931   ,   11777   ,0 };
            const std::uint32_t dim1903KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   3   ,   47  ,   27  ,   227 ,   477 ,   891 ,   1281    ,   1927    ,   7325    ,   14075   ,   26633   ,0 };
            const std::uint32_t dim1904KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   5   ,   29  ,   25  ,   23  ,   223 ,   65  ,   1511    ,   2563    ,   7825    ,   7339    ,   32095   ,0 };
            const std::uint32_t dim1905KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   3   ,   29  ,   49  ,   83  ,   317 ,   513 ,   755 ,   1339    ,   4829    ,   6213    ,   29055   ,0 };
            const std::uint32_t dim1906KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   23  ,   23  ,   97  ,   27  ,   379 ,   183 ,   933 ,   3431    ,   797 ,   9655    ,   32061   ,0 };
            const std::uint32_t dim1907KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   29  ,   61  ,   31  ,   75  ,   331 ,   487 ,   229 ,   2319    ,   1385    ,   14697   ,   17081   ,0 };
            const std::uint32_t dim1908KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   19  ,   1   ,   43  ,   27  ,   433 ,   751 ,   1283    ,   559 ,   7941    ,   7385    ,   13809   ,0 };
            const std::uint32_t dim1909KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   19  ,   37  ,   97  ,   219 ,   217 ,   39  ,   1969    ,   1909    ,   2895    ,   749 ,   27607   ,0 };
            const std::uint32_t dim1910KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   25  ,   17  ,   79  ,   213 ,   321 ,   73  ,   533 ,   3773    ,   6989    ,   10183   ,   20179   ,0 };
            const std::uint32_t dim1911KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   15  ,   51  ,   71  ,   161 ,   107 ,   531 ,   461 ,   15  ,   2887    ,   13271   ,   24273   ,0 };
            const std::uint32_t dim1912KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   29  ,   21  ,   119 ,   53  ,   207 ,   471 ,   987 ,   1771    ,   7259    ,   4377    ,   15405   ,0 };
            const std::uint32_t dim1913KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   3   ,   5   ,   7   ,   189 ,   231 ,   181 ,   751 ,   1   ,   225 ,   12575   ,   4853    ,0 };
            const std::uint32_t dim1914KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   1   ,   51  ,   35  ,   239 ,   145 ,   827 ,   1169    ,   3671    ,   7585    ,   4593    ,   4433    ,0 };
            const std::uint32_t dim1915KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   15  ,   55  ,   43  ,   157 ,   13  ,   517 ,   1669    ,   25  ,   1175    ,   3971    ,   11165   ,0 };
            const std::uint32_t dim1916KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   15  ,   37  ,   33  ,   155 ,   243 ,   375 ,   947 ,   1869    ,   2693    ,   5191    ,   9865    ,0 };
            const std::uint32_t dim1917KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   15  ,   57  ,   73  ,   15  ,   389 ,   341 ,   207 ,   3249    ,   439 ,   5975    ,   23461   ,0 };
            const std::uint32_t dim1918KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   17  ,   3   ,   35  ,   245 ,   349 ,   915 ,   1221    ,   1495    ,   5525    ,   10223   ,   29109   ,0 };
            const std::uint32_t dim1919KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   19  ,   17  ,   39  ,   49  ,   159 ,   163 ,   419 ,   1117    ,   7947    ,   7177    ,   10945   ,0 };
            const std::uint32_t dim1920KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   23  ,   35  ,   31  ,   33  ,   325 ,   565 ,   1951    ,   745 ,   6867    ,   13121   ,   25831   ,0 };
            const std::uint32_t dim1921KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   27  ,   11  ,   89  ,   191 ,   233 ,   57  ,   1621    ,   2167    ,   7155    ,   15613   ,   14111   ,0 };
            const std::uint32_t dim1922KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   31  ,   49  ,   3   ,   245 ,   51  ,   173 ,   1809    ,   379 ,   8085    ,   5125    ,   10279   ,0 };
            const std::uint32_t dim1923KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   29  ,   59  ,   37  ,   197 ,   377 ,   5   ,   1851    ,   3685    ,   3537    ,   1897    ,   24257   ,0 };
            const std::uint32_t dim1924KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   13  ,   9   ,   11  ,   19  ,   377 ,   435 ,   869 ,   497 ,   8181    ,   3411    ,   4415    ,0 };
            const std::uint32_t dim1925KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   7   ,   21  ,   51  ,   115 ,   435 ,   9   ,   1099    ,   987 ,   1633    ,   7689    ,   19131   ,0 };
            const std::uint32_t dim1926KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   17  ,   59  ,   93  ,   131 ,   17  ,   637 ,   211 ,   2759    ,   3059    ,   4691    ,   10225   ,0 };
            const std::uint32_t dim1927KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   5   ,   35  ,   55  ,   49  ,   425 ,   395 ,   615 ,   1505    ,   1477    ,   6689    ,   28435   ,0 };
            const std::uint32_t dim1928KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   27  ,   1   ,   43  ,   53  ,   375 ,   657 ,   1307    ,   1869    ,   415 ,   1143    ,   16961   ,0 };
            const std::uint32_t dim1929KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   13  ,   27  ,   111 ,   113 ,   459 ,   149 ,   139 ,   79  ,   5031    ,   15165   ,   443 ,0 };
            const std::uint32_t dim1930KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   9   ,   45  ,   35  ,   217 ,   259 ,   523 ,   601 ,   499 ,   7683    ,   1447    ,   5267    ,0 };
            const std::uint32_t dim1931KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   3   ,   51  ,   101 ,   191 ,   469 ,   435 ,   883 ,   343 ,   1897    ,   5245    ,   1037    ,0 };
            const std::uint32_t dim1932KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   19  ,   21  ,   109 ,   105 ,   363 ,   409 ,   1651    ,   3739    ,   339 ,   12915   ,   31603   ,0 };
            const std::uint32_t dim1933KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   9   ,   7   ,   65  ,   193 ,   447 ,   829 ,   1123    ,   2431    ,   3357    ,   6687    ,   26903   ,0 };
            const std::uint32_t dim1934KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   11  ,   9   ,   69  ,   147 ,   331 ,   657 ,   1589    ,   3417    ,   5805    ,   8673    ,   2517    ,0 };
            const std::uint32_t dim1935KuoInit[]        =   {   1   ,   3   ,   1   ,   5   ,   23  ,   45  ,   59  ,   53  ,   285 ,   711 ,   1447    ,   927 ,   8005    ,   3513    ,   18147   ,0 };
            const std::uint32_t dim1936KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   9   ,   15  ,   17  ,   85  ,   165 ,   923 ,   915 ,   3263    ,   1103    ,   9445    ,   15371   ,0 };
            const std::uint32_t dim1937KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   13  ,   13  ,   33  ,   249 ,   501 ,   495 ,   1771    ,   1305    ,   2821    ,   9405    ,   7193    ,0 };
            const std::uint32_t dim1938KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   9   ,   11  ,   23  ,   5   ,   359 ,   977 ,   613 ,   2163    ,   4511    ,   7901    ,   1609    ,0 };
            const std::uint32_t dim1939KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   29  ,   29  ,   73  ,   69  ,   155 ,   863 ,   243 ,   2705    ,   4005    ,   11249   ,   13983   ,0 };
            const std::uint32_t dim1940KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   9   ,   15  ,   75  ,   171 ,   213 ,   931 ,   1613    ,   3801    ,   4617    ,   3929    ,   24787   ,0 };
            const std::uint32_t dim1941KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   19  ,   35  ,   107 ,   251 ,   121 ,   455 ,   2027    ,   2323    ,   4297    ,   7949    ,   12043   ,0 };
            const std::uint32_t dim1942KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   3   ,   59  ,   13  ,   151 ,   161 ,   615 ,   1427    ,   2469    ,   3211    ,   6601    ,   26829   ,0 };
            const std::uint32_t dim1943KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   31  ,   1   ,   41  ,   247 ,   225 ,   65  ,   1751    ,   3557    ,   935 ,   16115   ,   3009    ,0 };
            const std::uint32_t dim1944KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   31  ,   3   ,   31  ,   39  ,   279 ,   213 ,   1141    ,   371 ,   7529    ,   12485   ,   6585    ,0 };
            const std::uint32_t dim1945KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   13  ,   31  ,   121 ,   185 ,   171 ,   991 ,   147 ,   1913    ,   475 ,   15155   ,   2427    ,0 };
            const std::uint32_t dim1946KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   7   ,   13  ,   59  ,   127 ,   175 ,   717 ,   759 ,   3949    ,   4229    ,   2091    ,   20267   ,0 };
            const std::uint32_t dim1947KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   21  ,   33  ,   45  ,   57  ,   1   ,   463 ,   1217    ,   1499    ,   269 ,   11159   ,   17175   ,0 };
            const std::uint32_t dim1948KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   21  ,   29  ,   51  ,   63  ,   299 ,   775 ,   239 ,   575 ,   1033    ,   3627    ,   12017   ,0 };
            const std::uint32_t dim1949KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   23  ,   35  ,   63  ,   197 ,   341 ,   775 ,   675 ,   1835    ,   4155    ,   7439    ,   1797    ,0 };
            const std::uint32_t dim1950KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   23  ,   57  ,   71  ,   181 ,   1   ,   95  ,   337 ,   1971    ,   5721    ,   15013   ,   3387    ,0 };
            const std::uint32_t dim1951KuoInit[]        =   {   1   ,   3   ,   1   ,   5   ,   31  ,   21  ,   33  ,   203 ,   463 ,   3   ,   1261    ,   555 ,   3847    ,   5653    ,   18155   ,0 };
            const std::uint32_t dim1952KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   27  ,   57  ,   57  ,   119 ,   213 ,   723 ,   1695    ,   2233    ,   1605    ,   8169    ,   28485   ,0 };
            const std::uint32_t dim1953KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   17  ,   35  ,   119 ,   167 ,   391 ,   111 ,   229 ,   695 ,   4209    ,   5457    ,   6729    ,0 };
            const std::uint32_t dim1954KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   5   ,   23  ,   5   ,   223 ,   89  ,   447 ,   2015    ,   3403    ,   1335    ,   15235   ,   20897   ,0 };
            const std::uint32_t dim1955KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   1   ,   63  ,   55  ,   233 ,   351 ,   323 ,   497 ,   1247    ,   2455    ,   2337    ,   17523   ,0 };
            const std::uint32_t dim1956KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   7   ,   21  ,   127 ,   207 ,   197 ,   479 ,   611 ,   3525    ,   2093    ,   2591    ,   21085   ,0 };
            const std::uint32_t dim1957KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   1   ,   37  ,   107 ,   199 ,   29  ,   995 ,   1857    ,   133 ,   1423    ,   9967    ,   11367   ,0 };
            const std::uint32_t dim1958KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   25  ,   25  ,   17  ,   155 ,   221 ,   539 ,   1895    ,   1909    ,   2921    ,   13107   ,   21681   ,0 };
            const std::uint32_t dim1959KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   25  ,   59  ,   45  ,   41  ,   401 ,   657 ,   2043    ,   1317    ,   8065    ,   11897   ,   4767    ,0 };
            const std::uint32_t dim1960KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   21  ,   29  ,   43  ,   125 ,   407 ,   851 ,   1421    ,   1101    ,   811 ,   9577    ,   27  ,0 };
            const std::uint32_t dim1961KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   25  ,   49  ,   65  ,   175 ,   319 ,   807 ,   1691    ,   357 ,   4015    ,   1059    ,   599 ,0 };
            const std::uint32_t dim1962KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   23  ,   5   ,   65  ,   79  ,   43  ,   665 ,   1931    ,   2143    ,   4577    ,   5905    ,   14917   ,0 };
            const std::uint32_t dim1963KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   5   ,   41  ,   121 ,   251 ,   395 ,   951 ,   795 ,   1589    ,   4027    ,   13671   ,   18787   ,0 };
            const std::uint32_t dim1964KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   3   ,   51  ,   57  ,   177 ,   63  ,   33  ,   1085    ,   1357    ,   5039    ,   2583    ,   2805    ,0 };
            const std::uint32_t dim1965KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   29  ,   53  ,   117 ,   225 ,   373 ,   1   ,   901 ,   3871    ,   2815    ,   9871    ,   7737    ,0 };
            const std::uint32_t dim1966KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   31  ,   61  ,   89  ,   253 ,   291 ,   829 ,   9   ,   1131    ,   4951    ,   14509   ,   23491   ,0 };
            const std::uint32_t dim1967KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   25  ,   43  ,   35  ,   63  ,   425 ,   757 ,   217 ,   821 ,   1453    ,   8413    ,   7745    ,0 };
            const std::uint32_t dim1968KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   7   ,   1   ,   41  ,   233 ,   235 ,   599 ,   833 ,   3637    ,   7005    ,   789 ,   27709   ,0 };
            const std::uint32_t dim1969KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   7   ,   57  ,   69  ,   115 ,   417 ,   99  ,   1435    ,   3119    ,   1655    ,   3515    ,   7273    ,0 };
            const std::uint32_t dim1970KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   9   ,   13  ,   33  ,   57  ,   179 ,   847 ,   289 ,   2213    ,   4635    ,   2349    ,   20203   ,0 };
            const std::uint32_t dim1971KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   1   ,   39  ,   63  ,   147 ,   277 ,   389 ,   575 ,   423 ,   4943    ,   4327    ,   29067   ,0 };
            const std::uint32_t dim1972KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   9   ,   9   ,   69  ,   167 ,   119 ,   591 ,   1679    ,   3543    ,   4517    ,   9263    ,   17957   ,0 };
            const std::uint32_t dim1973KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   25  ,   37  ,   127 ,   159 ,   391 ,   29  ,   329 ,   3477    ,   6513    ,   11971   ,   18791   ,0 };
            const std::uint32_t dim1974KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   25  ,   29  ,   49  ,   135 ,   387 ,   921 ,   391 ,   665 ,   6315    ,   16183   ,   553 ,0 };
            const std::uint32_t dim1975KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   27  ,   43  ,   43  ,   253 ,   9   ,   285 ,   1073    ,   2627    ,   7417    ,   3223    ,   2649    ,0 };
            const std::uint32_t dim1976KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   13  ,   57  ,   119 ,   37  ,   475 ,   471 ,   1145    ,   2709    ,   2115    ,   6507    ,   12393   ,0 };
            const std::uint32_t dim1977KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   17  ,   29  ,   117 ,   189 ,   319 ,   533 ,   1299    ,   1987    ,   4971    ,   15719   ,   19395   ,0 };
            const std::uint32_t dim1978KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   11  ,   63  ,   77  ,   245 ,   57  ,   9   ,   1285    ,   2069    ,   579 ,   5105    ,   13797   ,0 };
            const std::uint32_t dim1979KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   19  ,   49  ,   1   ,   241 ,   89  ,   519 ,   591 ,   3875    ,   1585    ,   7239    ,   25867   ,0 };
            const std::uint32_t dim1980KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   27  ,   47  ,   1   ,   143 ,   209 ,   695 ,   539 ,   3781    ,   6317    ,   14075   ,   27849   ,0 };
            const std::uint32_t dim1981KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   17  ,   3   ,   17  ,   201 ,   105 ,   771 ,   497 ,   735 ,   3517    ,   5207    ,   20897   ,0 };
            const std::uint32_t dim1982KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   3   ,   3   ,   103 ,   35  ,   421 ,   235 ,   1527    ,   3139    ,   2693    ,   9739    ,   63  ,0 };
            const std::uint32_t dim1983KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   21  ,   39  ,   101 ,   213 ,   205 ,   853 ,   1455    ,   39  ,   7917    ,   7893    ,   4627    ,0 };
            const std::uint32_t dim1984KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   13  ,   5   ,   9   ,   239 ,   129 ,   355 ,   809 ,   3413    ,   7535    ,   7063    ,   29149   ,0 };
            const std::uint32_t dim1985KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   19  ,   37  ,   125 ,   55  ,   495 ,   597 ,   735 ,   1729    ,   619 ,   12881   ,   22913   ,0 };
            const std::uint32_t dim1986KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   27  ,   31  ,   87  ,   65  ,   413 ,   421 ,   575 ,   2185    ,   4217    ,   12223   ,   22487   ,0 };
            const std::uint32_t dim1987KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   23  ,   51  ,   115 ,   221 ,   369 ,   27  ,   229 ,   613 ,   3739    ,   1425    ,   10927   ,0 };
            const std::uint32_t dim1988KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   23  ,   49  ,   73  ,   223 ,   139 ,   511 ,   899 ,   483 ,   7747    ,   7947    ,   32357   ,0 };
            const std::uint32_t dim1989KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   7   ,   31  ,   9   ,   119 ,   417 ,   723 ,   2033    ,   663 ,   5927    ,   1787    ,   12841   ,0 };
            const std::uint32_t dim1990KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   7   ,   5   ,   55  ,   201 ,   245 ,   221 ,   1447    ,   405 ,   447 ,   2447    ,   24331   ,0 };
            const std::uint32_t dim1991KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   9   ,   47  ,   33  ,   175 ,   187 ,   513 ,   1613    ,   2413    ,   4207    ,   6941    ,   2341    ,0 };
            const std::uint32_t dim1992KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   19  ,   33  ,   33  ,   181 ,   505 ,   923 ,   1923    ,   2471    ,   6499    ,   11243   ,   29653   ,0 };
            const std::uint32_t dim1993KuoInit[]        =   {   1   ,   1   ,   5   ,   15  ,   1   ,   49  ,   21  ,   15  ,   443 ,   565 ,   1955    ,   3299    ,   139 ,   14389   ,   28011   ,0 };
            const std::uint32_t dim1994KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   17  ,   27  ,   29  ,   65  ,   509 ,   867 ,   707 ,   2425    ,   7279    ,   15271   ,   18239   ,0 };
            const std::uint32_t dim1995KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   3   ,   1   ,   103 ,   79  ,   49  ,   909 ,   529 ,   1207    ,   231 ,   11181   ,   23319   ,0 };
            const std::uint32_t dim1996KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   13  ,   23  ,   33  ,   29  ,   189 ,   491 ,   129 ,   501 ,   2635    ,   2071    ,   18057   ,0 };
            const std::uint32_t dim1997KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   19  ,   1   ,   95  ,   185 ,   67  ,   251 ,   1017    ,   105 ,   3683    ,   9797    ,   24413   ,0 };
            const std::uint32_t dim1998KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   13  ,   35  ,   79  ,   213 ,   223 ,   1013    ,   1205    ,   1777    ,   1415    ,   5023    ,   15901   ,0 };
            const std::uint32_t dim1999KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   15  ,   13  ,   91  ,   57  ,   447 ,   897 ,   935 ,   1543    ,   5461    ,   5091    ,   12697   ,0 };
            const std::uint32_t dim2000KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   9   ,   61  ,   81  ,   147 ,   55  ,   121 ,   449 ,   2833    ,   2383    ,   12065   ,   19435   ,0 };
            const std::uint32_t dim2001KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   17  ,   27  ,   77  ,   203 ,   415 ,   489 ,   665 ,   21  ,   6453    ,   5069    ,   29629   ,0 };
            const std::uint32_t dim2002KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   7   ,   3   ,   33  ,   209 ,   85  ,   851 ,   367 ,   783 ,   309 ,   14821   ,   1217    ,0 };
            const std::uint32_t dim2003KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   5   ,   39  ,   15  ,   225 ,   241 ,   477 ,   999 ,   841 ,   4637    ,   5383    ,   18081   ,0 };
            const std::uint32_t dim2004KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   19  ,   49  ,   101 ,   115 ,   87  ,   781 ,   815 ,   2405    ,   2579    ,   15043   ,   31067   ,0 };
            const std::uint32_t dim2005KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   3   ,   57  ,   123 ,   191 ,   305 ,   999 ,   1091    ,   733 ,   3219    ,   891 ,   30495   ,0 };
            const std::uint32_t dim2006KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   27  ,   17  ,   95  ,   121 ,   39  ,   41  ,   171 ,   97  ,   7363    ,   11279   ,   28039   ,0 };
            const std::uint32_t dim2007KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   21  ,   9   ,   21  ,   147 ,   269 ,   475 ,   1825    ,   1459    ,   6337    ,   3259    ,   27731   ,0 };
            const std::uint32_t dim2008KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   9   ,   17  ,   107 ,   171 ,   253 ,   71  ,   629 ,   1671    ,   2587    ,   11429   ,   8985    ,0 };
            const std::uint32_t dim2009KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   25  ,   1   ,   63  ,   15  ,   173 ,   79  ,   1465    ,   2647    ,   6885    ,   13043   ,   24703   ,0 };
            const std::uint32_t dim2010KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   1   ,   13  ,   3   ,   217 ,   49  ,   77  ,   1635    ,   3767    ,   173 ,   12697   ,   11837   ,0 };
            const std::uint32_t dim2011KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   31  ,   7   ,   11  ,   181 ,   509 ,   601 ,   1267    ,   1857    ,   7871    ,   1703    ,   6091    ,0 };
            const std::uint32_t dim2012KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   29  ,   61  ,   117 ,   151 ,   487 ,   185 ,   1899    ,   575 ,   7341    ,   3055    ,   26513   ,0 };
            const std::uint32_t dim2013KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   1   ,   49  ,   87  ,   23  ,   483 ,   603 ,   1197    ,   2589    ,   1705    ,   5759    ,   19791   ,0 };
            const std::uint32_t dim2014KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   1   ,   37  ,   71  ,   115 ,   59  ,   167 ,   1907    ,   2225    ,   5673    ,   14571   ,   19389   ,0 };
            const std::uint32_t dim2015KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   15  ,   57  ,   33  ,   143 ,   45  ,   321 ,   779 ,   543 ,   3465    ,   4769    ,   19753   ,0 };
            const std::uint32_t dim2016KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   31  ,   21  ,   21  ,   141 ,   197 ,   397 ,   1041    ,   317 ,   109 ,   9395    ,   7141    ,0 };
            const std::uint32_t dim2017KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   1   ,   61  ,   45  ,   215 ,   405 ,   365 ,   1801    ,   2767    ,   6381    ,   12975   ,   41  ,0 };
            const std::uint32_t dim2018KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   23  ,   13  ,   37  ,   193 ,   305 ,   883 ,   1427    ,   3859    ,   2049    ,   16065   ,   2471    ,0 };
            const std::uint32_t dim2019KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   31  ,   3   ,   9   ,   169 ,   433 ,   187 ,   545 ,   985 ,   7699    ,   1183    ,   27773   ,0 };
            const std::uint32_t dim2020KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   11  ,   15  ,   9   ,   171 ,   89  ,   711 ,   163 ,   3637    ,   5725    ,   5079    ,   13373   ,0 };
            const std::uint32_t dim2021KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   1   ,   29  ,   123 ,   235 ,   229 ,   667 ,   1155    ,   3387    ,   129 ,   13889   ,   24547   ,0 };
            const std::uint32_t dim2022KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   27  ,   15  ,   75  ,   117 ,   335 ,   821 ,   609 ,   3843    ,   79  ,   6787    ,   5605    ,0 };
            const std::uint32_t dim2023KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   27  ,   47  ,   13  ,   163 ,   205 ,   773 ,   541 ,   1155    ,   4341    ,   14155   ,   6643    ,0 };
            const std::uint32_t dim2024KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   31  ,   1   ,   67  ,   35  ,   443 ,   723 ,   1089    ,   2605    ,   4193    ,   6133    ,   31127   ,0 };
            const std::uint32_t dim2025KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   27  ,   57  ,   11  ,   153 ,   199 ,   219 ,   1987    ,   2517    ,   1455    ,   6051    ,   9615    ,0 };
            const std::uint32_t dim2026KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   5   ,   7   ,   79  ,   187 ,   93  ,   679 ,   1607    ,   799 ,   2753    ,   6513    ,   11371   ,0 };
            const std::uint32_t dim2027KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   31  ,   55  ,   5   ,   175 ,   261 ,   545 ,   995 ,   2225    ,   2217    ,   2037    ,   14785   ,0 };
            const std::uint32_t dim2028KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   29  ,   5   ,   101 ,   223 ,   241 ,   829 ,   1625    ,   3417    ,   1335    ,   10705   ,   531 ,0 };
            const std::uint32_t dim2029KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   19  ,   15  ,   5   ,   203 ,   97  ,   165 ,   99  ,   2371    ,   3267    ,   13169   ,   22229   ,0 };
            const std::uint32_t dim2030KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   11  ,   63  ,   113 ,   255 ,   145 ,   589 ,   1149    ,   683 ,   2619    ,   5569    ,   5933    ,0 };
            const std::uint32_t dim2031KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   23  ,   41  ,   21  ,   217 ,   503 ,   975 ,   329 ,   3433    ,   6299    ,   5337    ,   199 ,0 };
            const std::uint32_t dim2032KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   3   ,   39  ,   109 ,   223 ,   241 ,   521 ,   1071    ,   589 ,   1199    ,   13059   ,   24921   ,0 };
            const std::uint32_t dim2033KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   11  ,   23  ,   27  ,   15  ,   107 ,   679 ,   87  ,   3259    ,   4369    ,   7365    ,   16293   ,0 };
            const std::uint32_t dim2034KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   11  ,   5   ,   75  ,   111 ,   21  ,   587 ,   1707    ,   1915    ,   6617    ,   11143   ,   24389   ,0 };
            const std::uint32_t dim2035KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   5   ,   59  ,   77  ,   3   ,   43  ,   583 ,   1601    ,   2183    ,   6209    ,   5409    ,   18175   ,0 };
            const std::uint32_t dim2036KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   15  ,   1   ,   55  ,   95  ,   437 ,   731 ,   1559    ,   2421    ,   7441    ,   6567    ,   1549    ,0 };
            const std::uint32_t dim2037KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   17  ,   21  ,   13  ,   61  ,   153 ,   81  ,   141 ,   3095    ,   5485    ,   14461   ,   8495    ,0 };
            const std::uint32_t dim2038KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   25  ,   61  ,   87  ,   195 ,   243 ,   47  ,   103 ,   3451    ,   5583    ,   1611    ,   11939   ,0 };
            const std::uint32_t dim2039KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   31  ,   53  ,   93  ,   101 ,   145 ,   917 ,   1669    ,   867 ,   6949    ,   16333   ,   12577   ,0 };
            const std::uint32_t dim2040KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   5   ,   41  ,   35  ,   75  ,   331 ,   671 ,   1623    ,   1573    ,   4275    ,   9031    ,   9047    ,0 };
            const std::uint32_t dim2041KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   15  ,   39  ,   29  ,   183 ,   477 ,   787 ,   1333    ,   2499    ,   2189    ,   8387    ,   2783    ,0 };
            const std::uint32_t dim2042KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   19  ,   33  ,   117 ,   201 ,   177 ,   595 ,   69  ,   3341    ,   1841    ,   11091   ,   16745   ,0 };
            const std::uint32_t dim2043KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   29  ,   59  ,   69  ,   119 ,   433 ,   595 ,   221 ,   1245    ,   7805    ,   1761    ,   27657   ,0 };
            const std::uint32_t dim2044KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   23  ,   19  ,   75  ,   189 ,   279 ,   867 ,   113 ,   3817    ,   6093    ,   12237   ,   20297   ,0 };
            const std::uint32_t dim2045KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   21  ,   39  ,   15  ,   249 ,   9   ,   997 ,   51  ,   1317    ,   1083    ,   13683   ,   5759    ,0 };
            const std::uint32_t dim2046KuoInit[]        =   {   1   ,   1   ,   5   ,   15  ,   29  ,   29  ,   25  ,   93  ,   465 ,   549 ,   283 ,   1673    ,   1745    ,   3913    ,   7931    ,0 };
            const std::uint32_t dim2047KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   5   ,   23  ,   123 ,   217 ,   211 ,   215 ,   1999    ,   1229    ,   6969    ,   13481   ,   14795   ,0 };
            const std::uint32_t dim2048KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   17  ,   35  ,   107 ,   163 ,   103 ,   807 ,   463 ,   2999    ,   4889    ,   12863   ,   24619   ,0 };
            const std::uint32_t dim2049KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   5   ,   17  ,   121 ,   209 ,   49  ,   871 ,   1931    ,   345 ,   6887    ,   1357    ,   14693   ,0 };
            const std::uint32_t dim2050KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   23  ,   63  ,   53  ,   35  ,   511 ,   261 ,   11  ,   283 ,   3283    ,   1963    ,   11703   ,0 };
            const std::uint32_t dim2051KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   15  ,   41  ,   19  ,   39  ,   445 ,   21  ,   513 ,   2957    ,   2307    ,   11451   ,   6539    ,0 };
            const std::uint32_t dim2052KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   19  ,   45  ,   7   ,   155 ,   387 ,   287 ,   347 ,   1557    ,   7407    ,   10885   ,   31829   ,0 };
            const std::uint32_t dim2053KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   9   ,   53  ,   61  ,   99  ,   355 ,   449 ,   1353    ,   3135    ,   2329    ,   733 ,   22443   ,0 };
            const std::uint32_t dim2054KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   27  ,   47  ,   43  ,   217 ,   113 ,   385 ,   903 ,   3015    ,   4169    ,   10705   ,   11351   ,0 };
            const std::uint32_t dim2055KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   9   ,   33  ,   7   ,   167 ,   473 ,   465 ,   357 ,   2387    ,   2901    ,   12995   ,   16871   ,0 };
            const std::uint32_t dim2056KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   29  ,   35  ,   85  ,   201 ,   311 ,   581 ,   491 ,   2977    ,   7433    ,   14615   ,   29995   ,0 };
            const std::uint32_t dim2057KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   5   ,   5   ,   121 ,   17  ,   93  ,   847 ,   835 ,   3885    ,   2437    ,   2237    ,   15669   ,0 };
            const std::uint32_t dim2058KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   29  ,   39  ,   57  ,   241 ,   247 ,   847 ,   311 ,   3115    ,   7605    ,   3117    ,   30677   ,0 };
            const std::uint32_t dim2059KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   21  ,   27  ,   123 ,   77  ,   511 ,   319 ,   1699    ,   709 ,   7021    ,   14377   ,   9601    ,0 };
            const std::uint32_t dim2060KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   31  ,   1   ,   49  ,   249 ,   271 ,   595 ,   1069    ,   2307    ,   567 ,   13145   ,   8779    ,0 };
            const std::uint32_t dim2061KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   29  ,   25  ,   55  ,   63  ,   289 ,   617 ,   1209    ,   3949    ,   481 ,   13495   ,   16659   ,0 };
            const std::uint32_t dim2062KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   5   ,   19  ,   47  ,   125 ,   323 ,   917 ,   1875    ,   1683    ,   7451    ,   16145   ,   3029    ,0 };
            const std::uint32_t dim2063KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   27  ,   33  ,   3   ,   133 ,   477 ,   457 ,   803 ,   1141    ,   3965    ,   9127    ,   21173   ,0 };
            const std::uint32_t dim2064KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   19  ,   61  ,   17  ,   27  ,   297 ,   995 ,   1119    ,   2555    ,   6741    ,   3233    ,   13735   ,0 };
            const std::uint32_t dim2065KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   11  ,   21  ,   21  ,   143 ,   319 ,   143 ,   675 ,   187 ,   6909    ,   7145    ,   27029   ,0 };
            const std::uint32_t dim2066KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   29  ,   5   ,   1   ,   65  ,   123 ,   801 ,   933 ,   3105    ,   1163    ,   15703   ,   9567    ,0 };
            const std::uint32_t dim2067KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   3   ,   15  ,   11  ,   109 ,   117 ,   1011    ,   1407    ,   3287    ,   5799    ,   147 ,   32641   ,0 };
            const std::uint32_t dim2068KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   29  ,   25  ,   63  ,   39  ,   139 ,   379 ,   1887    ,   417 ,   2965    ,   4409    ,   19149   ,0 };
            const std::uint32_t dim2069KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   31  ,   25  ,   123 ,   187 ,   311 ,   397 ,   1467    ,   15  ,   4253    ,   14565   ,   32609   ,0 };
            const std::uint32_t dim2070KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   25  ,   5   ,   13  ,   25  ,   489 ,   837 ,   865 ,   527 ,   4965    ,   2567    ,   13505   ,0 };
            const std::uint32_t dim2071KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   3   ,   15  ,   59  ,   115 ,   339 ,   459 ,   2011    ,   3311    ,   4067    ,   3437    ,   21435   ,0 };
            const std::uint32_t dim2072KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   17  ,   35  ,   49  ,   11  ,   217 ,   401 ,   385 ,   569 ,   1727    ,   9927    ,   27229   ,0 };
            const std::uint32_t dim2073KuoInit[]        =   {   1   ,   3   ,   1   ,   5   ,   27  ,   43  ,   21  ,   11  ,   459 ,   555 ,   237 ,   87  ,   7531    ,   16117   ,   23625   ,0 };
            const std::uint32_t dim2074KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   15  ,   57  ,   93  ,   35  ,   31  ,   257 ,   77  ,   3437    ,   3665    ,   3137    ,   2477    ,0 };
            const std::uint32_t dim2075KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   1   ,   43  ,   91  ,   55  ,   53  ,   265 ,   1495    ,   551 ,   4729    ,   7839    ,   23475   ,0 };
            const std::uint32_t dim2076KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   11  ,   45  ,   9   ,   27  ,   485 ,   397 ,   925 ,   3601    ,   4419    ,   4563    ,   6443    ,0 };
            const std::uint32_t dim2077KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   15  ,   35  ,   103 ,   239 ,   193 ,   831 ,   559 ,   1299    ,   4939    ,   8051    ,   6899    ,0 };
            const std::uint32_t dim2078KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   17  ,   47  ,   77  ,   13  ,   227 ,   935 ,   1973    ,   1789    ,   4357    ,   5135    ,   27643   ,0 };
            const std::uint32_t dim2079KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   11  ,   51  ,   109 ,   143 ,   101 ,   131 ,   565 ,   3503    ,   5649    ,   10007   ,   6283    ,0 };
            const std::uint32_t dim2080KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   19  ,   5   ,   15  ,   241 ,   399 ,   341 ,   943 ,   587 ,   4757    ,   13941   ,   7571    ,0 };
            const std::uint32_t dim2081KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   21  ,   9   ,   119 ,   119 ,   445 ,   349 ,   1517    ,   17  ,   3593    ,   11983   ,   9713    ,0 };
            const std::uint32_t dim2082KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   23  ,   55  ,   21  ,   251 ,   191 ,   585 ,   1619    ,   431 ,   4161    ,   5667    ,   17703   ,0 };
            const std::uint32_t dim2083KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   1   ,   57  ,   65  ,   231 ,   67  ,   531 ,   1403    ,   3883    ,   4463    ,   12795   ,   4427    ,0 };
            const std::uint32_t dim2084KuoInit[]        =   {   1   ,   1   ,   5   ,   15  ,   19  ,   7   ,   9   ,   163 ,   487 ,   455 ,   1663    ,   3141    ,   5975    ,   11001   ,   24781   ,0 };
            const std::uint32_t dim2085KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   29  ,   19  ,   45  ,   235 ,   371 ,   935 ,   1757    ,   187 ,   7729    ,   6241    ,   27171   ,0 };
            const std::uint32_t dim2086KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   15  ,   39  ,   39  ,   171 ,   145 ,   413 ,   1545    ,   3733    ,   1815    ,   9443    ,   32705   ,0 };
            const std::uint32_t dim2087KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   31  ,   1   ,   87  ,   11  ,   219 ,   913 ,   131 ,   3625    ,   7927    ,   9945    ,   2595    ,0 };
            const std::uint32_t dim2088KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   21  ,   15  ,   39  ,   29  ,   267 ,   275 ,   973 ,   701 ,   1057    ,   13641   ,   22149   ,0 };
            const std::uint32_t dim2089KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   3   ,   33  ,   81  ,   29  ,   85  ,   515 ,   1719    ,   3967    ,   5145    ,   12921   ,   8303    ,0 };
            const std::uint32_t dim2090KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   17  ,   23  ,   113 ,   129 ,   395 ,   153 ,   427 ,   1113    ,   8157    ,   9087    ,   20471   ,0 };
            const std::uint32_t dim2091KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   23  ,   5   ,   119 ,   67  ,   215 ,   581 ,   1249    ,   3949    ,   731 ,   10387   ,   27979   ,0 };
            const std::uint32_t dim2092KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   5   ,   53  ,   7   ,   39  ,   51  ,   519 ,   225 ,   119 ,   4335    ,   11723   ,   27971   ,0 };
            const std::uint32_t dim2093KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   5   ,   49  ,   105 ,   29  ,   443 ,   457 ,   191 ,   2679    ,   5803    ,   12017   ,   2205    ,0 };
            const std::uint32_t dim2094KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   23  ,   31  ,   11  ,   199 ,   479 ,   231 ,   431 ,   1989    ,   705 ,   6557    ,   27763   ,0 };
            const std::uint32_t dim2095KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   27  ,   9   ,   39  ,   105 ,   149 ,   1017    ,   79  ,   1575    ,   6365    ,   839 ,   27601   ,0 };
            const std::uint32_t dim2096KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   1   ,   29  ,   61  ,   129 ,   253 ,   541 ,   1953    ,   351 ,   2895    ,   14385   ,   23685   ,0 };
            const std::uint32_t dim2097KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   19  ,   15  ,   55  ,   133 ,   195 ,   881 ,   311 ,   2021    ,   7935    ,   4513    ,   31065   ,0 };
            const std::uint32_t dim2098KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   23  ,   55  ,   53  ,   169 ,   79  ,   707 ,   1415    ,   3999    ,   299 ,   6689    ,   10219   ,0 };
            const std::uint32_t dim2099KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   7   ,   47  ,   77  ,   209 ,   467 ,   39  ,   291 ,   3769    ,   1295    ,   12407   ,   2205    ,0 };
            const std::uint32_t dim2100KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   13  ,   3   ,   63  ,   241 ,   251 ,   939 ,   1391    ,   2053    ,   719 ,   13739   ,   12167   ,0 };
            const std::uint32_t dim2101KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   21  ,   31  ,   37  ,   11  ,   187 ,   201 ,   1425    ,   249 ,   2475    ,   12421   ,   14443   ,0 };
            const std::uint32_t dim2102KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   31  ,   51  ,   53  ,   119 ,   19  ,   13  ,   1513    ,   1115    ,   1265    ,   15707   ,   22795   ,0 };
            const std::uint32_t dim2103KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   23  ,   13  ,   69  ,   247 ,   103 ,   773 ,   997 ,   703 ,   2921    ,   3165    ,   3027    ,0 };
            const std::uint32_t dim2104KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   15  ,   27  ,   81  ,   221 ,   259 ,   405 ,   391 ,   2635    ,   1747    ,   7743    ,   28833   ,0 };
            const std::uint32_t dim2105KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   29  ,   47  ,   23  ,   127 ,   49  ,   81  ,   543 ,   919 ,   5517    ,   9573    ,   1523    ,0 };
            const std::uint32_t dim2106KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   11  ,   37  ,   123 ,   199 ,   343 ,   697 ,   293 ,   3123    ,   4601    ,   14209   ,   30425   ,0 };
            const std::uint32_t dim2107KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   3   ,   31  ,   127 ,   13  ,   191 ,   509 ,   1999    ,   3379    ,   2365    ,   10307   ,   26693   ,0 };
            const std::uint32_t dim2108KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   3   ,   41  ,   71  ,   153 ,   119 ,   9   ,   1601    ,   3839    ,   369 ,   16241   ,   19115   ,0 };
            const std::uint32_t dim2109KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   3   ,   17  ,   7   ,   65  ,   191 ,   143 ,   127 ,   1973    ,   6885    ,   13615   ,   26289   ,0 };
            const std::uint32_t dim2110KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   13  ,   5   ,   87  ,   17  ,   445 ,   975 ,   1527    ,   253 ,   5983    ,   7095    ,   21271   ,0 };
            const std::uint32_t dim2111KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   7   ,   49  ,   29  ,   19  ,   37  ,   695 ,   603 ,   3153    ,   4065    ,   5421    ,   3285    ,0 };
            const std::uint32_t dim2112KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   25  ,   47  ,   43  ,   35  ,   205 ,   629 ,   1255    ,   2843    ,   7533    ,   751 ,   10119   ,0 };
            const std::uint32_t dim2113KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   13  ,   27  ,   127 ,   221 ,   67  ,   523 ,   217 ,   1493    ,   1793    ,   10871   ,   14289   ,0 };
            const std::uint32_t dim2114KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   21  ,   47  ,   45  ,   73  ,   479 ,   653 ,   1553    ,   695 ,   3131    ,   8773    ,   20303   ,0 };
            const std::uint32_t dim2115KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   19  ,   31  ,   25  ,   207 ,   361 ,   961 ,   1595    ,   1807    ,   3649    ,   1029    ,   31579   ,0 };
            const std::uint32_t dim2116KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   27  ,   23  ,   109 ,   111 ,   477 ,   233 ,   1305    ,   51  ,   4517    ,   14867   ,   4075    ,0 };
            const std::uint32_t dim2117KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   21  ,   5   ,   51  ,   9   ,   131 ,   671 ,   191 ,   4045    ,   7773    ,   5037    ,   23229   ,0 };
            const std::uint32_t dim2118KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   3   ,   57  ,   75  ,   141 ,   439 ,   269 ,   99  ,   1595    ,   3597    ,   10183   ,   19849   ,0 };
            const std::uint32_t dim2119KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   17  ,   61  ,   81  ,   75  ,   471 ,   1023    ,   1045    ,   849 ,   3741    ,   12803   ,   10735   ,0 };
            const std::uint32_t dim2120KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   3   ,   33  ,   79  ,   113 ,   335 ,   245 ,   1807    ,   1927    ,   7381    ,   6405    ,   20035   ,0 };
            const std::uint32_t dim2121KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   5   ,   37  ,   31  ,   177 ,   233 ,   937 ,   1655    ,   511 ,   1109    ,   5083    ,   31325   ,0 };
            const std::uint32_t dim2122KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   15  ,   35  ,   125 ,   105 ,   313 ,   553 ,   259 ,   1433    ,   327 ,   2079    ,   5279    ,0 };
            const std::uint32_t dim2123KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   25  ,   57  ,   121 ,   189 ,   409 ,   459 ,   749 ,   3159    ,   6389    ,   4141    ,   16463   ,0 };
            const std::uint32_t dim2124KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   7   ,   21  ,   113 ,   139 ,   241 ,   617 ,   1385    ,   1387    ,   145 ,   6605    ,   2057    ,0 };
            const std::uint32_t dim2125KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   17  ,   33  ,   89  ,   17  ,   341 ,   369 ,   719 ,   2481    ,   7589    ,   16283   ,   28157   ,0 };
            const std::uint32_t dim2126KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   11  ,   17  ,   31  ,   135 ,   333 ,   335 ,   197 ,   2401    ,   7637    ,   703 ,   3001    ,0 };
            const std::uint32_t dim2127KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   17  ,   31  ,   33  ,   249 ,   315 ,   475 ,   1743    ,   2429    ,   4923    ,   2779    ,   25677   ,0 };
            const std::uint32_t dim2128KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   11  ,   29  ,   111 ,   103 ,   143 ,   779 ,   1437    ,   3759    ,   5827    ,   3129    ,   26961   ,0 };
            const std::uint32_t dim2129KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   25  ,   1   ,   109 ,   117 ,   159 ,   53  ,   1291    ,   1787    ,   7851    ,   14363   ,   15271   ,0 };
            const std::uint32_t dim2130KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   9   ,   1   ,   31  ,   131 ,   163 ,   723 ,   1023    ,   27  ,   853 ,   2623    ,   16859   ,0 };
            const std::uint32_t dim2131KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   23  ,   13  ,   91  ,   87  ,   141 ,   111 ,   1677    ,   1483    ,   1461    ,   15981   ,   29417   ,0 };
            const std::uint32_t dim2132KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   17  ,   17  ,   115 ,   43  ,   397 ,   683 ,   2017    ,   985 ,   3703    ,   16135   ,   3661    ,0 };
            const std::uint32_t dim2133KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   17  ,   45  ,   71  ,   149 ,   317 ,   559 ,   279 ,   2441    ,   2323    ,   16071   ,   29709   ,0 };
            const std::uint32_t dim2134KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   31  ,   33  ,   105 ,   127 ,   375 ,   1001    ,   115 ,   1429    ,   7003    ,   13369   ,   23281   ,0 };
            const std::uint32_t dim2135KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   21  ,   7   ,   27  ,   105 ,   99  ,   479 ,   849 ,   1361    ,   4935    ,   14831   ,   29  ,0 };
            const std::uint32_t dim2136KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   15  ,   53  ,   63  ,   109 ,   171 ,   323 ,   289 ,   2937    ,   3177    ,   4615    ,   10711   ,0 };
            const std::uint32_t dim2137KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   27  ,   41  ,   29  ,   101 ,   209 ,   673 ,   1597    ,   3743    ,   827 ,   4025    ,   27267   ,0 };
            const std::uint32_t dim2138KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   25  ,   17  ,   19  ,   219 ,   233 ,   769 ,   909 ,   3585    ,   55  ,   13349   ,   13685   ,0 };
            const std::uint32_t dim2139KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   17  ,   57  ,   63  ,   181 ,   339 ,   319 ,   655 ,   699 ,   1633    ,   8181    ,   23039   ,0 };
            const std::uint32_t dim2140KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   25  ,   11  ,   61  ,   195 ,   311 ,   723 ,   365 ,   2791    ,   1281    ,   9113    ,   26741   ,0 };
            const std::uint32_t dim2141KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   19  ,   43  ,   65  ,   37  ,   89  ,   847 ,   951 ,   851 ,   4441    ,   6681    ,   917 ,0 };
            const std::uint32_t dim2142KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   1   ,   11  ,   55  ,   29  ,   419 ,   769 ,   815 ,   1487    ,   2151    ,   7981    ,   19509   ,0 };
            const std::uint32_t dim2143KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   11  ,   55  ,   127 ,   19  ,   419 ,   679 ,   119 ,   1417    ,   1717    ,   5849    ,   6365    ,0 };
            const std::uint32_t dim2144KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   29  ,   5   ,   9   ,   241 ,   405 ,   253 ,   1015    ,   2027    ,   7695    ,   12003   ,   659 ,0 };
            const std::uint32_t dim2145KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   27  ,   63  ,   87  ,   221 ,   219 ,   355 ,   941 ,   3901    ,   6535    ,   4715    ,   3571    ,0 };
            const std::uint32_t dim2146KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   13  ,   1   ,   113 ,   21  ,   71  ,   353 ,   1063    ,   1447    ,   2157    ,   5195    ,   21311   ,0 };
            const std::uint32_t dim2147KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   29  ,   1   ,   7   ,   223 ,   43  ,   605 ,   1063    ,   67  ,   2529    ,   1125    ,   16933   ,0 };
            const std::uint32_t dim2148KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   29  ,   37  ,   51  ,   239 ,   117 ,   351 ,   1953    ,   1933    ,   6371    ,   13467   ,   8265    ,0 };
            const std::uint32_t dim2149KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   7   ,   25  ,   19  ,   221 ,   409 ,   121 ,   89  ,   219 ,   105 ,   4213    ,   1903    ,0 };
            const std::uint32_t dim2150KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   13  ,   3   ,   79  ,   123 ,   423 ,   589 ,   1085    ,   3387    ,   6117    ,   8749    ,   8947    ,0 };
            const std::uint32_t dim2151KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   21  ,   49  ,   1   ,   39  ,   461 ,   115 ,   1131    ,   719 ,   3709    ,   1495    ,   23871   ,0 };
            const std::uint32_t dim2152KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   23  ,   41  ,   107 ,   225 ,   499 ,   721 ,   1977    ,   2063    ,   1825    ,   9589    ,   22137   ,0 };
            const std::uint32_t dim2153KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   15  ,   53  ,   33  ,   145 ,   179 ,   109 ,   425 ,   2729    ,   7637    ,   6805    ,   26223   ,0 };
            const std::uint32_t dim2154KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   1   ,   1   ,   31  ,   117 ,   25  ,   427 ,   681 ,   2991    ,   7681    ,   15927   ,   20913   ,0 };
            const std::uint32_t dim2155KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   31  ,   53  ,   23  ,   71  ,   397 ,   661 ,   131 ,   2815    ,   2351    ,   15881   ,   10321   ,0 };
            const std::uint32_t dim2156KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   19  ,   41  ,   39  ,   57  ,   349 ,   761 ,   1999    ,   1151    ,   201 ,   1025    ,   18821   ,0 };
            const std::uint32_t dim2157KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   17  ,   43  ,   73  ,   163 ,   187 ,   913 ,   31  ,   81  ,   4829    ,   6993    ,   32175   ,0 };
            const std::uint32_t dim2158KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   19  ,   41  ,   79  ,   13  ,   343 ,   415 ,   863 ,   1943    ,   2231    ,   11353   ,   15631   ,0 };
            const std::uint32_t dim2159KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   29  ,   35  ,   101 ,   23  ,   111 ,   937 ,   833 ,   2369    ,   3503    ,   6605    ,   14279   ,0 };
            const std::uint32_t dim2160KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   27  ,   61  ,   43  ,   211 ,   259 ,   583 ,   1529    ,   1013    ,   8005    ,   7717    ,   1085    ,0 };
            const std::uint32_t dim2161KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   23  ,   39  ,   17  ,   201 ,   465 ,   289 ,   1051    ,   33  ,   7403    ,   7971    ,   24905   ,0 };
            const std::uint32_t dim2162KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   23  ,   41  ,   5   ,   239 ,   9   ,   23  ,   1353    ,   2005    ,   2513    ,   8707    ,   3893    ,0 };
            const std::uint32_t dim2163KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   7   ,   41  ,   73  ,   177 ,   351 ,   297 ,   1057    ,   3867    ,   2481    ,   15751   ,   25231   ,0 };
            const std::uint32_t dim2164KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   17  ,   59  ,   45  ,   171 ,   367 ,   575 ,   1085    ,   953 ,   3467    ,   8435    ,   6345    ,0 };
            const std::uint32_t dim2165KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   5   ,   21  ,   125 ,   137 ,   415 ,   101 ,   121 ,   3499    ,   6671    ,   15541   ,   14081   ,0 };
            const std::uint32_t dim2166KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   15  ,   19  ,   111 ,   235 ,   53  ,   119 ,   1307    ,   583 ,   1695    ,   211 ,   5567    ,0 };
            const std::uint32_t dim2167KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   7   ,   13  ,   119 ,   109 ,   273 ,   677 ,   2001    ,   3307    ,   7999    ,   11769   ,   10069   ,0 };
            const std::uint32_t dim2168KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   11  ,   15  ,   57  ,   233 ,   77  ,   815 ,   31  ,   669 ,   6365    ,   5085    ,   13583   ,0 };
            const std::uint32_t dim2169KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   31  ,   9   ,   101 ,   33  ,   13  ,   699 ,   637 ,   1159    ,   5101    ,   13805   ,   32651   ,0 };
            const std::uint32_t dim2170KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   15  ,   9   ,   125 ,   71  ,   241 ,   147 ,   529 ,   1863    ,   1551    ,   4981    ,   30389   ,0 };
            const std::uint32_t dim2171KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   11  ,   35  ,   11  ,   5   ,   473 ,   55  ,   1589    ,   2835    ,   3771    ,   11433   ,   11099   ,0 };
            const std::uint32_t dim2172KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   11  ,   11  ,   35  ,   207 ,   267 ,   289 ,   999 ,   3183    ,   3827    ,   6617    ,   29015   ,0 };
            const std::uint32_t dim2173KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   3   ,   11  ,   119 ,   223 ,   255 ,   319 ,   1823    ,   1301    ,   4401    ,   12827   ,   889 ,0 };
            const std::uint32_t dim2174KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   1   ,   5   ,   5   ,   109 ,   27  ,   963 ,   727 ,   335 ,   6295    ,   9775    ,   32681   ,0 };
            const std::uint32_t dim2175KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   29  ,   47  ,   55  ,   253 ,   281 ,   303 ,   857 ,   903 ,   2977    ,   14777   ,   31689   ,0 };
            const std::uint32_t dim2176KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   17  ,   49  ,   105 ,   155 ,   467 ,   467 ,   1287    ,   1281    ,   3429    ,   3195    ,   15297   ,0 };
            const std::uint32_t dim2177KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   27  ,   31  ,   17  ,   201 ,   23  ,   897 ,   1991    ,   2661    ,   645 ,   16127   ,   30857   ,0 };
            const std::uint32_t dim2178KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   9   ,   15  ,   85  ,   183 ,   31  ,   179 ,   779 ,   171 ,   5989    ,   7253    ,   15077   ,0 };
            const std::uint32_t dim2179KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   19  ,   23  ,   37  ,   39  ,   281 ,   707 ,   17  ,   2707    ,   289 ,   12081   ,   4381    ,0 };
            const std::uint32_t dim2180KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   21  ,   27  ,   115 ,   179 ,   99  ,   277 ,   331 ,   3407    ,   2057    ,   13893   ,   11501   ,0 };
            const std::uint32_t dim2181KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   31  ,   51  ,   51  ,   25  ,   319 ,   319 ,   27  ,   2161    ,   89  ,   3421    ,   18273   ,0 };
            const std::uint32_t dim2182KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   13  ,   21  ,   11  ,   189 ,   63  ,   15  ,   363 ,   1951    ,   5751    ,   5797    ,   22123   ,0 };
            const std::uint32_t dim2183KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   25  ,   47  ,   99  ,   77  ,   77  ,   595 ,   1473    ,   1653    ,   6751    ,   5005    ,   29051   ,0 };
            const std::uint32_t dim2184KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   25  ,   47  ,   31  ,   13  ,   311 ,   269 ,   1095    ,   1359    ,   305 ,   6811    ,   16455   ,0 };
            const std::uint32_t dim2185KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   13  ,   63  ,   87  ,   13  ,   221 ,   459 ,   1177    ,   891 ,   5781    ,   13803   ,   18795   ,0 };
            const std::uint32_t dim2186KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   23  ,   13  ,   25  ,   115 ,   47  ,   903 ,   1551    ,   2887    ,   229 ,   16067   ,   9511    ,0 };
            const std::uint32_t dim2187KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   23  ,   15  ,   7   ,   65  ,   27  ,   677 ,   1503    ,   125 ,   7739    ,   14655   ,   29577   ,0 };
            const std::uint32_t dim2188KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   9   ,   23  ,   93  ,   187 ,   205 ,   915 ,   599 ,   2105    ,   7767    ,   2411    ,   15045   ,0 };
            const std::uint32_t dim2189KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   21  ,   45  ,   17  ,   57  ,   171 ,   491 ,   1465    ,   2013    ,   3253    ,   5517    ,   19113   ,0 };
            const std::uint32_t dim2190KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   5   ,   25  ,   87  ,   247 ,   301 ,   385 ,   1655    ,   1351    ,   6307    ,   14695   ,   29745   ,0 };
            const std::uint32_t dim2191KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   31  ,   25  ,   113 ,   155 ,   123 ,   755 ,   649 ,   1809    ,   1703    ,   875 ,   5235    ,0 };
            const std::uint32_t dim2192KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   7   ,   43  ,   121 ,   47  ,   499 ,   63  ,   449 ,   2039    ,   835 ,   2883    ,   2287    ,0 };
            const std::uint32_t dim2193KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   9   ,   11  ,   99  ,   169 ,   305 ,   469 ,   157 ,   2043    ,   4851    ,   3367    ,   8689    ,0 };
            const std::uint32_t dim2194KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   17  ,   15  ,   41  ,   209 ,   377 ,   81  ,   335 ,   1685    ,   143 ,   1513    ,   28465   ,0 };
            const std::uint32_t dim2195KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   9   ,   45  ,   83  ,   123 ,   347 ,   437 ,   783 ,   3561    ,   6003    ,   9329    ,   4729    ,0 };
            const std::uint32_t dim2196KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   13  ,   33  ,   109 ,   217 ,   403 ,   539 ,   1393    ,   1069    ,   235 ,   11261   ,   13423   ,0 };
            const std::uint32_t dim2197KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   27  ,   1   ,   81  ,   139 ,   421 ,   301 ,   55  ,   1883    ,   1525    ,   6029    ,   1879    ,0 };
            const std::uint32_t dim2198KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   15  ,   55  ,   49  ,   249 ,   487 ,   373 ,   737 ,   2133    ,   6883    ,   1603    ,   27607   ,0 };
            const std::uint32_t dim2199KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   25  ,   17  ,   17  ,   15  ,   119 ,   571 ,   1053    ,   2153    ,   5221    ,   2681    ,   24595   ,0 };
            const std::uint32_t dim2200KuoInit[]        =   {   1   ,   3   ,   1   ,   5   ,   3   ,   63  ,   31  ,   9   ,   263 ,   977 ,   575 ,   1225    ,   4127    ,   15649   ,   1281    ,0 };
            const std::uint32_t dim2201KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   19  ,   1   ,   37  ,   109 ,   13  ,   191 ,   1483    ,   465 ,   1321    ,   13697   ,   26065   ,0 };
            const std::uint32_t dim2202KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   17  ,   15  ,   103 ,   97  ,   237 ,   861 ,   1251    ,   2069    ,   4459    ,   9999    ,   7369    ,0 };
            const std::uint32_t dim2203KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   15  ,   33  ,   55  ,   5   ,   355 ,   519 ,   445 ,   4033    ,   627 ,   2375    ,   31013   ,0 };
            const std::uint32_t dim2204KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   23  ,   51  ,   65  ,   177 ,   225 ,   63  ,   987 ,   2921    ,   823 ,   1781    ,   22923   ,0 };
            const std::uint32_t dim2205KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   27  ,   33  ,   111 ,   47  ,   465 ,   379 ,   1575    ,   1793    ,   513 ,   14033   ,   27409   ,0 };
            const std::uint32_t dim2206KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   1   ,   57  ,   31  ,   195 ,   393 ,   257 ,   1489    ,   2589    ,   5339    ,   7487    ,   29023   ,0 };
            const std::uint32_t dim2207KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   15  ,   27  ,   39  ,   89  ,   387 ,   753 ,   1213    ,   2417    ,   6287    ,   129 ,   12295   ,0 };
            const std::uint32_t dim2208KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   11  ,   37  ,   117 ,   55  ,   55  ,   677 ,   1057    ,   3971    ,   5017    ,   12941   ,   3001    ,0 };
            const std::uint32_t dim2209KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   21  ,   33  ,   103 ,   19  ,   427 ,   637 ,   393 ,   2245    ,   2853    ,   15927   ,   14633   ,0 };
            const std::uint32_t dim2210KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   31  ,   11  ,   75  ,   191 ,   367 ,   659 ,   121 ,   2947    ,   515 ,   10625   ,   19753   ,0 };
            const std::uint32_t dim2211KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   15  ,   63  ,   115 ,   119 ,   85  ,   527 ,   875 ,   67  ,   475 ,   2207    ,   4101    ,0 };
            const std::uint32_t dim2212KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   23  ,   37  ,   53  ,   187 ,   37  ,   535 ,   509 ,   1765    ,   6577    ,   13249   ,   3875    ,0 };
            const std::uint32_t dim2213KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   13  ,   49  ,   23  ,   193 ,   109 ,   295 ,   309 ,   2457    ,   4193    ,   9927    ,   16313   ,0 };
            const std::uint32_t dim2214KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   5   ,   15  ,   33  ,   69  ,   225 ,   231 ,   131 ,   3135    ,   3597    ,   2989    ,   12365   ,0 };
            const std::uint32_t dim2215KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   27  ,   33  ,   9   ,   139 ,   507 ,   789 ,   663 ,   1693    ,   949 ,   9149    ,   29529   ,0 };
            const std::uint32_t dim2216KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   11  ,   1   ,   57  ,   159 ,   511 ,   929 ,   1337    ,   2181    ,   5573    ,   425 ,   26935   ,0 };
            const std::uint32_t dim2217KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   15  ,   53  ,   57  ,   81  ,   105 ,   389 ,   1563    ,   1   ,   669 ,   8403    ,   15747   ,0 };
            const std::uint32_t dim2218KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   19  ,   21  ,   29  ,   133 ,   203 ,   689 ,   2011    ,   1825    ,   3365    ,   1957    ,   21393   ,0 };
            const std::uint32_t dim2219KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   7   ,   11  ,   73  ,   189 ,   63  ,   81  ,   1429    ,   3403    ,   4249    ,   16265   ,   22423   ,0 };
            const std::uint32_t dim2220KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   31  ,   47  ,   75  ,   199 ,   343 ,   957 ,   691 ,   939 ,   2165    ,   10523   ,   3577    ,0 };
            const std::uint32_t dim2221KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   3   ,   27  ,   5   ,   131 ,   437 ,   405 ,   1809    ,   2637    ,   5735    ,   12897   ,   22905   ,0 };
            const std::uint32_t dim2222KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   17  ,   17  ,   85  ,   161 ,   205 ,   81  ,   1125    ,   1783    ,   2241    ,   6321    ,   10891   ,0 };
            const std::uint32_t dim2223KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   27  ,   7   ,   119 ,   61  ,   383 ,   171 ,   1495    ,   1237    ,   729 ,   1977    ,   11779   ,0 };
            const std::uint32_t dim2224KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   21  ,   3   ,   63  ,   167 ,   493 ,   117 ,   855 ,   143 ,   2579    ,   7527    ,   7395    ,0 };
            const std::uint32_t dim2225KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   31  ,   61  ,   15  ,   31  ,   445 ,   397 ,   1369    ,   1047    ,   4751    ,   10375   ,   30319   ,0 };
            const std::uint32_t dim2226KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   7   ,   13  ,   87  ,   99  ,   333 ,   433 ,   287 ,   2861    ,   2085    ,   14691   ,   14801   ,0 };
            const std::uint32_t dim2227KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   27  ,   45  ,   41  ,   69  ,   391 ,   259 ,   899 ,   1019    ,   2999    ,   6487    ,   19831   ,0 };
            const std::uint32_t dim2228KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   19  ,   33  ,   49  ,   87  ,   89  ,   649 ,   1209    ,   43  ,   8035    ,   12687   ,   24783   ,0 };
            const std::uint32_t dim2229KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   13  ,   11  ,   55  ,   5   ,   315 ,   347 ,   1361    ,   41  ,   807 ,   11551   ,   499 ,0 };
            const std::uint32_t dim2230KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   25  ,   15  ,   11  ,   19  ,   233 ,   269 ,   135 ,   2577    ,   4385    ,   8109    ,   13161   ,0 };
            const std::uint32_t dim2231KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   19  ,   13  ,   127 ,   79  ,   49  ,   525 ,   1499    ,   1209    ,   3747    ,   8311    ,   15061   ,0 };
            const std::uint32_t dim2232KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   9   ,   47  ,   59  ,   81  ,   491 ,   401 ,   1691    ,   543 ,   7129    ,   13617   ,   17031   ,0 };
            const std::uint32_t dim2233KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   15  ,   51  ,   41  ,   85  ,   245 ,   91  ,   1293    ,   2041    ,   7205    ,   12709   ,   17421   ,0 };
            const std::uint32_t dim2234KuoInit[]        =   {   1   ,   3   ,   1   ,   5   ,   3   ,   19  ,   29  ,   149 ,   51  ,   133 ,   953 ,   2385    ,   7471    ,   14829   ,   8197    ,0 };
            const std::uint32_t dim2235KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   31  ,   15  ,   5   ,   139 ,   299 ,   595 ,   1585    ,   2115    ,   5647    ,   12125   ,   1265    ,0 };
            const std::uint32_t dim2236KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   7   ,   5   ,   93  ,   187 ,   307 ,   329 ,   671 ,   3983    ,   817 ,   3965    ,   21561   ,0 };
            const std::uint32_t dim2237KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   21  ,   57  ,   67  ,   159 ,   467 ,   65  ,   1365    ,   2797    ,   7051    ,   12603   ,   10429   ,0 };
            const std::uint32_t dim2238KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   27  ,   59  ,   113 ,   199 ,   13  ,   393 ,   1605    ,   3215    ,   5233    ,   12749   ,   32365   ,0 };
            const std::uint32_t dim2239KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   1   ,   13  ,   15  ,   217 ,   317 ,   945 ,   1713    ,   1951    ,   5585    ,   1529    ,   4969    ,0 };
            const std::uint32_t dim2240KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   3   ,   59  ,   23  ,   255 ,   71  ,   539 ,   21  ,   2603    ,   5145    ,   295 ,   2681    ,0 };
            const std::uint32_t dim2241KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   11  ,   41  ,   85  ,   145 ,   209 ,   1001    ,   659 ,   951 ,   4039    ,   1409    ,   4059    ,0 };
            const std::uint32_t dim2242KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   15  ,   41  ,   15  ,   121 ,   485 ,   515 ,   325 ,   3673    ,   2883    ,   8119    ,   29183   ,0 };
            const std::uint32_t dim2243KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   21  ,   39  ,   31  ,   163 ,   13  ,   219 ,   411 ,   2061    ,   1999    ,   2999    ,   24835   ,0 };
            const std::uint32_t dim2244KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   21  ,   49  ,   9   ,   75  ,   401 ,   339 ,   191 ,   2679    ,   7483    ,   1361    ,   21399   ,0 };
            const std::uint32_t dim2245KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   5   ,   29  ,   9   ,   77  ,   459 ,   247 ,   1777    ,   3873    ,   6747    ,   7541    ,   12015   ,0 };
            const std::uint32_t dim2246KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   23  ,   27  ,   55  ,   51  ,   389 ,   63  ,   1163    ,   255 ,   6049    ,   1737    ,   12403   ,0 };
            const std::uint32_t dim2247KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   23  ,   25  ,   81  ,   247 ,   261 ,   445 ,   1297    ,   1945    ,   2769    ,   1287    ,   24403   ,0 };
            const std::uint32_t dim2248KuoInit[]        =   {   1   ,   1   ,   5   ,   15  ,   19  ,   13  ,   127 ,   105 ,   475 ,   859 ,   683 ,   941 ,   2911    ,   14571   ,   22769   ,0 };
            const std::uint32_t dim2249KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   31  ,   25  ,   55  ,   63  ,   355 ,   525 ,   397 ,   3213    ,   2267    ,   2731    ,   32145   ,0 };
            const std::uint32_t dim2250KuoInit[]        =   {   1   ,   1   ,   5   ,   15  ,   3   ,   21  ,   45  ,   229 ,   83  ,   661 ,   149 ,   1615    ,   5309    ,   12233   ,   23101   ,0 };
            const std::uint32_t dim2251KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   15  ,   41  ,   91  ,   17  ,   119 ,   65  ,   1921    ,   97  ,   6521    ,   8969    ,   5419    ,0 };
            const std::uint32_t dim2252KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   31  ,   35  ,   73  ,   123 ,   331 ,   83  ,   125 ,   3001    ,   5485    ,   1693    ,   24327   ,0 };
            const std::uint32_t dim2253KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   29  ,   37  ,   63  ,   229 ,   143 ,   529 ,   961 ,   2845    ,   8003    ,   7741    ,   23393   ,0 };
            const std::uint32_t dim2254KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   25  ,   27  ,   91  ,   171 ,   361 ,   575 ,   1977    ,   2141    ,   89  ,   7097    ,   8115    ,0 };
            const std::uint32_t dim2255KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   13  ,   7   ,   51  ,   253 ,   17  ,   991 ,   595 ,   1819    ,   7091    ,   8619    ,   1147    ,0 };
            const std::uint32_t dim2256KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   13  ,   31  ,   41  ,   11  ,   57  ,   185 ,   1353    ,   907 ,   6585    ,   8597    ,   10239   ,0 };
            const std::uint32_t dim2257KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   31  ,   1   ,   119 ,   165 ,   105 ,   725 ,   493 ,   3279    ,   7117    ,   15141   ,   5957    ,0 };
            const std::uint32_t dim2258KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   29  ,   1   ,   35  ,   95  ,   477 ,   847 ,   733 ,   2599    ,   581 ,   6487    ,   10879   ,0 };
            const std::uint32_t dim2259KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   15  ,   23  ,   115 ,   177 ,   409 ,   711 ,   1179    ,   685 ,   4071    ,   15129   ,   2951    ,0 };
            const std::uint32_t dim2260KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   19  ,   5   ,   69  ,   33  ,   41  ,   501 ,   135 ,   1063    ,   4857    ,   15537   ,   29247   ,0 };
            const std::uint32_t dim2261KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   1   ,   25  ,   123 ,   1   ,   431 ,   399 ,   483 ,   3159    ,   7359    ,   6169    ,   22525   ,0 };
            const std::uint32_t dim2262KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   1   ,   9   ,   125 ,   131 ,   99  ,   911 ,   421 ,   1403    ,   993 ,   14155   ,   20863   ,0 };
            const std::uint32_t dim2263KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   1   ,   43  ,   93  ,   9   ,   345 ,   483 ,   1809    ,   2379    ,   653 ,   14851   ,   20619   ,0 };
            const std::uint32_t dim2264KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   15  ,   37  ,   33  ,   185 ,   173 ,   397 ,   2021    ,   613 ,   37  ,   7185    ,   15399   ,0 };
            const std::uint32_t dim2265KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   17  ,   55  ,   119 ,   207 ,   301 ,   461 ,   1853    ,   2471    ,   3611    ,   1149    ,   3321    ,0 };
            const std::uint32_t dim2266KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   25  ,   57  ,   51  ,   135 ,   337 ,   935 ,   619 ,   1165    ,   1613    ,   8711    ,   2329    ,0 };
            const std::uint32_t dim2267KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   27  ,   25  ,   63  ,   127 ,   169 ,   221 ,   1103    ,   1087    ,   1729    ,   3967    ,   6323    ,0 };
            const std::uint32_t dim2268KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   13  ,   29  ,   105 ,   189 ,   321 ,   103 ,   2047    ,   923 ,   4443    ,   2175    ,   12411   ,0 };
            const std::uint32_t dim2269KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   7   ,   3   ,   3   ,   61  ,   479 ,   533 ,   227 ,   3137    ,   6065    ,   3621    ,   3583    ,0 };
            const std::uint32_t dim2270KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   11  ,   31  ,   23  ,   147 ,   67  ,   823 ,   663 ,   3717    ,   6747    ,   10935   ,   21931   ,0 };
            const std::uint32_t dim2271KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   29  ,   9   ,   75  ,   31  ,   349 ,   603 ,   1071    ,   1767    ,   1811    ,   15921   ,   25681   ,0 };
            const std::uint32_t dim2272KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   29  ,   31  ,   57  ,   15  ,   405 ,   263 ,   715 ,   445 ,   1825    ,   15057   ,   3449    ,0 };
            const std::uint32_t dim2273KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   5   ,   21  ,   61  ,   137 ,   15  ,   935 ,   897 ,   125 ,   6651    ,   6813    ,   27863   ,0 };
            const std::uint32_t dim2274KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   9   ,   53  ,   5   ,   91  ,   93  ,   179 ,   489 ,   3615    ,   5911    ,   7501    ,   14205   ,0 };
            const std::uint32_t dim2275KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   27  ,   49  ,   35  ,   93  ,   371 ,   519 ,   589 ,   1563    ,   2609    ,   14055   ,   28071   ,0 };
            const std::uint32_t dim2276KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   29  ,   41  ,   23  ,   135 ,   491 ,   745 ,   1327    ,   4065    ,   6327    ,   6375    ,   24901   ,0 };
            const std::uint32_t dim2277KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   23  ,   47  ,   113 ,   85  ,   453 ,   321 ,   597 ,   1817    ,   7579    ,   11633   ,   25569   ,0 };
            const std::uint32_t dim2278KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   13  ,   55  ,   127 ,   47  ,   159 ,   885 ,   235 ,   199 ,   3133    ,   9793    ,   25877   ,0 };
            const std::uint32_t dim2279KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   17  ,   21  ,   27  ,   237 ,   413 ,   999 ,   451 ,   3279    ,   1607    ,   9625    ,   16943   ,0 };
            const std::uint32_t dim2280KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   21  ,   61  ,   29  ,   143 ,   33  ,   235 ,   1591    ,   2379    ,   3573    ,   1399    ,   16215   ,0 };
            const std::uint32_t dim2281KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   29  ,   23  ,   95  ,   207 ,   87  ,   199 ,   1389    ,   3587    ,   71  ,   14401   ,   28431   ,0 };
            const std::uint32_t dim2282KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   23  ,   43  ,   109 ,   119 ,   151 ,   451 ,   23  ,   2709    ,   3125    ,   11541   ,   3923    ,0 };
            const std::uint32_t dim2283KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   11  ,   55  ,   5   ,   227 ,   171 ,   465 ,   1685    ,   333 ,   2605    ,   15055   ,   8333    ,0 };
            const std::uint32_t dim2284KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   21  ,   11  ,   57  ,   37  ,   67  ,   667 ,   521 ,   2961    ,   6145    ,   12527   ,   17433   ,0 };
            const std::uint32_t dim2285KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   9   ,   39  ,   103 ,   83  ,   313 ,   827 ,   721 ,   2965    ,   3231    ,   10121   ,   19991   ,0 };
            const std::uint32_t dim2286KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   23  ,   9   ,   31  ,   39  ,   7   ,   767 ,   153 ,   2969    ,   5539    ,   6581    ,   30515   ,0 };
            const std::uint32_t dim2287KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   3   ,   43  ,   49  ,   143 ,   3   ,   227 ,   99  ,   597 ,   7207    ,   4737    ,   2259    ,0 };
            const std::uint32_t dim2288KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   3   ,   57  ,   69  ,   243 ,   199 ,   803 ,   657 ,   1209    ,   1343    ,   11673   ,   21543   ,0 };
            const std::uint32_t dim2289KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   17  ,   27  ,   127 ,   107 ,   171 ,   391 ,   1737    ,   1247    ,   1389    ,   14387   ,   1671    ,0 };
            const std::uint32_t dim2290KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   23  ,   47  ,   97  ,   139 ,   435 ,   943 ,   1111    ,   2723    ,   1021    ,   1155    ,   10241   ,0 };
            const std::uint32_t dim2291KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   15  ,   15  ,   101 ,   205 ,   229 ,   639 ,   1077    ,   1613    ,   3035    ,   12897   ,   14303   ,0 };
            const std::uint32_t dim2292KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   17  ,   43  ,   3   ,   81  ,   149 ,   931 ,   731 ,   4005    ,   7397    ,   8707    ,   27927   ,0 };
            const std::uint32_t dim2293KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   19  ,   59  ,   97  ,   97  ,   347 ,   489 ,   1577    ,   3927    ,   3431    ,   4051    ,   8489    ,0 };
            const std::uint32_t dim2294KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   29  ,   49  ,   19  ,   151 ,   27  ,   701 ,   541 ,   481 ,   101 ,   10701   ,   31909   ,0 };
            const std::uint32_t dim2295KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   11  ,   47  ,   59  ,   45  ,   439 ,   757 ,   1579    ,   1681    ,   6701    ,   11707   ,   10715   ,0 };
            const std::uint32_t dim2296KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   27  ,   55  ,   1   ,   35  ,   491 ,   767 ,   1247    ,   1143    ,   5079    ,   8029    ,   10267   ,0 };
            const std::uint32_t dim2297KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   15  ,   5   ,   53  ,   215 ,   249 ,   659 ,   329 ,   1959    ,   249 ,   11775   ,   4815    ,0 };
            const std::uint32_t dim2298KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   19  ,   17  ,   41  ,   29  ,   157 ,   995 ,   235 ,   1397    ,   3983    ,   11739   ,   7523    ,0 };
            const std::uint32_t dim2299KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   13  ,   3   ,   55  ,   211 ,   59  ,   717 ,   1389    ,   3219    ,   2279    ,   9583    ,   16981   ,0 };
            const std::uint32_t dim2300KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   31  ,   41  ,   95  ,   217 ,   375 ,   255 ,   1433    ,   1595    ,   5795    ,   11893   ,   16665   ,0 };
            const std::uint32_t dim2301KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   15  ,   45  ,   19  ,   125 ,   387 ,   1017    ,   1075    ,   3469    ,   7873    ,   9135    ,   28215   ,0 };
            const std::uint32_t dim2302KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   23  ,   41  ,   35  ,   171 ,   159 ,   545 ,   2043    ,   887 ,   8167    ,   8977    ,   30985   ,0 };
            const std::uint32_t dim2303KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   21  ,   17  ,   31  ,   171 ,   45  ,   979 ,   757 ,   3839    ,   4221    ,   8659    ,   7005    ,0 };
            const std::uint32_t dim2304KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   3   ,   23  ,   81  ,   157 ,   385 ,   233 ,   527 ,   2357    ,   7299    ,   10977   ,   16285   ,0 };
            const std::uint32_t dim2305KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   23  ,   27  ,   31  ,   211 ,   451 ,   211 ,   45  ,   2239    ,   981 ,   14279   ,   14515   ,0 };
            const std::uint32_t dim2306KuoInit[]        =   {   1   ,   3   ,   1   ,   5   ,   13  ,   61  ,   17  ,   197 ,   455 ,   457 ,   2023    ,   1809    ,   4243    ,   3269    ,   7159    ,0 };
            const std::uint32_t dim2307KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   9   ,   61  ,   49  ,   111 ,   281 ,   827 ,   1155    ,   3107    ,   5761    ,   12043   ,   3061    ,0 };
            const std::uint32_t dim2308KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   19  ,   29  ,   63  ,   209 ,   207 ,   503 ,   1563    ,   2539    ,   5115    ,   12939   ,   22977   ,0 };
            const std::uint32_t dim2309KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   31  ,   33  ,   91  ,   45  ,   399 ,   263 ,   53  ,   2723    ,   7909    ,   7125    ,   14795   ,0 };
            const std::uint32_t dim2310KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   9   ,   5   ,   119 ,   91  ,   87  ,   847 ,   85  ,   4025    ,   1891    ,   791 ,   30447   ,0 };
            const std::uint32_t dim2311KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   25  ,   59  ,   101 ,   85  ,   159 ,   491 ,   635 ,   1047    ,   6221    ,   11579   ,   13943   ,0 };
            const std::uint32_t dim2312KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   27  ,   55  ,   19  ,   29  ,   479 ,   299 ,   1705    ,   3505    ,   6811    ,   14851   ,   6827    ,0 };
            const std::uint32_t dim2313KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   23  ,   19  ,   47  ,   235 ,   81  ,   35  ,   1297    ,   2029    ,   1303    ,   6877    ,   30813   ,0 };
            const std::uint32_t dim2314KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   21  ,   37  ,   49  ,   209 ,   93  ,   439 ,   2023    ,   437 ,   6405    ,   2407    ,   10475   ,0 };
            const std::uint32_t dim2315KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   5   ,   51  ,   11  ,   127 ,   339 ,   419 ,   1495    ,   43  ,   5707    ,   3905    ,   331 ,0 };
            const std::uint32_t dim2316KuoInit[]        =   {   1   ,   1   ,   5   ,   15  ,   27  ,   7   ,   73  ,   137 ,   111 ,   283 ,   1017    ,   1487    ,   7359    ,   4921    ,   3285    ,0 };
            const std::uint32_t dim2317KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   3   ,   23  ,   123 ,   75  ,   317 ,   517 ,   109 ,   2307    ,   1095    ,   10309   ,   27651   ,0 };
            const std::uint32_t dim2318KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   21  ,   55  ,   5   ,   115 ,   483 ,   379 ,   1935    ,   3483    ,   2485    ,   1991    ,   2403    ,0 };
            const std::uint32_t dim2319KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   27  ,   57  ,   1   ,   227 ,   235 ,   373 ,   241 ,   1115    ,   3037    ,   6841    ,   28711   ,0 };
            const std::uint32_t dim2320KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   21  ,   27  ,   19  ,   217 ,   449 ,   727 ,   475 ,   515 ,   7933    ,   4401    ,   5455    ,0 };
            const std::uint32_t dim2321KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   27  ,   3   ,   117 ,   67  ,   293 ,   625 ,   1463    ,   3713    ,   1271    ,   11873   ,   24239   ,0 };
            const std::uint32_t dim2322KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   7   ,   25  ,   5   ,   187 ,   377 ,   15  ,   1973    ,   597 ,   725 ,   8809    ,   2419    ,0 };
            const std::uint32_t dim2323KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   7   ,   9   ,   89  ,   41  ,   443 ,   921 ,   17  ,   3675    ,   715 ,   7147    ,   25345   ,0 };
            const std::uint32_t dim2324KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   31  ,   27  ,   127 ,   139 ,   101 ,   349 ,   1551    ,   1703    ,   5981    ,   3259    ,   31203   ,0 };
            const std::uint32_t dim2325KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   31  ,   59  ,   1   ,   149 ,   111 ,   947 ,   1919    ,   2841    ,   5383    ,   6973    ,   19565   ,0 };
            const std::uint32_t dim2326KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   5   ,   57  ,   65  ,   197 ,   413 ,   741 ,   1737    ,   1333    ,   5101    ,   14375   ,   28969   ,0 };
            const std::uint32_t dim2327KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   5   ,   21  ,   31  ,   187 ,   51  ,   267 ,   539 ,   1305    ,   4085    ,   14735   ,   9441    ,0 };
            const std::uint32_t dim2328KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   9   ,   27  ,   123 ,   13  ,   383 ,   739 ,   649 ,   1253    ,   4697    ,   9571    ,   16983   ,0 };
            const std::uint32_t dim2329KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   23  ,   3   ,   31  ,   153 ,   185 ,   969 ,   329 ,   3919    ,   3905    ,   14321   ,   16535   ,0 };
            const std::uint32_t dim2330KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   15  ,   31  ,   97  ,   243 ,   117 ,   269 ,   1545    ,   1495    ,   167 ,   14281   ,   1369    ,0 };
            const std::uint32_t dim2331KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   7   ,   47  ,   9   ,   187 ,   233 ,   629 ,   1981    ,   2327    ,   7473    ,   14641   ,   31829   ,0 };
            const std::uint32_t dim2332KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   11  ,   43  ,   117 ,   193 ,   395 ,   501 ,   1213    ,   3499    ,   3369    ,   817 ,   22069   ,0 };
            const std::uint32_t dim2333KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   13  ,   63  ,   67  ,   67  ,   119 ,   371 ,   1887    ,   1281    ,   129 ,   14277   ,   5213    ,0 };
            const std::uint32_t dim2334KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   11  ,   57  ,   47  ,   149 ,   119 ,   547 ,   389 ,   1977    ,   1709    ,   2335    ,   7023    ,0 };
            const std::uint32_t dim2335KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   15  ,   41  ,   19  ,   57  ,   279 ,   737 ,   29  ,   2015    ,   1103    ,   4933    ,   26145   ,0 };
            const std::uint32_t dim2336KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   23  ,   61  ,   17  ,   1   ,   309 ,   637 ,   809 ,   3443    ,   135 ,   6851    ,   27321   ,0 };
            const std::uint32_t dim2337KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   21  ,   63  ,   81  ,   131 ,   495 ,   209 ,   1901    ,   2921    ,   1021    ,   7207    ,   22053   ,0 };
            const std::uint32_t dim2338KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   7   ,   63  ,   1   ,   119 ,   329 ,   553 ,   1405    ,   97  ,   4751    ,   6955    ,   20049   ,0 };
            const std::uint32_t dim2339KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   1   ,   59  ,   99  ,   201 ,   487 ,   271 ,   2035    ,   3261    ,   4953    ,   15257   ,   11835   ,0 };
            const std::uint32_t dim2340KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   27  ,   21  ,   27  ,   227 ,   331 ,   779 ,   1003    ,   2291    ,   7139    ,   14125   ,   14371   ,0 };
            const std::uint32_t dim2341KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   15  ,   43  ,   23  ,   183 ,   463 ,   273 ,   1707    ,   2001    ,   3219    ,   14481   ,   751 ,0 };
            const std::uint32_t dim2342KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   23  ,   31  ,   51  ,   39  ,   221 ,   687 ,   2003    ,   1251    ,   3541    ,   6347    ,   551 ,0 };
            const std::uint32_t dim2343KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   17  ,   51  ,   3   ,   57  ,   131 ,   13  ,   2027    ,   3301    ,   4223    ,   6499    ,   30913   ,0 };
            const std::uint32_t dim2344KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   11  ,   47  ,   53  ,   205 ,   59  ,   315 ,   1595    ,   3747    ,   2623    ,   7317    ,   8309    ,0 };
            const std::uint32_t dim2345KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   13  ,   45  ,   83  ,   131 ,   193 ,   739 ,   61  ,   1657    ,   3789    ,   9859    ,   3755    ,0 };
            const std::uint32_t dim2346KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   25  ,   7   ,   123 ,   103 ,   307 ,   463 ,   1113    ,   2245    ,   2819    ,   12983   ,   18077   ,0 };
            const std::uint32_t dim2347KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   7   ,   23  ,   103 ,   183 ,   409 ,   657 ,   583 ,   583 ,   5449    ,   7397    ,   13085   ,0 };
            const std::uint32_t dim2348KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   3   ,   61  ,   31  ,   147 ,   31  ,   449 ,   1579    ,   4021    ,   1163    ,   9719    ,   27079   ,0 };
            const std::uint32_t dim2349KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   9   ,   53  ,   125 ,   77  ,   99  ,   863 ,   1719    ,   51  ,   4183    ,   13009   ,   791 ,0 };
            const std::uint32_t dim2350KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   27  ,   33  ,   43  ,   5   ,   173 ,   775 ,   593 ,   3701    ,   3323    ,   6481    ,   25765   ,0 };
            const std::uint32_t dim2351KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   11  ,   3   ,   109 ,   221 ,   375 ,   883 ,   903 ,   2361    ,   255 ,   12851   ,   16697   ,0 };
            const std::uint32_t dim2352KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   3   ,   61  ,   127 ,   89  ,   213 ,   71  ,   303 ,   2525    ,   3691    ,   2945    ,   12359   ,0 };
            const std::uint32_t dim2353KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   19  ,   15  ,   7   ,   231 ,   159 ,   275 ,   1161    ,   819 ,   3003    ,   12707   ,   20699   ,0 };
            const std::uint32_t dim2354KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   31  ,   51  ,   125 ,   21  ,   27  ,   427 ,   941 ,   237 ,   4343    ,   9555    ,   30511   ,0 };
            const std::uint32_t dim2355KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   17  ,   23  ,   105 ,   21  ,   471 ,   357 ,   773 ,   1185    ,   2655    ,   2317    ,   9969    ,0 };
            const std::uint32_t dim2356KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   15  ,   55  ,   87  ,   249 ,   111 ,   319 ,   985 ,   2305    ,   1641    ,   12655   ,   7321    ,0 };
            const std::uint32_t dim2357KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   23  ,   49  ,   85  ,   31  ,   299 ,   391 ,   549 ,   3831    ,   1413    ,   13803   ,   30599   ,0 };
            const std::uint32_t dim2358KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   31  ,   39  ,   43  ,   253 ,   67  ,   321 ,   463 ,   2327    ,   6831    ,   10461   ,   18077   ,0 };
            const std::uint32_t dim2359KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   13  ,   13  ,   127 ,   175 ,   425 ,   567 ,   1663    ,   195 ,   1763    ,   13271   ,   1739    ,0 };
            const std::uint32_t dim2360KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   9   ,   33  ,   11  ,   167 ,   87  ,   901 ,   1625    ,   2055    ,   2475    ,   7241    ,   29717   ,0 };
            const std::uint32_t dim2361KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   15  ,   63  ,   127 ,   29  ,   227 ,   817 ,   637 ,   1873    ,   4885    ,   16299   ,   31243   ,0 };
            const std::uint32_t dim2362KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   17  ,   27  ,   81  ,   237 ,   283 ,   161 ,   1905    ,   1551    ,   6171    ,   4519    ,   11047   ,0 };
            const std::uint32_t dim2363KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   25  ,   23  ,   25  ,   1   ,   461 ,   623 ,   493 ,   827 ,   5795    ,   16065   ,   8401    ,0 };
            const std::uint32_t dim2364KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   29  ,   29  ,   91  ,   133 ,   91  ,   565 ,   1821    ,   269 ,   1731    ,   1499    ,   7975    ,0 };
            const std::uint32_t dim2365KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   3   ,   41  ,   99  ,   23  ,   239 ,   945 ,   219 ,   1127    ,   4919    ,   9713    ,   3321    ,0 };
            const std::uint32_t dim2366KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   25  ,   59  ,   59  ,   127 ,   83  ,   643 ,   881 ,   1671    ,   3521    ,   459 ,   15479   ,0 };
            const std::uint32_t dim2367KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   15  ,   23  ,   111 ,   225 ,   145 ,   703 ,   1643    ,   419 ,   4853    ,   7195    ,   20879   ,0 };
            const std::uint32_t dim2368KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   5   ,   31  ,   111 ,   151 ,   489 ,   629 ,   473 ,   1507    ,   117 ,   15305   ,   11011   ,0 };
            const std::uint32_t dim2369KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   1   ,   55  ,   55  ,   223 ,   489 ,   911 ,   1721    ,   3533    ,   5893    ,   2891    ,   8929    ,0 };
            const std::uint32_t dim2370KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   7   ,   43  ,   113 ,   99  ,   19  ,   681 ,   1765    ,   1983    ,   5477    ,   7531    ,   26507   ,0 };
            const std::uint32_t dim2371KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   9   ,   7   ,   77  ,   231 ,   345 ,   745 ,   285 ,   3213    ,   2611    ,   4449    ,   24621   ,0 };
            const std::uint32_t dim2372KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   21  ,   21  ,   3   ,   11  ,   131 ,   327 ,   1893    ,   33  ,   6947    ,   337 ,   8877    ,0 };
            const std::uint32_t dim2373KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   5   ,   11  ,   41  ,   7   ,   447 ,   625 ,   1231    ,   3621    ,   3785    ,   12351   ,   13829   ,0 };
            const std::uint32_t dim2374KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   29  ,   41  ,   11  ,   63  ,   357 ,   723 ,   1657    ,   91  ,   1373    ,   6383    ,   8327    ,0 };
            const std::uint32_t dim2375KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   23  ,   51  ,   85  ,   113 ,   103 ,   499 ,   1669    ,   3685    ,   63  ,   2853    ,   20859   ,0 };
            const std::uint32_t dim2376KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   31  ,   39  ,   15  ,   103 ,   365 ,   231 ,   443 ,   3213    ,   6951    ,   1715    ,   32301   ,0 };
            const std::uint32_t dim2377KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   19  ,   23  ,   13  ,   127 ,   475 ,   281 ,   1095    ,   473 ,   4955    ,   2217    ,   10427   ,0 };
            const std::uint32_t dim2378KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   17  ,   41  ,   47  ,   121 ,   131 ,   69  ,   1747    ,   3679    ,   2765    ,   4349    ,   32041   ,0 };
            const std::uint32_t dim2379KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   3   ,   47  ,   11  ,   127 ,   321 ,   669 ,   1283    ,   797 ,   6393    ,   12351   ,   5161    ,0 };
            const std::uint32_t dim2380KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   21  ,   37  ,   73  ,   15  ,   393 ,   173 ,   1461    ,   1437    ,   2367    ,   7171    ,   15123   ,0 };
            const std::uint32_t dim2381KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   7   ,   57  ,   29  ,   83  ,   241 ,   221 ,   1607    ,   1291    ,   4839    ,   11293   ,   1837    ,0 };
            const std::uint32_t dim2382KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   1   ,   31  ,   59  ,   143 ,   487 ,   317 ,   535 ,   1505    ,   3705    ,   9947    ,   6149    ,0 };
            const std::uint32_t dim2383KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   29  ,   31  ,   69  ,   63  ,   183 ,   173 ,   1965    ,   3331    ,   4473    ,   993 ,   4937    ,0 };
            const std::uint32_t dim2384KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   13  ,   13  ,   55  ,   43  ,   283 ,   897 ,   1019    ,   2761    ,   3237    ,   14661   ,   12309   ,0 };
            const std::uint32_t dim2385KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   9   ,   15  ,   1   ,   19  ,   227 ,   777 ,   1713    ,   3471    ,   2917    ,   1117    ,   16397   ,0 };
            const std::uint32_t dim2386KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   21  ,   19  ,   49  ,   3   ,   477 ,   659 ,   61  ,   2373    ,   6363    ,   13771   ,   5675    ,0 };
            const std::uint32_t dim2387KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   13  ,   23  ,   43  ,   253 ,   483 ,   975 ,   1629    ,   19  ,   6339    ,   13963   ,   6065    ,0 };
            const std::uint32_t dim2388KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   9   ,   31  ,   65  ,   1   ,   311 ,   67  ,   293 ,   667 ,   3685    ,   3589    ,   25251   ,0 };
            const std::uint32_t dim2389KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   29  ,   31  ,   47  ,   85  ,   431 ,   131 ,   1495    ,   1271    ,   6121    ,   7183    ,   20477   ,0 };
            const std::uint32_t dim2390KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   13  ,   37  ,   83  ,   201 ,   277 ,   643 ,   19  ,   2519    ,   2589    ,   2471    ,   19727   ,0 };
            const std::uint32_t dim2391KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   27  ,   13  ,   97  ,   183 ,   463 ,   639 ,   87  ,   181 ,   747 ,   3715    ,   16207   ,0 };
            const std::uint32_t dim2392KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   9   ,   29  ,   21  ,   191 ,   485 ,   211 ,   541 ,   69  ,   511 ,   9923    ,   24543   ,0 };
            const std::uint32_t dim2393KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   19  ,   43  ,   85  ,   189 ,   47  ,   723 ,   1211    ,   1259    ,   1645    ,   2983    ,   27195   ,0 };
            const std::uint32_t dim2394KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   17  ,   25  ,   103 ,   83  ,   389 ,   229 ,   1457    ,   4045    ,   161 ,   15471   ,   19929   ,0 };
            const std::uint32_t dim2395KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   5   ,   27  ,   55  ,   231 ,   245 ,   723 ,   479 ,   3761    ,   787 ,   12939   ,   30227   ,0 };
            const std::uint32_t dim2396KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   19  ,   39  ,   63  ,   27  ,   137 ,   399 ,   1353    ,   1143    ,   5835    ,   2013    ,   4107    ,0 };
            const std::uint32_t dim2397KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   5   ,   39  ,   45  ,   207 ,   7   ,   131 ,   961 ,   1715    ,   3761    ,   11501   ,   9803    ,0 };
            const std::uint32_t dim2398KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   17  ,   11  ,   23  ,   45  ,   417 ,   289 ,   1545    ,   2585    ,   1345    ,   15529   ,   8365    ,0 };
            const std::uint32_t dim2399KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   21  ,   27  ,   97  ,   23  ,   461 ,   983 ,   997 ,   1321    ,   2551    ,   5485    ,   23565   ,0 };
            const std::uint32_t dim2400KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   23  ,   19  ,   77  ,   103 ,   171 ,   553 ,   1767    ,   3255    ,   7955    ,   249 ,   32681   ,0 };
            const std::uint32_t dim2401KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   23  ,   43  ,   73  ,   15  ,   381 ,   245 ,   1389    ,   3693    ,   1975    ,   13629   ,   2079    ,0 };
            const std::uint32_t dim2402KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   23  ,   61  ,   79  ,   39  ,   345 ,   541 ,   875 ,   1375    ,   123 ,   15305   ,   13731   ,0 };
            const std::uint32_t dim2403KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   3   ,   17  ,   19  ,   11  ,   79  ,   415 ,   1791    ,   447 ,   6529    ,   11243   ,   10427   ,0 };
            const std::uint32_t dim2404KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   9   ,   31  ,   121 ,   247 ,   403 ,   935 ,   705 ,   2921    ,   3769    ,   625 ,   22905   ,0 };
            const std::uint32_t dim2405KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   19  ,   9   ,   5   ,   47  ,   135 ,   585 ,   1155    ,   1517    ,   4961    ,   15725   ,   7585    ,0 };
            const std::uint32_t dim2406KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   19  ,   57  ,   37  ,   69  ,   117 ,   485 ,   115 ,   2709    ,   1909    ,   12781   ,   19323   ,0 };
            const std::uint32_t dim2407KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   7   ,   1   ,   37  ,   39  ,   141 ,   1017    ,   993 ,   191 ,   6173    ,   8083    ,   9733    ,0 };
            const std::uint32_t dim2408KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   3   ,   21  ,   17  ,   55  ,   129 ,   353 ,   673 ,   3233    ,   6289    ,   10955   ,   19357   ,0 };
            const std::uint32_t dim2409KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   31  ,   31  ,   31  ,   105 ,   187 ,   839 ,   733 ,   1795    ,   5075    ,   1053    ,   613 ,0 };
            const std::uint32_t dim2410KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   9   ,   9   ,   23  ,   139 ,   417 ,   431 ,   1943    ,   3067    ,   267 ,   4401    ,   9847    ,0 };
            const std::uint32_t dim2411KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   23  ,   61  ,   61  ,   119 ,   383 ,   869 ,   503 ,   195 ,   1935    ,   4617    ,   21393   ,0 };
            const std::uint32_t dim2412KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   7   ,   15  ,   51  ,   53  ,   427 ,   499 ,   1829    ,   2533    ,   3029    ,   12485   ,   28425   ,0 };
            const std::uint32_t dim2413KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   9   ,   11  ,   55  ,   205 ,   255 ,   619 ,   1323    ,   1983    ,   15  ,   4237    ,   20983   ,0 };
            const std::uint32_t dim2414KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   15  ,   37  ,   109 ,   247 ,   179 ,   1005    ,   1111    ,   77  ,   4533    ,   12849   ,   25601   ,0 };
            const std::uint32_t dim2415KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   15  ,   25  ,   59  ,   117 ,   55  ,   755 ,   681 ,   649 ,   6041    ,   1695    ,   13719   ,0 };
            const std::uint32_t dim2416KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   15  ,   17  ,   117 ,   113 ,   197 ,   701 ,   773 ,   1097    ,   1267    ,   16093   ,   21555   ,0 };
            const std::uint32_t dim2417KuoInit[]        =   {   1   ,   3   ,   1   ,   5   ,   9   ,   57  ,   39  ,   171 ,   449 ,   507 ,   29  ,   3581    ,   1929    ,   12715   ,   24575   ,0 };
            const std::uint32_t dim2418KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   23  ,   1   ,   67  ,   153 ,   375 ,   333 ,   379 ,   3163    ,   8121    ,   13465   ,   27641   ,0 };
            const std::uint32_t dim2419KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   31  ,   27  ,   83  ,   243 ,   415 ,   997 ,   1787    ,   4021    ,   5955    ,   1861    ,   10511   ,0 };
            const std::uint32_t dim2420KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   13  ,   47  ,   69  ,   169 ,   185 ,   645 ,   1857    ,   3487    ,   1557    ,   9589    ,   7971    ,0 };
            const std::uint32_t dim2421KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   3   ,   1   ,   93  ,   97  ,   71  ,   433 ,   1371    ,   2495    ,   8171    ,   9101    ,   32435   ,0 };
            const std::uint32_t dim2422KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   3   ,   29  ,   37  ,   167 ,   169 ,   15  ,   1575    ,   1331    ,   7163    ,   1555    ,   32439   ,0 };
            const std::uint32_t dim2423KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   29  ,   11  ,   83  ,   135 ,   367 ,   37  ,   1455    ,   3939    ,   3383    ,   5291    ,   14269   ,0 };
            const std::uint32_t dim2424KuoInit[]        =   {   1   ,   1   ,   5   ,   15  ,   7   ,   63  ,   17  ,   45  ,   259 ,   57  ,   1933    ,   3101    ,   7871    ,   12633   ,   15789   ,0 };
            const std::uint32_t dim2425KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   19  ,   37  ,   89  ,   159 ,   487 ,   101 ,   1551    ,   3703    ,   4323    ,   9153    ,   6155    ,0 };
            const std::uint32_t dim2426KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   15  ,   49  ,   81  ,   51  ,   267 ,   761 ,   863 ,   2239    ,   7683    ,   15491   ,   28655   ,0 };
            const std::uint32_t dim2427KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   25  ,   53  ,   113 ,   117 ,   11  ,   1003    ,   539 ,   3603    ,   1007    ,   11329   ,   15099   ,0 };
            const std::uint32_t dim2428KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   9   ,   27  ,   125 ,   231 ,   301 ,   461 ,   2031    ,   183 ,   6361    ,   10811   ,   29425   ,0 };
            const std::uint32_t dim2429KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   3   ,   37  ,   65  ,   127 ,   487 ,   611 ,   867 ,   2361    ,   5243    ,   11829   ,   31297   ,0 };
            const std::uint32_t dim2430KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   9   ,   39  ,   31  ,   219 ,   77  ,   97  ,   1061    ,   435 ,   2449    ,   14751   ,   20273   ,0 };
            const std::uint32_t dim2431KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   1   ,   23  ,   41  ,   239 ,   183 ,   287 ,   969 ,   1325    ,   3553    ,   6751    ,   14679   ,0 };
            const std::uint32_t dim2432KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   17  ,   61  ,   47  ,   207 ,   509 ,   601 ,   1539    ,   345 ,   3723    ,   5415    ,   11667   ,0 };
            const std::uint32_t dim2433KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   23  ,   33  ,   25  ,   165 ,   345 ,   569 ,   983 ,   2857    ,   1563    ,   1737    ,   19285   ,0 };
            const std::uint32_t dim2434KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   3   ,   43  ,   107 ,   229 ,   223 ,   583 ,   1495    ,   3487    ,   7497    ,   10367   ,   20575   ,0 };
            const std::uint32_t dim2435KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   21  ,   49  ,   17  ,   195 ,   115 ,   797 ,   1489    ,   1587    ,   7847    ,   11013   ,   14547   ,0 };
            const std::uint32_t dim2436KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   9   ,   29  ,   19  ,   245 ,   153 ,   779 ,   1311    ,   425 ,   5809    ,   4457    ,   6905    ,0 };
            const std::uint32_t dim2437KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   21  ,   33  ,   13  ,   193 ,   343 ,   971 ,   1315    ,   1989    ,   1969    ,   9227    ,   8881    ,0 };
            const std::uint32_t dim2438KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   3   ,   59  ,   87  ,   205 ,   261 ,   567 ,   557 ,   1143    ,   6923    ,   9451    ,   20239   ,0 };
            const std::uint32_t dim2439KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   29  ,   35  ,   127 ,   123 ,   173 ,   807 ,   1279    ,   2413    ,   1899    ,   11657   ,   22257   ,0 };
            const std::uint32_t dim2440KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   23  ,   35  ,   125 ,   129 ,   239 ,   951 ,   499 ,   1609    ,   4643    ,   339 ,   26701   ,0 };
            const std::uint32_t dim2441KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   9   ,   15  ,   23  ,   55  ,   105 ,   81  ,   591 ,   947 ,   3761    ,   7351    ,   25697   ,0 };
            const std::uint32_t dim2442KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   23  ,   17  ,   127 ,   149 ,   227 ,   1005    ,   839 ,   3391    ,   5761    ,   10431   ,   31899   ,0 };
            const std::uint32_t dim2443KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   23  ,   7   ,   11  ,   3   ,   77  ,   457 ,   375 ,   3823    ,   5447    ,   8339    ,   18847   ,0 };
            const std::uint32_t dim2444KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   29  ,   1   ,   19  ,   39  ,   23  ,   285 ,   569 ,   2979    ,   7029    ,   11311   ,   18269   ,0 };
            const std::uint32_t dim2445KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   21  ,   19  ,   85  ,   211 ,   437 ,   185 ,   597 ,   787 ,   4555    ,   2853    ,   18493   ,0 };
            const std::uint32_t dim2446KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   11  ,   27  ,   25  ,   245 ,   55  ,   869 ,   323 ,   3999    ,   2639    ,   9385    ,   26823   ,0 };
            const std::uint32_t dim2447KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   19  ,   61  ,   51  ,   111 ,   115 ,   721 ,   893 ,   23  ,   6375    ,   5101    ,   25567   ,0 };
            const std::uint32_t dim2448KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   9   ,   13  ,   9   ,   241 ,   297 ,   391 ,   1529    ,   3843    ,   737 ,   5897    ,   23469   ,0 };
            const std::uint32_t dim2449KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   31  ,   53  ,   43  ,   219 ,   81  ,   507 ,   1627    ,   3503    ,   817 ,   6533    ,   31633   ,0 };
            const std::uint32_t dim2450KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   13  ,   59  ,   13  ,   185 ,   387 ,   869 ,   1013    ,   2291    ,   4945    ,   11493   ,   7785    ,0 };
            const std::uint32_t dim2451KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   31  ,   35  ,   11  ,   225 ,   235 ,   893 ,   1749    ,   2393    ,   5317    ,   10069   ,   8569    ,0 };
            const std::uint32_t dim2452KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   5   ,   15  ,   93  ,   25  ,   503 ,   205 ,   65  ,   2563    ,   7971    ,   2917    ,   19687   ,0 };
            const std::uint32_t dim2453KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   1   ,   37  ,   127 ,   63  ,   339 ,   121 ,   1895    ,   1943    ,   7527    ,   15869   ,   20533   ,0 };
            const std::uint32_t dim2454KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   19  ,   25  ,   87  ,   27  ,   279 ,   419 ,   1261    ,   613 ,   7687    ,   5301    ,   6761    ,0 };
            const std::uint32_t dim2455KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   13  ,   33  ,   59  ,   235 ,   471 ,   811 ,   695 ,   2727    ,   5615    ,   6269    ,   13469   ,0 };
            const std::uint32_t dim2456KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   17  ,   23  ,   123 ,   71  ,   15  ,   1005    ,   973 ,   411 ,   2627    ,   1967    ,   25597   ,0 };
            const std::uint32_t dim2457KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   3   ,   61  ,   71  ,   217 ,   377 ,   613 ,   1819    ,   141 ,   6265    ,   9223    ,   20635   ,0 };
            const std::uint32_t dim2458KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   15  ,   1   ,   39  ,   121 ,   83  ,   57  ,   1133    ,   3165    ,   7675    ,   13715   ,   11383   ,0 };
            const std::uint32_t dim2459KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   9   ,   3   ,   97  ,   223 ,   493 ,   77  ,   159 ,   2921    ,   5475    ,   9289    ,   20925   ,0 };
            const std::uint32_t dim2460KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   29  ,   13  ,   87  ,   219 ,   327 ,   879 ,   883 ,   1637    ,   3451    ,   13939   ,   8203    ,0 };
            const std::uint32_t dim2461KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   25  ,   21  ,   95  ,   129 ,   343 ,   9   ,   1415    ,   2965    ,   747 ,   7297    ,   24293   ,0 };
            const std::uint32_t dim2462KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   23  ,   47  ,   57  ,   31  ,   359 ,   1017    ,   769 ,   2761    ,   1933    ,   6091    ,   6475    ,0 };
            const std::uint32_t dim2463KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   27  ,   45  ,   125 ,   67  ,   145 ,   581 ,   157 ,   2153    ,   2727    ,   8025    ,   28165   ,0 };
            const std::uint32_t dim2464KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   7   ,   53  ,   27  ,   161 ,   343 ,   139 ,   1651    ,   1275    ,   2981    ,   9027    ,   31175   ,0 };
            const std::uint32_t dim2465KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   7   ,   15  ,   81  ,   229 ,   115 ,   849 ,   459 ,   1651    ,   3867    ,   7029    ,   6741    ,0 };
            const std::uint32_t dim2466KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   31  ,   45  ,   17  ,   107 ,   467 ,   401 ,   1473    ,   1953    ,   3779    ,   11237   ,   31257   ,0 };
            const std::uint32_t dim2467KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   3   ,   27  ,   45  ,   217 ,   133 ,   515 ,   1487    ,   1427    ,   1999    ,   12979   ,   3543    ,0 };
            const std::uint32_t dim2468KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   17  ,   31  ,   123 ,   205 ,   263 ,   963 ,   1697    ,   2453    ,   1249    ,   603 ,   8581    ,0 };
            const std::uint32_t dim2469KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   23  ,   9   ,   23  ,   251 ,   489 ,   393 ,   1103    ,   3273    ,   5703    ,   3033    ,   22631   ,0 };
            const std::uint32_t dim2470KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   23  ,   29  ,   49  ,   233 ,   461 ,   795 ,   991 ,   3695    ,   4715    ,   7211    ,   3695    ,0 };
            const std::uint32_t dim2471KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   21  ,   11  ,   33  ,   69  ,   347 ,   535 ,   25  ,   3465    ,   2825    ,   9345    ,   4485    ,0 };
            const std::uint32_t dim2472KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   23  ,   47  ,   65  ,   209 ,   357 ,   363 ,   1979    ,   289 ,   35  ,   4459    ,   17929   ,0 };
            const std::uint32_t dim2473KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   19  ,   17  ,   125 ,   231 ,   221 ,   953 ,   2041    ,   2359    ,   5925    ,   15693   ,   30859   ,0 };
            const std::uint32_t dim2474KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   31  ,   11  ,   11  ,   215 ,   335 ,   153 ,   1459    ,   2303    ,   3471    ,   7415    ,   3783    ,0 };
            const std::uint32_t dim2475KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   11  ,   55  ,   47  ,   43  ,   355 ,   469 ,   963 ,   383 ,   667 ,   2233    ,   27759   ,0 };
            const std::uint32_t dim2476KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   23  ,   29  ,   27  ,   135 ,   359 ,   111 ,   387 ,   3021    ,   817 ,   4211    ,   17243   ,0 };
            const std::uint32_t dim2477KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   25  ,   27  ,   63  ,   89  ,   195 ,   359 ,   413 ,   3509    ,   3831    ,   4785    ,   30097   ,0 };
            const std::uint32_t dim2478KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   11  ,   29  ,   29  ,   25  ,   445 ,   643 ,   261 ,   3901    ,   3019    ,   14213   ,   16115   ,0 };
            const std::uint32_t dim2479KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   21  ,   31  ,   7   ,   255 ,   207 ,   535 ,   1033    ,   1017    ,   3791    ,   11455   ,   31701   ,0 };
            const std::uint32_t dim2480KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   15  ,   37  ,   79  ,   205 ,   439 ,   609 ,   1433    ,   3333    ,   6583    ,   9689    ,   14979   ,0 };
            const std::uint32_t dim2481KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   31  ,   27  ,   53  ,   101 ,   427 ,   773 ,   1877    ,   1715    ,   6177    ,   11851   ,   17989   ,0 };
            const std::uint32_t dim2482KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   21  ,   11  ,   101 ,   203 ,   49  ,   543 ,   1979    ,   1469    ,   6701    ,   9963    ,   7793    ,0 };
            const std::uint32_t dim2483KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   15  ,   47  ,   123 ,   141 ,   433 ,   783 ,   211 ,   1489    ,   4983    ,   6417    ,   29767   ,0 };
            const std::uint32_t dim2484KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   1   ,   41  ,   109 ,   13  ,   465 ,   959 ,   431 ,   543 ,   4681    ,   8573    ,   7889    ,0 };
            const std::uint32_t dim2485KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   15  ,   43  ,   15  ,   63  ,   145 ,   859 ,   939 ,   629 ,   7077    ,   5617    ,   16779   ,0 };
            const std::uint32_t dim2486KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   23  ,   63  ,   67  ,   139 ,   219 ,   257 ,   943 ,   1501    ,   827 ,   10855   ,   10035   ,0 };
            const std::uint32_t dim2487KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   9   ,   47  ,   27  ,   119 ,   231 ,   767 ,   999 ,   3553    ,   7683    ,   5399    ,   11553   ,0 };
            const std::uint32_t dim2488KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   15  ,   13  ,   35  ,   139 ,   463 ,   985 ,   553 ,   3997    ,   2935    ,   7707    ,   2511    ,0 };
            const std::uint32_t dim2489KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   23  ,   53  ,   103 ,   1   ,   409 ,   853 ,   737 ,   2077    ,   523 ,   1839    ,   32145   ,0 };
            const std::uint32_t dim2490KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   23  ,   7   ,   77  ,   185 ,   371 ,   447 ,   499 ,   569 ,   6647    ,   501 ,   27649   ,0 };
            const std::uint32_t dim2491KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   19  ,   31  ,   119 ,   157 ,   385 ,   427 ,   1411    ,   4031    ,   4199    ,   14567   ,   8133    ,0 };
            const std::uint32_t dim2492KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   31  ,   3   ,   123 ,   149 ,   209 ,   467 ,   1619    ,   879 ,   5949    ,   7295    ,   25165   ,0 };
            const std::uint32_t dim2493KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   31  ,   47  ,   111 ,   129 ,   359 ,   385 ,   463 ,   3363    ,   6823    ,   10751   ,   4473    ,0 };
            const std::uint32_t dim2494KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   5   ,   39  ,   71  ,   45  ,   439 ,   161 ,   597 ,   2093    ,   1725    ,   11285   ,   18149   ,0 };
            const std::uint32_t dim2495KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   21  ,   55  ,   115 ,   199 ,   339 ,   425 ,   71  ,   305 ,   1161    ,   3359    ,   16835   ,0 };
            const std::uint32_t dim2496KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   1   ,   53  ,   51  ,   31  ,   57  ,   581 ,   147 ,   903 ,   7269    ,   1461    ,   7417    ,0 };
            const std::uint32_t dim2497KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   17  ,   31  ,   65  ,   195 ,   47  ,   575 ,   1877    ,   1603    ,   3043    ,   5385    ,   15177   ,0 };
            const std::uint32_t dim2498KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   15  ,   7   ,   121 ,   51  ,   67  ,   391 ,   1553    ,   1817    ,   6503    ,   2907    ,   3611    ,0 };
            const std::uint32_t dim2499KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   13  ,   51  ,   95  ,   19  ,   315 ,   549 ,   1417    ,   2073    ,   485 ,   5257    ,   32419   ,0 };
            const std::uint32_t dim2500KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   31  ,   63  ,   107 ,   103 ,   173 ,   681 ,   211 ,   3283    ,   2413    ,   2073    ,   24497   ,0 };
            const std::uint32_t dim2501KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   3   ,   41  ,   49  ,   81  ,   289 ,   177 ,   699 ,   1305    ,   7867    ,   4699    ,   27669   ,0 };
            const std::uint32_t dim2502KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   7   ,   15  ,   73  ,   57  ,   319 ,   959 ,   701 ,   2071    ,   1587    ,   4701    ,   2595    ,0 };
            const std::uint32_t dim2503KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   7   ,   1   ,   29  ,   129 ,   361 ,   619 ,   1405    ,   2185    ,   6631    ,   3505    ,   391 ,0 };
            const std::uint32_t dim2504KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   19  ,   9   ,   31  ,   63  ,   149 ,   181 ,   299 ,   2755    ,   1511    ,   5745    ,   20323   ,0 };
            const std::uint32_t dim2505KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   23  ,   5   ,   29  ,   175 ,   119 ,   25  ,   319 ,   835 ,   1339    ,   5429    ,   7175    ,0 };
            const std::uint32_t dim2506KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   31  ,   57  ,   55  ,   181 ,   473 ,   229 ,   309 ,   1567    ,   5063    ,   9745    ,   3713    ,0 };
            const std::uint32_t dim2507KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   1   ,   15  ,   23  ,   175 ,   71  ,   53  ,   1749    ,   743 ,   285 ,   49  ,   7389    ,0 };
            const std::uint32_t dim2508KuoInit[]        =   {   1   ,   3   ,   1   ,   5   ,   7   ,   39  ,   75  ,   177 ,   259 ,   975 ,   257 ,   1497    ,   1565    ,   6973    ,   3827    ,0 };
            const std::uint32_t dim2509KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   1   ,   39  ,   43  ,   213 ,   291 ,   941 ,   613 ,   3041    ,   1859    ,   10755   ,   29831   ,0 };
            const std::uint32_t dim2510KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   17  ,   43  ,   15  ,   135 ,   473 ,   989 ,   429 ,   3287    ,   3699    ,   14349   ,   16311   ,0 };
            const std::uint32_t dim2511KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   1   ,   51  ,   59  ,   203 ,   383 ,   731 ,   171 ,   1259    ,   5833    ,   12029   ,   18099   ,0 };
            const std::uint32_t dim2512KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   19  ,   63  ,   125 ,   57  ,   429 ,   93  ,   1179    ,   2707    ,   449 ,   2213    ,   4759    ,0 };
            const std::uint32_t dim2513KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   19  ,   11  ,   107 ,   127 ,   359 ,   759 ,   503 ,   761 ,   6817    ,   15343   ,   13777   ,0 };
            const std::uint32_t dim2514KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   21  ,   49  ,   67  ,   179 ,   241 ,   403 ,   769 ,   3341    ,   1845    ,   2855    ,   3825    ,0 };
            const std::uint32_t dim2515KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   7   ,   29  ,   71  ,   35  ,   389 ,   297 ,   673 ,   1353    ,   6781    ,   5633    ,   12459   ,0 };
            const std::uint32_t dim2516KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   13  ,   15  ,   11  ,   57  ,   143 ,   35  ,   809 ,   2295    ,   6497    ,   455 ,   23689   ,0 };
            const std::uint32_t dim2517KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   23  ,   39  ,   39  ,   211 ,   335 ,   537 ,   1569    ,   3989    ,   5777    ,   12951   ,   22841   ,0 };
            const std::uint32_t dim2518KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   23  ,   17  ,   107 ,   237 ,   241 ,   533 ,   57  ,   3421    ,   263 ,   889 ,   28841   ,0 };
            const std::uint32_t dim2519KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   11  ,   29  ,   17  ,   141 ,   431 ,   809 ,   1227    ,   2835    ,   2955    ,   11823   ,   23061   ,0 };
            const std::uint32_t dim2520KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   5   ,   51  ,   73  ,   43  ,   75  ,   985 ,   1665    ,   1369    ,   519 ,   6379    ,   8665    ,0 };
            const std::uint32_t dim2521KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   17  ,   21  ,   9   ,   173 ,   333 ,   689 ,   277 ,   1755    ,   5173    ,   7651    ,   30597   ,0 };
            const std::uint32_t dim2522KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   3   ,   59  ,   59  ,   221 ,   177 ,   819 ,   1483    ,   1945    ,   4725    ,   4821    ,   3709    ,0 };
            const std::uint32_t dim2523KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   19  ,   35  ,   93  ,   47  ,   49  ,   861 ,   561 ,   753 ,   8047    ,   419 ,   4335    ,0 };
            const std::uint32_t dim2524KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   31  ,   3   ,   97  ,   177 ,   443 ,   55  ,   1541    ,   2627    ,   6129    ,   4165    ,   3079    ,0 };
            const std::uint32_t dim2525KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   13  ,   13  ,   13  ,   29  ,   309 ,   679 ,   1893    ,   3629    ,   513 ,   16333   ,   25371   ,0 };
            const std::uint32_t dim2526KuoInit[]        =   {   1   ,   3   ,   1   ,   5   ,   3   ,   23  ,   85  ,   169 ,   143 ,   537 ,   1387    ,   3997    ,   3659    ,   12107   ,   11689   ,0 };
            const std::uint32_t dim2527KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   9   ,   7   ,   11  ,   59  ,   325 ,   855 ,   1853    ,   855 ,   5743    ,   7625    ,   10381   ,0 };
            const std::uint32_t dim2528KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   5   ,   37  ,   109 ,   101 ,   243 ,   301 ,   1849    ,   1633    ,   4451    ,   8859    ,   22017   ,0 };
            const std::uint32_t dim2529KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   7   ,   1   ,   9   ,   1   ,   411 ,   941 ,   153 ,   2709    ,   389 ,   9403    ,   24103   ,0 };
            const std::uint32_t dim2530KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   17  ,   19  ,   105 ,   127 ,   271 ,   543 ,   449 ,   1385    ,   7387    ,   8335    ,   741 ,0 };
            const std::uint32_t dim2531KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   23  ,   21  ,   43  ,   17  ,   357 ,   499 ,   649 ,   1121    ,   7655    ,   15623   ,   12975   ,0 };
            const std::uint32_t dim2532KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   1   ,   57  ,   37  ,   91  ,   159 ,   1013    ,   653 ,   3371    ,   4857    ,   441 ,   17729   ,0 };
            const std::uint32_t dim2533KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   15  ,   31  ,   71  ,   77  ,   113 ,   47  ,   1597    ,   43  ,   1139    ,   3191    ,   31775   ,0 };
            const std::uint32_t dim2534KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   19  ,   39  ,   93  ,   15  ,   433 ,   867 ,   1091    ,   2333    ,   6113    ,   13005   ,   13309   ,0 };
            const std::uint32_t dim2535KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   5   ,   57  ,   21  ,   7   ,   267 ,   79  ,   1829    ,   43  ,   211 ,   2795    ,   18739   ,0 };
            const std::uint32_t dim2536KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   25  ,   59  ,   93  ,   213 ,   23  ,   281 ,   625 ,   439 ,   1449    ,   2259    ,   31713   ,0 };
            const std::uint32_t dim2537KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   9   ,   13  ,   41  ,   171 ,   365 ,   907 ,   395 ,   3465    ,   6433    ,   33  ,   17191   ,0 };
            const std::uint32_t dim2538KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   3   ,   41  ,   45  ,   55  ,   413 ,   579 ,   1215    ,   3983    ,   1201    ,   3019    ,   16401   ,0 };
            const std::uint32_t dim2539KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   9   ,   25  ,   111 ,   33  ,   359 ,   427 ,   63  ,   4005    ,   2753    ,   15063   ,   1925    ,0 };
            const std::uint32_t dim2540KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   21  ,   55  ,   15  ,   5   ,   121 ,   867 ,   1645    ,   2387    ,   1167    ,   13865   ,   15899   ,0 };
            const std::uint32_t dim2541KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   13  ,   49  ,   9   ,   173 ,   291 ,   517 ,   143 ,   399 ,   7545    ,   7225    ,   29753   ,0 };
            const std::uint32_t dim2542KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   29  ,   23  ,   105 ,   165 ,   35  ,   325 ,   983 ,   215 ,   2537    ,   8661    ,   1715    ,0 };
            const std::uint32_t dim2543KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   19  ,   1   ,   91  ,   77  ,   311 ,   715 ,   347 ,   1705    ,   1045    ,   15003   ,   10961   ,0 };
            const std::uint32_t dim2544KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   5   ,   3   ,   73  ,   159 ,   113 ,   201 ,   257 ,   181 ,   551 ,   1189    ,   30719   ,0 };
            const std::uint32_t dim2545KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   15  ,   57  ,   69  ,   85  ,   133 ,   735 ,   429 ,   2087    ,   1453    ,   14277   ,   15245   ,0 };
            const std::uint32_t dim2546KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   27  ,   5   ,   27  ,   247 ,   401 ,   841 ,   1723    ,   3717    ,   3545    ,   3123    ,   27441   ,0 };
            const std::uint32_t dim2547KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   5   ,   11  ,   97  ,   117 ,   331 ,   843 ,   1101    ,   2977    ,   5123    ,   5761    ,   2019    ,0 };
            const std::uint32_t dim2548KuoInit[]        =   {   1   ,   3   ,   1   ,   5   ,   31  ,   25  ,   53  ,   191 ,   265 ,   961 ,   1695    ,   1847    ,   6377    ,   13261   ,   8853    ,0 };
            const std::uint32_t dim2549KuoInit[]        =   {   1   ,   3   ,   1   ,   5   ,   5   ,   29  ,   85  ,   3   ,   127 ,   407 ,   1511    ,   549 ,   4015    ,   15327   ,   9167    ,0 };
            const std::uint32_t dim2550KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   9   ,   11  ,   1   ,   217 ,   53  ,   201 ,   1237    ,   2663    ,   7429    ,   7349    ,   5619    ,0 };
            const std::uint32_t dim2551KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   13  ,   63  ,   21  ,   173 ,   59  ,   881 ,   351 ,   1285    ,   7155    ,   6665    ,   25117   ,0 };
            const std::uint32_t dim2552KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   3   ,   43  ,   103 ,   227 ,   397 ,   75  ,   1211    ,   2959    ,   3507    ,   3105    ,   21739   ,0 };
            const std::uint32_t dim2553KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   1   ,   1   ,   5   ,   3   ,   41  ,   243 ,   1317    ,   2205    ,   4079    ,   7447    ,   22493   ,0 };
            const std::uint32_t dim2554KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   7   ,   39  ,   23  ,   171 ,   263 ,   375 ,   805 ,   2309    ,   7123    ,   4935    ,   4517    ,0 };
            const std::uint32_t dim2555KuoInit[]        =   {   1   ,   1   ,   5   ,   15  ,   5   ,   47  ,   35  ,   15  ,   131 ,   875 ,   1771    ,   3001    ,   951 ,   14269   ,   6395    ,0 };
            const std::uint32_t dim2556KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   27  ,   1   ,   59  ,   247 ,   295 ,   229 ,   309 ,   213 ,   6661    ,   10415   ,   17855   ,0 };
            const std::uint32_t dim2557KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   15  ,   61  ,   47  ,   175 ,   279 ,   221 ,   1665    ,   3475    ,   4171    ,   15515   ,   30835   ,0 };
            const std::uint32_t dim2558KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   29  ,   21  ,   61  ,   123 ,   57  ,   839 ,   399 ,   3069    ,   4617    ,   7051    ,   3245    ,0 };
            const std::uint32_t dim2559KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   27  ,   57  ,   83  ,   163 ,   499 ,   901 ,   855 ,   2049    ,   2993    ,   10323   ,   3391    ,0 };
            const std::uint32_t dim2560KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   17  ,   5   ,   23  ,   51  ,   445 ,   639 ,   811 ,   139 ,   2863    ,   9447    ,   25971   ,0 };
            const std::uint32_t dim2561KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   31  ,   43  ,   75  ,   251 ,   9   ,   239 ,   1573    ,   871 ,   2211    ,   15057   ,   879 ,0 };
            const std::uint32_t dim2562KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   23  ,   39  ,   69  ,   79  ,   335 ,   729 ,   1807    ,   1497    ,   2363    ,   8713    ,   3987    ,0 };
            const std::uint32_t dim2563KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   27  ,   9   ,   1   ,   5   ,   207 ,   217 ,   1097    ,   2737    ,   6815    ,   9969    ,   21731   ,0 };
            const std::uint32_t dim2564KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   9   ,   33  ,   71  ,   85  ,   15  ,   323 ,   1955    ,   1299    ,   4439    ,   6413    ,   23055   ,0 };
            const std::uint32_t dim2565KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   15  ,   11  ,   75  ,   201 ,   5   ,   69  ,   1067    ,   2287    ,   8099    ,   11293   ,   22547   ,0 };
            const std::uint32_t dim2566KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   19  ,   1   ,   63  ,   195 ,   463 ,   463 ,   1741    ,   915 ,   1289    ,   11275   ,   16383   ,0 };
            const std::uint32_t dim2567KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   3   ,   53  ,   51  ,   95  ,   389 ,   385 ,   1621    ,   955 ,   137 ,   8523    ,   24087   ,0 };
            const std::uint32_t dim2568KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   25  ,   27  ,   49  ,   27  ,   459 ,   979 ,   277 ,   2917    ,   6639    ,   3471    ,   20407   ,0 };
            const std::uint32_t dim2569KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   19  ,   25  ,   75  ,   47  ,   395 ,   269 ,   1445    ,   287 ,   4563    ,   8817    ,   10645   ,0 };
            const std::uint32_t dim2570KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   5   ,   9   ,   59  ,   177 ,   463 ,   683 ,   1917    ,   1189    ,   2423    ,   6967    ,   433 ,0 };
            const std::uint32_t dim2571KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   11  ,   53  ,   101 ,   81  ,   89  ,   419 ,   1605    ,   3719    ,   5449    ,   4303    ,   11235   ,0 };
            const std::uint32_t dim2572KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   7   ,   55  ,   5   ,   133 ,   273 ,   757 ,   313 ,   3451    ,   7837    ,   14543   ,   1607    ,0 };
            const std::uint32_t dim2573KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   9   ,   13  ,   103 ,   95  ,   301 ,   637 ,   1951    ,   2577    ,   2571    ,   7881    ,   27057   ,0 };
            const std::uint32_t dim2574KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   25  ,   17  ,   119 ,   11  ,   7   ,   141 ,   1219    ,   3091    ,   1737    ,   16355   ,   2807    ,0 };
            const std::uint32_t dim2575KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   3   ,   55  ,   59  ,   193 ,   23  ,   643 ,   159 ,   3393    ,   2671    ,   14737   ,   21193   ,0 };
            const std::uint32_t dim2576KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   9   ,   11  ,   109 ,   227 ,   333 ,   861 ,   915 ,   3239    ,   6199    ,   9555    ,   28563   ,0 };
            const std::uint32_t dim2577KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   1   ,   33  ,   51  ,   169 ,   291 ,   159 ,   1983    ,   173 ,   4133    ,   11477   ,   31525   ,0 };
            const std::uint32_t dim2578KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   31  ,   39  ,   47  ,   195 ,   421 ,   949 ,   311 ,   1537    ,   8009    ,   6273    ,   10893   ,0 };
            const std::uint32_t dim2579KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   17  ,   19  ,   37  ,   211 ,   245 ,   553 ,   769 ,   2131    ,   2819    ,   16119   ,   25851   ,0 };
            const std::uint32_t dim2580KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   7   ,   3   ,   63  ,   141 ,   465 ,   367 ,   949 ,   3997    ,   5217    ,   3425    ,   31161   ,0 };
            const std::uint32_t dim2581KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   19  ,   35  ,   91  ,   115 ,   153 ,   127 ,   231 ,   3723    ,   7911    ,   4421    ,   2271    ,0 };
            const std::uint32_t dim2582KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   17  ,   57  ,   49  ,   151 ,   263 ,   89  ,   1635    ,   2991    ,   7011    ,   13243   ,   1473    ,0 };
            const std::uint32_t dim2583KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   21  ,   59  ,   53  ,   179 ,   113 ,   839 ,   649 ,   2083    ,   7015    ,   5507    ,   9539    ,0 };
            const std::uint32_t dim2584KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   13  ,   49  ,   97  ,   81  ,   255 ,   973 ,   275 ,   2005    ,   5493    ,   11019   ,   14427   ,0 };
            const std::uint32_t dim2585KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   5   ,   53  ,   27  ,   197 ,   269 ,   699 ,   285 ,   3725    ,   7681    ,   3767    ,   11881   ,0 };
            const std::uint32_t dim2586KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   15  ,   15  ,   11  ,   245 ,   419 ,   559 ,   727 ,   1545    ,   1821    ,   5655    ,   26971   ,0 };
            const std::uint32_t dim2587KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   5   ,   1   ,   77  ,   211 ,   139 ,   949 ,   1945    ,   3327    ,   6699    ,   6227    ,   9769    ,0 };
            const std::uint32_t dim2588KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   3   ,   9   ,   113 ,   17  ,   283 ,   939 ,   1941    ,   19  ,   7431    ,   14503   ,   24541   ,0 };
            const std::uint32_t dim2589KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   1   ,   57  ,   17  ,   85  ,   371 ,   491 ,   775 ,   2093    ,   5615    ,   4977    ,   30995   ,0 };
            const std::uint32_t dim2590KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   1   ,   61  ,   75  ,   163 ,   307 ,   527 ,   1821    ,   1291    ,   5761    ,   9983    ,   4647    ,0 };
            const std::uint32_t dim2591KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   7   ,   61  ,   9   ,   203 ,   255 ,   293 ,   1683    ,   1081    ,   3179    ,   13283   ,   13759   ,0 };
            const std::uint32_t dim2592KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   5   ,   25  ,   23  ,   97  ,   37  ,   277 ,   1787    ,   2709    ,   6201    ,   8041    ,   2301    ,0 };
            const std::uint32_t dim2593KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   21  ,   57  ,   33  ,   13  ,   307 ,   427 ,   1577    ,   2043    ,   8131    ,   11723   ,   14353   ,0 };
            const std::uint32_t dim2594KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   19  ,   39  ,   63  ,   11  ,   139 ,   173 ,   517 ,   1597    ,   3871    ,   15533   ,   4123    ,0 };
            const std::uint32_t dim2595KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   19  ,   43  ,   123 ,   127 ,   237 ,   599 ,   893 ,   3645    ,   947 ,   12565   ,   9367    ,0 };
            const std::uint32_t dim2596KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   27  ,   9   ,   119 ,   251 ,   499 ,   777 ,   1667    ,   1699    ,   3431    ,   2727    ,   7097    ,0 };
            const std::uint32_t dim2597KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   7   ,   25  ,   95  ,   143 ,   319 ,   659 ,   1567    ,   1391    ,   5149    ,   15177   ,   6583    ,0 };
            const std::uint32_t dim2598KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   7   ,   39  ,   125 ,   219 ,   405 ,   739 ,   1267    ,   3065    ,   7529    ,   3195    ,   21889   ,0 };
            const std::uint32_t dim2599KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   27  ,   13  ,   87  ,   129 ,   451 ,   997 ,   103 ,   1667    ,   545 ,   6341    ,   3105    ,0 };
            const std::uint32_t dim2600KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   11  ,   43  ,   95  ,   205 ,   445 ,   919 ,   1353    ,   2435    ,   269 ,   3221    ,   8983    ,0 };
            const std::uint32_t dim2601KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   5   ,   47  ,   15  ,   127 ,   47  ,   89  ,   1409    ,   1935    ,   2047    ,   10629   ,   4867    ,0 };
            const std::uint32_t dim2602KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   21  ,   51  ,   31  ,   175 ,   337 ,   643 ,   1233    ,   1049    ,   569 ,   3383    ,   18771   ,0 };
            const std::uint32_t dim2603KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   7   ,   7   ,   29  ,   139 ,   65  ,   621 ,   363 ,   513 ,   4149    ,   5225    ,   11595   ,0 };
            const std::uint32_t dim2604KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   11  ,   31  ,   43  ,   223 ,   249 ,   661 ,   123 ,   2725    ,   5179    ,   13237   ,   10483   ,0 };
            const std::uint32_t dim2605KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   5   ,   35  ,   121 ,   193 ,   33  ,   343 ,   413 ,   1879    ,   8013    ,   11161   ,   7945    ,0 };
            const std::uint32_t dim2606KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   27  ,   43  ,   123 ,   25  ,   45  ,   279 ,   979 ,   1121    ,   1041    ,   3757    ,   22217   ,0 };
            const std::uint32_t dim2607KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   29  ,   45  ,   29  ,   215 ,   39  ,   679 ,   799 ,   1491    ,   885 ,   15475   ,   29269   ,0 };
            const std::uint32_t dim2608KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   1   ,   5   ,   49  ,   181 ,   441 ,   691 ,   639 ,   859 ,   2785    ,   3237    ,   1703    ,0 };
            const std::uint32_t dim2609KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   19  ,   1   ,   41  ,   131 ,   469 ,   999 ,   1665    ,   2309    ,   4447    ,   13851   ,   7063    ,0 };
            const std::uint32_t dim2610KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   21  ,   53  ,   51  ,   155 ,   41  ,   43  ,   127 ,   1653    ,   6237    ,   10481   ,   22557   ,0 };
            const std::uint32_t dim2611KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   31  ,   21  ,   39  ,   177 ,   283 ,   535 ,   771 ,   3783    ,   3033    ,   10971   ,   8691    ,0 };
            const std::uint32_t dim2612KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   25  ,   57  ,   13  ,   139 ,   169 ,   717 ,   795 ,   2337    ,   7347    ,   6951    ,   20509   ,0 };
            const std::uint32_t dim2613KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   1   ,   29  ,   27  ,   21  ,   259 ,   889 ,   83  ,   3295    ,   3699    ,   1523    ,   6227    ,0 };
            const std::uint32_t dim2614KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   9   ,   37  ,   35  ,   95  ,   217 ,   335 ,   865 ,   3093    ,   3077    ,   9831    ,   12173   ,0 };
            const std::uint32_t dim2615KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   31  ,   7   ,   69  ,   193 ,   459 ,   967 ,   481 ,   3271    ,   677 ,   13131   ,   22665   ,0 };
            const std::uint32_t dim2616KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   13  ,   31  ,   43  ,   155 ,   465 ,   303 ,   1153    ,   1591    ,   7793    ,   921 ,   12805   ,0 };
            const std::uint32_t dim2617KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   23  ,   59  ,   3   ,   151 ,   391 ,   729 ,   913 ,   899 ,   1793    ,   10173   ,   19681   ,0 };
            const std::uint32_t dim2618KuoInit[]        =   {   1   ,   3   ,   1   ,   5   ,   31  ,   21  ,   19  ,   219 ,   311 ,   1013    ,   227 ,   1813    ,   3103    ,   14191   ,   22995   ,0 };
            const std::uint32_t dim2619KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   3   ,   59  ,   11  ,   191 ,   433 ,   63  ,   465 ,   3505    ,   6801    ,   3047    ,   16913   ,0 };
            const std::uint32_t dim2620KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   19  ,   3   ,   95  ,   203 ,   1   ,   679 ,   1719    ,   269 ,   1747    ,   9465    ,   24445   ,0 };
            const std::uint32_t dim2621KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   9   ,   17  ,   79  ,   45  ,   179 ,   863 ,   801 ,   2825    ,   5345    ,   637 ,   9729    ,0 };
            const std::uint32_t dim2622KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   11  ,   59  ,   45  ,   107 ,   45  ,   891 ,   629 ,   443 ,   805 ,   15277   ,   1961    ,0 };
            const std::uint32_t dim2623KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   9   ,   49  ,   123 ,   183 ,   13  ,   867 ,   261 ,   3883    ,   2479    ,   8221    ,   3327    ,0 };
            const std::uint32_t dim2624KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   19  ,   19  ,   95  ,   85  ,   351 ,   861 ,   1499    ,   3697    ,   7369    ,   10757   ,   16445   ,0 };
            const std::uint32_t dim2625KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   27  ,   13  ,   119 ,   243 ,   437 ,   655 ,   955 ,   1919    ,   3643    ,   12389   ,   6865    ,0 };
            const std::uint32_t dim2626KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   23  ,   15  ,   43  ,   65  ,   87  ,   833 ,   503 ,   999 ,   703 ,   4411    ,   3343    ,0 };
            const std::uint32_t dim2627KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   31  ,   13  ,   67  ,   199 ,   261 ,   257 ,   1767    ,   3983    ,   823 ,   149 ,   32353   ,0 };
            const std::uint32_t dim2628KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   15  ,   17  ,   69  ,   237 ,   441 ,   657 ,   1125    ,   3377    ,   5971    ,   15477   ,   31363   ,0 };
            const std::uint32_t dim2629KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   3   ,   55  ,   67  ,   93  ,   315 ,   1015    ,   61  ,   35  ,   3059    ,   15503   ,   16811   ,0 };
            const std::uint32_t dim2630KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   1   ,   51  ,   91  ,   213 ,   3   ,   37  ,   849 ,   2329    ,   2237    ,   6189    ,   625 ,0 };
            const std::uint32_t dim2631KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   25  ,   3   ,   57  ,   103 ,   401 ,   357 ,   461 ,   2677    ,   6059    ,   291 ,   11461   ,0 };
            const std::uint32_t dim2632KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   23  ,   29  ,   119 ,   61  ,   121 ,   535 ,   251 ,   565 ,   7307    ,   1085    ,   8429    ,0 };
            const std::uint32_t dim2633KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   23  ,   19  ,   63  ,   155 ,   5   ,   617 ,   9   ,   715 ,   5399    ,   1747    ,   17633   ,0 };
            const std::uint32_t dim2634KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   3   ,   57  ,   13  ,   161 ,   123 ,   389 ,   1695    ,   4083    ,   1957    ,   11359   ,   18961   ,0 };
            const std::uint32_t dim2635KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   27  ,   25  ,   65  ,   15  ,   205 ,   695 ,   995 ,   1471    ,   1131    ,   11435   ,   22107   ,0 };
            const std::uint32_t dim2636KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   31  ,   29  ,   109 ,   121 ,   81  ,   15  ,   1087    ,   299 ,   3495    ,   14137   ,   19073   ,0 };
            const std::uint32_t dim2637KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   23  ,   23  ,   117 ,   55  ,   215 ,   287 ,   1421    ,   731 ,   279 ,   15497   ,   15545   ,0 };
            const std::uint32_t dim2638KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   1   ,   31  ,   95  ,   249 ,   403 ,   239 ,   771 ,   1279    ,   1863    ,   12893   ,   21043   ,0 };
            const std::uint32_t dim2639KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   21  ,   23  ,   123 ,   169 ,   69  ,   591 ,   621 ,   1697    ,   5867    ,   5193    ,   16573   ,0 };
            const std::uint32_t dim2640KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   29  ,   19  ,   105 ,   177 ,   143 ,   141 ,   1455    ,   3119    ,   347 ,   8797    ,   3925    ,0 };
            const std::uint32_t dim2641KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   9   ,   11  ,   41  ,   169 ,   141 ,   555 ,   1761    ,   3441    ,   2245    ,   14205   ,   9769    ,0 };
            const std::uint32_t dim2642KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   9   ,   33  ,   125 ,   203 ,   333 ,   461 ,   551 ,   569 ,   1305    ,   10213   ,   24549   ,0 };
            const std::uint32_t dim2643KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   21  ,   9   ,   99  ,   43  ,   395 ,   667 ,   121 ,   1225    ,   7835    ,   8327    ,   17717   ,0 };
            const std::uint32_t dim2644KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   21  ,   9   ,   31  ,   59  ,   321 ,   505 ,   1357    ,   3213    ,   4219    ,   10637   ,   11127   ,0 };
            const std::uint32_t dim2645KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   17  ,   49  ,   77  ,   243 ,   189 ,   115 ,   1339    ,   2023    ,   7431    ,   5087    ,   24495   ,0 };
            const std::uint32_t dim2646KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   1   ,   39  ,   41  ,   51  ,   315 ,   383 ,   237 ,   3877    ,   5731    ,   11  ,   21307   ,0 };
            const std::uint32_t dim2647KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   5   ,   3   ,   17  ,   227 ,   483 ,   395 ,   1251    ,   1265    ,   3965    ,   15203   ,   17163   ,0 };
            const std::uint32_t dim2648KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   23  ,   41  ,   53  ,   45  ,   43  ,   989 ,   629 ,   1557    ,   2891    ,   4613    ,   3647    ,0 };
            const std::uint32_t dim2649KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   15  ,   39  ,   35  ,   127 ,   267 ,   45  ,   1299    ,   2251    ,   7363    ,   13595   ,   31061   ,0 };
            const std::uint32_t dim2650KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   23  ,   45  ,   99  ,   153 ,   419 ,   727 ,   1077    ,   3407    ,   4861    ,   3697    ,   14479   ,0 };
            const std::uint32_t dim2651KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   19  ,   21  ,   123 ,   173 ,   295 ,   47  ,   1977    ,   1185    ,   7403    ,   11901   ,   29753   ,0 };
            const std::uint32_t dim2652KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   21  ,   53  ,   83  ,   151 ,   309 ,   293 ,   439 ,   2381    ,   7965    ,   3449    ,   8861    ,0 };
            const std::uint32_t dim2653KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   31  ,   49  ,   61  ,   81  ,   327 ,   173 ,   111 ,   3893    ,   2621    ,   1409    ,   13255   ,0 };
            const std::uint32_t dim2654KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   3   ,   13  ,   75  ,   71  ,   271 ,   689 ,   369 ,   2719    ,   759 ,   8691    ,   24611   ,0 };
            const std::uint32_t dim2655KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   21  ,   7   ,   69  ,   17  ,   347 ,   699 ,   1581    ,   1095    ,   1727    ,   8213    ,   5033    ,0 };
            const std::uint32_t dim2656KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   23  ,   41  ,   85  ,   233 ,   43  ,   863 ,   553 ,   2625    ,   2323    ,   7471    ,   12457   ,0 };
            const std::uint32_t dim2657KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   3   ,   7   ,   99  ,   27  ,   173 ,   539 ,   113 ,   2309    ,   1771    ,   11709   ,   29703   ,0 };
            const std::uint32_t dim2658KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   7   ,   43  ,   73  ,   91  ,   151 ,   961 ,   251 ,   2089    ,   4475    ,   2745    ,   6077    ,0 };
            const std::uint32_t dim2659KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   15  ,   61  ,   91  ,   139 ,   161 ,   613 ,   603 ,   1587    ,   3995    ,   9241    ,   24467   ,0 };
            const std::uint32_t dim2660KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   1   ,   21  ,   7   ,   157 ,   311 ,   451 ,   137 ,   3289    ,   5583    ,   5107    ,   24471   ,0 };
            const std::uint32_t dim2661KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   15  ,   3   ,   7   ,   19  ,   375 ,   265 ,   1781    ,   335 ,   233 ,   3569    ,   21407   ,0 };
            const std::uint32_t dim2662KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   7   ,   53  ,   81  ,   79  ,   355 ,   89  ,   1233    ,   267 ,   6523    ,   8819    ,   30595   ,0 };
            const std::uint32_t dim2663KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   1   ,   59  ,   65  ,   93  ,   251 ,   565 ,   1575    ,   2709    ,   7845    ,   13355   ,   6043    ,0 };
            const std::uint32_t dim2664KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   9   ,   21  ,   71  ,   97  ,   383 ,   189 ,   3   ,   1841    ,   1403    ,   9649    ,   25053   ,0 };
            const std::uint32_t dim2665KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   25  ,   47  ,   41  ,   63  ,   177 ,   551 ,   1389    ,   1639    ,   4209    ,   15787   ,   26499   ,0 };
            const std::uint32_t dim2666KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   29  ,   53  ,   119 ,   3   ,   33  ,   677 ,   207 ,   1239    ,   453 ,   6281    ,   26701   ,0 };
            const std::uint32_t dim2667KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   7   ,   37  ,   87  ,   241 ,   477 ,   765 ,   1511    ,   2659    ,   1043    ,   313 ,   27957   ,0 };
            const std::uint32_t dim2668KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   1   ,   31  ,   101 ,   27  ,   401 ,   547 ,   617 ,   3605    ,   4899    ,   5093    ,   19933   ,0 };
            const std::uint32_t dim2669KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   7   ,   45  ,   127 ,   191 ,   439 ,   383 ,   745 ,   3143    ,   2083    ,   2941    ,   31981   ,0 };
            const std::uint32_t dim2670KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   7   ,   15  ,   31  ,   203 ,   75  ,   297 ,   603 ,   2945    ,   1823    ,   12359   ,   29245   ,0 };
            const std::uint32_t dim2671KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   1   ,   57  ,   35  ,   255 ,   77  ,   483 ,   1051    ,   1999    ,   4975    ,   16211   ,   22903   ,0 };
            const std::uint32_t dim2672KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   23  ,   53  ,   13  ,   251 ,   181 ,   1011    ,   983 ,   3735    ,   4221    ,   5557    ,   25777   ,0 };
            const std::uint32_t dim2673KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   13  ,   51  ,   21  ,   155 ,   293 ,   79  ,   1015    ,   2653    ,   2959    ,   9913    ,   17751   ,0 };
            const std::uint32_t dim2674KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   17  ,   33  ,   27  ,   125 ,   437 ,   663 ,   343 ,   1799    ,   2129    ,   7993    ,   1373    ,0 };
            const std::uint32_t dim2675KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   9   ,   17  ,   31  ,   123 ,   453 ,   853 ,   1221    ,   2863    ,   4637    ,   8239    ,   27233   ,0 };
            const std::uint32_t dim2676KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   7   ,   19  ,   43  ,   77  ,   19  ,   559 ,   1397    ,   1631    ,   3187    ,   1445    ,   25437   ,0 };
            const std::uint32_t dim2677KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   31  ,   21  ,   71  ,   127 ,   223 ,   127 ,   717 ,   3163    ,   2079    ,   2399    ,   16415   ,0 };
            const std::uint32_t dim2678KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   17  ,   13  ,   99  ,   227 ,   127 ,   625 ,   1065    ,   1779    ,   7275    ,   11865   ,   17397   ,0 };
            const std::uint32_t dim2679KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   31  ,   43  ,   27  ,   231 ,   103 ,   873 ,   949 ,   1179    ,   3149    ,   2251    ,   22993   ,0 };
            const std::uint32_t dim2680KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   25  ,   11  ,   89  ,   149 ,   71  ,   171 ,   1985    ,   3779    ,   901 ,   16307   ,   5663    ,0 };
            const std::uint32_t dim2681KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   1   ,   25  ,   125 ,   241 ,   167 ,   381 ,   407 ,   2801    ,   635 ,   313 ,   10199   ,0 };
            const std::uint32_t dim2682KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   29  ,   31  ,   101 ,   121 ,   251 ,   685 ,   677 ,   1683    ,   3499    ,   16193   ,   7139    ,0 };
            const std::uint32_t dim2683KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   7   ,   13  ,   27  ,   101 ,   7   ,   159 ,   2005    ,   3297    ,   2775    ,   11193   ,   17385   ,0 };
            const std::uint32_t dim2684KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   25  ,   31  ,   119 ,   43  ,   317 ,   371 ,   1505    ,   2631    ,   1021    ,   1297    ,   22791   ,0 };
            const std::uint32_t dim2685KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   17  ,   57  ,   63  ,   229 ,   97  ,   599 ,   1485    ,   1113    ,   403 ,   77  ,   25541   ,0 };
            const std::uint32_t dim2686KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   11  ,   43  ,   29  ,   85  ,   335 ,   943 ,   1605    ,   1757    ,   2787    ,   3313    ,   14991   ,0 };
            const std::uint32_t dim2687KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   17  ,   43  ,   5   ,   231 ,   441 ,   883 ,   465 ,   841 ,   2785    ,   8193    ,   7951    ,0 };
            const std::uint32_t dim2688KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   27  ,   33  ,   1   ,   215 ,   295 ,   381 ,   283 ,   219 ,   3419    ,   3343    ,   17629   ,0 };
            const std::uint32_t dim2689KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   5   ,   49  ,   107 ,   179 ,   281 ,   223 ,   1845    ,   2505    ,   2281    ,   12051   ,   12609   ,0 };
            const std::uint32_t dim2690KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   21  ,   13  ,   109 ,   183 ,   385 ,   293 ,   773 ,   3975    ,   4737    ,   8143    ,   1335    ,0 };
            const std::uint32_t dim2691KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   13  ,   47  ,   23  ,   27  ,   271 ,   957 ,   1937    ,   4091    ,   3563    ,   4055    ,   17595   ,0 };
            const std::uint32_t dim2692KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   31  ,   45  ,   43  ,   7   ,   125 ,   549 ,   169 ,   1567    ,   5405    ,   3919    ,   21795   ,0 };
            const std::uint32_t dim2693KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   5   ,   53  ,   121 ,   107 ,   217 ,   745 ,   861 ,   481 ,   5503    ,   3723    ,   12215   ,0 };
            const std::uint32_t dim2694KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   23  ,   27  ,   91  ,   175 ,   477 ,   289 ,   817 ,   2483    ,   6071    ,   5429    ,   12923   ,0 };
            const std::uint32_t dim2695KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   7   ,   63  ,   29  ,   157 ,   323 ,   851 ,   1941    ,   1927    ,   5165    ,   9875    ,   11809   ,0 };
            const std::uint32_t dim2696KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   13  ,   17  ,   93  ,   187 ,   329 ,   187 ,   1417    ,   1477    ,   7891    ,   11093   ,   24705   ,0 };
            const std::uint32_t dim2697KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   5   ,   41  ,   119 ,   135 ,   255 ,   47  ,   803 ,   3941    ,   1647    ,   7777    ,   17515   ,0 };
            const std::uint32_t dim2698KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   25  ,   11  ,   15  ,   231 ,   81  ,   267 ,   1633    ,   407 ,   3319    ,   12033   ,   9651    ,0 };
            const std::uint32_t dim2699KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   31  ,   43  ,   3   ,   101 ,   435 ,   869 ,   159 ,   441 ,   613 ,   10283   ,   6873    ,0 };
            const std::uint32_t dim2700KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   11  ,   55  ,   7   ,   65  ,   357 ,   595 ,   1543    ,   3957    ,   6075    ,   7265    ,   27063   ,0 };
            const std::uint32_t dim2701KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   23  ,   23  ,   41  ,   205 ,   197 ,   863 ,   695 ,   971 ,   39  ,   12389   ,   2983    ,0 };
            const std::uint32_t dim2702KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   7   ,   39  ,   39  ,   25  ,   173 ,   277 ,   999 ,   3797    ,   3051    ,   189 ,   13559   ,0 };
            const std::uint32_t dim2703KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   3   ,   7   ,   47  ,   79  ,   411 ,   109 ,   55  ,   3803    ,   6617    ,   14317   ,   9533    ,0 };
            const std::uint32_t dim2704KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   31  ,   17  ,   53  ,   97  ,   495 ,   995 ,   1735    ,   1055    ,   6805    ,   6865    ,   23321   ,0 };
            const std::uint32_t dim2705KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   3   ,   63  ,   37  ,   185 ,   311 ,   995 ,   1819    ,   2633    ,   2593    ,   2107    ,   15755   ,0 };
            const std::uint32_t dim2706KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   25  ,   37  ,   79  ,   179 ,   435 ,   167 ,   147 ,   2159    ,   5909    ,   10427   ,   12487   ,0 };
            const std::uint32_t dim2707KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   31  ,   9   ,   69  ,   93  ,   477 ,   283 ,   479 ,   1895    ,   5693    ,   4809    ,   3157    ,0 };
            const std::uint32_t dim2708KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   27  ,   21  ,   11  ,   3   ,   157 ,   1011    ,   1473    ,   2393    ,   259 ,   4155    ,   28375   ,0 };
            const std::uint32_t dim2709KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   7   ,   11  ,   73  ,   215 ,   289 ,   933 ,   1369    ,   2911    ,   3251    ,   727 ,   19237   ,0 };
            const std::uint32_t dim2710KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   29  ,   19  ,   77  ,   59  ,   213 ,   1005    ,   2009    ,   1899    ,   5987    ,   7429    ,   5607    ,0 };
            const std::uint32_t dim2711KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   7   ,   53  ,   79  ,   151 ,   443 ,   911 ,   1777    ,   1223    ,   663 ,   2099    ,   17297   ,0 };
            const std::uint32_t dim2712KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   11  ,   7   ,   81  ,   175 ,   265 ,   879 ,   1867    ,   539 ,   2353    ,   5667    ,   4973    ,0 };
            const std::uint32_t dim2713KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   23  ,   63  ,   35  ,   57  ,   139 ,   653 ,   1837    ,   681 ,   6993    ,   643 ,   21771   ,0 };
            const std::uint32_t dim2714KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   11  ,   13  ,   123 ,   199 ,   405 ,   373 ,   1817    ,   3331    ,   5585    ,   11721   ,   9355    ,0 };
            const std::uint32_t dim2715KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   27  ,   29  ,   79  ,   121 ,   399 ,   85  ,   531 ,   507 ,   4361    ,   6167    ,   29317   ,0 };
            const std::uint32_t dim2716KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   13  ,   19  ,   75  ,   245 ,   197 ,   731 ,   233 ,   487 ,   2245    ,   11413   ,   31865   ,0 };
            const std::uint32_t dim2717KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   27  ,   43  ,   109 ,   135 ,   91  ,   475 ,   209 ,   865 ,   2239    ,   8065    ,   23295   ,0 };
            const std::uint32_t dim2718KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   13  ,   27  ,   101 ,   121 ,   23  ,   319 ,   873 ,   251 ,   299 ,   7145    ,   26225   ,0 };
            const std::uint32_t dim2719KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   31  ,   51  ,   85  ,   91  ,   299 ,   545 ,   1557    ,   2447    ,   4055    ,   3911    ,   12805   ,0 };
            const std::uint32_t dim2720KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   31  ,   63  ,   123 ,   191 ,   241 ,   7   ,   347 ,   23  ,   5135    ,   7353    ,   30865   ,0 };
            const std::uint32_t dim2721KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   3   ,   13  ,   81  ,   249 ,   65  ,   853 ,   893 ,   219 ,   6555    ,   4941    ,   21669   ,0 };
            const std::uint32_t dim2722KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   13  ,   27  ,   13  ,   203 ,   205 ,   459 ,   883 ,   1723    ,   2721    ,   9173    ,   9643    ,0 };
            const std::uint32_t dim2723KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   11  ,   59  ,   109 ,   25  ,   107 ,   1007    ,   357 ,   2877    ,   5075    ,   3251    ,   29541   ,0 };
            const std::uint32_t dim2724KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   19  ,   37  ,   99  ,   183 ,   267 ,   571 ,   49  ,   975 ,   2441    ,   4459    ,   15481   ,0 };
            const std::uint32_t dim2725KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   21  ,   7   ,   89  ,   233 ,   209 ,   151 ,   1919    ,   31  ,   4363    ,   9781    ,   4683    ,0 };
            const std::uint32_t dim2726KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   15  ,   35  ,   101 ,   29  ,   27  ,   737 ,   1577    ,   2611    ,   3727    ,   2245    ,   31889   ,0 };
            const std::uint32_t dim2727KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   19  ,   19  ,   125 ,   229 ,   313 ,   239 ,   67  ,   1373    ,   6459    ,   1339    ,   19909   ,0 };
            const std::uint32_t dim2728KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   19  ,   35  ,   17  ,   31  ,   183 ,   391 ,   1515    ,   2357    ,   2673    ,   10055   ,   943 ,0 };
            const std::uint32_t dim2729KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   31  ,   17  ,   37  ,   239 ,   79  ,   869 ,   629 ,   2755    ,   7431    ,   127 ,   19155   ,0 };
            const std::uint32_t dim2730KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   9   ,   13  ,   91  ,   27  ,   163 ,   455 ,   2007    ,   2479    ,   2387    ,   1557    ,   437 ,0 };
            const std::uint32_t dim2731KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   15  ,   63  ,   11  ,   105 ,   51  ,   673 ,   997 ,   2487    ,   35  ,   8655    ,   21481   ,0 };
            const std::uint32_t dim2732KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   1   ,   3   ,   27  ,   117 ,   195 ,   233 ,   269 ,   2163    ,   2083    ,   8907    ,   28005   ,0 };
            const std::uint32_t dim2733KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   9   ,   17  ,   63  ,   211 ,   87  ,   107 ,   1183    ,   2705    ,   6811    ,   9959    ,   13937   ,0 };
            const std::uint32_t dim2734KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   1   ,   3   ,   57  ,   231 ,   209 ,   949 ,   895 ,   2773    ,   237 ,   8943    ,   22453   ,0 };
            const std::uint32_t dim2735KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   7   ,   53  ,   1   ,   247 ,   279 ,   411 ,   1247    ,   2121    ,   3127    ,   16279   ,   277 ,0 };
            const std::uint32_t dim2736KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   15  ,   35  ,   15  ,   15  ,   485 ,   763 ,   1631    ,   1717    ,   191 ,   6609    ,   32383   ,0 };
            const std::uint32_t dim2737KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   27  ,   5   ,   73  ,   143 ,   127 ,   477 ,   535 ,   3815    ,   3135    ,   9865    ,   5375    ,0 };
            const std::uint32_t dim2738KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   21  ,   31  ,   83  ,   63  ,   313 ,   775 ,   875 ,   4053    ,   905 ,   14255   ,   31537   ,0 };
            const std::uint32_t dim2739KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   7   ,   3   ,   107 ,   231 ,   333 ,   935 ,   1625    ,   2527    ,   2293    ,   10407   ,   4795    ,0 };
            const std::uint32_t dim2740KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   25  ,   19  ,   123 ,   193 ,   353 ,   353 ,   1403    ,   3007    ,   677 ,   15333   ,   1263    ,0 };
            const std::uint32_t dim2741KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   1   ,   39  ,   79  ,   251 ,   59  ,   973 ,   1707    ,   2153    ,   7445    ,   9083    ,   6675    ,0 };
            const std::uint32_t dim2742KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   7   ,   55  ,   21  ,   101 ,   203 ,   735 ,   1789    ,   3119    ,   6633    ,   3643    ,   1947    ,0 };
            const std::uint32_t dim2743KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   13  ,   49  ,   103 ,   141 ,   181 ,   893 ,   385 ,   1541    ,   5887    ,   10687   ,   16183   ,0 };
            const std::uint32_t dim2744KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   17  ,   59  ,   35  ,   119 ,   467 ,   77  ,   1591    ,   469 ,   4991    ,   8113    ,   20231   ,0 };
            const std::uint32_t dim2745KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   19  ,   41  ,   5   ,   71  ,   247 ,   955 ,   565 ,   1931    ,   2895    ,   13189   ,   28461   ,0 };
            const std::uint32_t dim2746KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   19  ,   21  ,   123 ,   39  ,   175 ,   35  ,   673 ,   107 ,   3157    ,   1495    ,   16341   ,0 };
            const std::uint32_t dim2747KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   31  ,   25  ,   9   ,   17  ,   463 ,   585 ,   1701    ,   3325    ,   6071    ,   2719    ,   4479    ,0 };
            const std::uint32_t dim2748KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   25  ,   51  ,   63  ,   241 ,   289 ,   787 ,   1109    ,   453 ,   5119    ,   139 ,   377 ,0 };
            const std::uint32_t dim2749KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   29  ,   3   ,   53  ,   119 ,   219 ,   367 ,   1785    ,   777 ,   5255    ,   10013   ,   27979   ,0 };
            const std::uint32_t dim2750KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   1   ,   45  ,   3   ,   239 ,   429 ,   595 ,   1591    ,   3111    ,   2373    ,   4121    ,   12671   ,0 };
            const std::uint32_t dim2751KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   5   ,   49  ,   11  ,   145 ,   167 ,   19  ,   155 ,   2017    ,   3593    ,   15275   ,   22319   ,0 };
            const std::uint32_t dim2752KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   11  ,   15  ,   17  ,   241 ,   293 ,   345 ,   1663    ,   301 ,   627 ,   12161   ,   19939   ,0 };
            const std::uint32_t dim2753KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   3   ,   19  ,   41  ,   75  ,   121 ,   611 ,   1741    ,   4055    ,   5567    ,   773 ,   767 ,0 };
            const std::uint32_t dim2754KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   5   ,   49  ,   127 ,   49  ,   93  ,   819 ,   1391    ,   2173    ,   4021    ,   11953   ,   28465   ,0 };
            const std::uint32_t dim2755KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   9   ,   59  ,   63  ,   85  ,   249 ,   239 ,   521 ,   3333    ,   6301    ,   15283   ,   10645   ,0 };
            const std::uint32_t dim2756KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   9   ,   53  ,   107 ,   201 ,   151 ,   79  ,   1561    ,   3497    ,   4473    ,   4369    ,   6231    ,0 };
            const std::uint32_t dim2757KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   11  ,   61  ,   57  ,   69  ,   215 ,   637 ,   1087    ,   2827    ,   2495    ,   7471    ,   19127   ,0 };
            const std::uint32_t dim2758KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   3   ,   25  ,   87  ,   131 ,   171 ,   577 ,   957 ,   989 ,   3391    ,   3803    ,   27229   ,0 };
            const std::uint32_t dim2759KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   1   ,   25  ,   83  ,   71  ,   161 ,   477 ,   573 ,   3709    ,   4393    ,   4607    ,   32373   ,0 };
            const std::uint32_t dim2760KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   13  ,   21  ,   19  ,   71  ,   207 ,   433 ,   849 ,   2685    ,   4455    ,   463 ,   25163   ,0 };
            const std::uint32_t dim2761KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   5   ,   19  ,   35  ,   41  ,   487 ,   3   ,   865 ,   25  ,   7925    ,   9015    ,   29397   ,0 };
            const std::uint32_t dim2762KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   7   ,   41  ,   83  ,   27  ,   79  ,   501 ,   267 ,   2015    ,   8109    ,   8877    ,   4029    ,0 };
            const std::uint32_t dim2763KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   1   ,   31  ,   71  ,   233 ,   167 ,   185 ,   33  ,   1249    ,   3755    ,   2805    ,   29559   ,0 };
            const std::uint32_t dim2764KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   11  ,   21  ,   111 ,   105 ,   469 ,   527 ,   711 ,   3551    ,   521 ,   10593   ,   22701   ,0 };
            const std::uint32_t dim2765KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   29  ,   1   ,   79  ,   109 ,   279 ,   643 ,   1263    ,   2405    ,   3717    ,   11395   ,   4325    ,0 };
            const std::uint32_t dim2766KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   29  ,   47  ,   59  ,   1   ,   195 ,   399 ,   1963    ,   265 ,   317 ,   15117   ,   9935    ,0 };
            const std::uint32_t dim2767KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   21  ,   43  ,   93  ,   113 ,   273 ,   67  ,   281 ,   477 ,   6309    ,   3649    ,   20147   ,0 };
            const std::uint32_t dim2768KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   29  ,   61  ,   69  ,   151 ,   185 ,   809 ,   993 ,   2383    ,   7263    ,   901 ,   18607   ,0 };
            const std::uint32_t dim2769KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   27  ,   33  ,   25  ,   103 ,   387 ,   131 ,   1555    ,   301 ,   1471    ,   11331   ,   15091   ,0 };
            const std::uint32_t dim2770KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   19  ,   55  ,   115 ,   121 ,   99  ,   371 ,   1563    ,   895 ,   6207    ,   93  ,   8549    ,0 };
            const std::uint32_t dim2771KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   19  ,   23  ,   13  ,   181 ,   281 ,   479 ,   1   ,   1515    ,   3853    ,   8601    ,   19241   ,0 };
            const std::uint32_t dim2772KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   29  ,   63  ,   113 ,   253 ,   105 ,   421 ,   1679    ,   2113    ,   4671    ,   7923    ,   7671    ,0 };
            const std::uint32_t dim2773KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   17  ,   9   ,   15  ,   241 ,   339 ,   619 ,   417 ,   3257    ,   5917    ,   9981    ,   19033   ,0 };
            const std::uint32_t dim2774KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   21  ,   11  ,   97  ,   201 ,   257 ,   307 ,   133 ,   1793    ,   193 ,   8609    ,   27771   ,0 };
            const std::uint32_t dim2775KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   25  ,   55  ,   51  ,   97  ,   453 ,   37  ,   639 ,   3451    ,   6587    ,   3835    ,   13229   ,0 };
            const std::uint32_t dim2776KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   3   ,   21  ,   123 ,   81  ,   447 ,   963 ,   449 ,   1329    ,   4887    ,   1141    ,   3213    ,0 };
            const std::uint32_t dim2777KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   5   ,   33  ,   107 ,   89  ,   67  ,   229 ,   2025    ,   1925    ,   5369    ,   14049   ,   10461   ,0 };
            const std::uint32_t dim2778KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   23  ,   17  ,   75  ,   79  ,   51  ,   25  ,   1541    ,   3475    ,   6129    ,   13391   ,   31091   ,0 };
            const std::uint32_t dim2779KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   17  ,   27  ,   5   ,   57  ,   147 ,   549 ,   721 ,   2477    ,   893 ,   6413    ,   24053   ,0 };
            const std::uint32_t dim2780KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   11  ,   29  ,   119 ,   149 ,   185 ,   713 ,   1603    ,   3671    ,   3409    ,   2689    ,   7933    ,0 };
            const std::uint32_t dim2781KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   9   ,   33  ,   97  ,   85  ,   185 ,   225 ,   1747    ,   1677    ,   4133    ,   11421   ,   26591   ,0 };
            const std::uint32_t dim2782KuoInit[]        =   {   1   ,   1   ,   5   ,   15  ,   29  ,   43  ,   75  ,   251 ,   157 ,   861 ,   517 ,   3341    ,   4447    ,   14803   ,   18465   ,0 };
            const std::uint32_t dim2783KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   11  ,   37  ,   57  ,   189 ,   423 ,   881 ,   1199    ,   1263    ,   2691    ,   6969    ,   21803   ,0 };
            const std::uint32_t dim2784KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   25  ,   47  ,   15  ,   107 ,   119 ,   885 ,   1149    ,   673 ,   4459    ,   9997    ,   4519    ,0 };
            const std::uint32_t dim2785KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   23  ,   7   ,   37  ,   161 ,   17  ,   499 ,   1675    ,   2309    ,   4159    ,   13771   ,   17741   ,0 };
            const std::uint32_t dim2786KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   7   ,   51  ,   111 ,   163 ,   313 ,   835 ,   1903    ,   2201    ,   321 ,   14655   ,   16845   ,0 };
            const std::uint32_t dim2787KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   7   ,   41  ,   23  ,   87  ,   101 ,   371 ,   257 ,   1679    ,   7449    ,   12967   ,   31  ,0 };
            const std::uint32_t dim2788KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   29  ,   37  ,   57  ,   163 ,   507 ,   1   ,   691 ,   2933    ,   4687    ,   10621   ,   32351   ,0 };
            const std::uint32_t dim2789KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   31  ,   63  ,   73  ,   67  ,   503 ,   289 ,   1533    ,   1203    ,   7931    ,   11399   ,   23463   ,0 };
            const std::uint32_t dim2790KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   23  ,   39  ,   19  ,   73  ,   467 ,   65  ,   791 ,   2017    ,   1763    ,   11921   ,   31643   ,0 };
            const std::uint32_t dim2791KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   19  ,   21  ,   53  ,   61  ,   401 ,   429 ,   1095    ,   297 ,   7931    ,   13085   ,   2013    ,0 };
            const std::uint32_t dim2792KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   27  ,   41  ,   23  ,   225 ,   299 ,   943 ,   823 ,   3507    ,   4333    ,   817 ,   26137   ,0 };
            const std::uint32_t dim2793KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   27  ,   29  ,   31  ,   251 ,   499 ,   151 ,   295 ,   1731    ,   7661    ,   11825   ,   29587   ,0 };
            const std::uint32_t dim2794KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   17  ,   43  ,   17  ,   5   ,   25  ,   813 ,   1875    ,   2941    ,   1407    ,   11669   ,   16753   ,0 };
            const std::uint32_t dim2795KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   17  ,   59  ,   93  ,   173 ,   335 ,   933 ,   369 ,   3421    ,   2769    ,   16361   ,   11891   ,0 };
            const std::uint32_t dim2796KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   27  ,   5   ,   63  ,   7   ,   415 ,   533 ,   179 ,   851 ,   1623    ,   16375   ,   1271    ,0 };
            const std::uint32_t dim2797KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   17  ,   45  ,   125 ,   93  ,   43  ,   311 ,   153 ,   1225    ,   4891    ,   5621    ,   14355   ,0 };
            const std::uint32_t dim2798KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   13  ,   63  ,   103 ,   205 ,   119 ,   953 ,   1087    ,   703 ,   3729    ,   10249   ,   19085   ,0 };
            const std::uint32_t dim2799KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   11  ,   51  ,   17  ,   97  ,   323 ,   657 ,   269 ,   467 ,   2747    ,   13603   ,   22803   ,0 };
            const std::uint32_t dim2800KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   3   ,   5   ,   35  ,   23  ,   433 ,   259 ,   1857    ,   2313    ,   7709    ,   2297    ,   31109   ,0 };
            const std::uint32_t dim2801KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   19  ,   11  ,   51  ,   251 ,   167 ,   741 ,   1705    ,   3763    ,   967 ,   2593    ,   28229   ,0 };
            const std::uint32_t dim2802KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   29  ,   47  ,   47  ,   183 ,   305 ,   223 ,   381 ,   1753    ,   2285    ,   9113    ,   21685   ,0 };
            const std::uint32_t dim2803KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   31  ,   17  ,   105 ,   25  ,   49  ,   679 ,   1501    ,   3887    ,   5007    ,   4275    ,   31161   ,0 };
            const std::uint32_t dim2804KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   27  ,   59  ,   17  ,   183 ,   477 ,   191 ,   1111    ,   383 ,   5519    ,   7435    ,   20341   ,0 };
            const std::uint32_t dim2805KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   25  ,   15  ,   67  ,   57  ,   5   ,   955 ,   731 ,   3785    ,   2055    ,   13017   ,   27843   ,0 };
            const std::uint32_t dim2806KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   27  ,   45  ,   67  ,   93  ,   311 ,   635 ,   1893    ,   1753    ,   7307    ,   2765    ,   6263    ,0 };
            const std::uint32_t dim2807KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   13  ,   53  ,   109 ,   5   ,   3   ,   705 ,   1745    ,   2233    ,   3425    ,   6125    ,   28839   ,0 };
            const std::uint32_t dim2808KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   5   ,   39  ,   5   ,   251 ,   431 ,   85  ,   599 ,   3459    ,   3211    ,   15611   ,   28739   ,0 };
            const std::uint32_t dim2809KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   25  ,   5   ,   25  ,   31  ,   283 ,   909 ,   399 ,   1335    ,   6973    ,   15791   ,   28351   ,0 };
            const std::uint32_t dim2810KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   3   ,   29  ,   47  ,   227 ,   463 ,   815 ,   1089    ,   2217    ,   4911    ,   14743   ,   17843   ,0 };
            const std::uint32_t dim2811KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   29  ,   39  ,   125 ,   165 ,   367 ,   461 ,   569 ,   3441    ,   1293    ,   1577    ,   10567   ,0 };
            const std::uint32_t dim2812KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   5   ,   11  ,   19  ,   129 ,   401 ,   111 ,   2019    ,   899 ,   2079    ,   7363    ,   32675   ,0 };
            const std::uint32_t dim2813KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   13  ,   27  ,   47  ,   183 ,   465 ,   421 ,   665 ,   1279    ,   5629    ,   7559    ,   21265   ,0 };
            const std::uint32_t dim2814KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   11  ,   19  ,   75  ,   1   ,   137 ,   893 ,   1709    ,   385 ,   2221    ,   15185   ,   10923   ,0 };
            const std::uint32_t dim2815KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   9   ,   1   ,   115 ,   203 ,   133 ,   259 ,   915 ,   2477    ,   3615    ,   1749    ,   7643    ,0 };
            const std::uint32_t dim2816KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   9   ,   57  ,   21  ,   113 ,   453 ,   739 ,   1857    ,   685 ,   5727    ,   10625   ,   23469   ,0 };
            const std::uint32_t dim2817KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   13  ,   45  ,   37  ,   25  ,   495 ,   723 ,   1805    ,   1631    ,   4889    ,   12885   ,   16895   ,0 };
            const std::uint32_t dim2818KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   17  ,   59  ,   111 ,   29  ,   143 ,   863 ,   1757    ,   1621    ,   3995    ,   7315    ,   30271   ,0 };
            const std::uint32_t dim2819KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   5   ,   31  ,   81  ,   161 ,   275 ,   623 ,   2017    ,   967 ,   2395    ,   14923   ,   23931   ,0 };
            const std::uint32_t dim2820KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   31  ,   33  ,   95  ,   135 ,   477 ,   221 ,   1603    ,   231 ,   5957    ,   12461   ,   2623    ,0 };
            const std::uint32_t dim2821KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   7   ,   3   ,   53  ,   43  ,   351 ,   557 ,   1981    ,   2127    ,   909 ,   8943    ,   21035   ,0 };
            const std::uint32_t dim2822KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   31  ,   11  ,   13  ,   231 ,   145 ,   321 ,   567 ,   1919    ,   7101    ,   12089   ,   8331    ,0 };
            const std::uint32_t dim2823KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   13  ,   27  ,   101 ,   229 ,   89  ,   395 ,   349 ,   1785    ,   6441    ,   8241    ,   30735   ,0 };
            const std::uint32_t dim2824KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   21  ,   57  ,   123 ,   77  ,   251 ,   347 ,   1367    ,   2205    ,   4017    ,   16057   ,   9247    ,0 };
            const std::uint32_t dim2825KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   5   ,   1   ,   47  ,   57  ,   69  ,   381 ,   1613    ,   1525    ,   5715    ,   3677    ,   13015   ,0 };
            const std::uint32_t dim2826KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   31  ,   33  ,   15  ,   255 ,   149 ,   1021    ,   1149    ,   3609    ,   1739    ,   11867   ,   3093    ,0 };
            const std::uint32_t dim2827KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   27  ,   25  ,   57  ,   5   ,   137 ,   1005    ,   343 ,   2567    ,   1025    ,   8615    ,   6357    ,0 };
            const std::uint32_t dim2828KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   29  ,   57  ,   85  ,   65  ,   85  ,   789 ,   1179    ,   2523    ,   7589    ,   14657   ,   23637   ,0 };
            const std::uint32_t dim2829KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   3   ,   3   ,   107 ,   37  ,   125 ,   423 ,   225 ,   2991    ,   4515    ,   5057    ,   31181   ,0 };
            const std::uint32_t dim2830KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   31  ,   5   ,   111 ,   241 ,   301 ,   37  ,   943 ,   555 ,   7051    ,   11627   ,   7125    ,0 };
            const std::uint32_t dim2831KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   17  ,   31  ,   119 ,   185 ,   187 ,   621 ,   395 ,   3595    ,   1055    ,   7993    ,   28441   ,0 };
            const std::uint32_t dim2832KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   31  ,   25  ,   113 ,   223 ,   493 ,   919 ,   1455    ,   31  ,   4743    ,   14435   ,   31627   ,0 };
            const std::uint32_t dim2833KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   27  ,   59  ,   45  ,   75  ,   343 ,   701 ,   1737    ,   161 ,   6919    ,   13537   ,   26835   ,0 };
            const std::uint32_t dim2834KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   31  ,   45  ,   89  ,   215 ,   137 ,   237 ,   1135    ,   3239    ,   3345    ,   12063   ,   14599   ,0 };
            const std::uint32_t dim2835KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   5   ,   51  ,   85  ,   73  ,   353 ,   943 ,   1981    ,   127 ,   2605    ,   5673    ,   10037   ,0 };
            const std::uint32_t dim2836KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   3   ,   49  ,   109 ,   105 ,   483 ,   499 ,   1581    ,   793 ,   5857    ,   5509    ,   4651    ,0 };
            const std::uint32_t dim2837KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   23  ,   5   ,   109 ,   83  ,   7   ,   155 ,   187 ,   2205    ,   4199    ,   5487    ,   31925   ,0 };
            const std::uint32_t dim2838KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   13  ,   11  ,   75  ,   53  ,   125 ,   139 ,   1241    ,   203 ,   7361    ,   13783   ,   4317    ,0 };
            const std::uint32_t dim2839KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   25  ,   57  ,   105 ,   197 ,   207 ,   261 ,   1251    ,   4057    ,   3877    ,   13613   ,   7829    ,0 };
            const std::uint32_t dim2840KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   31  ,   21  ,   89  ,   73  ,   163 ,   941 ,   1683    ,   2239    ,   1893    ,   16067   ,   609 ,0 };
            const std::uint32_t dim2841KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   5   ,   9   ,   41  ,   149 ,   43  ,   333 ,   1459    ,   277 ,   5687    ,   14201   ,   26879   ,0 };
            const std::uint32_t dim2842KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   21  ,   37  ,   67  ,   227 ,   443 ,   767 ,   1109    ,   2151    ,   7875    ,   15519   ,   13741   ,0 };
            const std::uint32_t dim2843KuoInit[]        =   {   1   ,   3   ,   1   ,   5   ,   31  ,   15  ,   107 ,   43  ,   343 ,   27  ,   1321    ,   3009    ,   5751    ,   2931    ,   9733    ,0 };
            const std::uint32_t dim2844KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   5   ,   27  ,   49  ,   33  ,   439 ,   555 ,   97  ,   59  ,   4043    ,   12063   ,   27227   ,0 };
            const std::uint32_t dim2845KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   27  ,   9   ,   55  ,   69  ,   485 ,   75  ,   1255    ,   101 ,   7193    ,   9427    ,   31125   ,0 };
            const std::uint32_t dim2846KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   15  ,   23  ,   51  ,   145 ,   501 ,   875 ,   1611    ,   1321    ,   6809    ,   5051    ,   17135   ,0 };
            const std::uint32_t dim2847KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   5   ,   45  ,   35  ,   115 ,   3   ,   639 ,   1705    ,   207 ,   4235    ,   3329    ,   14481   ,0 };
            const std::uint32_t dim2848KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   5   ,   15  ,   17  ,   115 ,   175 ,   583 ,   1649    ,   2195    ,   3827    ,   16227   ,   21401   ,0 };
            const std::uint32_t dim2849KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   1   ,   3   ,   107 ,   167 ,   195 ,   953 ,   743 ,   1375    ,   701 ,   1155    ,   1027    ,0 };
            const std::uint32_t dim2850KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   31  ,   31  ,   67  ,   133 ,   219 ,   307 ,   1031    ,   3321    ,   4855    ,   11285   ,   16987   ,0 };
            const std::uint32_t dim2851KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   25  ,   9   ,   41  ,   105 ,   89  ,   289 ,   1851    ,   2245    ,   1647    ,   2925    ,   8637    ,0 };
            const std::uint32_t dim2852KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   29  ,   29  ,   107 ,   21  ,   101 ,   419 ,   1207    ,   3301    ,   1217    ,   14157   ,   17373   ,0 };
            const std::uint32_t dim2853KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   9   ,   41  ,   49  ,   165 ,   353 ,   215 ,   883 ,   2031    ,   7363    ,   13221   ,   8329    ,0 };
            const std::uint32_t dim2854KuoInit[]        =   {   1   ,   1   ,   5   ,   15  ,   17  ,   7   ,   67  ,   217 ,   87  ,   217 ,   2013    ,   3809    ,   4983    ,   5341    ,   30353   ,0 };
            const std::uint32_t dim2855KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   1   ,   37  ,   97  ,   109 ,   485 ,   777 ,   171 ,   1391    ,   781 ,   5019    ,   19883   ,0 };
            const std::uint32_t dim2856KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   7   ,   17  ,   27  ,   69  ,   265 ,   663 ,   569 ,   2909    ,   7409    ,   14813   ,   5849    ,0 };
            const std::uint32_t dim2857KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   11  ,   29  ,   27  ,   105 ,   215 ,   59  ,   1251    ,   2003    ,   2201    ,   7221    ,   7549    ,0 };
            const std::uint32_t dim2858KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   15  ,   7   ,   79  ,   237 ,   327 ,   839 ,   1167    ,   3211    ,   275 ,   16031   ,   25691   ,0 };
            const std::uint32_t dim2859KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   3   ,   33  ,   117 ,   113 ,   361 ,   381 ,   1093    ,   1791    ,   2399    ,   1245    ,   23275   ,0 };
            const std::uint32_t dim2860KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   7   ,   49  ,   77  ,   5   ,   217 ,   995 ,   1127    ,   3891    ,   81  ,   13331   ,   12479   ,0 };
            const std::uint32_t dim2861KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   9   ,   57  ,   119 ,   227 ,   41  ,   337 ,   183 ,   3201    ,   3627    ,   16263   ,   28153   ,0 };
            const std::uint32_t dim2862KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   11  ,   9   ,   81  ,   99  ,   247 ,   157 ,   1421    ,   1087    ,   151 ,   6529    ,   13537   ,0 };
            const std::uint32_t dim2863KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   31  ,   43  ,   113 ,   143 ,   163 ,   583 ,   2031    ,   3087    ,   7565    ,   4987    ,   17131   ,0 };
            const std::uint32_t dim2864KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   9   ,   1   ,   121 ,   93  ,   113 ,   849 ,   679 ,   1403    ,   6815    ,   15605   ,   29785   ,0 };
            const std::uint32_t dim2865KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   27  ,   63  ,   53  ,   83  ,   397 ,   935 ,   23  ,   125 ,   5813    ,   15765   ,   2869    ,0 };
            const std::uint32_t dim2866KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   9   ,   11  ,   65  ,   77  ,   387 ,   129 ,   1039    ,   1583    ,   2235    ,   3851    ,   30603   ,0 };
            const std::uint32_t dim2867KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   5   ,   27  ,   45  ,   233 ,   351 ,   827 ,   215 ,   1209    ,   409 ,   2185    ,   3827    ,0 };
            const std::uint32_t dim2868KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   31  ,   23  ,   35  ,   83  ,   271 ,   65  ,   553 ,   3189    ,   2435    ,   12865   ,   28271   ,0 };
            const std::uint32_t dim2869KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   29  ,   51  ,   35  ,   105 ,   477 ,   1001    ,   1859    ,   2063    ,   6895    ,   1855    ,   13931   ,0 };
            const std::uint32_t dim2870KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   17  ,   63  ,   125 ,   165 ,   37  ,   671 ,   2001    ,   1237    ,   7355    ,   339 ,   24771   ,0 };
            const std::uint32_t dim2871KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   13  ,   5   ,   9   ,   201 ,   183 ,   39  ,   119 ,   3889    ,   949 ,   7889    ,   25951   ,0 };
            const std::uint32_t dim2872KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   13  ,   63  ,   71  ,   117 ,   209 ,   955 ,   1175    ,   317 ,   4261    ,   2341    ,   29819   ,0 };
            const std::uint32_t dim2873KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   9   ,   59  ,   109 ,   137 ,   353 ,   355 ,   1227    ,   3183    ,   1553    ,   15039   ,   27979   ,0 };
            const std::uint32_t dim2874KuoInit[]        =   {   1   ,   3   ,   1   ,   5   ,   25  ,   57  ,   87  ,   231 ,   259 ,   333 ,   975 ,   3413    ,   6035    ,   14783   ,   22309   ,0 };
            const std::uint32_t dim2875KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   19  ,   37  ,   55  ,   229 ,   423 ,   761 ,   1669    ,   3023    ,   2517    ,   2961    ,   12043   ,0 };
            const std::uint32_t dim2876KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   23  ,   5   ,   87  ,   193 ,   113 ,   577 ,   269 ,   983 ,   5453    ,   7827    ,   28197   ,0 };
            const std::uint32_t dim2877KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   1   ,   49  ,   89  ,   107 ,   155 ,   767 ,   1547    ,   2139    ,   5951    ,   3143    ,   12735   ,0 };
            const std::uint32_t dim2878KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   13  ,   57  ,   53  ,   243 ,   231 ,   131 ,   1505    ,   1255    ,   7831    ,   15615   ,   28755   ,0 };
            const std::uint32_t dim2879KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   21  ,   21  ,   37  ,   65  ,   327 ,   353 ,   1625    ,   543 ,   669 ,   1139    ,   20745   ,0 };
            const std::uint32_t dim2880KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   5   ,   33  ,   87  ,   211 ,   21  ,   581 ,   397 ,   2691    ,   1069    ,   10449   ,   17727   ,0 };
            const std::uint32_t dim2881KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   1   ,   5   ,   115 ,   143 ,   99  ,   523 ,   51  ,   939 ,   4635    ,   11491   ,   32731   ,0 };
            const std::uint32_t dim2882KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   1   ,   19  ,   119 ,   193 ,   127 ,   897 ,   1337    ,   3977    ,   5027    ,   5913    ,   9329    ,0 };
            const std::uint32_t dim2883KuoInit[]        =   {   1   ,   1   ,   5   ,   15  ,   15  ,   1   ,   93  ,   209 ,   427 ,   625 ,   1581    ,   2639    ,   1291    ,   11177   ,   26943   ,0 };
            const std::uint32_t dim2884KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   27  ,   9   ,   47  ,   243 ,   211 ,   21  ,   1159    ,   3157    ,   6729    ,   219 ,   19671   ,0 };
            const std::uint32_t dim2885KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   19  ,   27  ,   39  ,   237 ,   39  ,   389 ,   1201    ,   2237    ,   7623    ,   12041   ,   18491   ,0 };
            const std::uint32_t dim2886KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   25  ,   43  ,   47  ,   101 ,   319 ,   749 ,   659 ,   2319    ,   1221    ,   3887    ,   29927   ,0 };
            const std::uint32_t dim2887KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   1   ,   55  ,   57  ,   179 ,   163 ,   695 ,   611 ,   2511    ,   1261    ,   15561   ,   29535   ,0 };
            const std::uint32_t dim2888KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   7   ,   31  ,   79  ,   21  ,   143 ,   993 ,   377 ,   791 ,   187 ,   6485    ,   6827    ,0 };
            const std::uint32_t dim2889KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   11  ,   57  ,   39  ,   159 ,   373 ,   179 ,   1907    ,   2475    ,   1355    ,   9885    ,   18683   ,0 };
            const std::uint32_t dim2890KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   7   ,   5   ,   83  ,   151 ,   267 ,   377 ,   1463    ,   365 ,   4725    ,   2319    ,   18957   ,0 };
            const std::uint32_t dim2891KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   21  ,   51  ,   115 ,   119 ,   73  ,   561 ,   1513    ,   403 ,   4889    ,   2329    ,   20141   ,0 };
            const std::uint32_t dim2892KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   21  ,   47  ,   31  ,   61  ,   171 ,   529 ,   185 ,   717 ,   7065    ,   4273    ,   16643   ,0 };
            const std::uint32_t dim2893KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   3   ,   55  ,   41  ,   213 ,   489 ,   379 ,   1951    ,   1957    ,   7721    ,   6415    ,   27049   ,0 };
            const std::uint32_t dim2894KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   19  ,   43  ,   29  ,   203 ,   139 ,   137 ,   463 ,   1447    ,   2585    ,   14381   ,   29073   ,0 };
            const std::uint32_t dim2895KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   19  ,   37  ,   111 ,   119 ,   411 ,   671 ,   1135    ,   2891    ,   7929    ,   7465    ,   21699   ,0 };
            const std::uint32_t dim2896KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   21  ,   31  ,   83  ,   227 ,   435 ,   61  ,   969 ,   2171    ,   789 ,   3415    ,   18293   ,0 };
            const std::uint32_t dim2897KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   31  ,   33  ,   87  ,   227 ,   369 ,   341 ,   1515    ,   25  ,   2891    ,   16199   ,   22179   ,0 };
            const std::uint32_t dim2898KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   25  ,   49  ,   111 ,   167 ,   59  ,   355 ,   1687    ,   1799    ,   5963    ,   6161    ,   32157   ,0 };
            const std::uint32_t dim2899KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   7   ,   57  ,   95  ,   171 ,   417 ,   277 ,   47  ,   847 ,   3889    ,   8645    ,   3367    ,0 };
            const std::uint32_t dim2900KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   25  ,   51  ,   99  ,   251 ,   463 ,   833 ,   491 ,   3595    ,   2883    ,   8183    ,   28937   ,0 };
            const std::uint32_t dim2901KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   1   ,   5   ,   73  ,   151 ,   397 ,   521 ,   905 ,   603 ,   2315    ,   15231   ,   17955   ,0 };
            const std::uint32_t dim2902KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   23  ,   59  ,   9   ,   187 ,   163 ,   727 ,   1909    ,   1135    ,   6135    ,   11563   ,   2047    ,0 };
            const std::uint32_t dim2903KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   9   ,   1   ,   121 ,   207 ,   55  ,   947 ,   873 ,   419 ,   2799    ,   3285    ,   10237   ,0 };
            const std::uint32_t dim2904KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   21  ,   27  ,   27  ,   241 ,   509 ,   295 ,   1509    ,   3527    ,   4269    ,   13579   ,   29125   ,0 };
            const std::uint32_t dim2905KuoInit[]        =   {   1   ,   3   ,   1   ,   5   ,   7   ,   21  ,   35  ,   67  ,   251 ,   883 ,   1117    ,   1311    ,   1251    ,   10401   ,   10615   ,0 };
            const std::uint32_t dim2906KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   21  ,   13  ,   23  ,   75  ,   401 ,   279 ,   1557    ,   1419    ,   7067    ,   2563    ,   22285   ,0 };
            const std::uint32_t dim2907KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   23  ,   15  ,   11  ,   189 ,   315 ,   353 ,   1377    ,   3551    ,   4939    ,   14529   ,   12459   ,0 };
            const std::uint32_t dim2908KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   21  ,   41  ,   111 ,   67  ,   311 ,   95  ,   1919    ,   165 ,   2097    ,   12965   ,   12517   ,0 };
            const std::uint32_t dim2909KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   29  ,   61  ,   33  ,   35  ,   209 ,   541 ,   149 ,   3073    ,   8187    ,   15087   ,   17617   ,0 };
            const std::uint32_t dim2910KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   9   ,   53  ,   73  ,   145 ,   205 ,   157 ,   1737    ,   1737    ,   6471    ,   12327   ,   11605   ,0 };
            const std::uint32_t dim2911KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   15  ,   35  ,   105 ,   99  ,   467 ,   421 ,   483 ,   3191    ,   2321    ,   8953    ,   22045   ,0 };
            const std::uint32_t dim2912KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   1   ,   35  ,   65  ,   249 ,   37  ,   535 ,   1301    ,   2141    ,   1629    ,   9709    ,   995 ,0 };
            const std::uint32_t dim2913KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   9   ,   27  ,   75  ,   115 ,   121 ,   731 ,   1567    ,   2341    ,   6657    ,   14959   ,   6781    ,0 };
            const std::uint32_t dim2914KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   13  ,   33  ,   89  ,   215 ,   189 ,   693 ,   357 ,   3383    ,   6345    ,   14263   ,   23973   ,0 };
            const std::uint32_t dim2915KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   21  ,   5   ,   59  ,   11  ,   21  ,   703 ,   1217    ,   2623    ,   6429    ,   479 ,   28659   ,0 };
            const std::uint32_t dim2916KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   11  ,   15  ,   113 ,   89  ,   453 ,   233 ,   1323    ,   3859    ,   1841    ,   2753    ,   2839    ,0 };
            const std::uint32_t dim2917KuoInit[]        =   {   1   ,   1   ,   5   ,   15  ,   19  ,   1   ,   119 ,   83  ,   205 ,   861 ,   787 ,   1039    ,   5257    ,   8945    ,   27271   ,0 };
            const std::uint32_t dim2918KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   9   ,   37  ,   7   ,   83  ,   51  ,   611 ,   1121    ,   3185    ,   1603    ,   5821    ,   14533   ,0 };
            const std::uint32_t dim2919KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   27  ,   61  ,   115 ,   191 ,   357 ,   93  ,   1647    ,   3249    ,   2479    ,   2423    ,   649 ,0 };
            const std::uint32_t dim2920KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   25  ,   17  ,   13  ,   213 ,   37  ,   571 ,   1179    ,   3897    ,   3817    ,   7597    ,   26239   ,0 };
            const std::uint32_t dim2921KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   27  ,   57  ,   73  ,   209 ,   433 ,   779 ,   75  ,   2135    ,   8183    ,   7343    ,   23751   ,0 };
            const std::uint32_t dim2922KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   27  ,   51  ,   31  ,   33  ,   195 ,   443 ,   1639    ,   1415    ,   6203    ,   4373    ,   31271   ,0 };
            const std::uint32_t dim2923KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   9   ,   9   ,   75  ,   103 ,   237 ,   521 ,   1653    ,   1209    ,   5981    ,   5961    ,   15229   ,0 };
            const std::uint32_t dim2924KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   15  ,   29  ,   1   ,   201 ,   171 ,   81  ,   729 ,   589 ,   441 ,   2453    ,   25209   ,0 };
            const std::uint32_t dim2925KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   21  ,   11  ,   95  ,   225 ,   213 ,   981 ,   1479    ,   3259    ,   4415    ,   8393    ,   17647   ,0 };
            const std::uint32_t dim2926KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   7   ,   11  ,   95  ,   135 ,   329 ,   483 ,   1711    ,   3223    ,   4841    ,   11083   ,   4033    ,0 };
            const std::uint32_t dim2927KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   23  ,   37  ,   77  ,   39  ,   363 ,   555 ,   1451    ,   99  ,   6963    ,   13279   ,   24155   ,0 };
            const std::uint32_t dim2928KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   11  ,   17  ,   31  ,   29  ,   357 ,   177 ,   411 ,   1439    ,   815 ,   7017    ,   25527   ,0 };
            const std::uint32_t dim2929KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   25  ,   7   ,   105 ,   9   ,   301 ,   209 ,   917 ,   1369    ,   2941    ,   11599   ,   25847   ,0 };
            const std::uint32_t dim2930KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   11  ,   33  ,   121 ,   9   ,   465 ,   945 ,   201 ,   3929    ,   5521    ,   4787    ,   10713   ,0 };
            const std::uint32_t dim2931KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   27  ,   3   ,   77  ,   11  ,   103 ,   181 ,   1199    ,   2833    ,   6259    ,   3879    ,   13217   ,0 };
            const std::uint32_t dim2932KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   11  ,   9   ,   5   ,   217 ,   471 ,   973 ,   293 ,   3693    ,   5457    ,   11359   ,   30043   ,0 };
            const std::uint32_t dim2933KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   27  ,   25  ,   7   ,   65  ,   95  ,   883 ,   277 ,   3147    ,   6203    ,   12201   ,   23203   ,0 };
            const std::uint32_t dim2934KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   3   ,   19  ,   51  ,   55  ,   381 ,   879 ,   845 ,   1605    ,   2433    ,   4781    ,   5075    ,0 };
            const std::uint32_t dim2935KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   17  ,   49  ,   21  ,   81  ,   209 ,   285 ,   1483    ,   1897    ,   5591    ,   131 ,   30459   ,0 };
            const std::uint32_t dim2936KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   17  ,   19  ,   47  ,   97  ,   325 ,   963 ,   1665    ,   3361    ,   369 ,   11023   ,   23701   ,0 };
            const std::uint32_t dim2937KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   3   ,   19  ,   57  ,   7   ,   57  ,   383 ,   1945    ,   3357    ,   2553    ,   5161    ,   22363   ,0 };
            const std::uint32_t dim2938KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   15  ,   37  ,   41  ,   123 ,   453 ,   879 ,   337 ,   251 ,   7137    ,   4117    ,   30879   ,0 };
            const std::uint32_t dim2939KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   13  ,   45  ,   55  ,   151 ,   357 ,   429 ,   671 ,   1183    ,   3047    ,   4991    ,   15273   ,0 };
            const std::uint32_t dim2940KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   15  ,   15  ,   65  ,   131 ,   505 ,   339 ,   869 ,   2983    ,   4451    ,   2375    ,   26745   ,0 };
            const std::uint32_t dim2941KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   15  ,   55  ,   23  ,   83  ,   255 ,   395 ,   15  ,   1175    ,   849 ,   5959    ,   17355   ,0 };
            const std::uint32_t dim2942KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   9   ,   3   ,   57  ,   95  ,   7   ,   267 ,   801 ,   3843    ,   3139    ,   12565   ,   20737   ,0 };
            const std::uint32_t dim2943KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   9   ,   41  ,   121 ,   77  ,   489 ,   975 ,   215 ,   325 ,   7505    ,   15517   ,   8833    ,0 };
            const std::uint32_t dim2944KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   9   ,   43  ,   105 ,   199 ,   339 ,   335 ,   1719    ,   1999    ,   4153    ,   9665    ,   15457   ,0 };
            const std::uint32_t dim2945KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   1   ,   35  ,   47  ,   157 ,   3   ,   93  ,   1399    ,   471 ,   6337    ,   2789    ,   32727   ,0 };
            const std::uint32_t dim2946KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   29  ,   9   ,   101 ,   195 ,   371 ,   573 ,   1361    ,   521 ,   5737    ,   4845    ,   4871    ,0 };
            const std::uint32_t dim2947KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   9   ,   11  ,   43  ,   129 ,   295 ,   1015    ,   665 ,   451 ,   1249    ,   7733    ,   8861    ,0 };
            const std::uint32_t dim2948KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   19  ,   31  ,   127 ,   171 ,   341 ,   865 ,   1391    ,   955 ,   5585    ,   1481    ,   1311    ,0 };
            const std::uint32_t dim2949KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   19  ,   43  ,   113 ,   83  ,   285 ,   865 ,   815 ,   807 ,   779 ,   6685    ,   22315   ,0 };
            const std::uint32_t dim2950KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   1   ,   19  ,   99  ,   19  ,   455 ,   155 ,   637 ,   2153    ,   3013    ,   4791    ,   20619   ,0 };
            const std::uint32_t dim2951KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   13  ,   39  ,   95  ,   229 ,   35  ,   515 ,   1945    ,   3631    ,   3359    ,   7913    ,   8081    ,0 };
            const std::uint32_t dim2952KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   1   ,   5   ,   25  ,   227 ,   487 ,   269 ,   1213    ,   303 ,   4041    ,   15847   ,   1125    ,0 };
            const std::uint32_t dim2953KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   27  ,   53  ,   121 ,   143 ,   1   ,   977 ,   1963    ,   807 ,   253 ,   7649    ,   16047   ,0 };
            const std::uint32_t dim2954KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   29  ,   17  ,   97  ,   93  ,   83  ,   739 ,   1221    ,   963 ,   6849    ,   4307    ,   17277   ,0 };
            const std::uint32_t dim2955KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   27  ,   55  ,   71  ,   177 ,   63  ,   11  ,   1781    ,   3341    ,   2797    ,   8035    ,   6135    ,0 };
            const std::uint32_t dim2956KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   15  ,   43  ,   59  ,   107 ,   485 ,   995 ,   1571    ,   1527    ,   2195    ,   4883    ,   32563   ,0 };
            const std::uint32_t dim2957KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   7   ,   45  ,   55  ,   211 ,   425 ,   771 ,   621 ,   1141    ,   5277    ,   13575   ,   203 ,0 };
            const std::uint32_t dim2958KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   21  ,   51  ,   81  ,   41  ,   71  ,   551 ,   839 ,   3315    ,   5075    ,   3651    ,   6649    ,0 };
            const std::uint32_t dim2959KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   17  ,   45  ,   51  ,   211 ,   349 ,   329 ,   987 ,   3153    ,   7121    ,   16101   ,   1475    ,0 };
            const std::uint32_t dim2960KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   5   ,   5   ,   99  ,   17  ,   245 ,   827 ,   231 ,   949 ,   2577    ,   12925   ,   2055    ,0 };
            const std::uint32_t dim2961KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   19  ,   59  ,   75  ,   97  ,   303 ,   649 ,   901 ,   3987    ,   1209    ,   14483   ,   25855   ,0 };
            const std::uint32_t dim2962KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   25  ,   51  ,   5   ,   69  ,   199 ,   845 ,   1847    ,   1491    ,   6183    ,   3359    ,   11809   ,0 };
            const std::uint32_t dim2963KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   19  ,   43  ,   17  ,   113 ,   215 ,   337 ,   583 ,   2199    ,   6375    ,   499 ,   11283   ,0 };
            const std::uint32_t dim2964KuoInit[]        =   {   1   ,   1   ,   5   ,   15  ,   5   ,   3   ,   45  ,   219 ,   375 ,   269 ,   1251    ,   2711    ,   7897    ,   3379    ,   11887   ,0 };
            const std::uint32_t dim2965KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   3   ,   59  ,   17  ,   41  ,   275 ,   1007    ,   711 ,   1689    ,   3727    ,   14237   ,   32057   ,0 };
            const std::uint32_t dim2966KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   5   ,   27  ,   73  ,   167 ,   295 ,   581 ,   233 ,   585 ,   7207    ,   12709   ,   3847    ,0 };
            const std::uint32_t dim2967KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   9   ,   17  ,   65  ,   15  ,   439 ,   385 ,   455 ,   1073    ,   5727    ,   2679    ,   3689    ,0 };
            const std::uint32_t dim2968KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   7   ,   63  ,   111 ,   161 ,   85  ,   295 ,   755 ,   2805    ,   3031    ,   4833    ,   11149   ,0 };
            const std::uint32_t dim2969KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   13  ,   53  ,   63  ,   47  ,   163 ,   275 ,   289 ,   1377    ,   639 ,   15367   ,   32517   ,0 };
            const std::uint32_t dim2970KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   21  ,   43  ,   123 ,   221 ,   451 ,   901 ,   1339    ,   3367    ,   2531    ,   9319    ,   4461    ,0 };
            const std::uint32_t dim2971KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   3   ,   53  ,   87  ,   117 ,   471 ,   349 ,   1487    ,   2375    ,   7399    ,   8561    ,   19611   ,0 };
            const std::uint32_t dim2972KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   29  ,   55  ,   53  ,   197 ,   301 ,   701 ,   357 ,   3651    ,   2233    ,   6365    ,   705 ,0 };
            const std::uint32_t dim2973KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   17  ,   19  ,   23  ,   17  ,   433 ,   979 ,   1377    ,   213 ,   3993    ,   3773    ,   24369   ,0 };
            const std::uint32_t dim2974KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   17  ,   9   ,   105 ,   149 ,   145 ,   751 ,   1173    ,   1831    ,   7005    ,   3559    ,   10913   ,0 };
            const std::uint32_t dim2975KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   23  ,   47  ,   83  ,   213 ,   135 ,   223 ,   937 ,   3607    ,   7375    ,   4731    ,   14307   ,0 };
            const std::uint32_t dim2976KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   23  ,   21  ,   71  ,   241 ,   399 ,   199 ,   289 ,   2049    ,   7959    ,   14897   ,   18661   ,0 };
            const std::uint32_t dim2977KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   13  ,   45  ,   125 ,   217 ,   325 ,   893 ,   1523    ,   2477    ,   7829    ,   15737   ,   2127    ,0 };
            const std::uint32_t dim2978KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   21  ,   51  ,   117 ,   203 ,   253 ,   713 ,   545 ,   191 ,   729 ,   8403    ,   8381    ,0 };
            const std::uint32_t dim2979KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   11  ,   23  ,   3   ,   193 ,   421 ,   341 ,   1309    ,   2457    ,   5805    ,   7457    ,   26857   ,0 };
            const std::uint32_t dim2980KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   1   ,   17  ,   27  ,   159 ,   127 ,   713 ,   1465    ,   3551    ,   7409    ,   7957    ,   2317    ,0 };
            const std::uint32_t dim2981KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   7   ,   33  ,   17  ,   1   ,   237 ,   199 ,   527 ,   3361    ,   3785    ,   13111   ,   19119   ,0 };
            const std::uint32_t dim2982KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   23  ,   37  ,   91  ,   31  ,   35  ,   969 ,   661 ,   85  ,   5917    ,   10895   ,   11049   ,0 };
            const std::uint32_t dim2983KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   23  ,   53  ,   101 ,   181 ,   381 ,   159 ,   1967    ,   3427    ,   4499    ,   6877    ,   12155   ,0 };
            const std::uint32_t dim2984KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   9   ,   57  ,   77  ,   27  ,   223 ,   101 ,   1709    ,   3023    ,   6655    ,   6221    ,   1027    ,0 };
            const std::uint32_t dim2985KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   19  ,   47  ,   73  ,   175 ,   103 ,   35  ,   1039    ,   343 ,   6757    ,   11521   ,   24495   ,0 };
            const std::uint32_t dim2986KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   17  ,   19  ,   9   ,   205 ,   279 ,   373 ,   173 ,   3641    ,   3945    ,   10831   ,   15621   ,0 };
            const std::uint32_t dim2987KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   29  ,   63  ,   71  ,   217 ,   367 ,   381 ,   647 ,   9   ,   5521    ,   5209    ,   24275   ,0 };
            const std::uint32_t dim2988KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   23  ,   15  ,   7   ,   203 ,   153 ,   655 ,   2047    ,   287 ,   973 ,   6757    ,   29207   ,0 };
            const std::uint32_t dim2989KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   17  ,   33  ,   63  ,   97  ,   49  ,   31  ,   1989    ,   569 ,   3321    ,   4017    ,   6437    ,0 };
            const std::uint32_t dim2990KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   15  ,   15  ,   57  ,   255 ,   381 ,   115 ,   573 ,   3903    ,   7141    ,   1569    ,   11789   ,0 };
            const std::uint32_t dim2991KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   9   ,   45  ,   69  ,   111 ,   91  ,   389 ,   1347    ,   3351    ,   3023    ,   517 ,   28373   ,0 };
            const std::uint32_t dim2992KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   9   ,   11  ,   81  ,   205 ,   299 ,   903 ,   661 ,   3377    ,   5355    ,   9151    ,   17597   ,0 };
            const std::uint32_t dim2993KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   19  ,   55  ,   45  ,   123 ,   285 ,   161 ,   1591    ,   1971    ,   5471    ,   8221    ,   2855    ,0 };
            const std::uint32_t dim2994KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   23  ,   25  ,   87  ,   197 ,   303 ,   487 ,   395 ,   3137    ,   4395    ,   5861    ,   5847    ,0 };
            const std::uint32_t dim2995KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   23  ,   9   ,   107 ,   13  ,   127 ,   971 ,   1701    ,   2387    ,   6195    ,   5041    ,   24857   ,0 };
            const std::uint32_t dim2996KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   19  ,   63  ,   91  ,   205 ,   207 ,   897 ,   295 ,   2093    ,   1223    ,   14599   ,   13803   ,0 };
            const std::uint32_t dim2997KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   1   ,   25  ,   93  ,   33  ,   393 ,   221 ,   1845    ,   2517    ,   1723    ,   13881   ,   15777   ,0 };
            const std::uint32_t dim2998KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   1   ,   21  ,   115 ,   103 ,   377 ,   789 ,   541 ,   3423    ,   3111    ,   8077    ,   25089   ,0 };
            const std::uint32_t dim2999KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   31  ,   55  ,   95  ,   53  ,   141 ,   697 ,   1085    ,   3031    ,   653 ,   4145    ,   28121   ,0 };
            const std::uint32_t dim3000KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   7   ,   39  ,   55  ,   57  ,   447 ,   257 ,   101 ,   2307    ,   5623    ,   8505    ,   995 ,0 };
            const std::uint32_t dim3001KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   25  ,   37  ,   11  ,   203 ,   361 ,   281 ,   701 ,   3643    ,   957 ,   14541   ,   8109    ,0 };
            const std::uint32_t dim3002KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   21  ,   49  ,   57  ,   225 ,   21  ,   523 ,   1275    ,   3743    ,   6259    ,   13625   ,   26721   ,0 };
            const std::uint32_t dim3003KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   13  ,   53  ,   9   ,   167 ,   117 ,   971 ,   875 ,   2659    ,   7589    ,   13575   ,   11659   ,0 };
            const std::uint32_t dim3004KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   21  ,   1   ,   35  ,   201 ,   261 ,   533 ,   1069    ,   1459    ,   5433    ,   7211    ,   3535    ,0 };
            const std::uint32_t dim3005KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   23  ,   7   ,   41  ,   137 ,   341 ,   767 ,   1823    ,   3745    ,   1415    ,   4811    ,   21669   ,0 };
            const std::uint32_t dim3006KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   5   ,   11  ,   71  ,   117 ,   451 ,   1   ,   381 ,   967 ,   7977    ,   10741   ,   20141   ,0 };
            const std::uint32_t dim3007KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   21  ,   1   ,   65  ,   37  ,   451 ,   29  ,   327 ,   2471    ,   7573    ,   5051    ,   23925   ,0 };
            const std::uint32_t dim3008KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   17  ,   61  ,   97  ,   121 ,   327 ,   929 ,   1165    ,   185 ,   2343    ,   1479    ,   3817    ,0 };
            const std::uint32_t dim3009KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   27  ,   55  ,   87  ,   53  ,   389 ,   577 ,   1051    ,   2413    ,   609 ,   12651   ,   15695   ,0 };
            const std::uint32_t dim3010KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   1   ,   41  ,   25  ,   149 ,   175 ,   667 ,   1219    ,   2297    ,   6599    ,   1667    ,   19647   ,0 };
            const std::uint32_t dim3011KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   17  ,   63  ,   83  ,   37  ,   425 ,   675 ,   1111    ,   499 ,   7727    ,   7491    ,   9759    ,0 };
            const std::uint32_t dim3012KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   21  ,   23  ,   17  ,   125 ,   485 ,   643 ,   341 ,   1159    ,   7073    ,   14405   ,   22409   ,0 };
            const std::uint32_t dim3013KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   15  ,   53  ,   23  ,   17  ,   365 ,   101 ,   685 ,   1391    ,   5123    ,   14961   ,   31179   ,0 };
            const std::uint32_t dim3014KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   23  ,   11  ,   101 ,   139 ,   401 ,   779 ,   1723    ,   3421    ,   623 ,   3443    ,   17179   ,0 };
            const std::uint32_t dim3015KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   13  ,   19  ,   93  ,   129 ,   127 ,   389 ,   1361    ,   2341    ,   6491    ,   15063   ,   8199    ,0 };
            const std::uint32_t dim3016KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   31  ,   1   ,   55  ,   169 ,   373 ,   69  ,   539 ,   513 ,   6329    ,   393 ,   21963   ,0 };
            const std::uint32_t dim3017KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   5   ,   39  ,   73  ,   87  ,   401 ,   923 ,   1747    ,   565 ,   2227    ,   14509   ,   7601    ,0 };
            const std::uint32_t dim3018KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   25  ,   3   ,   77  ,   207 ,   149 ,   591 ,   1165    ,   3235    ,   7615    ,   12237   ,   20849   ,0 };
            const std::uint32_t dim3019KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   21  ,   41  ,   83  ,   109 ,   265 ,   349 ,   485 ,   1411    ,   2705    ,   13017   ,   25205   ,0 };
            const std::uint32_t dim3020KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   31  ,   27  ,   55  ,   23  ,   129 ,   369 ,   1785    ,   2031    ,   1993    ,   123 ,   20063   ,0 };
            const std::uint32_t dim3021KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   9   ,   45  ,   75  ,   37  ,   69  ,   957 ,   2047    ,   2515    ,   5327    ,   15345   ,   2147    ,0 };
            const std::uint32_t dim3022KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   5   ,   57  ,   91  ,   19  ,   499 ,   173 ,   765 ,   3653    ,   6397    ,   1509    ,   11223   ,0 };
            const std::uint32_t dim3023KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   1   ,   15  ,   69  ,   107 ,   225 ,   233 ,   1015    ,   807 ,   4265    ,   8823    ,   22047   ,0 };
            const std::uint32_t dim3024KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   15  ,   55  ,   15  ,   83  ,   49  ,   711 ,   935 ,   1865    ,   29  ,   607 ,   8113    ,0 };
            const std::uint32_t dim3025KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   13  ,   15  ,   127 ,   193 ,   219 ,   653 ,   1787    ,   905 ,   3311    ,   11595   ,   21193   ,0 };
            const std::uint32_t dim3026KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   21  ,   51  ,   67  ,   97  ,   371 ,   367 ,   1763    ,   2953    ,   3701    ,   15983   ,   18631   ,0 };
            const std::uint32_t dim3027KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   13  ,   1   ,   83  ,   15  ,   305 ,   939 ,   1073    ,   1577    ,   2073    ,   5335    ,   17173   ,0 };
            const std::uint32_t dim3028KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   19  ,   7   ,   27  ,   213 ,   357 ,   681 ,   1969    ,   4007    ,   7887    ,   11191   ,   19395   ,0 };
            const std::uint32_t dim3029KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   19  ,   29  ,   119 ,   239 ,   123 ,   559 ,   1613    ,   1563    ,   8047    ,   5753    ,   26719   ,0 };
            const std::uint32_t dim3030KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   3   ,   3   ,   127 ,   241 ,   333 ,   453 ,   1407    ,   2687    ,   4603    ,   3637    ,   23041   ,0 };
            const std::uint32_t dim3031KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   17  ,   9   ,   7   ,   31  ,   145 ,   613 ,   1851    ,   1981    ,   3921    ,   6469    ,   32397   ,0 };
            const std::uint32_t dim3032KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   9   ,   39  ,   113 ,   79  ,   165 ,   359 ,   1573    ,   2311    ,   651 ,   7047    ,   15961   ,0 };
            const std::uint32_t dim3033KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   11  ,   57  ,   59  ,   153 ,   363 ,   279 ,   77  ,   3085    ,   5971    ,   29  ,   22087   ,0 };
            const std::uint32_t dim3034KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   25  ,   47  ,   49  ,   229 ,   147 ,   777 ,   1177    ,   1117    ,   3783    ,   3681    ,   1465    ,0 };
            const std::uint32_t dim3035KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   3   ,   45  ,   11  ,   139 ,   393 ,   9   ,   471 ,   1643    ,   4963    ,   5837    ,   17023   ,0 };
            const std::uint32_t dim3036KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   5   ,   41  ,   123 ,   113 ,   223 ,   237 ,   239 ,   1099    ,   6065    ,   11105   ,   10259   ,0 };
            const std::uint32_t dim3037KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   15  ,   57  ,   41  ,   173 ,   169 ,   585 ,   201 ,   2133    ,   2629    ,   12861   ,   16559   ,0 };
            const std::uint32_t dim3038KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   9   ,   27  ,   3   ,   157 ,   279 ,   393 ,   1849    ,   437 ,   5549    ,   10009   ,   11783   ,0 };
            const std::uint32_t dim3039KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   17  ,   23  ,   67  ,   143 ,   1   ,   203 ,   153 ,   1699    ,   1333    ,   16001   ,   11755   ,0 };
            const std::uint32_t dim3040KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   17  ,   61  ,   59  ,   235 ,   67  ,   393 ,   1597    ,   3523    ,   2049    ,   11887   ,   7737    ,0 };
            const std::uint32_t dim3041KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   21  ,   45  ,   5   ,   221 ,   299 ,   887 ,   699 ,   959 ,   1143    ,   4879    ,   8767    ,0 };
            const std::uint32_t dim3042KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   11  ,   35  ,   83  ,   237 ,   167 ,   1   ,   1429    ,   2877    ,   4611    ,   14881   ,   4453    ,0 };
            const std::uint32_t dim3043KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   7   ,   55  ,   21  ,   237 ,   9   ,   743 ,   1707    ,   1229    ,   6827    ,   407 ,   777 ,0 };
            const std::uint32_t dim3044KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   15  ,   39  ,   3   ,   127 ,   163 ,   747 ,   1773    ,   1569    ,   2377    ,   15023   ,   32249   ,0 };
            const std::uint32_t dim3045KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   19  ,   33  ,   1   ,   55  ,   319 ,   585 ,   413 ,   1241    ,   95  ,   7163    ,   29935   ,0 };
            const std::uint32_t dim3046KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   7   ,   51  ,   77  ,   197 ,   481 ,   517 ,   1441    ,   1779    ,   1405    ,   3633    ,   32545   ,0 };
            const std::uint32_t dim3047KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   13  ,   51  ,   69  ,   35  ,   131 ,   115 ,   1759    ,   3991    ,   8065    ,   10311   ,   12749   ,0 };
            const std::uint32_t dim3048KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   5   ,   35  ,   37  ,   181 ,   371 ,   543 ,   1389    ,   815 ,   3261    ,   11997   ,   29665   ,0 };
            const std::uint32_t dim3049KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   31  ,   47  ,   33  ,   147 ,   445 ,   663 ,   63  ,   1033    ,   6081    ,   15523   ,   28477   ,0 };
            const std::uint32_t dim3050KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   11  ,   9   ,   1   ,   39  ,   357 ,   873 ,   1829    ,   3245    ,   3219    ,   601 ,   1335    ,0 };
            const std::uint32_t dim3051KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   5   ,   5   ,   33  ,   145 ,   465 ,   5   ,   1959    ,   3573    ,   3791    ,   8689    ,   14513   ,0 };
            const std::uint32_t dim3052KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   31  ,   37  ,   103 ,   255 ,   87  ,   903 ,   1325    ,   1423    ,   8031    ,   14845   ,   12261   ,0 };
            const std::uint32_t dim3053KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   31  ,   25  ,   41  ,   45  ,   261 ,   225 ,   1711    ,   641 ,   2331    ,   10825   ,   21539   ,0 };
            const std::uint32_t dim3054KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   9   ,   33  ,   23  ,   135 ,   165 ,   363 ,   1435    ,   3019    ,   4907    ,   9791    ,   1337    ,0 };
            const std::uint32_t dim3055KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   13  ,   23  ,   109 ,   161 ,   107 ,   829 ,   1635    ,   791 ,   2757    ,   15265   ,   8771    ,0 };
            const std::uint32_t dim3056KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   7   ,   17  ,   45  ,   167 ,   69  ,   437 ,   1051    ,   1443    ,   875 ,   2461    ,   28471   ,0 };
            const std::uint32_t dim3057KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   23  ,   43  ,   55  ,   69  ,   365 ,   497 ,   1529    ,   1101    ,   211 ,   8145    ,   10579   ,0 };
            const std::uint32_t dim3058KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   19  ,   9   ,   91  ,   91  ,   453 ,   875 ,   1815    ,   1455    ,   7969    ,   5621    ,   4773    ,0 };
            const std::uint32_t dim3059KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   17  ,   63  ,   19  ,   193 ,   335 ,   571 ,   703 ,   919 ,   773 ,   1789    ,   17839   ,0 };
            const std::uint32_t dim3060KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   1   ,   57  ,   11  ,   171 ,   11  ,   833 ,   191 ,   1719    ,   7649    ,   11005   ,   20171   ,0 };
            const std::uint32_t dim3061KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   25  ,   55  ,   63  ,   71  ,   127 ,   445 ,   1151    ,   2709    ,   6633    ,   4959    ,   13511   ,0 };
            const std::uint32_t dim3062KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   3   ,   41  ,   43  ,   59  ,   211 ,   123 ,   987 ,   3701    ,   6391    ,   6755    ,   3069    ,0 };
            const std::uint32_t dim3063KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   5   ,   3   ,   93  ,   29  ,   233 ,   365 ,   117 ,   1483    ,   4917    ,   1949    ,   23697   ,0 };
            const std::uint32_t dim3064KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   15  ,   53  ,   21  ,   9   ,   23  ,   701 ,   1337    ,   2591    ,   7719    ,   14063   ,   28453   ,0 };
            const std::uint32_t dim3065KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   21  ,   3   ,   127 ,   179 ,   409 ,   261 ,   1683    ,   3197    ,   1999    ,   10009   ,   25031   ,0 };
            const std::uint32_t dim3066KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   31  ,   57  ,   9   ,   91  ,   31  ,   125 ,   1831    ,   1943    ,   5931    ,   15015   ,   22269   ,0 };
            const std::uint32_t dim3067KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   7   ,   7   ,   83  ,   113 ,   203 ,   679 ,   1279    ,   3403    ,   7069    ,   8617    ,   27827   ,0 };
            const std::uint32_t dim3068KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   29  ,   47  ,   93  ,   59  ,   315 ,   107 ,   807 ,   2861    ,   2345    ,   11787   ,   6543    ,0 };
            const std::uint32_t dim3069KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   21  ,   25  ,   3   ,   35  ,   345 ,   833 ,   2029    ,   281 ,   2389    ,   11529   ,   20647   ,0 };
            const std::uint32_t dim3070KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   19  ,   47  ,   109 ,   21  ,   251 ,   625 ,   1699    ,   2169    ,   7293    ,   14035   ,   24277   ,0 };
            const std::uint32_t dim3071KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   15  ,   7   ,   51  ,   125 ,   423 ,   981 ,   437 ,   1021    ,   5209    ,   11447   ,   26181   ,0 };
            const std::uint32_t dim3072KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   15  ,   41  ,   75  ,   227 ,   13  ,   85  ,   675 ,   3993    ,   8163    ,   8095    ,   23801   ,0 };
            const std::uint32_t dim3073KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   25  ,   1   ,   85  ,   143 ,   309 ,   815 ,   1271    ,   1331    ,   6565    ,   369 ,   7975    ,0 };
            const std::uint32_t dim3074KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   21  ,   45  ,   113 ,   153 ,   283 ,   117 ,   1481    ,   3527    ,   3371    ,   15801   ,   22337   ,0 };
            const std::uint32_t dim3075KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   17  ,   47  ,   107 ,   25  ,   373 ,   549 ,   1387    ,   1247    ,   2307    ,   6469    ,   24327   ,0 };
            const std::uint32_t dim3076KuoInit[]        =   {   1   ,   1   ,   5   ,   15  ,   9   ,   57  ,   43  ,   179 ,   157 ,   119 ,   547 ,   3665    ,   1495    ,   13405   ,   2391    ,0 };
            const std::uint32_t dim3077KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   7   ,   57  ,   123 ,   189 ,   281 ,   87  ,   1559    ,   2863    ,   8017    ,   10279   ,   32005   ,0 };
            const std::uint32_t dim3078KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   29  ,   21  ,   51  ,   123 ,   351 ,   683 ,   1505    ,   681 ,   49  ,   2929    ,   7591    ,0 };
            const std::uint32_t dim3079KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   17  ,   63  ,   119 ,   209 ,   441 ,   717 ,   567 ,   1283    ,   1007    ,   14661   ,   32383   ,0 };
            const std::uint32_t dim3080KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   27  ,   41  ,   41  ,   157 ,   487 ,   257 ,   1267    ,   165 ,   1023    ,   16065   ,   16431   ,0 };
            const std::uint32_t dim3081KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   17  ,   53  ,   51  ,   175 ,   367 ,   453 ,   1445    ,   1889    ,   4567    ,   1781    ,   6543    ,0 };
            const std::uint32_t dim3082KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   27  ,   47  ,   95  ,   51  ,   483 ,   581 ,   1617    ,   685 ,   3017    ,   4889    ,   6185    ,0 };
            const std::uint32_t dim3083KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   29  ,   23  ,   9   ,   23  ,   165 ,   3   ,   279 ,   861 ,   1007    ,   9607    ,   24999   ,0 };
            const std::uint32_t dim3084KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   11  ,   59  ,   55  ,   135 ,   399 ,   729 ,   683 ,   2119    ,   3781    ,   15525   ,   1125    ,0 };
            const std::uint32_t dim3085KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   25  ,   61  ,   123 ,   153 ,   267 ,   823 ,   951 ,   4069    ,   8017    ,   4899    ,   6535    ,0 };
            const std::uint32_t dim3086KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   5   ,   43  ,   5   ,   123 ,   57  ,   229 ,   129 ,   131 ,   7491    ,   2105    ,   16411   ,0 };
            const std::uint32_t dim3087KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   9   ,   37  ,   123 ,   211 ,   331 ,   623 ,   1469    ,   1155    ,   6327    ,   12591   ,   18971   ,0 };
            const std::uint32_t dim3088KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   17  ,   35  ,   59  ,   137 ,   451 ,   829 ,   365 ,   305 ,   5857    ,   2095    ,   14597   ,0 };
            const std::uint32_t dim3089KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   15  ,   11  ,   23  ,   201 ,   247 ,   883 ,   1103    ,   4035    ,   5915    ,   4275    ,   12511   ,0 };
            const std::uint32_t dim3090KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   27  ,   19  ,   87  ,   189 ,   91  ,   113 ,   237 ,   2073    ,   419 ,   1339    ,   16705   ,0 };
            const std::uint32_t dim3091KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   15  ,   59  ,   99  ,   237 ,   167 ,   327 ,   1507    ,   771 ,   3743    ,   1723    ,   28873   ,0 };
            const std::uint32_t dim3092KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   27  ,   19  ,   35  ,   175 ,   403 ,   1   ,   617 ,   2425    ,   2021    ,   12547   ,   23655   ,0 };
            const std::uint32_t dim3093KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   7   ,   1   ,   45  ,   169 ,   43  ,   501 ,   1653    ,   593 ,   7219    ,   5501    ,   3671    ,0 };
            const std::uint32_t dim3094KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   23  ,   53  ,   117 ,   165 ,   329 ,   177 ,   89  ,   2269    ,   7897    ,   11225   ,   25807   ,0 };
            const std::uint32_t dim3095KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   25  ,   41  ,   91  ,   43  ,   107 ,   699 ,   1745    ,   3117    ,   7497    ,   6579    ,   21803   ,0 };
            const std::uint32_t dim3096KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   19  ,   9   ,   103 ,   65  ,   413 ,   459 ,   1751    ,   4025    ,   6695    ,   9589    ,   1443    ,0 };
            const std::uint32_t dim3097KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   31  ,   31  ,   23  ,   251 ,   343 ,   809 ,   283 ,   1501    ,   445 ,   7945    ,   26993   ,0 };
            const std::uint32_t dim3098KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   1   ,   11  ,   113 ,   235 ,   127 ,   45  ,   109 ,   2421    ,   3955    ,   1017    ,   21497   ,0 };
            const std::uint32_t dim3099KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   5   ,   57  ,   47  ,   227 ,   447 ,   499 ,   1755    ,   3527    ,   1625    ,   13341   ,   22301   ,0 };
            const std::uint32_t dim3100KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   13  ,   9   ,   113 ,   101 ,   377 ,   39  ,   991 ,   3791    ,   7351    ,   12841   ,   2911    ,0 };
            const std::uint32_t dim3101KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   1   ,   31  ,   111 ,   85  ,   247 ,   387 ,   1907    ,   3061    ,   569 ,   5845    ,   6729    ,0 };
            const std::uint32_t dim3102KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   31  ,   17  ,   77  ,   33  ,   109 ,   661 ,   67  ,   3725    ,   955 ,   9475    ,   14345   ,0 };
            const std::uint32_t dim3103KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   11  ,   23  ,   63  ,   23  ,   67  ,   843 ,   1747    ,   2441    ,   2063    ,   8575    ,   11921   ,0 };
            const std::uint32_t dim3104KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   25  ,   19  ,   43  ,   177 ,   67  ,   57  ,   1127    ,   3817    ,   3097    ,   6143    ,   27757   ,0 };
            const std::uint32_t dim3105KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   19  ,   25  ,   65  ,   135 ,   143 ,   863 ,   1013    ,   1285    ,   6133    ,   13491   ,   5093    ,0 };
            const std::uint32_t dim3106KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   7   ,   17  ,   61  ,   199 ,   39  ,   767 ,   295 ,   127 ,   335 ,   10789   ,   20473   ,0 };
            const std::uint32_t dim3107KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   15  ,   51  ,   87  ,   75  ,   439 ,   71  ,   1371    ,   1911    ,   1145    ,   4201    ,   26883   ,0 };
            const std::uint32_t dim3108KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   3   ,   15  ,   79  ,   237 ,   43  ,   375 ,   1925    ,   1517    ,   6415    ,   303 ,   2217    ,0 };
            const std::uint32_t dim3109KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   21  ,   23  ,   19  ,   83  ,   159 ,   249 ,   1297    ,   1853    ,   2609    ,   13635   ,   29119   ,0 };
            const std::uint32_t dim3110KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   29  ,   53  ,   125 ,   73  ,   299 ,   45  ,   557 ,   3641    ,   1593    ,   10585   ,   22545   ,0 };
            const std::uint32_t dim3111KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   13  ,   45  ,   53  ,   245 ,   401 ,   635 ,   785 ,   2841    ,   3033    ,   12377   ,   1235    ,0 };
            const std::uint32_t dim3112KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   23  ,   35  ,   71  ,   207 ,   211 ,   901 ,   351 ,   1473    ,   6683    ,   981 ,   17449   ,0 };
            const std::uint32_t dim3113KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   17  ,   13  ,   125 ,   213 ,   109 ,   631 ,   677 ,   2141    ,   1037    ,   6119    ,   25945   ,0 };
            const std::uint32_t dim3114KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   29  ,   3   ,   53  ,   23  ,   45  ,   347 ,   27  ,   1537    ,   7833    ,   16315   ,   12337   ,0 };
            const std::uint32_t dim3115KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   31  ,   23  ,   15  ,   241 ,   315 ,   977 ,   99  ,   3067    ,   3227    ,   6153    ,   9751    ,0 };
            const std::uint32_t dim3116KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   13  ,   33  ,   5   ,   5   ,   29  ,   547 ,   1105    ,   1135    ,   7263    ,   7421    ,   9545    ,0 };
            const std::uint32_t dim3117KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   19  ,   25  ,   53  ,   239 ,   65  ,   417 ,   1681    ,   659 ,   133 ,   4113    ,   16735   ,0 };
            const std::uint32_t dim3118KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   3   ,   55  ,   57  ,   33  ,   357 ,   885 ,   941 ,   3471    ,   6863    ,   777 ,   19111   ,0 };
            const std::uint32_t dim3119KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   27  ,   47  ,   65  ,   161 ,   115 ,   577 ,   1951    ,   363 ,   2045    ,   2497    ,   6931    ,0 };
            const std::uint32_t dim3120KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   29  ,   37  ,   21  ,   235 ,   233 ,   833 ,   81  ,   2875    ,   4759    ,   8435    ,   16017   ,0 };
            const std::uint32_t dim3121KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   9   ,   57  ,   89  ,   21  ,   291 ,   445 ,   1833    ,   735 ,   3935    ,   14943   ,   30987   ,0 };
            const std::uint32_t dim3122KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   23  ,   9   ,   37  ,   71  ,   175 ,   899 ,   1897    ,   707 ,   6201    ,   15543   ,   13801   ,0 };
            const std::uint32_t dim3123KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   13  ,   25  ,   17  ,   209 ,   455 ,   969 ,   755 ,   397 ,   4103    ,   3159    ,   28665   ,0 };
            const std::uint32_t dim3124KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   15  ,   7   ,   17  ,   249 ,   299 ,   423 ,   83  ,   1203    ,   7397    ,   15657   ,   15661   ,0 };
            const std::uint32_t dim3125KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   19  ,   19  ,   21  ,   231 ,   443 ,   729 ,   947 ,   1451    ,   3399    ,   5691    ,   11943   ,0 };
            const std::uint32_t dim3126KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   15  ,   11  ,   89  ,   211 ,   459 ,   3   ,   741 ,   105 ,   1147    ,   927 ,   31805   ,0 };
            const std::uint32_t dim3127KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   7   ,   1   ,   61  ,   145 ,   291 ,   1021    ,   221 ,   821 ,   4999    ,   3165    ,   22549   ,0 };
            const std::uint32_t dim3128KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   5   ,   41  ,   101 ,   137 ,   143 ,   249 ,   87  ,   4045    ,   2301    ,   3833    ,   9841    ,0 };
            const std::uint32_t dim3129KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   19  ,   61  ,   111 ,   109 ,   87  ,   65  ,   971 ,   3943    ,   6559    ,   9647    ,   3049    ,0 };
            const std::uint32_t dim3130KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   9   ,   11  ,   41  ,   61  ,   145 ,   27  ,   1287    ,   3537    ,   1943    ,   10635   ,   32557   ,0 };
            const std::uint32_t dim3131KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   17  ,   35  ,   29  ,   177 ,   5   ,   131 ,   465 ,   1235    ,   1383    ,   14253   ,   17595   ,0 };
            const std::uint32_t dim3132KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   15  ,   63  ,   21  ,   119 ,   195 ,   627 ,   1635    ,   2369    ,   5549    ,   7641    ,   29481   ,0 };
            const std::uint32_t dim3133KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   25  ,   3   ,   73  ,   233 ,   115 ,   749 ,   707 ,   1939    ,   3667    ,   1899    ,   22345   ,0 };
            const std::uint32_t dim3134KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   15  ,   33  ,   17  ,   91  ,   507 ,   289 ,   1929    ,   2001    ,   629 ,   15559   ,   12725   ,0 };
            const std::uint32_t dim3135KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   7   ,   7   ,   91  ,   171 ,   95  ,   257 ,   1611    ,   3527    ,   2769    ,   5779    ,   7783    ,0 };
            const std::uint32_t dim3136KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   27  ,   27  ,   55  ,   113 ,   171 ,   61  ,   1229    ,   3681    ,   4487    ,   9815    ,   20357   ,0 };
            const std::uint32_t dim3137KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   1   ,   21  ,   57  ,   67  ,   185 ,   189 ,   1673    ,   3637    ,   2987    ,   4619    ,   6339    ,0 };
            const std::uint32_t dim3138KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   9   ,   45  ,   71  ,   183 ,   107 ,   145 ,   821 ,   1115    ,   6067    ,   8301    ,   7565    ,0 };
            const std::uint32_t dim3139KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   21  ,   29  ,   85  ,   9   ,   427 ,   553 ,   887 ,   2463    ,   4023    ,   9107    ,   25405   ,0 };
            const std::uint32_t dim3140KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   25  ,   45  ,   89  ,   235 ,   349 ,   671 ,   1667    ,   2023    ,   2385    ,   1831    ,   515 ,0 };
            const std::uint32_t dim3141KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   17  ,   37  ,   95  ,   77  ,   445 ,   169 ,   829 ,   9   ,   2589    ,   12809   ,   32469   ,0 };
            const std::uint32_t dim3142KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   23  ,   31  ,   117 ,   81  ,   275 ,   861 ,   1439    ,   4041    ,   3337    ,   14945   ,   15921   ,0 };
            const std::uint32_t dim3143KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   9   ,   21  ,   121 ,   23  ,   133 ,   563 ,   1889    ,   1939    ,   4427    ,   5501    ,   4609    ,0 };
            const std::uint32_t dim3144KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   17  ,   25  ,   7   ,   245 ,   319 ,   697 ,   1561    ,   3209    ,   2369    ,   16045   ,   31799   ,0 };
            const std::uint32_t dim3145KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   13  ,   19  ,   83  ,   165 ,   457 ,   1005    ,   743 ,   4049    ,   2563    ,   14487   ,   23699   ,0 };
            const std::uint32_t dim3146KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   5   ,   25  ,   65  ,   185 ,   27  ,   235 ,   1771    ,   3505    ,   6807    ,   14715   ,   19841   ,0 };
            const std::uint32_t dim3147KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   15  ,   15  ,   19  ,   111 ,   99  ,   397 ,   315 ,   2587    ,   7335    ,   4371    ,   11753   ,0 };
            const std::uint32_t dim3148KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   1   ,   21  ,   55  ,   255 ,   105 ,   865 ,   179 ,   2127    ,   4485    ,   1803    ,   19503   ,0 };
            const std::uint32_t dim3149KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   27  ,   23  ,   9   ,   9   ,   323 ,   421 ,   671 ,   3323    ,   5263    ,   2963    ,   16065   ,0 };
            const std::uint32_t dim3150KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   17  ,   47  ,   79  ,   255 ,   259 ,   913 ,   1691    ,   1553    ,   2443    ,   14167   ,   24499   ,0 };
            const std::uint32_t dim3151KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   21  ,   7   ,   17  ,   71  ,   57  ,   715 ,   2023    ,   2133    ,   5439    ,   12483   ,   32547   ,0 };
            const std::uint32_t dim3152KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   1   ,   37  ,   23  ,   235 ,   35  ,   739 ,   1767    ,   3531    ,   597 ,   13259   ,   7869    ,0 };
            const std::uint32_t dim3153KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   7   ,   5   ,   29  ,   129 ,   223 ,   991 ,   31  ,   375 ,   1917    ,   1157    ,   9723    ,0 };
            const std::uint32_t dim3154KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   29  ,   33  ,   33  ,   73  ,   339 ,   21  ,   2037    ,   1127    ,   6385    ,   16335   ,   25825   ,0 };
            const std::uint32_t dim3155KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   7   ,   49  ,   103 ,   235 ,   503 ,   687 ,   277 ,   2639    ,   5997    ,   11797   ,   27141   ,0 };
            const std::uint32_t dim3156KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   27  ,   31  ,   103 ,   145 ,   245 ,   493 ,   867 ,   2075    ,   5369    ,   12551   ,   4907    ,0 };
            const std::uint32_t dim3157KuoInit[]        =   {   1   ,   3   ,   1   ,   5   ,   19  ,   57  ,   101 ,   165 ,   61  ,   201 ,   1299    ,   3081    ,   8173    ,   12835   ,   7915    ,0 };
            const std::uint32_t dim3158KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   29  ,   23  ,   49  ,   41  ,   473 ,   273 ,   1493    ,   1915    ,   6669    ,   14263   ,   13385   ,0 };
            const std::uint32_t dim3159KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   21  ,   27  ,   49  ,   73  ,   281 ,   1017    ,   1905    ,   1005    ,   631 ,   5963    ,   5729    ,0 };
            const std::uint32_t dim3160KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   9   ,   25  ,   1   ,   155 ,   275 ,   675 ,   831 ,   109 ,   5349    ,   9607    ,   22431   ,0 };
            const std::uint32_t dim3161KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   11  ,   33  ,   43  ,   63  ,   293 ,   425 ,   1525    ,   4091    ,   1865    ,   13187   ,   25191   ,0 };
            const std::uint32_t dim3162KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   27  ,   25  ,   89  ,   39  ,   11  ,   961 ,   1601    ,   785 ,   3317    ,   13121   ,   13647   ,0 };
            const std::uint32_t dim3163KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   31  ,   59  ,   25  ,   75  ,   317 ,   305 ,   1585    ,   3649    ,   7099    ,   1819    ,   10977   ,0 };
            const std::uint32_t dim3164KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   7   ,   29  ,   85  ,   189 ,   137 ,   783 ,   395 ,   1887    ,   6253    ,   4043    ,   32279   ,0 };
            const std::uint32_t dim3165KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   15  ,   47  ,   53  ,   125 ,   325 ,   579 ,   1783    ,   3393    ,   485 ,   13923   ,   4947    ,0 };
            const std::uint32_t dim3166KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   19  ,   53  ,   67  ,   47  ,   503 ,   875 ,   1717    ,   857 ,   5151    ,   12279   ,   21249   ,0 };
            const std::uint32_t dim3167KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   1   ,   53  ,   49  ,   211 ,   139 ,   955 ,   1129    ,   1967    ,   6833    ,   2923    ,   13251   ,0 };
            const std::uint32_t dim3168KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   15  ,   53  ,   103 ,   71  ,   51  ,   379 ,   1565    ,   2017    ,   6013    ,   13147   ,   1227    ,0 };
            const std::uint32_t dim3169KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   17  ,   25  ,   105 ,   177 ,   275 ,   969 ,   1373    ,   2471    ,   6959    ,   11107   ,   23657   ,0 };
            const std::uint32_t dim3170KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   15  ,   3   ,   19  ,   145 ,   309 ,   1021    ,   985 ,   2385    ,   5727    ,   10357   ,   4915    ,0 };
            const std::uint32_t dim3171KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   27  ,   33  ,   63  ,   115 ,   369 ,   613 ,   277 ,   751 ,   1959    ,   5709    ,   1851    ,0 };
            const std::uint32_t dim3172KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   11  ,   31  ,   95  ,   131 ,   383 ,   821 ,   725 ,   1381    ,   3953    ,   14945   ,   29101   ,0 };
            const std::uint32_t dim3173KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   1   ,   59  ,   81  ,   89  ,   325 ,   27  ,   1865    ,   987 ,   3877    ,   12509   ,   4129    ,0 };
            const std::uint32_t dim3174KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   3   ,   33  ,   63  ,   141 ,   429 ,   847 ,   1355    ,   1451    ,   4741    ,   5427    ,   16907   ,0 };
            const std::uint32_t dim3175KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   25  ,   45  ,   27  ,   249 ,   453 ,   673 ,   1519    ,   905 ,   5235    ,   10057   ,   24965   ,0 };
            const std::uint32_t dim3176KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   27  ,   43  ,   91  ,   61  ,   121 ,   485 ,   1047    ,   405 ,   8159    ,   8363    ,   19695   ,0 };
            const std::uint32_t dim3177KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   17  ,   5   ,   107 ,   139 ,   293 ,   685 ,   521 ,   253 ,   3309    ,   15335   ,   4967    ,0 };
            const std::uint32_t dim3178KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   7   ,   43  ,   63  ,   119 ,   225 ,   269 ,   1489    ,   2983    ,   1041    ,   15149   ,   21039   ,0 };
            const std::uint32_t dim3179KuoInit[]        =   {   1   ,   3   ,   1   ,   5   ,   5   ,   1   ,   123 ,   255 ,   469 ,   139 ,   1861    ,   385 ,   3123    ,   14739   ,   23049   ,0 };
            const std::uint32_t dim3180KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   25  ,   47  ,   107 ,   55  ,   435 ,   935 ,   1751    ,   555 ,   973 ,   10123   ,   31869   ,0 };
            const std::uint32_t dim3181KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   21  ,   25  ,   113 ,   169 ,   313 ,   607 ,   631 ,   3409    ,   6539    ,   5781    ,   12681   ,0 };
            const std::uint32_t dim3182KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   7   ,   13  ,   1   ,   245 ,   57  ,   495 ,   905 ,   1627    ,   7107    ,   13939   ,   22091   ,0 };
            const std::uint32_t dim3183KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   7   ,   55  ,   121 ,   137 ,   93  ,   265 ,   1263    ,   2251    ,   7101    ,   3095    ,   13779   ,0 };
            const std::uint32_t dim3184KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   21  ,   11  ,   37  ,   193 ,   481 ,   551 ,   1659    ,   563 ,   4405    ,   9541    ,   8495    ,0 };
            const std::uint32_t dim3185KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   5   ,   7   ,   23  ,   19  ,   147 ,   779 ,   1089    ,   723 ,   3837    ,   16291   ,   23911   ,0 };
            const std::uint32_t dim3186KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   27  ,   17  ,   57  ,   191 ,   337 ,   361 ,   1261    ,   3605    ,   8051    ,   8909    ,   14951   ,0 };
            const std::uint32_t dim3187KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   25  ,   23  ,   39  ,   109 ,   107 ,   605 ,   373 ,   649 ,   5747    ,   2037    ,   24933   ,0 };
            const std::uint32_t dim3188KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   9   ,   27  ,   91  ,   53  ,   153 ,   497 ,   941 ,   2999    ,   3721    ,   11115   ,   17589   ,0 };
            const std::uint32_t dim3189KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   31  ,   7   ,   101 ,   115 ,   419 ,   479 ,   1097    ,   2253    ,   4365    ,   14285   ,   26469   ,0 };
            const std::uint32_t dim3190KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   13  ,   37  ,   31  ,   231 ,   195 ,   539 ,   941 ,   3723    ,   2483    ,   2603    ,   18897   ,0 };
            const std::uint32_t dim3191KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   7   ,   31  ,   19  ,   99  ,   197 ,   833 ,   79  ,   3899    ,   7045    ,   6913    ,   17959   ,0 };
            const std::uint32_t dim3192KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   1   ,   51  ,   83  ,   135 ,   307 ,   121 ,   187 ,   2135    ,   2927    ,   6183    ,   20327   ,0 };
            const std::uint32_t dim3193KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   7   ,   31  ,   47  ,   123 ,   409 ,   239 ,   1787    ,   3063    ,   6685    ,   7487    ,   31243   ,0 };
            const std::uint32_t dim3194KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   9   ,   31  ,   57  ,   5   ,   493 ,   771 ,   1941    ,   199 ,   6389    ,   681 ,   19379   ,0 };
            const std::uint32_t dim3195KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   1   ,   57  ,   63  ,   35  ,   369 ,   267 ,   923 ,   2019    ,   6487    ,   15555   ,   6993    ,0 };
            const std::uint32_t dim3196KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   15  ,   59  ,   123 ,   179 ,   5   ,   35  ,   1061    ,   125 ,   1025    ,   5907    ,   29671   ,0 };
            const std::uint32_t dim3197KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   21  ,   63  ,   71  ,   237 ,   333 ,   893 ,   1139    ,   1969    ,   2007    ,   10017   ,   27597   ,0 };
            const std::uint32_t dim3198KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   15  ,   29  ,   103 ,   241 ,   25  ,   135 ,   1147    ,   1263    ,   4793    ,   16109   ,   22447   ,0 };
            const std::uint32_t dim3199KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   11  ,   21  ,   85  ,   7   ,   123 ,   69  ,   1379    ,   3243    ,   7907    ,   15859   ,   19993   ,0 };
            const std::uint32_t dim3200KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   17  ,   49  ,   125 ,   211 ,   165 ,   307 ,   1331    ,   2287    ,   1127    ,   4031    ,   13719   ,0 };
            const std::uint32_t dim3201KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   23  ,   23  ,   21  ,   159 ,   387 ,   443 ,   291 ,   2843    ,   4413    ,   9035    ,   28887   ,0 };
            const std::uint32_t dim3202KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   9   ,   25  ,   113 ,   185 ,   285 ,   211 ,   317 ,   3721    ,   6921    ,   4921    ,   2353    ,0 };
            const std::uint32_t dim3203KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   21  ,   9   ,   53  ,   21  ,   337 ,   51  ,   429 ,   4035    ,   4697    ,   3695    ,   22589   ,0 };
            const std::uint32_t dim3204KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   21  ,   63  ,   79  ,   213 ,   471 ,   183 ,   299 ,   409 ,   6125    ,   3653    ,   9785    ,0 };
            const std::uint32_t dim3205KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   27  ,   27  ,   9   ,   73  ,   129 ,   391 ,   1877    ,   4023    ,   1631    ,   7101    ,   1491    ,0 };
            const std::uint32_t dim3206KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   21  ,   7   ,   93  ,   51  ,   469 ,   3   ,   1343    ,   3827    ,   6623    ,   10149   ,   29233   ,0 };
            const std::uint32_t dim3207KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   31  ,   25  ,   35  ,   249 ,   469 ,   393 ,   1315    ,   1247    ,   275 ,   15841   ,   23877   ,0 };
            const std::uint32_t dim3208KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   25  ,   47  ,   105 ,   45  ,   79  ,   131 ,   499 ,   1411    ,   2077    ,   9809    ,   14917   ,0 };
            const std::uint32_t dim3209KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   13  ,   15  ,   117 ,   27  ,   499 ,   885 ,   301 ,   935 ,   3443    ,   3845    ,   26873   ,0 };
            const std::uint32_t dim3210KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   1   ,   47  ,   21  ,   97  ,   245 ,   95  ,   899 ,   993 ,   2493    ,   5249    ,   32695   ,0 };
            const std::uint32_t dim3211KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   21  ,   39  ,   53  ,   15  ,   53  ,   687 ,   1269    ,   1673    ,   2015    ,   3205    ,   21447   ,0 };
            const std::uint32_t dim3212KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   1   ,   39  ,   117 ,   85  ,   277 ,   635 ,   1459    ,   3977    ,   2449    ,   13341   ,   30607   ,0 };
            const std::uint32_t dim3213KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   27  ,   45  ,   7   ,   255 ,   281 ,   807 ,   533 ,   2173    ,   4561    ,   2501    ,   5767    ,0 };
            const std::uint32_t dim3214KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   21  ,   17  ,   65  ,   123 ,   239 ,   431 ,   1003    ,   241 ,   8115    ,   11633   ,   27709   ,0 };
            const std::uint32_t dim3215KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   23  ,   39  ,   81  ,   35  ,   33  ,   905 ,   2019    ,   3327    ,   1197    ,   6891    ,   5521    ,0 };
            const std::uint32_t dim3216KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   1   ,   51  ,   51  ,   153 ,   23  ,   685 ,   1663    ,   3167    ,   5803    ,   11111   ,   3371    ,0 };
            const std::uint32_t dim3217KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   31  ,   29  ,   7   ,   173 ,   27  ,   129 ,   341 ,   2971    ,   4907    ,   13481   ,   19619   ,0 };
            const std::uint32_t dim3218KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   29  ,   29  ,   115 ,   3   ,   45  ,   765 ,   385 ,   3775    ,   5349    ,   8809    ,   11019   ,0 };
            const std::uint32_t dim3219KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   15  ,   19  ,   21  ,   29  ,   377 ,   915 ,   1835    ,   517 ,   3763    ,   5439    ,   7649    ,0 };
            const std::uint32_t dim3220KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   25  ,   27  ,   33  ,   225 ,   135 ,   869 ,   1383    ,   3817    ,   2981    ,   8185    ,   5689    ,0 };
            const std::uint32_t dim3221KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   1   ,   27  ,   19  ,   55  ,   39  ,   451 ,   365 ,   2905    ,   4311    ,   16005   ,   4537    ,0 };
            const std::uint32_t dim3222KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   19  ,   1   ,   99  ,   177 ,   163 ,   877 ,   511 ,   1977    ,   3291    ,   7739    ,   6383    ,0 };
            const std::uint32_t dim3223KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   1   ,   29  ,   27  ,   1   ,   411 ,   425 ,   2027    ,   1739    ,   5137    ,   107 ,   3515    ,0 };
            const std::uint32_t dim3224KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   5   ,   29  ,   15  ,   55  ,   423 ,   671 ,   1145    ,   2403    ,   5429    ,   11507   ,   24747   ,0 };
            const std::uint32_t dim3225KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   9   ,   61  ,   93  ,   215 ,   447 ,   969 ,   853 ,   487 ,   5735    ,   2153    ,   27857   ,0 };
            const std::uint32_t dim3226KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   29  ,   41  ,   47  ,   245 ,   197 ,   261 ,   77  ,   805 ,   965 ,   14089   ,   29199   ,0 };
            const std::uint32_t dim3227KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   3   ,   49  ,   53  ,   7   ,   91  ,   123 ,   413 ,   123 ,   7611    ,   11493   ,   16417   ,0 };
            const std::uint32_t dim3228KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   23  ,   59  ,   105 ,   191 ,   13  ,   421 ,   1541    ,   2045    ,   2821    ,   9769    ,   19893   ,0 };
            const std::uint32_t dim3229KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   3   ,   19  ,   37  ,   229 ,   465 ,   1015    ,   1871    ,   1101    ,   7515    ,   8547    ,   7853    ,0 };
            const std::uint32_t dim3230KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   9   ,   61  ,   113 ,   209 ,   503 ,   441 ,   905 ,   2693    ,   1827    ,   9551    ,   26081   ,0 };
            const std::uint32_t dim3231KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   31  ,   27  ,   123 ,   37  ,   415 ,   729 ,   921 ,   453 ,   673 ,   14393   ,   9139    ,0 };
            const std::uint32_t dim3232KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   13  ,   9   ,   79  ,   243 ,   211 ,   89  ,   295 ,   3663    ,   8165    ,   12099   ,   1413    ,0 };
            const std::uint32_t dim3233KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   23  ,   33  ,   33  ,   129 ,   51  ,   965 ,   1145    ,   713 ,   8143    ,   10045   ,   5291    ,0 };
            const std::uint32_t dim3234KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   11  ,   45  ,   77  ,   223 ,   423 ,   1021    ,   343 ,   3103    ,   119 ,   3371    ,   24053   ,0 };
            const std::uint32_t dim3235KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   7   ,   3   ,   65  ,   31  ,   433 ,   277 ,   1541    ,   2001    ,   121 ,   13543   ,   6723    ,0 };
            const std::uint32_t dim3236KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   1   ,   15  ,   83  ,   85  ,   351 ,   351 ,   1063    ,   3989    ,   5739    ,   11939   ,   28009   ,0 };
            const std::uint32_t dim3237KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   25  ,   57  ,   73  ,   127 ,   25  ,   67  ,   1789    ,   199 ,   6373    ,   10945   ,   17839   ,0 };
            const std::uint32_t dim3238KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   17  ,   15  ,   5   ,   191 ,   209 ,   455 ,   89  ,   2611    ,   7557    ,   16167   ,   25993   ,0 };
            const std::uint32_t dim3239KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   29  ,   21  ,   79  ,   81  ,   257 ,   373 ,   557 ,   2363    ,   5497    ,   8343    ,   2011    ,0 };
            const std::uint32_t dim3240KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   25  ,   63  ,   83  ,   31  ,   477 ,   201 ,   2013    ,   3349    ,   3517    ,   9527    ,   14883   ,0 };
            const std::uint32_t dim3241KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   21  ,   13  ,   41  ,   151 ,   359 ,   829 ,   661 ,   1959    ,   6109    ,   13757   ,   17677   ,0 };
            const std::uint32_t dim3242KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   11  ,   15  ,   119 ,   25  ,   351 ,   135 ,   515 ,   3727    ,   5701    ,   5283    ,   18771   ,0 };
            const std::uint32_t dim3243KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   3   ,   59  ,   55  ,   117 ,   269 ,   161 ,   645 ,   3459    ,   8173    ,   7193    ,   10275   ,0 };
            const std::uint32_t dim3244KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   21  ,   25  ,   53  ,   211 ,   237 ,   775 ,   43  ,   3613    ,   5555    ,   1689    ,   1781    ,0 };
            const std::uint32_t dim3245KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   31  ,   43  ,   71  ,   201 ,   371 ,   457 ,   1757    ,   2529    ,   7067    ,   2987    ,   3945    ,0 };
            const std::uint32_t dim3246KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   15  ,   47  ,   29  ,   83  ,   259 ,   813 ,   881 ,   1901    ,   6635    ,   8515    ,   20385   ,0 };
            const std::uint32_t dim3247KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   3   ,   45  ,   55  ,   43  ,   17  ,   179 ,   1801    ,   49  ,   8121    ,   9333    ,   12701   ,0 };
            const std::uint32_t dim3248KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   21  ,   9   ,   55  ,   59  ,   275 ,   775 ,   1567    ,   1557    ,   3465    ,   5727    ,   12881   ,0 };
            const std::uint32_t dim3249KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   21  ,   63  ,   81  ,   27  ,   139 ,   859 ,   1211    ,   3787    ,   1179    ,   4045    ,   26225   ,0 };
            const std::uint32_t dim3250KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   7   ,   5   ,   99  ,   125 ,   499 ,   437 ,   1141    ,   3557    ,   5349    ,   2701    ,   25741   ,0 };
            const std::uint32_t dim3251KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   7   ,   59  ,   65  ,   117 ,   201 ,   351 ,   1063    ,   3083    ,   6637    ,   5969    ,   23037   ,0 };
            const std::uint32_t dim3252KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   25  ,   45  ,   115 ,   31  ,   351 ,   203 ,   1791    ,   2931    ,   7127    ,   12117   ,   10781   ,0 };
            const std::uint32_t dim3253KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   29  ,   59  ,   85  ,   101 ,   147 ,   219 ,   1293    ,   1645    ,   7653    ,   649 ,   32221   ,0 };
            const std::uint32_t dim3254KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   29  ,   51  ,   127 ,   139 ,   205 ,   77  ,   859 ,   2277    ,   2333    ,   105 ,   9053    ,0 };
            const std::uint32_t dim3255KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   29  ,   23  ,   119 ,   71  ,   263 ,   551 ,   1095    ,   359 ,   6223    ,   7665    ,   1095    ,0 };
            const std::uint32_t dim3256KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   13  ,   47  ,   11  ,   207 ,   507 ,   139 ,   1383    ,   1339    ,   4111    ,   11685   ,   12607   ,0 };
            const std::uint32_t dim3257KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   25  ,   9   ,   87  ,   117 ,   21  ,   289 ,   351 ,   225 ,   4045    ,   5275    ,   531 ,0 };
            const std::uint32_t dim3258KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   29  ,   55  ,   31  ,   57  ,   83  ,   423 ,   201 ,   4055    ,   1977    ,   8891    ,   17961   ,0 };
            const std::uint32_t dim3259KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   9   ,   7   ,   45  ,   237 ,   413 ,   53  ,   1063    ,   23  ,   6615    ,   16359   ,   4743    ,0 };
            const std::uint32_t dim3260KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   21  ,   57  ,   63  ,   221 ,   111 ,   95  ,   647 ,   3419    ,   1919    ,   923 ,   8357    ,0 };
            const std::uint32_t dim3261KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   27  ,   25  ,   119 ,   237 ,   397 ,   73  ,   41  ,   17  ,   6839    ,   15695   ,   30365   ,0 };
            const std::uint32_t dim3262KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   23  ,   59  ,   107 ,   121 ,   267 ,   163 ,   181 ,   2289    ,   167 ,   7077    ,   12895   ,0 };
            const std::uint32_t dim3263KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   15  ,   45  ,   45  ,   179 ,   195 ,   95  ,   43  ,   377 ,   629 ,   11983   ,   23439   ,0 };
            const std::uint32_t dim3264KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   17  ,   43  ,   67  ,   143 ,   223 ,   243 ,   209 ,   3   ,   7651    ,   12607   ,   3927    ,0 };
            const std::uint32_t dim3265KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   19  ,   21  ,   59  ,   75  ,   353 ,   509 ,   1215    ,   3223    ,   2373    ,   3873    ,   20391   ,0 };
            const std::uint32_t dim3266KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   7   ,   9   ,   53  ,   89  ,   407 ,   987 ,   1165    ,   2473    ,   4295    ,   2531    ,   5615    ,0 };
            const std::uint32_t dim3267KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   23  ,   7   ,   111 ,   147 ,   49  ,   627 ,   1769    ,   3497    ,   2807    ,   4743    ,   26491   ,0 };
            const std::uint32_t dim3268KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   29  ,   29  ,   83  ,   57  ,   377 ,   581 ,   1699    ,   1689    ,   2297    ,   1377    ,   24551   ,0 };
            const std::uint32_t dim3269KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   25  ,   33  ,   41  ,   187 ,   195 ,   647 ,   73  ,   619 ,   5585    ,   8379    ,   26079   ,0 };
            const std::uint32_t dim3270KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   3   ,   47  ,   105 ,   83  ,   501 ,   843 ,   1867    ,   1855    ,   6347    ,   3269    ,   26155   ,0 };
            const std::uint32_t dim3271KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   29  ,   33  ,   117 ,   141 ,   171 ,   801 ,   1489    ,   1   ,   4081    ,   15529   ,   4081    ,0 };
            const std::uint32_t dim3272KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   21  ,   43  ,   13  ,   75  ,   75  ,   443 ,   1443    ,   3227    ,   907 ,   11821   ,   24209   ,0 };
            const std::uint32_t dim3273KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   31  ,   31  ,   111 ,   193 ,   275 ,   545 ,   371 ,   3071    ,   3491    ,   6661    ,   1113    ,0 };
            const std::uint32_t dim3274KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   11  ,   39  ,   17  ,   107 ,   303 ,   201 ,   321 ,   3083    ,   6839    ,   4381    ,   3449    ,0 };
            const std::uint32_t dim3275KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   31  ,   21  ,   7   ,   143 ,   211 ,   369 ,   369 ,   323 ,   3811    ,   5131    ,   11425   ,0 };
            const std::uint32_t dim3276KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   9   ,   27  ,   23  ,   21  ,   349 ,   607 ,   529 ,   1161    ,   5753    ,   6015    ,   20489   ,0 };
            const std::uint32_t dim3277KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   23  ,   17  ,   103 ,   97  ,   227 ,   933 ,   2011    ,   1705    ,   5185    ,   299 ,   5673    ,0 };
            const std::uint32_t dim3278KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   7   ,   45  ,   63  ,   43  ,   339 ,   299 ,   1617    ,   1393    ,   4507    ,   13513   ,   29039   ,0 };
            const std::uint32_t dim3279KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   17  ,   11  ,   49  ,   159 ,   51  ,   449 ,   497 ,   2627    ,   1541    ,   15711   ,   16591   ,0 };
            const std::uint32_t dim3280KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   23  ,   19  ,   53  ,   79  ,   133 ,   279 ,   327 ,   2847    ,   5825    ,   14429   ,   26491   ,0 };
            const std::uint32_t dim3281KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   17  ,   3   ,   33  ,   55  ,   263 ,   663 ,   1253    ,   1509    ,   4487    ,   1811    ,   32123   ,0 };
            const std::uint32_t dim3282KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   17  ,   7   ,   23  ,   87  ,   221 ,   183 ,   1577    ,   1373    ,   2717    ,   3323    ,   24573   ,0 };
            const std::uint32_t dim3283KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   5   ,   51  ,   45  ,   11  ,   11  ,   135 ,   505 ,   221 ,   3847    ,   13487   ,   23843   ,0 };
            const std::uint32_t dim3284KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   15  ,   61  ,   85  ,   53  ,   321 ,   433 ,   61  ,   3377    ,   3993    ,   15325   ,   8641    ,0 };
            const std::uint32_t dim3285KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   27  ,   35  ,   57  ,   43  ,   509 ,   595 ,   2033    ,   77  ,   7533    ,   5027    ,   15567   ,0 };
            const std::uint32_t dim3286KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   31  ,   51  ,   69  ,   157 ,   105 ,   797 ,   249 ,   2033    ,   2457    ,   10773   ,   31537   ,0 };
            const std::uint32_t dim3287KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   23  ,   25  ,   75  ,   11  ,   145 ,   361 ,   819 ,   3689    ,   5751    ,   6395    ,   30685   ,0 };
            const std::uint32_t dim3288KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   13  ,   25  ,   13  ,   175 ,   11  ,   685 ,   835 ,   2641    ,   2037    ,   2037    ,   2807    ,0 };
            const std::uint32_t dim3289KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   21  ,   27  ,   115 ,   91  ,   21  ,   105 ,   1817    ,   2057    ,   2797    ,   3825    ,   23761   ,0 };
            const std::uint32_t dim3290KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   5   ,   49  ,   51  ,   57  ,   425 ,   959 ,   473 ,   575 ,   6851    ,   3683    ,   27429   ,0 };
            const std::uint32_t dim3291KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   29  ,   1   ,   65  ,   13  ,   447 ,   467 ,   1193    ,   4021    ,   275 ,   13453   ,   29749   ,0 };
            const std::uint32_t dim3292KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   27  ,   53  ,   71  ,   63  ,   125 ,   545 ,   1673    ,   3917    ,   6625    ,   12805   ,   2905    ,0 };
            const std::uint32_t dim3293KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   7   ,   1   ,   45  ,   65  ,   23  ,   237 ,   1573    ,   3445    ,   6307    ,   5015    ,   11263   ,0 };
            const std::uint32_t dim3294KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   7   ,   29  ,   67  ,   35  ,   307 ,   675 ,   727 ,   2789    ,   2353    ,   13241   ,   16621   ,0 };
            const std::uint32_t dim3295KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   13  ,   5   ,   115 ,   75  ,   21  ,   745 ,   2027    ,   265 ,   3583    ,   1365    ,   397 ,0 };
            const std::uint32_t dim3296KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   9   ,   31  ,   115 ,   25  ,   441 ,   433 ,   1665    ,   2499    ,   5765    ,   4001    ,   22105   ,0 };
            const std::uint32_t dim3297KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   23  ,   21  ,   71  ,   165 ,   353 ,   101 ,   1335    ,   3411    ,   1415    ,   12641   ,   21961   ,0 };
            const std::uint32_t dim3298KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   3   ,   3   ,   21  ,   157 ,   85  ,   117 ,   469 ,   1573    ,   2475    ,   6471    ,   15975   ,0 };
            const std::uint32_t dim3299KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   31  ,   35  ,   127 ,   221 ,   447 ,   697 ,   1393    ,   701 ,   7291    ,   4279    ,   2897    ,0 };
            const std::uint32_t dim3300KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   21  ,   13  ,   15  ,   15  ,   395 ,   519 ,   1985    ,   2331    ,   5483    ,   13905   ,   31549   ,0 };
            const std::uint32_t dim3301KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   1   ,   43  ,   57  ,   131 ,   7   ,   893 ,   1631    ,   1581    ,   6691    ,   6249    ,   4975    ,0 };
            const std::uint32_t dim3302KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   29  ,   33  ,   51  ,   177 ,   423 ,   459 ,   1293    ,   2467    ,   3877    ,   15653   ,   2727    ,0 };
            const std::uint32_t dim3303KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   5   ,   45  ,   11  ,   27  ,   311 ,   645 ,   283 ,   65  ,   5913    ,   12811   ,   20041   ,0 };
            const std::uint32_t dim3304KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   19  ,   3   ,   39  ,   99  ,   269 ,   429 ,   1901    ,   2213    ,   6755    ,   1205    ,   16073   ,0 };
            const std::uint32_t dim3305KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   7   ,   37  ,   109 ,   113 ,   395 ,   981 ,   1991    ,   845 ,   2473    ,   3801    ,   24405   ,0 };
            const std::uint32_t dim3306KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   9   ,   31  ,   117 ,   213 ,   141 ,   867 ,   387 ,   1985    ,   1985    ,   12683   ,   20501   ,0 };
            const std::uint32_t dim3307KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   11  ,   3   ,   25  ,   31  ,   375 ,   437 ,   645 ,   335 ,   207 ,   14915   ,   2577    ,0 };
            const std::uint32_t dim3308KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   19  ,   61  ,   87  ,   107 ,   53  ,   777 ,   31  ,   3335    ,   157 ,   2927    ,   25905   ,0 };
            const std::uint32_t dim3309KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   13  ,   13  ,   21  ,   151 ,   51  ,   501 ,   213 ,   2177    ,   2821    ,   3081    ,   5955    ,0 };
            const std::uint32_t dim3310KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   19  ,   33  ,   5   ,   209 ,   283 ,   613 ,   281 ,   715 ,   297 ,   15033   ,   20489   ,0 };
            const std::uint32_t dim3311KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   31  ,   7   ,   31  ,   49  ,   5   ,   41  ,   939 ,   2359    ,   3663    ,   10151   ,   20457   ,0 };
            const std::uint32_t dim3312KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   7   ,   61  ,   69  ,   255 ,   17  ,   637 ,   863 ,   3351    ,   6033    ,   5005    ,   23107   ,0 };
            const std::uint32_t dim3313KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   5   ,   61  ,   15  ,   87  ,   111 ,   383 ,   1577    ,   3515    ,   789 ,   4219    ,   2527    ,0 };
            const std::uint32_t dim3314KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   19  ,   9   ,   37  ,   61  ,   329 ,   811 ,   1829    ,   3109    ,   397 ,   2065    ,   32001   ,0 };
            const std::uint32_t dim3315KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   7   ,   13  ,   55  ,   7   ,   463 ,   307 ,   1551    ,   3161    ,   649 ,   14073   ,   20839   ,0 };
            const std::uint32_t dim3316KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   1   ,   43  ,   71  ,   87  ,   149 ,   557 ,   857 ,   2739    ,   6269    ,   3297    ,   26067   ,0 };
            const std::uint32_t dim3317KuoInit[]        =   {   1   ,   3   ,   1   ,   5   ,   5   ,   29  ,   45  ,   159 ,   125 ,   389 ,   627 ,   983 ,   755 ,   15585   ,   12555   ,0 };
            const std::uint32_t dim3318KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   9   ,   53  ,   79  ,   29  ,   423 ,   423 ,   1493    ,   61  ,   1631    ,   5157    ,   29845   ,0 };
            const std::uint32_t dim3319KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   23  ,   27  ,   57  ,   235 ,   57  ,   833 ,   371 ,   1797    ,   4541    ,   12491   ,   23127   ,0 };
            const std::uint32_t dim3320KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   17  ,   1   ,   79  ,   87  ,   247 ,   987 ,   651 ,   3167    ,   4423    ,   831 ,   16811   ,0 };
            const std::uint32_t dim3321KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   15  ,   23  ,   51  ,   167 ,   421 ,   493 ,   1877    ,   1079    ,   4147    ,   13485   ,   28619   ,0 };
            const std::uint32_t dim3322KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   19  ,   15  ,   69  ,   31  ,   225 ,   597 ,   1477    ,   2363    ,   6969    ,   13221   ,   2561    ,0 };
            const std::uint32_t dim3323KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   19  ,   61  ,   75  ,   199 ,   103 ,   823 ,   375 ,   1301    ,   4349    ,   135 ,   5701    ,0 };
            const std::uint32_t dim3324KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   21  ,   25  ,   85  ,   249 ,   91  ,   885 ,   469 ,   1809    ,   4351    ,   14393   ,   19607   ,0 };
            const std::uint32_t dim3325KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   25  ,   19  ,   71  ,   111 ,   427 ,   523 ,   1691    ,   4085    ,   7587    ,   1949    ,   10471   ,0 };
            const std::uint32_t dim3326KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   27  ,   59  ,   13  ,   117 ,   155 ,   369 ,   1767    ,   2951    ,   6109    ,   13867   ,   13887   ,0 };
            const std::uint32_t dim3327KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   31  ,   53  ,   35  ,   101 ,   295 ,   653 ,   337 ,   2281    ,   7563    ,   8847    ,   15235   ,0 };
            const std::uint32_t dim3328KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   3   ,   17  ,   63  ,   251 ,   293 ,   861 ,   1539    ,   2409    ,   663 ,   1637    ,   22309   ,0 };
            const std::uint32_t dim3329KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   13  ,   27  ,   41  ,   81  ,   483 ,   901 ,   1963    ,   1855    ,   799 ,   10933   ,   14395   ,0 };
            const std::uint32_t dim3330KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   19  ,   23  ,   97  ,   179 ,   93  ,   657 ,   1361    ,   4019    ,   7577    ,   355 ,   4881    ,0 };
            const std::uint32_t dim3331KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   23  ,   25  ,   101 ,   141 ,   91  ,   37  ,   1165    ,   3509    ,   2445    ,   7675    ,   30803   ,0 };
            const std::uint32_t dim3332KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   13  ,   53  ,   87  ,   197 ,   321 ,   297 ,   277 ,   2159    ,   5457    ,   6463    ,   1797    ,0 };
            const std::uint32_t dim3333KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   3   ,   3   ,   117 ,   5   ,   95  ,   527 ,   755 ,   2865    ,   6359    ,   4859    ,   11395   ,0 };
            const std::uint32_t dim3334KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   1   ,   49  ,   43  ,   247 ,   369 ,   351 ,   1277    ,   1639    ,   3133    ,   4193    ,   26645   ,0 };
            const std::uint32_t dim3335KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   27  ,   21  ,   59  ,   191 ,   365 ,   95  ,   337 ,   3279    ,   4455    ,   8235    ,   12457   ,0 };
            const std::uint32_t dim3336KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   9   ,   1   ,   7   ,   23  ,   117 ,   711 ,   1027    ,   613 ,   4729    ,   14415   ,   15705   ,0 };
            const std::uint32_t dim3337KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   29  ,   13  ,   43  ,   3   ,   117 ,   763 ,   1787    ,   2109    ,   4949    ,   7579    ,   24083   ,0 };
            const std::uint32_t dim3338KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   7   ,   61  ,   107 ,   113 ,   127 ,   495 ,   1167    ,   2871    ,   7187    ,   13235   ,   2037    ,0 };
            const std::uint32_t dim3339KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   13  ,   33  ,   23  ,   69  ,   5   ,   137 ,   157 ,   1107    ,   1025    ,   1907    ,   2279    ,0 };
            const std::uint32_t dim3340KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   11  ,   63  ,   27  ,   13  ,   295 ,   951 ,   2027    ,   3625    ,   1447    ,   8939    ,   3965    ,0 };
            const std::uint32_t dim3341KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   29  ,   31  ,   67  ,   221 ,   413 ,   13  ,   1643    ,   2847    ,   4889    ,   3733    ,   25713   ,0 };
            const std::uint32_t dim3342KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   11  ,   17  ,   37  ,   37  ,   159 ,   835 ,   1775    ,   2059    ,   2995    ,   6141    ,   12277   ,0 };
            const std::uint32_t dim3343KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   11  ,   25  ,   107 ,   239 ,   361 ,   835 ,   1943    ,   1375    ,   7077    ,   13843   ,   5685    ,0 };
            const std::uint32_t dim3344KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   23  ,   27  ,   3   ,   191 ,   339 ,   675 ,   1181    ,   2005    ,   245 ,   7305    ,   5831    ,0 };
            const std::uint32_t dim3345KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   15  ,   17  ,   91  ,   15  ,   255 ,   201 ,   535 ,   3063    ,   4351    ,   12527   ,   15981   ,0 };
            const std::uint32_t dim3346KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   7   ,   47  ,   111 ,   245 ,   223 ,   781 ,   367 ,   559 ,   1433    ,   9631    ,   7207    ,0 };
            const std::uint32_t dim3347KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   23  ,   5   ,   111 ,   237 ,   371 ,   541 ,   663 ,   693 ,   6591    ,   13089   ,   11381   ,0 };
            const std::uint32_t dim3348KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   25  ,   5   ,   99  ,   17  ,   401 ,   787 ,   971 ,   1035    ,   1143    ,   12041   ,   22455   ,0 };
            const std::uint32_t dim3349KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   3   ,   5   ,   125 ,   193 ,   69  ,   939 ,   37  ,   2843    ,   3139    ,   7967    ,   15099   ,0 };
            const std::uint32_t dim3350KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   11  ,   39  ,   35  ,   103 ,   203 ,   255 ,   727 ,   2513    ,   1981    ,   12855   ,   20887   ,0 };
            const std::uint32_t dim3351KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   27  ,   41  ,   41  ,   57  ,   275 ,   497 ,   727 ,   901 ,   5653    ,   12917   ,   20783   ,0 };
            const std::uint32_t dim3352KuoInit[]        =   {   1   ,   3   ,   1   ,   5   ,   17  ,   13  ,   101 ,   95  ,   465 ,   155 ,   973 ,   1911    ,   2719    ,   157 ,   19475   ,0 };
            const std::uint32_t dim3353KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   3   ,   61  ,   31  ,   225 ,   351 ,   931 ,   855 ,   3871    ,   1835    ,   11133   ,   25203   ,0 };
            const std::uint32_t dim3354KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   25  ,   1   ,   91  ,   193 ,   455 ,   873 ,   1255    ,   1657    ,   4143    ,   433 ,   22789   ,0 };
            const std::uint32_t dim3355KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   31  ,   19  ,   35  ,   81  ,   175 ,   885 ,   1007    ,   3443    ,   2063    ,   3179    ,   28563   ,0 };
            const std::uint32_t dim3356KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   1   ,   25  ,   109 ,   249 ,   341 ,   393 ,   497 ,   1181    ,   2943    ,   9021    ,   9985    ,0 };
            const std::uint32_t dim3357KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   15  ,   49  ,   27  ,   145 ,   351 ,   119 ,   257 ,   151 ,   4287    ,   1709    ,   2585    ,0 };
            const std::uint32_t dim3358KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   3   ,   19  ,   105 ,   51  ,   443 ,   693 ,   29  ,   2657    ,   6967    ,   4797    ,   14565   ,0 };
            const std::uint32_t dim3359KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   25  ,   53  ,   65  ,   169 ,   461 ,   275 ,   1191    ,   731 ,   6295    ,   15083   ,   28445   ,0 };
            const std::uint32_t dim3360KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   11  ,   39  ,   21  ,   3   ,   411 ,   45  ,   1325    ,   3279    ,   3153    ,   289 ,   30973   ,0 };
            const std::uint32_t dim3361KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   29  ,   57  ,   107 ,   245 ,   279 ,   677 ,   599 ,   1145    ,   5135    ,   6131    ,   12667   ,0 };
            const std::uint32_t dim3362KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   27  ,   7   ,   99  ,   215 ,   17  ,   171 ,   977 ,   2065    ,   1357    ,   8705    ,   29641   ,0 };
            const std::uint32_t dim3363KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   31  ,   23  ,   53  ,   9   ,   177 ,   645 ,   99  ,   3175    ,   3543    ,   13637   ,   9923    ,0 };
            const std::uint32_t dim3364KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   5   ,   45  ,   69  ,   39  ,   207 ,   651 ,   1507    ,   2969    ,   2743    ,   4025    ,   9983    ,0 };
            const std::uint32_t dim3365KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   13  ,   57  ,   27  ,   215 ,   51  ,   927 ,   1973    ,   3127    ,   3655    ,   10653   ,   5649    ,0 };
            const std::uint32_t dim3366KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   21  ,   7   ,   119 ,   163 ,   461 ,   859 ,   253 ,   2817    ,   8001    ,   393 ,   20171   ,0 };
            const std::uint32_t dim3367KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   25  ,   7   ,   101 ,   109 ,   57  ,   185 ,   2005    ,   3167    ,   3539    ,   2465    ,   783 ,0 };
            const std::uint32_t dim3368KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   31  ,   43  ,   69  ,   189 ,   471 ,   669 ,   339 ,   1125    ,   4273    ,   10417   ,   20129   ,0 };
            const std::uint32_t dim3369KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   19  ,   37  ,   115 ,   111 ,   439 ,   19  ,   425 ,   995 ,   3983    ,   15523   ,   25679   ,0 };
            const std::uint32_t dim3370KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   5   ,   1   ,   37  ,   105 ,   359 ,   423 ,   545 ,   1099    ,   6809    ,   8531    ,   25155   ,0 };
            const std::uint32_t dim3371KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   9   ,   37  ,   37  ,   149 ,   457 ,   1017    ,   25  ,   3641    ,   2673    ,   1501    ,   28811   ,0 };
            const std::uint32_t dim3372KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   25  ,   31  ,   57  ,   233 ,   125 ,   755 ,   1807    ,   337 ,   81  ,   14709   ,   4061    ,0 };
            const std::uint32_t dim3373KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   25  ,   7   ,   37  ,   35  ,   437 ,   889 ,   965 ,   3997    ,   4493    ,   1357    ,   26383   ,0 };
            const std::uint32_t dim3374KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   9   ,   37  ,   105 ,   127 ,   283 ,   141 ,   1451    ,   2275    ,   3261    ,   8135    ,   429 ,0 };
            const std::uint32_t dim3375KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   3   ,   19  ,   9   ,   233 ,   293 ,   827 ,   103 ,   1963    ,   2877    ,   7701    ,   17431   ,0 };
            const std::uint32_t dim3376KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   15  ,   17  ,   87  ,   243 ,   141 ,   721 ,   829 ,   3569    ,   4081    ,   6039    ,   21523   ,0 };
            const std::uint32_t dim3377KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   17  ,   21  ,   31  ,   169 ,   425 ,   755 ,   1391    ,   3433    ,   3275    ,   15657   ,   9085    ,0 };
            const std::uint32_t dim3378KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   25  ,   23  ,   49  ,   227 ,   103 ,   5   ,   1995    ,   3803    ,   1109    ,   6015    ,   2433    ,0 };
            const std::uint32_t dim3379KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   19  ,   39  ,   91  ,   219 ,   403 ,   475 ,   1629    ,   117 ,   2317    ,   3991    ,   23467   ,0 };
            const std::uint32_t dim3380KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   19  ,   63  ,   79  ,   9   ,   19  ,   747 ,   1045    ,   875 ,   5809    ,   949 ,   10943   ,0 };
            const std::uint32_t dim3381KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   3   ,   29  ,   83  ,   103 ,   481 ,   565 ,   451 ,   1353    ,   5417    ,   2747    ,   141 ,0 };
            const std::uint32_t dim3382KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   17  ,   43  ,   75  ,   51  ,   335 ,   257 ,   1077    ,   517 ,   4029    ,   13761   ,   8653    ,0 };
            const std::uint32_t dim3383KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   13  ,   51  ,   41  ,   195 ,   331 ,   155 ,   1711    ,   2787    ,   6163    ,   12641   ,   20731   ,0 };
            const std::uint32_t dim3384KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   5   ,   37  ,   117 ,   97  ,   133 ,   793 ,   491 ,   2185    ,   3671    ,   12257   ,   6239    ,0 };
            const std::uint32_t dim3385KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   9   ,   33  ,   69  ,   153 ,   29  ,   443 ,   921 ,   3679    ,   7385    ,   7229    ,   16443   ,0 };
            const std::uint32_t dim3386KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   19  ,   19  ,   87  ,   147 ,   113 ,   577 ,   505 ,   343 ,   7385    ,   3247    ,   6411    ,0 };
            const std::uint32_t dim3387KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   15  ,   33  ,   83  ,   69  ,   27  ,   519 ,   115 ,   4059    ,   5281    ,   7995    ,   25537   ,0 };
            const std::uint32_t dim3388KuoInit[]        =   {   1   ,   1   ,   5   ,   15  ,   21  ,   25  ,   37  ,   35  ,   263 ,   531 ,   197 ,   27  ,   7871    ,   7383    ,   28467   ,0 };
            const std::uint32_t dim3389KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   1   ,   49  ,   87  ,   173 ,   37  ,   633 ,   65  ,   2449    ,   149 ,   7145    ,   6461    ,0 };
            const std::uint32_t dim3390KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   17  ,   35  ,   91  ,   45  ,   257 ,   351 ,   1569    ,   3757    ,   5203    ,   8071    ,   32211   ,0 };
            const std::uint32_t dim3391KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   9   ,   39  ,   51  ,   33  ,   77  ,   663 ,   287 ,   1127    ,   4549    ,   6321    ,   16199   ,0 };
            const std::uint32_t dim3392KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   3   ,   3   ,   123 ,   35  ,   75  ,   253 ,   1661    ,   3191    ,   1749    ,   14421   ,   15767   ,0 };
            const std::uint32_t dim3393KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   21  ,   27  ,   69  ,   233 ,   425 ,   89  ,   1069    ,   603 ,   5439    ,   5597    ,   24183   ,0 };
            const std::uint32_t dim3394KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   19  ,   57  ,   127 ,   83  ,   445 ,   619 ,   1541    ,   2695    ,   1657    ,   10787   ,   27703   ,0 };
            const std::uint32_t dim3395KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   31  ,   31  ,   29  ,   61  ,   245 ,   449 ,   145 ,   3619    ,   5267    ,   9403    ,   9637    ,0 };
            const std::uint32_t dim3396KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   29  ,   61  ,   33  ,   245 ,   341 ,   991 ,   639 ,   3391    ,   2971    ,   857 ,   26191   ,0 };
            const std::uint32_t dim3397KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   9   ,   7   ,   57  ,   33  ,   79  ,   489 ,   379 ,   3907    ,   3759    ,   4243    ,   9811    ,0 };
            const std::uint32_t dim3398KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   7   ,   61  ,   7   ,   119 ,   51  ,   927 ,   1505    ,   2997    ,   723 ,   8987    ,   29007   ,0 };
            const std::uint32_t dim3399KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   31  ,   55  ,   63  ,   15  ,   421 ,   423 ,   1041    ,   3967    ,   2471    ,   13273   ,   18587   ,0 };
            const std::uint32_t dim3400KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   9   ,   49  ,   111 ,   211 ,   87  ,   887 ,   1867    ,   19  ,   5329    ,   12411   ,   18537   ,0 };
            const std::uint32_t dim3401KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   27  ,   35  ,   89  ,   81  ,   119 ,   635 ,   63  ,   2185    ,   7001    ,   11283   ,   11883   ,0 };
            const std::uint32_t dim3402KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   31  ,   61  ,   55  ,   237 ,   327 ,   537 ,   123 ,   3589    ,   3019    ,   705 ,   16701   ,0 };
            const std::uint32_t dim3403KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   7   ,   13  ,   103 ,   101 ,   473 ,   7   ,   381 ,   3643    ,   1227    ,   11335   ,   615 ,0 };
            const std::uint32_t dim3404KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   1   ,   9   ,   127 ,   65  ,   479 ,   623 ,   469 ,   3403    ,   2423    ,   4269    ,   15195   ,0 };
            const std::uint32_t dim3405KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   3   ,   23  ,   125 ,   195 ,   267 ,   923 ,   961 ,   799 ,   783 ,   893 ,   22403   ,0 };
            const std::uint32_t dim3406KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   21  ,   7   ,   21  ,   151 ,   373 ,   377 ,   1685    ,   3731    ,   6019    ,   1059    ,   32457   ,0 };
            const std::uint32_t dim3407KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   9   ,   31  ,   55  ,   207 ,   109 ,   945 ,   1073    ,   3545    ,   4191    ,   12965   ,   20863   ,0 };
            const std::uint32_t dim3408KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   27  ,   45  ,   15  ,   67  ,   101 ,   207 ,   77  ,   3309    ,   747 ,   13857   ,   25737   ,0 };
            const std::uint32_t dim3409KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   1   ,   31  ,   15  ,   235 ,   57  ,   449 ,   411 ,   3739    ,   5093    ,   12963   ,   30649   ,0 };
            const std::uint32_t dim3410KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   5   ,   33  ,   87  ,   13  ,   57  ,   727 ,   1041    ,   3369    ,   6047    ,   1007    ,   4587    ,0 };
            const std::uint32_t dim3411KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   29  ,   43  ,   11  ,   251 ,   99  ,   413 ,   1943    ,   3461    ,   993 ,   13983   ,   8157    ,0 };
            const std::uint32_t dim3412KuoInit[]        =   {   1   ,   1   ,   5   ,   15  ,   7   ,   27  ,   105 ,   9   ,   69  ,   949 ,   245 ,   2537    ,   5941    ,   10961   ,   17115   ,0 };
            const std::uint32_t dim3413KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   17  ,   41  ,   63  ,   167 ,   45  ,   391 ,   895 ,   2565    ,   2681    ,   10855   ,   6919    ,0 };
            const std::uint32_t dim3414KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   7   ,   53  ,   15  ,   207 ,   467 ,   131 ,   761 ,   189 ,   4977    ,   4345    ,   7539    ,0 };
            const std::uint32_t dim3415KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   23  ,   17  ,   127 ,   3   ,   455 ,   787 ,   383 ,   2381    ,   6407    ,   3253    ,   1787    ,0 };
            const std::uint32_t dim3416KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   5   ,   7   ,   37  ,   75  ,   351 ,   141 ,   93  ,   2631    ,   609 ,   11455   ,   20603   ,0 };
            const std::uint32_t dim3417KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   5   ,   33  ,   19  ,   15  ,   101 ,   1005    ,   7   ,   1341    ,   4577    ,   11627   ,   17061   ,0 };
            const std::uint32_t dim3418KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   5   ,   7   ,   87  ,   181 ,   197 ,   423 ,   361 ,   545 ,   2459    ,   7419    ,   14457   ,0 };
            const std::uint32_t dim3419KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   25  ,   37  ,   93  ,   85  ,   345 ,   459 ,   465 ,   3377    ,   795 ,   13439   ,   4765    ,0 };
            const std::uint32_t dim3420KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   25  ,   55  ,   109 ,   63  ,   381 ,   329 ,   1787    ,   3163    ,   279 ,   4647    ,   8723    ,0 };
            const std::uint32_t dim3421KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   23  ,   33  ,   85  ,   41  ,   151 ,   319 ,   265 ,   259 ,   29  ,   4217    ,   21025   ,0 };
            const std::uint32_t dim3422KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   31  ,   17  ,   93  ,   27  ,   455 ,   1015    ,   81  ,   621 ,   6511    ,   7617    ,   6775    ,0 };
            const std::uint32_t dim3423KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   25  ,   21  ,   73  ,   161 ,   267 ,   911 ,   25  ,   1385    ,   4073    ,   14423   ,   31473   ,0 };
            const std::uint32_t dim3424KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   13  ,   33  ,   95  ,   113 ,   371 ,   291 ,   1055    ,   3779    ,   991 ,   9699    ,   9495    ,0 };
            const std::uint32_t dim3425KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   31  ,   55  ,   111 ,   215 ,   399 ,   721 ,   1443    ,   763 ,   3119    ,   11075   ,   15489   ,0 };
            const std::uint32_t dim3426KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   17  ,   57  ,   119 ,   171 ,   299 ,   299 ,   1919    ,   3103    ,   5691    ,   7927    ,   18875   ,0 };
            const std::uint32_t dim3427KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   13  ,   41  ,   35  ,   209 ,   383 ,   381 ,   901 ,   3341    ,   3421    ,   11501   ,   2187    ,0 };
            const std::uint32_t dim3428KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   1   ,   3   ,   83  ,   105 ,   495 ,   297 ,   413 ,   2941    ,   4309    ,   9829    ,   32115   ,0 };
            const std::uint32_t dim3429KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   3   ,   7   ,   81  ,   9   ,   55  ,   19  ,   225 ,   2915    ,   6255    ,   10967   ,   8767    ,0 };
            const std::uint32_t dim3430KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   23  ,   59  ,   21  ,   127 ,   7   ,   703 ,   1189    ,   2375    ,   6273    ,   1655    ,   10115   ,0 };
            const std::uint32_t dim3431KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   19  ,   35  ,   39  ,   185 ,   143 ,   163 ,   1491    ,   201 ,   2473    ,   661 ,   12827   ,0 };
            const std::uint32_t dim3432KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   29  ,   49  ,   5   ,   27  ,   131 ,   1005    ,   991 ,   1159    ,   5437    ,   5039    ,   4037    ,0 };
            const std::uint32_t dim3433KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   11  ,   41  ,   123 ,   43  ,   11  ,   443 ,   109 ,   3995    ,   5377    ,   2907    ,   30035   ,0 };
            const std::uint32_t dim3434KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   31  ,   59  ,   53  ,   219 ,   185 ,   31  ,   641 ,   1695    ,   5817    ,   9001    ,   28827   ,0 };
            const std::uint32_t dim3435KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   13  ,   37  ,   37  ,   119 ,   123 ,   57  ,   1241    ,   551 ,   5825    ,   11551   ,   23521   ,0 };
            const std::uint32_t dim3436KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   13  ,   37  ,   33  ,   61  ,   209 ,   375 ,   335 ,   1223    ,   4023    ,   12743   ,   8375    ,0 };
            const std::uint32_t dim3437KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   31  ,   7   ,   103 ,   43  ,   451 ,   517 ,   1025    ,   2853    ,   5943    ,   13655   ,   21409   ,0 };
            const std::uint32_t dim3438KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   11  ,   37  ,   11  ,   167 ,   271 ,   763 ,   85  ,   3727    ,   641 ,   2841    ,   23803   ,0 };
            const std::uint32_t dim3439KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   3   ,   19  ,   117 ,   225 ,   275 ,   327 ,   1263    ,   1597    ,   1439    ,   8531    ,   18063   ,0 };
            const std::uint32_t dim3440KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   9   ,   45  ,   57  ,   169 ,   453 ,   949 ,   585 ,   1365    ,   4263    ,   3461    ,   7191    ,0 };
            const std::uint32_t dim3441KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   25  ,   51  ,   97  ,   255 ,   457 ,   293 ,   1027    ,   1291    ,   6685    ,   2617    ,   3055    ,0 };
            const std::uint32_t dim3442KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   27  ,   33  ,   47  ,   65  ,   43  ,   545 ,   123 ,   1093    ,   5563    ,   3013    ,   18451   ,0 };
            const std::uint32_t dim3443KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   9   ,   25  ,   71  ,   241 ,   495 ,   561 ,   1565    ,   703 ,   809 ,   10961   ,   3001    ,0 };
            const std::uint32_t dim3444KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   1   ,   47  ,   97  ,   233 ,   259 ,   39  ,   543 ,   303 ,   2705    ,   3683    ,   32123   ,0 };
            const std::uint32_t dim3445KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   1   ,   35  ,   91  ,   43  ,   417 ,   299 ,   1635    ,   2163    ,   7959    ,   9015    ,   5661    ,0 };
            const std::uint32_t dim3446KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   1   ,   63  ,   49  ,   209 ,   125 ,   241 ,   987 ,   3173    ,   631 ,   9767    ,   8467    ,0 };
            const std::uint32_t dim3447KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   25  ,   49  ,   43  ,   117 ,   65  ,   81  ,   313 ,   1917    ,   6087    ,   1503    ,   3383    ,0 };
            const std::uint32_t dim3448KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   23  ,   53  ,   43  ,   29  ,   91  ,   727 ,   1157    ,   2985    ,   3851    ,   15897   ,   17577   ,0 };
            const std::uint32_t dim3449KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   15  ,   27  ,   35  ,   129 ,   161 ,   679 ,   1001    ,   2681    ,   5287    ,   10367   ,   21017   ,0 };
            const std::uint32_t dim3450KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   23  ,   51  ,   127 ,   119 ,   467 ,   161 ,   1229    ,   2969    ,   6321    ,   1141    ,   7827    ,0 };
            const std::uint32_t dim3451KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   19  ,   45  ,   33  ,   173 ,   205 ,   815 ,   783 ,   1323    ,   69  ,   5191    ,   23795   ,0 };
            const std::uint32_t dim3452KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   19  ,   1   ,   111 ,   253 ,   463 ,   247 ,   1877    ,   1831    ,   8037    ,   12769   ,   8111    ,0 };
            const std::uint32_t dim3453KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   21  ,   7   ,   19  ,   241 ,   297 ,   953 ,   1759    ,   2187    ,   1587    ,   14857   ,   13245   ,0 };
            const std::uint32_t dim3454KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   27  ,   21  ,   111 ,   37  ,   333 ,   485 ,   127 ,   1781    ,   545 ,   251 ,   2757    ,0 };
            const std::uint32_t dim3455KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   3   ,   7   ,   21  ,   69  ,   171 ,   225 ,   1505    ,   2725    ,   923 ,   9451    ,   29443   ,0 };
            const std::uint32_t dim3456KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   13  ,   57  ,   97  ,   175 ,   429 ,   529 ,   677 ,   1501    ,   4717    ,   12705   ,   31473   ,0 };
            const std::uint32_t dim3457KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   29  ,   7   ,   57  ,   115 ,   55  ,   167 ,   903 ,   3855    ,   8051    ,   15567   ,   31733   ,0 };
            const std::uint32_t dim3458KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   1   ,   1   ,   1   ,   1   ,   1   ,   1   ,   1   ,   1   ,   1   ,   1   ,   1   ,0 };
            const std::uint32_t dim3459KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   11  ,   17  ,   73  ,   193 ,   151 ,   927 ,   1375    ,   4037    ,   6855    ,   10481   ,   8973    ,0 };
            const std::uint32_t dim3460KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   25  ,   7   ,   115 ,   39  ,   469 ,   903 ,   655 ,   299 ,   6007    ,   6629    ,   11871   ,0 };
            const std::uint32_t dim3461KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   15  ,   49  ,   79  ,   115 ,   55  ,   841 ,   1091    ,   1641    ,   5693    ,   3607    ,   13699   ,0 };
            const std::uint32_t dim3462KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   5   ,   33  ,   99  ,   239 ,   157 ,   133 ,   2023    ,   683 ,   3419    ,   10993   ,   32187   ,0 };
            const std::uint32_t dim3463KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   3   ,   13  ,   95  ,   233 ,   341 ,   243 ,   2043    ,   653 ,   4673    ,   1441    ,   19087   ,0 };
            const std::uint32_t dim3464KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   29  ,   51  ,   117 ,   199 ,   49  ,   467 ,   461 ,   2465    ,   7541    ,   6815    ,   28711   ,0 };
            const std::uint32_t dim3465KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   25  ,   47  ,   31  ,   79  ,   9   ,   39  ,   733 ,   3567    ,   5965    ,   6627    ,   1109    ,0 };
            const std::uint32_t dim3466KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   9   ,   53  ,   27  ,   101 ,   341 ,   369 ,   1659    ,   1645    ,   4465    ,   10175   ,   4565    ,0 };
            const std::uint32_t dim3467KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   13  ,   61  ,   67  ,   125 ,   427 ,   105 ,   133 ,   2303    ,   5595    ,   4527    ,   23151   ,0 };
            const std::uint32_t dim3468KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   19  ,   29  ,   87  ,   167 ,   141 ,   657 ,   947 ,   367 ,   2617    ,   9287    ,   629 ,0 };
            const std::uint32_t dim3469KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   21  ,   25  ,   35  ,   21  ,   391 ,   1019    ,   991 ,   3343    ,   1221    ,   1591    ,   18095   ,0 };
            const std::uint32_t dim3470KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   31  ,   49  ,   99  ,   185 ,   405 ,   261 ,   935 ,   3447    ,   4081    ,   5537    ,   26329   ,0 };
            const std::uint32_t dim3471KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   25  ,   51  ,   107 ,   83  ,   449 ,   733 ,   597 ,   1023    ,   7457    ,   14343   ,   7119    ,0 };
            const std::uint32_t dim3472KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   23  ,   21  ,   35  ,   83  ,   185 ,   531 ,   1283    ,   2235    ,   7775    ,   15895   ,   32651   ,0 };
            const std::uint32_t dim3473KuoInit[]        =   {   1   ,   1   ,   5   ,   15  ,   27  ,   13  ,   23  ,   227 ,   491 ,   701 ,   341 ,   2109    ,   8045    ,   1529    ,   10589   ,0 };
            const std::uint32_t dim3474KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   21  ,   51  ,   31  ,   101 ,   31  ,   861 ,   401 ,   1519    ,   5349    ,   2623    ,   22667   ,0 };
            const std::uint32_t dim3475KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   1   ,   41  ,   43  ,   25  ,   491 ,   329 ,   537 ,   1357    ,   5567    ,   3951    ,   15293   ,0 };
            const std::uint32_t dim3476KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   15  ,   39  ,   113 ,   105 ,   51  ,   483 ,   1417    ,   2971    ,   3   ,   9673    ,   4331    ,0 };
            const std::uint32_t dim3477KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   17  ,   3   ,   19  ,   55  ,   443 ,   967 ,   327 ,   3463    ,   5427    ,   195 ,   7495    ,0 };
            const std::uint32_t dim3478KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   15  ,   15  ,   11  ,   157 ,   311 ,   967 ,   89  ,   3691    ,   7307    ,   12309   ,   1915    ,0 };
            const std::uint32_t dim3479KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   25  ,   7   ,   125 ,   163 ,   231 ,   177 ,   1497    ,   3119    ,   3281    ,   15033   ,   9457    ,0 };
            const std::uint32_t dim3480KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   25  ,   51  ,   51  ,   243 ,   427 ,   831 ,   709 ,   3741    ,   445 ,   14275   ,   32323   ,0 };
            const std::uint32_t dim3481KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   1   ,   41  ,   123 ,   237 ,   401 ,   19  ,   1161    ,   985 ,   5119    ,   14879   ,   5785    ,0 };
            const std::uint32_t dim3482KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   3   ,   11  ,   121 ,   209 ,   507 ,   271 ,   1045    ,   2547    ,   1019    ,   7107    ,   31823   ,0 };
            const std::uint32_t dim3483KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   21  ,   3   ,   33  ,   73  ,   79  ,   607 ,   47  ,   3045    ,   2471    ,   2023    ,   8115    ,0 };
            const std::uint32_t dim3484KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   19  ,   49  ,   111 ,   185 ,   209 ,   683 ,   1459    ,   3827    ,   6591    ,   13139   ,   2057    ,0 };
            const std::uint32_t dim3485KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   17  ,   63  ,   77  ,   217 ,   161 ,   287 ,   335 ,   3947    ,   5255    ,   12297   ,   16829   ,0 };
            const std::uint32_t dim3486KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   17  ,   17  ,   31  ,   231 ,   483 ,   437 ,   431 ,   957 ,   6499    ,   12947   ,   29751   ,0 };
            const std::uint32_t dim3487KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   5   ,   57  ,   119 ,   43  ,   385 ,   743 ,   249 ,   3479    ,   7751    ,   6321    ,   31747   ,0 };
            const std::uint32_t dim3488KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   5   ,   1   ,   113 ,   87  ,   439 ,   507 ,   1517    ,   2081    ,   5947    ,   10967   ,   10219   ,0 };
            const std::uint32_t dim3489KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   23  ,   29  ,   39  ,   33  ,   129 ,   493 ,   1119    ,   2177    ,   4135    ,   5051    ,   20241   ,0 };
            const std::uint32_t dim3490KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   19  ,   13  ,   71  ,   163 ,   107 ,   285 ,   1999    ,   3371    ,   3555    ,   16265   ,   2825    ,0 };
            const std::uint32_t dim3491KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   5   ,   19  ,   67  ,   201 ,   203 ,   619 ,   927 ,   1769    ,   5655    ,   4539    ,   1719    ,0 };
            const std::uint32_t dim3492KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   15  ,   43  ,   107 ,   91  ,   315 ,   281 ,   525 ,   3243    ,   7751    ,   8991    ,   29195   ,0 };
            const std::uint32_t dim3493KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   21  ,   43  ,   35  ,   81  ,   199 ,   51  ,   935 ,   357 ,   1723    ,   8183    ,   6209    ,0 };
            const std::uint32_t dim3494KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   9   ,   31  ,   75  ,   71  ,   375 ,   181 ,   1503    ,   3479    ,   2255    ,   1371    ,   16127   ,0 };
            const std::uint32_t dim3495KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   29  ,   61  ,   57  ,   145 ,   149 ,   673 ,   1953    ,   2111    ,   3525    ,   1007    ,   15927   ,0 };
            const std::uint32_t dim3496KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   25  ,   25  ,   103 ,   175 ,   273 ,   193 ,   1215    ,   3059    ,   7805    ,   1455    ,   1627    ,0 };
            const std::uint32_t dim3497KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   23  ,   45  ,   61  ,   227 ,   487 ,   89  ,   739 ,   1867    ,   3643    ,   9879    ,   17307   ,0 };
            const std::uint32_t dim3498KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   23  ,   5   ,   117 ,   25  ,   325 ,   725 ,   1999    ,   3453    ,   2353    ,   5467    ,   2065    ,0 };
            const std::uint32_t dim3499KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   25  ,   3   ,   95  ,   243 ,   175 ,   291 ,   821 ,   3531    ,   4873    ,   9975    ,   30437   ,0 };
            const std::uint32_t dim3500KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   5   ,   41  ,   121 ,   23  ,   15  ,   195 ,   1141    ,   171 ,   2245    ,   8043    ,   2201    ,0 };
            const std::uint32_t dim3501KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   29  ,   1   ,   41  ,   233 ,   217 ,   501 ,   913 ,   3589    ,   1153    ,   4601    ,   23147   ,0 };
            const std::uint32_t dim3502KuoInit[]        =   {   1   ,   1   ,   5   ,   15  ,   1   ,   41  ,   71  ,   255 ,   283 ,   125 ,   845 ,   1261    ,   7519    ,   15623   ,   13301   ,0 };
            const std::uint32_t dim3503KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   11  ,   3   ,   73  ,   161 ,   203 ,   775 ,   905 ,   411 ,   4139    ,   8289    ,   8581    ,0 };
            const std::uint32_t dim3504KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   7   ,   57  ,   17  ,   115 ,   273 ,   949 ,   913 ,   3267    ,   6949    ,   6785    ,   30449   ,0 };
            const std::uint32_t dim3505KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   3   ,   49  ,   55  ,   191 ,   505 ,   807 ,   287 ,   3595    ,   2261    ,   13751   ,   15339   ,0 };
            const std::uint32_t dim3506KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   23  ,   13  ,   83  ,   145 ,   387 ,   37  ,   341 ,   111 ,   3309    ,   4481    ,   21679   ,0 };
            const std::uint32_t dim3507KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   3   ,   51  ,   13  ,   247 ,   419 ,   555 ,   431 ,   187 ,   2753    ,   9071    ,   25189   ,0 };
            const std::uint32_t dim3508KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   29  ,   33  ,   119 ,   63  ,   363 ,   197 ,   1901    ,   2231    ,   1453    ,   3901    ,   13713   ,0 };
            const std::uint32_t dim3509KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   9   ,   15  ,   91  ,   107 ,   397 ,   739 ,   1419    ,   481 ,   5713    ,   14089   ,   11699   ,0 };
            const std::uint32_t dim3510KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   9   ,   37  ,   47  ,   183 ,   45  ,   135 ,   903 ,   2769    ,   5929    ,   8175    ,   8661    ,0 };
            const std::uint32_t dim3511KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   7   ,   63  ,   117 ,   81  ,   385 ,   459 ,   1455    ,   4089    ,   395 ,   7569    ,   18089   ,0 };
            const std::uint32_t dim3512KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   15  ,   29  ,   71  ,   47  ,   423 ,   177 ,   1481    ,   1087    ,   3703    ,   5857    ,   9631    ,0 };
            const std::uint32_t dim3513KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   23  ,   45  ,   127 ,   91  ,   457 ,   81  ,   681 ,   257 ,   361 ,   11739   ,   1503    ,0 };
            const std::uint32_t dim3514KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   29  ,   29  ,   107 ,   125 ,   55  ,   759 ,   1287    ,   1937    ,   353 ,   1275    ,   14349   ,0 };
            const std::uint32_t dim3515KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   15  ,   53  ,   35  ,   1   ,   419 ,   255 ,   1891    ,   7   ,   3005    ,   1493    ,   165 ,0 };
            const std::uint32_t dim3516KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   5   ,   19  ,   45  ,   109 ,   479 ,   309 ,   277 ,   2749    ,   4859    ,   4301    ,   17799   ,0 };
            const std::uint32_t dim3517KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   21  ,   57  ,   39  ,   19  ,   433 ,   77  ,   1999    ,   3467    ,   2097    ,   6853    ,   1763    ,0 };
            const std::uint32_t dim3518KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   7   ,   39  ,   109 ,   53  ,   1   ,   543 ,   623 ,   573 ,   4039    ,   1367    ,   23177   ,0 };
            const std::uint32_t dim3519KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   1   ,   31  ,   3   ,   203 ,   409 ,   409 ,   1471    ,   1245    ,   3881    ,   14467   ,   22731   ,0 };
            const std::uint32_t dim3520KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   19  ,   41  ,   39  ,   95  ,   187 ,   823 ,   973 ,   3055    ,   3803    ,   4229    ,   29363   ,0 };
            const std::uint32_t dim3521KuoInit[]        =   {   1   ,   1   ,   5   ,   15  ,   29  ,   41  ,   69  ,   121 ,   385 ,   717 ,   1601    ,   3061    ,   6523    ,   13423   ,   12559   ,0 };
            const std::uint32_t dim3522KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   5   ,   45  ,   85  ,   153 ,   337 ,   587 ,   595 ,   1183    ,   3799    ,   12775   ,   19537   ,0 };
            const std::uint32_t dim3523KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   11  ,   45  ,   97  ,   37  ,   167 ,   227 ,   1003    ,   2991    ,   2291    ,   15865   ,   6645    ,0 };
            const std::uint32_t dim3524KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   31  ,   41  ,   123 ,   225 ,   275 ,   733 ,   1611    ,   1599    ,   7345    ,   297 ,   22551   ,0 };
            const std::uint32_t dim3525KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   7   ,   45  ,   45  ,   155 ,   41  ,   581 ,   635 ,   4065    ,   3993    ,   7233    ,   27097   ,0 };
            const std::uint32_t dim3526KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   9   ,   39  ,   17  ,   19  ,   335 ,   819 ,   1845    ,   1199    ,   591 ,   7743    ,   26797   ,0 };
            const std::uint32_t dim3527KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   29  ,   33  ,   35  ,   19  ,   287 ,   935 ,   1463    ,   3639    ,   5537    ,   2751    ,   20073   ,0 };
            const std::uint32_t dim3528KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   3   ,   45  ,   59  ,   117 ,   431 ,   419 ,   1325    ,   983 ,   6065    ,   3501    ,   15765   ,0 };
            const std::uint32_t dim3529KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   27  ,   7   ,   123 ,   205 ,   155 ,   59  ,   1139    ,   1147    ,   4845    ,   15131   ,   10155   ,0 };
            const std::uint32_t dim3530KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   23  ,   37  ,   97  ,   33  ,   337 ,   837 ,   1379    ,   2459    ,   469 ,   10615   ,   16475   ,0 };
            const std::uint32_t dim3531KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   1   ,   23  ,   27  ,   63  ,   503 ,   635 ,   935 ,   1767    ,   6887    ,   6675    ,   10973   ,0 };
            const std::uint32_t dim3532KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   13  ,   29  ,   15  ,   109 ,   185 ,   33  ,   1039    ,   959 ,   1745    ,   10587   ,   9269    ,0 };
            const std::uint32_t dim3533KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   5   ,   29  ,   89  ,   63  ,   341 ,   773 ,   1851    ,   775 ,   1717    ,   6041    ,   11901   ,0 };
            const std::uint32_t dim3534KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   23  ,   47  ,   21  ,   111 ,   289 ,   997 ,   1559    ,   501 ,   5913    ,   4737    ,   4623    ,0 };
            const std::uint32_t dim3535KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   3   ,   3   ,   87  ,   197 ,   391 ,   121 ,   627 ,   3705    ,   4093    ,   3933    ,   13787   ,0 };
            const std::uint32_t dim3536KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   31  ,   9   ,   117 ,   47  ,   373 ,   697 ,   131 ,   3933    ,   3135    ,   9155    ,   3937    ,0 };
            const std::uint32_t dim3537KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   11  ,   39  ,   5   ,   27  ,   253 ,   301 ,   1151    ,   3771    ,   1581    ,   9811    ,   17617   ,0 };
            const std::uint32_t dim3538KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   25  ,   59  ,   97  ,   229 ,   291 ,   349 ,   1153    ,   1859    ,   3357    ,   7919    ,   2733    ,0 };
            const std::uint32_t dim3539KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   5   ,   7   ,   37  ,   177 ,   177 ,   969 ,   29  ,   4017    ,   6791    ,   2823    ,   10607   ,0 };
            const std::uint32_t dim3540KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   27  ,   17  ,   25  ,   137 ,   325 ,   949 ,   1519    ,   3711    ,   4399    ,   9501    ,   2989    ,0 };
            const std::uint32_t dim3541KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   29  ,   27  ,   75  ,   195 ,   417 ,   945 ,   1851    ,   2887    ,   2379    ,   15229   ,   4805    ,0 };
            const std::uint32_t dim3542KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   31  ,   45  ,   105 ,   87  ,   241 ,   153 ,   1941    ,   3459    ,   4809    ,   9823    ,   19419   ,0 };
            const std::uint32_t dim3543KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   1   ,   59  ,   75  ,   51  ,   309 ,   671 ,   1039    ,   2999    ,   1025    ,   15823   ,   4835    ,0 };
            const std::uint32_t dim3544KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   19  ,   37  ,   41  ,   85  ,   11  ,   713 ,   1047    ,   989 ,   2941    ,   6423    ,   7983    ,0 };
            const std::uint32_t dim3545KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   1   ,   55  ,   103 ,   207 ,   275 ,   431 ,   563 ,   101 ,   691 ,   1997    ,   17227   ,0 };
            const std::uint32_t dim3546KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   19  ,   15  ,   67  ,   197 ,   125 ,   377 ,   367 ,   601 ,   4983    ,   1699    ,   29315   ,0 };
            const std::uint32_t dim3547KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   23  ,   19  ,   19  ,   133 ,   83  ,   625 ,   757 ,   1349    ,   5821    ,   2483    ,   26653   ,0 };
            const std::uint32_t dim3548KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   19  ,   17  ,   19  ,   83  ,   235 ,   657 ,   733 ,   1773    ,   7011    ,   3893    ,   8495    ,0 };
            const std::uint32_t dim3549KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   19  ,   33  ,   37  ,   69  ,   385 ,   835 ,   1025    ,   1585    ,   6685    ,   10627   ,   19203   ,0 };
            const std::uint32_t dim3550KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   9   ,   31  ,   65  ,   177 ,   153 ,   781 ,   1183    ,   1215    ,   6271    ,   13099   ,   12449   ,0 };
            const std::uint32_t dim3551KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   13  ,   49  ,   41  ,   57  ,   443 ,   633 ,   1953    ,   2423    ,   789 ,   5591    ,   20891   ,0 };
            const std::uint32_t dim3552KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   17  ,   21  ,   69  ,   177 ,   57  ,   797 ,   13  ,   3987    ,   6597    ,   9935    ,   26559   ,0 };
            const std::uint32_t dim3553KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   21  ,   27  ,   17  ,   207 ,   139 ,   43  ,   1935    ,   3285    ,   4251    ,   4411    ,   24469   ,0 };
            const std::uint32_t dim3554KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   11  ,   47  ,   63  ,   243 ,   19  ,   801 ,   971 ,   1925    ,   5981    ,   13055   ,   12185   ,0 };
            const std::uint32_t dim3555KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   9   ,   13  ,   49  ,   251 ,   315 ,   889 ,   1613    ,   1007    ,   7849    ,   3121    ,   4279    ,0 };
            const std::uint32_t dim3556KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   7   ,   37  ,   95  ,   253 ,   65  ,   177 ,   1551    ,   2307    ,   2325    ,   9975    ,   18277   ,0 };
            const std::uint32_t dim3557KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   7   ,   53  ,   45  ,   5   ,   447 ,   1005    ,   279 ,   2141    ,   4271    ,   4707    ,   11225   ,0 };
            const std::uint32_t dim3558KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   31  ,   11  ,   15  ,   133 ,   313 ,   249 ,   1971    ,   2905    ,   819 ,   11603   ,   25679   ,0 };
            const std::uint32_t dim3559KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   21  ,   49  ,   107 ,   229 ,   101 ,   449 ,   245 ,   1401    ,   391 ,   3749    ,   14555   ,0 };
            const std::uint32_t dim3560KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   7   ,   39  ,   69  ,   223 ,   37  ,   771 ,   1469    ,   2085    ,   1075    ,   14485   ,   10019   ,0 };
            const std::uint32_t dim3561KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   3   ,   27  ,   37  ,   59  ,   69  ,   675 ,   807 ,   2711    ,   3867    ,   9737    ,   21913   ,0 };
            const std::uint32_t dim3562KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   25  ,   45  ,   109 ,   113 ,   267 ,   867 ,   771 ,   1647    ,   2063    ,   14063   ,   27737   ,0 };
            const std::uint32_t dim3563KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   23  ,   51  ,   71  ,   33  ,   103 ,   71  ,   1177    ,   2353    ,   4741    ,   6907    ,   11121   ,0 };
            const std::uint32_t dim3564KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   21  ,   31  ,   77  ,   255 ,   341 ,   249 ,   1263    ,   505 ,   1845    ,   12867   ,   11393   ,0 };
            const std::uint32_t dim3565KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   3   ,   1   ,   5   ,   215 ,   155 ,   107 ,   1283    ,   3501    ,   8079    ,   13921   ,   22415   ,0 };
            const std::uint32_t dim3566KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   31  ,   21  ,   21  ,   29  ,   341 ,   13  ,   155 ,   2161    ,   517 ,   13135   ,   15893   ,0 };
            const std::uint32_t dim3567KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   21  ,   33  ,   23  ,   131 ,   367 ,   939 ,   1139    ,   865 ,   6015    ,   6945    ,   2301    ,0 };
            const std::uint32_t dim3568KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   1   ,   25  ,   109 ,   183 ,   267 ,   757 ,   371 ,   1459    ,   3671    ,   2925    ,   10345   ,0 };
            const std::uint32_t dim3569KuoInit[]        =   {   1   ,   1   ,   5   ,   15  ,   29  ,   57  ,   95  ,   169 ,   301 ,   645 ,   5   ,   225 ,   5711    ,   305 ,   16515   ,0 };
            const std::uint32_t dim3570KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   27  ,   47  ,   95  ,   121 ,   203 ,   341 ,   657 ,   2467    ,   7619    ,   9587    ,   7981    ,0 };
            const std::uint32_t dim3571KuoInit[]        =   {   1   ,   3   ,   1   ,   5   ,   27  ,   11  ,   103 ,   67  ,   19  ,   289 ,   187 ,   3857    ,   8117    ,   12931   ,   11279   ,0 };
            const std::uint32_t dim3572KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   31  ,   9   ,   57  ,   67  ,   507 ,   405 ,   181 ,   2301    ,   715 ,   12165   ,   18415   ,0 };
            const std::uint32_t dim3573KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   11  ,   3   ,   35  ,   215 ,   177 ,   679 ,   735 ,   1569    ,   6231    ,   5141    ,   28291   ,0 };
            const std::uint32_t dim3574KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   7   ,   7   ,   101 ,   247 ,   103 ,   373 ,   1485    ,   2515    ,   3981    ,   12029   ,   5845    ,0 };
            const std::uint32_t dim3575KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   29  ,   27  ,   117 ,   111 ,   107 ,   737 ,   629 ,   1331    ,   7495    ,   9813    ,   24925   ,0 };
            const std::uint32_t dim3576KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   17  ,   11  ,   95  ,   11  ,   1   ,   525 ,   1677    ,   2673    ,   2353    ,   7211    ,   1075    ,0 };
            const std::uint32_t dim3577KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   9   ,   29  ,   9   ,   125 ,   249 ,   815 ,   105 ,   1649    ,   2789    ,   6041    ,   15287   ,0 };
            const std::uint32_t dim3578KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   25  ,   53  ,   87  ,   99  ,   427 ,   255 ,   285 ,   2339    ,   5003    ,   10395   ,   20969   ,0 };
            const std::uint32_t dim3579KuoInit[]        =   {   1   ,   3   ,   1   ,   5   ,   25  ,   33  ,   97  ,   149 ,   207 ,   925 ,   645 ,   1867    ,   4591    ,   10823   ,   16603   ,0 };
            const std::uint32_t dim3580KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   1   ,   33  ,   71  ,   49  ,   417 ,   535 ,   923 ,   525 ,   811 ,   7443    ,   12971   ,0 };
            const std::uint32_t dim3581KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   5   ,   9   ,   39  ,   121 ,   87  ,   883 ,   1957    ,   1375    ,   4109    ,   12691   ,   15557   ,0 };
            const std::uint32_t dim3582KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   23  ,   11  ,   59  ,   41  ,   117 ,   243 ,   1953    ,   3967    ,   7303    ,   10767   ,   1345    ,0 };
            const std::uint32_t dim3583KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   29  ,   59  ,   19  ,   177 ,   405 ,   197 ,   59  ,   855 ,   5009    ,   11887   ,   6361    ,0 };
            const std::uint32_t dim3584KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   19  ,   59  ,   71  ,   199 ,   207 ,   757 ,   1147    ,   1857    ,   3787    ,   16081   ,   29557   ,0 };
            const std::uint32_t dim3585KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   25  ,   13  ,   37  ,   27  ,   511 ,   983 ,   1087    ,   371 ,   4953    ,   8987    ,   3155    ,0 };
            const std::uint32_t dim3586KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   21  ,   43  ,   75  ,   227 ,   441 ,   523 ,   551 ,   3517    ,   77  ,   5869    ,   24607   ,0 };
            const std::uint32_t dim3587KuoInit[]        =   {   1   ,   1   ,   5   ,   15  ,   1   ,   33  ,   25  ,   217 ,   277 ,   73  ,   105 ,   1697    ,   1545    ,   10205   ,   4275    ,0 };
            const std::uint32_t dim3588KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   3   ,   53  ,   99  ,   19  ,   121 ,   427 ,   585 ,   2471    ,   103 ,   3771    ,   23525   ,0 };
            const std::uint32_t dim3589KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   15  ,   17  ,   35  ,   205 ,   9   ,   941 ,   1281    ,   1339    ,   7421    ,   3341    ,   4393    ,0 };
            const std::uint32_t dim3590KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   27  ,   13  ,   35  ,   99  ,   87  ,   157 ,   951 ,   2739    ,   1993    ,   6107    ,   29023   ,0 };
            const std::uint32_t dim3591KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   15  ,   5   ,   83  ,   5   ,   283 ,   393 ,   1273    ,   2251    ,   4181    ,   3851    ,   6845    ,0 };
            const std::uint32_t dim3592KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   1   ,   9   ,   63  ,   97  ,   83  ,   93  ,   293 ,   2087    ,   2259    ,   10313   ,   1037    ,0 };
            const std::uint32_t dim3593KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   11  ,   19  ,   39  ,   19  ,   327 ,   329 ,   189 ,   3851    ,   4839    ,   1669    ,   25805   ,0 };
            const std::uint32_t dim3594KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   21  ,   1   ,   41  ,   233 ,   497 ,   265 ,   1041    ,   4003    ,   8029    ,   15  ,   14437   ,0 };
            const std::uint32_t dim3595KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   7   ,   15  ,   123 ,   215 ,   403 ,   931 ,   277 ,   3501    ,   3667    ,   13313   ,   23977   ,0 };
            const std::uint32_t dim3596KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   5   ,   23  ,   99  ,   161 ,   25  ,   403 ,   1695    ,   2493    ,   199 ,   15745   ,   9167    ,0 };
            const std::uint32_t dim3597KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   1   ,   25  ,   93  ,   31  ,   227 ,   833 ,   1891    ,   1171    ,   4551    ,   3329    ,   30593   ,0 };
            const std::uint32_t dim3598KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   29  ,   51  ,   109 ,   27  ,   475 ,   511 ,   1763    ,   2285    ,   3191    ,   7943    ,   8373    ,0 };
            const std::uint32_t dim3599KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   21  ,   63  ,   89  ,   9   ,   429 ,   613 ,   141 ,   4011    ,   6563    ,   5871    ,   30701   ,0 };
            const std::uint32_t dim3600KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   31  ,   49  ,   87  ,   15  ,   481 ,   237 ,   133 ,   3267    ,   7385    ,   4733    ,   16853   ,0 };
            const std::uint32_t dim3601KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   1   ,   63  ,   95  ,   17  ,   311 ,   29  ,   1543    ,   2971    ,   695 ,   3641    ,   28155   ,0 };
            const std::uint32_t dim3602KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   27  ,   1   ,   59  ,   181 ,   321 ,   431 ,   143 ,   213 ,   1471    ,   4707    ,   22897   ,0 };
            const std::uint32_t dim3603KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   19  ,   3   ,   95  ,   1   ,   407 ,   755 ,   1581    ,   3435    ,   2025    ,   7781    ,   5573    ,0 };
            const std::uint32_t dim3604KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   19  ,   15  ,   119 ,   169 ,   109 ,   1003    ,   403 ,   1633    ,   4963    ,   9785    ,   18483   ,0 };
            const std::uint32_t dim3605KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   23  ,   5   ,   77  ,   79  ,   429 ,   921 ,   1913    ,   2075    ,   7923    ,   5515    ,   19257   ,0 };
            const std::uint32_t dim3606KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   1   ,   45  ,   99  ,   249 ,   385 ,   427 ,   1201    ,   1363    ,   335 ,   12561   ,   18753   ,0 };
            const std::uint32_t dim3607KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   27  ,   41  ,   9   ,   13  ,   267 ,   987 ,   1023    ,   2723    ,   3873    ,   15911   ,   3165    ,0 };
            const std::uint32_t dim3608KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   17  ,   7   ,   117 ,   241 ,   509 ,   757 ,   1301    ,   3935    ,   3361    ,   13745   ,   27239   ,0 };
            const std::uint32_t dim3609KuoInit[]        =   {   1   ,   1   ,   5   ,   15  ,   21  ,   33  ,   55  ,   245 ,   1   ,   263 ,   437 ,   2279    ,   1201    ,   2043    ,   20473   ,0 };
            const std::uint32_t dim3610KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   29  ,   9   ,   31  ,   165 ,   299 ,   923 ,   847 ,   769 ,   5683    ,   1805    ,   13433   ,0 };
            const std::uint32_t dim3611KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   29  ,   13  ,   49  ,   173 ,   269 ,   35  ,   1057    ,   973 ,   1853    ,   12677   ,   13565   ,0 };
            const std::uint32_t dim3612KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   11  ,   21  ,   19  ,   3   ,   127 ,   133 ,   193 ,   2665    ,   7187    ,   15425   ,   23805   ,0 };
            const std::uint32_t dim3613KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   13  ,   61  ,   95  ,   17  ,   197 ,   381 ,   865 ,   1241    ,   685 ,   9525    ,   2503    ,0 };
            const std::uint32_t dim3614KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   13  ,   19  ,   83  ,   141 ,   179 ,   201 ,   463 ,   2083    ,   3617    ,   1945    ,   20371   ,0 };
            const std::uint32_t dim3615KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   9   ,   39  ,   47  ,   3   ,   13  ,   739 ,   1501    ,   1007    ,   6963    ,   15819   ,   29739   ,0 };
            const std::uint32_t dim3616KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   3   ,   17  ,   105 ,   27  ,   165 ,   515 ,   949 ,   81  ,   947 ,   9615    ,   24403   ,0 };
            const std::uint32_t dim3617KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   23  ,   43  ,   81  ,   141 ,   181 ,   1007    ,   1343    ,   1919    ,   5971    ,   8563    ,   17091   ,0 };
            const std::uint32_t dim3618KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   1   ,   25  ,   19  ,   117 ,   225 ,   347 ,   785 ,   791 ,   7321    ,   15647   ,   25491   ,0 };
            const std::uint32_t dim3619KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   11  ,   61  ,   25  ,   205 ,   145 ,   695 ,   713 ,   1787    ,   8087    ,   5935    ,   5105    ,0 };
            const std::uint32_t dim3620KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   15  ,   17  ,   25  ,   141 ,   75  ,   657 ,   1641    ,   575 ,   3387    ,   6093    ,   15565   ,0 };
            const std::uint32_t dim3621KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   31  ,   49  ,   113 ,   37  ,   321 ,   547 ,   819 ,   2079    ,   7231    ,   7497    ,   29877   ,0 };
            const std::uint32_t dim3622KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   31  ,   19  ,   39  ,   99  ,   271 ,   527 ,   1551    ,   2491    ,   5515    ,   5541    ,   6131    ,0 };
            const std::uint32_t dim3623KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   23  ,   35  ,   31  ,   35  ,   315 ,   911 ,   1133    ,   3509    ,   1381    ,   15869   ,   23211   ,0 };
            const std::uint32_t dim3624KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   1   ,   33  ,   127 ,   175 ,   311 ,   497 ,   187 ,   2983    ,   6553    ,   9653    ,   5711    ,0 };
            const std::uint32_t dim3625KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   19  ,   3   ,   65  ,   91  ,   265 ,   199 ,   2035    ,   1277    ,   4575    ,   5517    ,   15247   ,0 };
            const std::uint32_t dim3626KuoInit[]        =   {   1   ,   1   ,   5   ,   15  ,   31  ,   39  ,   71  ,   167 ,   337 ,   245 ,   399 ,   2681    ,   1257    ,   15117   ,   24145   ,0 };
            const std::uint32_t dim3627KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   7   ,   19  ,   113 ,   133 ,   83  ,   851 ,   1543    ,   1699    ,   4527    ,   3167    ,   10793   ,0 };
            const std::uint32_t dim3628KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   31  ,   55  ,   35  ,   161 ,   133 ,   83  ,   469 ,   3011    ,   4513    ,   4677    ,   2363    ,0 };
            const std::uint32_t dim3629KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   29  ,   51  ,   29  ,   163 ,   95  ,   221 ,   973 ,   2819    ,   3103    ,   9969    ,   10347   ,0 };
            const std::uint32_t dim3630KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   31  ,   5   ,   73  ,   159 ,   339 ,   523 ,   399 ,   4041    ,   4341    ,   11527   ,   505 ,0 };
            const std::uint32_t dim3631KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   15  ,   55  ,   91  ,   117 ,   233 ,   497 ,   485 ,   1187    ,   5185    ,   13127   ,   14393   ,0 };
            const std::uint32_t dim3632KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   27  ,   19  ,   23  ,   197 ,   99  ,   779 ,   423 ,   2735    ,   3513    ,   8227    ,   31127   ,0 };
            const std::uint32_t dim3633KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   3   ,   61  ,   89  ,   137 ,   189 ,   325 ,   1797    ,   2287    ,   5033    ,   7351    ,   1131    ,0 };
            const std::uint32_t dim3634KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   19  ,   9   ,   83  ,   87  ,   451 ,   317 ,   667 ,   3379    ,   2225    ,   6437    ,   31515   ,0 };
            const std::uint32_t dim3635KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   13  ,   31  ,   121 ,   131 ,   473 ,   717 ,   1507    ,   1483    ,   4819    ,   14375   ,   24667   ,0 };
            const std::uint32_t dim3636KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   5   ,   55  ,   101 ,   111 ,   89  ,   481 ,   2031    ,   3043    ,   5727    ,   1253    ,   11951   ,0 };
            const std::uint32_t dim3637KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   3   ,   13  ,   67  ,   129 ,   311 ,   125 ,   121 ,   2833    ,   3555    ,   7761    ,   27343   ,0 };
            const std::uint32_t dim3638KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   29  ,   37  ,   63  ,   59  ,   5   ,   691 ,   1625    ,   97  ,   6113    ,   14795   ,   31471   ,0 };
            const std::uint32_t dim3639KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   25  ,   7   ,   65  ,   207 ,   371 ,   29  ,   1627    ,   1785    ,   5203    ,   5153    ,   1461    ,0 };
            const std::uint32_t dim3640KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   1   ,   37  ,   121 ,   249 ,   381 ,   309 ,   1545    ,   4039    ,   5657    ,   6783    ,   1889    ,0 };
            const std::uint32_t dim3641KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   29  ,   19  ,   51  ,   213 ,   185 ,   481 ,   1929    ,   2475    ,   567 ,   10045   ,   32619   ,0 };
            const std::uint32_t dim3642KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   13  ,   13  ,   17  ,   47  ,   55  ,   521 ,   473 ,   495 ,   7807    ,   1645    ,   17713   ,0 };
            const std::uint32_t dim3643KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   5   ,   63  ,   119 ,   167 ,   357 ,   231 ,   1915    ,   3605    ,   3579    ,   3041    ,   603 ,0 };
            const std::uint32_t dim3644KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   31  ,   5   ,   93  ,   193 ,   175 ,   801 ,   1963    ,   1413    ,   1641    ,   4073    ,   16017   ,0 };
            const std::uint32_t dim3645KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   11  ,   49  ,   53  ,   57  ,   1   ,   799 ,   301 ,   2611    ,   2975    ,   7595    ,   25891   ,0 };
            const std::uint32_t dim3646KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   19  ,   41  ,   63  ,   173 ,   257 ,   903 ,   1977    ,   3799    ,   3985    ,   14807   ,   24903   ,0 };
            const std::uint32_t dim3647KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   17  ,   53  ,   61  ,   115 ,   453 ,   395 ,   993 ,   3365    ,   4071    ,   4737    ,   29469   ,0 };
            const std::uint32_t dim3648KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   3   ,   55  ,   109 ,   149 ,   313 ,   621 ,   345 ,   4037    ,   677 ,   3787    ,   6701    ,0 };
            const std::uint32_t dim3649KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   23  ,   11  ,   63  ,   21  ,   47  ,   949 ,   47  ,   3055    ,   3403    ,   7581    ,   12853   ,0 };
            const std::uint32_t dim3650KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   7   ,   21  ,   15  ,   203 ,   167 ,   677 ,   49  ,   2777    ,   7817    ,   13207   ,   31485   ,0 };
            const std::uint32_t dim3651KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   29  ,   41  ,   37  ,   61  ,   343 ,   279 ,   127 ,   925 ,   7091    ,   14477   ,   24149   ,0 };
            const std::uint32_t dim3652KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   3   ,   33  ,   35  ,   237 ,   133 ,   653 ,   1491    ,   2183    ,   3565    ,   14773   ,   4521    ,0 };
            const std::uint32_t dim3653KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   31  ,   43  ,   13  ,   79  ,   465 ,   785 ,   1913    ,   1133    ,   2701    ,   9007    ,   15695   ,0 };
            const std::uint32_t dim3654KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   23  ,   43  ,   5   ,   155 ,   369 ,   131 ,   671 ,   1109    ,   7951    ,   1929    ,   23965   ,0 };
            const std::uint32_t dim3655KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   9   ,   15  ,   23  ,   59  ,   511 ,   931 ,   259 ,   1953    ,   1197    ,   9441    ,   25545   ,0 };
            const std::uint32_t dim3656KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   27  ,   25  ,   51  ,   81  ,   479 ,   491 ,   203 ,   4009    ,   4621    ,   11153   ,   12049   ,0 };
            const std::uint32_t dim3657KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   25  ,   11  ,   77  ,   253 ,   249 ,   761 ,   707 ,   161 ,   7519    ,   5381    ,   1549    ,0 };
            const std::uint32_t dim3658KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   11  ,   39  ,   59  ,   191 ,   443 ,   471 ,   53  ,   1639    ,   505 ,   1281    ,   1919    ,0 };
            const std::uint32_t dim3659KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   29  ,   47  ,   121 ,   135 ,   411 ,   95  ,   1255    ,   635 ,   835 ,   7905    ,   18435   ,0 };
            const std::uint32_t dim3660KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   21  ,   57  ,   65  ,   75  ,   333 ,   61  ,   1861    ,   3903    ,   6051    ,   8311    ,   2791    ,0 };
            const std::uint32_t dim3661KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   7   ,   49  ,   121 ,   233 ,   305 ,   697 ,   525 ,   3921    ,   5747    ,   2951    ,   24321   ,0 };
            const std::uint32_t dim3662KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   9   ,   23  ,   53  ,   121 ,   187 ,   35  ,   1973    ,   829 ,   575 ,   4003    ,   32159   ,0 };
            const std::uint32_t dim3663KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   3   ,   57  ,   25  ,   99  ,   383 ,   97  ,   1751    ,   1799    ,   2001    ,   8335    ,   20349   ,0 };
            const std::uint32_t dim3664KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   11  ,   17  ,   25  ,   107 ,   483 ,   183 ,   559 ,   2531    ,   6509    ,   9449    ,   1793    ,0 };
            const std::uint32_t dim3665KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   3   ,   43  ,   89  ,   57  ,   15  ,   269 ,   521 ,   1119    ,   3573    ,   9801    ,   30943   ,0 };
            const std::uint32_t dim3666KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   7   ,   41  ,   101 ,   177 ,   47  ,   47  ,   2009    ,   2127    ,   5113    ,   13541   ,   4133    ,0 };
            const std::uint32_t dim3667KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   23  ,   63  ,   67  ,   73  ,   335 ,   471 ,   1137    ,   3101    ,   5539    ,   16203   ,   15395   ,   12455   ,0 };
            const std::uint32_t dim3668KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   5   ,   9   ,   43  ,   123 ,   91  ,   23  ,   1199    ,   287 ,   5343    ,   1937    ,   12115   ,   4749    ,0 };
            const std::uint32_t dim3669KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   27  ,   3   ,   29  ,   251 ,   413 ,   147 ,   403 ,   2065    ,   2695    ,   11657   ,   15519   ,   49391   ,0 };
            const std::uint32_t dim3670KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   25  ,   7   ,   125 ,   137 ,   479 ,   753 ,   309 ,   1075    ,   7991    ,   2629    ,   4039    ,   6749    ,0 };
            const std::uint32_t dim3671KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   3   ,   27  ,   69  ,   227 ,   503 ,   915 ,   569 ,   115 ,   4299    ,   10799   ,   13745   ,   7973    ,0 };
            const std::uint32_t dim3672KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   17  ,   49  ,   33  ,   161 ,   429 ,   153 ,   1179    ,   4005    ,   6507    ,   10507   ,   1779    ,   5331    ,0 };
            const std::uint32_t dim3673KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   25  ,   45  ,   117 ,   47  ,   253 ,   851 ,   627 ,   593 ,   7555    ,   3677    ,   30695   ,   38851   ,0 };
            const std::uint32_t dim3674KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   25  ,   19  ,   95  ,   191 ,   505 ,   683 ,   67  ,   2375    ,   995 ,   8647    ,   4853    ,   17483   ,0 };
            const std::uint32_t dim3675KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   7   ,   57  ,   101 ,   151 ,   477 ,   343 ,   879 ,   2161    ,   1585    ,   1903    ,   6459    ,   45285   ,0 };
            const std::uint32_t dim3676KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   7   ,   7   ,   31  ,   219 ,   137 ,   107 ,   119 ,   2959    ,   7453    ,   9215    ,   20463   ,   61165   ,0 };
            const std::uint32_t dim3677KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   25  ,   39  ,   41  ,   165 ,   421 ,   567 ,   1095    ,   4055    ,   7321    ,   831 ,   81  ,   50377   ,0 };
            const std::uint32_t dim3678KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   21  ,   23  ,   65  ,   31  ,   331 ,   875 ,   1449    ,   653 ,   1975    ,   783 ,   29021   ,   47225   ,0 };
            const std::uint32_t dim3679KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   21  ,   21  ,   39  ,   39  ,   289 ,   129 ,   345 ,   2983    ,   2419    ,   133 ,   2519    ,   33307   ,0 };
            const std::uint32_t dim3680KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   27  ,   23  ,   53  ,   63  ,   315 ,   93  ,   335 ,   3239    ,   6749    ,   12985   ,   5863    ,   49565   ,0 };
            const std::uint32_t dim3681KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   17  ,   23  ,   89  ,   253 ,   329 ,   837 ,   589 ,   1135    ,   4099    ,   3123    ,   25567   ,   21017   ,0 };
            const std::uint32_t dim3682KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   21  ,   17  ,   111 ,   21  ,   73  ,   901 ,   2017    ,   3711    ,   159 ,   6703    ,   32209   ,   34411   ,0 };
            const std::uint32_t dim3683KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   19  ,   59  ,   1   ,   31  ,   273 ,   683 ,   1155    ,   2543    ,   477 ,   8479    ,   25235   ,   61595   ,0 };
            const std::uint32_t dim3684KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   13  ,   17  ,   97  ,   49  ,   221 ,   63  ,   197 ,   465 ,   1801    ,   5389    ,   10395   ,   54157   ,0 };
            const std::uint32_t dim3685KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   11  ,   59  ,   79  ,   139 ,   249 ,   185 ,   1131    ,   507 ,   3325    ,   2713    ,   27293   ,   21539   ,0 };
            const std::uint32_t dim3686KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   9   ,   45  ,   103 ,   145 ,   327 ,   675 ,   1609    ,   1703    ,   761 ,   4947    ,   187 ,   53903   ,0 };
            const std::uint32_t dim3687KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   19  ,   13  ,   77  ,   143 ,   303 ,   119 ,   1985    ,   1347    ,   6661    ,   6081    ,   9723    ,   52129   ,0 };
            const std::uint32_t dim3688KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   27  ,   27  ,   15  ,   163 ,   139 ,   159 ,   1921    ,   3549    ,   6477    ,   11423   ,   16055   ,   32399   ,0 };
            const std::uint32_t dim3689KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   19  ,   59  ,   5   ,   73  ,   481 ,   945 ,   187 ,   1223    ,   1771    ,   12961   ,   13853   ,   14513   ,0 };
            const std::uint32_t dim3690KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   5   ,   63  ,   33  ,   185 ,   477 ,   857 ,   1057    ,   2509    ,   7341    ,   7669    ,   13829   ,   51965   ,0 };
            const std::uint32_t dim3691KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   23  ,   17  ,   7   ,   87  ,   101 ,   817 ,   241 ,   853 ,   4067    ,   6409    ,   28217   ,   54395   ,0 };
            const std::uint32_t dim3692KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   21  ,   55  ,   47  ,   159 ,   407 ,   675 ,   1805    ,   2079    ,   1113    ,   149 ,   26071   ,   30829   ,0 };
            const std::uint32_t dim3693KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   7   ,   3   ,   89  ,   161 ,   95  ,   333 ,   525 ,   3979    ,   6831    ,   8007    ,   7063    ,   45299   ,0 };
            const std::uint32_t dim3694KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   17  ,   37  ,   95  ,   129 ,   215 ,   313 ,   1395    ,   2415    ,   6191    ,   6409    ,   29717   ,   4199    ,0 };
            const std::uint32_t dim3695KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   7   ,   45  ,   75  ,   175 ,   407 ,   763 ,   1037    ,   2477    ,   3167    ,   6991    ,   23905   ,   14707   ,0 };
            const std::uint32_t dim3696KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   23  ,   23  ,   103 ,   217 ,   479 ,   779 ,   941 ,   3173    ,   3639    ,   12833   ,   7133    ,   39269   ,0 };
            const std::uint32_t dim3697KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   9   ,   55  ,   19  ,   147 ,   287 ,   291 ,   1751    ,   2475    ,   6639    ,   5933    ,   27837   ,   33713   ,0 };
            const std::uint32_t dim3698KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   11  ,   39  ,   65  ,   109 ,   95  ,   637 ,   1897    ,   2395    ,   6975    ,   12431   ,   25097   ,   15649   ,0 };
            const std::uint32_t dim3699KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   25  ,   37  ,   27  ,   53  ,   373 ,   881 ,   1221    ,   2127    ,   1775    ,   2025    ,   10249   ,   55325   ,0 };
            const std::uint32_t dim3700KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   5   ,   37  ,   1   ,   99  ,   249 ,   209 ,   1177    ,   2953    ,   4455    ,   12125   ,   7679    ,   25543   ,0 };
            const std::uint32_t dim3701KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   9   ,   19  ,   97  ,   11  ,   331 ,   107 ,   1475    ,   769 ,   1749    ,   9375    ,   19477   ,   47559   ,0 };
            const std::uint32_t dim3702KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   25  ,   57  ,   69  ,   45  ,   21  ,   455 ,   1841    ,   1101    ,   2931    ,   2845    ,   21925   ,   43731   ,0 };
            const std::uint32_t dim3703KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   27  ,   33  ,   31  ,   33  ,   9   ,   825 ,   883 ,   2259    ,   7317    ,   5507    ,   3931    ,   61075   ,0 };
            const std::uint32_t dim3704KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   7   ,   21  ,   97  ,   203 ,   449 ,   671 ,   1037    ,   3985    ,   5655    ,   11099   ,   21981   ,   50149   ,0 };
            const std::uint32_t dim3705KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   5   ,   19  ,   109 ,   247 ,   73  ,   981 ,   1981    ,   3613    ,   6575    ,   3493    ,   9553    ,   259 ,0 };
            const std::uint32_t dim3706KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   3   ,   55  ,   13  ,   175 ,   285 ,   865 ,   1817    ,   911 ,   6393    ,   4843    ,   31569   ,   30115   ,0 };
            const std::uint32_t dim3707KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   21  ,   51  ,   85  ,   239 ,   171 ,   741 ,   881 ,   749 ,   4021    ,   2049    ,   25495   ,   62913   ,0 };
            const std::uint32_t dim3708KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   19  ,   9   ,   111 ,   119 ,   171 ,   903 ,   567 ,   1513    ,   8179    ,   10553   ,   5315    ,   63291   ,0 };
            const std::uint32_t dim3709KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   1   ,   61  ,   21  ,   197 ,   165 ,   371 ,   3   ,   2085    ,   669 ,   4497    ,   27467   ,   52995   ,0 };
            const std::uint32_t dim3710KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   29  ,   37  ,   95  ,   247 ,   161 ,   621 ,   83  ,   2597    ,   6779    ,   13747   ,   18873   ,   6173    ,0 };
            const std::uint32_t dim3711KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   21  ,   5   ,   41  ,   137 ,   77  ,   829 ,   689 ,   563 ,   5331    ,   8061    ,   21371   ,   58565   ,0 };
            const std::uint32_t dim3712KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   1   ,   19  ,   11  ,   111 ,   35  ,   39  ,   1513    ,   1241    ,   3739    ,   16191   ,   25097   ,   25947   ,0 };
            const std::uint32_t dim3713KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   27  ,   45  ,   11  ,   29  ,   153 ,   321 ,   1657    ,   1419    ,   6983    ,   11935   ,   8295    ,   24313   ,0 };
            const std::uint32_t dim3714KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   1   ,   57  ,   109 ,   139 ,   53  ,   883 ,   81  ,   333 ,   5133    ,   13891   ,   7775    ,   13401   ,0 };
            const std::uint32_t dim3715KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   5   ,   35  ,   121 ,   15  ,   73  ,   313 ,   1903    ,   437 ,   1567    ,   11905   ,   7679    ,   14265   ,0 };
            const std::uint32_t dim3716KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   31  ,   63  ,   69  ,   135 ,   75  ,   489 ,   1271    ,   585 ,   7361    ,   15965   ,   3099    ,   37309   ,0 };
            const std::uint32_t dim3717KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   15  ,   21  ,   97  ,   73  ,   115 ,   795 ,   421 ,   69  ,   7795    ,   9895    ,   1755    ,   44375   ,0 };
            const std::uint32_t dim3718KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   17  ,   13  ,   49  ,   61  ,   395 ,   637 ,   1737    ,   3103    ,   5197    ,   7799    ,   25425   ,   56313   ,0 };
            const std::uint32_t dim3719KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   17  ,   19  ,   87  ,   131 ,   315 ,   865 ,   813 ,   163 ,   1045    ,   12573   ,   12657   ,   43715   ,0 };
            const std::uint32_t dim3720KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   27  ,   23  ,   9   ,   185 ,   291 ,   421 ,   603 ,   1339    ,   1085    ,   15449   ,   1543    ,   5815    ,0 };
            const std::uint32_t dim3721KuoInit[]        =   {   1   ,   3   ,   1   ,   5   ,   29  ,   35  ,   15  ,   75  ,   135 ,   911 ,   1153    ,   3067    ,   3475    ,   11653   ,   27485   ,   8459    ,0 };
            const std::uint32_t dim3722KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   3   ,   9   ,   43  ,   29  ,   77  ,   551 ,   973 ,   2165    ,   1499    ,   9185    ,   27025   ,   31605   ,0 };
            const std::uint32_t dim3723KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   23  ,   49  ,   13  ,   229 ,   295 ,   497 ,   187 ,   1995    ,   1883    ,   9109    ,   2689    ,   37275   ,0 };
            const std::uint32_t dim3724KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   11  ,   1   ,   61  ,   183 ,   129 ,   869 ,   1271    ,   3439    ,   7743    ,   5831    ,   12829   ,   1341    ,0 };
            const std::uint32_t dim3725KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   17  ,   45  ,   31  ,   29  ,   441 ,   533 ,   1479    ,   3519    ,   2083    ,   149 ,   22119   ,   37615   ,0 };
            const std::uint32_t dim3726KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   31  ,   39  ,   101 ,   209 ,   237 ,   211 ,   1015    ,   1339    ,   857 ,   3833    ,   16875   ,   38147   ,0 };
            const std::uint32_t dim3727KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   29  ,   23  ,   9   ,   79  ,   71  ,   363 ,   487 ,   595 ,   259 ,   12425   ,   28181   ,   20717   ,0 };
            const std::uint32_t dim3728KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   1   ,   21  ,   97  ,   39  ,   101 ,   1   ,   121 ,   3083    ,   109 ,   7889    ,   29005   ,   57081   ,0 };
            const std::uint32_t dim3729KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   19  ,   19  ,   91  ,   17  ,   281 ,   121 ,   1653    ,   3099    ,   181 ,   15911   ,   29553   ,   10047   ,0 };
            const std::uint32_t dim3730KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   27  ,   39  ,   69  ,   57  ,   25  ,   595 ,   723 ,   1779    ,   7537    ,   9397    ,   5563    ,   8197    ,0 };
            const std::uint32_t dim3731KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   11  ,   61  ,   127 ,   81  ,   439 ,   723 ,   1147    ,   3639    ,   1207    ,   5127    ,   10209   ,   33629   ,0 };
            const std::uint32_t dim3732KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   27  ,   55  ,   69  ,   147 ,   477 ,   663 ,   833 ,   3113    ,   2585    ,   9497    ,   679 ,   62759   ,0 };
            const std::uint32_t dim3733KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   9   ,   51  ,   67  ,   191 ,   105 ,   3   ,   1439    ,   1915    ,   3059    ,   3001    ,   4035    ,   551 ,0 };
            const std::uint32_t dim3734KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   1   ,   3   ,   11  ,   171 ,   189 ,   659 ,   1279    ,   3995    ,   6729    ,   6187    ,   22213   ,   22709   ,0 };
            const std::uint32_t dim3735KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   27  ,   31  ,   3   ,   183 ,   209 ,   931 ,   99  ,   1901    ,   113 ,   15779   ,   11525   ,   29949   ,0 };
            const std::uint32_t dim3736KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   11  ,   51  ,   1   ,   173 ,   271 ,   785 ,   1875    ,   2115    ,   1977    ,   189 ,   7819    ,   8133    ,0 };
            const std::uint32_t dim3737KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   21  ,   9   ,   5   ,   253 ,   495 ,   415 ,   3   ,   1979    ,   2331    ,   12229   ,   29901   ,   7115    ,0 };
            const std::uint32_t dim3738KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   21  ,   11  ,   105 ,   81  ,   269 ,   347 ,   901 ,   81  ,   7077    ,   11813   ,   18739   ,   57959   ,0 };
            const std::uint32_t dim3739KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   19  ,   57  ,   17  ,   87  ,   325 ,   129 ,   1907    ,   1641    ,   6247    ,   12073   ,   31629   ,   28503   ,0 };
            const std::uint32_t dim3740KuoInit[]        =   {   1   ,   1   ,   5   ,   15  ,   29  ,   27  ,   81  ,   11  ,   383 ,   881 ,   1385    ,   3787    ,   503 ,   1369    ,   25031   ,   42049   ,0 };
            const std::uint32_t dim3741KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   27  ,   15  ,   13  ,   13  ,   279 ,   785 ,   163 ,   1907    ,   4523    ,   12133   ,   1497    ,   18845   ,0 };
            const std::uint32_t dim3742KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   13  ,   37  ,   51  ,   83  ,   309 ,   645 ,   383 ,   1607    ,   2087    ,   14287   ,   14375   ,   39619   ,0 };
            const std::uint32_t dim3743KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   11  ,   13  ,   21  ,   45  ,   95  ,   667 ,   1597    ,   1823    ,   5887    ,   10909   ,   26279   ,   29845   ,0 };
            const std::uint32_t dim3744KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   25  ,   61  ,   21  ,   91  ,   81  ,   173 ,   1271    ,   339 ,   2185    ,   16033   ,   3687    ,   53797   ,0 };
            const std::uint32_t dim3745KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   19  ,   27  ,   59  ,   153 ,   453 ,   523 ,   85  ,   3367    ,   4439    ,   13605   ,   6219    ,   25593   ,0 };
            const std::uint32_t dim3746KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   27  ,   57  ,   127 ,   225 ,   199 ,   823 ,   431 ,   2911    ,   4421    ,   14063   ,   1467    ,   46787   ,0 };
            const std::uint32_t dim3747KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   31  ,   33  ,   17  ,   73  ,   357 ,   199 ,   677 ,   2015    ,   1213    ,   8503    ,   4785    ,   54835   ,0 };
            const std::uint32_t dim3748KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   15  ,   13  ,   65  ,   1   ,   311 ,   469 ,   1307    ,   2605    ,   5281    ,   15665   ,   6349    ,   61753   ,0 };
            const std::uint32_t dim3749KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   19  ,   33  ,   49  ,   141 ,   229 ,   925 ,   1059    ,   1295    ,   3093    ,   6207    ,   7607    ,   63987   ,0 };
            const std::uint32_t dim3750KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   21  ,   63  ,   17  ,   131 ,   27  ,   295 ,   1969    ,   3259    ,   2011    ,   11005   ,   32249   ,   57641   ,0 };
            const std::uint32_t dim3751KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   25  ,   27  ,   11  ,   105 ,   99  ,   923 ,   1003    ,   2765    ,   49  ,   10367   ,   22119   ,   27199   ,0 };
            const std::uint32_t dim3752KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   31  ,   11  ,   57  ,   253 ,   31  ,   259 ,   1687    ,   1135    ,   1675    ,   12051   ,   3543    ,   19087   ,0 };
            const std::uint32_t dim3753KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   9   ,   53  ,   119 ,   215 ,   213 ,   67  ,   343 ,   2743    ,   7303    ,   14225   ,   13379   ,   51001   ,0 };
            const std::uint32_t dim3754KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   1   ,   45  ,   11  ,   125 ,   209 ,   459 ,   1037    ,   673 ,   2497    ,   669 ,   11251   ,   19387   ,0 };
            const std::uint32_t dim3755KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   21  ,   47  ,   63  ,   45  ,   349 ,   561 ,   1823    ,   2005    ,   4173    ,   5595    ,   3789    ,   34133   ,0 };
            const std::uint32_t dim3756KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   5   ,   7   ,   83  ,   63  ,   305 ,   679 ,   879 ,   3613    ,   7627    ,   9849    ,   3987    ,   28795   ,0 };
            const std::uint32_t dim3757KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   7   ,   51  ,   119 ,   1   ,   21  ,   213 ,   1399    ,   3715    ,   7775    ,   1003    ,   6749    ,   5547    ,0 };
            const std::uint32_t dim3758KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   21  ,   53  ,   51  ,   137 ,   379 ,   439 ,   1497    ,   3455    ,   2509    ,   2539    ,   3583    ,   5107    ,0 };
            const std::uint32_t dim3759KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   9   ,   13  ,   73  ,   237 ,   65  ,   53  ,   663 ,   3895    ,   7579    ,   10027   ,   23969   ,   34767   ,0 };
            const std::uint32_t dim3760KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   13  ,   57  ,   125 ,   245 ,   243 ,   561 ,   91  ,   863 ,   1925    ,   13553   ,   4113    ,   31077   ,0 };
            const std::uint32_t dim3761KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   9   ,   31  ,   9   ,   83  ,   355 ,   249 ,   1741    ,   3593    ,   425 ,   6377    ,   10607   ,   48275   ,0 };
            const std::uint32_t dim3762KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   19  ,   17  ,   123 ,   75  ,   413 ,   981 ,   877 ,   3489    ,   5907    ,   6141    ,   2729    ,   49219   ,0 };
            const std::uint32_t dim3763KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   31  ,   39  ,   97  ,   233 ,   99  ,   17  ,   105 ,   2911    ,   347 ,   4069    ,   32535   ,   47179   ,0 };
            const std::uint32_t dim3764KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   1   ,   51  ,   1   ,   59  ,   197 ,   487 ,   1763    ,   2449    ,   4249    ,   55  ,   11885   ,   57597   ,0 };
            const std::uint32_t dim3765KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   25  ,   49  ,   43  ,   101 ,   353 ,   759 ,   1295    ,   3441    ,   1521    ,   2879    ,   9815    ,   27091   ,0 };
            const std::uint32_t dim3766KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   1   ,   7   ,   69  ,   205 ,   271 ,   511 ,   1157    ,   3597    ,   2857    ,   10997   ,   15525   ,   6807    ,0 };
            const std::uint32_t dim3767KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   11  ,   1   ,   45  ,   213 ,   463 ,   389 ,   1761    ,   3005    ,   3359    ,   12829   ,   18211   ,   2107    ,0 };
            const std::uint32_t dim3768KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   27  ,   59  ,   115 ,   203 ,   321 ,   711 ,   1489    ,   2893    ,   1427    ,   4599    ,   17105   ,   10063   ,0 };
            const std::uint32_t dim3769KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   5   ,   5   ,   53  ,   221 ,   97  ,   535 ,   1967    ,   1951    ,   4077    ,   327 ,   18243   ,   43285   ,0 };
            const std::uint32_t dim3770KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   9   ,   61  ,   59  ,   255 ,   143 ,   21  ,   1859    ,   3509    ,   4295    ,   5107    ,   11117   ,   29431   ,0 };
            const std::uint32_t dim3771KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   19  ,   13  ,   33  ,   169 ,   17  ,   773 ,   1693    ,   147 ,   5143    ,   2357    ,   2295    ,   50187   ,0 };
            const std::uint32_t dim3772KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   11  ,   19  ,   79  ,   151 ,   441 ,   825 ,   665 ,   2947    ,   5391    ,   8695    ,   155 ,   26751   ,0 };
            const std::uint32_t dim3773KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   13  ,   31  ,   77  ,   61  ,   249 ,   341 ,   1737    ,   3567    ,   6337    ,   14457   ,   3799    ,   20283   ,0 };
            const std::uint32_t dim3774KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   13  ,   5   ,   83  ,   59  ,   185 ,   325 ,   2029    ,   1329    ,   1125    ,   10799   ,   27107   ,   2817    ,0 };
            const std::uint32_t dim3775KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   17  ,   43  ,   21  ,   113 ,   57  ,   503 ,   1647    ,   393 ,   4525    ,   8385    ,   27153   ,   37175   ,0 };
            const std::uint32_t dim3776KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   23  ,   57  ,   3   ,   177 ,   419 ,   65  ,   1895    ,   1107    ,   7705    ,   7915    ,   20677   ,   27931   ,0 };
            const std::uint32_t dim3777KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   13  ,   63  ,   53  ,   237 ,   237 ,   161 ,   265 ,   1053    ,   161 ,   11635   ,   1455    ,   55551   ,0 };
            const std::uint32_t dim3778KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   15  ,   41  ,   7   ,   77  ,   93  ,   737 ,   1195    ,   1381    ,   399 ,   7829    ,   6251    ,   34883   ,0 };
            const std::uint32_t dim3779KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   23  ,   63  ,   119 ,   35  ,   115 ,   829 ,   441 ,   4059    ,   4755    ,   11331   ,   18071   ,   6911    ,0 };
            const std::uint32_t dim3780KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   21  ,   33  ,   49  ,   47  ,   329 ,   341 ,   45  ,   3093    ,   5937    ,   6803    ,   31681   ,   9575    ,0 };
            const std::uint32_t dim3781KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   13  ,   19  ,   121 ,   71  ,   231 ,   915 ,   981 ,   93  ,   5879    ,   15645   ,   8555    ,   58411   ,0 };
            const std::uint32_t dim3782KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   31  ,   45  ,   71  ,   189 ,   337 ,   955 ,   1263    ,   2271    ,   1615    ,   15137   ,   29933   ,   16585   ,0 };
            const std::uint32_t dim3783KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   29  ,   49  ,   85  ,   255 ,   143 ,   585 ,   1099    ,   1159    ,   1519    ,   15593   ,   6177    ,   16083   ,0 };
            const std::uint32_t dim3784KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   13  ,   59  ,   79  ,   67  ,   341 ,   815 ,   703 ,   3857    ,   4711    ,   15155   ,   15997   ,   31699   ,0 };
            const std::uint32_t dim3785KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   11  ,   51  ,   77  ,   231 ,   241 ,   261 ,   1607    ,   4031    ,   3779    ,   4289    ,   22039   ,   47177   ,0 };
            const std::uint32_t dim3786KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   21  ,   23  ,   31  ,   233 ,   225 ,   883 ,   715 ,   777 ,   2433    ,   3665    ,   26695   ,   60997   ,0 };
            const std::uint32_t dim3787KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   27  ,   17  ,   55  ,   33  ,   133 ,   899 ,   1443    ,   283 ,   6839    ,   9497    ,   22399   ,   60527   ,0 };
            const std::uint32_t dim3788KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   5   ,   63  ,   91  ,   5   ,   275 ,   219 ,   1679    ,   2385    ,   4727    ,   9995    ,   14079   ,   24695   ,0 };
            const std::uint32_t dim3789KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   9   ,   3   ,   77  ,   215 ,   265 ,   317 ,   1655    ,   1027    ,   5029    ,   6867    ,   9465    ,   64257   ,0 };
            const std::uint32_t dim3790KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   23  ,   7   ,   67  ,   63  ,   503 ,   269 ,   85  ,   3669    ,   5941    ,   13833   ,   25857   ,   34221   ,0 };
            const std::uint32_t dim3791KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   13  ,   31  ,   83  ,   113 ,   389 ,   923 ,   1173    ,   2457    ,   997 ,   9761    ,   17033   ,   50521   ,0 };
            const std::uint32_t dim3792KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   15  ,   31  ,   93  ,   243 ,   221 ,   331 ,   1961    ,   3251    ,   6459    ,   3341    ,   28535   ,   27909   ,0 };
            const std::uint32_t dim3793KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   27  ,   1   ,   75  ,   169 ,   277 ,   921 ,   5   ,   1391    ,   5665    ,   14659   ,   6895    ,   37927   ,0 };
            const std::uint32_t dim3794KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   17  ,   63  ,   93  ,   35  ,   225 ,   109 ,   977 ,   2623    ,   3779    ,   8011    ,   11643   ,   57789   ,0 };
            const std::uint32_t dim3795KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   17  ,   5   ,   63  ,   109 ,   449 ,   695 ,   1021    ,   2749    ,   3981    ,   2073    ,   24537   ,   43643   ,0 };
            const std::uint32_t dim3796KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   1   ,   19  ,   15  ,   249 ,   3   ,   431 ,   743 ,   3813    ,   4013    ,   4027    ,   1943    ,   23569   ,0 };
            const std::uint32_t dim3797KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   9   ,   49  ,   93  ,   59  ,   425 ,   325 ,   1925    ,   495 ,   6611    ,   2425    ,   19847   ,   58683   ,0 };
            const std::uint32_t dim3798KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   7   ,   21  ,   71  ,   51  ,   335 ,   67  ,   373 ,   1805    ,   1805    ,   4069    ,   6585    ,   56579   ,0 };
            const std::uint32_t dim3799KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   25  ,   27  ,   49  ,   131 ,   491 ,   105 ,   1467    ,   665 ,   6777    ,   15467   ,   13597   ,   49141   ,0 };
            const std::uint32_t dim3800KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   9   ,   9   ,   37  ,   159 ,   19  ,   91  ,   1963    ,   3133    ,   5147    ,   8655    ,   11153   ,   44491   ,0 };
            const std::uint32_t dim3801KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   13  ,   55  ,   41  ,   67  ,   155 ,   853 ,   1651    ,   3511    ,   4391    ,   6359    ,   9129    ,   32359   ,0 };
            const std::uint32_t dim3802KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   9   ,   3   ,   27  ,   101 ,   467 ,   185 ,   1071    ,   1477    ,   1523    ,   9535    ,   15433   ,   7493    ,0 };
            const std::uint32_t dim3803KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   15  ,   19  ,   3   ,   97  ,   241 ,   995 ,   451 ,   1651    ,   241 ,   1063    ,   2521    ,   65531   ,0 };
            const std::uint32_t dim3804KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   23  ,   13  ,   117 ,   65  ,   119 ,   871 ,   1245    ,   3577    ,   7303    ,   9433    ,   13701   ,   21321   ,0 };
            const std::uint32_t dim3805KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   25  ,   33  ,   121 ,   203 ,   325 ,   775 ,   1835    ,   1385    ,   2541    ,   3399    ,   275 ,   54311   ,0 };
            const std::uint32_t dim3806KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   13  ,   41  ,   5   ,   63  ,   415 ,   771 ,   375 ,   3933    ,   5239    ,   1731    ,   7675    ,   11855   ,0 };
            const std::uint32_t dim3807KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   23  ,   49  ,   27  ,   119 ,   231 ,   897 ,   1995    ,   3847    ,   25  ,   7505    ,   2823    ,   10115   ,0 };
            const std::uint32_t dim3808KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   5   ,   41  ,   41  ,   129 ,   339 ,   861 ,   147 ,   3299    ,   1123    ,   2175    ,   27111   ,   2067    ,0 };
            const std::uint32_t dim3809KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   5   ,   39  ,   71  ,   53  ,   483 ,   585 ,   1167    ,   2037    ,   3125    ,   499 ,   29491   ,   43467   ,0 };
            const std::uint32_t dim3810KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   25  ,   9   ,   85  ,   197 ,   271 ,   457 ,   1159    ,   3805    ,   2423    ,   11777   ,   4383    ,   57495   ,0 };
            const std::uint32_t dim3811KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   25  ,   5   ,   33  ,   255 ,   325 ,   643 ,   499 ,   3233    ,   4477    ,   14189   ,   12183   ,   7667    ,0 };
            const std::uint32_t dim3812KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   1   ,   63  ,   3   ,   51  ,   173 ,   1011    ,   1423    ,   3453    ,   2471    ,   7801    ,   29989   ,   8347    ,0 };
            const std::uint32_t dim3813KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   17  ,   39  ,   23  ,   13  ,   413 ,   503 ,   321 ,   3699    ,   6441    ,   11953   ,   24253   ,   2561    ,0 };
            const std::uint32_t dim3814KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   31  ,   45  ,   21  ,   215 ,   55  ,   555 ,   771 ,   2703    ,   8113    ,   3279    ,   6053    ,   48617   ,0 };
            const std::uint32_t dim3815KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   25  ,   25  ,   33  ,   101 ,   111 ,   643 ,   1277    ,   3833    ,   7431    ,   14395   ,   20849   ,   14455   ,0 };
            const std::uint32_t dim3816KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   21  ,   15  ,   95  ,   179 ,   437 ,   747 ,   1131    ,   83  ,   415 ,   12605   ,   29245   ,   28021   ,0 };
            const std::uint32_t dim3817KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   13  ,   59  ,   9   ,   217 ,   287 ,   929 ,   691 ,   3201    ,   4915    ,   3301    ,   15371   ,   17063   ,0 };
            const std::uint32_t dim3818KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   31  ,   3   ,   27  ,   229 ,   151 ,   321 ,   801 ,   1271    ,   1195    ,   11221   ,   16903   ,   27919   ,0 };
            const std::uint32_t dim3819KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   5   ,   41  ,   105 ,   133 ,   265 ,   167 ,   505 ,   3939    ,   771 ,   1291    ,   1109    ,   52601   ,0 };
            const std::uint32_t dim3820KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   21  ,   23  ,   23  ,   229 ,   197 ,   623 ,   1973    ,   901 ,   147 ,   15751   ,   29429   ,   13159   ,0 };
            const std::uint32_t dim3821KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   25  ,   53  ,   79  ,   123 ,   245 ,   939 ,   1889    ,   4073    ,   417 ,   13625   ,   14691   ,   56965   ,0 };
            const std::uint32_t dim3822KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   1   ,   39  ,   51  ,   231 ,   367 ,   233 ,   1453    ,   3095    ,   6071    ,   7521    ,   469 ,   8407    ,0 };
            const std::uint32_t dim3823KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   9   ,   17  ,   109 ,   135 ,   85  ,   151 ,   1217    ,   1643    ,   4455    ,   3923    ,   11681   ,   32807   ,0 };
            const std::uint32_t dim3824KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   11  ,   39  ,   27  ,   205 ,   85  ,   1019    ,   1759    ,   1705    ,   4585    ,   8311    ,   29123   ,   44045   ,0 };
            const std::uint32_t dim3825KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   9   ,   33  ,   65  ,   253 ,   319 ,   65  ,   851 ,   3357    ,   2827    ,   10107   ,   10197   ,   19111   ,0 };
            const std::uint32_t dim3826KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   3   ,   53  ,   67  ,   99  ,   501 ,   603 ,   1409    ,   359 ,   7395    ,   12827   ,   10867   ,   17473   ,0 };
            const std::uint32_t dim3827KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   5   ,   35  ,   97  ,   49  ,   365 ,   971 ,   1707    ,   1305    ,   6801    ,   14451   ,   32473   ,   57269   ,0 };
            const std::uint32_t dim3828KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   25  ,   57  ,   115 ,   195 ,   47  ,   923 ,   1515    ,   2043    ,   803 ,   6371    ,   25341   ,   63263   ,0 };
            const std::uint32_t dim3829KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   27  ,   53  ,   83  ,   91  ,   367 ,   695 ,   1809    ,   927 ,   6815    ,   1229    ,   27359   ,   28937   ,0 };
            const std::uint32_t dim3830KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   3   ,   3   ,   17  ,   203 ,   95  ,   577 ,   1531    ,   1645    ,   7271    ,   5541    ,   30905   ,   38825   ,0 };
            const std::uint32_t dim3831KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   7   ,   57  ,   97  ,   185 ,   75  ,   681 ,   1197    ,   3713    ,   6429    ,   4723    ,   26275   ,   23495   ,0 };
            const std::uint32_t dim3832KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   5   ,   25  ,   71  ,   171 ,   143 ,   603 ,   1349    ,   1723    ,   7493    ,   8417    ,   24171   ,   13421   ,0 };
            const std::uint32_t dim3833KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   23  ,   57  ,   33  ,   247 ,   409 ,   511 ,   29  ,   1403    ,   5831    ,   1749    ,   28441   ,   4117    ,0 };
            const std::uint32_t dim3834KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   31  ,   11  ,   105 ,   239 ,   431 ,   127 ,   343 ,   961 ,   6449    ,   1677    ,   24937   ,   15859   ,0 };
            const std::uint32_t dim3835KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   27  ,   57  ,   61  ,   245 ,   425 ,   417 ,   301 ,   521 ,   2425    ,   2547    ,   11349   ,   47931   ,0 };
            const std::uint32_t dim3836KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   15  ,   19  ,   19  ,   127 ,   151 ,   913 ,   1061    ,   1795    ,   2519    ,   6297    ,   2519    ,   56677   ,0 };
            const std::uint32_t dim3837KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   25  ,   3   ,   67  ,   53  ,   305 ,   609 ,   1067    ,   1003    ,   6933    ,   14009   ,   24475   ,   23183   ,0 };
            const std::uint32_t dim3838KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   21  ,   35  ,   89  ,   95  ,   399 ,   341 ,   1337    ,   2815    ,   3605    ,   3209    ,   9881    ,   6399    ,0 };
            const std::uint32_t dim3839KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   29  ,   63  ,   23  ,   219 ,   145 ,   583 ,   985 ,   2577    ,   3951    ,   15199   ,   26981   ,   2755    ,0 };
            const std::uint32_t dim3840KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   13  ,   45  ,   105 ,   139 ,   103 ,   83  ,   819 ,   2655    ,   39  ,   11661   ,   11057   ,   38189   ,0 };
            const std::uint32_t dim3841KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   23  ,   41  ,   79  ,   237 ,   353 ,   67  ,   1551    ,   2345    ,   1169    ,   4623    ,   1391    ,   18607   ,0 };
            const std::uint32_t dim3842KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   29  ,   31  ,   43  ,   65  ,   25  ,   387 ,   1109    ,   2515    ,   3967    ,   2221    ,   27321   ,   20511   ,0 };
            const std::uint32_t dim3843KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   17  ,   45  ,   35  ,   211 ,   31  ,   45  ,   1791    ,   2225    ,   6995    ,   15241   ,   24555   ,   45993   ,0 };
            const std::uint32_t dim3844KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   31  ,   25  ,   71  ,   57  ,   87  ,   531 ,   117 ,   267 ,   2415    ,   2213    ,   603 ,   23369   ,0 };
            const std::uint32_t dim3845KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   23  ,   53  ,   39  ,   3   ,   93  ,   697 ,   25  ,   465 ,   1517    ,   6061    ,   11759   ,   34863   ,0 };
            const std::uint32_t dim3846KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   29  ,   29  ,   41  ,   27  ,   499 ,   285 ,   355 ,   3915    ,   1683    ,   11933   ,   24685   ,   59013   ,0 };
            const std::uint32_t dim3847KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   21  ,   21  ,   25  ,   251 ,   109 ,   469 ,   1841    ,   889 ,   6541    ,   12961   ,   9449    ,   48755   ,0 };
            const std::uint32_t dim3848KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   21  ,   59  ,   41  ,   159 ,   159 ,   105 ,   999 ,   2535    ,   3251    ,   12213   ,   24005   ,   17145   ,0 };
            const std::uint32_t dim3849KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   1   ,   39  ,   43  ,   235 ,   447 ,   767 ,   871 ,   453 ,   7285    ,   3387    ,   14625   ,   40099   ,0 };
            const std::uint32_t dim3850KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   5   ,   11  ,   15  ,   205 ,   183 ,   309 ,   1747    ,   1089    ,   3141    ,   9129    ,   25149   ,   63109   ,0 };
            const std::uint32_t dim3851KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   23  ,   15  ,   7   ,   157 ,   45  ,   263 ,   1383    ,   735 ,   205 ,   16021   ,   13233   ,   23425   ,0 };
            const std::uint32_t dim3852KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   11  ,   31  ,   53  ,   23  ,   357 ,   953 ,   611 ,   2579    ,   475 ,   15183   ,   12755   ,   10347   ,0 };
            const std::uint32_t dim3853KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   7   ,   27  ,   41  ,   215 ,   247 ,   1001    ,   1369    ,   3105    ,   3195    ,   13417   ,   6967    ,   52501   ,0 };
            const std::uint32_t dim3854KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   3   ,   61  ,   35  ,   175 ,   415 ,   835 ,   1381    ,   3951    ,   6857    ,   10273   ,   26657   ,   5239    ,0 };
            const std::uint32_t dim3855KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   1   ,   27  ,   3   ,   251 ,   499 ,   637 ,   1101    ,   3817    ,   4823    ,   3065    ,   29919   ,   4151    ,0 };
            const std::uint32_t dim3856KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   19  ,   39  ,   1   ,   141 ,   353 ,   853 ,   295 ,   1201    ,   6895    ,   3965    ,   6417    ,   47379   ,0 };
            const std::uint32_t dim3857KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   11  ,   9   ,   99  ,   225 ,   161 ,   349 ,   421 ,   2803    ,   4461    ,   2319    ,   2495    ,   62429   ,0 };
            const std::uint32_t dim3858KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   31  ,   1   ,   47  ,   115 ,   299 ,   331 ,   1917    ,   2547    ,   969 ,   4841    ,   8237    ,   2405    ,0 };
            const std::uint32_t dim3859KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   9   ,   19  ,   77  ,   35  ,   225 ,   211 ,   1875    ,   3531    ,   2753    ,   12679   ,   6863    ,   42143   ,0 };
            const std::uint32_t dim3860KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   29  ,   25  ,   105 ,   19  ,   269 ,   863 ,   811 ,   2741    ,   143 ,   6353    ,   25109   ,   62251   ,0 };
            const std::uint32_t dim3861KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   27  ,   51  ,   11  ,   61  ,   245 ,   517 ,   891 ,   2081    ,   4523    ,   11703   ,   31477   ,   12113   ,0 };
            const std::uint32_t dim3862KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   27  ,   29  ,   25  ,   47  ,   143 ,   489 ,   1475    ,   1139    ,   1855    ,   8031    ,   21341   ,   23619   ,0 };
            const std::uint32_t dim3863KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   3   ,   45  ,   103 ,   59  ,   123 ,   831 ,   1883    ,   149 ,   5843    ,   10275   ,   3121    ,   21411   ,0 };
            const std::uint32_t dim3864KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   21  ,   11  ,   1   ,   35  ,   285 ,   501 ,   1407    ,   1307    ,   1371    ,   15057   ,   14091   ,   52279   ,0 };
            const std::uint32_t dim3865KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   3   ,   5   ,   9   ,   167 ,   139 ,   255 ,   1561    ,   2183    ,   1079    ,   2055    ,   24779   ,   19737   ,0 };
            const std::uint32_t dim3866KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   31  ,   29  ,   59  ,   157 ,   311 ,   447 ,   21  ,   2177    ,   3679    ,   7519    ,   987 ,   44221   ,0 };
            const std::uint32_t dim3867KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   11  ,   31  ,   95  ,   23  ,   457 ,   733 ,   1413    ,   273 ,   333 ,   14391   ,   16557   ,   35227   ,0 };
            const std::uint32_t dim3868KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   5   ,   3   ,   103 ,   59  ,   21  ,   475 ,   1455    ,   2995    ,   7651    ,   4893    ,   21739   ,   21379   ,0 };
            const std::uint32_t dim3869KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   9   ,   63  ,   55  ,   127 ,   283 ,   603 ,   1477    ,   331 ,   2115    ,   15965   ,   22433   ,   17311   ,0 };
            const std::uint32_t dim3870KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   5   ,   61  ,   105 ,   175 ,   245 ,   431 ,   479 ,   821 ,   3835    ,   3585    ,   16533   ,   63233   ,0 };
            const std::uint32_t dim3871KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   31  ,   57  ,   9   ,   11  ,   145 ,   519 ,   1915    ,   2809    ,   2943    ,   13885   ,   31223   ,   32897   ,0 };
            const std::uint32_t dim3872KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   5   ,   39  ,   67  ,   179 ,   285 ,   91  ,   1429    ,   3571    ,   1925    ,   9737    ,   28647   ,   8189    ,0 };
            const std::uint32_t dim3873KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   21  ,   25  ,   51  ,   173 ,   151 ,   283 ,   765 ,   2717    ,   3541    ,   10317   ,   9827    ,   24445   ,0 };
            const std::uint32_t dim3874KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   31  ,   25  ,   121 ,   71  ,   347 ,   129 ,   159 ,   1845    ,   475 ,   12777   ,   19607   ,   7163    ,0 };
            const std::uint32_t dim3875KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   29  ,   37  ,   59  ,   117 ,   375 ,   411 ,   1031    ,   3781    ,   3119    ,   6851    ,   30759   ,   46181   ,0 };
            const std::uint32_t dim3876KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   5   ,   41  ,   81  ,   141 ,   377 ,   817 ,   1007    ,   2211    ,   7303    ,   5833    ,   6117    ,   52265   ,0 };
            const std::uint32_t dim3877KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   7   ,   63  ,   83  ,   181 ,   169 ,   19  ,   1589    ,   3793    ,   7003    ,   12145   ,   25625   ,   35731   ,0 };
            const std::uint32_t dim3878KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   21  ,   39  ,   15  ,   225 ,   231 ,   497 ,   917 ,   559 ,   6515    ,   13637   ,   17721   ,   4725    ,0 };
            const std::uint32_t dim3879KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   17  ,   19  ,   93  ,   65  ,   281 ,   775 ,   613 ,   2453    ,   1969    ,   2499    ,   5373    ,   28207   ,0 };
            const std::uint32_t dim3880KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   9   ,   37  ,   103 ,   211 ,   357 ,   409 ,   457 ,   1527    ,   3289    ,   14293   ,   7681    ,   58069   ,0 };
            const std::uint32_t dim3881KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   1   ,   29  ,   83  ,   1   ,   35  ,   655 ,   491 ,   1447    ,   725 ,   7807    ,   13311   ,   345 ,0 };
            const std::uint32_t dim3882KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   19  ,   59  ,   103 ,   243 ,   157 ,   209 ,   399 ,   1113    ,   1595    ,   15075   ,   22475   ,   42835   ,0 };
            const std::uint32_t dim3883KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   27  ,   53  ,   69  ,   73  ,   413 ,   443 ,   559 ,   427 ,   2841    ,   13107   ,   8909    ,   35265   ,0 };
            const std::uint32_t dim3884KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   21  ,   39  ,   99  ,   75  ,   341 ,   917 ,   11  ,   1247    ,   247 ,   14285   ,   24531   ,   58523   ,0 };
            const std::uint32_t dim3885KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   29  ,   1   ,   55  ,   143 ,   363 ,   527 ,   103 ,   3735    ,   6373    ,   7837    ,   24451   ,   36999   ,0 };
            const std::uint32_t dim3886KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   3   ,   51  ,   71  ,   103 ,   173 ,   397 ,   1683    ,   489 ,   6515    ,   2531    ,   12517   ,   63165   ,0 };
            const std::uint32_t dim3887KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   27  ,   15  ,   31  ,   63  ,   323 ,   903 ,   1025    ,   2761    ,   1813    ,   2839    ,   2065    ,   20013   ,0 };
            const std::uint32_t dim3888KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   19  ,   37  ,   49  ,   207 ,   57  ,   45  ,   1517    ,   2715    ,   6315    ,   10499   ,   27195   ,   56175   ,0 };
            const std::uint32_t dim3889KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   13  ,   47  ,   91  ,   81  ,   459 ,   801 ,   1111    ,   3023    ,   5901    ,   12735   ,   14233   ,   24383   ,0 };
            const std::uint32_t dim3890KuoInit[]        =   {   1   ,   3   ,   1   ,   5   ,   19  ,   39  ,   11  ,   69  ,   333 ,   17  ,   1339    ,   2991    ,   4411    ,   2749    ,   15423   ,   13805   ,0 };
            const std::uint32_t dim3891KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   19  ,   3   ,   109 ,   45  ,   461 ,   103 ,   811 ,   3089    ,   893 ,   16121   ,   1337    ,   31929   ,0 };
            const std::uint32_t dim3892KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   3   ,   21  ,   125 ,   241 ,   355 ,   519 ,   1551    ,   3273    ,   2413    ,   3371    ,   11435   ,   2277    ,0 };
            const std::uint32_t dim3893KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   7   ,   21  ,   93  ,   79  ,   25  ,   265 ,   1045    ,   2011    ,   4883    ,   8631    ,   22461   ,   31117   ,0 };
            const std::uint32_t dim3894KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   13  ,   35  ,   61  ,   203 ,   371 ,   185 ,   1445    ,   2017    ,   363 ,   13603   ,   23097   ,   22617   ,0 };
            const std::uint32_t dim3895KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   29  ,   33  ,   9   ,   139 ,   73  ,   119 ,   755 ,   2117    ,   3949    ,   3403    ,   30007   ,   58147   ,0 };
            const std::uint32_t dim3896KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   9   ,   29  ,   85  ,   1   ,   349 ,   573 ,   1191    ,   133 ,   235 ,   1557    ,   18147   ,   5839    ,0 };
            const std::uint32_t dim3897KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   15  ,   45  ,   5   ,   95  ,   359 ,   223 ,   37  ,   547 ,   3407    ,   4927    ,   32417   ,   49205   ,0 };
            const std::uint32_t dim3898KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   21  ,   57  ,   127 ,   95  ,   355 ,   903 ,   1555    ,   9   ,   1249    ,   2463    ,   7921    ,   20633   ,0 };
            const std::uint32_t dim3899KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   29  ,   35  ,   95  ,   237 ,   43  ,   289 ,   1547    ,   3951    ,   5489    ,   2699    ,   347 ,   14405   ,0 };
            const std::uint32_t dim3900KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   11  ,   23  ,   33  ,   171 ,   37  ,   989 ,   917 ,   139 ,   5497    ,   617 ,   25555   ,   27031   ,0 };
            const std::uint32_t dim3901KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   21  ,   55  ,   63  ,   191 ,   93  ,   207 ,   1799    ,   2143    ,   4147    ,   6853    ,   18129   ,   18287   ,0 };
            const std::uint32_t dim3902KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   23  ,   39  ,   59  ,   131 ,   51  ,   113 ,   941 ,   2599    ,   5593    ,   11311   ,   30561   ,   22307   ,0 };
            const std::uint32_t dim3903KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   21  ,   49  ,   93  ,   5   ,   399 ,   173 ,   1017    ,   3551    ,   937 ,   13653   ,   21411   ,   56835   ,0 };
            const std::uint32_t dim3904KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   15  ,   47  ,   57  ,   19  ,   93  ,   931 ,   1803    ,   2947    ,   1291    ,   10979   ,   22069   ,   47485   ,0 };
            const std::uint32_t dim3905KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   31  ,   19  ,   75  ,   195 ,   23  ,   235 ,   137 ,   2521    ,   4109    ,   233 ,   26961   ,   19185   ,0 };
            const std::uint32_t dim3906KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   9   ,   17  ,   87  ,   239 ,   233 ,   939 ,   1643    ,   1189    ,   7875    ,   5199    ,   26603   ,   52223   ,0 };
            const std::uint32_t dim3907KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   3   ,   31  ,   21  ,   255 ,   41  ,   95  ,   1267    ,   1873    ,   5535    ,   8419    ,   19791   ,   14811   ,0 };
            const std::uint32_t dim3908KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   7   ,   51  ,   27  ,   35  ,   17  ,   1015    ,   661 ,   2679    ,   1269    ,   15729   ,   17329   ,   33555   ,0 };
            const std::uint32_t dim3909KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   13  ,   19  ,   39  ,   105 ,   173 ,   255 ,   1873    ,   1527    ,   253 ,   3517    ,   19867   ,   56765   ,0 };
            const std::uint32_t dim3910KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   15  ,   13  ,   85  ,   27  ,   491 ,   827 ,   1151    ,   3591    ,   7819    ,   10085   ,   11307   ,   45059   ,0 };
            const std::uint32_t dim3911KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   21  ,   17  ,   23  ,   207 ,   223 ,   721 ,   655 ,   243 ,   4289    ,   4973    ,   29709   ,   9203    ,0 };
            const std::uint32_t dim3912KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   27  ,   51  ,   3   ,   199 ,   277 ,   121 ,   1637    ,   3973    ,   861 ,   7215    ,   32577   ,   4391    ,0 };
            const std::uint32_t dim3913KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   21  ,   27  ,   33  ,   199 ,   29  ,   917 ,   99  ,   2755    ,   821 ,   16003   ,   8325    ,   55587   ,0 };
            const std::uint32_t dim3914KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   19  ,   17  ,   61  ,   39  ,   377 ,   739 ,   13  ,   3435    ,   5081    ,   10591   ,   11957   ,   30049   ,0 };
            const std::uint32_t dim3915KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   25  ,   13  ,   117 ,   5   ,   479 ,   579 ,   907 ,   3135    ,   1011    ,   3389    ,   135 ,   41711   ,0 };
            const std::uint32_t dim3916KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   19  ,   15  ,   89  ,   169 ,   321 ,   981 ,   365 ,   333 ,   4913    ,   9577    ,   13835   ,   23439   ,0 };
            const std::uint32_t dim3917KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   31  ,   27  ,   103 ,   25  ,   129 ,   207 ,   259 ,   2033    ,   7931    ,   8357    ,   17451   ,   60583   ,0 };
            const std::uint32_t dim3918KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   15  ,   47  ,   59  ,   151 ,   291 ,   669 ,   663 ,   111 ,   4809    ,   14179   ,   22313   ,   51969   ,0 };
            const std::uint32_t dim3919KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   1   ,   5   ,   87  ,   25  ,   179 ,   641 ,   1133    ,   629 ,   2281    ,   6213    ,   14281   ,   54147   ,0 };
            const std::uint32_t dim3920KuoInit[]        =   {   1   ,   1   ,   5   ,   15  ,   29  ,   33  ,   89  ,   63  ,   331 ,   379 ,   453 ,   1903    ,   7319    ,   15063   ,   31383   ,   23099   ,0 };
            const std::uint32_t dim3921KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   23  ,   7   ,   13  ,   71  ,   367 ,   53  ,   983 ,   3615    ,   5601    ,   2569    ,   18173   ,   40563   ,0 };
            const std::uint32_t dim3922KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   23  ,   41  ,   35  ,   215 ,   401 ,   807 ,   1809    ,   3919    ,   5651    ,   1249    ,   9699    ,   14275   ,0 };
            const std::uint32_t dim3923KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   15  ,   55  ,   7   ,   235 ,   171 ,   911 ,   1351    ,   2863    ,   5735    ,   8577    ,   7489    ,   42047   ,0 };
            const std::uint32_t dim3924KuoInit[]        =   {   1   ,   3   ,   1   ,   5   ,   29  ,   35  ,   11  ,   211 ,   133 ,   507 ,   1127    ,   2443    ,   7895    ,   10519   ,   13035   ,   26165   ,0 };
            const std::uint32_t dim3925KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   21  ,   39  ,   107 ,   55  ,   235 ,   409 ,   39  ,   1681    ,   2699    ,   3143    ,   847 ,   35635   ,0 };
            const std::uint32_t dim3926KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   27  ,   57  ,   79  ,   173 ,   273 ,   919 ,   1917    ,   4005    ,   1299    ,   14743   ,   24093   ,   64047   ,0 };
            const std::uint32_t dim3927KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   13  ,   53  ,   45  ,   195 ,   39  ,   379 ,   1699    ,   2401    ,   7131    ,   7205    ,   24419   ,   32161   ,0 };
            const std::uint32_t dim3928KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   31  ,   31  ,   35  ,   199 ,   421 ,   367 ,   1517    ,   1559    ,   3627    ,   10281   ,   27963   ,   31115   ,0 };
            const std::uint32_t dim3929KuoInit[]        =   {   1   ,   1   ,   5   ,   15  ,   5   ,   59  ,   89  ,   195 ,   263 ,   853 ,   1043    ,   3699    ,   2543    ,   9893    ,   727 ,   62533   ,0 };
            const std::uint32_t dim3930KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   29  ,   49  ,   101 ,   219 ,   135 ,   643 ,   321 ,   83  ,   1651    ,   2347    ,   1519    ,   21683   ,0 };
            const std::uint32_t dim3931KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   11  ,   17  ,   3   ,   75  ,   255 ,   359 ,   1231    ,   2333    ,   6745    ,   2393    ,   4213    ,   7689    ,0 };
            const std::uint32_t dim3932KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   23  ,   27  ,   53  ,   51  ,   307 ,   87  ,   1409    ,   3555    ,   8139    ,   8597    ,   27357   ,   28489   ,0 };
            const std::uint32_t dim3933KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   29  ,   31  ,   53  ,   175 ,   245 ,   815 ,   461 ,   1681    ,   2255    ,   761 ,   18061   ,   13273   ,0 };
            const std::uint32_t dim3934KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   21  ,   41  ,   81  ,   243 ,   9   ,   973 ,   1411    ,   2327    ,   4575    ,   2659    ,   22903   ,   27605   ,0 };
            const std::uint32_t dim3935KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   1   ,   3   ,   91  ,   203 ,   149 ,   101 ,   1745    ,   1427    ,   4107    ,   11967   ,   13545   ,   19249   ,0 };
            const std::uint32_t dim3936KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   3   ,   13  ,   47  ,   13  ,   291 ,   813 ,   97  ,   2741    ,   2847    ,   2845    ,   6437    ,   1497    ,0 };
            const std::uint32_t dim3937KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   15  ,   7   ,   121 ,   173 ,   333 ,   977 ,   357 ,   3439    ,   8023    ,   8741    ,   205 ,   11447   ,0 };
            const std::uint32_t dim3938KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   17  ,   57  ,   79  ,   3   ,   455 ,   673 ,   1877    ,   2019    ,   4809    ,   10635   ,   19927   ,   38703   ,0 };
            const std::uint32_t dim3939KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   17  ,   23  ,   65  ,   157 ,   265 ,   177 ,   697 ,   3281    ,   409 ,   471 ,   113 ,   16349   ,0 };
            const std::uint32_t dim3940KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   19  ,   57  ,   125 ,   55  ,   343 ,   177 ,   621 ,   1827    ,   983 ,   2491    ,   10389   ,   49879   ,0 };
            const std::uint32_t dim3941KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   23  ,   21  ,   125 ,   13  ,   155 ,   459 ,   1677    ,   2585    ,   6703    ,   945 ,   5341    ,   54821   ,0 };
            const std::uint32_t dim3942KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   1   ,   59  ,   75  ,   137 ,   261 ,   563 ,   1145    ,   759 ,   2363    ,   12949   ,   16677   ,   43535   ,0 };
            const std::uint32_t dim3943KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   31  ,   13  ,   29  ,   59  ,   263 ,   879 ,   49  ,   1365    ,   4977    ,   6981    ,   32683   ,   25063   ,0 };
            const std::uint32_t dim3944KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   27  ,   63  ,   41  ,   101 ,   353 ,   611 ,   349 ,   1947    ,   6473    ,   3099    ,   28855   ,   27945   ,0 };
            const std::uint32_t dim3945KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   13  ,   49  ,   59  ,   5   ,   401 ,   679 ,   2045    ,   2267    ,   5879    ,   12809   ,   23767   ,   47855   ,0 };
            const std::uint32_t dim3946KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   17  ,   1   ,   25  ,   235 ,   67  ,   155 ,   629 ,   25  ,   2565    ,   12261   ,   28847   ,   19987   ,0 };
            const std::uint32_t dim3947KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   23  ,   39  ,   117 ,   147 ,   155 ,   797 ,   1487    ,   921 ,   1205    ,   9947    ,   14603   ,   21335   ,0 };
            const std::uint32_t dim3948KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   21  ,   45  ,   49  ,   175 ,   447 ,   303 ,   531 ,   2923    ,   3887    ,   16273   ,   5121    ,   38965   ,0 };
            const std::uint32_t dim3949KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   5   ,   21  ,   53  ,   201 ,   1   ,   207 ,   181 ,   1263    ,   833 ,   5435    ,   28363   ,   62913   ,0 };
            const std::uint32_t dim3950KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   11  ,   31  ,   1   ,   63  ,   343 ,   221 ,   23  ,   1315    ,   7639    ,   9983    ,   9167    ,   63489   ,0 };
            const std::uint32_t dim3951KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   21  ,   43  ,   7   ,   161 ,   471 ,   749 ,   1547    ,   1645    ,   1557    ,   9719    ,   14017   ,   43281   ,0 };
            const std::uint32_t dim3952KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   3   ,   23  ,   49  ,   29  ,   259 ,   367 ,   1929    ,   3925    ,   4197    ,   8353    ,   28995   ,   41225   ,0 };
            const std::uint32_t dim3953KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   5   ,   31  ,   33  ,   195 ,   33  ,   171 ,   1021    ,   127 ,   5275    ,   10751   ,   12483   ,   7097    ,0 };
            const std::uint32_t dim3954KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   19  ,   21  ,   3   ,   113 ,   217 ,   953 ,   419 ,   1689    ,   8011    ,   805 ,   20691   ,   39159   ,0 };
            const std::uint32_t dim3955KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   27  ,   35  ,   83  ,   173 ,   299 ,   687 ,   493 ,   3965    ,   5963    ,   1307    ,   16379   ,   34297   ,0 };
            const std::uint32_t dim3956KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   11  ,   63  ,   103 ,   199 ,   207 ,   25  ,   1471    ,   2047    ,   7271    ,   7735    ,   4313    ,   45205   ,0 };
            const std::uint32_t dim3957KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   9   ,   23  ,   33  ,   207 ,   213 ,   125 ,   1871    ,   2073    ,   53  ,   9953    ,   1327    ,   41943   ,0 };
            const std::uint32_t dim3958KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   19  ,   55  ,   3   ,   159 ,   147 ,   649 ,   1161    ,   2245    ,   4303    ,   9971    ,   29633   ,   56535   ,0 };
            const std::uint32_t dim3959KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   1   ,   1   ,   57  ,   101 ,   265 ,   859 ,   137 ,   763 ,   6657    ,   8659    ,   21037   ,   22757   ,0 };
            const std::uint32_t dim3960KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   11  ,   23  ,   39  ,   129 ,   49  ,   987 ,   2013    ,   4071    ,   1289    ,   6471    ,   6231    ,   23987   ,0 };
            const std::uint32_t dim3961KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   29  ,   7   ,   87  ,   253 ,   111 ,   55  ,   1719    ,   321 ,   3579    ,   4489    ,   28323   ,   35091   ,0 };
            const std::uint32_t dim3962KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   17  ,   1   ,   39  ,   73  ,   455 ,   31  ,   1215    ,   2683    ,   6193    ,   15725   ,   2737    ,   24927   ,0 };
            const std::uint32_t dim3963KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   15  ,   63  ,   69  ,   125 ,   127 ,   337 ,   129 ,   2667    ,   4723    ,   8489    ,   6129    ,   14973   ,0 };
            const std::uint32_t dim3964KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   21  ,   37  ,   109 ,   91  ,   499 ,   767 ,   1095    ,   2731    ,   6129    ,   2167    ,   21311   ,   43503   ,0 };
            const std::uint32_t dim3965KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   29  ,   11  ,   87  ,   101 ,   19  ,   699 ,   1601    ,   2341    ,   3623    ,   1799    ,   2253    ,   40705   ,0 };
            const std::uint32_t dim3966KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   27  ,   25  ,   111 ,   91  ,   49  ,   3   ,   13  ,   3851    ,   3735    ,   13387   ,   4501    ,   64303   ,0 };
            const std::uint32_t dim3967KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   21  ,   63  ,   7   ,   65  ,   241 ,   925 ,   705 ,   3745    ,   827 ,   7227    ,   1869    ,   60375   ,0 };
            const std::uint32_t dim3968KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   31  ,   45  ,   5   ,   51  ,   45  ,   595 ,   1069    ,   3139    ,   5843    ,   2581    ,   22573   ,   53297   ,0 };
            const std::uint32_t dim3969KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   5   ,   9   ,   89  ,   91  ,   349 ,   241 ,   369 ,   279 ,   617 ,   4479    ,   12761   ,   14473   ,0 };
            const std::uint32_t dim3970KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   13  ,   45  ,   91  ,   29  ,   219 ,   341 ,   1831    ,   1993    ,   3661    ,   1855    ,   7243    ,   3477    ,0 };
            const std::uint32_t dim3971KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   15  ,   17  ,   27  ,   123 ,   223 ,   127 ,   111 ,   2375    ,   3919    ,   7569    ,   4419    ,   24957   ,0 };
            const std::uint32_t dim3972KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   17  ,   1   ,   49  ,   111 ,   103 ,   67  ,   75  ,   3109    ,   1783    ,   13291   ,   5409    ,   33123   ,0 };
            const std::uint32_t dim3973KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   1   ,   51  ,   107 ,   89  ,   233 ,   51  ,   745 ,   2005    ,   5485    ,   7537    ,   13353   ,   34579   ,0 };
            const std::uint32_t dim3974KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   9   ,   3   ,   25  ,   95  ,   413 ,   461 ,   1597    ,   767 ,   3183    ,   10285   ,   10579   ,   26581   ,0 };
            const std::uint32_t dim3975KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   25  ,   3   ,   27  ,   93  ,   433 ,   59  ,   701 ,   1825    ,   6375    ,   6477    ,   6743    ,   42101   ,0 };
            const std::uint32_t dim3976KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   19  ,   45  ,   95  ,   207 ,   267 ,   623 ,   1523    ,   1541    ,   3955    ,   4681    ,   2365    ,   16661   ,0 };
            const std::uint32_t dim3977KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   19  ,   35  ,   83  ,   151 ,   159 ,   825 ,   205 ,   2215    ,   4767    ,   797 ,   12821   ,   14951   ,0 };
            const std::uint32_t dim3978KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   15  ,   5   ,   99  ,   141 ,   21  ,   537 ,   657 ,   2055    ,   1571    ,   12725   ,   4227    ,   21061   ,0 };
            const std::uint32_t dim3979KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   1   ,   39  ,   85  ,   229 ,   9   ,   721 ,   1117    ,   519 ,   1763    ,   13211   ,   32533   ,   41393   ,0 };
            const std::uint32_t dim3980KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   23  ,   11  ,   125 ,   59  ,   439 ,   887 ,   1273    ,   3707    ,   7737    ,   4115    ,   7013    ,   47453   ,0 };
            const std::uint32_t dim3981KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   9   ,   25  ,   53  ,   203 ,   9   ,   189 ,   471 ,   637 ,   5983    ,   1693    ,   8425    ,   52181   ,0 };
            const std::uint32_t dim3982KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   29  ,   61  ,   33  ,   87  ,   153 ,   625 ,   539 ,   3595    ,   3161    ,   3929    ,   22825   ,   50113   ,0 };
            const std::uint32_t dim3983KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   1   ,   31  ,   105 ,   169 ,   475 ,   631 ,   1511    ,   3687    ,   5321    ,   3859    ,   19329   ,   9571    ,0 };
            const std::uint32_t dim3984KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   9   ,   13  ,   111 ,   79  ,   245 ,   351 ,   69  ,   59  ,   5561    ,   4713    ,   22789   ,   14929   ,0 };
            const std::uint32_t dim3985KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   1   ,   55  ,   87  ,   147 ,   37  ,   587 ,   479 ,   3175    ,   5437    ,   12267   ,   7057    ,   57899   ,0 };
            const std::uint32_t dim3986KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   15  ,   55  ,   87  ,   53  ,   359 ,   491 ,   343 ,   621 ,   1055    ,   8697    ,   28993   ,   20473   ,0 };
            const std::uint32_t dim3987KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   13  ,   11  ,   63  ,   179 ,   293 ,   639 ,   809 ,   1365    ,   7043    ,   13269   ,   5423    ,   36465   ,0 };
            const std::uint32_t dim3988KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   31  ,   49  ,   27  ,   71  ,   187 ,   377 ,   283 ,   2407    ,   2987    ,   8565    ,   15159   ,   44501   ,0 };
            const std::uint32_t dim3989KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   27  ,   5   ,   79  ,   211 ,   315 ,   645 ,   951 ,   4025    ,   1647    ,   2893    ,   23829   ,   23941   ,0 };
            const std::uint32_t dim3990KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   15  ,   29  ,   81  ,   133 ,   345 ,   573 ,   1605    ,   2693    ,   5293    ,   13579   ,   21793   ,   30981   ,0 };
            const std::uint32_t dim3991KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   31  ,   19  ,   109 ,   141 ,   389 ,   473 ,   1359    ,   1695    ,   6761    ,   3701    ,   27583   ,   47907   ,0 };
            const std::uint32_t dim3992KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   7   ,   43  ,   51  ,   139 ,   81  ,   111 ,   417 ,   2627    ,   2297    ,   12493   ,   24401   ,   42525   ,0 };
            const std::uint32_t dim3993KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   21  ,   9   ,   65  ,   141 ,   119 ,   971 ,   589 ,   2635    ,   6365    ,   1925    ,   15853   ,   47123   ,0 };
            const std::uint32_t dim3994KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   25  ,   15  ,   93  ,   151 ,   443 ,   325 ,   457 ,   3779    ,   7669    ,   2063    ,   20005   ,   6513    ,0 };
            const std::uint32_t dim3995KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   7   ,   13  ,   127 ,   55  ,   183 ,   663 ,   437 ,   3475    ,   6391    ,   8423    ,   8473    ,   41971   ,0 };
            const std::uint32_t dim3996KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   7   ,   15  ,   113 ,   225 ,   259 ,   85  ,   945 ,   645 ,   5129    ,   3657    ,   931 ,   30429   ,0 };
            const std::uint32_t dim3997KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   9   ,   63  ,   23  ,   117 ,   205 ,   295 ,   1325    ,   1349    ,   5521    ,   9399    ,   7907    ,   26373   ,0 };
            const std::uint32_t dim3998KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   17  ,   23  ,   47  ,   75  ,   97  ,   35  ,   1363    ,   793 ,   2811    ,   3491    ,   18173   ,   8353    ,0 };
            const std::uint32_t dim3999KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   25  ,   27  ,   107 ,   9   ,   331 ,   1017    ,   615 ,   1123    ,   1303    ,   5705    ,   14013   ,   39207   ,0 };
            const std::uint32_t dim4000KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   3   ,   17  ,   101 ,   17  ,   461 ,   781 ,   345 ,   2687    ,   5867    ,   1367    ,   17245   ,   18929   ,0 };
            const std::uint32_t dim4001KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   3   ,   53  ,   55  ,   37  ,   257 ,   101 ,   195 ,   1193    ,   5419    ,   4243    ,   6079    ,   32461   ,0 };
            const std::uint32_t dim4002KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   29  ,   21  ,   51  ,   123 ,   145 ,   105 ,   639 ,   2389    ,   6985    ,   2519    ,   12351   ,   45859   ,0 };
            const std::uint32_t dim4003KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   31  ,   17  ,   75  ,   121 ,   11  ,   945 ,   1917    ,   601 ,   3765    ,   14215   ,   19075   ,   26317   ,0 };
            const std::uint32_t dim4004KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   21  ,   3   ,   57  ,   17  ,   97  ,   567 ,   839 ,   135 ,   2441    ,   4613    ,   10511   ,   21927   ,0 };
            const std::uint32_t dim4005KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   21  ,   27  ,   1   ,   109 ,   381 ,   241 ,   1701    ,   1255    ,   1469    ,   8415    ,   18789   ,   1769    ,0 };
            const std::uint32_t dim4006KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   11  ,   45  ,   77  ,   209 ,   55  ,   371 ,   1323    ,   2899    ,   7387    ,   10317   ,   32695   ,   52199   ,0 };
            const std::uint32_t dim4007KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   15  ,   59  ,   45  ,   97  ,   369 ,   247 ,   1621    ,   2037    ,   4569    ,   16043   ,   2225    ,   39055   ,0 };
            const std::uint32_t dim4008KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   21  ,   43  ,   85  ,   195 ,   99  ,   85  ,   1759    ,   547 ,   4371    ,   14467   ,   17551   ,   52185   ,0 };
            const std::uint32_t dim4009KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   17  ,   53  ,   79  ,   203 ,   49  ,   289 ,   1547    ,   1173    ,   1445    ,   11593   ,   29927   ,   63479   ,0 };
            const std::uint32_t dim4010KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   3   ,   61  ,   31  ,   71  ,   321 ,   923 ,   1337    ,   3465    ,   3305    ,   10841   ,   31921   ,   3057    ,0 };
            const std::uint32_t dim4011KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   31  ,   1   ,   39  ,   201 ,   57  ,   913 ,   1953    ,   193 ,   4185    ,   5895    ,   27027   ,   10889   ,0 };
            const std::uint32_t dim4012KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   7   ,   9   ,   89  ,   145 ,   445 ,   643 ,   279 ,   1983    ,   491 ,   11825   ,   1857    ,   11201   ,0 };
            const std::uint32_t dim4013KuoInit[]        =   {   1   ,   3   ,   1   ,   5   ,   9   ,   39  ,   21  ,   245 ,   403 ,   393 ,   779 ,   1419    ,   967 ,   14309   ,   6789    ,   54477   ,0 };
            const std::uint32_t dim4014KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   31  ,   21  ,   65  ,   211 ,   447 ,   263 ,   665 ,   3311    ,   405 ,   1775    ,   31121   ,   54025   ,0 };
            const std::uint32_t dim4015KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   13  ,   9   ,   95  ,   243 ,   139 ,   733 ,   813 ,   3855    ,   2731    ,   11651   ,   2175    ,   9655    ,0 };
            const std::uint32_t dim4016KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   21  ,   5   ,   5   ,   241 ,   415 ,   241 ,   1223    ,   3237    ,   2265    ,   3761    ,   26883   ,   37875   ,0 };
            const std::uint32_t dim4017KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   25  ,   45  ,   97  ,   73  ,   353 ,   393 ,   1217    ,   563 ,   5813    ,   2791    ,   16477   ,   4401    ,0 };
            const std::uint32_t dim4018KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   17  ,   61  ,   1   ,   247 ,   439 ,   1013    ,   501 ,   881 ,   353 ,   4689    ,   18733   ,   46731   ,0 };
            const std::uint32_t dim4019KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   11  ,   29  ,   87  ,   53  ,   461 ,   751 ,   1503    ,   2851    ,   2891    ,   15231   ,   1513    ,   12573   ,0 };
            const std::uint32_t dim4020KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   1   ,   13  ,   95  ,   239 ,   151 ,   159 ,   55  ,   1203    ,   1331    ,   10429   ,   19159   ,   18431   ,0 };
            const std::uint32_t dim4021KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   11  ,   43  ,   81  ,   133 ,   449 ,   523 ,   667 ,   2759    ,   6829    ,   15129   ,   19829   ,   31745   ,0 };
            const std::uint32_t dim4022KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   25  ,   43  ,   115 ,   171 ,   475 ,   553 ,   1615    ,   1421    ,   2363    ,   13091   ,   27505   ,   21247   ,0 };
            const std::uint32_t dim4023KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   1   ,   23  ,   15  ,   25  ,   205 ,   797 ,   1013    ,   1903    ,   1595    ,   16373   ,   29983   ,   23009   ,0 };
            const std::uint32_t dim4024KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   3   ,   27  ,   79  ,   179 ,   147 ,   905 ,   1893    ,   2459    ,   3063    ,   7447    ,   16293   ,   14331   ,0 };
            const std::uint32_t dim4025KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   19  ,   49  ,   41  ,   19  ,   97  ,   559 ,   1213    ,   847 ,   3715    ,   13963   ,   20273   ,   25565   ,0 };
            const std::uint32_t dim4026KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   27  ,   21  ,   75  ,   1   ,   157 ,   715 ,   41  ,   2383    ,   4609    ,   9875    ,   21509   ,   57199   ,0 };
            const std::uint32_t dim4027KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   5   ,   51  ,   93  ,   115 ,   495 ,   687 ,   1805    ,   1369    ,   1525    ,   15841   ,   8897    ,   21023   ,0 };
            const std::uint32_t dim4028KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   21  ,   41  ,   93  ,   107 ,   391 ,   567 ,   223 ,   2331    ,   6009    ,   9405    ,   13137   ,   54727   ,0 };
            const std::uint32_t dim4029KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   5   ,   59  ,   119 ,   165 ,   485 ,   765 ,   243 ,   2589    ,   4631    ,   4045    ,   26867   ,   55329   ,0 };
            const std::uint32_t dim4030KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   17  ,   45  ,   35  ,   219 ,   137 ,   315 ,   293 ,   1137    ,   6675    ,   10693   ,   17455   ,   35603   ,0 };
            const std::uint32_t dim4031KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   11  ,   43  ,   65  ,   205 ,   351 ,   155 ,   1371    ,   3069    ,   1345    ,   859 ,   21385   ,   25923   ,0 };
            const std::uint32_t dim4032KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   11  ,   21  ,   39  ,   195 ,   349 ,   333 ,   687 ,   1155    ,   1491    ,   10453   ,   17615   ,   64801   ,0 };
            const std::uint32_t dim4033KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   17  ,   45  ,   39  ,   137 ,   25  ,   105 ,   441 ,   2437    ,   7715    ,   8501    ,   3999    ,   15913   ,0 };
            const std::uint32_t dim4034KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   31  ,   21  ,   93  ,   31  ,   63  ,   635 ,   331 ,   149 ,   1683    ,   6183    ,   19333   ,   34947   ,0 };
            const std::uint32_t dim4035KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   23  ,   11  ,   15  ,   239 ,   365 ,   983 ,   389 ,   945 ,   1765    ,   6417    ,   4471    ,   41431   ,0 };
            const std::uint32_t dim4036KuoInit[]        =   {   1   ,   3   ,   1   ,   5   ,   5   ,   49  ,   49  ,   27  ,   417 ,   605 ,   1495    ,   4021    ,   1775    ,   3691    ,   21803   ,   60999   ,0 };
            const std::uint32_t dim4037KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   23  ,   21  ,   33  ,   205 ,   481 ,   105 ,   359 ,   1407    ,   4007    ,   35  ,   10789   ,   27721   ,0 };
            const std::uint32_t dim4038KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   5   ,   33  ,   51  ,   61  ,   29  ,   337 ,   1523    ,   955 ,   4923    ,   1977    ,   16505   ,   21249   ,0 };
            const std::uint32_t dim4039KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   17  ,   19  ,   39  ,   7   ,   443 ,   557 ,   611 ,   4037    ,   5873    ,   15161   ,   449 ,   41747   ,0 };
            const std::uint32_t dim4040KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   5   ,   53  ,   91  ,   227 ,   217 ,   689 ,   7   ,   775 ,   8139    ,   10997   ,   29539   ,   60185   ,0 };
            const std::uint32_t dim4041KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   7   ,   59  ,   117 ,   101 ,   145 ,   779 ,   1359    ,   3375    ,   2493    ,   13075   ,   11475   ,   49507   ,0 };
            const std::uint32_t dim4042KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   13  ,   31  ,   39  ,   219 ,   181 ,   203 ,   19  ,   659 ,   533 ,   2541    ,   7285    ,   29353   ,0 };
            const std::uint32_t dim4043KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   29  ,   33  ,   1   ,   125 ,   283 ,   61  ,   303 ,   1613    ,   4309    ,   1891    ,   7107    ,   25977   ,0 };
            const std::uint32_t dim4044KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   21  ,   59  ,   41  ,   63  ,   123 ,   715 ,   893 ,   3509    ,   6785    ,   11009   ,   17749   ,   18349   ,0 };
            const std::uint32_t dim4045KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   25  ,   23  ,   15  ,   1   ,   147 ,   709 ,   957 ,   1101    ,   2733    ,   14069   ,   18905   ,   12467   ,0 };
            const std::uint32_t dim4046KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   9   ,   63  ,   109 ,   39  ,   123 ,   919 ,   427 ,   435 ,   5241    ,   14169   ,   31179   ,   15887   ,0 };
            const std::uint32_t dim4047KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   13  ,   25  ,   29  ,   187 ,   433 ,   633 ,   1203    ,   113 ,   4577    ,   13349   ,   18407   ,   62825   ,0 };
            const std::uint32_t dim4048KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   15  ,   33  ,   53  ,   209 ,   415 ,   711 ,   1543    ,   1529    ,   4991    ,   9545    ,   19655   ,   40427   ,0 };
            const std::uint32_t dim4049KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   23  ,   59  ,   27  ,   23  ,   7   ,   841 ,   1715    ,   43  ,   4987    ,   2073    ,   13765   ,   36105   ,0 };
            const std::uint32_t dim4050KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   31  ,   5   ,   51  ,   183 ,   319 ,   443 ,   621 ,   349 ,   2835    ,   10847   ,   19059   ,   51689   ,0 };
            const std::uint32_t dim4051KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   5   ,   3   ,   21  ,   81  ,   357 ,   609 ,   2019    ,   2613    ,   333 ,   5699    ,   2485    ,   52105   ,0 };
            const std::uint32_t dim4052KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   3   ,   11  ,   73  ,   121 ,   263 ,   833 ,   65  ,   347 ,   4821    ,   4631    ,   29929   ,   42157   ,0 };
            const std::uint32_t dim4053KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   1   ,   63  ,   7   ,   191 ,   47  ,   405 ,   43  ,   1499    ,   5539    ,   12607   ,   26095   ,   20759   ,0 };
            const std::uint32_t dim4054KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   15  ,   21  ,   109 ,   3   ,   15  ,   57  ,   1669    ,   4033    ,   5251    ,   4465    ,   28057   ,   64943   ,0 };
            const std::uint32_t dim4055KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   7   ,   61  ,   31  ,   17  ,   331 ,   671 ,   1955    ,   1035    ,   7183    ,   6559    ,   19299   ,   10225   ,0 };
            const std::uint32_t dim4056KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   31  ,   15  ,   97  ,   3   ,   361 ,   541 ,   323 ,   1463    ,   6867    ,   12717   ,   9593    ,   15407   ,0 };
            const std::uint32_t dim4057KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   29  ,   39  ,   71  ,   27  ,   305 ,   589 ,   1441    ,   2349    ,   185 ,   447 ,   24223   ,   53591   ,0 };
            const std::uint32_t dim4058KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   15  ,   59  ,   81  ,   77  ,   371 ,   891 ,   31  ,   457 ,   3073    ,   8427    ,   8225    ,   53157   ,0 };
            const std::uint32_t dim4059KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   23  ,   61  ,   71  ,   85  ,   39  ,   77  ,   1583    ,   933 ,   6147    ,   2271    ,   24761   ,   15835   ,0 };
            const std::uint32_t dim4060KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   25  ,   55  ,   41  ,   131 ,   275 ,   603 ,   43  ,   761 ,   5071    ,   14149   ,   4001    ,   6545    ,0 };
            const std::uint32_t dim4061KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   5   ,   1   ,   25  ,   217 ,   445 ,   197 ,   863 ,   3557    ,   585 ,   13599   ,   12329   ,   17331   ,0 };
            const std::uint32_t dim4062KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   9   ,   21  ,   21  ,   89  ,   121 ,   1017    ,   1559    ,   83  ,   5225    ,   13247   ,   12003   ,   10049   ,0 };
            const std::uint32_t dim4063KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   31  ,   15  ,   71  ,   45  ,   161 ,   895 ,   1431    ,   1277    ,   2547    ,   1943    ,   17631   ,   59133   ,0 };
            const std::uint32_t dim4064KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   11  ,   17  ,   29  ,   157 ,   355 ,   89  ,   401 ,   983 ,   8175    ,   11687   ,   20087   ,   7541    ,0 };
            const std::uint32_t dim4065KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   15  ,   45  ,   23  ,   141 ,   365 ,   593 ,   1137    ,   873 ,   2903    ,   8861    ,   25805   ,   22601   ,0 };
            const std::uint32_t dim4066KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   27  ,   17  ,   97  ,   3   ,   359 ,   531 ,   329 ,   437 ,   3483    ,   8653    ,   15953   ,   48333   ,0 };
            const std::uint32_t dim4067KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   9   ,   43  ,   79  ,   223 ,   149 ,   177 ,   1075    ,   545 ,   7235    ,   4271    ,   20153   ,   65481   ,0 };
            const std::uint32_t dim4068KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   5   ,   55  ,   29  ,   51  ,   497 ,   677 ,   167 ,   391 ,   1371    ,   8753    ,   23771   ,   48167   ,0 };
            const std::uint32_t dim4069KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   7   ,   17  ,   7   ,   227 ,   21  ,   521 ,   221 ,   3529    ,   5641    ,   4139    ,   14839   ,   49863   ,0 };
            const std::uint32_t dim4070KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   7   ,   41  ,   17  ,   151 ,   401 ,   407 ,   689 ,   507 ,   6683    ,   12515   ,   26895   ,   60863   ,0 };
            const std::uint32_t dim4071KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   3   ,   53  ,   27  ,   185 ,   119 ,   891 ,   2025    ,   607 ,   6961    ,   4263    ,   7795    ,   34157   ,0 };
            const std::uint32_t dim4072KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   25  ,   19  ,   15  ,   131 ,   323 ,   27  ,   1749    ,   2429    ,   2207    ,   9207    ,   18333   ,   25857   ,0 };
            const std::uint32_t dim4073KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   21  ,   57  ,   61  ,   93  ,   305 ,   497 ,   1465    ,   3639    ,   7695    ,   3903    ,   31201   ,   45699   ,0 };
            const std::uint32_t dim4074KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   25  ,   35  ,   93  ,   55  ,   415 ,   397 ,   1375    ,   809 ,   6205    ,   9761    ,   23129   ,   28757   ,0 };
            const std::uint32_t dim4075KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   13  ,   21  ,   1   ,   167 ,   65  ,   689 ,   525 ,   2839    ,   4069    ,   10123   ,   24403   ,   4121    ,0 };
            const std::uint32_t dim4076KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   11  ,   21  ,   67  ,   159 ,   131 ,   579 ,   1397    ,   251 ,   3933    ,   14737   ,   22047   ,   4173    ,0 };
            const std::uint32_t dim4077KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   9   ,   47  ,   71  ,   81  ,   141 ,   607 ,   1879    ,   3057    ,   6493    ,   1177    ,   27261   ,   59313   ,0 };
            const std::uint32_t dim4078KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   25  ,   45  ,   35  ,   193 ,   251 ,   223 ,   1725    ,   1533    ,   5799    ,   12417   ,   29765   ,   50203   ,0 };
            const std::uint32_t dim4079KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   27  ,   1   ,   41  ,   171 ,   293 ,   65  ,   607 ,   2843    ,   2955    ,   8783    ,   21249   ,   41695   ,0 };
            const std::uint32_t dim4080KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   3   ,   57  ,   39  ,   31  ,   507 ,   687 ,   2009    ,   2881    ,   4595    ,   9275    ,   9773    ,   31489   ,0 };
            const std::uint32_t dim4081KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   17  ,   11  ,   47  ,   233 ,   193 ,   395 ,   1879    ,   1983    ,   4811    ,   1221    ,   27279   ,   52089   ,0 };
            const std::uint32_t dim4082KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   13  ,   57  ,   51  ,   253 ,   381 ,   779 ,   897 ,   2893    ,   4373    ,   6599    ,   7533    ,   30359   ,0 };
            const std::uint32_t dim4083KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   5   ,   35  ,   1   ,   117 ,   81  ,   35  ,   2005    ,   2133    ,   4493    ,   9773    ,   24265   ,   45945   ,0 };
            const std::uint32_t dim4084KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   21  ,   57  ,   67  ,   157 ,   111 ,   857 ,   899 ,   2081    ,   2097    ,   16005   ,   20535   ,   2955    ,0 };
            const std::uint32_t dim4085KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   19  ,   45  ,   109 ,   83  ,   375 ,   1003    ,   79  ,   3801    ,   3433    ,   4429    ,   32385   ,   31551   ,0 };
            const std::uint32_t dim4086KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   1   ,   15  ,   115 ,   47  ,   511 ,   533 ,   1711    ,   2433    ,   3027    ,   13511   ,   23743   ,   23805   ,0 };
            const std::uint32_t dim4087KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   31  ,   11  ,   107 ,   215 ,   431 ,   935 ,   1033    ,   213 ,   7913    ,   557 ,   22063   ,   7947    ,0 };
            const std::uint32_t dim4088KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   23  ,   25  ,   109 ,   183 ,   445 ,   477 ,   1297    ,   2269    ,   3593    ,   5657    ,   995 ,   19821   ,0 };
            const std::uint32_t dim4089KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   5   ,   19  ,   93  ,   137 ,   155 ,   5   ,   1905    ,   1551    ,   6321    ,   11213   ,   6305    ,   5063    ,0 };
            const std::uint32_t dim4090KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   9   ,   5   ,   123 ,   203 ,   379 ,   159 ,   1871    ,   2377    ,   665 ,   4877    ,   17663   ,   60371   ,0 };
            const std::uint32_t dim4091KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   3   ,   7   ,   109 ,   15  ,   109 ,   117 ,   79  ,   3061    ,   667 ,   6963    ,   30565   ,   25745   ,0 };
            const std::uint32_t dim4092KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   15  ,   7   ,   105 ,   139 ,   29  ,   923 ,   1449    ,   1349    ,   2951    ,   7443    ,   10243   ,   51739   ,0 };
            const std::uint32_t dim4093KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   5   ,   47  ,   91  ,   77  ,   437 ,   483 ,   1309    ,   1559    ,   6491    ,   13469   ,   9461    ,   40993   ,0 };
            const std::uint32_t dim4094KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   5   ,   35  ,   57  ,   139 ,   207 ,   267 ,   707 ,   1887    ,   3447    ,   3959    ,   8169    ,   14511   ,0 };
            const std::uint32_t dim4095KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   23  ,   9   ,   57  ,   183 ,   437 ,   595 ,   1317    ,   3847    ,   2515    ,   13415   ,   26651   ,   41885   ,0 };
            const std::uint32_t dim4096KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   21  ,   49  ,   71  ,   129 ,   15  ,   183 ,   315 ,   57  ,   1739    ,   15119   ,   15293   ,   8489    ,0 };
            const std::uint32_t dim4097KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   7   ,   63  ,   91  ,   241 ,   355 ,   921 ,   1827    ,   1   ,   5713    ,   3233    ,   21901   ,   48009   ,0 };
            const std::uint32_t dim4098KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   31  ,   9   ,   103 ,   209 ,   289 ,   575 ,   1543    ,   653 ,   7189    ,   1843    ,   5205    ,   27325   ,0 };
            const std::uint32_t dim4099KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   15  ,   63  ,   7   ,   71  ,   95  ,   861 ,   857 ,   701 ,   6843    ,   10609   ,   11177   ,   21043   ,0 };
            const std::uint32_t dim4100KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   25  ,   31  ,   85  ,   255 ,   247 ,   773 ,   1503    ,   2379    ,   7231    ,   6013    ,   16193   ,   33855   ,0 };
            const std::uint32_t dim4101KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   5   ,   27  ,   125 ,   159 ,   381 ,   665 ,   1059    ,   2527    ,   1423    ,   3055    ,   8363    ,   57053   ,0 };
            const std::uint32_t dim4102KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   25  ,   57  ,   107 ,   89  ,   499 ,   761 ,   909 ,   1487    ,   1569    ,   9353    ,   27477   ,   39373   ,0 };
            const std::uint32_t dim4103KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   1   ,   57  ,   81  ,   27  ,   41  ,   371 ,   1111    ,   2437    ,   3669    ,   6033    ,   28601   ,   38985   ,0 };
            const std::uint32_t dim4104KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   25  ,   63  ,   85  ,   171 ,   187 ,   387 ,   1971    ,   579 ,   2779    ,   7667    ,   25423   ,   61005   ,0 };
            const std::uint32_t dim4105KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   25  ,   37  ,   87  ,   93  ,   387 ,   95  ,   65  ,   3345    ,   6581    ,   13325   ,   9683    ,   25399   ,0 };
            const std::uint32_t dim4106KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   9   ,   33  ,   81  ,   69  ,   483 ,   79  ,   123 ,   3241    ,   2599    ,   7545    ,   17775   ,   34933   ,0 };
            const std::uint32_t dim4107KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   9   ,   41  ,   27  ,   191 ,   385 ,   439 ,   347 ,   1279    ,   4491    ,   8883    ,   31599   ,   27167   ,0 };
            const std::uint32_t dim4108KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   1   ,   57  ,   51  ,   81  ,   161 ,   15  ,   7   ,   3695    ,   1777    ,   14947   ,   27853   ,   22383   ,0 };
            const std::uint32_t dim4109KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   15  ,   21  ,   79  ,   159 ,   85  ,   677 ,   401 ,   665 ,   3547    ,   13659   ,   18035   ,   38181   ,0 };
            const std::uint32_t dim4110KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   11  ,   55  ,   29  ,   219 ,   45  ,   683 ,   673 ,   2653    ,   6841    ,   7809    ,   8969    ,   17773   ,0 };
            const std::uint32_t dim4111KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   25  ,   61  ,   19  ,   67  ,   469 ,   265 ,   1835    ,   2733    ,   4537    ,   8113    ,   27089   ,   59191   ,0 };
            const std::uint32_t dim4112KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   9   ,   37  ,   99  ,   31  ,   229 ,   635 ,   1615    ,   3073    ,   2161    ,   13917   ,   22197   ,   4331    ,0 };
            const std::uint32_t dim4113KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   13  ,   59  ,   119 ,   65  ,   55  ,   113 ,   189 ,   57  ,   903 ,   11119   ,   3835    ,   30549   ,0 };
            const std::uint32_t dim4114KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   23  ,   25  ,   29  ,   167 ,   199 ,   669 ,   691 ,   3047    ,   7433    ,   15043   ,   22471   ,   39473   ,0 };
            const std::uint32_t dim4115KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   13  ,   15  ,   121 ,   127 ,   343 ,   293 ,   511 ,   1873    ,   4535    ,   6395    ,   10161   ,   52113   ,0 };
            const std::uint32_t dim4116KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   13  ,   7   ,   95  ,   151 ,   187 ,   221 ,   843 ,   2433    ,   5083    ,   15319   ,   5763    ,   46801   ,0 };
            const std::uint32_t dim4117KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   3   ,   57  ,   109 ,   65  ,   203 ,   583 ,   209 ,   2395    ,   5615    ,   14949   ,   10819   ,   5109    ,0 };
            const std::uint32_t dim4118KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   23  ,   41  ,   65  ,   17  ,   351 ,   89  ,   1451    ,   219 ,   5863    ,   15197   ,   22741   ,   16599   ,0 };
            const std::uint32_t dim4119KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   23  ,   49  ,   51  ,   9   ,   365 ,   595 ,   1619    ,   933 ,   2231    ,   15219   ,   105 ,   1657    ,0 };
            const std::uint32_t dim4120KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   27  ,   33  ,   39  ,   243 ,   257 ,   299 ,   479 ,   1999    ,   1781    ,   9267    ,   3631    ,   21449   ,0 };
            const std::uint32_t dim4121KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   13  ,   1   ,   83  ,   9   ,   373 ,   99  ,   1873    ,   3959    ,   1009    ,   31  ,   29329   ,   1489    ,0 };
            const std::uint32_t dim4122KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   15  ,   21  ,   99  ,   25  ,   265 ,   461 ,   467 ,   2475    ,   8149    ,   5685    ,   22679   ,   9787    ,0 };
            const std::uint32_t dim4123KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   5   ,   43  ,   109 ,   55  ,   451 ,   11  ,   1631    ,   999 ,   1181    ,   3377    ,   4807    ,   14675   ,0 };
            const std::uint32_t dim4124KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   5   ,   43  ,   27  ,   253 ,   73  ,   697 ,   81  ,   3739    ,   4267    ,   3801    ,   2913    ,   33117   ,0 };
            const std::uint32_t dim4125KuoInit[]        =   {   1   ,   3   ,   1   ,   5   ,   11  ,   55  ,   97  ,   3   ,   3   ,   949 ,   155 ,   3575    ,   941 ,   3727    ,   4047    ,   26071   ,0 };
            const std::uint32_t dim4126KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   17  ,   35  ,   3   ,   9   ,   185 ,   1   ,   421 ,   2831    ,   957 ,   4505    ,   6421    ,   16279   ,0 };
            const std::uint32_t dim4127KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   21  ,   43  ,   115 ,   183 ,   231 ,   13  ,   1711    ,   3403    ,   5447    ,   2761    ,   27591   ,   431 ,0 };
            const std::uint32_t dim4128KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   1   ,   25  ,   111 ,   157 ,   429 ,   981 ,   1117    ,   2767    ,   3107    ,   2203    ,   15335   ,   62597   ,0 };
            const std::uint32_t dim4129KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   5   ,   11  ,   59  ,   163 ,   37  ,   101 ,   63  ,   2829    ,   5583    ,   12695   ,   21683   ,   62563   ,0 };
            const std::uint32_t dim4130KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   7   ,   29  ,   39  ,   241 ,   333 ,   321 ,   931 ,   3811    ,   1981    ,   229 ,   18877   ,   6597    ,0 };
            const std::uint32_t dim4131KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   31  ,   3   ,   83  ,   21  ,   253 ,   117 ,   757 ,   2335    ,   291 ,   3723    ,   24961   ,   41985   ,0 };
            const std::uint32_t dim4132KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   23  ,   37  ,   71  ,   227 ,   211 ,   671 ,   757 ,   597 ,   4015    ,   7297    ,   26275   ,   46051   ,0 };
            const std::uint32_t dim4133KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   9   ,   15  ,   23  ,   143 ,   207 ,   235 ,   1215    ,   1401    ,   7487    ,   13397   ,   30443   ,   43735   ,0 };
            const std::uint32_t dim4134KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   23  ,   5   ,   57  ,   169 ,   3   ,   609 ,   1077    ,   109 ,   6029    ,   14891   ,   6641    ,   26525   ,0 };
            const std::uint32_t dim4135KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   7   ,   45  ,   99  ,   187 ,   43  ,   751 ,   1189    ,   1787    ,   4903    ,   10605   ,   15799   ,   61769   ,0 };
            const std::uint32_t dim4136KuoInit[]        =   {   1   ,   3   ,   1   ,   5   ,   31  ,   51  ,   95  ,   127 ,   149 ,   557 ,   1027    ,   3377    ,   1461    ,   15217   ,   16955   ,   27339   ,0 };
            const std::uint32_t dim4137KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   31  ,   29  ,   11  ,   143 ,   47  ,   709 ,   1413    ,   343 ,   5421    ,   3567    ,   5383    ,   62347   ,0 };
            const std::uint32_t dim4138KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   13  ,   3   ,   33  ,   19  ,   79  ,   751 ,   1979    ,   785 ,   6339    ,   4133    ,   31633   ,   1963    ,0 };
            const std::uint32_t dim4139KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   15  ,   21  ,   117 ,   13  ,   105 ,   519 ,   1575    ,   3041    ,   5465    ,   7167    ,   17443   ,   15781   ,0 };
            const std::uint32_t dim4140KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   29  ,   25  ,   51  ,   237 ,   11  ,   431 ,   1597    ,   751 ,   4115    ,   12345   ,   9451    ,   1417    ,0 };
            const std::uint32_t dim4141KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   1   ,   43  ,   61  ,   141 ,   279 ,   541 ,   149 ,   3783    ,   1503    ,   7597    ,   25469   ,   21143   ,0 };
            const std::uint32_t dim4142KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   23  ,   13  ,   21  ,   53  ,   49  ,   491 ,   135 ,   3079    ,   2593    ,   10611   ,   24467   ,   18627   ,0 };
            const std::uint32_t dim4143KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   19  ,   31  ,   59  ,   139 ,   137 ,   839 ,   799 ,   1081    ,   251 ,   2685    ,   15993   ,   15909   ,0 };
            const std::uint32_t dim4144KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   3   ,   1   ,   33  ,   131 ,   259 ,   137 ,   651 ,   3879    ,   3089    ,   6957    ,   24589   ,   8945    ,0 };
            const std::uint32_t dim4145KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   23  ,   13  ,   127 ,   255 ,   325 ,   451 ,   275 ,   1425    ,   3649    ,   8149    ,   28913   ,   16481   ,0 };
            const std::uint32_t dim4146KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   19  ,   35  ,   55  ,   183 ,   383 ,   419 ,   551 ,   961 ,   5413    ,   3779    ,   10935   ,   30523   ,0 };
            const std::uint32_t dim4147KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   19  ,   35  ,   125 ,   165 ,   21  ,   23  ,   1119    ,   4061    ,   8057    ,   5129    ,   6035    ,   29907   ,0 };
            const std::uint32_t dim4148KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   31  ,   5   ,   9   ,   165 ,   189 ,   117 ,   1371    ,   3171    ,   3723    ,   9051    ,   11071   ,   1669    ,0 };
            const std::uint32_t dim4149KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   23  ,   37  ,   61  ,   241 ,   253 ,   79  ,   241 ,   2629    ,   6791    ,   2305    ,   17085   ,   17163   ,0 };
            const std::uint32_t dim4150KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   25  ,   49  ,   109 ,   139 ,   271 ,   325 ,   1673    ,   1827    ,   319 ,   10729   ,   15739   ,   19971   ,0 };
            const std::uint32_t dim4151KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   15  ,   3   ,   21  ,   153 ,   229 ,   781 ,   2029    ,   3169    ,   2191    ,   7861    ,   26817   ,   44695   ,0 };
            const std::uint32_t dim4152KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   9   ,   45  ,   93  ,   117 ,   361 ,   319 ,   1747    ,   2379    ,   259 ,   15451   ,   2431    ,   29633   ,0 };
            const std::uint32_t dim4153KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   21  ,   3   ,   87  ,   157 ,   389 ,   373 ,   1235    ,   1347    ,   6573    ,   3447    ,   1569    ,   42287   ,0 };
            const std::uint32_t dim4154KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   3   ,   35  ,   27  ,   49  ,   283 ,   281 ,   733 ,   1557    ,   3589    ,   4047    ,   4589    ,   981 ,0 };
            const std::uint32_t dim4155KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   11  ,   15  ,   69  ,   209 ,   319 ,   601 ,   1559    ,   35  ,   185 ,   8659    ,   26943   ,   10885   ,0 };
            const std::uint32_t dim4156KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   15  ,   25  ,   105 ,   241 ,   153 ,   813 ,   481 ,   2269    ,   5677    ,   11121   ,   21781   ,   29427   ,0 };
            const std::uint32_t dim4157KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   1   ,   41  ,   123 ,   235 ,   487 ,   339 ,   1815    ,   241 ,   5673    ,   9319    ,   6031    ,   3785    ,0 };
            const std::uint32_t dim4158KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   3   ,   15  ,   111 ,   207 ,   281 ,   7   ,   1089    ,   709 ,   8001    ,   14277   ,   27351   ,   21503   ,0 };
            const std::uint32_t dim4159KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   29  ,   11  ,   69  ,   111 ,   471 ,   549 ,   1731    ,   115 ,   1067    ,   8417    ,   19377   ,   18729   ,0 };
            const std::uint32_t dim4160KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   29  ,   11  ,   31  ,   251 ,   437 ,   217 ,   1815    ,   1229    ,   5735    ,   11813   ,   20831   ,   27237   ,0 };
            const std::uint32_t dim4161KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   25  ,   63  ,   115 ,   45  ,   71  ,   359 ,   1313    ,   543 ,   1837    ,   5359    ,   13635   ,   47057   ,0 };
            const std::uint32_t dim4162KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   5   ,   21  ,   73  ,   47  ,   13  ,   553 ,   471 ,   465 ,   591 ,   1943    ,   12549   ,   20245   ,0 };
            const std::uint32_t dim4163KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   5   ,   35  ,   1   ,   5   ,   403 ,   797 ,   987 ,   1227    ,   2847    ,   931 ,   7417    ,   7551    ,0 };
            const std::uint32_t dim4164KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   15  ,   13  ,   7   ,   201 ,   145 ,   475 ,   1557    ,   2871    ,   3161    ,   3489    ,   7893    ,   1745    ,0 };
            const std::uint32_t dim4165KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   15  ,   27  ,   9   ,   129 ,   83  ,   31  ,   1351    ,   647 ,   6217    ,   15201   ,   21019   ,   39925   ,0 };
            const std::uint32_t dim4166KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   19  ,   39  ,   99  ,   253 ,   491 ,   455 ,   405 ,   131 ,   4755    ,   8395    ,   26647   ,   65287   ,0 };
            const std::uint32_t dim4167KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   13  ,   13  ,   15  ,   49  ,   397 ,   237 ,   1491    ,   1881    ,   4233    ,   15801   ,   25591   ,   47061   ,0 };
            const std::uint32_t dim4168KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   11  ,   11  ,   11  ,   161 ,   225 ,   257 ,   231 ,   3303    ,   5145    ,   5217    ,   21527   ,   50231   ,0 };
            const std::uint32_t dim4169KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   21  ,   51  ,   11  ,   161 ,   55  ,   945 ,   1835    ,   1493    ,   5069    ,   9443    ,   31181   ,   2157    ,0 };
            const std::uint32_t dim4170KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   29  ,   45  ,   75  ,   141 ,   475 ,   43  ,   219 ,   2689    ,   7579    ,   523 ,   27125   ,   48615   ,0 };
            const std::uint32_t dim4171KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   5   ,   7   ,   125 ,   13  ,   73  ,   231 ,   1397    ,   295 ,   3197    ,   4023    ,   2167    ,   42101   ,0 };
            const std::uint32_t dim4172KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   5   ,   15  ,   99  ,   241 ,   1   ,   49  ,   1635    ,   2467    ,   4939    ,   9411    ,   145 ,   62117   ,0 };
            const std::uint32_t dim4173KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   3   ,   43  ,   91  ,   179 ,   379 ,   997 ,   1839    ,   3463    ,   4967    ,   12773   ,   26273   ,   52999   ,0 };
            const std::uint32_t dim4174KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   7   ,   45  ,   127 ,   213 ,   63  ,   93  ,   1735    ,   623 ,   153 ,   7039    ,   4233    ,   49775   ,0 };
            const std::uint32_t dim4175KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   19  ,   57  ,   27  ,   225 ,   225 ,   361 ,   1349    ,   829 ,   1441    ,   3557    ,   7595    ,   48405   ,0 };
            const std::uint32_t dim4176KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   27  ,   19  ,   119 ,   115 ,   15  ,   929 ,   345 ,   2199    ,   8101    ,   5787    ,   3105    ,   58313   ,0 };
            const std::uint32_t dim4177KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   23  ,   41  ,   81  ,   19  ,   445 ,   11  ,   771 ,   3767    ,   6781    ,   6969    ,   28385   ,   8473    ,0 };
            const std::uint32_t dim4178KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   1   ,   49  ,   5   ,   149 ,   383 ,   567 ,   1663    ,   1277    ,   733 ,   7651    ,   4835    ,   56429   ,0 };
            const std::uint32_t dim4179KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   29  ,   53  ,   33  ,   135 ,   491 ,   957 ,   1215    ,   687 ,   1025    ,   607 ,   459 ,   58433   ,0 };
            const std::uint32_t dim4180KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   17  ,   29  ,   67  ,   149 ,   93  ,   169 ,   851 ,   2311    ,   4971    ,   13403   ,   15023   ,   31645   ,0 };
            const std::uint32_t dim4181KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   25  ,   61  ,   127 ,   73  ,   379 ,   279 ,   1407    ,   285 ,   5697    ,   11141   ,   28961   ,   35551   ,0 };
            const std::uint32_t dim4182KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   17  ,   17  ,   123 ,   113 ,   349 ,   203 ,   685 ,   687 ,   6957    ,   13033   ,   25147   ,   61541   ,0 };
            const std::uint32_t dim4183KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   29  ,   47  ,   67  ,   161 ,   163 ,   427 ,   241 ,   2767    ,   6855    ,   4975    ,   19081   ,   4613    ,0 };
            const std::uint32_t dim4184KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   7   ,   51  ,   81  ,   57  ,   107 ,   171 ,   1671    ,   2373    ,   341 ,   4071    ,   12877   ,   55775   ,0 };
            const std::uint32_t dim4185KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   29  ,   63  ,   111 ,   255 ,   189 ,   33  ,   1613    ,   113 ,   4347    ,   549 ,   9793    ,   52611   ,0 };
            const std::uint32_t dim4186KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   17  ,   11  ,   41  ,   103 ,   509 ,   387 ,   1341    ,   663 ,   611 ,   12977   ,   6435    ,   40351   ,0 };
            const std::uint32_t dim4187KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   5   ,   39  ,   13  ,   229 ,   473 ,   159 ,   585 ,   2905    ,   3467    ,   8331    ,   11539   ,   57525   ,0 };
            const std::uint32_t dim4188KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   13  ,   25  ,   87  ,   115 ,   199 ,   611 ,   635 ,   2653    ,   5559    ,   7959    ,   9545    ,   14829   ,0 };
            const std::uint32_t dim4189KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   5   ,   57  ,   53  ,   155 ,   57  ,   301 ,   263 ,   1597    ,   7805    ,   8327    ,   20457   ,   6761    ,0 };
            const std::uint32_t dim4190KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   17  ,   39  ,   105 ,   177 ,   317 ,   681 ,   679 ,   691 ,   7751    ,   959 ,   2989    ,   31533   ,0 };
            const std::uint32_t dim4191KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   23  ,   15  ,   65  ,   223 ,   379 ,   523 ,   1285    ,   3175    ,   1821    ,   15655   ,   25183   ,   9415    ,0 };
            const std::uint32_t dim4192KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   11  ,   15  ,   49  ,   33  ,   243 ,   755 ,   2027    ,   3115    ,   4665    ,   12511   ,   8653    ,   35519   ,0 };
            const std::uint32_t dim4193KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   5   ,   45  ,   45  ,   183 ,   409 ,   107 ,   1277    ,   2975    ,   2291    ,   13839   ,   18513   ,   62993   ,0 };
            const std::uint32_t dim4194KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   21  ,   39  ,   47  ,   175 ,   197 ,   737 ,   707 ,   2769    ,   171 ,   12341   ,   22361   ,   16647   ,0 };
            const std::uint32_t dim4195KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   3   ,   35  ,   127 ,   23  ,   349 ,   477 ,   1347    ,   1939    ,   1199    ,   14441   ,   9795    ,   48051   ,0 };
            const std::uint32_t dim4196KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   23  ,   59  ,   69  ,   227 ,   429 ,   359 ,   507 ,   3615    ,   2331    ,   5741    ,   23905   ,   977 ,0 };
            const std::uint32_t dim4197KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   7   ,   5   ,   111 ,   17  ,   425 ,   697 ,   1957    ,   1771    ,   3495    ,   14373   ,   8385    ,   59295   ,0 };
            const std::uint32_t dim4198KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   1   ,   25  ,   113 ,   237 ,   393 ,   23  ,   575 ,   1117    ,   665 ,   3803    ,   28291   ,   60053   ,0 };
            const std::uint32_t dim4199KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   5   ,   33  ,   43  ,   121 ,   109 ,   201 ,   877 ,   3203    ,   7967    ,   11671   ,   13397   ,   9063    ,0 };
            const std::uint32_t dim4200KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   31  ,   57  ,   31  ,   75  ,   429 ,   471 ,   683 ,   3593    ,   4277    ,   10315   ,   1913    ,   54527   ,0 };
            const std::uint32_t dim4201KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   29  ,   17  ,   69  ,   75  ,   251 ,   595 ,   1127    ,   3015    ,   5621    ,   389 ,   2245    ,   43007   ,0 };
            const std::uint32_t dim4202KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   7   ,   41  ,   127 ,   57  ,   321 ,   971 ,   1217    ,   3731    ,   4667    ,   5919    ,   29871   ,   60487   ,0 };
            const std::uint32_t dim4203KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   21  ,   9   ,   83  ,   109 ,   489 ,   689 ,   1601    ,   2979    ,   405 ,   3131    ,   19409   ,   20739   ,0 };
            const std::uint32_t dim4204KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   31  ,   45  ,   77  ,   129 ,   269 ,   473 ,   427 ,   2751    ,   6841    ,   5957    ,   25297   ,   2301    ,0 };
            const std::uint32_t dim4205KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   27  ,   3   ,   107 ,   99  ,   37  ,   421 ,   1853    ,   2683    ,   7305    ,   467 ,   32481   ,   1085    ,0 };
            const std::uint32_t dim4206KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   25  ,   3   ,   79  ,   7   ,   47  ,   299 ,   731 ,   1321    ,   1917    ,   4315    ,   17177   ,   26499   ,0 };
            const std::uint32_t dim4207KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   5   ,   1   ,   19  ,   163 ,   335 ,   13  ,   1855    ,   3805    ,   6707    ,   2133    ,   19671   ,   53653   ,0 };
            const std::uint32_t dim4208KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   3   ,   5   ,   77  ,   69  ,   31  ,   959 ,   1815    ,   669 ,   5965    ,   2925    ,   16285   ,   42043   ,0 };
            const std::uint32_t dim4209KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   25  ,   5   ,   35  ,   175 ,   55  ,   765 ,   597 ,   703 ,   3141    ,   9825    ,   29067   ,   32817   ,0 };
            const std::uint32_t dim4210KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   1   ,   57  ,   119 ,   85  ,   167 ,   299 ,   561 ,   1045    ,   4255    ,   14663   ,   27787   ,   38785   ,0 };
            const std::uint32_t dim4211KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   5   ,   41  ,   97  ,   31  ,   55  ,   773 ,   707 ,   1083    ,   359 ,   15955   ,   11203   ,   50129   ,0 };
            const std::uint32_t dim4212KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   9   ,   35  ,   101 ,   231 ,   23  ,   301 ,   683 ,   3075    ,   3221    ,   7763    ,   5585    ,   35205   ,0 };
            const std::uint32_t dim4213KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   23  ,   29  ,   83  ,   227 ,   111 ,   307 ,   837 ,   465 ,   5933    ,   5265    ,   4507    ,   8719    ,0 };
            const std::uint32_t dim4214KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   21  ,   9   ,   49  ,   157 ,   271 ,   809 ,   1467    ,   1337    ,   5893    ,   13681   ,   11261   ,   56709   ,0 };
            const std::uint32_t dim4215KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   29  ,   33  ,   89  ,   39  ,   131 ,   339 ,   359 ,   3087    ,   5167    ,   5659    ,   629 ,   53865   ,0 };
            const std::uint32_t dim4216KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   11  ,   23  ,   59  ,   105 ,   201 ,   17  ,   923 ,   613 ,   1665    ,   8931    ,   28457   ,   63933   ,0 };
            const std::uint32_t dim4217KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   17  ,   33  ,   67  ,   73  ,   367 ,   263 ,   1377    ,   393 ,   1561    ,   3409    ,   24453   ,   61637   ,0 };
            const std::uint32_t dim4218KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   29  ,   9   ,   31  ,   51  ,   485 ,   775 ,   741 ,   1427    ,   1857    ,   10243   ,   18101   ,   29795   ,0 };
            const std::uint32_t dim4219KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   5   ,   39  ,   29  ,   137 ,   171 ,   837 ,   347 ,   1271    ,   7365    ,   3783    ,   22731   ,   18131   ,0 };
            const std::uint32_t dim4220KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   1   ,   45  ,   89  ,   175 ,   11  ,   859 ,   355 ,   1033    ,   4767    ,   11495   ,   28761   ,   11335   ,0 };
            const std::uint32_t dim4221KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   25  ,   7   ,   85  ,   229 ,   243 ,   259 ,   383 ,   1163    ,   4833    ,   11283   ,   31573   ,   30891   ,0 };
            const std::uint32_t dim4222KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   11  ,   41  ,   111 ,   87  ,   203 ,   177 ,   1113    ,   415 ,   3613    ,   1327    ,   20103   ,   61295   ,0 };
            const std::uint32_t dim4223KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   15  ,   53  ,   25  ,   245 ,   335 ,   31  ,   1335    ,   3339    ,   2337    ,   5719    ,   3333    ,   51325   ,0 };
            const std::uint32_t dim4224KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   5   ,   29  ,   117 ,   11  ,   239 ,   135 ,   1501    ,   2707    ,   2775    ,   2135    ,   11477   ,   44363   ,0 };
            const std::uint32_t dim4225KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   23  ,   33  ,   3   ,   219 ,   301 ,   643 ,   1555    ,   1   ,   709 ,   11  ,   30649   ,   19729   ,0 };
            const std::uint32_t dim4226KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   31  ,   9   ,   45  ,   185 ,   203 ,   741 ,   1851    ,   981 ,   6437    ,   1559    ,   27245   ,   36797   ,0 };
            const std::uint32_t dim4227KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   1   ,   41  ,   11  ,   141 ,   53  ,   533 ,   927 ,   2733    ,   1049    ,   16191   ,   1241    ,   49695   ,0 };
            const std::uint32_t dim4228KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   31  ,   21  ,   105 ,   181 ,   487 ,   1009    ,   135 ,   3649    ,   6459    ,   3397    ,   1805    ,   29793   ,0 };
            const std::uint32_t dim4229KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   1   ,   29  ,   65  ,   127 ,   461 ,   297 ,   1151    ,   2403    ,   4875    ,   343 ,   24293   ,   47203   ,0 };
            const std::uint32_t dim4230KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   9   ,   1   ,   23  ,   139 ,   337 ,   591 ,   1557    ,   1993    ,   6927    ,   5791    ,   29199   ,   2991    ,0 };
            const std::uint32_t dim4231KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   7   ,   1   ,   81  ,   129 ,   469 ,   215 ,   695 ,   2691    ,   6165    ,   14741   ,   24339   ,   58681   ,0 };
            const std::uint32_t dim4232KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   29  ,   59  ,   113 ,   143 ,   15  ,   399 ,   1141    ,   975 ,   1285    ,   12773   ,   593 ,   15481   ,0 };
            const std::uint32_t dim4233KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   19  ,   41  ,   85  ,   95  ,   479 ,   311 ,   1721    ,   1089    ,   7199    ,   15683   ,   15909   ,   40911   ,0 };
            const std::uint32_t dim4234KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   25  ,   55  ,   23  ,   195 ,   413 ,   623 ,   411 ,   279 ,   3381    ,   15313   ,   19323   ,   22829   ,0 };
            const std::uint32_t dim4235KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   13  ,   1   ,   55  ,   91  ,   493 ,   967 ,   1571    ,   2887    ,   2791    ,   1331    ,   20565   ,   61267   ,0 };
            const std::uint32_t dim4236KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   1   ,   17  ,   127 ,   253 ,   249 ,   559 ,   739 ,   2921    ,   1315    ,   13699   ,   22501   ,   9699    ,0 };
            const std::uint32_t dim4237KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   19  ,   53  ,   31  ,   103 ,   307 ,   821 ,   661 ,   591 ,   5379    ,   6401    ,   10109   ,   7325    ,0 };
            const std::uint32_t dim4238KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   15  ,   35  ,   59  ,   149 ,   443 ,   413 ,   139 ,   1851    ,   3679    ,   10721   ,   31393   ,   37329   ,0 };
            const std::uint32_t dim4239KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   15  ,   47  ,   43  ,   241 ,   323 ,   357 ,   1567    ,   3183    ,   6869    ,   4615    ,   5617    ,   28691   ,0 };
            const std::uint32_t dim4240KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   25  ,   11  ,   55  ,   55  ,   105 ,   277 ,   1317    ,   3631    ,   5351    ,   12747   ,   1685    ,   61239   ,0 };
            const std::uint32_t dim4241KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   31  ,   19  ,   87  ,   119 ,   409 ,   817 ,   97  ,   3549    ,   3517    ,   13901   ,   11707   ,   9501    ,0 };
            const std::uint32_t dim4242KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   13  ,   17  ,   55  ,   195 ,   457 ,   223 ,   837 ,   453 ,   2953    ,   2269    ,   10149   ,   48941   ,0 };
            const std::uint32_t dim4243KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   5   ,   31  ,   63  ,   117 ,   419 ,   329 ,   1759    ,   1167    ,   7967    ,   8975    ,   11247   ,   37159   ,0 };
            const std::uint32_t dim4244KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   17  ,   19  ,   41  ,   61  ,   349 ,   299 ,   1449    ,   2329    ,   471 ,   5119    ,   29595   ,   43335   ,0 };
            const std::uint32_t dim4245KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   13  ,   63  ,   99  ,   239 ,   239 ,   903 ,   55  ,   1347    ,   969 ,   9409    ,   11603   ,   28553   ,0 };
            const std::uint32_t dim4246KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   25  ,   59  ,   23  ,   241 ,   361 ,   1005    ,   771 ,   923 ,   3315    ,   4201    ,   32695   ,   54151   ,0 };
            const std::uint32_t dim4247KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   19  ,   1   ,   113 ,   103 ,   469 ,   591 ,   319 ,   2297    ,   1033    ,   9273    ,   20529   ,   58301   ,0 };
            const std::uint32_t dim4248KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   23  ,   1   ,   77  ,   161 ,   321 ,   855 ,   1987    ,   3735    ,   4533    ,   12061   ,   19305   ,   31679   ,0 };
            const std::uint32_t dim4249KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   27  ,   15  ,   73  ,   83  ,   113 ,   455 ,   1855    ,   2677    ,   3243    ,   14961   ,   27147   ,   21865   ,0 };
            const std::uint32_t dim4250KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   15  ,   33  ,   61  ,   87  ,   237 ,   775 ,   1765    ,   2783    ,   3051    ,   3617    ,   32519   ,   43991   ,0 };
            const std::uint32_t dim4251KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   9   ,   57  ,   21  ,   177 ,   499 ,   605 ,   391 ,   381 ,   2027    ,   9221    ,   11213   ,   10365   ,0 };
            const std::uint32_t dim4252KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   31  ,   29  ,   57  ,   159 ,   413 ,   321 ,   245 ,   2007    ,   2817    ,   5173    ,   23227   ,   19885   ,0 };
            const std::uint32_t dim4253KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   29  ,   43  ,   113 ,   173 ,   505 ,   449 ,   409 ,   981 ,   2257    ,   13261   ,   85  ,   6477    ,0 };
            const std::uint32_t dim4254KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   9   ,   51  ,   1   ,   127 ,   65  ,   963 ,   1541    ,   1321    ,   7849    ,   6481    ,   1583    ,   14737   ,0 };
            const std::uint32_t dim4255KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   1   ,   45  ,   11  ,   157 ,   375 ,   439 ,   1673    ,   271 ,   3853    ,   8795    ,   23287   ,   45365   ,0 };
            const std::uint32_t dim4256KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   17  ,   7   ,   43  ,   3   ,   3   ,   1005    ,   523 ,   2553    ,   2457    ,   259 ,   20999   ,   23611   ,0 };
            const std::uint32_t dim4257KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   17  ,   33  ,   97  ,   227 ,   19  ,   19  ,   2039    ,   3181    ,   1393    ,   1427    ,   215 ,   49915   ,0 };
            const std::uint32_t dim4258KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   19  ,   1   ,   83  ,   95  ,   7   ,   571 ,   655 ,   1281    ,   3841    ,   3925    ,   24603   ,   38413   ,0 };
            const std::uint32_t dim4259KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   19  ,   47  ,   43  ,   105 ,   431 ,   921 ,   927 ,   3713    ,   8181    ,   4177    ,   9411    ,   1481    ,0 };
            const std::uint32_t dim4260KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   3   ,   29  ,   11  ,   121 ,   505 ,   629 ,   959 ,   523 ,   257 ,   3089    ,   15075   ,   14087   ,0 };
            const std::uint32_t dim4261KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   9   ,   3   ,   5   ,   167 ,   7   ,   705 ,   1737    ,   583 ,   2297    ,   13073   ,   27617   ,   22083   ,0 };
            const std::uint32_t dim4262KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   9   ,   51  ,   33  ,   191 ,   263 ,   961 ,   1019    ,   2771    ,   3487    ,   7471    ,   10939   ,   23831   ,0 };
            const std::uint32_t dim4263KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   25  ,   19  ,   75  ,   115 ,   221 ,   93  ,   1135    ,   257 ,   5597    ,   14715   ,   2385    ,   46659   ,0 };
            const std::uint32_t dim4264KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   31  ,   13  ,   63  ,   231 ,   463 ,   501 ,   1437    ,   1777    ,   6161    ,   9885    ,   10543   ,   26031   ,0 };
            const std::uint32_t dim4265KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   5   ,   1   ,   51  ,   141 ,   311 ,   929 ,   261 ,   2959    ,   59  ,   4163    ,   9855    ,   54825   ,0 };
            const std::uint32_t dim4266KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   1   ,   57  ,   31  ,   21  ,   395 ,   211 ,   89  ,   3703    ,   7565    ,   2095    ,   16273   ,   52105   ,0 };
            const std::uint32_t dim4267KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   25  ,   57  ,   27  ,   163 ,   459 ,   849 ,   955 ,   2437    ,   7115    ,   8029    ,   165 ,   12007   ,0 };
            const std::uint32_t dim4268KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   29  ,   57  ,   49  ,   71  ,   389 ,   483 ,   991 ,   629 ,   1517    ,   2481    ,   4881    ,   39431   ,0 };
            const std::uint32_t dim4269KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   1   ,   11  ,   29  ,   81  ,   323 ,   581 ,   1515    ,   905 ,   2813    ,   12221   ,   20181   ,   9855    ,0 };
            const std::uint32_t dim4270KuoInit[]        =   {   1   ,   3   ,   1   ,   5   ,   27  ,   3   ,   41  ,   65  ,   369 ,   925 ,   1449    ,   2711    ,   3333    ,   6263    ,   10639   ,   43537   ,0 };
            const std::uint32_t dim4271KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   17  ,   5   ,   31  ,   181 ,   77  ,   999 ,   1011    ,   2631    ,   1761    ,   10139   ,   24369   ,   39093   ,0 };
            const std::uint32_t dim4272KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   11  ,   23  ,   65  ,   165 ,   41  ,   591 ,   1045    ,   263 ,   1707    ,   4419    ,   24005   ,   47489   ,0 };
            const std::uint32_t dim4273KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   11  ,   43  ,   65  ,   161 ,   229 ,   35  ,   637 ,   3693    ,   721 ,   6863    ,   12001   ,   48067   ,0 };
            const std::uint32_t dim4274KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   9   ,   39  ,   27  ,   65  ,   407 ,   103 ,   1437    ,   3403    ,   7355    ,   2009    ,   5979    ,   37959   ,0 };
            const std::uint32_t dim4275KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   13  ,   23  ,   65  ,   145 ,   395 ,   603 ,   1711    ,   1529    ,   6309    ,   14631   ,   4615    ,   24459   ,0 };
            const std::uint32_t dim4276KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   25  ,   27  ,   109 ,   91  ,   205 ,   53  ,   199 ,   1215    ,   4371    ,   4821    ,   11793   ,   20719   ,0 };
            const std::uint32_t dim4277KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   9   ,   9   ,   115 ,   77  ,   223 ,   381 ,   1035    ,   1961    ,   5285    ,   12465   ,   20531   ,   51677   ,0 };
            const std::uint32_t dim4278KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   13  ,   31  ,   123 ,   123 ,   325 ,   719 ,   1683    ,   1253    ,   4241    ,   1443    ,   7507    ,   8253    ,0 };
            const std::uint32_t dim4279KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   5   ,   1   ,   71  ,   145 ,   299 ,   1021    ,   677 ,   1733    ,   2791    ,   12337   ,   24395   ,   64145   ,0 };
            const std::uint32_t dim4280KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   21  ,   31  ,   113 ,   79  ,   1   ,   29  ,   1171    ,   4081    ,   7599    ,   11661   ,   4305    ,   11383   ,0 };
            const std::uint32_t dim4281KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   27  ,   9   ,   97  ,   117 ,   205 ,   391 ,   1571    ,   1801    ,   6085    ,   15867   ,   8987    ,   29925   ,0 };
            const std::uint32_t dim4282KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   5   ,   35  ,   27  ,   143 ,   503 ,   533 ,   1293    ,   3737    ,   3011    ,   4457    ,   18381   ,   45513   ,0 };
            const std::uint32_t dim4283KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   21  ,   55  ,   113 ,   127 ,   365 ,   265 ,   1211    ,   841 ,   807 ,   3901    ,   28993   ,   28467   ,0 };
            const std::uint32_t dim4284KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   21  ,   17  ,   101 ,   217 ,   413 ,   273 ,   53  ,   2415    ,   655 ,   9939    ,   11233   ,   31631   ,0 };
            const std::uint32_t dim4285KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   11  ,   11  ,   111 ,   63  ,   301 ,   343 ,   1757    ,   2615    ,   1683    ,   11143   ,   16405   ,   16671   ,0 };
            const std::uint32_t dim4286KuoInit[]        =   {   1   ,   1   ,   5   ,   15  ,   17  ,   19  ,   83  ,   195 ,   475 ,   189 ,   1881    ,   699 ,   4853    ,   7849    ,   15063   ,   5517    ,0 };
            const std::uint32_t dim4287KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   27  ,   25  ,   19  ,   239 ,   153 ,   725 ,   709 ,   3717    ,   4801    ,   1433    ,   17789   ,   34549   ,0 };
            const std::uint32_t dim4288KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   9   ,   5   ,   47  ,   215 ,   123 ,   161 ,   583 ,   917 ,   5373    ,   6839    ,   20747   ,   47179   ,0 };
            const std::uint32_t dim4289KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   1   ,   25  ,   31  ,   217 ,   185 ,   331 ,   261 ,   3877    ,   2339    ,   11557   ,   22779   ,   58509   ,0 };
            const std::uint32_t dim4290KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   11  ,   1   ,   13  ,   53  ,   319 ,   237 ,   763 ,   2411    ,   7953    ,   2117    ,   24947   ,   26643   ,0 };
            const std::uint32_t dim4291KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   17  ,   53  ,   9   ,   253 ,   219 ,   715 ,   1923    ,   823 ,   1495    ,   1975    ,   3739    ,   61343   ,0 };
            const std::uint32_t dim4292KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   27  ,   31  ,   121 ,   253 ,   319 ,   1001    ,   125 ,   567 ,   215 ,   6879    ,   22581   ,   38495   ,0 };
            const std::uint32_t dim4293KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   23  ,   17  ,   83  ,   65  ,   279 ,   725 ,   1611    ,   3911    ,   509 ,   1729    ,   30025   ,   10791   ,0 };
            const std::uint32_t dim4294KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   19  ,   17  ,   67  ,   101 ,   129 ,   607 ,   557 ,   3475    ,   1445    ,   8789    ,   1815    ,   18171   ,0 };
            const std::uint32_t dim4295KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   23  ,   57  ,   69  ,   127 ,   147 ,   743 ,   549 ,   3269    ,   6193    ,   12667   ,   17081   ,   6899    ,0 };
            const std::uint32_t dim4296KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   9   ,   29  ,   83  ,   175 ,   389 ,   289 ,   367 ,   1259    ,   6631    ,   15675   ,   20975   ,   54067   ,0 };
            const std::uint32_t dim4297KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   27  ,   11  ,   31  ,   209 ,   159 ,   615 ,   1813    ,   3235    ,   7487    ,   7103    ,   5857    ,   19435   ,0 };
            const std::uint32_t dim4298KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   17  ,   3   ,   13  ,   255 ,   405 ,   925 ,   55  ,   3539    ,   3351    ,   359 ,   7633    ,   38209   ,0 };
            const std::uint32_t dim4299KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   5   ,   51  ,   123 ,   61  ,   485 ,   785 ,   1975    ,   121 ,   7841    ,   7253    ,   11769   ,   7389    ,0 };
            const std::uint32_t dim4300KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   1   ,   3   ,   51  ,   169 ,   163 ,   875 ,   35  ,   1573    ,   7931    ,   13611   ,   14697   ,   64843   ,0 };
            const std::uint32_t dim4301KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   11  ,   35  ,   47  ,   135 ,   475 ,   893 ,   39  ,   2763    ,   2671    ,   7417    ,   22905   ,   60593   ,0 };
            const std::uint32_t dim4302KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   27  ,   27  ,   85  ,   219 ,   341 ,   509 ,   1131    ,   3607    ,   1307    ,   15265   ,   28589   ,   61113   ,0 };
            const std::uint32_t dim4303KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   11  ,   37  ,   53  ,   67  ,   177 ,   951 ,   237 ,   3865    ,   2233    ,   1405    ,   28373   ,   47767   ,0 };
            const std::uint32_t dim4304KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   17  ,   49  ,   35  ,   167 ,   67  ,   397 ,   927 ,   3305    ,   2791    ,   3609    ,   3111    ,   4555    ,0 };
            const std::uint32_t dim4305KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   13  ,   41  ,   123 ,   89  ,   65  ,   931 ,   1959    ,   1751    ,   2765    ,   8361    ,   23653   ,   45677   ,0 };
            const std::uint32_t dim4306KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   25  ,   37  ,   91  ,   225 ,   181 ,   275 ,   1515    ,   1355    ,   7971    ,   16081   ,   13715   ,   63963   ,0 };
            const std::uint32_t dim4307KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   7   ,   11  ,   125 ,   181 ,   127 ,   855 ,   1277    ,   3587    ,   1351    ,   4907    ,   16985   ,   357 ,0 };
            const std::uint32_t dim4308KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   13  ,   57  ,   23  ,   99  ,   115 ,   923 ,   1395    ,   3083    ,   3939    ,   475 ,   12385   ,   30113   ,0 };
            const std::uint32_t dim4309KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   1   ,   19  ,   27  ,   73  ,   91  ,   155 ,   1145    ,   467 ,   5655    ,   341 ,   8875    ,   61583   ,0 };
            const std::uint32_t dim4310KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   17  ,   33  ,   113 ,   219 ,   99  ,   817 ,   1731    ,   3379    ,   5729    ,   13615   ,   19047   ,   14143   ,0 };
            const std::uint32_t dim4311KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   29  ,   7   ,   35  ,   111 ,   405 ,   207 ,   1811    ,   3701    ,   6101    ,   7147    ,   13825   ,   52081   ,0 };
            const std::uint32_t dim4312KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   19  ,   23  ,   89  ,   95  ,   503 ,   311 ,   1615    ,   371 ,   5853    ,   4635    ,   31911   ,   65345   ,0 };
            const std::uint32_t dim4313KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   17  ,   41  ,   49  ,   143 ,   445 ,   855 ,   1311    ,   3961    ,   3559    ,   5483    ,   31609   ,   34147   ,0 };
            const std::uint32_t dim4314KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   19  ,   49  ,   67  ,   141 ,   293 ,   757 ,   1905    ,   2513    ,   4405    ,   41  ,   1191    ,   15259   ,0 };
            const std::uint32_t dim4315KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   11  ,   39  ,   113 ,   73  ,   23  ,   117 ,   1315    ,   725 ,   7429    ,   5483    ,   26213   ,   9331    ,0 };
            const std::uint32_t dim4316KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   3   ,   9   ,   119 ,   35  ,   309 ,   515 ,   751 ,   323 ,   2521    ,   12093   ,   1123    ,   43651   ,0 };
            const std::uint32_t dim4317KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   29  ,   43  ,   49  ,   53  ,   481 ,   269 ,   915 ,   1845    ,   3341    ,   511 ,   23845   ,   34623   ,0 };
            const std::uint32_t dim4318KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   23  ,   23  ,   71  ,   225 ,   269 ,   713 ,   21  ,   1051    ,   7635    ,   14245   ,   3947    ,   41757   ,0 };
            const std::uint32_t dim4319KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   5   ,   19  ,   39  ,   99  ,   309 ,   531 ,   1645    ,   787 ,   6913    ,   8159    ,   1359    ,   61973   ,0 };
            const std::uint32_t dim4320KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   5   ,   61  ,   107 ,   91  ,   197 ,   109 ,   369 ,   1053    ,   1995    ,   11551   ,   4751    ,   4981    ,0 };
            const std::uint32_t dim4321KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   29  ,   31  ,   103 ,   21  ,   393 ,   63  ,   1465    ,   2813    ,   995 ,   67  ,   11997   ,   34887   ,0 };
            const std::uint32_t dim4322KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   9   ,   49  ,   111 ,   135 ,   83  ,   79  ,   353 ,   2703    ,   5027    ,   10287   ,   3753    ,   60785   ,0 };
            const std::uint32_t dim4323KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   17  ,   17  ,   51  ,   69  ,   465 ,   25  ,   1231    ,   995 ,   4643    ,   3405    ,   2237    ,   54357   ,0 };
            const std::uint32_t dim4324KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   5   ,   39  ,   31  ,   187 ,   459 ,   197 ,   905 ,   279 ,   2279    ,   6585    ,   7073    ,   1897    ,0 };
            const std::uint32_t dim4325KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   13  ,   17  ,   105 ,   29  ,   183 ,   193 ,   541 ,   977 ,   2247    ,   5173    ,   10511   ,   59969   ,0 };
            const std::uint32_t dim4326KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   3   ,   11  ,   89  ,   1   ,   411 ,   503 ,   267 ,   2875    ,   2585    ,   9391    ,   19395   ,   30107   ,0 };
            const std::uint32_t dim4327KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   7   ,   19  ,   45  ,   251 ,   143 ,   729 ,   1825    ,   2571    ,   6277    ,   12759   ,   5057    ,   58455   ,0 };
            const std::uint32_t dim4328KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   7   ,   49  ,   119 ,   3   ,   127 ,   1015    ,   937 ,   2585    ,   1229    ,   16289   ,   30087   ,   45069   ,0 };
            const std::uint32_t dim4329KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   15  ,   39  ,   39  ,   13  ,   315 ,   533 ,   143 ,   2107    ,   805 ,   1487    ,   8049    ,   3643    ,0 };
            const std::uint32_t dim4330KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   23  ,   35  ,   127 ,   143 ,   247 ,   491 ,   837 ,   2263    ,   1375    ,   8283    ,   24527   ,   37967   ,0 };
            const std::uint32_t dim4331KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   13  ,   9   ,   51  ,   171 ,   421 ,   161 ,   1777    ,   3679    ,   4821    ,   10113   ,   28459   ,   55339   ,0 };
            const std::uint32_t dim4332KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   25  ,   61  ,   53  ,   145 ,   81  ,   509 ,   2001    ,   315 ,   7775    ,   7741    ,   9239    ,   10041   ,0 };
            const std::uint32_t dim4333KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   11  ,   31  ,   21  ,   91  ,   425 ,   415 ,   523 ,   3649    ,   6595    ,   9409    ,   26631   ,   8761    ,0 };
            const std::uint32_t dim4334KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   13  ,   1   ,   51  ,   53  ,   123 ,   125 ,   1055    ,   3951    ,   6621    ,   9207    ,   25991   ,   36435   ,0 };
            const std::uint32_t dim4335KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   21  ,   63  ,   57  ,   35  ,   197 ,   601 ,   665 ,   3223    ,   817 ,   3467    ,   2667    ,   2811    ,0 };
            const std::uint32_t dim4336KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   7   ,   29  ,   51  ,   29  ,   383 ,   969 ,   557 ,   795 ,   7535    ,   513 ,   1329    ,   57567   ,0 };
            const std::uint32_t dim4337KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   11  ,   59  ,   85  ,   183 ,   163 ,   445 ,   1595    ,   133 ,   4277    ,   3323    ,   6833    ,   50359   ,0 };
            const std::uint32_t dim4338KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   9   ,   11  ,   65  ,   209 ,   509 ,   65  ,   1299    ,   2225    ,   7727    ,   3851    ,   17661   ,   39777   ,0 };
            const std::uint32_t dim4339KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   13  ,   31  ,   15  ,   189 ,   43  ,   435 ,   707 ,   83  ,   6713    ,   13721   ,   24013   ,   47037   ,0 };
            const std::uint32_t dim4340KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   29  ,   49  ,   101 ,   205 ,   7   ,   539 ,   1809    ,   4095    ,   7581    ,   8187    ,   16475   ,   10923   ,0 };
            const std::uint32_t dim4341KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   27  ,   39  ,   65  ,   117 ,   183 ,   439 ,   997 ,   1389    ,   2945    ,   13303   ,   10621   ,   63085   ,0 };
            const std::uint32_t dim4342KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   11  ,   21  ,   121 ,   179 ,   37  ,   993 ,   1299    ,   2741    ,   5797    ,   10677   ,   32519   ,   45061   ,0 };
            const std::uint32_t dim4343KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   23  ,   47  ,   107 ,   131 ,   145 ,   679 ,   1519    ,   1147    ,   887 ,   2017    ,   31191   ,   4047    ,0 };
            const std::uint32_t dim4344KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   1   ,   51  ,   1   ,   105 ,   245 ,   269 ,   1067    ,   3551    ,   6323    ,   3729    ,   16351   ,   62965   ,0 };
            const std::uint32_t dim4345KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   17  ,   11  ,   53  ,   163 ,   387 ,   601 ,   75  ,   3219    ,   5683    ,   783 ,   28143   ,   20695   ,0 };
            const std::uint32_t dim4346KuoInit[]        =   {   1   ,   1   ,   5   ,   15  ,   21  ,   21  ,   33  ,   171 ,   73  ,   157 ,   49  ,   3443    ,   4057    ,   8631    ,   17555   ,   8959    ,0 };
            const std::uint32_t dim4347KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   3   ,   35  ,   13  ,   211 ,   181 ,   425 ,   1367    ,   2217    ,   5949    ,   2741    ,   8141    ,   45769   ,0 };
            const std::uint32_t dim4348KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   27  ,   43  ,   117 ,   3   ,   331 ,   553 ,   1847    ,   2085    ,   7125    ,   10827   ,   10583   ,   60169   ,0 };
            const std::uint32_t dim4349KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   15  ,   35  ,   81  ,   15  ,   259 ,   89  ,   1071    ,   3807    ,   3149    ,   3309    ,   17791   ,   63869   ,0 };
            const std::uint32_t dim4350KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   19  ,   7   ,   113 ,   131 ,   399 ,   691 ,   57  ,   1837    ,   3613    ,   1755    ,   521 ,   64867   ,0 };
            const std::uint32_t dim4351KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   25  ,   53  ,   11  ,   241 ,   187 ,   237 ,   1591    ,   4059    ,   6021    ,   8451    ,   14305   ,   30965   ,0 };
            const std::uint32_t dim4352KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   27  ,   15  ,   9   ,   209 ,   43  ,   137 ,   1351    ,   2553    ,   2841    ,   6375    ,   20291   ,   2523    ,0 };
            const std::uint32_t dim4353KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   27  ,   37  ,   83  ,   61  ,   365 ,   739 ,   69  ,   725 ,   6745    ,   7353    ,   2621    ,   57747   ,0 };
            const std::uint32_t dim4354KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   17  ,   9   ,   53  ,   93  ,   103 ,   467 ,   1543    ,   2353    ,   4901    ,   13269   ,   21635   ,   63425   ,0 };
            const std::uint32_t dim4355KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   15  ,   19  ,   61  ,   127 ,   423 ,   749 ,   809 ,   515 ,   7819    ,   1209    ,   22879   ,   54069   ,0 };
            const std::uint32_t dim4356KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   11  ,   23  ,   93  ,   5   ,   91  ,   613 ,   1529    ,   2621    ,   2689    ,   2251    ,   16049   ,   60773   ,0 };
            const std::uint32_t dim4357KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   15  ,   27  ,   57  ,   177 ,   477 ,   585 ,   249 ,   3673    ,   2651    ,   10137   ,   30395   ,   57475   ,0 };
            const std::uint32_t dim4358KuoInit[]        =   {   1   ,   3   ,   1   ,   5   ,   31  ,   39  ,   25  ,   185 ,   233 ,   915 ,   1335    ,   2889    ,   1135    ,   12515   ,   27385   ,   54785   ,0 };
            const std::uint32_t dim4359KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   3   ,   19  ,   13  ,   105 ,   465 ,   11  ,   799 ,   1699    ,   6495    ,   14307   ,   18071   ,   55405   ,0 };
            const std::uint32_t dim4360KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   31  ,   49  ,   27  ,   209 ,   503 ,   979 ,   877 ,   3121    ,   3545    ,   12875   ,   799 ,   44427   ,0 };
            const std::uint32_t dim4361KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   23  ,   17  ,   113 ,   109 ,   301 ,   587 ,   1865    ,   1623    ,   453 ,   14449   ,   26901   ,   34687   ,0 };
            const std::uint32_t dim4362KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   1   ,   29  ,   25  ,   113 ,   147 ,   53  ,   27  ,   2971    ,   5663    ,   12013   ,   1281    ,   65173   ,0 };
            const std::uint32_t dim4363KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   13  ,   47  ,   13  ,   209 ,   339 ,   393 ,   1389    ,   2205    ,   537 ,   10911   ,   20093   ,   61499   ,0 };
            const std::uint32_t dim4364KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   21  ,   45  ,   75  ,   43  ,   425 ,   89  ,   1319    ,   2245    ,   6519    ,   12819   ,   30653   ,   18927   ,0 };
            const std::uint32_t dim4365KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   1   ,   31  ,   55  ,   29  ,   337 ,   733 ,   1303    ,   1721    ,   7163    ,   13807   ,   5865    ,   20009   ,0 };
            const std::uint32_t dim4366KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   1   ,   5   ,   101 ,   211 ,   263 ,   865 ,   59  ,   2473    ,   3857    ,   9909    ,   21353   ,   8807    ,0 };
            const std::uint32_t dim4367KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   25  ,   29  ,   5   ,   157 ,   17  ,   985 ,   369 ,   1903    ,   2431    ,   15395   ,   20245   ,   51253   ,0 };
            const std::uint32_t dim4368KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   7   ,   31  ,   45  ,   209 ,   287 ,   13  ,   591 ,   3907    ,   7501    ,   10003   ,   21815   ,   43213   ,0 };
            const std::uint32_t dim4369KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   27  ,   25  ,   73  ,   191 ,   361 ,   731 ,   757 ,   1907    ,   9   ,   16357   ,   4241    ,   40187   ,0 };
            const std::uint32_t dim4370KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   5   ,   55  ,   121 ,   89  ,   39  ,   531 ,   493 ,   3453    ,   5709    ,   8215    ,   21831   ,   5661    ,0 };
            const std::uint32_t dim4371KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   27  ,   59  ,   49  ,   251 ,   17  ,   223 ,   875 ,   1133    ,   3161    ,   10273   ,   26463   ,   45987   ,0 };
            const std::uint32_t dim4372KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   17  ,   39  ,   117 ,   153 ,   243 ,   449 ,   1261    ,   3917    ,   1359    ,   4525    ,   22119   ,   1781    ,0 };
            const std::uint32_t dim4373KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   15  ,   15  ,   19  ,   151 ,   411 ,   693 ,   445 ,   2525    ,   2867    ,   12809   ,   1487    ,   7019    ,0 };
            const std::uint32_t dim4374KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   15  ,   57  ,   61  ,   243 ,   427 ,   529 ,   1051    ,   3391    ,   6259    ,   8791    ,   3405    ,   54757   ,0 };
            const std::uint32_t dim4375KuoInit[]        =   {   1   ,   3   ,   1   ,   5   ,   13  ,   41  ,   105 ,   73  ,   485 ,   881 ,   1943    ,   1419    ,   5761    ,   11807   ,   16497   ,   12763   ,0 };
            const std::uint32_t dim4376KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   7   ,   47  ,   61  ,   99  ,   473 ,   487 ,   1973    ,   1675    ,   3163    ,   4033    ,   5323    ,   31313   ,0 };
            const std::uint32_t dim4377KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   21  ,   33  ,   23  ,   129 ,   469 ,   743 ,   769 ,   1561    ,   235 ,   13713   ,   6827    ,   61273   ,0 };
            const std::uint32_t dim4378KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   11  ,   19  ,   59  ,   37  ,   431 ,   5   ,   1333    ,   2381    ,   5707    ,   2499    ,   9339    ,   35803   ,0 };
            const std::uint32_t dim4379KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   17  ,   11  ,   77  ,   137 ,   111 ,   567 ,   1469    ,   543 ,   5633    ,   1927    ,   26491   ,   37955   ,0 };
            const std::uint32_t dim4380KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   21  ,   9   ,   57  ,   35  ,   291 ,   371 ,   65  ,   2891    ,   841 ,   11859   ,   16685   ,   5641    ,0 };
            const std::uint32_t dim4381KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   3   ,   35  ,   121 ,   153 ,   353 ,   633 ,   995 ,   121 ,   7317    ,   273 ,   23329   ,   32591   ,0 };
            const std::uint32_t dim4382KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   25  ,   19  ,   35  ,   221 ,   295 ,   543 ,   1269    ,   3901    ,   2109    ,   4463    ,   4275    ,   89  ,0 };
            const std::uint32_t dim4383KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   1   ,   13  ,   85  ,   97  ,   155 ,   731 ,   1017    ,   3713    ,   1613    ,   805 ,   8927    ,   32165   ,0 };
            const std::uint32_t dim4384KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   17  ,   1   ,   21  ,   235 ,   103 ,   875 ,   1849    ,   2669    ,   3193    ,   9053    ,   16123   ,   29481   ,0 };
            const std::uint32_t dim4385KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   23  ,   21  ,   37  ,   251 ,   441 ,   437 ,   629 ,   1009    ,   5663    ,   14447   ,   23437   ,   32521   ,0 };
            const std::uint32_t dim4386KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   9   ,   5   ,   7   ,   123 ,   483 ,   433 ,   867 ,   149 ,   1975    ,   5497    ,   7887    ,   25779   ,0 };
            const std::uint32_t dim4387KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   31  ,   17  ,   81  ,   167 ,   399 ,   1   ,   1777    ,   833 ,   8035    ,   8597    ,   28371   ,   19293   ,0 };
            const std::uint32_t dim4388KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   9   ,   45  ,   125 ,   121 ,   147 ,   613 ,   599 ,   111 ,   7583    ,   3189    ,   13185   ,   35603   ,0 };
            const std::uint32_t dim4389KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   31  ,   51  ,   9   ,   191 ,   55  ,   837 ,   1773    ,   2781    ,   6351    ,   1909    ,   5407    ,   7533    ,0 };
            const std::uint32_t dim4390KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   13  ,   35  ,   71  ,   25  ,   465 ,   377 ,   613 ,   2487    ,   6297    ,   8299    ,   27541   ,   17779   ,0 };
            const std::uint32_t dim4391KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   21  ,   59  ,   43  ,   115 ,   369 ,   315 ,   315 ,   3451    ,   5785    ,   6353    ,   22609   ,   42793   ,0 };
            const std::uint32_t dim4392KuoInit[]        =   {   1   ,   1   ,   5   ,   15  ,   13  ,   3   ,   127 ,   87  ,   211 ,   981 ,   629 ,   2683    ,   5683    ,   15475   ,   20431   ,   32977   ,0 };
            const std::uint32_t dim4393KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   31  ,   3   ,   23  ,   7   ,   117 ,   1001    ,   431 ,   2215    ,   5817    ,   16283   ,   12781   ,   63883   ,0 };
            const std::uint32_t dim4394KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   27  ,   11  ,   43  ,   195 ,   329 ,   375 ,   655 ,   3815    ,   5699    ,   11259   ,   6733    ,   26015   ,0 };
            const std::uint32_t dim4395KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   19  ,   3   ,   63  ,   187 ,   47  ,   891 ,   1463    ,   3259    ,   1479    ,   15109   ,   25387   ,   43753   ,0 };
            const std::uint32_t dim4396KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   31  ,   43  ,   59  ,   149 ,   205 ,   447 ,   1787    ,   627 ,   6227    ,   9951    ,   19069   ,   50193   ,0 };
            const std::uint32_t dim4397KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   7   ,   1   ,   41  ,   33  ,   395 ,   139 ,   689 ,   1597    ,   529 ,   6861    ,   2025    ,   19569   ,0 };
            const std::uint32_t dim4398KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   17  ,   63  ,   17  ,   73  ,   459 ,   1007    ,   1563    ,   879 ,   1441    ,   525 ,   32679   ,   56409   ,0 };
            const std::uint32_t dim4399KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   3   ,   5   ,   23  ,   239 ,   7   ,   807 ,   1999    ,   1427    ,   6647    ,   2249    ,   17687   ,   5519    ,0 };
            const std::uint32_t dim4400KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   7   ,   15  ,   7   ,   243 ,   347 ,   415 ,   1519    ,   2267    ,   3119    ,   3145    ,   27799   ,   24453   ,0 };
            const std::uint32_t dim4401KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   5   ,   1   ,   93  ,   215 ,   475 ,   209 ,   361 ,   951 ,   147 ,   1401    ,   6851    ,   59257   ,0 };
            const std::uint32_t dim4402KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   29  ,   39  ,   67  ,   195 ,   287 ,   587 ,   315 ,   1747    ,   7169    ,   11967   ,   4893    ,   797 ,0 };
            const std::uint32_t dim4403KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   13  ,   49  ,   47  ,   97  ,   105 ,   203 ,   1237    ,   805 ,   3595    ,   9225    ,   23105   ,   52679   ,0 };
            const std::uint32_t dim4404KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   23  ,   41  ,   39  ,   85  ,   7   ,   237 ,   1545    ,   2591    ,   1771    ,   2291    ,   20185   ,   46995   ,0 };
            const std::uint32_t dim4405KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   15  ,   5   ,   43  ,   211 ,   109 ,   599 ,   77  ,   703 ,   5749    ,   15909   ,   12619   ,   41635   ,0 };
            const std::uint32_t dim4406KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   19  ,   9   ,   49  ,   211 ,   149 ,   883 ,   1617    ,   497 ,   7689    ,   4253    ,   18737   ,   25293   ,0 };
            const std::uint32_t dim4407KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   25  ,   3   ,   57  ,   83  ,   181 ,   801 ,   1515    ,   3821    ,   5287    ,   15243   ,   2347    ,   42333   ,0 };
            const std::uint32_t dim4408KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   15  ,   25  ,   107 ,   79  ,   249 ,   721 ,   1237    ,   1587    ,   3469    ,   10319   ,   6421    ,   59103   ,0 };
            const std::uint32_t dim4409KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   17  ,   21  ,   81  ,   35  ,   173 ,   101 ,   1879    ,   3301    ,   4409    ,   8563    ,   27981   ,   64269   ,0 };
            const std::uint32_t dim4410KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   29  ,   17  ,   103 ,   17  ,   443 ,   821 ,   1133    ,   73  ,   2587    ,   16119   ,   17385   ,   2293    ,0 };
            const std::uint32_t dim4411KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   9   ,   3   ,   41  ,   125 ,   149 ,   403 ,   537 ,   695 ,   3885    ,   15769   ,   11315   ,   53979   ,0 };
            const std::uint32_t dim4412KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   11  ,   47  ,   57  ,   105 ,   433 ,   1009    ,   1749    ,   2453    ,   2083    ,   1543    ,   25941   ,   58037   ,0 };
            const std::uint32_t dim4413KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   19  ,   63  ,   45  ,   251 ,   265 ,   591 ,   1235    ,   1349    ,   6069    ,   14139   ,   4299    ,   32719   ,0 };
            const std::uint32_t dim4414KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   1   ,   49  ,   125 ,   217 ,   247 ,   915 ,   1289    ,   3589    ,   7   ,   5285    ,   32443   ,   56439   ,0 };
            const std::uint32_t dim4415KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   31  ,   31  ,   67  ,   55  ,   203 ,   487 ,   983 ,   1841    ,   1587    ,   14881   ,   29187   ,   59293   ,0 };
            const std::uint32_t dim4416KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   1   ,   59  ,   121 ,   57  ,   99  ,   857 ,   1085    ,   3505    ,   3615    ,   13725   ,   10363   ,   16841   ,0 };
            const std::uint32_t dim4417KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   19  ,   55  ,   43  ,   95  ,   141 ,   217 ,   1087    ,   1129    ,   3417    ,   515 ,   23815   ,   13135   ,0 };
            const std::uint32_t dim4418KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   9   ,   63  ,   5   ,   139 ,   327 ,   743 ,   1321    ,   4055    ,   4337    ,   15115   ,   8635    ,   53571   ,0 };
            const std::uint32_t dim4419KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   31  ,   47  ,   105 ,   91  ,   493 ,   77  ,   1767    ,   1647    ,   4287    ,   5455    ,   1875    ,   6669    ,0 };
            const std::uint32_t dim4420KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   25  ,   47  ,   19  ,   243 ,   131 ,   387 ,   69  ,   2057    ,   7151    ,   8497    ,   10975   ,   64383   ,0 };
            const std::uint32_t dim4421KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   13  ,   19  ,   93  ,   35  ,   63  ,   881 ,   1787    ,   331 ,   57  ,   12875   ,   5689    ,   56411   ,0 };
            const std::uint32_t dim4422KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   1   ,   33  ,   39  ,   193 ,   17  ,   291 ,   1507    ,   1719    ,   3507    ,   12683   ,   16467   ,   21453   ,0 };
            const std::uint32_t dim4423KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   15  ,   41  ,   113 ,   23  ,   499 ,   641 ,   937 ,   2505    ,   4093    ,   4897    ,   2493    ,   28043   ,0 };
            const std::uint32_t dim4424KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   13  ,   11  ,   59  ,   175 ,   299 ,   233 ,   189 ,   675 ,   2623    ,   15695   ,   2895    ,   29213   ,0 };
            const std::uint32_t dim4425KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   25  ,   33  ,   113 ,   81  ,   485 ,   615 ,   1451    ,   1331    ,   607 ,   13451   ,   5853    ,   5051    ,0 };
            const std::uint32_t dim4426KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   13  ,   55  ,   107 ,   43  ,   343 ,   383 ,   63  ,   2761    ,   5543    ,   10249   ,   2903    ,   28567   ,0 };
            const std::uint32_t dim4427KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   7   ,   23  ,   13  ,   199 ,   109 ,   87  ,   389 ,   561 ,   2403    ,   12411   ,   18247   ,   40239   ,0 };
            const std::uint32_t dim4428KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   21  ,   31  ,   3   ,   109 ,   97  ,   803 ,   991 ,   847 ,   6517    ,   3389    ,   15347   ,   18295   ,0 };
            const std::uint32_t dim4429KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   27  ,   41  ,   115 ,   59  ,   189 ,   105 ,   63  ,   3169    ,   2293    ,   6051    ,   26017   ,   49947   ,0 };
            const std::uint32_t dim4430KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   19  ,   27  ,   47  ,   13  ,   9   ,   135 ,   637 ,   2167    ,   2865    ,   13353   ,   1725    ,   41671   ,0 };
            const std::uint32_t dim4431KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   17  ,   61  ,   37  ,   247 ,   447 ,   633 ,   1761    ,   2075    ,   6385    ,   12393   ,   31483   ,   1857    ,0 };
            const std::uint32_t dim4432KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   17  ,   17  ,   103 ,   47  ,   391 ,   725 ,   1379    ,   3939    ,   6467    ,   6723    ,   4229    ,   50221   ,0 };
            const std::uint32_t dim4433KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   1   ,   61  ,   13  ,   157 ,   379 ,   935 ,   105 ,   419 ,   147 ,   6369    ,   15413   ,   38553   ,0 };
            const std::uint32_t dim4434KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   13  ,   49  ,   63  ,   165 ,   207 ,   741 ,   1285    ,   3247    ,   4053    ,   1647    ,   6571    ,   61075   ,0 };
            const std::uint32_t dim4435KuoInit[]        =   {   1   ,   1   ,   5   ,   15  ,   29  ,   41  ,   51  ,   5   ,   123 ,   45  ,   537 ,   2887    ,   1329    ,   9447    ,   22285   ,   45247   ,0 };
            const std::uint32_t dim4436KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   29  ,   51  ,   65  ,   91  ,   153 ,   673 ,   1759    ,   401 ,   2969    ,   6631    ,   16965   ,   49027   ,0 };
            const std::uint32_t dim4437KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   29  ,   61  ,   31  ,   85  ,   13  ,   427 ,   1833    ,   2145    ,   4229    ,   14543   ,   22741   ,   24913   ,0 };
            const std::uint32_t dim4438KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   21  ,   9   ,   45  ,   253 ,   89  ,   397 ,   965 ,   685 ,   4013    ,   11731   ,   2947    ,   11995   ,0 };
            const std::uint32_t dim4439KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   27  ,   45  ,   101 ,   151 ,   21  ,   563 ,   203 ,   445 ,   6863    ,   2151    ,   4999    ,   8839    ,0 };
            const std::uint32_t dim4440KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   25  ,   57  ,   15  ,   29  ,   3   ,   127 ,   871 ,   1851    ,   7825    ,   1593    ,   11143   ,   24507   ,0 };
            const std::uint32_t dim4441KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   17  ,   27  ,   49  ,   159 ,   425 ,   773 ,   1841    ,   1693    ,   7829    ,   2905    ,   16347   ,   5581    ,0 };
            const std::uint32_t dim4442KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   13  ,   29  ,   81  ,   77  ,   349 ,   747 ,   119 ,   1195    ,   5   ,   8481    ,   1543    ,   50033   ,0 };
            const std::uint32_t dim4443KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   1   ,   25  ,   33  ,   13  ,   9   ,   565 ,   555 ,   699 ,   4691    ,   1749    ,   9531    ,   30133   ,0 };
            const std::uint32_t dim4444KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   13  ,   43  ,   17  ,   31  ,   199 ,   381 ,   393 ,   3511    ,   6331    ,   10377   ,   31467   ,   25305   ,0 };
            const std::uint32_t dim4445KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   1   ,   49  ,   23  ,   241 ,   499 ,   791 ,   1851    ,   321 ,   6057    ,   2141    ,   8825    ,   1829    ,0 };
            const std::uint32_t dim4446KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   13  ,   23  ,   77  ,   103 ,   123 ,   247 ,   1655    ,   1403    ,   6059    ,   14505   ,   1579    ,   48169   ,0 };
            const std::uint32_t dim4447KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   9   ,   23  ,   125 ,   15  ,   479 ,   447 ,   327 ,   3743    ,   1199    ,   5015    ,   19009   ,   50929   ,0 };
            const std::uint32_t dim4448KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   5   ,   55  ,   39  ,   131 ,   229 ,   607 ,   1591    ,   769 ,   2899    ,   9681    ,   11789   ,   62135   ,0 };
            const std::uint32_t dim4449KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   17  ,   59  ,   65  ,   117 ,   299 ,   85  ,   1187    ,   3249    ,   295 ,   15603   ,   28909   ,   60317   ,0 };
            const std::uint32_t dim4450KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   13  ,   31  ,   7   ,   5   ,   65  ,   785 ,   985 ,   1637    ,   3015    ,   14261   ,   15089   ,   37337   ,0 };
            const std::uint32_t dim4451KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   17  ,   49  ,   123 ,   151 ,   41  ,   419 ,   391 ,   1265    ,   6225    ,   2037    ,   8409    ,   13437   ,0 };
            const std::uint32_t dim4452KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   1   ,   23  ,   111 ,   21  ,   381 ,   343 ,   519 ,   1071    ,   3889    ,   14897   ,   9611    ,   10657   ,0 };
            const std::uint32_t dim4453KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   25  ,   15  ,   79  ,   215 ,   99  ,   783 ,   107 ,   3845    ,   443 ,   1115    ,   24657   ,   54263   ,0 };
            const std::uint32_t dim4454KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   7   ,   29  ,   15  ,   213 ,   165 ,   911 ,   351 ,   4025    ,   7657    ,   2079    ,   21525   ,   60751   ,0 };
            const std::uint32_t dim4455KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   15  ,   19  ,   107 ,   181 ,   177 ,   279 ,   803 ,   2825    ,   4609    ,   9955    ,   7725    ,   44161   ,0 };
            const std::uint32_t dim4456KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   21  ,   9   ,   69  ,   107 ,   43  ,   239 ,   397 ,   2567    ,   1375    ,   12483   ,   19783   ,   27889   ,0 };
            const std::uint32_t dim4457KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   7   ,   39  ,   39  ,   71  ,   397 ,   829 ,   373 ,   1869    ,   6229    ,   2299    ,   19737   ,   58479   ,0 };
            const std::uint32_t dim4458KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   13  ,   53  ,   39  ,   41  ,   105 ,   547 ,   1687    ,   153 ,   4067    ,   16317   ,   15  ,   52949   ,0 };
            const std::uint32_t dim4459KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   9   ,   19  ,   97  ,   45  ,   225 ,   977 ,   545 ,   3691    ,   5315    ,   6239    ,   26833   ,   28115   ,0 };
            const std::uint32_t dim4460KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   23  ,   11  ,   17  ,   13  ,   437 ,   145 ,   1153    ,   1193    ,   835 ,   5095    ,   5535    ,   17033   ,0 };
            const std::uint32_t dim4461KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   7   ,   13  ,   17  ,   197 ,   289 ,   875 ,   97  ,   1721    ,   2369    ,   8351    ,   10813   ,   10129   ,0 };
            const std::uint32_t dim4462KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   7   ,   59  ,   11  ,   37  ,   77  ,   541 ,   837 ,   2943    ,   423 ,   6093    ,   32495   ,   59203   ,0 };
            const std::uint32_t dim4463KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   13  ,   17  ,   117 ,   239 ,   499 ,   819 ,   1585    ,   1755    ,   219 ,   4681    ,   10771   ,   14713   ,0 };
            const std::uint32_t dim4464KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   15  ,   21  ,   3   ,   123 ,   303 ,   223 ,   1579    ,   1959    ,   7767    ,   6079    ,   2085    ,   7683    ,0 };
            const std::uint32_t dim4465KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   13  ,   37  ,   35  ,   37  ,   479 ,   341 ,   1315    ,   3339    ,   3059    ,   251 ,   31629   ,   32757   ,0 };
            const std::uint32_t dim4466KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   19  ,   23  ,   55  ,   109 ,   443 ,   77  ,   577 ,   1963    ,   3769    ,   1783    ,   5059    ,   35905   ,0 };
            const std::uint32_t dim4467KuoInit[]        =   {   1   ,   1   ,   5   ,   15  ,   17  ,   45  ,   53  ,   139 ,   261 ,   147 ,   1117    ,   2255    ,   1389    ,   6505    ,   21785   ,   52763   ,0 };
            const std::uint32_t dim4468KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   21  ,   61  ,   97  ,   147 ,   397 ,   231 ,   775 ,   3297    ,   4883    ,   7059    ,   16769   ,   22765   ,0 };
            const std::uint32_t dim4469KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   13  ,   29  ,   67  ,   117 ,   381 ,   505 ,   1437    ,   939 ,   4551    ,   8767    ,   7355    ,   10507   ,0 };
            const std::uint32_t dim4470KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   5   ,   57  ,   115 ,   205 ,   159 ,   587 ,   169 ,   3787    ,   1271    ,   9583    ,   12205   ,   63993   ,0 };
            const std::uint32_t dim4471KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   9   ,   59  ,   51  ,   165 ,   159 ,   391 ,   421 ,   2179    ,   2943    ,   505 ,   19315   ,   16175   ,0 };
            const std::uint32_t dim4472KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   21  ,   53  ,   95  ,   131 ,   275 ,   421 ,   435 ,   2655    ,   4999    ,   14225   ,   26417   ,   57465   ,0 };
            const std::uint32_t dim4473KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   29  ,   39  ,   115 ,   183 ,   507 ,   849 ,   1935    ,   2849    ,   6301    ,   11937   ,   19519   ,   37019   ,0 };
            const std::uint32_t dim4474KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   13  ,   15  ,   37  ,   25  ,   113 ,   885 ,   1265    ,   2287    ,   4535    ,   12265   ,   10433   ,   56641   ,0 };
            const std::uint32_t dim4475KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   29  ,   11  ,   67  ,   19  ,   11  ,   347 ,   1659    ,   3251    ,   3179    ,   2583    ,   10127   ,   21549   ,0 };
            const std::uint32_t dim4476KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   13  ,   27  ,   101 ,   101 ,   197 ,   381 ,   987 ,   1699    ,   2913    ,   5179    ,   3423    ,   30389   ,0 };
            const std::uint32_t dim4477KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   29  ,   39  ,   87  ,   65  ,   265 ,   891 ,   973 ,   1487    ,   6687    ,   7875    ,   13389   ,   39141   ,0 };
            const std::uint32_t dim4478KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   7   ,   13  ,   101 ,   223 ,   181 ,   143 ,   1291    ,   2803    ,   251 ,   12541   ,   20713   ,   18137   ,0 };
            const std::uint32_t dim4479KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   3   ,   9   ,   103 ,   137 ,   121 ,   563 ,   1079    ,   3119    ,   5619    ,   2175    ,   27223   ,   25289   ,0 };
            const std::uint32_t dim4480KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   7   ,   13  ,   109 ,   201 ,   385 ,   347 ,   319 ,   883 ,   13  ,   3683    ,   19615   ,   9781    ,0 };
            const std::uint32_t dim4481KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   13  ,   15  ,   127 ,   161 ,   353 ,   567 ,   555 ,   2287    ,   1791    ,   9535    ,   26227   ,   15335   ,0 };
            const std::uint32_t dim4482KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   3   ,   63  ,   11  ,   83  ,   235 ,   741 ,   977 ,   2265    ,   449 ,   10293   ,   20451   ,   25143   ,0 };
            const std::uint32_t dim4483KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   23  ,   25  ,   119 ,   1   ,   381 ,   463 ,   67  ,   257 ,   7087    ,   10553   ,   10781   ,   60003   ,0 };
            const std::uint32_t dim4484KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   17  ,   11  ,   81  ,   17  ,   363 ,   163 ,   1765    ,   285 ,   4239    ,   14777   ,   15081   ,   54151   ,0 };
            const std::uint32_t dim4485KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   17  ,   9   ,   73  ,   237 ,   273 ,   439 ,   1419    ,   1539    ,   667 ,   13833   ,   31783   ,   49459   ,0 };
            const std::uint32_t dim4486KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   15  ,   11  ,   85  ,   3   ,   481 ,   169 ,   1443    ,   3403    ,   1157    ,   595 ,   6851    ,   59343   ,0 };
            const std::uint32_t dim4487KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   23  ,   21  ,   13  ,   251 ,   403 ,   859 ,   175 ,   1373    ,   3711    ,   1233    ,   16879   ,   4659    ,0 };
            const std::uint32_t dim4488KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   21  ,   7   ,   15  ,   165 ,   265 ,   117 ,   385 ,   2661    ,   1481    ,   1709    ,   19843   ,   29639   ,0 };
            const std::uint32_t dim4489KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   3   ,   7   ,   81  ,   3   ,   429 ,   997 ,   1759    ,   285 ,   375 ,   3487    ,   5257    ,   14203   ,0 };
            const std::uint32_t dim4490KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   15  ,   17  ,   93  ,   69  ,   303 ,   809 ,   929 ,   3025    ,   6333    ,   4525    ,   6441    ,   32265   ,0 };
            const std::uint32_t dim4491KuoInit[]        =   {   1   ,   3   ,   1   ,   5   ,   27  ,   41  ,   119 ,   25  ,   461 ,   347 ,   369 ,   489 ,   377 ,   3899    ,   12711   ,   24475   ,0 };
            const std::uint32_t dim4492KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   29  ,   59  ,   101 ,   159 ,   305 ,   337 ,   1371    ,   891 ,   6013    ,   2987    ,   27201   ,   61055   ,0 };
            const std::uint32_t dim4493KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   19  ,   5   ,   3   ,   219 ,   71  ,   213 ,   137 ,   1925    ,   2365    ,   583 ,   11591   ,   9495    ,0 };
            const std::uint32_t dim4494KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   31  ,   31  ,   85  ,   115 ,   169 ,   499 ,   1669    ,   499 ,   1987    ,   2505    ,   435 ,   6377    ,0 };
            const std::uint32_t dim4495KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   3   ,   33  ,   33  ,   41  ,   199 ,   187 ,   1023    ,   771 ,   3447    ,   4355    ,   29353   ,   42293   ,0 };
            const std::uint32_t dim4496KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   1   ,   41  ,   17  ,   231 ,   305 ,   975 ,   975 ,   1697    ,   7267    ,   9567    ,   9975    ,   51313   ,0 };
            const std::uint32_t dim4497KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   9   ,   41  ,   27  ,   29  ,   285 ,   469 ,   1845    ,   665 ,   3007    ,   4199    ,   3367    ,   50849   ,0 };
            const std::uint32_t dim4498KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   29  ,   5   ,   93  ,   63  ,   227 ,   751 ,   1591    ,   649 ,   6219    ,   13371   ,   3473    ,   34033   ,0 };
            const std::uint32_t dim4499KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   13  ,   5   ,   27  ,   239 ,   89  ,   893 ,   1869    ,   3789    ,   7569    ,   525 ,   32019   ,   17501   ,0 };
            const std::uint32_t dim4500KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   9   ,   5   ,   51  ,   149 ,   351 ,   81  ,   1895    ,   3011    ,   2521    ,   4185    ,   1277    ,   65397   ,0 };
            const std::uint32_t dim4501KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   21  ,   13  ,   121 ,   213 ,   67  ,   825 ,   1493    ,   2933    ,   6189    ,   14135   ,   7021    ,   47435   ,0 };
            const std::uint32_t dim4502KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   11  ,   51  ,   63  ,   163 ,   371 ,   363 ,   1885    ,   1535    ,   629 ,   2939    ,   12547   ,   24779   ,0 };
            const std::uint32_t dim4503KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   3   ,   3   ,   49  ,   47  ,   409 ,   963 ,   1499    ,   1107    ,   8063    ,   11137   ,   21251   ,   4695    ,0 };
            const std::uint32_t dim4504KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   31  ,   17  ,   61  ,   149 ,   263 ,   503 ,   219 ,   3419    ,   4525    ,   14689   ,   30841   ,   60799   ,0 };
            const std::uint32_t dim4505KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   31  ,   25  ,   5   ,   247 ,   219 ,   79  ,   1605    ,   3523    ,   4815    ,   12907   ,   22017   ,   16145   ,0 };
            const std::uint32_t dim4506KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   21  ,   51  ,   47  ,   85  ,   37  ,   461 ,   1299    ,   2007    ,   2093    ,   10707   ,   17997   ,   4221    ,0 };
            const std::uint32_t dim4507KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   11  ,   59  ,   63  ,   191 ,   359 ,   859 ,   1265    ,   853 ,   6733    ,   4605    ,   27559   ,   32557   ,0 };
            const std::uint32_t dim4508KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   29  ,   61  ,   119 ,   73  ,   73  ,   259 ,   1939    ,   59  ,   5177    ,   12375   ,   22143   ,   28073   ,0 };
            const std::uint32_t dim4509KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   21  ,   29  ,   19  ,   33  ,   59  ,   539 ,   281 ,   2989    ,   2239    ,   6671    ,   31629   ,   16065   ,0 };
            const std::uint32_t dim4510KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   17  ,   27  ,   39  ,   57  ,   483 ,   463 ,   51  ,   3771    ,   5641    ,   5875    ,   2369    ,   21619   ,0 };
            const std::uint32_t dim4511KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   15  ,   9   ,   121 ,   217 ,   107 ,   615 ,   1413    ,   2083    ,   231 ,   9177    ,   12275   ,   20069   ,0 };
            const std::uint32_t dim4512KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   17  ,   55  ,   85  ,   27  ,   477 ,   687 ,   1295    ,   3471    ,   6951    ,   2645    ,   30051   ,   36149   ,0 };
            const std::uint32_t dim4513KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   1   ,   27  ,   9   ,   183 ,   39  ,   559 ,   1639    ,   5   ,   1177    ,   16011   ,   1447    ,   42897   ,0 };
            const std::uint32_t dim4514KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   21  ,   9   ,   75  ,   217 ,   311 ,   679 ,   1913    ,   2623    ,   3853    ,   10889   ,   22501   ,   40089   ,0 };
            const std::uint32_t dim4515KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   17  ,   59  ,   23  ,   199 ,   147 ,   339 ,   1027    ,   1471    ,   6539    ,   7963    ,   30713   ,   1939    ,0 };
            const std::uint32_t dim4516KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   23  ,   51  ,   111 ,   175 ,   433 ,   803 ,   1577    ,   4091    ,   2197    ,   10003   ,   2597    ,   53553   ,0 };
            const std::uint32_t dim4517KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   3   ,   11  ,   125 ,   11  ,   281 ,   969 ,   1943    ,   1003    ,   2189    ,   3551    ,   25831   ,   64261   ,0 };
            const std::uint32_t dim4518KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   17  ,   19  ,   111 ,   235 ,   511 ,   723 ,   1779    ,   1041    ,   4067    ,   3827    ,   17285   ,   63075   ,0 };
            const std::uint32_t dim4519KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   3   ,   63  ,   7   ,   165 ,   153 ,   829 ,   221 ,   1485    ,   4319    ,   9865    ,   937 ,   65171   ,0 };
            const std::uint32_t dim4520KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   21  ,   21  ,   89  ,   233 ,   417 ,   15  ,   367 ,   311 ,   3575    ,   11285   ,   5245    ,   3947    ,0 };
            const std::uint32_t dim4521KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   27  ,   55  ,   3   ,   71  ,   227 ,   397 ,   561 ,   4075    ,   5495    ,   16071   ,   11495   ,   48733   ,0 };
            const std::uint32_t dim4522KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   3   ,   39  ,   57  ,   219 ,   237 ,   151 ,   1305    ,   2485    ,   5045    ,   5065    ,   21041   ,   20055   ,0 };
            const std::uint32_t dim4523KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   15  ,   33  ,   75  ,   241 ,   335 ,   207 ,   1695    ,   119 ,   839 ,   12449   ,   28467   ,   7445    ,0 };
            const std::uint32_t dim4524KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   21  ,   3   ,   43  ,   137 ,   321 ,   763 ,   575 ,   2317    ,   8073    ,   1225    ,   8257    ,   11639   ,0 };
            const std::uint32_t dim4525KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   27  ,   21  ,   17  ,   115 ,   265 ,   1023    ,   1403    ,   853 ,   757 ,   1799    ,   25505   ,   49207   ,0 };
            const std::uint32_t dim4526KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   9   ,   45  ,   57  ,   77  ,   127 ,   447 ,   1097    ,   1729    ,   2361    ,   1599    ,   15727   ,   49413   ,0 };
            const std::uint32_t dim4527KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   21  ,   41  ,   13  ,   41  ,   183 ,   151 ,   441 ,   3077    ,   4205    ,   125 ,   23767   ,   44667   ,0 };
            const std::uint32_t dim4528KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   3   ,   37  ,   5   ,   203 ,   39  ,   49  ,   1793    ,   3523    ,   7541    ,   23  ,   22527   ,   35999   ,0 };
            const std::uint32_t dim4529KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   13  ,   5   ,   127 ,   169 ,   465 ,   759 ,   393 ,   1543    ,   3327    ,   6223    ,   18675   ,   36075   ,0 };
            const std::uint32_t dim4530KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   17  ,   57  ,   83  ,   237 ,   307 ,   495 ,   135 ,   1461    ,   4353    ,   15251   ,   10005   ,   12769   ,0 };
            const std::uint32_t dim4531KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   27  ,   49  ,   57  ,   19  ,   463 ,   97  ,   217 ,   2825    ,   7729    ,   2375    ,   8339    ,   17563   ,0 };
            const std::uint32_t dim4532KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   31  ,   13  ,   17  ,   245 ,   329 ,   1021    ,   619 ,   3149    ,   7089    ,   4381    ,   14079   ,   35659   ,0 };
            const std::uint32_t dim4533KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   31  ,   19  ,   15  ,   217 ,   115 ,   159 ,   281 ,   2233    ,   4315    ,   7429    ,   25527   ,   44671   ,0 };
            const std::uint32_t dim4534KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   11  ,   23  ,   7   ,   181 ,   43  ,   271 ,   607 ,   389 ,   357 ,   3003    ,   15899   ,   50849   ,0 };
            const std::uint32_t dim4535KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   11  ,   15  ,   41  ,   247 ,   37  ,   163 ,   665 ,   3059    ,   5151    ,   15335   ,   13167   ,   18541   ,0 };
            const std::uint32_t dim4536KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   25  ,   33  ,   33  ,   135 ,   425 ,   785 ,   1557    ,   793 ,   7153    ,   13473   ,   8833    ,   21335   ,0 };
            const std::uint32_t dim4537KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   17  ,   27  ,   7   ,   75  ,   205 ,   71  ,   581 ,   733 ,   5009    ,   1029    ,   27537   ,   41905   ,0 };
            const std::uint32_t dim4538KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   5   ,   63  ,   121 ,   3   ,   381 ,   607 ,   1099    ,   1571    ,   1077    ,   15491   ,   13785   ,   31537   ,0 };
            const std::uint32_t dim4539KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   17  ,   15  ,   87  ,   81  ,   313 ,   683 ,   31  ,   3301    ,   1683    ,   12667   ,   17867   ,   38405   ,0 };
            const std::uint32_t dim4540KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   3   ,   23  ,   51  ,   95  ,   409 ,   711 ,   381 ,   245 ,   7   ,   15679   ,   14281   ,   39789   ,0 };
            const std::uint32_t dim4541KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   31  ,   35  ,   97  ,   35  ,   121 ,   45  ,   1397    ,   4009    ,   2829    ,   3273    ,   2725    ,   913 ,0 };
            const std::uint32_t dim4542KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   29  ,   29  ,   111 ,   153 ,   499 ,   371 ,   1767    ,   3063    ,   6175    ,   8205    ,   3485    ,   8951    ,0 };
            const std::uint32_t dim4543KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   27  ,   9   ,   113 ,   141 ,   295 ,   901 ,   1367    ,   791 ,   1645    ,   5993    ,   6139    ,   12853   ,0 };
            const std::uint32_t dim4544KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   27  ,   17  ,   113 ,   187 ,   293 ,   517 ,   1327    ,   579 ,   1191    ,   12039   ,   13973   ,   51129   ,0 };
            const std::uint32_t dim4545KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   11  ,   9   ,   55  ,   71  ,   47  ,   787 ,   1311    ,   2567    ,   7555    ,   2825    ,   11485   ,   16787   ,0 };
            const std::uint32_t dim4546KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   29  ,   33  ,   115 ,   115 ,   69  ,   155 ,   1185    ,   2653    ,   7127    ,   1449    ,   8875    ,   34819   ,0 };
            const std::uint32_t dim4547KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   9   ,   61  ,   61  ,   161 ,   29  ,   33  ,   1155    ,   613 ,   7233    ,   2811    ,   4837    ,   27781   ,0 };
            const std::uint32_t dim4548KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   25  ,   57  ,   85  ,   121 ,   505 ,   45  ,   1143    ,   3237    ,   6403    ,   2377    ,   30791   ,   26637   ,0 };
            const std::uint32_t dim4549KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   31  ,   39  ,   63  ,   255 ,   153 ,   417 ,   865 ,   441 ,   7649    ,   16321   ,   29147   ,   11089   ,0 };
            const std::uint32_t dim4550KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   25  ,   19  ,   43  ,   45  ,   457 ,   353 ,   25  ,   1135    ,   4663    ,   11419   ,   25373   ,   8411    ,0 };
            const std::uint32_t dim4551KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   11  ,   47  ,   101 ,   255 ,   437 ,   937 ,   263 ,   1171    ,   7893    ,   277 ,   4413    ,   20197   ,0 };
            const std::uint32_t dim4552KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   21  ,   61  ,   1   ,   31  ,   227 ,   345 ,   1535    ,   1597    ,   7061    ,   11595   ,   12055   ,   29611   ,0 };
            const std::uint32_t dim4553KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   19  ,   49  ,   83  ,   61  ,   305 ,   611 ,   399 ,   1397    ,   4753    ,   2309    ,   15097   ,   13439   ,0 };
            const std::uint32_t dim4554KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   27  ,   37  ,   77  ,   165 ,   273 ,   85  ,   483 ,   299 ,   5073    ,   1255    ,   4073    ,   56333   ,0 };
            const std::uint32_t dim4555KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   5   ,   11  ,   127 ,   157 ,   489 ,   653 ,   165 ,   2071    ,   4819    ,   121 ,   32755   ,   21623   ,0 };
            const std::uint32_t dim4556KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   23  ,   5   ,   111 ,   25  ,   173 ,   661 ,   353 ,   1167    ,   2625    ,   8021    ,   18731   ,   42705   ,0 };
            const std::uint32_t dim4557KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   9   ,   33  ,   31  ,   137 ,   283 ,   925 ,   1641    ,   115 ,   7047    ,   11365   ,   13097   ,   4711    ,0 };
            const std::uint32_t dim4558KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   13  ,   13  ,   29  ,   135 ,   273 ,   325 ,   1085    ,   1683    ,   1365    ,   9931    ,   8557    ,   3855    ,0 };
            const std::uint32_t dim4559KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   17  ,   27  ,   103 ,   183 ,   237 ,   343 ,   907 ,   2945    ,   3039    ,   12873   ,   28635   ,   14791   ,0 };
            const std::uint32_t dim4560KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   5   ,   51  ,   13  ,   57  ,   131 ,   1021    ,   1995    ,   921 ,   6911    ,   14381   ,   17113   ,   56783   ,0 };
            const std::uint32_t dim4561KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   5   ,   55  ,   89  ,   29  ,   409 ,   687 ,   1151    ,   3423    ,   1893    ,   12153   ,   8167    ,   14849   ,0 };
            const std::uint32_t dim4562KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   1   ,   53  ,   41  ,   53  ,   81  ,   797 ,   1665    ,   85  ,   8131    ,   3853    ,   17815   ,   7771    ,0 };
            const std::uint32_t dim4563KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   31  ,   41  ,   37  ,   107 ,   319 ,   421 ,   279 ,   2061    ,   1981    ,   6917    ,   25545   ,   46053   ,0 };
            const std::uint32_t dim4564KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   13  ,   25  ,   85  ,   203 ,   399 ,   863 ,   1577    ,   1445    ,   8093    ,   1845    ,   16307   ,   61075   ,0 };
            const std::uint32_t dim4565KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   1   ,   35  ,   117 ,   201 ,   271 ,   901 ,   1939    ,   2291    ,   343 ,   13591   ,   28371   ,   61429   ,0 };
            const std::uint32_t dim4566KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   21  ,   55  ,   85  ,   123 ,   183 ,   787 ,   1121    ,   447 ,   5761    ,   6925    ,   22407   ,   53149   ,0 };
            const std::uint32_t dim4567KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   31  ,   25  ,   63  ,   247 ,   109 ,   741 ,   231 ,   2621    ,   4939    ,   11155   ,   21625   ,   30433   ,0 };
            const std::uint32_t dim4568KuoInit[]        =   {   1   ,   1   ,   5   ,   15  ,   3   ,   49  ,   63  ,   147 ,   117 ,   703 ,   1317    ,   2803    ,   4655    ,   5981    ,   14473   ,   52739   ,0 };
            const std::uint32_t dim4569KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   27  ,   45  ,   117 ,   55  ,   391 ,   275 ,   1793    ,   1279    ,   4799    ,   15509   ,   17173   ,   25103   ,0 };
            const std::uint32_t dim4570KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   27  ,   15  ,   35  ,   43  ,   209 ,   869 ,   1833    ,   3625    ,   5973    ,   8965    ,   1443    ,   59053   ,0 };
            const std::uint32_t dim4571KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   1   ,   19  ,   93  ,   63  ,   407 ,   735 ,   1821    ,   2875    ,   1263    ,   1461    ,   7811    ,   17257   ,0 };
            const std::uint32_t dim4572KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   15  ,   35  ,   3   ,   89  ,   355 ,   983 ,   1183    ,   2709    ,   127 ,   10671   ,   31223   ,   26689   ,0 };
            const std::uint32_t dim4573KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   15  ,   29  ,   105 ,   239 ,   293 ,   57  ,   515 ,   363 ,   5227    ,   14693   ,   18437   ,   13107   ,0 };
            const std::uint32_t dim4574KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   29  ,   61  ,   65  ,   77  ,   23  ,   311 ,   1581    ,   215 ,   1409    ,   2575    ,   13915   ,   63179   ,0 };
            const std::uint32_t dim4575KuoInit[]        =   {   1   ,   3   ,   1   ,   5   ,   27  ,   17  ,   113 ,   255 ,   347 ,   493 ,   1795    ,   817 ,   7483    ,   10611   ,   9941    ,   56425   ,0 };
            const std::uint32_t dim4576KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   1   ,   29  ,   79  ,   153 ,   183 ,   975 ,   1127    ,   881 ,   1319    ,   11481   ,   16807   ,   23167   ,0 };
            const std::uint32_t dim4577KuoInit[]        =   {   1   ,   1   ,   5   ,   15  ,   7   ,   31  ,   107 ,   245 ,   59  ,   579 ,   423 ,   2165    ,   5137    ,   14735   ,   13187   ,   28781   ,0 };
            const std::uint32_t dim4578KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   13  ,   55  ,   63  ,   155 ,   63  ,   581 ,   1083    ,   2249    ,   7397    ,   2081    ,   23727   ,   23981   ,0 };
            const std::uint32_t dim4579KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   23  ,   29  ,   93  ,   215 ,   361 ,   71  ,   119 ,   3215    ,   3529    ,   14249   ,   29593   ,   27305   ,0 };
            const std::uint32_t dim4580KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   5   ,   63  ,   45  ,   181 ,   463 ,   21  ,   229 ,   4069    ,   4889    ,   2141    ,   25623   ,   6191    ,0 };
            const std::uint32_t dim4581KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   17  ,   31  ,   105 ,   153 ,   301 ,   433 ,   517 ,   585 ,   285 ,   12805   ,   30173   ,   21363   ,0 };
            const std::uint32_t dim4582KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   29  ,   23  ,   117 ,   19  ,   415 ,   389 ,   881 ,   2067    ,   583 ,   11383   ,   24951   ,   34745   ,0 };
            const std::uint32_t dim4583KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   27  ,   55  ,   37  ,   5   ,   337 ,   943 ,   1851    ,   3227    ,   3881    ,   7365    ,   10853   ,   23325   ,0 };
            const std::uint32_t dim4584KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   25  ,   5   ,   39  ,   189 ,   503 ,   745 ,   1349    ,   3881    ,   5037    ,   13855   ,   19537   ,   22329   ,0 };
            const std::uint32_t dim4585KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   7   ,   33  ,   63  ,   61  ,   39  ,   825 ,   53  ,   1471    ,   3589    ,   13473   ,   29241   ,   40829   ,0 };
            const std::uint32_t dim4586KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   1   ,   37  ,   111 ,   251 ,   427 ,   427 ,   937 ,   3921    ,   8033    ,   269 ,   14261   ,   37345   ,0 };
            const std::uint32_t dim4587KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   31  ,   59  ,   111 ,   205 ,   285 ,   113 ,   951 ,   2867    ,   3769    ,   5237    ,   693 ,   42097   ,0 };
            const std::uint32_t dim4588KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   29  ,   43  ,   15  ,   253 ,   383 ,   783 ,   1407    ,   3851    ,   4333    ,   11607   ,   12777   ,   55499   ,0 };
            const std::uint32_t dim4589KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   15  ,   27  ,   75  ,   57  ,   87  ,   185 ,   1079    ,   2721    ,   915 ,   13633   ,   26439   ,   10697   ,0 };
            const std::uint32_t dim4590KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   17  ,   63  ,   43  ,   65  ,   5   ,   699 ,   1157    ,   2271    ,   837 ,   687 ,   29551   ,   22109   ,0 };
            const std::uint32_t dim4591KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   5   ,   47  ,   103 ,   143 ,   281 ,   81  ,   283 ,   3073    ,   3741    ,   11525   ,   4499    ,   41325   ,0 };
            const std::uint32_t dim4592KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   13  ,   19  ,   63  ,   215 ,   215 ,   21  ,   1443    ,   2485    ,   2661    ,   8123    ,   11739   ,   48729   ,0 };
            const std::uint32_t dim4593KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   27  ,   13  ,   111 ,   153 ,   17  ,   715 ,   1453    ,   1827    ,   5201    ,   1139    ,   19531   ,   18853   ,0 };
            const std::uint32_t dim4594KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   7   ,   61  ,   109 ,   213 ,   383 ,   483 ,   301 ,   1791    ,   559 ,   14205   ,   28441   ,   13179   ,0 };
            const std::uint32_t dim4595KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   23  ,   55  ,   119 ,   45  ,   467 ,   775 ,   951 ,   2533    ,   6703    ,   15791   ,   12891   ,   54513   ,0 };
            const std::uint32_t dim4596KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   19  ,   49  ,   71  ,   127 ,   455 ,   881 ,   329 ,   663 ,   4997    ,   8755    ,   17517   ,   31507   ,0 };
            const std::uint32_t dim4597KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   9   ,   13  ,   75  ,   161 ,   109 ,   631 ,   153 ,   15  ,   1181    ,   14299   ,   11815   ,   32017   ,0 };
            const std::uint32_t dim4598KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   9   ,   63  ,   101 ,   85  ,   487 ,   213 ,   1743    ,   2575    ,   6979    ,   14421   ,   18051   ,   14505   ,0 };
            const std::uint32_t dim4599KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   5   ,   5   ,   109 ,   245 ,   427 ,   765 ,   2013    ,   2929    ,   6737    ,   14561   ,   32227   ,   60605   ,0 };
            const std::uint32_t dim4600KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   1   ,   7   ,   17  ,   169 ,   27  ,   925 ,   1711    ,   101 ,   2065    ,   4857    ,   863 ,   38371   ,0 };
            const std::uint32_t dim4601KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   5   ,   25  ,   119 ,   145 ,   27  ,   377 ,   1535    ,   441 ,   5181    ,   9789    ,   26757   ,   46977   ,0 };
            const std::uint32_t dim4602KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   31  ,   1   ,   79  ,   223 ,   199 ,   409 ,   2033    ,   1781    ,   5269    ,   2631    ,   10627   ,   41785   ,0 };
            const std::uint32_t dim4603KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   29  ,   7   ,   91  ,   123 ,   407 ,   19  ,   847 ,   4019    ,   1029    ,   15763   ,   30265   ,   49287   ,0 };
            const std::uint32_t dim4604KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   1   ,   37  ,   33  ,   53  ,   49  ,   949 ,   1737    ,   229 ,   3419    ,   5125    ,   16365   ,   48867   ,0 };
            const std::uint32_t dim4605KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   25  ,   17  ,   13  ,   31  ,   27  ,   53  ,   287 ,   4021    ,   7687    ,   14511   ,   12627   ,   54409   ,0 };
            const std::uint32_t dim4606KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   21  ,   29  ,   1   ,   193 ,   479 ,   895 ,   605 ,   2013    ,   6571    ,   14073   ,   28185   ,   58845   ,0 };
            const std::uint32_t dim4607KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   3   ,   21  ,   111 ,   215 ,   259 ,   941 ,   1729    ,   645 ,   695 ,   3295    ,   23825   ,   1009    ,0 };
            const std::uint32_t dim4608KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   25  ,   17  ,   103 ,   187 ,   153 ,   287 ,   911 ,   1265    ,   41  ,   1687    ,   22443   ,   21117   ,0 };
            const std::uint32_t dim4609KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   31  ,   25  ,   3   ,   107 ,   271 ,   531 ,   1413    ,   2813    ,   5075    ,   2127    ,   18647   ,   5257    ,0 };
            const std::uint32_t dim4610KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   5   ,   25  ,   71  ,   225 ,   391 ,   877 ,   1713    ,   1841    ,   3239    ,   9063    ,   11445   ,   48693   ,0 };
            const std::uint32_t dim4611KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   21  ,   25  ,   15  ,   157 ,   59  ,   37  ,   1349    ,   413 ,   6401    ,   3533    ,   6019    ,   40373   ,0 };
            const std::uint32_t dim4612KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   5   ,   3   ,   31  ,   185 ,   59  ,   933 ,   1415    ,   901 ,   6075    ,   4839    ,   32477   ,   43085   ,0 };
            const std::uint32_t dim4613KuoInit[]        =   {   1   ,   3   ,   1   ,   5   ,   11  ,   7   ,   81  ,   109 ,   167 ,   277 ,   1803    ,   39  ,   7421    ,   15573   ,   2233    ,   8193    ,0 };
            const std::uint32_t dim4614KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   13  ,   15  ,   47  ,   109 ,   279 ,   515 ,   1393    ,   1785    ,   4297    ,   813 ,   19177   ,   5951    ,0 };
            const std::uint32_t dim4615KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   21  ,   23  ,   3   ,   27  ,   317 ,   677 ,   1775    ,   1109    ,   93  ,   9007    ,   8767    ,   42181   ,0 };
            const std::uint32_t dim4616KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   23  ,   15  ,   49  ,   9   ,   369 ,   293 ,   529 ,   2115    ,   4781    ,   1955    ,   21897   ,   22871   ,0 };
            const std::uint32_t dim4617KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   5   ,   39  ,   85  ,   85  ,   405 ,   837 ,   1891    ,   27  ,   509 ,   14643   ,   10497   ,   34021   ,0 };
            const std::uint32_t dim4618KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   7   ,   47  ,   49  ,   87  ,   481 ,   1003    ,   741 ,   329 ,   2951    ,   5317    ,   21601   ,   20485   ,0 };
            const std::uint32_t dim4619KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   27  ,   61  ,   45  ,   251 ,   489 ,   623 ,   1673    ,   891 ,   5429    ,   4457    ,   23147   ,   5201    ,0 };
            const std::uint32_t dim4620KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   25  ,   27  ,   3   ,   233 ,   193 ,   253 ,   483 ,   1881    ,   6753    ,   7843    ,   3975    ,   23413   ,0 };
            const std::uint32_t dim4621KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   27  ,   31  ,   51  ,   213 ,   463 ,   995 ,   1127    ,   3589    ,   1409    ,   15743   ,   22755   ,   39913   ,0 };
            const std::uint32_t dim4622KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   21  ,   17  ,   35  ,   157 ,   233 ,   899 ,   1003    ,   201 ,   3425    ,   6703    ,   26585   ,   18389   ,0 };
            const std::uint32_t dim4623KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   11  ,   23  ,   69  ,   93  ,   361 ,   177 ,   1071    ,   3523    ,   4117    ,   6107    ,   3701    ,   64213   ,0 };
            const std::uint32_t dim4624KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   19  ,   1   ,   35  ,   95  ,   385 ,   853 ,   1635    ,   1815    ,   5307    ,   3155    ,   11347   ,   39289   ,0 };
            const std::uint32_t dim4625KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   3   ,   41  ,   37  ,   161 ,   293 ,   1005    ,   1915    ,   2867    ,   841 ,   195 ,   4247    ,   8621    ,0 };
            const std::uint32_t dim4626KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   19  ,   43  ,   69  ,   95  ,   455 ,   669 ,   217 ,   129 ,   1275    ,   8431    ,   22519   ,   39261   ,0 };
            const std::uint32_t dim4627KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   31  ,   49  ,   105 ,   61  ,   437 ,   923 ,   1579    ,   1695    ,   7129    ,   10555   ,   3177    ,   6667    ,0 };
            const std::uint32_t dim4628KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   3   ,   47  ,   29  ,   159 ,   207 ,   969 ,   433 ,   3541    ,   689 ,   1255    ,   1359    ,   38349   ,0 };
            const std::uint32_t dim4629KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   9   ,   31  ,   23  ,   37  ,   435 ,   729 ,   121 ,   2483    ,   8009    ,   14229   ,   6961    ,   40681   ,0 };
            const std::uint32_t dim4630KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   19  ,   33  ,   111 ,   131 ,   155 ,   641 ,   795 ,   3753    ,   4381    ,   11135   ,   8381    ,   62553   ,0 };
            const std::uint32_t dim4631KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   29  ,   37  ,   15  ,   245 ,   341 ,   1023    ,   1123    ,   3317    ,   2409    ,   8957    ,   4607    ,   53947   ,0 };
            const std::uint32_t dim4632KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   7   ,   19  ,   105 ,   187 ,   407 ,   339 ,   607 ,   11  ,   1679    ,   13701   ,   2385    ,   6203    ,0 };
            const std::uint32_t dim4633KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   7   ,   63  ,   7   ,   173 ,   475 ,   87  ,   807 ,   1467    ,   791 ,   1949    ,   20839   ,   54179   ,0 };
            const std::uint32_t dim4634KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   25  ,   25  ,   111 ,   155 ,   249 ,   55  ,   1455    ,   2503    ,   6869    ,   14463   ,   10519   ,   56761   ,0 };
            const std::uint32_t dim4635KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   9   ,   31  ,   89  ,   235 ,   499 ,   61  ,   747 ,   487 ,   6767    ,   4777    ,   12513   ,   43677   ,0 };
            const std::uint32_t dim4636KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   25  ,   47  ,   13  ,   3   ,   313 ,   541 ,   1323    ,   3551    ,   7971    ,   1453    ,   1531    ,   38915   ,0 };
            const std::uint32_t dim4637KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   7   ,   63  ,   125 ,   243 ,   199 ,   875 ,   791 ,   103 ,   3997    ,   16199   ,   20615   ,   18359   ,0 };
            const std::uint32_t dim4638KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   21  ,   19  ,   13  ,   9   ,   117 ,   625 ,   1333    ,   561 ,   889 ,   10961   ,   11313   ,   48139   ,0 };
            const std::uint32_t dim4639KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   19  ,   57  ,   121 ,   163 ,   333 ,   681 ,   1065    ,   885 ,   5961    ,   6385    ,   20135   ,   19733   ,0 };
            const std::uint32_t dim4640KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   27  ,   11  ,   113 ,   187 ,   91  ,   83  ,   591 ,   517 ,   7379    ,   12823   ,   31815   ,   14721   ,0 };
            const std::uint32_t dim4641KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   27  ,   21  ,   47  ,   203 ,   411 ,   191 ,   881 ,   2597    ,   6107    ,   135 ,   14525   ,   4059    ,0 };
            const std::uint32_t dim4642KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   29  ,   3   ,   61  ,   231 ,   259 ,   425 ,   1953    ,   803 ,   7921    ,   2321    ,   28919   ,   41349   ,0 };
            const std::uint32_t dim4643KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   27  ,   7   ,   87  ,   197 ,   287 ,   345 ,   457 ,   1813    ,   2701    ,   2095    ,   32705   ,   52579   ,0 };
            const std::uint32_t dim4644KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   13  ,   59  ,   87  ,   105 ,   49  ,   387 ,   73  ,   2983    ,   6453    ,   10977   ,   8851    ,   61031   ,0 };
            const std::uint32_t dim4645KuoInit[]        =   {   1   ,   3   ,   5   ,   7   ,   1   ,   53  ,   121 ,   129 ,   307 ,   251 ,   1405    ,   3093    ,   4487    ,   1953    ,   2681    ,   4391    ,0 };
            const std::uint32_t dim4646KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   1   ,   29  ,   119 ,   125 ,   95  ,   425 ,   385 ,   1577    ,   3387    ,   14709   ,   25143   ,   4317    ,0 };
            const std::uint32_t dim4647KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   27  ,   59  ,   53  ,   203 ,   75  ,   731 ,   1019    ,   3179    ,   4533    ,   3217    ,   30801   ,   53439   ,0 };
            const std::uint32_t dim4648KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   29  ,   53  ,   93  ,   251 ,   441 ,   75  ,   363 ,   2405    ,   6263    ,   12121   ,   11963   ,   13219   ,0 };
            const std::uint32_t dim4649KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   3   ,   7   ,   57  ,   169 ,   387 ,   543 ,   1027    ,   1169    ,   5089    ,   5077    ,   17933   ,   8131    ,0 };
            const std::uint32_t dim4650KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   17  ,   17  ,   123 ,   161 ,   21  ,   641 ,   795 ,   2415    ,   2743    ,   1489    ,   25137   ,   19393   ,0 };
            const std::uint32_t dim4651KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   1   ,   47  ,   37  ,   95  ,   315 ,   37  ,   1481    ,   2189    ,   687 ,   2859    ,   5339    ,   26907   ,0 };
            const std::uint32_t dim4652KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   23  ,   51  ,   71  ,   203 ,   237 ,   777 ,   417 ,   2767    ,   5243    ,   1453    ,   17269   ,   27679   ,0 };
            const std::uint32_t dim4653KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   17  ,   41  ,   29  ,   45  ,   363 ,   77  ,   1071    ,   3419    ,   6453    ,   13897   ,   25275   ,   26379   ,0 };
            const std::uint32_t dim4654KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   21  ,   5   ,   89  ,   133 ,   339 ,   971 ,   1581    ,   377 ,   6563    ,   13073   ,   24521   ,   41107   ,0 };
            const std::uint32_t dim4655KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   1   ,   27  ,   57  ,   249 ,   511 ,   833 ,   269 ,   2771    ,   4127    ,   12567   ,   27359   ,   22105   ,0 };
            const std::uint32_t dim4656KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   31  ,   47  ,   63  ,   221 ,   25  ,   869 ,   1947    ,   3075    ,   6857    ,   13507   ,   16601   ,   29621   ,0 };
            const std::uint32_t dim4657KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   17  ,   23  ,   109 ,   169 ,   211 ,   407 ,   1147    ,   2453    ,   2281    ,   10763   ,   11539   ,   49127   ,0 };
            const std::uint32_t dim4658KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   27  ,   25  ,   111 ,   75  ,   465 ,   67  ,   1641    ,   3623    ,   7957    ,   14307   ,   17469   ,   52229   ,0 };
            const std::uint32_t dim4659KuoInit[]        =   {   1   ,   3   ,   1   ,   5   ,   23  ,   31  ,   49  ,   131 ,   351 ,   311 ,   1937    ,   2181    ,   7485    ,   10883   ,   20843   ,   33447   ,0 };
            const std::uint32_t dim4660KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   5   ,   47  ,   81  ,   47  ,   305 ,   567 ,   219 ,   2495    ,   1207    ,   14359   ,   4683    ,   53717   ,0 };
            const std::uint32_t dim4661KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   29  ,   43  ,   107 ,   81  ,   227 ,   795 ,   1261    ,   3887    ,   6177    ,   6219    ,   2557    ,   53203   ,0 };
            const std::uint32_t dim4662KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   25  ,   47  ,   87  ,   177 ,   511 ,   899 ,   1967    ,   601 ,   3659    ,   3961    ,   27301   ,   9497    ,0 };
            const std::uint32_t dim4663KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   7   ,   19  ,   69  ,   95  ,   319 ,   811 ,   1539    ,   931 ,   6609    ,   4325    ,   4639    ,   60125   ,0 };
            const std::uint32_t dim4664KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   31  ,   25  ,   65  ,   137 ,   67  ,   903 ,   1519    ,   3   ,   81  ,   9991    ,   24985   ,   12571   ,0 };
            const std::uint32_t dim4665KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   13  ,   45  ,   87  ,   95  ,   185 ,   531 ,   591 ,   3649    ,   2289    ,   6353    ,   4305    ,   12801   ,0 };
            const std::uint32_t dim4666KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   13  ,   49  ,   79  ,   205 ,   9   ,   457 ,   151 ,   3363    ,   1865    ,   12337   ,   3601    ,   23781   ,0 };
            const std::uint32_t dim4667KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   21  ,   7   ,   117 ,   177 ,   327 ,   547 ,   385 ,   301 ,   5595    ,   14389   ,   8243    ,   3133    ,0 };
            const std::uint32_t dim4668KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   17  ,   39  ,   61  ,   45  ,   489 ,   769 ,   1893    ,   1633    ,   2645    ,   10849   ,   3827    ,   41365   ,0 };
            const std::uint32_t dim4669KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   11  ,   43  ,   93  ,   81  ,   497 ,   731 ,   1049    ,   91  ,   7979    ,   4707    ,   8757    ,   54837   ,0 };
            const std::uint32_t dim4670KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   1   ,   63  ,   127 ,   173 ,   137 ,   291 ,   473 ,   3095    ,   6291    ,   14415   ,   20763   ,   45687   ,0 };
            const std::uint32_t dim4671KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   29  ,   59  ,   73  ,   47  ,   171 ,   1001    ,   537 ,   2009    ,   5057    ,   15013   ,   22195   ,   56067   ,0 };
            const std::uint32_t dim4672KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   21  ,   35  ,   121 ,   169 ,   377 ,   389 ,   1209    ,   415 ,   2641    ,   10423   ,   11327   ,   64157   ,0 };
            const std::uint32_t dim4673KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   23  ,   43  ,   59  ,   205 ,   39  ,   455 ,   633 ,   1965    ,   7955    ,   305 ,   12245   ,   45229   ,0 };
            const std::uint32_t dim4674KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   15  ,   27  ,   49  ,   77  ,   407 ,   549 ,   1159    ,   1701    ,   7331    ,   6421    ,   1799    ,   43539   ,0 };
            const std::uint32_t dim4675KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   5   ,   33  ,   41  ,   127 ,   141 ,   149 ,   1957    ,   2823    ,   1303    ,   7339    ,   25253   ,   32329   ,0 };
            const std::uint32_t dim4676KuoInit[]        =   {   1   ,   1   ,   5   ,   15  ,   5   ,   37  ,   119 ,   111 ,   329 ,   781 ,   983 ,   2021    ,   1191    ,   1579    ,   4191    ,   24065   ,0 };
            const std::uint32_t dim4677KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   7   ,   11  ,   25  ,   111 ,   301 ,   819 ,   1073    ,   2311    ,   2357    ,   6385    ,   17015   ,   8051    ,0 };
            const std::uint32_t dim4678KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   29  ,   63  ,   91  ,   101 ,   71  ,   679 ,   267 ,   2909    ,   5359    ,   2305    ,   2523    ,   32423   ,0 };
            const std::uint32_t dim4679KuoInit[]        =   {   1   ,   3   ,   1   ,   5   ,   11  ,   45  ,   107 ,   95  ,   487 ,   605 ,   1647    ,   1977    ,   5305    ,   8855    ,   9057    ,   7809    ,0 };
            const std::uint32_t dim4680KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   5   ,   45  ,   51  ,   51  ,   97  ,   775 ,   1559    ,   935 ,   7421    ,   2823    ,   11415   ,   49193   ,0 };
            const std::uint32_t dim4681KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   23  ,   63  ,   99  ,   189 ,   175 ,   77  ,   675 ,   4021    ,   899 ,   11315   ,   18627   ,   46175   ,0 };
            const std::uint32_t dim4682KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   9   ,   31  ,   67  ,   235 ,   409 ,   541 ,   2013    ,   2715    ,   2121    ,   3695    ,   11953   ,   5745    ,0 };
            const std::uint32_t dim4683KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   13  ,   3   ,   15  ,   111 ,   455 ,   849 ,   231 ,   2711    ,   6831    ,   7813    ,   17173   ,   26019   ,0 };
            const std::uint32_t dim4684KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   19  ,   3   ,   21  ,   135 ,   275 ,   891 ,   61  ,   5   ,   2901    ,   15727   ,   18015   ,   55741   ,0 };
            const std::uint32_t dim4685KuoInit[]        =   {   1   ,   3   ,   1   ,   5   ,   5   ,   31  ,   5   ,   147 ,   353 ,   199 ,   229 ,   3821    ,   537 ,   11667   ,   649 ,   33923   ,0 };
            const std::uint32_t dim4686KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   3   ,   9   ,   75  ,   217 ,   423 ,   487 ,   723 ,   4091    ,   7075    ,   819 ,   2755    ,   13593   ,0 };
            const std::uint32_t dim4687KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   25  ,   45  ,   69  ,   41  ,   183 ,   547 ,   69  ,   3591    ,   1331    ,   5701    ,   25891   ,   26553   ,0 };
            const std::uint32_t dim4688KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   29  ,   51  ,   79  ,   153 ,   145 ,   923 ,   1345    ,   3113    ,   93  ,   10617   ,   12865   ,   27341   ,0 };
            const std::uint32_t dim4689KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   13  ,   61  ,   67  ,   115 ,   295 ,   767 ,   1077    ,   3959    ,   7741    ,   16145   ,   3571    ,   38941   ,0 };
            const std::uint32_t dim4690KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   1   ,   11  ,   25  ,   33  ,   481 ,   901 ,   135 ,   2093    ,   3531    ,   12137   ,   4521    ,   42301   ,0 };
            const std::uint32_t dim4691KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   9   ,   59  ,   105 ,   71  ,   57  ,   131 ,   1491    ,   3259    ,   4125    ,   10279   ,   7537    ,   38827   ,0 };
            const std::uint32_t dim4692KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   7   ,   53  ,   83  ,   43  ,   243 ,   423 ,   43  ,   2021    ,   4269    ,   1793    ,   9969    ,   55429   ,0 };
            const std::uint32_t dim4693KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   17  ,   57  ,   73  ,   55  ,   369 ,   975 ,   603 ,   1893    ,   3299    ,   12177   ,   8965    ,   17159   ,0 };
            const std::uint32_t dim4694KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   23  ,   11  ,   61  ,   11  ,   119 ,   905 ,   1841    ,   2597    ,   691 ,   6237    ,   2285    ,   33503   ,0 };
            const std::uint32_t dim4695KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   21  ,   17  ,   35  ,   169 ,   511 ,   1009    ,   1287    ,   3967    ,   1543    ,   6983    ,   6895    ,   24959   ,0 };
            const std::uint32_t dim4696KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   23  ,   9   ,   21  ,   47  ,   119 ,   323 ,   1255    ,   3601    ,   3157    ,   14041   ,   32065   ,   4759    ,0 };
            const std::uint32_t dim4697KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   9   ,   1   ,   103 ,   43  ,   485 ,   281 ,   1651    ,   1957    ,   4215    ,   2105    ,   24455   ,   51001   ,0 };
            const std::uint32_t dim4698KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   11  ,   11  ,   59  ,   31  ,   351 ,   275 ,   573 ,   2481    ,   2545    ,   15767   ,   4319    ,   63375   ,0 };
            const std::uint32_t dim4699KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   1   ,   41  ,   41  ,   13  ,   33  ,   693 ,   1035    ,   905 ,   6129    ,   11131   ,   23571   ,   28789   ,0 };
            const std::uint32_t dim4700KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   9   ,   39  ,   119 ,   31  ,   109 ,   837 ,   1905    ,   763 ,   3737    ,   16031   ,   8751    ,   17307   ,0 };
            const std::uint32_t dim4701KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   17  ,   49  ,   77  ,   199 ,   33  ,   185 ,   1489    ,   445 ,   5495    ,   13693   ,   21453   ,   21039   ,0 };
            const std::uint32_t dim4702KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   5   ,   9   ,   113 ,   179 ,   315 ,   85  ,   1559    ,   1505    ,   593 ,   259 ,   10393   ,   39025   ,0 };
            const std::uint32_t dim4703KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   31  ,   33  ,   41  ,   45  ,   313 ,   513 ,   861 ,   2697    ,   4767    ,   10737   ,   25019   ,   12715   ,0 };
            const std::uint32_t dim4704KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   19  ,   21  ,   19  ,   19  ,   127 ,   1009    ,   859 ,   829 ,   6887    ,   5407    ,   28491   ,   61079   ,0 };
            const std::uint32_t dim4705KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   15  ,   35  ,   69  ,   255 ,   367 ,   889 ,   49  ,   3237    ,   3269    ,   1559    ,   26337   ,   16967   ,0 };
            const std::uint32_t dim4706KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   17  ,   5   ,   125 ,   171 ,   505 ,   981 ,   773 ,   2973    ,   2905    ,   1537    ,   17729   ,   52289   ,0 };
            const std::uint32_t dim4707KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   29  ,   5   ,   57  ,   247 ,   149 ,   707 ,   673 ,   429 ,   7583    ,   12135   ,   5405    ,   313 ,0 };
            const std::uint32_t dim4708KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   31  ,   35  ,   117 ,   69  ,   413 ,   723 ,   645 ,   3989    ,   6461    ,   77  ,   29713   ,   32381   ,0 };
            const std::uint32_t dim4709KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   11  ,   59  ,   5   ,   53  ,   507 ,   355 ,   335 ,   4027    ,   3111    ,   8385    ,   22369   ,   42907   ,0 };
            const std::uint32_t dim4710KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   1   ,   47  ,   87  ,   13  ,   397 ,   693 ,   1745    ,   2907    ,   3919    ,   14843   ,   869 ,   24161   ,0 };
            const std::uint32_t dim4711KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   11  ,   25  ,   25  ,   153 ,   501 ,   305 ,   941 ,   2379    ,   2587    ,   8225    ,   27951   ,   14809   ,0 };
            const std::uint32_t dim4712KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   31  ,   7   ,   9   ,   47  ,   129 ,   611 ,   1367    ,   1575    ,   4421    ,   2277    ,   8113    ,   34229   ,0 };
            const std::uint32_t dim4713KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   7   ,   41  ,   65  ,   5   ,   289 ,   799 ,   1143    ,   291 ,   243 ,   12957   ,   2729    ,   14589   ,0 };
            const std::uint32_t dim4714KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   15  ,   29  ,   49  ,   243 ,   191 ,   565 ,   271 ,   2485    ,   1507    ,   13479   ,   3541    ,   10039   ,0 };
            const std::uint32_t dim4715KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   25  ,   29  ,   113 ,   157 ,   357 ,   891 ,   199 ,   3113    ,   7133    ,   11047   ,   27517   ,   26795   ,0 };
            const std::uint32_t dim4716KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   27  ,   23  ,   5   ,   207 ,   183 ,   85  ,   247 ,   15  ,   5559    ,   8005    ,   32485   ,   26403   ,0 };
            const std::uint32_t dim4717KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   13  ,   9   ,   87  ,   9   ,   237 ,   875 ,   1621    ,   2955    ,   4105    ,   9645    ,   9613    ,   31235   ,0 };
            const std::uint32_t dim4718KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   17  ,   3   ,   77  ,   241 ,   75  ,   433 ,   1481    ,   1901    ,   6249    ,   12411   ,   18975   ,   18911   ,0 };
            const std::uint32_t dim4719KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   3   ,   43  ,   99  ,   197 ,   407 ,   161 ,   1103    ,   587 ,   6695    ,   255 ,   15571   ,   7523    ,0 };
            const std::uint32_t dim4720KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   1   ,   21  ,   9   ,   155 ,   447 ,   785 ,   1573    ,   2497    ,   1515    ,   6031    ,   23509   ,   38199   ,0 };
            const std::uint32_t dim4721KuoInit[]        =   {   1   ,   1   ,   5   ,   15  ,   23  ,   43  ,   125 ,   187 ,   57  ,   259 ,   941 ,   1213    ,   2303    ,   1127    ,   31819   ,   53539   ,0 };
            const std::uint32_t dim4722KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   23  ,   19  ,   29  ,   83  ,   431 ,   79  ,   781 ,   1887    ,   4857    ,   2079    ,   11521   ,   64925   ,0 };
            const std::uint32_t dim4723KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   23  ,   11  ,   33  ,   107 ,   127 ,   173 ,   223 ,   491 ,   1529    ,   14655   ,   18857   ,   25247   ,0 };
            const std::uint32_t dim4724KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   17  ,   53  ,   119 ,   159 ,   503 ,   153 ,   697 ,   657 ,   6207    ,   7659    ,   23899   ,   10347   ,0 };
            const std::uint32_t dim4725KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   13  ,   37  ,   117 ,   219 ,   341 ,   983 ,   193 ,   1641    ,   7811    ,   11961   ,   12553   ,   9467    ,0 };
            const std::uint32_t dim4726KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   27  ,   11  ,   35  ,   45  ,   89  ,   535 ,   965 ,   1269    ,   1243    ,   3987    ,   4629    ,   45335   ,0 };
            const std::uint32_t dim4727KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   17  ,   25  ,   79  ,   133 ,   287 ,   7   ,   269 ,   697 ,   2537    ,   241 ,   15747   ,   49429   ,0 };
            const std::uint32_t dim4728KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   27  ,   63  ,   23  ,   229 ,   3   ,   625 ,   453 ,   3037    ,   5747    ,   13525   ,   28835   ,   13411   ,0 };
            const std::uint32_t dim4729KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   25  ,   57  ,   101 ,   13  ,   81  ,   917 ,   1849    ,   3931    ,   3319    ,   1353    ,   8253    ,   28897   ,0 };
            const std::uint32_t dim4730KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   3   ,   41  ,   89  ,   165 ,   1   ,   935 ,   1859    ,   2881    ,   4351    ,   6737    ,   12361   ,   27821   ,0 };
            const std::uint32_t dim4731KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   9   ,   45  ,   89  ,   251 ,   77  ,   899 ,   777 ,   4063    ,   8111    ,   5953    ,   26645   ,   62567   ,0 };
            const std::uint32_t dim4732KuoInit[]        =   {   1   ,   3   ,   5   ,   1   ,   25  ,   7   ,   15  ,   189 ,   157 ,   751 ,   627 ,   629 ,   2875    ,   11143   ,   23841   ,   58751   ,0 };
            const std::uint32_t dim4733KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   7   ,   43  ,   95  ,   171 ,   311 ,   809 ,   971 ,   1317    ,   3521    ,   15227   ,   18155   ,   11409   ,0 };
            const std::uint32_t dim4734KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   29  ,   7   ,   69  ,   1   ,   235 ,   699 ,   971 ,   3149    ,   71  ,   3609    ,   859 ,   17059   ,0 };
            const std::uint32_t dim4735KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   3   ,   43  ,   3   ,   181 ,   465 ,   843 ,   1391    ,   3313    ,   8115    ,   1835    ,   32365   ,   31303   ,0 };
            const std::uint32_t dim4736KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   27  ,   49  ,   15  ,   37  ,   257 ,   365 ,   1577    ,   3037    ,   2767    ,   8183    ,   173 ,   43089   ,0 };
            const std::uint32_t dim4737KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   7   ,   29  ,   81  ,   33  ,   299 ,   827 ,   221 ,   2049    ,   1163    ,   13023   ,   6755    ,   53987   ,0 };
            const std::uint32_t dim4738KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   19  ,   17  ,   63  ,   19  ,   469 ,   925 ,   37  ,   3291    ,   2699    ,   10083   ,   32197   ,   53749   ,0 };
            const std::uint32_t dim4739KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   1   ,   23  ,   71  ,   173 ,   441 ,   109 ,   391 ,   3611    ,   7515    ,   5095    ,   26379   ,   55999   ,0 };
            const std::uint32_t dim4740KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   29  ,   13  ,   23  ,   57  ,   329 ,   285 ,   1595    ,   2681    ,   5427    ,   3251    ,   7025    ,   3921    ,0 };
            const std::uint32_t dim4741KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   7   ,   45  ,   121 ,   19  ,   19  ,   317 ,   1619    ,   2245    ,   7151    ,   5797    ,   31369   ,   7765    ,0 };
            const std::uint32_t dim4742KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   9   ,   17  ,   11  ,   127 ,   337 ,   271 ,   2005    ,   787 ,   1017    ,   3075    ,   29453   ,   62275   ,0 };
            const std::uint32_t dim4743KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   9   ,   51  ,   77  ,   31  ,   395 ,   175 ,   247 ,   1021    ,   4343    ,   3829    ,   959 ,   12069   ,0 };
            const std::uint32_t dim4744KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   21  ,   33  ,   3   ,   129 ,   327 ,   13  ,   1943    ,   3305    ,   6173    ,   6903    ,   32539   ,   9525    ,0 };
            const std::uint32_t dim4745KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   23  ,   5   ,   49  ,   125 ,   445 ,   849 ,   547 ,   2911    ,   7611    ,   8137    ,   28701   ,   6883    ,0 };
            const std::uint32_t dim4746KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   11  ,   15  ,   21  ,   35  ,   303 ,   401 ,   187 ,   1981    ,   7919    ,   6179    ,   15643   ,   10327   ,0 };
            const std::uint32_t dim4747KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   9   ,   45  ,   95  ,   205 ,   137 ,   425 ,   353 ,   673 ,   1337    ,   4357    ,   12521   ,   55229   ,0 };
            const std::uint32_t dim4748KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   29  ,   47  ,   93  ,   213 ,   357 ,   821 ,   467 ,   395 ,   5079    ,   10341   ,   24117   ,   59757   ,0 };
            const std::uint32_t dim4749KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   29  ,   39  ,   25  ,   85  ,   437 ,   873 ,   795 ,   91  ,   1979    ,   15503   ,   12157   ,   6803    ,0 };
            const std::uint32_t dim4750KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   31  ,   21  ,   31  ,   245 ,   79  ,   661 ,   323 ,   1843    ,   2225    ,   15383   ,   17507   ,   30667   ,0 };
            const std::uint32_t dim4751KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   1   ,   11  ,   119 ,   151 ,   489 ,   303 ,   835 ,   319 ,   2071    ,   1497    ,   10343   ,   40641   ,0 };
            const std::uint32_t dim4752KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   7   ,   7   ,   125 ,   237 ,   103 ,   65  ,   1917    ,   2203    ,   5895    ,   8651    ,   7331    ,   27591   ,0 };
            const std::uint32_t dim4753KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   21  ,   17  ,   73  ,   21  ,   485 ,   985 ,   253 ,   1877    ,   7423    ,   6569    ,   25971   ,   57821   ,0 };
            const std::uint32_t dim4754KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   3   ,   59  ,   9   ,   77  ,   99  ,   851 ,   343 ,   2655    ,   367 ,   7253    ,   16357   ,   61563   ,0 };
            const std::uint32_t dim4755KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   11  ,   1   ,   15  ,   227 ,   223 ,   317 ,   1111    ,   2287    ,   4035    ,   6803    ,   16787   ,   27797   ,0 };
            const std::uint32_t dim4756KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   17  ,   49  ,   103 ,   191 ,   245 ,   473 ,   2007    ,   3297    ,   6487    ,   7371    ,   30497   ,   40255   ,0 };
            const std::uint32_t dim4757KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   1   ,   61  ,   39  ,   1   ,   501 ,   665 ,   1085    ,   3933    ,   855 ,   883 ,   26949   ,   48761   ,0 };
            const std::uint32_t dim4758KuoInit[]        =   {   1   ,   3   ,   3   ,   13  ,   29  ,   39  ,   5   ,   43  ,   39  ,   529 ,   1605    ,   2235    ,   5081    ,   7467    ,   20727   ,   48611   ,0 };
            const std::uint32_t dim4759KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   19  ,   61  ,   89  ,   15  ,   149 ,   639 ,   337 ,   2953    ,   2229    ,   11161   ,   21981   ,   26003   ,0 };
            const std::uint32_t dim4760KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   29  ,   47  ,   71  ,   65  ,   107 ,   485 ,   57  ,   2255    ,   4383    ,   12383   ,   18161   ,   40233   ,0 };
            const std::uint32_t dim4761KuoInit[]        =   {   1   ,   1   ,   7   ,   3   ,   21  ,   41  ,   75  ,   133 ,   141 ,   343 ,   633 ,   2043    ,   2441    ,   5479    ,   2493    ,   45707   ,0 };
            const std::uint32_t dim4762KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   21  ,   37  ,   19  ,   73  ,   361 ,   195 ,   1007    ,   1265    ,   4075    ,   1383    ,   11809   ,   64265   ,0 };
            const std::uint32_t dim4763KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   19  ,   63  ,   21  ,   163 ,   349 ,   961 ,   1221    ,   2265    ,   4801    ,   14049   ,   8655    ,   32823   ,0 };
            const std::uint32_t dim4764KuoInit[]        =   {   1   ,   1   ,   5   ,   1   ,   9   ,   1   ,   101 ,   37  ,   473 ,   293 ,   1191    ,   791 ,   5327    ,   13739   ,   21761   ,   5755    ,0 };
            const std::uint32_t dim4765KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   23  ,   57  ,   63  ,   195 ,   451 ,   627 ,   1725    ,   2405    ,   6943    ,   6855    ,   31563   ,   44699   ,0 };
            const std::uint32_t dim4766KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   31  ,   41  ,   51  ,   177 ,   95  ,   961 ,   1407    ,   2847    ,   7   ,   8975    ,   4017    ,   46229   ,0 };
            const std::uint32_t dim4767KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   19  ,   9   ,   67  ,   183 ,   255 ,   1   ,   1769    ,   2585    ,   2157    ,   9747    ,   32047   ,   13063   ,0 };
            const std::uint32_t dim4768KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   21  ,   39  ,   31  ,   117 ,   397 ,   441 ,   1443    ,   3849    ,   5993    ,   13981   ,   23579   ,   40637   ,0 };
            const std::uint32_t dim4769KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   31  ,   23  ,   61  ,   203 ,   111 ,   273 ,   1693    ,   3031    ,   4125    ,   1527    ,   30525   ,   17465   ,0 };
            const std::uint32_t dim4770KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   19  ,   39  ,   127 ,   51  ,   419 ,   205 ,   425 ,   1939    ,   3703    ,   12009   ,   6291    ,   48639   ,0 };
            const std::uint32_t dim4771KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   15  ,   27  ,   63  ,   239 ,   483 ,   181 ,   1621    ,   3789    ,   1929    ,   11115   ,   29385   ,   53075   ,0 };
            const std::uint32_t dim4772KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   13  ,   9   ,   61  ,   15  ,   221 ,   163 ,   1645    ,   419 ,   639 ,   15081   ,   2097    ,   42133   ,0 };
            const std::uint32_t dim4773KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   7   ,   31  ,   27  ,   141 ,   215 ,   645 ,   1293    ,   2237    ,   7129    ,   12619   ,   14563   ,   46081   ,0 };
            const std::uint32_t dim4774KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   3   ,   41  ,   85  ,   37  ,   295 ,   815 ,   1417    ,   3083    ,   5873    ,   2037    ,   29909   ,   3817    ,0 };
            const std::uint32_t dim4775KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   11  ,   49  ,   77  ,   103 ,   189 ,   319 ,   439 ,   3547    ,   173 ,   1105    ,   12125   ,   49989   ,0 };
            const std::uint32_t dim4776KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   21  ,   9   ,   5   ,   37  ,   87  ,   905 ,   145 ,   1151    ,   2213    ,   4157    ,   16171   ,   56121   ,0 };
            const std::uint32_t dim4777KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   15  ,   21  ,   91  ,   103 ,   367 ,   423 ,   101 ,   327 ,   3819    ,   3141    ,   3515    ,   11433   ,0 };
            const std::uint32_t dim4778KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   13  ,   11  ,   61  ,   175 ,   265 ,   1011    ,   1825    ,   937 ,   983 ,   9575    ,   6053    ,   19633   ,0 };
            const std::uint32_t dim4779KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   25  ,   47  ,   55  ,   233 ,   397 ,   325 ,   1217    ,   1691    ,   2751    ,   5339    ,   14269   ,   28791   ,0 };
            const std::uint32_t dim4780KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   15  ,   51  ,   29  ,   215 ,   47  ,   713 ,   1879    ,   1981    ,   3087    ,   9945    ,   8959    ,   59367   ,0 };
            const std::uint32_t dim4781KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   1   ,   33  ,   97  ,   7   ,   247 ,   893 ,   655 ,   3137    ,   6593    ,   7261    ,   11829   ,   22101   ,0 };
            const std::uint32_t dim4782KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   11  ,   23  ,   75  ,   55  ,   313 ,   533 ,   529 ,   1929    ,   3647    ,   3317    ,   2987    ,   11917   ,0 };
            const std::uint32_t dim4783KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   17  ,   35  ,   105 ,   221 ,   211 ,   545 ,   1595    ,   1949    ,   1895    ,   39  ,   7163    ,   33303   ,0 };
            const std::uint32_t dim4784KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   21  ,   29  ,   73  ,   235 ,   189 ,   11  ,   1747    ,   1023    ,   3987    ,   10337   ,   1689    ,   64043   ,0 };
            const std::uint32_t dim4785KuoInit[]        =   {   1   ,   3   ,   1   ,   5   ,   11  ,   17  ,   115 ,   57  ,   465 ,   899 ,   1421    ,   1329    ,   6099    ,   8081    ,   11297   ,   13217   ,0 };
            const std::uint32_t dim4786KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   5   ,   23  ,   53  ,   23  ,   11  ,   177 ,   817 ,   3003    ,   5073    ,   12071   ,   11263   ,   43159   ,0 };
            const std::uint32_t dim4787KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   1   ,   63  ,   127 ,   41  ,   303 ,   681 ,   1559    ,   2385    ,   6265    ,   2417    ,   7063    ,   57965   ,0 };
            const std::uint32_t dim4788KuoInit[]        =   {   1   ,   3   ,   1   ,   1   ,   3   ,   21  ,   21  ,   37  ,   485 ,   771 ,   2043    ,   2065    ,   7047    ,   8867    ,   7019    ,   31437   ,0 };
            const std::uint32_t dim4789KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   27  ,   49  ,   77  ,   89  ,   391 ,   623 ,   1675    ,   1919    ,   3575    ,   2187    ,   22801   ,   11059   ,0 };
            const std::uint32_t dim4790KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   9   ,   57  ,   51  ,   255 ,   287 ,   851 ,   1999    ,   811 ,   7769    ,   11185   ,   19279   ,   65491   ,0 };
            const std::uint32_t dim4791KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   31  ,   43  ,   113 ,   11  ,   461 ,   95  ,   841 ,   2937    ,   3969    ,   5901    ,   32681   ,   9231    ,0 };
            const std::uint32_t dim4792KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   31  ,   47  ,   21  ,   187 ,   171 ,   249 ,   787 ,   459 ,   6897    ,   12131   ,   14843   ,   11805   ,0 };
            const std::uint32_t dim4793KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   27  ,   61  ,   91  ,   77  ,   9   ,   393 ,   1231    ,   1901    ,   291 ,   1487    ,   22139   ,   30569   ,0 };
            const std::uint32_t dim4794KuoInit[]        =   {   1   ,   1   ,   1   ,   1   ,   27  ,   33  ,   55  ,   151 ,   89  ,   603 ,   551 ,   3767    ,   695 ,   15225   ,   9665    ,   60459   ,0 };
            const std::uint32_t dim4795KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   31  ,   19  ,   83  ,   27  ,   381 ,   105 ,   481 ,   3095    ,   137 ,   10433   ,   12967   ,   19555   ,0 };
            const std::uint32_t dim4796KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   15  ,   1   ,   3   ,   121 ,   107 ,   435 ,   1571    ,   3205    ,   5213    ,   3689    ,   31365   ,   14353   ,0 };
            const std::uint32_t dim4797KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   23  ,   61  ,   93  ,   59  ,   179 ,   361 ,   965 ,   413 ,   7757    ,   15779   ,   1119    ,   34673   ,0 };
            const std::uint32_t dim4798KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   29  ,   63  ,   79  ,   135 ,   431 ,   723 ,   727 ,   2685    ,   1775    ,   9027    ,   27051   ,   42581   ,0 };
            const std::uint32_t dim4799KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   27  ,   19  ,   17  ,   141 ,   367 ,   1021    ,   651 ,   2549    ,   4003    ,   15737   ,   22063   ,   12443   ,0 };
            const std::uint32_t dim4800KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   23  ,   27  ,   35  ,   225 ,   399 ,   173 ,   451 ,   1701    ,   1093    ,   5639    ,   1855    ,   1817    ,0 };
            const std::uint32_t dim4801KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   23  ,   63  ,   119 ,   13  ,   147 ,   997 ,   53  ,   3127    ,   101 ,   6633    ,   14377   ,   61843   ,0 };
            const std::uint32_t dim4802KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   23  ,   21  ,   65  ,   213 ,   311 ,   789 ,   1395    ,   1239    ,   241 ,   15041   ,   14683   ,   27805   ,0 };
            const std::uint32_t dim4803KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   7   ,   29  ,   83  ,   153 ,   231 ,   337 ,   153 ,   3097    ,   6137    ,   11003   ,   31091   ,   57005   ,0 };
            const std::uint32_t dim4804KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   19  ,   33  ,   91  ,   235 ,   123 ,   747 ,   1331    ,   2307    ,   3791    ,   2063    ,   23613   ,   3589    ,0 };
            const std::uint32_t dim4805KuoInit[]        =   {   1   ,   3   ,   3   ,   15  ,   9   ,   25  ,   95  ,   237 ,   381 ,   349 ,   1339    ,   3187    ,   2387    ,   3487    ,   4149    ,   39343   ,0 };
            const std::uint32_t dim4806KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   5   ,   3   ,   43  ,   193 ,   431 ,   853 ,   1419    ,   905 ,   2395    ,   11459   ,   26109   ,   31277   ,0 };
            const std::uint32_t dim4807KuoInit[]        =   {   1   ,   3   ,   1   ,   15  ,   13  ,   29  ,   13  ,   253 ,   475 ,   81  ,   1199    ,   841 ,   7385    ,   2609    ,   10445   ,   11151   ,0 };
            const std::uint32_t dim4808KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   29  ,   11  ,   81  ,   91  ,   287 ,   615 ,   949 ,   2541    ,   5059    ,   12567   ,   9547    ,   45647   ,0 };
            const std::uint32_t dim4809KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   9   ,   27  ,   123 ,   165 ,   249 ,   457 ,   607 ,   1203    ,   987 ,   4477    ,   21205   ,   44547   ,0 };
            const std::uint32_t dim4810KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   3   ,   1   ,   37  ,   43  ,   445 ,   205 ,   1849    ,   3461    ,   7667    ,   209 ,   8773    ,   1507    ,0 };
            const std::uint32_t dim4811KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   27  ,   43  ,   75  ,   199 ,   185 ,   249 ,   725 ,   301 ,   2181    ,   6859    ,   16825   ,   3471    ,0 };
            const std::uint32_t dim4812KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   29  ,   5   ,   55  ,   5   ,   345 ,   325 ,   1853    ,   3925    ,   1739    ,   14991   ,   27845   ,   6931    ,0 };
            const std::uint32_t dim4813KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   31  ,   15  ,   33  ,   47  ,   201 ,   649 ,   415 ,   639 ,   391 ,   12065   ,   17343   ,   3063    ,0 };
            const std::uint32_t dim4814KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   19  ,   37  ,   39  ,   77  ,   367 ,   29  ,   1251    ,   2637    ,   5601    ,   10661   ,   17647   ,   22131   ,0 };
            const std::uint32_t dim4815KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   29  ,   51  ,   13  ,   129 ,   279 ,   427 ,   1535    ,   2185    ,   2651    ,   8251    ,   14857   ,   61467   ,0 };
            const std::uint32_t dim4816KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   25  ,   55  ,   45  ,   105 ,   213 ,   31  ,   735 ,   3795    ,   6627    ,   14299   ,   3155    ,   3659    ,0 };
            const std::uint32_t dim4817KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   21  ,   27  ,   21  ,   85  ,   315 ,   793 ,   1663    ,   437 ,   4113    ,   4639    ,   11321   ,   13633   ,0 };
            const std::uint32_t dim4818KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   23  ,   17  ,   49  ,   35  ,   451 ,   799 ,   1451    ,   539 ,   4549    ,   43  ,   1901    ,   21155   ,0 };
            const std::uint32_t dim4819KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   23  ,   53  ,   25  ,   71  ,   371 ,   1005    ,   129 ,   157 ,   2977    ,   15823   ,   30393   ,   55629   ,0 };
            const std::uint32_t dim4820KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   9   ,   27  ,   79  ,   101 ,   147 ,   511 ,   199 ,   2843    ,   101 ,   14975   ,   3455    ,   843 ,0 };
            const std::uint32_t dim4821KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   11  ,   33  ,   43  ,   7   ,   445 ,   501 ,   1071    ,   1851    ,   5763    ,   5233    ,   16121   ,   23357   ,0 };
            const std::uint32_t dim4822KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   11  ,   21  ,   75  ,   153 ,   421 ,   311 ,   1709    ,   3745    ,   2971    ,   11219   ,   23107   ,   40057   ,0 };
            const std::uint32_t dim4823KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   17  ,   39  ,   17  ,   165 ,   103 ,   31  ,   575 ,   3945    ,   1921    ,   11305   ,   13417   ,   20603   ,0 };
            const std::uint32_t dim4824KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   5   ,   49  ,   37  ,   61  ,   177 ,   595 ,   1133    ,   1883    ,   819 ,   5137    ,   10423   ,   42009   ,0 };
            const std::uint32_t dim4825KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   5   ,   15  ,   89  ,   191 ,   97  ,   1017    ,   205 ,   4037    ,   3431    ,   13877   ,   29867   ,   26041   ,0 };
            const std::uint32_t dim4826KuoInit[]        =   {   1   ,   3   ,   3   ,   7   ,   9   ,   9   ,   109 ,   157 ,   357 ,   815 ,   1539    ,   3507    ,   1379    ,   1105    ,   14387   ,   46689   ,0 };
            const std::uint32_t dim4827KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   3   ,   11  ,   77  ,   161 ,   473 ,   619 ,   741 ,   2945    ,   5123    ,   3325    ,   8679    ,   36167   ,0 };
            const std::uint32_t dim4828KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   9   ,   53  ,   3   ,   77  ,   319 ,   223 ,   875 ,   425 ,   1369    ,   509 ,   25895   ,   32803   ,0 };
            const std::uint32_t dim4829KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   31  ,   15  ,   113 ,   133 ,   473 ,   29  ,   1009    ,   1385    ,   871 ,   15785   ,   1015    ,   42627   ,0 };
            const std::uint32_t dim4830KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   5   ,   53  ,   123 ,   7   ,   465 ,   485 ,   1413    ,   1663    ,   6541    ,   13051   ,   12251   ,   36151   ,0 };
            const std::uint32_t dim4831KuoInit[]        =   {   1   ,   1   ,   1   ,   13  ,   9   ,   21  ,   123 ,   223 ,   483 ,   849 ,   489 ,   3905    ,   4697    ,   7583    ,   5373    ,   62397   ,0 };
            const std::uint32_t dim4832KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   29  ,   53  ,   85  ,   151 ,   511 ,   917 ,   1719    ,   937 ,   2035    ,   6385    ,   23529   ,   62213   ,0 };
            const std::uint32_t dim4833KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   11  ,   47  ,   111 ,   79  ,   377 ,   585 ,   475 ,   3201    ,   7025    ,   1483    ,   8815    ,   47235   ,0 };
            const std::uint32_t dim4834KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   13  ,   5   ,   39  ,   31  ,   71  ,   39  ,   941 ,   2215    ,   2195    ,   2827    ,   24353   ,   18435   ,0 };
            const std::uint32_t dim4835KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   13  ,   31  ,   31  ,   15  ,   421 ,   81  ,   895 ,   1345    ,   7049    ,   4373    ,   28005   ,   41781   ,0 };
            const std::uint32_t dim4836KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   17  ,   57  ,   21  ,   175 ,   453 ,   755 ,   1295    ,   353 ,   5257    ,   15901   ,   15643   ,   31725   ,0 };
            const std::uint32_t dim4837KuoInit[]        =   {   1   ,   1   ,   1   ,   9   ,   17  ,   17  ,   71  ,   209 ,   155 ,   511 ,   1461    ,   3313    ,   7515    ,   8407    ,   9561    ,   48169   ,0 };
            const std::uint32_t dim4838KuoInit[]        =   {   1   ,   3   ,   7   ,   15  ,   23  ,   59  ,   89  ,   39  ,   85  ,   857 ,   1285    ,   3099    ,   6497    ,   5501    ,   21321   ,   34319   ,0 };
            const std::uint32_t dim4839KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   27  ,   13  ,   41  ,   1   ,   191 ,   275 ,   1567    ,   895 ,   13  ,   673 ,   10079   ,   55075   ,0 };
            const std::uint32_t dim4840KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   9   ,   33  ,   33  ,   35  ,   55  ,   597 ,   365 ,   3205    ,   6427    ,   837 ,   16011   ,   23279   ,0 };
            const std::uint32_t dim4841KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   23  ,   23  ,   9   ,   79  ,   383 ,   303 ,   1715    ,   1651    ,   7507    ,   14553   ,   30715   ,   56659   ,0 };
            const std::uint32_t dim4842KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   1   ,   61  ,   31  ,   85  ,   181 ,   593 ,   1783    ,   901 ,   6069    ,   1521    ,   13275   ,   18057   ,0 };
            const std::uint32_t dim4843KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   23  ,   59  ,   111 ,   221 ,   47  ,   599 ,   193 ,   1547    ,   4077    ,   15271   ,   19315   ,   1115    ,0 };
            const std::uint32_t dim4844KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   23  ,   53  ,   115 ,   69  ,   19  ,   409 ,   1041    ,   3395    ,   6429    ,   9263    ,   21637   ,   35533   ,0 };
            const std::uint32_t dim4845KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   31  ,   45  ,   43  ,   251 ,   163 ,   907 ,   761 ,   2009    ,   3807    ,   1529    ,   12001   ,   38823   ,0 };
            const std::uint32_t dim4846KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   3   ,   59  ,   87  ,   247 ,   179 ,   931 ,   709 ,   53  ,   6283    ,   13723   ,   15407   ,   22417   ,0 };
            const std::uint32_t dim4847KuoInit[]        =   {   1   ,   1   ,   1   ,   5   ,   27  ,   17  ,   21  ,   183 ,   393 ,   177 ,   1187    ,   19  ,   5409    ,   2539    ,   17401   ,   29287   ,0 };
            const std::uint32_t dim4848KuoInit[]        =   {   1   ,   1   ,   5   ,   15  ,   3   ,   51  ,   91  ,   95  ,   389 ,   855 ,   1453    ,   2815    ,   7507    ,   5449    ,   12459   ,   59111   ,0 };
            const std::uint32_t dim4849KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   7   ,   53  ,   101 ,   255 ,   395 ,   345 ,   915 ,   1649    ,   6641    ,   7771    ,   20747   ,   17067   ,0 };
            const std::uint32_t dim4850KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   5   ,   35  ,   69  ,   63  ,   249 ,   189 ,   1937    ,   965 ,   3463    ,   13615   ,   12449   ,   11891   ,0 };
            const std::uint32_t dim4851KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   5   ,   59  ,   57  ,   187 ,   403 ,   825 ,   1291    ,   2995    ,   6365    ,   15995   ,   6871    ,   25785   ,0 };
            const std::uint32_t dim4852KuoInit[]        =   {   1   ,   3   ,   5   ,   15  ,   17  ,   23  ,   117 ,   103 ,   131 ,   601 ,   1259    ,   1331    ,   3039    ,   4761    ,   8105    ,   14521   ,0 };
            const std::uint32_t dim4853KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   27  ,   51  ,   97  ,   221 ,   345 ,   615 ,   487 ,   2535    ,   139 ,   16233   ,   16271   ,   713 ,0 };
            const std::uint32_t dim4854KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   25  ,   49  ,   99  ,   71  ,   353 ,   1015    ,   1889    ,   689 ,   1925    ,   6523    ,   30995   ,   23057   ,0 };
            const std::uint32_t dim4855KuoInit[]        =   {   1   ,   3   ,   5   ,   9   ,   21  ,   55  ,   11  ,   29  ,   477 ,   581 ,   1719    ,   2603    ,   1757    ,   3995    ,   27025   ,   62833   ,0 };
            const std::uint32_t dim4856KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   9   ,   39  ,   9   ,   121 ,   459 ,   991 ,   2021    ,   1469    ,   2399    ,   4441    ,   11829   ,   36865   ,0 };
            const std::uint32_t dim4857KuoInit[]        =   {   1   ,   3   ,   1   ,   5   ,   9   ,   13  ,   115 ,   27  ,   487 ,   307 ,   453 ,   351 ,   885 ,   12539   ,   39  ,   33887   ,0 };
            const std::uint32_t dim4858KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   23  ,   35  ,   87  ,   131 ,   129 ,   1   ,   2015    ,   3921    ,   1309    ,   7915    ,   16661   ,   45945   ,0 };
            const std::uint32_t dim4859KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   1   ,   15  ,   93  ,   255 ,   285 ,   915 ,   563 ,   527 ,   7763    ,   4581    ,   11161   ,   64619   ,0 };
            const std::uint32_t dim4860KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   31  ,   37  ,   87  ,   81  ,   313 ,   647 ,   1065    ,   863 ,   6121    ,   1385    ,   26171   ,   56323   ,0 };
            const std::uint32_t dim4861KuoInit[]        =   {   1   ,   1   ,   3   ,   7   ,   25  ,   49  ,   23  ,   107 ,   507 ,   511 ,   951 ,   669 ,   67  ,   14319   ,   17669   ,   32497   ,0 };
            const std::uint32_t dim4862KuoInit[]        =   {   1   ,   3   ,   1   ,   13  ,   9   ,   33  ,   93  ,   171 ,   457 ,   687 ,   703 ,   1073    ,   3699    ,   7029    ,   28983   ,   14501   ,0 };
            const std::uint32_t dim4863KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   29  ,   3   ,   19  ,   173 ,   131 ,   285 ,   469 ,   1223    ,   7779    ,   15367   ,   643 ,   63715   ,0 };
            const std::uint32_t dim4864KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   5   ,   37  ,   21  ,   223 ,   227 ,   939 ,   1205    ,   3167    ,   5535    ,   11543   ,   7411    ,   30841   ,0 };
            const std::uint32_t dim4865KuoInit[]        =   {   1   ,   3   ,   5   ,   11  ,   31  ,   37  ,   75  ,   39  ,   171 ,   135 ,   1487    ,   3503    ,   7939    ,   77  ,   19745   ,   2551    ,0 };
            const std::uint32_t dim4866KuoInit[]        =   {   1   ,   3   ,   5   ,   13  ,   25  ,   33  ,   79  ,   213 ,   289 ,   27  ,   1435    ,   1839    ,   3089    ,   8173    ,   27555   ,   20599   ,0 };
            const std::uint32_t dim4867KuoInit[]        =   {   1   ,   1   ,   3   ,   13  ,   19  ,   31  ,   67  ,   9   ,   229 ,   591 ,   561 ,   3797    ,   1833    ,   3311    ,   16053   ,   61183   ,0 };
            const std::uint32_t dim4868KuoInit[]        =   {   1   ,   1   ,   3   ,   3   ,   27  ,   27  ,   79  ,   95  ,   7   ,   1023    ,   517 ,   3627    ,   4117    ,   8165    ,   17961   ,   39011   ,0 };
            const std::uint32_t dim4869KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   3   ,   43  ,   37  ,   231 ,   389 ,   367 ,   517 ,   3117    ,   2643    ,   2103    ,   127 ,   42669   ,0 };
            const std::uint32_t dim4870KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   11  ,   49  ,   35  ,   71  ,   295 ,   87  ,   1653    ,   1899    ,   1177    ,   16071   ,   8429    ,   54751   ,0 };
            const std::uint32_t dim4871KuoInit[]        =   {   1   ,   1   ,   7   ,   13  ,   5   ,   47  ,   7   ,   229 ,   261 ,   837 ,   645 ,   1581    ,   159 ,   73  ,   10233   ,   18557   ,0 };
            const std::uint32_t dim4872KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   11  ,   45  ,   25  ,   3   ,   271 ,   1005    ,   1193    ,   507 ,   269 ,   14689   ,   7601    ,   56781   ,0 };
            const std::uint32_t dim4873KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   13  ,   61  ,   107 ,   29  ,   155 ,   415 ,   1435    ,   1979    ,   7339    ,   1839    ,   21097   ,   5851    ,0 };
            const std::uint32_t dim4874KuoInit[]        =   {   1   ,   1   ,   5   ,   9   ,   9   ,   27  ,   83  ,   163 ,   15  ,   539 ,   765 ,   463 ,   7493    ,   1413    ,   15597   ,   42819   ,0 };
            const std::uint32_t dim4875KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   21  ,   7   ,   91  ,   213 ,   463 ,   827 ,   1847    ,   2825    ,   2115    ,   14549   ,   29923   ,   61355   ,0 };
            const std::uint32_t dim4876KuoInit[]        =   {   1   ,   1   ,   3   ,   15  ,   1   ,   55  ,   69  ,   85  ,   7   ,   847 ,   1935    ,   3225    ,   693 ,   12069   ,   26303   ,   19143   ,0 };
            const std::uint32_t dim4877KuoInit[]        =   {   1   ,   3   ,   1   ,   11  ,   15  ,   47  ,   53  ,   181 ,   327 ,   493 ,   483 ,   999 ,   4421    ,   6707    ,   27933   ,   11533   ,0 };
            const std::uint32_t dim4878KuoInit[]        =   {   1   ,   3   ,   3   ,   3   ,   23  ,   7   ,   7   ,   63  ,   235 ,   493 ,   937 ,   2935    ,   2869    ,   14243   ,   30975   ,   12881   ,0 };
            const std::uint32_t dim4879KuoInit[]        =   {   1   ,   1   ,   3   ,   9   ,   9   ,   7   ,   113 ,   203 ,   297 ,   183 ,   1687    ,   3211    ,   8131    ,   7033    ,   15007   ,   1307    ,0 };
            const std::uint32_t dim4880KuoInit[]        =   {   1   ,   3   ,   1   ,   9   ,   9   ,   39  ,   99  ,   5   ,   61  ,   435 ,   427 ,   2719    ,   7741    ,   4267    ,   2423    ,   37573   ,0 };
            const std::uint32_t dim4881KuoInit[]        =   {   1   ,   3   ,   7   ,   3   ,   17  ,   1   ,   105 ,   13  ,   89  ,   693 ,   1835    ,   2455    ,   1135    ,   15545   ,   2447    ,   25673   ,0 };
            const std::uint32_t dim4882KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   15  ,   47  ,   103 ,   167 ,   21  ,   791 ,   1297    ,   3523    ,   4427    ,   7013    ,   1845    ,   44461   ,0 };
            const std::uint32_t dim4883KuoInit[]        =   {   1   ,   1   ,   5   ,   7   ,   11  ,   17  ,   55  ,   247 ,   317 ,   229 ,   1465    ,   3781    ,   2397    ,   10541   ,   8943    ,   29155   ,0 };
            const std::uint32_t dim4884KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   17  ,   17  ,   97  ,   141 ,   153 ,   883 ,   449 ,   1163    ,   3165    ,   125 ,   4689    ,   44461   ,0 };
            const std::uint32_t dim4885KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   17  ,   13  ,   9   ,   235 ,   87  ,   251 ,   57  ,   2769    ,   4845    ,   5733    ,   4305    ,   49489   ,0 };
            const std::uint32_t dim4886KuoInit[]        =   {   1   ,   1   ,   7   ,   1   ,   9   ,   41  ,   79  ,   97  ,   201 ,   789 ,   37  ,   2593    ,   8023    ,   139 ,   30623   ,   7667    ,0 };
            const std::uint32_t dim4887KuoInit[]        =   {   1   ,   1   ,   7   ,   7   ,   7   ,   27  ,   9   ,   99  ,   199 ,   163 ,   1175    ,   729 ,   2731    ,   4391    ,   27597   ,   23087   ,0 };
            const std::uint32_t dim4888KuoInit[]        =   {   1   ,   3   ,   5   ,   5   ,   29  ,   39  ,   5   ,   129 ,   395 ,   1007    ,   1751    ,   3951    ,   5879    ,   13105   ,   26223   ,   31361   ,0 };
            const std::uint32_t dim4889KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   3   ,   55  ,   89  ,   253 ,   207 ,   553 ,   1407    ,   2277    ,   6879    ,   16027   ,   23477   ,   43633   ,0 };
            const std::uint32_t dim4890KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   13  ,   21  ,   9   ,   149 ,   31  ,   359 ,   1631    ,   2199    ,   2937    ,   15663   ,   5899    ,   59959   ,0 };
            const std::uint32_t dim4891KuoInit[]        =   {   1   ,   1   ,   1   ,   7   ,   25  ,   63  ,   87  ,   13  ,   179 ,   237 ,   359 ,   3841    ,   6467    ,   5621    ,   29459   ,   31339   ,0 };
            const std::uint32_t dim4892KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   25  ,   45  ,   77  ,   17  ,   419 ,   759 ,   1045    ,   1285    ,   6739    ,   11035   ,   11401   ,   44821   ,0 };
            const std::uint32_t dim4893KuoInit[]        =   {   1   ,   3   ,   7   ,   1   ,   31  ,   47  ,   17  ,   237 ,   69  ,   389 ,   1251    ,   1205    ,   833 ,   2313    ,   17005   ,   32683   ,0 };
            const std::uint32_t dim4894KuoInit[]        =   {   1   ,   1   ,   7   ,   9   ,   13  ,   19  ,   51  ,   69  ,   261 ,   85  ,   215 ,   2215    ,   1643    ,   12985   ,   10363   ,   17123   ,0 };
            const std::uint32_t dim4895KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   3   ,   51  ,   41  ,   173 ,   161 ,   633 ,   1727    ,   3089    ,   7791    ,   7367    ,   32641   ,   14361   ,0 };
            const std::uint32_t dim4896KuoInit[]        =   {   1   ,   3   ,   5   ,   3   ,   21  ,   49  ,   19  ,   243 ,   427 ,   589 ,   1699    ,   2187    ,   4177    ,   927 ,   6201    ,   46319   ,0 };
            const std::uint32_t dim4897KuoInit[]        =   {   1   ,   1   ,   3   ,   11  ,   1   ,   59  ,   49  ,   235 ,   345 ,   731 ,   793 ,   1893    ,   4735    ,   10647   ,   31169   ,   12051   ,0 };
            const std::uint32_t dim4898KuoInit[]        =   {   1   ,   1   ,   7   ,   15  ,   23  ,   51  ,   67  ,   151 ,   253 ,   793 ,   1673    ,   3255    ,   4919    ,   11309   ,   24903   ,   9083    ,0 };
            const std::uint32_t dim4899KuoInit[]        =   {   1   ,   3   ,   3   ,   9   ,   7   ,   59  ,   41  ,   225 ,   397 ,   671 ,   513 ,   1351    ,   2835    ,   15789   ,   17679   ,   28641   ,0 };
            const std::uint32_t dim4900KuoInit[]        =   {   1   ,   3   ,   1   ,   7   ,   17  ,   39  ,   49  ,   103 ,   181 ,   375 ,   1843    ,   1183    ,   4219    ,   2931    ,   18385   ,   1203    ,0 };
            const std::uint32_t dim4901KuoInit[]        =   {   1   ,   1   ,   1   ,   3   ,   29  ,   19  ,   113 ,   55  ,   81  ,   69  ,   1541    ,   3249    ,   643 ,   841 ,   6053    ,   63571   ,0 };
            const std::uint32_t dim4902KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   1   ,   3   ,   39  ,   237 ,   283 ,   283 ,   813 ,   3539    ,   5899    ,   8489    ,   18393   ,   22371   ,0 };
            const std::uint32_t dim4903KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   5   ,   53  ,   15  ,   129 ,   95  ,   181 ,   657 ,   3735    ,   7517    ,   2435    ,   17245   ,   4075    ,0 };
            const std::uint32_t dim4904KuoInit[]        =   {   1   ,   1   ,   5   ,   3   ,   9   ,   37  ,   73  ,   95  ,   175 ,   989 ,   1443    ,   1745    ,   8117    ,   5867    ,   29729   ,   28441   ,0 };
            const std::uint32_t dim4905KuoInit[]        =   {   1   ,   3   ,   3   ,   11  ,   5   ,   41  ,   25  ,   3   ,   177 ,   735 ,   187 ,   357 ,   5365    ,   8161    ,   2071    ,   41651   ,0 };
            const std::uint32_t dim4906KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   29  ,   47  ,   27  ,   233 ,   177 ,   339 ,   1839    ,   1761    ,   5483    ,   7203    ,   32411   ,   59859   ,0 };
            const std::uint32_t dim4907KuoInit[]        =   {   1   ,   3   ,   7   ,   9   ,   13  ,   59  ,   25  ,   17  ,   157 ,   247 ,   697 ,   4011    ,   4539    ,   4253    ,   1381    ,   63009   ,0 };
            const std::uint32_t dim4908KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   19  ,   21  ,   19  ,   161 ,   325 ,   389 ,   1067    ,   525 ,   529 ,   277 ,   13775   ,   52265   ,0 };
            const std::uint32_t dim4909KuoInit[]        =   {   1   ,   1   ,   5   ,   13  ,   21  ,   17  ,   77  ,   191 ,   329 ,   627 ,   1857    ,   1705    ,   2207    ,   5329    ,   29833   ,   1523    ,0 };
            const std::uint32_t dim4910KuoInit[]        =   {   1   ,   3   ,   3   ,   1   ,   21  ,   3   ,   107 ,   85  ,   29  ,   887 ,   793 ,   1089    ,   1361    ,   10361   ,   15869   ,   1659    ,0 };
            const std::uint32_t dim4911KuoInit[]        =   {   1   ,   1   ,   1   ,   15  ,   11  ,   47  ,   85  ,   137 ,   373 ,   777 ,   875 ,   2735    ,   4381    ,   8831    ,   5891    ,   44809   ,0 };
            const std::uint32_t dim4912KuoInit[]        =   {   1   ,   1   ,   1   ,   11  ,   19  ,   9   ,   77  ,   59  ,   497 ,   643 ,   51  ,   3115    ,   7267    ,   11927   ,   28119   ,   28151   ,0 };
            const std::uint32_t dim4913KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   13  ,   27  ,   55  ,   201 ,   319 ,   167 ,   1435    ,   2197    ,   5049    ,   5923    ,   12759   ,   62383   ,0 };
            const std::uint32_t dim4914KuoInit[]        =   {   1   ,   3   ,   1   ,   3   ,   23  ,   43  ,   45  ,   193 ,   221 ,   647 ,   1933    ,   2915    ,   6461    ,   4927    ,   22105   ,   54557   ,0 };
            const std::uint32_t dim4915KuoInit[]        =   {   1   ,   1   ,   5   ,   11  ,   5   ,   23  ,   67  ,   59  ,   79  ,   507 ,   925 ,   3015    ,   317 ,   3887    ,   29967   ,   17205   ,0 };
            const std::uint32_t dim4916KuoInit[]        =   {   1   ,   3   ,   7   ,   7   ,   19  ,   39  ,   51  ,   159 ,   485 ,   315 ,   1739    ,   2617    ,   8017    ,   11655   ,   1141    ,   26055   ,0 };
            const std::uint32_t dim4917KuoInit[]        =   {   1   ,   1   ,   3   ,   1   ,   27  ,   53  ,   119 ,   113 ,   135 ,   85  ,   2023    ,   1659    ,   307 ,   8189    ,   28339   ,   53297   ,0 };
            const std::uint32_t dim4918KuoInit[]        =   {   1   ,   3   ,   3   ,   5   ,   9   ,   61  ,   57  ,   225 ,   137 ,   381 ,   1045    ,   1253    ,   1185    ,   9885    ,   30153   ,   29355   ,0 };
            const std::uint32_t dim4919KuoInit[]        =   {   1   ,   1   ,   3   ,   5   ,   19  ,   9   ,   87  ,   87  ,   393 ,   421 ,   1941    ,   57  ,   2483    ,   10855   ,   26741   ,   28091   ,0 };
            const std::uint32_t dim4920KuoInit[]        =   {   1   ,   1   ,   7   ,   5   ,   3   ,   35  ,   35  ,   137 ,   123 ,   327 ,   933 ,   3429    ,   281 ,   1705    ,   17123   ,   29337   ,0 };
            const std::uint32_t dim4921KuoInit[]        =   {   1   ,   3   ,   7   ,   13  ,   9   ,   61  ,   111 ,   207 ,   45  ,   57  ,   1093    ,   2223    ,   575 ,   11959   ,   21147   ,   30273   ,0 };
            const std::uint32_t dim4922KuoInit[]        =   {   1   ,   1   ,   5   ,   5   ,   31  ,   37  ,   123 ,   5   ,   277 ,   273 ,   525 ,   1773    ,   2685    ,   11607   ,   32079   ,   25199   ,0 };
            const std::uint32_t dim4923KuoInit[]        =   {   1   ,   1   ,   7   ,   11  ,   5   ,   29  ,   121 ,   193 ,   437 ,   417 ,   1521    ,   3057    ,   4681    ,   2773    ,   5391    ,   59747   ,0 };
            const std::uint32_t dim4924KuoInit[]        =   {   1   ,   3   ,   7   ,   11  ,   27  ,   3   ,   103 ,   17  ,   395 ,   695 ,   1731    ,   4055    ,   2727    ,   2171    ,   26893   ,   7047    ,0 };
            const std::uint32_t dim4925KuoInit[]        =   {   1   ,   3   ,   7   ,   5   ,   23  ,   9   ,   25  ,   167 ,   241 ,   755 ,   1789    ,   1977    ,   6325    ,   5425    ,   23247   ,   64181   ,0 };


            const std::uint32_t * const Kuoinitializers[4925]
            =
            {
                dim1KuoInit,
                dim2KuoInit,
                dim3KuoInit,
                dim4KuoInit,
                dim5KuoInit,
                dim6KuoInit,
                dim7KuoInit,
                dim8KuoInit,
                dim9KuoInit,
                dim10KuoInit,
                dim11KuoInit,
                dim12KuoInit,
                dim13KuoInit,
                dim14KuoInit,
                dim15KuoInit,
                dim16KuoInit,
                dim17KuoInit,
                dim18KuoInit,
                dim19KuoInit,
                dim20KuoInit,
                dim21KuoInit,
                dim22KuoInit,
                dim23KuoInit,
                dim24KuoInit,
                dim25KuoInit,
                dim26KuoInit,
                dim27KuoInit,
                dim28KuoInit,
                dim29KuoInit,
                dim30KuoInit,
                dim31KuoInit,
                dim32KuoInit,
                dim33KuoInit,
                dim34KuoInit,
                dim35KuoInit,
                dim36KuoInit,
                dim37KuoInit,
                dim38KuoInit,
                dim39KuoInit,
                dim40KuoInit,
                dim41KuoInit,
                dim42KuoInit,
                dim43KuoInit,
                dim44KuoInit,
                dim45KuoInit,
                dim46KuoInit,
                dim47KuoInit,
                dim48KuoInit,
                dim49KuoInit,
                dim50KuoInit,
                dim51KuoInit,
                dim52KuoInit,
                dim53KuoInit,
                dim54KuoInit,
                dim55KuoInit,
                dim56KuoInit,
                dim57KuoInit,
                dim58KuoInit,
                dim59KuoInit,
                dim60KuoInit,
                dim61KuoInit,
                dim62KuoInit,
                dim63KuoInit,
                dim64KuoInit,
                dim65KuoInit,
                dim66KuoInit,
                dim67KuoInit,
                dim68KuoInit,
                dim69KuoInit,
                dim70KuoInit,
                dim71KuoInit,
                dim72KuoInit,
                dim73KuoInit,
                dim74KuoInit,
                dim75KuoInit,
                dim76KuoInit,
                dim77KuoInit,
                dim78KuoInit,
                dim79KuoInit,
                dim80KuoInit,
                dim81KuoInit,
                dim82KuoInit,
                dim83KuoInit,
                dim84KuoInit,
                dim85KuoInit,
                dim86KuoInit,
                dim87KuoInit,
                dim88KuoInit,
                dim89KuoInit,
                dim90KuoInit,
                dim91KuoInit,
                dim92KuoInit,
                dim93KuoInit,
                dim94KuoInit,
                dim95KuoInit,
                dim96KuoInit,
                dim97KuoInit,
                dim98KuoInit,
                dim99KuoInit,
                dim100KuoInit,
                dim101KuoInit,
                dim102KuoInit,
                dim103KuoInit,
                dim104KuoInit,
                dim105KuoInit,
                dim106KuoInit,
                dim107KuoInit,
                dim108KuoInit,
                dim109KuoInit,
                dim110KuoInit,
                dim111KuoInit,
                dim112KuoInit,
                dim113KuoInit,
                dim114KuoInit,
                dim115KuoInit,
                dim116KuoInit,
                dim117KuoInit,
                dim118KuoInit,
                dim119KuoInit,
                dim120KuoInit,
                dim121KuoInit,
                dim122KuoInit,
                dim123KuoInit,
                dim124KuoInit,
                dim125KuoInit,
                dim126KuoInit,
                dim127KuoInit,
                dim128KuoInit,
                dim129KuoInit,
                dim130KuoInit,
                dim131KuoInit,
                dim132KuoInit,
                dim133KuoInit,
                dim134KuoInit,
                dim135KuoInit,
                dim136KuoInit,
                dim137KuoInit,
                dim138KuoInit,
                dim139KuoInit,
                dim140KuoInit,
                dim141KuoInit,
                dim142KuoInit,
                dim143KuoInit,
                dim144KuoInit,
                dim145KuoInit,
                dim146KuoInit,
                dim147KuoInit,
                dim148KuoInit,
                dim149KuoInit,
                dim150KuoInit,
                dim151KuoInit,
                dim152KuoInit,
                dim153KuoInit,
                dim154KuoInit,
                dim155KuoInit,
                dim156KuoInit,
                dim157KuoInit,
                dim158KuoInit,
                dim159KuoInit,
                dim160KuoInit,
                dim161KuoInit,
                dim162KuoInit,
                dim163KuoInit,
                dim164KuoInit,
                dim165KuoInit,
                dim166KuoInit,
                dim167KuoInit,
                dim168KuoInit,
                dim169KuoInit,
                dim170KuoInit,
                dim171KuoInit,
                dim172KuoInit,
                dim173KuoInit,
                dim174KuoInit,
                dim175KuoInit,
                dim176KuoInit,
                dim177KuoInit,
                dim178KuoInit,
                dim179KuoInit,
                dim180KuoInit,
                dim181KuoInit,
                dim182KuoInit,
                dim183KuoInit,
                dim184KuoInit,
                dim185KuoInit,
                dim186KuoInit,
                dim187KuoInit,
                dim188KuoInit,
                dim189KuoInit,
                dim190KuoInit,
                dim191KuoInit,
                dim192KuoInit,
                dim193KuoInit,
                dim194KuoInit,
                dim195KuoInit,
                dim196KuoInit,
                dim197KuoInit,
                dim198KuoInit,
                dim199KuoInit,
                dim200KuoInit,
                dim201KuoInit,
                dim202KuoInit,
                dim203KuoInit,
                dim204KuoInit,
                dim205KuoInit,
                dim206KuoInit,
                dim207KuoInit,
                dim208KuoInit,
                dim209KuoInit,
                dim210KuoInit,
                dim211KuoInit,
                dim212KuoInit,
                dim213KuoInit,
                dim214KuoInit,
                dim215KuoInit,
                dim216KuoInit,
                dim217KuoInit,
                dim218KuoInit,
                dim219KuoInit,
                dim220KuoInit,
                dim221KuoInit,
                dim222KuoInit,
                dim223KuoInit,
                dim224KuoInit,
                dim225KuoInit,
                dim226KuoInit,
                dim227KuoInit,
                dim228KuoInit,
                dim229KuoInit,
                dim230KuoInit,
                dim231KuoInit,
                dim232KuoInit,
                dim233KuoInit,
                dim234KuoInit,
                dim235KuoInit,
                dim236KuoInit,
                dim237KuoInit,
                dim238KuoInit,
                dim239KuoInit,
                dim240KuoInit,
                dim241KuoInit,
                dim242KuoInit,
                dim243KuoInit,
                dim244KuoInit,
                dim245KuoInit,
                dim246KuoInit,
                dim247KuoInit,
                dim248KuoInit,
                dim249KuoInit,
                dim250KuoInit,
                dim251KuoInit,
                dim252KuoInit,
                dim253KuoInit,
                dim254KuoInit,
                dim255KuoInit,
                dim256KuoInit,
                dim257KuoInit,
                dim258KuoInit,
                dim259KuoInit,
                dim260KuoInit,
                dim261KuoInit,
                dim262KuoInit,
                dim263KuoInit,
                dim264KuoInit,
                dim265KuoInit,
                dim266KuoInit,
                dim267KuoInit,
                dim268KuoInit,
                dim269KuoInit,
                dim270KuoInit,
                dim271KuoInit,
                dim272KuoInit,
                dim273KuoInit,
                dim274KuoInit,
                dim275KuoInit,
                dim276KuoInit,
                dim277KuoInit,
                dim278KuoInit,
                dim279KuoInit,
                dim280KuoInit,
                dim281KuoInit,
                dim282KuoInit,
                dim283KuoInit,
                dim284KuoInit,
                dim285KuoInit,
                dim286KuoInit,
                dim287KuoInit,
                dim288KuoInit,
                dim289KuoInit,
                dim290KuoInit,
                dim291KuoInit,
                dim292KuoInit,
                dim293KuoInit,
                dim294KuoInit,
                dim295KuoInit,
                dim296KuoInit,
                dim297KuoInit,
                dim298KuoInit,
                dim299KuoInit,
                dim300KuoInit,
                dim301KuoInit,
                dim302KuoInit,
                dim303KuoInit,
                dim304KuoInit,
                dim305KuoInit,
                dim306KuoInit,
                dim307KuoInit,
                dim308KuoInit,
                dim309KuoInit,
                dim310KuoInit,
                dim311KuoInit,
                dim312KuoInit,
                dim313KuoInit,
                dim314KuoInit,
                dim315KuoInit,
                dim316KuoInit,
                dim317KuoInit,
                dim318KuoInit,
                dim319KuoInit,
                dim320KuoInit,
                dim321KuoInit,
                dim322KuoInit,
                dim323KuoInit,
                dim324KuoInit,
                dim325KuoInit,
                dim326KuoInit,
                dim327KuoInit,
                dim328KuoInit,
                dim329KuoInit,
                dim330KuoInit,
                dim331KuoInit,
                dim332KuoInit,
                dim333KuoInit,
                dim334KuoInit,
                dim335KuoInit,
                dim336KuoInit,
                dim337KuoInit,
                dim338KuoInit,
                dim339KuoInit,
                dim340KuoInit,
                dim341KuoInit,
                dim342KuoInit,
                dim343KuoInit,
                dim344KuoInit,
                dim345KuoInit,
                dim346KuoInit,
                dim347KuoInit,
                dim348KuoInit,
                dim349KuoInit,
                dim350KuoInit,
                dim351KuoInit,
                dim352KuoInit,
                dim353KuoInit,
                dim354KuoInit,
                dim355KuoInit,
                dim356KuoInit,
                dim357KuoInit,
                dim358KuoInit,
                dim359KuoInit,
                dim360KuoInit,
                dim361KuoInit,
                dim362KuoInit,
                dim363KuoInit,
                dim364KuoInit,
                dim365KuoInit,
                dim366KuoInit,
                dim367KuoInit,
                dim368KuoInit,
                dim369KuoInit,
                dim370KuoInit,
                dim371KuoInit,
                dim372KuoInit,
                dim373KuoInit,
                dim374KuoInit,
                dim375KuoInit,
                dim376KuoInit,
                dim377KuoInit,
                dim378KuoInit,
                dim379KuoInit,
                dim380KuoInit,
                dim381KuoInit,
                dim382KuoInit,
                dim383KuoInit,
                dim384KuoInit,
                dim385KuoInit,
                dim386KuoInit,
                dim387KuoInit,
                dim388KuoInit,
                dim389KuoInit,
                dim390KuoInit,
                dim391KuoInit,
                dim392KuoInit,
                dim393KuoInit,
                dim394KuoInit,
                dim395KuoInit,
                dim396KuoInit,
                dim397KuoInit,
                dim398KuoInit,
                dim399KuoInit,
                dim400KuoInit,
                dim401KuoInit,
                dim402KuoInit,
                dim403KuoInit,
                dim404KuoInit,
                dim405KuoInit,
                dim406KuoInit,
                dim407KuoInit,
                dim408KuoInit,
                dim409KuoInit,
                dim410KuoInit,
                dim411KuoInit,
                dim412KuoInit,
                dim413KuoInit,
                dim414KuoInit,
                dim415KuoInit,
                dim416KuoInit,
                dim417KuoInit,
                dim418KuoInit,
                dim419KuoInit,
                dim420KuoInit,
                dim421KuoInit,
                dim422KuoInit,
                dim423KuoInit,
                dim424KuoInit,
                dim425KuoInit,
                dim426KuoInit,
                dim427KuoInit,
                dim428KuoInit,
                dim429KuoInit,
                dim430KuoInit,
                dim431KuoInit,
                dim432KuoInit,
                dim433KuoInit,
                dim434KuoInit,
                dim435KuoInit,
                dim436KuoInit,
                dim437KuoInit,
                dim438KuoInit,
                dim439KuoInit,
                dim440KuoInit,
                dim441KuoInit,
                dim442KuoInit,
                dim443KuoInit,
                dim444KuoInit,
                dim445KuoInit,
                dim446KuoInit,
                dim447KuoInit,
                dim448KuoInit,
                dim449KuoInit,
                dim450KuoInit,
                dim451KuoInit,
                dim452KuoInit,
                dim453KuoInit,
                dim454KuoInit,
                dim455KuoInit,
                dim456KuoInit,
                dim457KuoInit,
                dim458KuoInit,
                dim459KuoInit,
                dim460KuoInit,
                dim461KuoInit,
                dim462KuoInit,
                dim463KuoInit,
                dim464KuoInit,
                dim465KuoInit,
                dim466KuoInit,
                dim467KuoInit,
                dim468KuoInit,
                dim469KuoInit,
                dim470KuoInit,
                dim471KuoInit,
                dim472KuoInit,
                dim473KuoInit,
                dim474KuoInit,
                dim475KuoInit,
                dim476KuoInit,
                dim477KuoInit,
                dim478KuoInit,
                dim479KuoInit,
                dim480KuoInit,
                dim481KuoInit,
                dim482KuoInit,
                dim483KuoInit,
                dim484KuoInit,
                dim485KuoInit,
                dim486KuoInit,
                dim487KuoInit,
                dim488KuoInit,
                dim489KuoInit,
                dim490KuoInit,
                dim491KuoInit,
                dim492KuoInit,
                dim493KuoInit,
                dim494KuoInit,
                dim495KuoInit,
                dim496KuoInit,
                dim497KuoInit,
                dim498KuoInit,
                dim499KuoInit,
                dim500KuoInit,
                dim501KuoInit,
                dim502KuoInit,
                dim503KuoInit,
                dim504KuoInit,
                dim505KuoInit,
                dim506KuoInit,
                dim507KuoInit,
                dim508KuoInit,
                dim509KuoInit,
                dim510KuoInit,
                dim511KuoInit,
                dim512KuoInit,
                dim513KuoInit,
                dim514KuoInit,
                dim515KuoInit,
                dim516KuoInit,
                dim517KuoInit,
                dim518KuoInit,
                dim519KuoInit,
                dim520KuoInit,
                dim521KuoInit,
                dim522KuoInit,
                dim523KuoInit,
                dim524KuoInit,
                dim525KuoInit,
                dim526KuoInit,
                dim527KuoInit,
                dim528KuoInit,
                dim529KuoInit,
                dim530KuoInit,
                dim531KuoInit,
                dim532KuoInit,
                dim533KuoInit,
                dim534KuoInit,
                dim535KuoInit,
                dim536KuoInit,
                dim537KuoInit,
                dim538KuoInit,
                dim539KuoInit,
                dim540KuoInit,
                dim541KuoInit,
                dim542KuoInit,
                dim543KuoInit,
                dim544KuoInit,
                dim545KuoInit,
                dim546KuoInit,
                dim547KuoInit,
                dim548KuoInit,
                dim549KuoInit,
                dim550KuoInit,
                dim551KuoInit,
                dim552KuoInit,
                dim553KuoInit,
                dim554KuoInit,
                dim555KuoInit,
                dim556KuoInit,
                dim557KuoInit,
                dim558KuoInit,
                dim559KuoInit,
                dim560KuoInit,
                dim561KuoInit,
                dim562KuoInit,
                dim563KuoInit,
                dim564KuoInit,
                dim565KuoInit,
                dim566KuoInit,
                dim567KuoInit,
                dim568KuoInit,
                dim569KuoInit,
                dim570KuoInit,
                dim571KuoInit,
                dim572KuoInit,
                dim573KuoInit,
                dim574KuoInit,
                dim575KuoInit,
                dim576KuoInit,
                dim577KuoInit,
                dim578KuoInit,
                dim579KuoInit,
                dim580KuoInit,
                dim581KuoInit,
                dim582KuoInit,
                dim583KuoInit,
                dim584KuoInit,
                dim585KuoInit,
                dim586KuoInit,
                dim587KuoInit,
                dim588KuoInit,
                dim589KuoInit,
                dim590KuoInit,
                dim591KuoInit,
                dim592KuoInit,
                dim593KuoInit,
                dim594KuoInit,
                dim595KuoInit,
                dim596KuoInit,
                dim597KuoInit,
                dim598KuoInit,
                dim599KuoInit,
                dim600KuoInit,
                dim601KuoInit,
                dim602KuoInit,
                dim603KuoInit,
                dim604KuoInit,
                dim605KuoInit,
                dim606KuoInit,
                dim607KuoInit,
                dim608KuoInit,
                dim609KuoInit,
                dim610KuoInit,
                dim611KuoInit,
                dim612KuoInit,
                dim613KuoInit,
                dim614KuoInit,
                dim615KuoInit,
                dim616KuoInit,
                dim617KuoInit,
                dim618KuoInit,
                dim619KuoInit,
                dim620KuoInit,
                dim621KuoInit,
                dim622KuoInit,
                dim623KuoInit,
                dim624KuoInit,
                dim625KuoInit,
                dim626KuoInit,
                dim627KuoInit,
                dim628KuoInit,
                dim629KuoInit,
                dim630KuoInit,
                dim631KuoInit,
                dim632KuoInit,
                dim633KuoInit,
                dim634KuoInit,
                dim635KuoInit,
                dim636KuoInit,
                dim637KuoInit,
                dim638KuoInit,
                dim639KuoInit,
                dim640KuoInit,
                dim641KuoInit,
                dim642KuoInit,
                dim643KuoInit,
                dim644KuoInit,
                dim645KuoInit,
                dim646KuoInit,
                dim647KuoInit,
                dim648KuoInit,
                dim649KuoInit,
                dim650KuoInit,
                dim651KuoInit,
                dim652KuoInit,
                dim653KuoInit,
                dim654KuoInit,
                dim655KuoInit,
                dim656KuoInit,
                dim657KuoInit,
                dim658KuoInit,
                dim659KuoInit,
                dim660KuoInit,
                dim661KuoInit,
                dim662KuoInit,
                dim663KuoInit,
                dim664KuoInit,
                dim665KuoInit,
                dim666KuoInit,
                dim667KuoInit,
                dim668KuoInit,
                dim669KuoInit,
                dim670KuoInit,
                dim671KuoInit,
                dim672KuoInit,
                dim673KuoInit,
                dim674KuoInit,
                dim675KuoInit,
                dim676KuoInit,
                dim677KuoInit,
                dim678KuoInit,
                dim679KuoInit,
                dim680KuoInit,
                dim681KuoInit,
                dim682KuoInit,
                dim683KuoInit,
                dim684KuoInit,
                dim685KuoInit,
                dim686KuoInit,
                dim687KuoInit,
                dim688KuoInit,
                dim689KuoInit,
                dim690KuoInit,
                dim691KuoInit,
                dim692KuoInit,
                dim693KuoInit,
                dim694KuoInit,
                dim695KuoInit,
                dim696KuoInit,
                dim697KuoInit,
                dim698KuoInit,
                dim699KuoInit,
                dim700KuoInit,
                dim701KuoInit,
                dim702KuoInit,
                dim703KuoInit,
                dim704KuoInit,
                dim705KuoInit,
                dim706KuoInit,
                dim707KuoInit,
                dim708KuoInit,
                dim709KuoInit,
                dim710KuoInit,
                dim711KuoInit,
                dim712KuoInit,
                dim713KuoInit,
                dim714KuoInit,
                dim715KuoInit,
                dim716KuoInit,
                dim717KuoInit,
                dim718KuoInit,
                dim719KuoInit,
                dim720KuoInit,
                dim721KuoInit,
                dim722KuoInit,
                dim723KuoInit,
                dim724KuoInit,
                dim725KuoInit,
                dim726KuoInit,
                dim727KuoInit,
                dim728KuoInit,
                dim729KuoInit,
                dim730KuoInit,
                dim731KuoInit,
                dim732KuoInit,
                dim733KuoInit,
                dim734KuoInit,
                dim735KuoInit,
                dim736KuoInit,
                dim737KuoInit,
                dim738KuoInit,
                dim739KuoInit,
                dim740KuoInit,
                dim741KuoInit,
                dim742KuoInit,
                dim743KuoInit,
                dim744KuoInit,
                dim745KuoInit,
                dim746KuoInit,
                dim747KuoInit,
                dim748KuoInit,
                dim749KuoInit,
                dim750KuoInit,
                dim751KuoInit,
                dim752KuoInit,
                dim753KuoInit,
                dim754KuoInit,
                dim755KuoInit,
                dim756KuoInit,
                dim757KuoInit,
                dim758KuoInit,
                dim759KuoInit,
                dim760KuoInit,
                dim761KuoInit,
                dim762KuoInit,
                dim763KuoInit,
                dim764KuoInit,
                dim765KuoInit,
                dim766KuoInit,
                dim767KuoInit,
                dim768KuoInit,
                dim769KuoInit,
                dim770KuoInit,
                dim771KuoInit,
                dim772KuoInit,
                dim773KuoInit,
                dim774KuoInit,
                dim775KuoInit,
                dim776KuoInit,
                dim777KuoInit,
                dim778KuoInit,
                dim779KuoInit,
                dim780KuoInit,
                dim781KuoInit,
                dim782KuoInit,
                dim783KuoInit,
                dim784KuoInit,
                dim785KuoInit,
                dim786KuoInit,
                dim787KuoInit,
                dim788KuoInit,
                dim789KuoInit,
                dim790KuoInit,
                dim791KuoInit,
                dim792KuoInit,
                dim793KuoInit,
                dim794KuoInit,
                dim795KuoInit,
                dim796KuoInit,
                dim797KuoInit,
                dim798KuoInit,
                dim799KuoInit,
                dim800KuoInit,
                dim801KuoInit,
                dim802KuoInit,
                dim803KuoInit,
                dim804KuoInit,
                dim805KuoInit,
                dim806KuoInit,
                dim807KuoInit,
                dim808KuoInit,
                dim809KuoInit,
                dim810KuoInit,
                dim811KuoInit,
                dim812KuoInit,
                dim813KuoInit,
                dim814KuoInit,
                dim815KuoInit,
                dim816KuoInit,
                dim817KuoInit,
                dim818KuoInit,
                dim819KuoInit,
                dim820KuoInit,
                dim821KuoInit,
                dim822KuoInit,
                dim823KuoInit,
                dim824KuoInit,
                dim825KuoInit,
                dim826KuoInit,
                dim827KuoInit,
                dim828KuoInit,
                dim829KuoInit,
                dim830KuoInit,
                dim831KuoInit,
                dim832KuoInit,
                dim833KuoInit,
                dim834KuoInit,
                dim835KuoInit,
                dim836KuoInit,
                dim837KuoInit,
                dim838KuoInit,
                dim839KuoInit,
                dim840KuoInit,
                dim841KuoInit,
                dim842KuoInit,
                dim843KuoInit,
                dim844KuoInit,
                dim845KuoInit,
                dim846KuoInit,
                dim847KuoInit,
                dim848KuoInit,
                dim849KuoInit,
                dim850KuoInit,
                dim851KuoInit,
                dim852KuoInit,
                dim853KuoInit,
                dim854KuoInit,
                dim855KuoInit,
                dim856KuoInit,
                dim857KuoInit,
                dim858KuoInit,
                dim859KuoInit,
                dim860KuoInit,
                dim861KuoInit,
                dim862KuoInit,
                dim863KuoInit,
                dim864KuoInit,
                dim865KuoInit,
                dim866KuoInit,
                dim867KuoInit,
                dim868KuoInit,
                dim869KuoInit,
                dim870KuoInit,
                dim871KuoInit,
                dim872KuoInit,
                dim873KuoInit,
                dim874KuoInit,
                dim875KuoInit,
                dim876KuoInit,
                dim877KuoInit,
                dim878KuoInit,
                dim879KuoInit,
                dim880KuoInit,
                dim881KuoInit,
                dim882KuoInit,
                dim883KuoInit,
                dim884KuoInit,
                dim885KuoInit,
                dim886KuoInit,
                dim887KuoInit,
                dim888KuoInit,
                dim889KuoInit,
                dim890KuoInit,
                dim891KuoInit,
                dim892KuoInit,
                dim893KuoInit,
                dim894KuoInit,
                dim895KuoInit,
                dim896KuoInit,
                dim897KuoInit,
                dim898KuoInit,
                dim899KuoInit,
                dim900KuoInit,
                dim901KuoInit,
                dim902KuoInit,
                dim903KuoInit,
                dim904KuoInit,
                dim905KuoInit,
                dim906KuoInit,
                dim907KuoInit,
                dim908KuoInit,
                dim909KuoInit,
                dim910KuoInit,
                dim911KuoInit,
                dim912KuoInit,
                dim913KuoInit,
                dim914KuoInit,
                dim915KuoInit,
                dim916KuoInit,
                dim917KuoInit,
                dim918KuoInit,
                dim919KuoInit,
                dim920KuoInit,
                dim921KuoInit,
                dim922KuoInit,
                dim923KuoInit,
                dim924KuoInit,
                dim925KuoInit,
                dim926KuoInit,
                dim927KuoInit,
                dim928KuoInit,
                dim929KuoInit,
                dim930KuoInit,
                dim931KuoInit,
                dim932KuoInit,
                dim933KuoInit,
                dim934KuoInit,
                dim935KuoInit,
                dim936KuoInit,
                dim937KuoInit,
                dim938KuoInit,
                dim939KuoInit,
                dim940KuoInit,
                dim941KuoInit,
                dim942KuoInit,
                dim943KuoInit,
                dim944KuoInit,
                dim945KuoInit,
                dim946KuoInit,
                dim947KuoInit,
                dim948KuoInit,
                dim949KuoInit,
                dim950KuoInit,
                dim951KuoInit,
                dim952KuoInit,
                dim953KuoInit,
                dim954KuoInit,
                dim955KuoInit,
                dim956KuoInit,
                dim957KuoInit,
                dim958KuoInit,
                dim959KuoInit,
                dim960KuoInit,
                dim961KuoInit,
                dim962KuoInit,
                dim963KuoInit,
                dim964KuoInit,
                dim965KuoInit,
                dim966KuoInit,
                dim967KuoInit,
                dim968KuoInit,
                dim969KuoInit,
                dim970KuoInit,
                dim971KuoInit,
                dim972KuoInit,
                dim973KuoInit,
                dim974KuoInit,
                dim975KuoInit,
                dim976KuoInit,
                dim977KuoInit,
                dim978KuoInit,
                dim979KuoInit,
                dim980KuoInit,
                dim981KuoInit,
                dim982KuoInit,
                dim983KuoInit,
                dim984KuoInit,
                dim985KuoInit,
                dim986KuoInit,
                dim987KuoInit,
                dim988KuoInit,
                dim989KuoInit,
                dim990KuoInit,
                dim991KuoInit,
                dim992KuoInit,
                dim993KuoInit,
                dim994KuoInit,
                dim995KuoInit,
                dim996KuoInit,
                dim997KuoInit,
                dim998KuoInit,
                dim999KuoInit,
                dim1000KuoInit,
                dim1001KuoInit,
                dim1002KuoInit,
                dim1003KuoInit,
                dim1004KuoInit,
                dim1005KuoInit,
                dim1006KuoInit,
                dim1007KuoInit,
                dim1008KuoInit,
                dim1009KuoInit,
                dim1010KuoInit,
                dim1011KuoInit,
                dim1012KuoInit,
                dim1013KuoInit,
                dim1014KuoInit,
                dim1015KuoInit,
                dim1016KuoInit,
                dim1017KuoInit,
                dim1018KuoInit,
                dim1019KuoInit,
                dim1020KuoInit,
                dim1021KuoInit,
                dim1022KuoInit,
                dim1023KuoInit,
                dim1024KuoInit,
                dim1025KuoInit,
                dim1026KuoInit,
                dim1027KuoInit,
                dim1028KuoInit,
                dim1029KuoInit,
                dim1030KuoInit,
                dim1031KuoInit,
                dim1032KuoInit,
                dim1033KuoInit,
                dim1034KuoInit,
                dim1035KuoInit,
                dim1036KuoInit,
                dim1037KuoInit,
                dim1038KuoInit,
                dim1039KuoInit,
                dim1040KuoInit,
                dim1041KuoInit,
                dim1042KuoInit,
                dim1043KuoInit,
                dim1044KuoInit,
                dim1045KuoInit,
                dim1046KuoInit,
                dim1047KuoInit,
                dim1048KuoInit,
                dim1049KuoInit,
                dim1050KuoInit,
                dim1051KuoInit,
                dim1052KuoInit,
                dim1053KuoInit,
                dim1054KuoInit,
                dim1055KuoInit,
                dim1056KuoInit,
                dim1057KuoInit,
                dim1058KuoInit,
                dim1059KuoInit,
                dim1060KuoInit,
                dim1061KuoInit,
                dim1062KuoInit,
                dim1063KuoInit,
                dim1064KuoInit,
                dim1065KuoInit,
                dim1066KuoInit,
                dim1067KuoInit,
                dim1068KuoInit,
                dim1069KuoInit,
                dim1070KuoInit,
                dim1071KuoInit,
                dim1072KuoInit,
                dim1073KuoInit,
                dim1074KuoInit,
                dim1075KuoInit,
                dim1076KuoInit,
                dim1077KuoInit,
                dim1078KuoInit,
                dim1079KuoInit,
                dim1080KuoInit,
                dim1081KuoInit,
                dim1082KuoInit,
                dim1083KuoInit,
                dim1084KuoInit,
                dim1085KuoInit,
                dim1086KuoInit,
                dim1087KuoInit,
                dim1088KuoInit,
                dim1089KuoInit,
                dim1090KuoInit,
                dim1091KuoInit,
                dim1092KuoInit,
                dim1093KuoInit,
                dim1094KuoInit,
                dim1095KuoInit,
                dim1096KuoInit,
                dim1097KuoInit,
                dim1098KuoInit,
                dim1099KuoInit,
                dim1100KuoInit,
                dim1101KuoInit,
                dim1102KuoInit,
                dim1103KuoInit,
                dim1104KuoInit,
                dim1105KuoInit,
                dim1106KuoInit,
                dim1107KuoInit,
                dim1108KuoInit,
                dim1109KuoInit,
                dim1110KuoInit,
                dim1111KuoInit,
                dim1112KuoInit,
                dim1113KuoInit,
                dim1114KuoInit,
                dim1115KuoInit,
                dim1116KuoInit,
                dim1117KuoInit,
                dim1118KuoInit,
                dim1119KuoInit,
                dim1120KuoInit,
                dim1121KuoInit,
                dim1122KuoInit,
                dim1123KuoInit,
                dim1124KuoInit,
                dim1125KuoInit,
                dim1126KuoInit,
                dim1127KuoInit,
                dim1128KuoInit,
                dim1129KuoInit,
                dim1130KuoInit,
                dim1131KuoInit,
                dim1132KuoInit,
                dim1133KuoInit,
                dim1134KuoInit,
                dim1135KuoInit,
                dim1136KuoInit,
                dim1137KuoInit,
                dim1138KuoInit,
                dim1139KuoInit,
                dim1140KuoInit,
                dim1141KuoInit,
                dim1142KuoInit,
                dim1143KuoInit,
                dim1144KuoInit,
                dim1145KuoInit,
                dim1146KuoInit,
                dim1147KuoInit,
                dim1148KuoInit,
                dim1149KuoInit,
                dim1150KuoInit,
                dim1151KuoInit,
                dim1152KuoInit,
                dim1153KuoInit,
                dim1154KuoInit,
                dim1155KuoInit,
                dim1156KuoInit,
                dim1157KuoInit,
                dim1158KuoInit,
                dim1159KuoInit,
                dim1160KuoInit,
                dim1161KuoInit,
                dim1162KuoInit,
                dim1163KuoInit,
                dim1164KuoInit,
                dim1165KuoInit,
                dim1166KuoInit,
                dim1167KuoInit,
                dim1168KuoInit,
                dim1169KuoInit,
                dim1170KuoInit,
                dim1171KuoInit,
                dim1172KuoInit,
                dim1173KuoInit,
                dim1174KuoInit,
                dim1175KuoInit,
                dim1176KuoInit,
                dim1177KuoInit,
                dim1178KuoInit,
                dim1179KuoInit,
                dim1180KuoInit,
                dim1181KuoInit,
                dim1182KuoInit,
                dim1183KuoInit,
                dim1184KuoInit,
                dim1185KuoInit,
                dim1186KuoInit,
                dim1187KuoInit,
                dim1188KuoInit,
                dim1189KuoInit,
                dim1190KuoInit,
                dim1191KuoInit,
                dim1192KuoInit,
                dim1193KuoInit,
                dim1194KuoInit,
                dim1195KuoInit,
                dim1196KuoInit,
                dim1197KuoInit,
                dim1198KuoInit,
                dim1199KuoInit,
                dim1200KuoInit,
                dim1201KuoInit,
                dim1202KuoInit,
                dim1203KuoInit,
                dim1204KuoInit,
                dim1205KuoInit,
                dim1206KuoInit,
                dim1207KuoInit,
                dim1208KuoInit,
                dim1209KuoInit,
                dim1210KuoInit,
                dim1211KuoInit,
                dim1212KuoInit,
                dim1213KuoInit,
                dim1214KuoInit,
                dim1215KuoInit,
                dim1216KuoInit,
                dim1217KuoInit,
                dim1218KuoInit,
                dim1219KuoInit,
                dim1220KuoInit,
                dim1221KuoInit,
                dim1222KuoInit,
                dim1223KuoInit,
                dim1224KuoInit,
                dim1225KuoInit,
                dim1226KuoInit,
                dim1227KuoInit,
                dim1228KuoInit,
                dim1229KuoInit,
                dim1230KuoInit,
                dim1231KuoInit,
                dim1232KuoInit,
                dim1233KuoInit,
                dim1234KuoInit,
                dim1235KuoInit,
                dim1236KuoInit,
                dim1237KuoInit,
                dim1238KuoInit,
                dim1239KuoInit,
                dim1240KuoInit,
                dim1241KuoInit,
                dim1242KuoInit,
                dim1243KuoInit,
                dim1244KuoInit,
                dim1245KuoInit,
                dim1246KuoInit,
                dim1247KuoInit,
                dim1248KuoInit,
                dim1249KuoInit,
                dim1250KuoInit,
                dim1251KuoInit,
                dim1252KuoInit,
                dim1253KuoInit,
                dim1254KuoInit,
                dim1255KuoInit,
                dim1256KuoInit,
                dim1257KuoInit,
                dim1258KuoInit,
                dim1259KuoInit,
                dim1260KuoInit,
                dim1261KuoInit,
                dim1262KuoInit,
                dim1263KuoInit,
                dim1264KuoInit,
                dim1265KuoInit,
                dim1266KuoInit,
                dim1267KuoInit,
                dim1268KuoInit,
                dim1269KuoInit,
                dim1270KuoInit,
                dim1271KuoInit,
                dim1272KuoInit,
                dim1273KuoInit,
                dim1274KuoInit,
                dim1275KuoInit,
                dim1276KuoInit,
                dim1277KuoInit,
                dim1278KuoInit,
                dim1279KuoInit,
                dim1280KuoInit,
                dim1281KuoInit,
                dim1282KuoInit,
                dim1283KuoInit,
                dim1284KuoInit,
                dim1285KuoInit,
                dim1286KuoInit,
                dim1287KuoInit,
                dim1288KuoInit,
                dim1289KuoInit,
                dim1290KuoInit,
                dim1291KuoInit,
                dim1292KuoInit,
                dim1293KuoInit,
                dim1294KuoInit,
                dim1295KuoInit,
                dim1296KuoInit,
                dim1297KuoInit,
                dim1298KuoInit,
                dim1299KuoInit,
                dim1300KuoInit,
                dim1301KuoInit,
                dim1302KuoInit,
                dim1303KuoInit,
                dim1304KuoInit,
                dim1305KuoInit,
                dim1306KuoInit,
                dim1307KuoInit,
                dim1308KuoInit,
                dim1309KuoInit,
                dim1310KuoInit,
                dim1311KuoInit,
                dim1312KuoInit,
                dim1313KuoInit,
                dim1314KuoInit,
                dim1315KuoInit,
                dim1316KuoInit,
                dim1317KuoInit,
                dim1318KuoInit,
                dim1319KuoInit,
                dim1320KuoInit,
                dim1321KuoInit,
                dim1322KuoInit,
                dim1323KuoInit,
                dim1324KuoInit,
                dim1325KuoInit,
                dim1326KuoInit,
                dim1327KuoInit,
                dim1328KuoInit,
                dim1329KuoInit,
                dim1330KuoInit,
                dim1331KuoInit,
                dim1332KuoInit,
                dim1333KuoInit,
                dim1334KuoInit,
                dim1335KuoInit,
                dim1336KuoInit,
                dim1337KuoInit,
                dim1338KuoInit,
                dim1339KuoInit,
                dim1340KuoInit,
                dim1341KuoInit,
                dim1342KuoInit,
                dim1343KuoInit,
                dim1344KuoInit,
                dim1345KuoInit,
                dim1346KuoInit,
                dim1347KuoInit,
                dim1348KuoInit,
                dim1349KuoInit,
                dim1350KuoInit,
                dim1351KuoInit,
                dim1352KuoInit,
                dim1353KuoInit,
                dim1354KuoInit,
                dim1355KuoInit,
                dim1356KuoInit,
                dim1357KuoInit,
                dim1358KuoInit,
                dim1359KuoInit,
                dim1360KuoInit,
                dim1361KuoInit,
                dim1362KuoInit,
                dim1363KuoInit,
                dim1364KuoInit,
                dim1365KuoInit,
                dim1366KuoInit,
                dim1367KuoInit,
                dim1368KuoInit,
                dim1369KuoInit,
                dim1370KuoInit,
                dim1371KuoInit,
                dim1372KuoInit,
                dim1373KuoInit,
                dim1374KuoInit,
                dim1375KuoInit,
                dim1376KuoInit,
                dim1377KuoInit,
                dim1378KuoInit,
                dim1379KuoInit,
                dim1380KuoInit,
                dim1381KuoInit,
                dim1382KuoInit,
                dim1383KuoInit,
                dim1384KuoInit,
                dim1385KuoInit,
                dim1386KuoInit,
                dim1387KuoInit,
                dim1388KuoInit,
                dim1389KuoInit,
                dim1390KuoInit,
                dim1391KuoInit,
                dim1392KuoInit,
                dim1393KuoInit,
                dim1394KuoInit,
                dim1395KuoInit,
                dim1396KuoInit,
                dim1397KuoInit,
                dim1398KuoInit,
                dim1399KuoInit,
                dim1400KuoInit,
                dim1401KuoInit,
                dim1402KuoInit,
                dim1403KuoInit,
                dim1404KuoInit,
                dim1405KuoInit,
                dim1406KuoInit,
                dim1407KuoInit,
                dim1408KuoInit,
                dim1409KuoInit,
                dim1410KuoInit,
                dim1411KuoInit,
                dim1412KuoInit,
                dim1413KuoInit,
                dim1414KuoInit,
                dim1415KuoInit,
                dim1416KuoInit,
                dim1417KuoInit,
                dim1418KuoInit,
                dim1419KuoInit,
                dim1420KuoInit,
                dim1421KuoInit,
                dim1422KuoInit,
                dim1423KuoInit,
                dim1424KuoInit,
                dim1425KuoInit,
                dim1426KuoInit,
                dim1427KuoInit,
                dim1428KuoInit,
                dim1429KuoInit,
                dim1430KuoInit,
                dim1431KuoInit,
                dim1432KuoInit,
                dim1433KuoInit,
                dim1434KuoInit,
                dim1435KuoInit,
                dim1436KuoInit,
                dim1437KuoInit,
                dim1438KuoInit,
                dim1439KuoInit,
                dim1440KuoInit,
                dim1441KuoInit,
                dim1442KuoInit,
                dim1443KuoInit,
                dim1444KuoInit,
                dim1445KuoInit,
                dim1446KuoInit,
                dim1447KuoInit,
                dim1448KuoInit,
                dim1449KuoInit,
                dim1450KuoInit,
                dim1451KuoInit,
                dim1452KuoInit,
                dim1453KuoInit,
                dim1454KuoInit,
                dim1455KuoInit,
                dim1456KuoInit,
                dim1457KuoInit,
                dim1458KuoInit,
                dim1459KuoInit,
                dim1460KuoInit,
                dim1461KuoInit,
                dim1462KuoInit,
                dim1463KuoInit,
                dim1464KuoInit,
                dim1465KuoInit,
                dim1466KuoInit,
                dim1467KuoInit,
                dim1468KuoInit,
                dim1469KuoInit,
                dim1470KuoInit,
                dim1471KuoInit,
                dim1472KuoInit,
                dim1473KuoInit,
                dim1474KuoInit,
                dim1475KuoInit,
                dim1476KuoInit,
                dim1477KuoInit,
                dim1478KuoInit,
                dim1479KuoInit,
                dim1480KuoInit,
                dim1481KuoInit,
                dim1482KuoInit,
                dim1483KuoInit,
                dim1484KuoInit,
                dim1485KuoInit,
                dim1486KuoInit,
                dim1487KuoInit,
                dim1488KuoInit,
                dim1489KuoInit,
                dim1490KuoInit,
                dim1491KuoInit,
                dim1492KuoInit,
                dim1493KuoInit,
                dim1494KuoInit,
                dim1495KuoInit,
                dim1496KuoInit,
                dim1497KuoInit,
                dim1498KuoInit,
                dim1499KuoInit,
                dim1500KuoInit,
                dim1501KuoInit,
                dim1502KuoInit,
                dim1503KuoInit,
                dim1504KuoInit,
                dim1505KuoInit,
                dim1506KuoInit,
                dim1507KuoInit,
                dim1508KuoInit,
                dim1509KuoInit,
                dim1510KuoInit,
                dim1511KuoInit,
                dim1512KuoInit,
                dim1513KuoInit,
                dim1514KuoInit,
                dim1515KuoInit,
                dim1516KuoInit,
                dim1517KuoInit,
                dim1518KuoInit,
                dim1519KuoInit,
                dim1520KuoInit,
                dim1521KuoInit,
                dim1522KuoInit,
                dim1523KuoInit,
                dim1524KuoInit,
                dim1525KuoInit,
                dim1526KuoInit,
                dim1527KuoInit,
                dim1528KuoInit,
                dim1529KuoInit,
                dim1530KuoInit,
                dim1531KuoInit,
                dim1532KuoInit,
                dim1533KuoInit,
                dim1534KuoInit,
                dim1535KuoInit,
                dim1536KuoInit,
                dim1537KuoInit,
                dim1538KuoInit,
                dim1539KuoInit,
                dim1540KuoInit,
                dim1541KuoInit,
                dim1542KuoInit,
                dim1543KuoInit,
                dim1544KuoInit,
                dim1545KuoInit,
                dim1546KuoInit,
                dim1547KuoInit,
                dim1548KuoInit,
                dim1549KuoInit,
                dim1550KuoInit,
                dim1551KuoInit,
                dim1552KuoInit,
                dim1553KuoInit,
                dim1554KuoInit,
                dim1555KuoInit,
                dim1556KuoInit,
                dim1557KuoInit,
                dim1558KuoInit,
                dim1559KuoInit,
                dim1560KuoInit,
                dim1561KuoInit,
                dim1562KuoInit,
                dim1563KuoInit,
                dim1564KuoInit,
                dim1565KuoInit,
                dim1566KuoInit,
                dim1567KuoInit,
                dim1568KuoInit,
                dim1569KuoInit,
                dim1570KuoInit,
                dim1571KuoInit,
                dim1572KuoInit,
                dim1573KuoInit,
                dim1574KuoInit,
                dim1575KuoInit,
                dim1576KuoInit,
                dim1577KuoInit,
                dim1578KuoInit,
                dim1579KuoInit,
                dim1580KuoInit,
                dim1581KuoInit,
                dim1582KuoInit,
                dim1583KuoInit,
                dim1584KuoInit,
                dim1585KuoInit,
                dim1586KuoInit,
                dim1587KuoInit,
                dim1588KuoInit,
                dim1589KuoInit,
                dim1590KuoInit,
                dim1591KuoInit,
                dim1592KuoInit,
                dim1593KuoInit,
                dim1594KuoInit,
                dim1595KuoInit,
                dim1596KuoInit,
                dim1597KuoInit,
                dim1598KuoInit,
                dim1599KuoInit,
                dim1600KuoInit,
                dim1601KuoInit,
                dim1602KuoInit,
                dim1603KuoInit,
                dim1604KuoInit,
                dim1605KuoInit,
                dim1606KuoInit,
                dim1607KuoInit,
                dim1608KuoInit,
                dim1609KuoInit,
                dim1610KuoInit,
                dim1611KuoInit,
                dim1612KuoInit,
                dim1613KuoInit,
                dim1614KuoInit,
                dim1615KuoInit,
                dim1616KuoInit,
                dim1617KuoInit,
                dim1618KuoInit,
                dim1619KuoInit,
                dim1620KuoInit,
                dim1621KuoInit,
                dim1622KuoInit,
                dim1623KuoInit,
                dim1624KuoInit,
                dim1625KuoInit,
                dim1626KuoInit,
                dim1627KuoInit,
                dim1628KuoInit,
                dim1629KuoInit,
                dim1630KuoInit,
                dim1631KuoInit,
                dim1632KuoInit,
                dim1633KuoInit,
                dim1634KuoInit,
                dim1635KuoInit,
                dim1636KuoInit,
                dim1637KuoInit,
                dim1638KuoInit,
                dim1639KuoInit,
                dim1640KuoInit,
                dim1641KuoInit,
                dim1642KuoInit,
                dim1643KuoInit,
                dim1644KuoInit,
                dim1645KuoInit,
                dim1646KuoInit,
                dim1647KuoInit,
                dim1648KuoInit,
                dim1649KuoInit,
                dim1650KuoInit,
                dim1651KuoInit,
                dim1652KuoInit,
                dim1653KuoInit,
                dim1654KuoInit,
                dim1655KuoInit,
                dim1656KuoInit,
                dim1657KuoInit,
                dim1658KuoInit,
                dim1659KuoInit,
                dim1660KuoInit,
                dim1661KuoInit,
                dim1662KuoInit,
                dim1663KuoInit,
                dim1664KuoInit,
                dim1665KuoInit,
                dim1666KuoInit,
                dim1667KuoInit,
                dim1668KuoInit,
                dim1669KuoInit,
                dim1670KuoInit,
                dim1671KuoInit,
                dim1672KuoInit,
                dim1673KuoInit,
                dim1674KuoInit,
                dim1675KuoInit,
                dim1676KuoInit,
                dim1677KuoInit,
                dim1678KuoInit,
                dim1679KuoInit,
                dim1680KuoInit,
                dim1681KuoInit,
                dim1682KuoInit,
                dim1683KuoInit,
                dim1684KuoInit,
                dim1685KuoInit,
                dim1686KuoInit,
                dim1687KuoInit,
                dim1688KuoInit,
                dim1689KuoInit,
                dim1690KuoInit,
                dim1691KuoInit,
                dim1692KuoInit,
                dim1693KuoInit,
                dim1694KuoInit,
                dim1695KuoInit,
                dim1696KuoInit,
                dim1697KuoInit,
                dim1698KuoInit,
                dim1699KuoInit,
                dim1700KuoInit,
                dim1701KuoInit,
                dim1702KuoInit,
                dim1703KuoInit,
                dim1704KuoInit,
                dim1705KuoInit,
                dim1706KuoInit,
                dim1707KuoInit,
                dim1708KuoInit,
                dim1709KuoInit,
                dim1710KuoInit,
                dim1711KuoInit,
                dim1712KuoInit,
                dim1713KuoInit,
                dim1714KuoInit,
                dim1715KuoInit,
                dim1716KuoInit,
                dim1717KuoInit,
                dim1718KuoInit,
                dim1719KuoInit,
                dim1720KuoInit,
                dim1721KuoInit,
                dim1722KuoInit,
                dim1723KuoInit,
                dim1724KuoInit,
                dim1725KuoInit,
                dim1726KuoInit,
                dim1727KuoInit,
                dim1728KuoInit,
                dim1729KuoInit,
                dim1730KuoInit,
                dim1731KuoInit,
                dim1732KuoInit,
                dim1733KuoInit,
                dim1734KuoInit,
                dim1735KuoInit,
                dim1736KuoInit,
                dim1737KuoInit,
                dim1738KuoInit,
                dim1739KuoInit,
                dim1740KuoInit,
                dim1741KuoInit,
                dim1742KuoInit,
                dim1743KuoInit,
                dim1744KuoInit,
                dim1745KuoInit,
                dim1746KuoInit,
                dim1747KuoInit,
                dim1748KuoInit,
                dim1749KuoInit,
                dim1750KuoInit,
                dim1751KuoInit,
                dim1752KuoInit,
                dim1753KuoInit,
                dim1754KuoInit,
                dim1755KuoInit,
                dim1756KuoInit,
                dim1757KuoInit,
                dim1758KuoInit,
                dim1759KuoInit,
                dim1760KuoInit,
                dim1761KuoInit,
                dim1762KuoInit,
                dim1763KuoInit,
                dim1764KuoInit,
                dim1765KuoInit,
                dim1766KuoInit,
                dim1767KuoInit,
                dim1768KuoInit,
                dim1769KuoInit,
                dim1770KuoInit,
                dim1771KuoInit,
                dim1772KuoInit,
                dim1773KuoInit,
                dim1774KuoInit,
                dim1775KuoInit,
                dim1776KuoInit,
                dim1777KuoInit,
                dim1778KuoInit,
                dim1779KuoInit,
                dim1780KuoInit,
                dim1781KuoInit,
                dim1782KuoInit,
                dim1783KuoInit,
                dim1784KuoInit,
                dim1785KuoInit,
                dim1786KuoInit,
                dim1787KuoInit,
                dim1788KuoInit,
                dim1789KuoInit,
                dim1790KuoInit,
                dim1791KuoInit,
                dim1792KuoInit,
                dim1793KuoInit,
                dim1794KuoInit,
                dim1795KuoInit,
                dim1796KuoInit,
                dim1797KuoInit,
                dim1798KuoInit,
                dim1799KuoInit,
                dim1800KuoInit,
                dim1801KuoInit,
                dim1802KuoInit,
                dim1803KuoInit,
                dim1804KuoInit,
                dim1805KuoInit,
                dim1806KuoInit,
                dim1807KuoInit,
                dim1808KuoInit,
                dim1809KuoInit,
                dim1810KuoInit,
                dim1811KuoInit,
                dim1812KuoInit,
                dim1813KuoInit,
                dim1814KuoInit,
                dim1815KuoInit,
                dim1816KuoInit,
                dim1817KuoInit,
                dim1818KuoInit,
                dim1819KuoInit,
                dim1820KuoInit,
                dim1821KuoInit,
                dim1822KuoInit,
                dim1823KuoInit,
                dim1824KuoInit,
                dim1825KuoInit,
                dim1826KuoInit,
                dim1827KuoInit,
                dim1828KuoInit,
                dim1829KuoInit,
                dim1830KuoInit,
                dim1831KuoInit,
                dim1832KuoInit,
                dim1833KuoInit,
                dim1834KuoInit,
                dim1835KuoInit,
                dim1836KuoInit,
                dim1837KuoInit,
                dim1838KuoInit,
                dim1839KuoInit,
                dim1840KuoInit,
                dim1841KuoInit,
                dim1842KuoInit,
                dim1843KuoInit,
                dim1844KuoInit,
                dim1845KuoInit,
                dim1846KuoInit,
                dim1847KuoInit,
                dim1848KuoInit,
                dim1849KuoInit,
                dim1850KuoInit,
                dim1851KuoInit,
                dim1852KuoInit,
                dim1853KuoInit,
                dim1854KuoInit,
                dim1855KuoInit,
                dim1856KuoInit,
                dim1857KuoInit,
                dim1858KuoInit,
                dim1859KuoInit,
                dim1860KuoInit,
                dim1861KuoInit,
                dim1862KuoInit,
                dim1863KuoInit,
                dim1864KuoInit,
                dim1865KuoInit,
                dim1866KuoInit,
                dim1867KuoInit,
                dim1868KuoInit,
                dim1869KuoInit,
                dim1870KuoInit,
                dim1871KuoInit,
                dim1872KuoInit,
                dim1873KuoInit,
                dim1874KuoInit,
                dim1875KuoInit,
                dim1876KuoInit,
                dim1877KuoInit,
                dim1878KuoInit,
                dim1879KuoInit,
                dim1880KuoInit,
                dim1881KuoInit,
                dim1882KuoInit,
                dim1883KuoInit,
                dim1884KuoInit,
                dim1885KuoInit,
                dim1886KuoInit,
                dim1887KuoInit,
                dim1888KuoInit,
                dim1889KuoInit,
                dim1890KuoInit,
                dim1891KuoInit,
                dim1892KuoInit,
                dim1893KuoInit,
                dim1894KuoInit,
                dim1895KuoInit,
                dim1896KuoInit,
                dim1897KuoInit,
                dim1898KuoInit,
                dim1899KuoInit,
                dim1900KuoInit,
                dim1901KuoInit,
                dim1902KuoInit,
                dim1903KuoInit,
                dim1904KuoInit,
                dim1905KuoInit,
                dim1906KuoInit,
                dim1907KuoInit,
                dim1908KuoInit,
                dim1909KuoInit,
                dim1910KuoInit,
                dim1911KuoInit,
                dim1912KuoInit,
                dim1913KuoInit,
                dim1914KuoInit,
                dim1915KuoInit,
                dim1916KuoInit,
                dim1917KuoInit,
                dim1918KuoInit,
                dim1919KuoInit,
                dim1920KuoInit,
                dim1921KuoInit,
                dim1922KuoInit,
                dim1923KuoInit,
                dim1924KuoInit,
                dim1925KuoInit,
                dim1926KuoInit,
                dim1927KuoInit,
                dim1928KuoInit,
                dim1929KuoInit,
                dim1930KuoInit,
                dim1931KuoInit,
                dim1932KuoInit,
                dim1933KuoInit,
                dim1934KuoInit,
                dim1935KuoInit,
                dim1936KuoInit,
                dim1937KuoInit,
                dim1938KuoInit,
                dim1939KuoInit,
                dim1940KuoInit,
                dim1941KuoInit,
                dim1942KuoInit,
                dim1943KuoInit,
                dim1944KuoInit,
                dim1945KuoInit,
                dim1946KuoInit,
                dim1947KuoInit,
                dim1948KuoInit,
                dim1949KuoInit,
                dim1950KuoInit,
                dim1951KuoInit,
                dim1952KuoInit,
                dim1953KuoInit,
                dim1954KuoInit,
                dim1955KuoInit,
                dim1956KuoInit,
                dim1957KuoInit,
                dim1958KuoInit,
                dim1959KuoInit,
                dim1960KuoInit,
                dim1961KuoInit,
                dim1962KuoInit,
                dim1963KuoInit,
                dim1964KuoInit,
                dim1965KuoInit,
                dim1966KuoInit,
                dim1967KuoInit,
                dim1968KuoInit,
                dim1969KuoInit,
                dim1970KuoInit,
                dim1971KuoInit,
                dim1972KuoInit,
                dim1973KuoInit,
                dim1974KuoInit,
                dim1975KuoInit,
                dim1976KuoInit,
                dim1977KuoInit,
                dim1978KuoInit,
                dim1979KuoInit,
                dim1980KuoInit,
                dim1981KuoInit,
                dim1982KuoInit,
                dim1983KuoInit,
                dim1984KuoInit,
                dim1985KuoInit,
                dim1986KuoInit,
                dim1987KuoInit,
                dim1988KuoInit,
                dim1989KuoInit,
                dim1990KuoInit,
                dim1991KuoInit,
                dim1992KuoInit,
                dim1993KuoInit,
                dim1994KuoInit,
                dim1995KuoInit,
                dim1996KuoInit,
                dim1997KuoInit,
                dim1998KuoInit,
                dim1999KuoInit,
                dim2000KuoInit,
                dim2001KuoInit,
                dim2002KuoInit,
                dim2003KuoInit,
                dim2004KuoInit,
                dim2005KuoInit,
                dim2006KuoInit,
                dim2007KuoInit,
                dim2008KuoInit,
                dim2009KuoInit,
                dim2010KuoInit,
                dim2011KuoInit,
                dim2012KuoInit,
                dim2013KuoInit,
                dim2014KuoInit,
                dim2015KuoInit,
                dim2016KuoInit,
                dim2017KuoInit,
                dim2018KuoInit,
                dim2019KuoInit,
                dim2020KuoInit,
                dim2021KuoInit,
                dim2022KuoInit,
                dim2023KuoInit,
                dim2024KuoInit,
                dim2025KuoInit,
                dim2026KuoInit,
                dim2027KuoInit,
                dim2028KuoInit,
                dim2029KuoInit,
                dim2030KuoInit,
                dim2031KuoInit,
                dim2032KuoInit,
                dim2033KuoInit,
                dim2034KuoInit,
                dim2035KuoInit,
                dim2036KuoInit,
                dim2037KuoInit,
                dim2038KuoInit,
                dim2039KuoInit,
                dim2040KuoInit,
                dim2041KuoInit,
                dim2042KuoInit,
                dim2043KuoInit,
                dim2044KuoInit,
                dim2045KuoInit,
                dim2046KuoInit,
                dim2047KuoInit,
                dim2048KuoInit,
                dim2049KuoInit,
                dim2050KuoInit,
                dim2051KuoInit,
                dim2052KuoInit,
                dim2053KuoInit,
                dim2054KuoInit,
                dim2055KuoInit,
                dim2056KuoInit,
                dim2057KuoInit,
                dim2058KuoInit,
                dim2059KuoInit,
                dim2060KuoInit,
                dim2061KuoInit,
                dim2062KuoInit,
                dim2063KuoInit,
                dim2064KuoInit,
                dim2065KuoInit,
                dim2066KuoInit,
                dim2067KuoInit,
                dim2068KuoInit,
                dim2069KuoInit,
                dim2070KuoInit,
                dim2071KuoInit,
                dim2072KuoInit,
                dim2073KuoInit,
                dim2074KuoInit,
                dim2075KuoInit,
                dim2076KuoInit,
                dim2077KuoInit,
                dim2078KuoInit,
                dim2079KuoInit,
                dim2080KuoInit,
                dim2081KuoInit,
                dim2082KuoInit,
                dim2083KuoInit,
                dim2084KuoInit,
                dim2085KuoInit,
                dim2086KuoInit,
                dim2087KuoInit,
                dim2088KuoInit,
                dim2089KuoInit,
                dim2090KuoInit,
                dim2091KuoInit,
                dim2092KuoInit,
                dim2093KuoInit,
                dim2094KuoInit,
                dim2095KuoInit,
                dim2096KuoInit,
                dim2097KuoInit,
                dim2098KuoInit,
                dim2099KuoInit,
                dim2100KuoInit,
                dim2101KuoInit,
                dim2102KuoInit,
                dim2103KuoInit,
                dim2104KuoInit,
                dim2105KuoInit,
                dim2106KuoInit,
                dim2107KuoInit,
                dim2108KuoInit,
                dim2109KuoInit,
                dim2110KuoInit,
                dim2111KuoInit,
                dim2112KuoInit,
                dim2113KuoInit,
                dim2114KuoInit,
                dim2115KuoInit,
                dim2116KuoInit,
                dim2117KuoInit,
                dim2118KuoInit,
                dim2119KuoInit,
                dim2120KuoInit,
                dim2121KuoInit,
                dim2122KuoInit,
                dim2123KuoInit,
                dim2124KuoInit,
                dim2125KuoInit,
                dim2126KuoInit,
                dim2127KuoInit,
                dim2128KuoInit,
                dim2129KuoInit,
                dim2130KuoInit,
                dim2131KuoInit,
                dim2132KuoInit,
                dim2133KuoInit,
                dim2134KuoInit,
                dim2135KuoInit,
                dim2136KuoInit,
                dim2137KuoInit,
                dim2138KuoInit,
                dim2139KuoInit,
                dim2140KuoInit,
                dim2141KuoInit,
                dim2142KuoInit,
                dim2143KuoInit,
                dim2144KuoInit,
                dim2145KuoInit,
                dim2146KuoInit,
                dim2147KuoInit,
                dim2148KuoInit,
                dim2149KuoInit,
                dim2150KuoInit,
                dim2151KuoInit,
                dim2152KuoInit,
                dim2153KuoInit,
                dim2154KuoInit,
                dim2155KuoInit,
                dim2156KuoInit,
                dim2157KuoInit,
                dim2158KuoInit,
                dim2159KuoInit,
                dim2160KuoInit,
                dim2161KuoInit,
                dim2162KuoInit,
                dim2163KuoInit,
                dim2164KuoInit,
                dim2165KuoInit,
                dim2166KuoInit,
                dim2167KuoInit,
                dim2168KuoInit,
                dim2169KuoInit,
                dim2170KuoInit,
                dim2171KuoInit,
                dim2172KuoInit,
                dim2173KuoInit,
                dim2174KuoInit,
                dim2175KuoInit,
                dim2176KuoInit,
                dim2177KuoInit,
                dim2178KuoInit,
                dim2179KuoInit,
                dim2180KuoInit,
                dim2181KuoInit,
                dim2182KuoInit,
                dim2183KuoInit,
                dim2184KuoInit,
                dim2185KuoInit,
                dim2186KuoInit,
                dim2187KuoInit,
                dim2188KuoInit,
                dim2189KuoInit,
                dim2190KuoInit,
                dim2191KuoInit,
                dim2192KuoInit,
                dim2193KuoInit,
                dim2194KuoInit,
                dim2195KuoInit,
                dim2196KuoInit,
                dim2197KuoInit,
                dim2198KuoInit,
                dim2199KuoInit,
                dim2200KuoInit,
                dim2201KuoInit,
                dim2202KuoInit,
                dim2203KuoInit,
                dim2204KuoInit,
                dim2205KuoInit,
                dim2206KuoInit,
                dim2207KuoInit,
                dim2208KuoInit,
                dim2209KuoInit,
                dim2210KuoInit,
                dim2211KuoInit,
                dim2212KuoInit,
                dim2213KuoInit,
                dim2214KuoInit,
                dim2215KuoInit,
                dim2216KuoInit,
                dim2217KuoInit,
                dim2218KuoInit,
                dim2219KuoInit,
                dim2220KuoInit,
                dim2221KuoInit,
                dim2222KuoInit,
                dim2223KuoInit,
                dim2224KuoInit,
                dim2225KuoInit,
                dim2226KuoInit,
                dim2227KuoInit,
                dim2228KuoInit,
                dim2229KuoInit,
                dim2230KuoInit,
                dim2231KuoInit,
                dim2232KuoInit,
                dim2233KuoInit,
                dim2234KuoInit,
                dim2235KuoInit,
                dim2236KuoInit,
                dim2237KuoInit,
                dim2238KuoInit,
                dim2239KuoInit,
                dim2240KuoInit,
                dim2241KuoInit,
                dim2242KuoInit,
                dim2243KuoInit,
                dim2244KuoInit,
                dim2245KuoInit,
                dim2246KuoInit,
                dim2247KuoInit,
                dim2248KuoInit,
                dim2249KuoInit,
                dim2250KuoInit,
                dim2251KuoInit,
                dim2252KuoInit,
                dim2253KuoInit,
                dim2254KuoInit,
                dim2255KuoInit,
                dim2256KuoInit,
                dim2257KuoInit,
                dim2258KuoInit,
                dim2259KuoInit,
                dim2260KuoInit,
                dim2261KuoInit,
                dim2262KuoInit,
                dim2263KuoInit,
                dim2264KuoInit,
                dim2265KuoInit,
                dim2266KuoInit,
                dim2267KuoInit,
                dim2268KuoInit,
                dim2269KuoInit,
                dim2270KuoInit,
                dim2271KuoInit,
                dim2272KuoInit,
                dim2273KuoInit,
                dim2274KuoInit,
                dim2275KuoInit,
                dim2276KuoInit,
                dim2277KuoInit,
                dim2278KuoInit,
                dim2279KuoInit,
                dim2280KuoInit,
                dim2281KuoInit,
                dim2282KuoInit,
                dim2283KuoInit,
                dim2284KuoInit,
                dim2285KuoInit,
                dim2286KuoInit,
                dim2287KuoInit,
                dim2288KuoInit,
                dim2289KuoInit,
                dim2290KuoInit,
                dim2291KuoInit,
                dim2292KuoInit,
                dim2293KuoInit,
                dim2294KuoInit,
                dim2295KuoInit,
                dim2296KuoInit,
                dim2297KuoInit,
                dim2298KuoInit,
                dim2299KuoInit,
                dim2300KuoInit,
                dim2301KuoInit,
                dim2302KuoInit,
                dim2303KuoInit,
                dim2304KuoInit,
                dim2305KuoInit,
                dim2306KuoInit,
                dim2307KuoInit,
                dim2308KuoInit,
                dim2309KuoInit,
                dim2310KuoInit,
                dim2311KuoInit,
                dim2312KuoInit,
                dim2313KuoInit,
                dim2314KuoInit,
                dim2315KuoInit,
                dim2316KuoInit,
                dim2317KuoInit,
                dim2318KuoInit,
                dim2319KuoInit,
                dim2320KuoInit,
                dim2321KuoInit,
                dim2322KuoInit,
                dim2323KuoInit,
                dim2324KuoInit,
                dim2325KuoInit,
                dim2326KuoInit,
                dim2327KuoInit,
                dim2328KuoInit,
                dim2329KuoInit,
                dim2330KuoInit,
                dim2331KuoInit,
                dim2332KuoInit,
                dim2333KuoInit,
                dim2334KuoInit,
                dim2335KuoInit,
                dim2336KuoInit,
                dim2337KuoInit,
                dim2338KuoInit,
                dim2339KuoInit,
                dim2340KuoInit,
                dim2341KuoInit,
                dim2342KuoInit,
                dim2343KuoInit,
                dim2344KuoInit,
                dim2345KuoInit,
                dim2346KuoInit,
                dim2347KuoInit,
                dim2348KuoInit,
                dim2349KuoInit,
                dim2350KuoInit,
                dim2351KuoInit,
                dim2352KuoInit,
                dim2353KuoInit,
                dim2354KuoInit,
                dim2355KuoInit,
                dim2356KuoInit,
                dim2357KuoInit,
                dim2358KuoInit,
                dim2359KuoInit,
                dim2360KuoInit,
                dim2361KuoInit,
                dim2362KuoInit,
                dim2363KuoInit,
                dim2364KuoInit,
                dim2365KuoInit,
                dim2366KuoInit,
                dim2367KuoInit,
                dim2368KuoInit,
                dim2369KuoInit,
                dim2370KuoInit,
                dim2371KuoInit,
                dim2372KuoInit,
                dim2373KuoInit,
                dim2374KuoInit,
                dim2375KuoInit,
                dim2376KuoInit,
                dim2377KuoInit,
                dim2378KuoInit,
                dim2379KuoInit,
                dim2380KuoInit,
                dim2381KuoInit,
                dim2382KuoInit,
                dim2383KuoInit,
                dim2384KuoInit,
                dim2385KuoInit,
                dim2386KuoInit,
                dim2387KuoInit,
                dim2388KuoInit,
                dim2389KuoInit,
                dim2390KuoInit,
                dim2391KuoInit,
                dim2392KuoInit,
                dim2393KuoInit,
                dim2394KuoInit,
                dim2395KuoInit,
                dim2396KuoInit,
                dim2397KuoInit,
                dim2398KuoInit,
                dim2399KuoInit,
                dim2400KuoInit,
                dim2401KuoInit,
                dim2402KuoInit,
                dim2403KuoInit,
                dim2404KuoInit,
                dim2405KuoInit,
                dim2406KuoInit,
                dim2407KuoInit,
                dim2408KuoInit,
                dim2409KuoInit,
                dim2410KuoInit,
                dim2411KuoInit,
                dim2412KuoInit,
                dim2413KuoInit,
                dim2414KuoInit,
                dim2415KuoInit,
                dim2416KuoInit,
                dim2417KuoInit,
                dim2418KuoInit,
                dim2419KuoInit,
                dim2420KuoInit,
                dim2421KuoInit,
                dim2422KuoInit,
                dim2423KuoInit,
                dim2424KuoInit,
                dim2425KuoInit,
                dim2426KuoInit,
                dim2427KuoInit,
                dim2428KuoInit,
                dim2429KuoInit,
                dim2430KuoInit,
                dim2431KuoInit,
                dim2432KuoInit,
                dim2433KuoInit,
                dim2434KuoInit,
                dim2435KuoInit,
                dim2436KuoInit,
                dim2437KuoInit,
                dim2438KuoInit,
                dim2439KuoInit,
                dim2440KuoInit,
                dim2441KuoInit,
                dim2442KuoInit,
                dim2443KuoInit,
                dim2444KuoInit,
                dim2445KuoInit,
                dim2446KuoInit,
                dim2447KuoInit,
                dim2448KuoInit,
                dim2449KuoInit,
                dim2450KuoInit,
                dim2451KuoInit,
                dim2452KuoInit,
                dim2453KuoInit,
                dim2454KuoInit,
                dim2455KuoInit,
                dim2456KuoInit,
                dim2457KuoInit,
                dim2458KuoInit,
                dim2459KuoInit,
                dim2460KuoInit,
                dim2461KuoInit,
                dim2462KuoInit,
                dim2463KuoInit,
                dim2464KuoInit,
                dim2465KuoInit,
                dim2466KuoInit,
                dim2467KuoInit,
                dim2468KuoInit,
                dim2469KuoInit,
                dim2470KuoInit,
                dim2471KuoInit,
                dim2472KuoInit,
                dim2473KuoInit,
                dim2474KuoInit,
                dim2475KuoInit,
                dim2476KuoInit,
                dim2477KuoInit,
                dim2478KuoInit,
                dim2479KuoInit,
                dim2480KuoInit,
                dim2481KuoInit,
                dim2482KuoInit,
                dim2483KuoInit,
                dim2484KuoInit,
                dim2485KuoInit,
                dim2486KuoInit,
                dim2487KuoInit,
                dim2488KuoInit,
                dim2489KuoInit,
                dim2490KuoInit,
                dim2491KuoInit,
                dim2492KuoInit,
                dim2493KuoInit,
                dim2494KuoInit,
                dim2495KuoInit,
                dim2496KuoInit,
                dim2497KuoInit,
                dim2498KuoInit,
                dim2499KuoInit,
                dim2500KuoInit,
                dim2501KuoInit,
                dim2502KuoInit,
                dim2503KuoInit,
                dim2504KuoInit,
                dim2505KuoInit,
                dim2506KuoInit,
                dim2507KuoInit,
                dim2508KuoInit,
                dim2509KuoInit,
                dim2510KuoInit,
                dim2511KuoInit,
                dim2512KuoInit,
                dim2513KuoInit,
                dim2514KuoInit,
                dim2515KuoInit,
                dim2516KuoInit,
                dim2517KuoInit,
                dim2518KuoInit,
                dim2519KuoInit,
                dim2520KuoInit,
                dim2521KuoInit,
                dim2522KuoInit,
                dim2523KuoInit,
                dim2524KuoInit,
                dim2525KuoInit,
                dim2526KuoInit,
                dim2527KuoInit,
                dim2528KuoInit,
                dim2529KuoInit,
                dim2530KuoInit,
                dim2531KuoInit,
                dim2532KuoInit,
                dim2533KuoInit,
                dim2534KuoInit,
                dim2535KuoInit,
                dim2536KuoInit,
                dim2537KuoInit,
                dim2538KuoInit,
                dim2539KuoInit,
                dim2540KuoInit,
                dim2541KuoInit,
                dim2542KuoInit,
                dim2543KuoInit,
                dim2544KuoInit,
                dim2545KuoInit,
                dim2546KuoInit,
                dim2547KuoInit,
                dim2548KuoInit,
                dim2549KuoInit,
                dim2550KuoInit,
                dim2551KuoInit,
                dim2552KuoInit,
                dim2553KuoInit,
                dim2554KuoInit,
                dim2555KuoInit,
                dim2556KuoInit,
                dim2557KuoInit,
                dim2558KuoInit,
                dim2559KuoInit,
                dim2560KuoInit,
                dim2561KuoInit,
                dim2562KuoInit,
                dim2563KuoInit,
                dim2564KuoInit,
                dim2565KuoInit,
                dim2566KuoInit,
                dim2567KuoInit,
                dim2568KuoInit,
                dim2569KuoInit,
                dim2570KuoInit,
                dim2571KuoInit,
                dim2572KuoInit,
                dim2573KuoInit,
                dim2574KuoInit,
                dim2575KuoInit,
                dim2576KuoInit,
                dim2577KuoInit,
                dim2578KuoInit,
                dim2579KuoInit,
                dim2580KuoInit,
                dim2581KuoInit,
                dim2582KuoInit,
                dim2583KuoInit,
                dim2584KuoInit,
                dim2585KuoInit,
                dim2586KuoInit,
                dim2587KuoInit,
                dim2588KuoInit,
                dim2589KuoInit,
                dim2590KuoInit,
                dim2591KuoInit,
                dim2592KuoInit,
                dim2593KuoInit,
                dim2594KuoInit,
                dim2595KuoInit,
                dim2596KuoInit,
                dim2597KuoInit,
                dim2598KuoInit,
                dim2599KuoInit,
                dim2600KuoInit,
                dim2601KuoInit,
                dim2602KuoInit,
                dim2603KuoInit,
                dim2604KuoInit,
                dim2605KuoInit,
                dim2606KuoInit,
                dim2607KuoInit,
                dim2608KuoInit,
                dim2609KuoInit,
                dim2610KuoInit,
                dim2611KuoInit,
                dim2612KuoInit,
                dim2613KuoInit,
                dim2614KuoInit,
                dim2615KuoInit,
                dim2616KuoInit,
                dim2617KuoInit,
                dim2618KuoInit,
                dim2619KuoInit,
                dim2620KuoInit,
                dim2621KuoInit,
                dim2622KuoInit,
                dim2623KuoInit,
                dim2624KuoInit,
                dim2625KuoInit,
                dim2626KuoInit,
                dim2627KuoInit,
                dim2628KuoInit,
                dim2629KuoInit,
                dim2630KuoInit,
                dim2631KuoInit,
                dim2632KuoInit,
                dim2633KuoInit,
                dim2634KuoInit,
                dim2635KuoInit,
                dim2636KuoInit,
                dim2637KuoInit,
                dim2638KuoInit,
                dim2639KuoInit,
                dim2640KuoInit,
                dim2641KuoInit,
                dim2642KuoInit,
                dim2643KuoInit,
                dim2644KuoInit,
                dim2645KuoInit,
                dim2646KuoInit,
                dim2647KuoInit,
                dim2648KuoInit,
                dim2649KuoInit,
                dim2650KuoInit,
                dim2651KuoInit,
                dim2652KuoInit,
                dim2653KuoInit,
                dim2654KuoInit,
                dim2655KuoInit,
                dim2656KuoInit,
                dim2657KuoInit,
                dim2658KuoInit,
                dim2659KuoInit,
                dim2660KuoInit,
                dim2661KuoInit,
                dim2662KuoInit,
                dim2663KuoInit,
                dim2664KuoInit,
                dim2665KuoInit,
                dim2666KuoInit,
                dim2667KuoInit,
                dim2668KuoInit,
                dim2669KuoInit,
                dim2670KuoInit,
                dim2671KuoInit,
                dim2672KuoInit,
                dim2673KuoInit,
                dim2674KuoInit,
                dim2675KuoInit,
                dim2676KuoInit,
                dim2677KuoInit,
                dim2678KuoInit,
                dim2679KuoInit,
                dim2680KuoInit,
                dim2681KuoInit,
                dim2682KuoInit,
                dim2683KuoInit,
                dim2684KuoInit,
                dim2685KuoInit,
                dim2686KuoInit,
                dim2687KuoInit,
                dim2688KuoInit,
                dim2689KuoInit,
                dim2690KuoInit,
                dim2691KuoInit,
                dim2692KuoInit,
                dim2693KuoInit,
                dim2694KuoInit,
                dim2695KuoInit,
                dim2696KuoInit,
                dim2697KuoInit,
                dim2698KuoInit,
                dim2699KuoInit,
                dim2700KuoInit,
                dim2701KuoInit,
                dim2702KuoInit,
                dim2703KuoInit,
                dim2704KuoInit,
                dim2705KuoInit,
                dim2706KuoInit,
                dim2707KuoInit,
                dim2708KuoInit,
                dim2709KuoInit,
                dim2710KuoInit,
                dim2711KuoInit,
                dim2712KuoInit,
                dim2713KuoInit,
                dim2714KuoInit,
                dim2715KuoInit,
                dim2716KuoInit,
                dim2717KuoInit,
                dim2718KuoInit,
                dim2719KuoInit,
                dim2720KuoInit,
                dim2721KuoInit,
                dim2722KuoInit,
                dim2723KuoInit,
                dim2724KuoInit,
                dim2725KuoInit,
                dim2726KuoInit,
                dim2727KuoInit,
                dim2728KuoInit,
                dim2729KuoInit,
                dim2730KuoInit,
                dim2731KuoInit,
                dim2732KuoInit,
                dim2733KuoInit,
                dim2734KuoInit,
                dim2735KuoInit,
                dim2736KuoInit,
                dim2737KuoInit,
                dim2738KuoInit,
                dim2739KuoInit,
                dim2740KuoInit,
                dim2741KuoInit,
                dim2742KuoInit,
                dim2743KuoInit,
                dim2744KuoInit,
                dim2745KuoInit,
                dim2746KuoInit,
                dim2747KuoInit,
                dim2748KuoInit,
                dim2749KuoInit,
                dim2750KuoInit,
                dim2751KuoInit,
                dim2752KuoInit,
                dim2753KuoInit,
                dim2754KuoInit,
                dim2755KuoInit,
                dim2756KuoInit,
                dim2757KuoInit,
                dim2758KuoInit,
                dim2759KuoInit,
                dim2760KuoInit,
                dim2761KuoInit,
                dim2762KuoInit,
                dim2763KuoInit,
                dim2764KuoInit,
                dim2765KuoInit,
                dim2766KuoInit,
                dim2767KuoInit,
                dim2768KuoInit,
                dim2769KuoInit,
                dim2770KuoInit,
                dim2771KuoInit,
                dim2772KuoInit,
                dim2773KuoInit,
                dim2774KuoInit,
                dim2775KuoInit,
                dim2776KuoInit,
                dim2777KuoInit,
                dim2778KuoInit,
                dim2779KuoInit,
                dim2780KuoInit,
                dim2781KuoInit,
                dim2782KuoInit,
                dim2783KuoInit,
                dim2784KuoInit,
                dim2785KuoInit,
                dim2786KuoInit,
                dim2787KuoInit,
                dim2788KuoInit,
                dim2789KuoInit,
                dim2790KuoInit,
                dim2791KuoInit,
                dim2792KuoInit,
                dim2793KuoInit,
                dim2794KuoInit,
                dim2795KuoInit,
                dim2796KuoInit,
                dim2797KuoInit,
                dim2798KuoInit,
                dim2799KuoInit,
                dim2800KuoInit,
                dim2801KuoInit,
                dim2802KuoInit,
                dim2803KuoInit,
                dim2804KuoInit,
                dim2805KuoInit,
                dim2806KuoInit,
                dim2807KuoInit,
                dim2808KuoInit,
                dim2809KuoInit,
                dim2810KuoInit,
                dim2811KuoInit,
                dim2812KuoInit,
                dim2813KuoInit,
                dim2814KuoInit,
                dim2815KuoInit,
                dim2816KuoInit,
                dim2817KuoInit,
                dim2818KuoInit,
                dim2819KuoInit,
                dim2820KuoInit,
                dim2821KuoInit,
                dim2822KuoInit,
                dim2823KuoInit,
                dim2824KuoInit,
                dim2825KuoInit,
                dim2826KuoInit,
                dim2827KuoInit,
                dim2828KuoInit,
                dim2829KuoInit,
                dim2830KuoInit,
                dim2831KuoInit,
                dim2832KuoInit,
                dim2833KuoInit,
                dim2834KuoInit,
                dim2835KuoInit,
                dim2836KuoInit,
                dim2837KuoInit,
                dim2838KuoInit,
                dim2839KuoInit,
                dim2840KuoInit,
                dim2841KuoInit,
                dim2842KuoInit,
                dim2843KuoInit,
                dim2844KuoInit,
                dim2845KuoInit,
                dim2846KuoInit,
                dim2847KuoInit,
                dim2848KuoInit,
                dim2849KuoInit,
                dim2850KuoInit,
                dim2851KuoInit,
                dim2852KuoInit,
                dim2853KuoInit,
                dim2854KuoInit,
                dim2855KuoInit,
                dim2856KuoInit,
                dim2857KuoInit,
                dim2858KuoInit,
                dim2859KuoInit,
                dim2860KuoInit,
                dim2861KuoInit,
                dim2862KuoInit,
                dim2863KuoInit,
                dim2864KuoInit,
                dim2865KuoInit,
                dim2866KuoInit,
                dim2867KuoInit,
                dim2868KuoInit,
                dim2869KuoInit,
                dim2870KuoInit,
                dim2871KuoInit,
                dim2872KuoInit,
                dim2873KuoInit,
                dim2874KuoInit,
                dim2875KuoInit,
                dim2876KuoInit,
                dim2877KuoInit,
                dim2878KuoInit,
                dim2879KuoInit,
                dim2880KuoInit,
                dim2881KuoInit,
                dim2882KuoInit,
                dim2883KuoInit,
                dim2884KuoInit,
                dim2885KuoInit,
                dim2886KuoInit,
                dim2887KuoInit,
                dim2888KuoInit,
                dim2889KuoInit,
                dim2890KuoInit,
                dim2891KuoInit,
                dim2892KuoInit,
                dim2893KuoInit,
                dim2894KuoInit,
                dim2895KuoInit,
                dim2896KuoInit,
                dim2897KuoInit,
                dim2898KuoInit,
                dim2899KuoInit,
                dim2900KuoInit,
                dim2901KuoInit,
                dim2902KuoInit,
                dim2903KuoInit,
                dim2904KuoInit,
                dim2905KuoInit,
                dim2906KuoInit,
                dim2907KuoInit,
                dim2908KuoInit,
                dim2909KuoInit,
                dim2910KuoInit,
                dim2911KuoInit,
                dim2912KuoInit,
                dim2913KuoInit,
                dim2914KuoInit,
                dim2915KuoInit,
                dim2916KuoInit,
                dim2917KuoInit,
                dim2918KuoInit,
                dim2919KuoInit,
                dim2920KuoInit,
                dim2921KuoInit,
                dim2922KuoInit,
                dim2923KuoInit,
                dim2924KuoInit,
                dim2925KuoInit,
                dim2926KuoInit,
                dim2927KuoInit,
                dim2928KuoInit,
                dim2929KuoInit,
                dim2930KuoInit,
                dim2931KuoInit,
                dim2932KuoInit,
                dim2933KuoInit,
                dim2934KuoInit,
                dim2935KuoInit,
                dim2936KuoInit,
                dim2937KuoInit,
                dim2938KuoInit,
                dim2939KuoInit,
                dim2940KuoInit,
                dim2941KuoInit,
                dim2942KuoInit,
                dim2943KuoInit,
                dim2944KuoInit,
                dim2945KuoInit,
                dim2946KuoInit,
                dim2947KuoInit,
                dim2948KuoInit,
                dim2949KuoInit,
                dim2950KuoInit,
                dim2951KuoInit,
                dim2952KuoInit,
                dim2953KuoInit,
                dim2954KuoInit,
                dim2955KuoInit,
                dim2956KuoInit,
                dim2957KuoInit,
                dim2958KuoInit,
                dim2959KuoInit,
                dim2960KuoInit,
                dim2961KuoInit,
                dim2962KuoInit,
                dim2963KuoInit,
                dim2964KuoInit,
                dim2965KuoInit,
                dim2966KuoInit,
                dim2967KuoInit,
                dim2968KuoInit,
                dim2969KuoInit,
                dim2970KuoInit,
                dim2971KuoInit,
                dim2972KuoInit,
                dim2973KuoInit,
                dim2974KuoInit,
                dim2975KuoInit,
                dim2976KuoInit,
                dim2977KuoInit,
                dim2978KuoInit,
                dim2979KuoInit,
                dim2980KuoInit,
                dim2981KuoInit,
                dim2982KuoInit,
                dim2983KuoInit,
                dim2984KuoInit,
                dim2985KuoInit,
                dim2986KuoInit,
                dim2987KuoInit,
                dim2988KuoInit,
                dim2989KuoInit,
                dim2990KuoInit,
                dim2991KuoInit,
                dim2992KuoInit,
                dim2993KuoInit,
                dim2994KuoInit,
                dim2995KuoInit,
                dim2996KuoInit,
                dim2997KuoInit,
                dim2998KuoInit,
                dim2999KuoInit,
                dim3000KuoInit,
                dim3001KuoInit,
                dim3002KuoInit,
                dim3003KuoInit,
                dim3004KuoInit,
                dim3005KuoInit,
                dim3006KuoInit,
                dim3007KuoInit,
                dim3008KuoInit,
                dim3009KuoInit,
                dim3010KuoInit,
                dim3011KuoInit,
                dim3012KuoInit,
                dim3013KuoInit,
                dim3014KuoInit,
                dim3015KuoInit,
                dim3016KuoInit,
                dim3017KuoInit,
                dim3018KuoInit,
                dim3019KuoInit,
                dim3020KuoInit,
                dim3021KuoInit,
                dim3022KuoInit,
                dim3023KuoInit,
                dim3024KuoInit,
                dim3025KuoInit,
                dim3026KuoInit,
                dim3027KuoInit,
                dim3028KuoInit,
                dim3029KuoInit,
                dim3030KuoInit,
                dim3031KuoInit,
                dim3032KuoInit,
                dim3033KuoInit,
                dim3034KuoInit,
                dim3035KuoInit,
                dim3036KuoInit,
                dim3037KuoInit,
                dim3038KuoInit,
                dim3039KuoInit,
                dim3040KuoInit,
                dim3041KuoInit,
                dim3042KuoInit,
                dim3043KuoInit,
                dim3044KuoInit,
                dim3045KuoInit,
                dim3046KuoInit,
                dim3047KuoInit,
                dim3048KuoInit,
                dim3049KuoInit,
                dim3050KuoInit,
                dim3051KuoInit,
                dim3052KuoInit,
                dim3053KuoInit,
                dim3054KuoInit,
                dim3055KuoInit,
                dim3056KuoInit,
                dim3057KuoInit,
                dim3058KuoInit,
                dim3059KuoInit,
                dim3060KuoInit,
                dim3061KuoInit,
                dim3062KuoInit,
                dim3063KuoInit,
                dim3064KuoInit,
                dim3065KuoInit,
                dim3066KuoInit,
                dim3067KuoInit,
                dim3068KuoInit,
                dim3069KuoInit,
                dim3070KuoInit,
                dim3071KuoInit,
                dim3072KuoInit,
                dim3073KuoInit,
                dim3074KuoInit,
                dim3075KuoInit,
                dim3076KuoInit,
                dim3077KuoInit,
                dim3078KuoInit,
                dim3079KuoInit,
                dim3080KuoInit,
                dim3081KuoInit,
                dim3082KuoInit,
                dim3083KuoInit,
                dim3084KuoInit,
                dim3085KuoInit,
                dim3086KuoInit,
                dim3087KuoInit,
                dim3088KuoInit,
                dim3089KuoInit,
                dim3090KuoInit,
                dim3091KuoInit,
                dim3092KuoInit,
                dim3093KuoInit,
                dim3094KuoInit,
                dim3095KuoInit,
                dim3096KuoInit,
                dim3097KuoInit,
                dim3098KuoInit,
                dim3099KuoInit,
                dim3100KuoInit,
                dim3101KuoInit,
                dim3102KuoInit,
                dim3103KuoInit,
                dim3104KuoInit,
                dim3105KuoInit,
                dim3106KuoInit,
                dim3107KuoInit,
                dim3108KuoInit,
                dim3109KuoInit,
                dim3110KuoInit,
                dim3111KuoInit,
                dim3112KuoInit,
                dim3113KuoInit,
                dim3114KuoInit,
                dim3115KuoInit,
                dim3116KuoInit,
                dim3117KuoInit,
                dim3118KuoInit,
                dim3119KuoInit,
                dim3120KuoInit,
                dim3121KuoInit,
                dim3122KuoInit,
                dim3123KuoInit,
                dim3124KuoInit,
                dim3125KuoInit,
                dim3126KuoInit,
                dim3127KuoInit,
                dim3128KuoInit,
                dim3129KuoInit,
                dim3130KuoInit,
                dim3131KuoInit,
                dim3132KuoInit,
                dim3133KuoInit,
                dim3134KuoInit,
                dim3135KuoInit,
                dim3136KuoInit,
                dim3137KuoInit,
                dim3138KuoInit,
                dim3139KuoInit,
                dim3140KuoInit,
                dim3141KuoInit,
                dim3142KuoInit,
                dim3143KuoInit,
                dim3144KuoInit,
                dim3145KuoInit,
                dim3146KuoInit,
                dim3147KuoInit,
                dim3148KuoInit,
                dim3149KuoInit,
                dim3150KuoInit,
                dim3151KuoInit,
                dim3152KuoInit,
                dim3153KuoInit,
                dim3154KuoInit,
                dim3155KuoInit,
                dim3156KuoInit,
                dim3157KuoInit,
                dim3158KuoInit,
                dim3159KuoInit,
                dim3160KuoInit,
                dim3161KuoInit,
                dim3162KuoInit,
                dim3163KuoInit,
                dim3164KuoInit,
                dim3165KuoInit,
                dim3166KuoInit,
                dim3167KuoInit,
                dim3168KuoInit,
                dim3169KuoInit,
                dim3170KuoInit,
                dim3171KuoInit,
                dim3172KuoInit,
                dim3173KuoInit,
                dim3174KuoInit,
                dim3175KuoInit,
                dim3176KuoInit,
                dim3177KuoInit,
                dim3178KuoInit,
                dim3179KuoInit,
                dim3180KuoInit,
                dim3181KuoInit,
                dim3182KuoInit,
                dim3183KuoInit,
                dim3184KuoInit,
                dim3185KuoInit,
                dim3186KuoInit,
                dim3187KuoInit,
                dim3188KuoInit,
                dim3189KuoInit,
                dim3190KuoInit,
                dim3191KuoInit,
                dim3192KuoInit,
                dim3193KuoInit,
                dim3194KuoInit,
                dim3195KuoInit,
                dim3196KuoInit,
                dim3197KuoInit,
                dim3198KuoInit,
                dim3199KuoInit,
                dim3200KuoInit,
                dim3201KuoInit,
                dim3202KuoInit,
                dim3203KuoInit,
                dim3204KuoInit,
                dim3205KuoInit,
                dim3206KuoInit,
                dim3207KuoInit,
                dim3208KuoInit,
                dim3209KuoInit,
                dim3210KuoInit,
                dim3211KuoInit,
                dim3212KuoInit,
                dim3213KuoInit,
                dim3214KuoInit,
                dim3215KuoInit,
                dim3216KuoInit,
                dim3217KuoInit,
                dim3218KuoInit,
                dim3219KuoInit,
                dim3220KuoInit,
                dim3221KuoInit,
                dim3222KuoInit,
                dim3223KuoInit,
                dim3224KuoInit,
                dim3225KuoInit,
                dim3226KuoInit,
                dim3227KuoInit,
                dim3228KuoInit,
                dim3229KuoInit,
                dim3230KuoInit,
                dim3231KuoInit,
                dim3232KuoInit,
                dim3233KuoInit,
                dim3234KuoInit,
                dim3235KuoInit,
                dim3236KuoInit,
                dim3237KuoInit,
                dim3238KuoInit,
                dim3239KuoInit,
                dim3240KuoInit,
                dim3241KuoInit,
                dim3242KuoInit,
                dim3243KuoInit,
                dim3244KuoInit,
                dim3245KuoInit,
                dim3246KuoInit,
                dim3247KuoInit,
                dim3248KuoInit,
                dim3249KuoInit,
                dim3250KuoInit,
                dim3251KuoInit,
                dim3252KuoInit,
                dim3253KuoInit,
                dim3254KuoInit,
                dim3255KuoInit,
                dim3256KuoInit,
                dim3257KuoInit,
                dim3258KuoInit,
                dim3259KuoInit,
                dim3260KuoInit,
                dim3261KuoInit,
                dim3262KuoInit,
                dim3263KuoInit,
                dim3264KuoInit,
                dim3265KuoInit,
                dim3266KuoInit,
                dim3267KuoInit,
                dim3268KuoInit,
                dim3269KuoInit,
                dim3270KuoInit,
                dim3271KuoInit,
                dim3272KuoInit,
                dim3273KuoInit,
                dim3274KuoInit,
                dim3275KuoInit,
                dim3276KuoInit,
                dim3277KuoInit,
                dim3278KuoInit,
                dim3279KuoInit,
                dim3280KuoInit,
                dim3281KuoInit,
                dim3282KuoInit,
                dim3283KuoInit,
                dim3284KuoInit,
                dim3285KuoInit,
                dim3286KuoInit,
                dim3287KuoInit,
                dim3288KuoInit,
                dim3289KuoInit,
                dim3290KuoInit,
                dim3291KuoInit,
                dim3292KuoInit,
                dim3293KuoInit,
                dim3294KuoInit,
                dim3295KuoInit,
                dim3296KuoInit,
                dim3297KuoInit,
                dim3298KuoInit,
                dim3299KuoInit,
                dim3300KuoInit,
                dim3301KuoInit,
                dim3302KuoInit,
                dim3303KuoInit,
                dim3304KuoInit,
                dim3305KuoInit,
                dim3306KuoInit,
                dim3307KuoInit,
                dim3308KuoInit,
                dim3309KuoInit,
                dim3310KuoInit,
                dim3311KuoInit,
                dim3312KuoInit,
                dim3313KuoInit,
                dim3314KuoInit,
                dim3315KuoInit,
                dim3316KuoInit,
                dim3317KuoInit,
                dim3318KuoInit,
                dim3319KuoInit,
                dim3320KuoInit,
                dim3321KuoInit,
                dim3322KuoInit,
                dim3323KuoInit,
                dim3324KuoInit,
                dim3325KuoInit,
                dim3326KuoInit,
                dim3327KuoInit,
                dim3328KuoInit,
                dim3329KuoInit,
                dim3330KuoInit,
                dim3331KuoInit,
                dim3332KuoInit,
                dim3333KuoInit,
                dim3334KuoInit,
                dim3335KuoInit,
                dim3336KuoInit,
                dim3337KuoInit,
                dim3338KuoInit,
                dim3339KuoInit,
                dim3340KuoInit,
                dim3341KuoInit,
                dim3342KuoInit,
                dim3343KuoInit,
                dim3344KuoInit,
                dim3345KuoInit,
                dim3346KuoInit,
                dim3347KuoInit,
                dim3348KuoInit,
                dim3349KuoInit,
                dim3350KuoInit,
                dim3351KuoInit,
                dim3352KuoInit,
                dim3353KuoInit,
                dim3354KuoInit,
                dim3355KuoInit,
                dim3356KuoInit,
                dim3357KuoInit,
                dim3358KuoInit,
                dim3359KuoInit,
                dim3360KuoInit,
                dim3361KuoInit,
                dim3362KuoInit,
                dim3363KuoInit,
                dim3364KuoInit,
                dim3365KuoInit,
                dim3366KuoInit,
                dim3367KuoInit,
                dim3368KuoInit,
                dim3369KuoInit,
                dim3370KuoInit,
                dim3371KuoInit,
                dim3372KuoInit,
                dim3373KuoInit,
                dim3374KuoInit,
                dim3375KuoInit,
                dim3376KuoInit,
                dim3377KuoInit,
                dim3378KuoInit,
                dim3379KuoInit,
                dim3380KuoInit,
                dim3381KuoInit,
                dim3382KuoInit,
                dim3383KuoInit,
                dim3384KuoInit,
                dim3385KuoInit,
                dim3386KuoInit,
                dim3387KuoInit,
                dim3388KuoInit,
                dim3389KuoInit,
                dim3390KuoInit,
                dim3391KuoInit,
                dim3392KuoInit,
                dim3393KuoInit,
                dim3394KuoInit,
                dim3395KuoInit,
                dim3396KuoInit,
                dim3397KuoInit,
                dim3398KuoInit,
                dim3399KuoInit,
                dim3400KuoInit,
                dim3401KuoInit,
                dim3402KuoInit,
                dim3403KuoInit,
                dim3404KuoInit,
                dim3405KuoInit,
                dim3406KuoInit,
                dim3407KuoInit,
                dim3408KuoInit,
                dim3409KuoInit,
                dim3410KuoInit,
                dim3411KuoInit,
                dim3412KuoInit,
                dim3413KuoInit,
                dim3414KuoInit,
                dim3415KuoInit,
                dim3416KuoInit,
                dim3417KuoInit,
                dim3418KuoInit,
                dim3419KuoInit,
                dim3420KuoInit,
                dim3421KuoInit,
                dim3422KuoInit,
                dim3423KuoInit,
                dim3424KuoInit,
                dim3425KuoInit,
                dim3426KuoInit,
                dim3427KuoInit,
                dim3428KuoInit,
                dim3429KuoInit,
                dim3430KuoInit,
                dim3431KuoInit,
                dim3432KuoInit,
                dim3433KuoInit,
                dim3434KuoInit,
                dim3435KuoInit,
                dim3436KuoInit,
                dim3437KuoInit,
                dim3438KuoInit,
                dim3439KuoInit,
                dim3440KuoInit,
                dim3441KuoInit,
                dim3442KuoInit,
                dim3443KuoInit,
                dim3444KuoInit,
                dim3445KuoInit,
                dim3446KuoInit,
                dim3447KuoInit,
                dim3448KuoInit,
                dim3449KuoInit,
                dim3450KuoInit,
                dim3451KuoInit,
                dim3452KuoInit,
                dim3453KuoInit,
                dim3454KuoInit,
                dim3455KuoInit,
                dim3456KuoInit,
                dim3457KuoInit,
                dim3458KuoInit,
                dim3459KuoInit,
                dim3460KuoInit,
                dim3461KuoInit,
                dim3462KuoInit,
                dim3463KuoInit,
                dim3464KuoInit,
                dim3465KuoInit,
                dim3466KuoInit,
                dim3467KuoInit,
                dim3468KuoInit,
                dim3469KuoInit,
                dim3470KuoInit,
                dim3471KuoInit,
                dim3472KuoInit,
                dim3473KuoInit,
                dim3474KuoInit,
                dim3475KuoInit,
                dim3476KuoInit,
                dim3477KuoInit,
                dim3478KuoInit,
                dim3479KuoInit,
                dim3480KuoInit,
                dim3481KuoInit,
                dim3482KuoInit,
                dim3483KuoInit,
                dim3484KuoInit,
                dim3485KuoInit,
                dim3486KuoInit,
                dim3487KuoInit,
                dim3488KuoInit,
                dim3489KuoInit,
                dim3490KuoInit,
                dim3491KuoInit,
                dim3492KuoInit,
                dim3493KuoInit,
                dim3494KuoInit,
                dim3495KuoInit,
                dim3496KuoInit,
                dim3497KuoInit,
                dim3498KuoInit,
                dim3499KuoInit,
                dim3500KuoInit,
                dim3501KuoInit,
                dim3502KuoInit,
                dim3503KuoInit,
                dim3504KuoInit,
                dim3505KuoInit,
                dim3506KuoInit,
                dim3507KuoInit,
                dim3508KuoInit,
                dim3509KuoInit,
                dim3510KuoInit,
                dim3511KuoInit,
                dim3512KuoInit,
                dim3513KuoInit,
                dim3514KuoInit,
                dim3515KuoInit,
                dim3516KuoInit,
                dim3517KuoInit,
                dim3518KuoInit,
                dim3519KuoInit,
                dim3520KuoInit,
                dim3521KuoInit,
                dim3522KuoInit,
                dim3523KuoInit,
                dim3524KuoInit,
                dim3525KuoInit,
                dim3526KuoInit,
                dim3527KuoInit,
                dim3528KuoInit,
                dim3529KuoInit,
                dim3530KuoInit,
                dim3531KuoInit,
                dim3532KuoInit,
                dim3533KuoInit,
                dim3534KuoInit,
                dim3535KuoInit,
                dim3536KuoInit,
                dim3537KuoInit,
                dim3538KuoInit,
                dim3539KuoInit,
                dim3540KuoInit,
                dim3541KuoInit,
                dim3542KuoInit,
                dim3543KuoInit,
                dim3544KuoInit,
                dim3545KuoInit,
                dim3546KuoInit,
                dim3547KuoInit,
                dim3548KuoInit,
                dim3549KuoInit,
                dim3550KuoInit,
                dim3551KuoInit,
                dim3552KuoInit,
                dim3553KuoInit,
                dim3554KuoInit,
                dim3555KuoInit,
                dim3556KuoInit,
                dim3557KuoInit,
                dim3558KuoInit,
                dim3559KuoInit,
                dim3560KuoInit,
                dim3561KuoInit,
                dim3562KuoInit,
                dim3563KuoInit,
                dim3564KuoInit,
                dim3565KuoInit,
                dim3566KuoInit,
                dim3567KuoInit,
                dim3568KuoInit,
                dim3569KuoInit,
                dim3570KuoInit,
                dim3571KuoInit,
                dim3572KuoInit,
                dim3573KuoInit,
                dim3574KuoInit,
                dim3575KuoInit,
                dim3576KuoInit,
                dim3577KuoInit,
                dim3578KuoInit,
                dim3579KuoInit,
                dim3580KuoInit,
                dim3581KuoInit,
                dim3582KuoInit,
                dim3583KuoInit,
                dim3584KuoInit,
                dim3585KuoInit,
                dim3586KuoInit,
                dim3587KuoInit,
                dim3588KuoInit,
                dim3589KuoInit,
                dim3590KuoInit,
                dim3591KuoInit,
                dim3592KuoInit,
                dim3593KuoInit,
                dim3594KuoInit,
                dim3595KuoInit,
                dim3596KuoInit,
                dim3597KuoInit,
                dim3598KuoInit,
                dim3599KuoInit,
                dim3600KuoInit,
                dim3601KuoInit,
                dim3602KuoInit,
                dim3603KuoInit,
                dim3604KuoInit,
                dim3605KuoInit,
                dim3606KuoInit,
                dim3607KuoInit,
                dim3608KuoInit,
                dim3609KuoInit,
                dim3610KuoInit,
                dim3611KuoInit,
                dim3612KuoInit,
                dim3613KuoInit,
                dim3614KuoInit,
                dim3615KuoInit,
                dim3616KuoInit,
                dim3617KuoInit,
                dim3618KuoInit,
                dim3619KuoInit,
                dim3620KuoInit,
                dim3621KuoInit,
                dim3622KuoInit,
                dim3623KuoInit,
                dim3624KuoInit,
                dim3625KuoInit,
                dim3626KuoInit,
                dim3627KuoInit,
                dim3628KuoInit,
                dim3629KuoInit,
                dim3630KuoInit,
                dim3631KuoInit,
                dim3632KuoInit,
                dim3633KuoInit,
                dim3634KuoInit,
                dim3635KuoInit,
                dim3636KuoInit,
                dim3637KuoInit,
                dim3638KuoInit,
                dim3639KuoInit,
                dim3640KuoInit,
                dim3641KuoInit,
                dim3642KuoInit,
                dim3643KuoInit,
                dim3644KuoInit,
                dim3645KuoInit,
                dim3646KuoInit,
                dim3647KuoInit,
                dim3648KuoInit,
                dim3649KuoInit,
                dim3650KuoInit,
                dim3651KuoInit,
                dim3652KuoInit,
                dim3653KuoInit,
                dim3654KuoInit,
                dim3655KuoInit,
                dim3656KuoInit,
                dim3657KuoInit,
                dim3658KuoInit,
                dim3659KuoInit,
                dim3660KuoInit,
                dim3661KuoInit,
                dim3662KuoInit,
                dim3663KuoInit,
                dim3664KuoInit,
                dim3665KuoInit,
                dim3666KuoInit,
                dim3667KuoInit,
                dim3668KuoInit,
                dim3669KuoInit,
                dim3670KuoInit,
                dim3671KuoInit,
                dim3672KuoInit,
                dim3673KuoInit,
                dim3674KuoInit,
                dim3675KuoInit,
                dim3676KuoInit,
                dim3677KuoInit,
                dim3678KuoInit,
                dim3679KuoInit,
                dim3680KuoInit,
                dim3681KuoInit,
                dim3682KuoInit,
                dim3683KuoInit,
                dim3684KuoInit,
                dim3685KuoInit,
                dim3686KuoInit,
                dim3687KuoInit,
                dim3688KuoInit,
                dim3689KuoInit,
                dim3690KuoInit,
                dim3691KuoInit,
                dim3692KuoInit,
                dim3693KuoInit,
                dim3694KuoInit,
                dim3695KuoInit,
                dim3696KuoInit,
                dim3697KuoInit,
                dim3698KuoInit,
                dim3699KuoInit,
                dim3700KuoInit,
                dim3701KuoInit,
                dim3702KuoInit,
                dim3703KuoInit,
                dim3704KuoInit,
                dim3705KuoInit,
                dim3706KuoInit,
                dim3707KuoInit,
                dim3708KuoInit,
                dim3709KuoInit,
                dim3710KuoInit,
                dim3711KuoInit,
                dim3712KuoInit,
                dim3713KuoInit,
                dim3714KuoInit,
                dim3715KuoInit,
                dim3716KuoInit,
                dim3717KuoInit,
                dim3718KuoInit,
                dim3719KuoInit,
                dim3720KuoInit,
                dim3721KuoInit,
                dim3722KuoInit,
                dim3723KuoInit,
                dim3724KuoInit,
                dim3725KuoInit,
                dim3726KuoInit,
                dim3727KuoInit,
                dim3728KuoInit,
                dim3729KuoInit,
                dim3730KuoInit,
                dim3731KuoInit,
                dim3732KuoInit,
                dim3733KuoInit,
                dim3734KuoInit,
                dim3735KuoInit,
                dim3736KuoInit,
                dim3737KuoInit,
                dim3738KuoInit,
                dim3739KuoInit,
                dim3740KuoInit,
                dim3741KuoInit,
                dim3742KuoInit,
                dim3743KuoInit,
                dim3744KuoInit,
                dim3745KuoInit,
                dim3746KuoInit,
                dim3747KuoInit,
                dim3748KuoInit,
                dim3749KuoInit,
                dim3750KuoInit,
                dim3751KuoInit,
                dim3752KuoInit,
                dim3753KuoInit,
                dim3754KuoInit,
                dim3755KuoInit,
                dim3756KuoInit,
                dim3757KuoInit,
                dim3758KuoInit,
                dim3759KuoInit,
                dim3760KuoInit,
                dim3761KuoInit,
                dim3762KuoInit,
                dim3763KuoInit,
                dim3764KuoInit,
                dim3765KuoInit,
                dim3766KuoInit,
                dim3767KuoInit,
                dim3768KuoInit,
                dim3769KuoInit,
                dim3770KuoInit,
                dim3771KuoInit,
                dim3772KuoInit,
                dim3773KuoInit,
                dim3774KuoInit,
                dim3775KuoInit,
                dim3776KuoInit,
                dim3777KuoInit,
                dim3778KuoInit,
                dim3779KuoInit,
                dim3780KuoInit,
                dim3781KuoInit,
                dim3782KuoInit,
                dim3783KuoInit,
                dim3784KuoInit,
                dim3785KuoInit,
                dim3786KuoInit,
                dim3787KuoInit,
                dim3788KuoInit,
                dim3789KuoInit,
                dim3790KuoInit,
                dim3791KuoInit,
                dim3792KuoInit,
                dim3793KuoInit,
                dim3794KuoInit,
                dim3795KuoInit,
                dim3796KuoInit,
                dim3797KuoInit,
                dim3798KuoInit,
                dim3799KuoInit,
                dim3800KuoInit,
                dim3801KuoInit,
                dim3802KuoInit,
                dim3803KuoInit,
                dim3804KuoInit,
                dim3805KuoInit,
                dim3806KuoInit,
                dim3807KuoInit,
                dim3808KuoInit,
                dim3809KuoInit,
                dim3810KuoInit,
                dim3811KuoInit,
                dim3812KuoInit,
                dim3813KuoInit,
                dim3814KuoInit,
                dim3815KuoInit,
                dim3816KuoInit,
                dim3817KuoInit,
                dim3818KuoInit,
                dim3819KuoInit,
                dim3820KuoInit,
                dim3821KuoInit,
                dim3822KuoInit,
                dim3823KuoInit,
                dim3824KuoInit,
                dim3825KuoInit,
                dim3826KuoInit,
                dim3827KuoInit,
                dim3828KuoInit,
                dim3829KuoInit,
                dim3830KuoInit,
                dim3831KuoInit,
                dim3832KuoInit,
                dim3833KuoInit,
                dim3834KuoInit,
                dim3835KuoInit,
                dim3836KuoInit,
                dim3837KuoInit,
                dim3838KuoInit,
                dim3839KuoInit,
                dim3840KuoInit,
                dim3841KuoInit,
                dim3842KuoInit,
                dim3843KuoInit,
                dim3844KuoInit,
                dim3845KuoInit,
                dim3846KuoInit,
                dim3847KuoInit,
                dim3848KuoInit,
                dim3849KuoInit,
                dim3850KuoInit,
                dim3851KuoInit,
                dim3852KuoInit,
                dim3853KuoInit,
                dim3854KuoInit,
                dim3855KuoInit,
                dim3856KuoInit,
                dim3857KuoInit,
                dim3858KuoInit,
                dim3859KuoInit,
                dim3860KuoInit,
                dim3861KuoInit,
                dim3862KuoInit,
                dim3863KuoInit,
                dim3864KuoInit,
                dim3865KuoInit,
                dim3866KuoInit,
                dim3867KuoInit,
                dim3868KuoInit,
                dim3869KuoInit,
                dim3870KuoInit,
                dim3871KuoInit,
                dim3872KuoInit,
                dim3873KuoInit,
                dim3874KuoInit,
                dim3875KuoInit,
                dim3876KuoInit,
                dim3877KuoInit,
                dim3878KuoInit,
                dim3879KuoInit,
                dim3880KuoInit,
                dim3881KuoInit,
                dim3882KuoInit,
                dim3883KuoInit,
                dim3884KuoInit,
                dim3885KuoInit,
                dim3886KuoInit,
                dim3887KuoInit,
                dim3888KuoInit,
                dim3889KuoInit,
                dim3890KuoInit,
                dim3891KuoInit,
                dim3892KuoInit,
                dim3893KuoInit,
                dim3894KuoInit,
                dim3895KuoInit,
                dim3896KuoInit,
                dim3897KuoInit,
                dim3898KuoInit,
                dim3899KuoInit,
                dim3900KuoInit,
                dim3901KuoInit,
                dim3902KuoInit,
                dim3903KuoInit,
                dim3904KuoInit,
                dim3905KuoInit,
                dim3906KuoInit,
                dim3907KuoInit,
                dim3908KuoInit,
                dim3909KuoInit,
                dim3910KuoInit,
                dim3911KuoInit,
                dim3912KuoInit,
                dim3913KuoInit,
                dim3914KuoInit,
                dim3915KuoInit,
                dim3916KuoInit,
                dim3917KuoInit,
                dim3918KuoInit,
                dim3919KuoInit,
                dim3920KuoInit,
                dim3921KuoInit,
                dim3922KuoInit,
                dim3923KuoInit,
                dim3924KuoInit,
                dim3925KuoInit,
                dim3926KuoInit,
                dim3927KuoInit,
                dim3928KuoInit,
                dim3929KuoInit,
                dim3930KuoInit,
                dim3931KuoInit,
                dim3932KuoInit,
                dim3933KuoInit,
                dim3934KuoInit,
                dim3935KuoInit,
                dim3936KuoInit,
                dim3937KuoInit,
                dim3938KuoInit,
                dim3939KuoInit,
                dim3940KuoInit,
                dim3941KuoInit,
                dim3942KuoInit,
                dim3943KuoInit,
                dim3944KuoInit,
                dim3945KuoInit,
                dim3946KuoInit,
                dim3947KuoInit,
                dim3948KuoInit,
                dim3949KuoInit,
                dim3950KuoInit,
                dim3951KuoInit,
                dim3952KuoInit,
                dim3953KuoInit,
                dim3954KuoInit,
                dim3955KuoInit,
                dim3956KuoInit,
                dim3957KuoInit,
                dim3958KuoInit,
                dim3959KuoInit,
                dim3960KuoInit,
                dim3961KuoInit,
                dim3962KuoInit,
                dim3963KuoInit,
                dim3964KuoInit,
                dim3965KuoInit,
                dim3966KuoInit,
                dim3967KuoInit,
                dim3968KuoInit,
                dim3969KuoInit,
                dim3970KuoInit,
                dim3971KuoInit,
                dim3972KuoInit,
                dim3973KuoInit,
                dim3974KuoInit,
                dim3975KuoInit,
                dim3976KuoInit,
                dim3977KuoInit,
                dim3978KuoInit,
                dim3979KuoInit,
                dim3980KuoInit,
                dim3981KuoInit,
                dim3982KuoInit,
                dim3983KuoInit,
                dim3984KuoInit,
                dim3985KuoInit,
                dim3986KuoInit,
                dim3987KuoInit,
                dim3988KuoInit,
                dim3989KuoInit,
                dim3990KuoInit,
                dim3991KuoInit,
                dim3992KuoInit,
                dim3993KuoInit,
                dim3994KuoInit,
                dim3995KuoInit,
                dim3996KuoInit,
                dim3997KuoInit,
                dim3998KuoInit,
                dim3999KuoInit,
                dim4000KuoInit,
                dim4001KuoInit,
                dim4002KuoInit,
                dim4003KuoInit,
                dim4004KuoInit,
                dim4005KuoInit,
                dim4006KuoInit,
                dim4007KuoInit,
                dim4008KuoInit,
                dim4009KuoInit,
                dim4010KuoInit,
                dim4011KuoInit,
                dim4012KuoInit,
                dim4013KuoInit,
                dim4014KuoInit,
                dim4015KuoInit,
                dim4016KuoInit,
                dim4017KuoInit,
                dim4018KuoInit,
                dim4019KuoInit,
                dim4020KuoInit,
                dim4021KuoInit,
                dim4022KuoInit,
                dim4023KuoInit,
                dim4024KuoInit,
                dim4025KuoInit,
                dim4026KuoInit,
                dim4027KuoInit,
                dim4028KuoInit,
                dim4029KuoInit,
                dim4030KuoInit,
                dim4031KuoInit,
                dim4032KuoInit,
                dim4033KuoInit,
                dim4034KuoInit,
                dim4035KuoInit,
                dim4036KuoInit,
                dim4037KuoInit,
                dim4038KuoInit,
                dim4039KuoInit,
                dim4040KuoInit,
                dim4041KuoInit,
                dim4042KuoInit,
                dim4043KuoInit,
                dim4044KuoInit,
                dim4045KuoInit,
                dim4046KuoInit,
                dim4047KuoInit,
                dim4048KuoInit,
                dim4049KuoInit,
                dim4050KuoInit,
                dim4051KuoInit,
                dim4052KuoInit,
                dim4053KuoInit,
                dim4054KuoInit,
                dim4055KuoInit,
                dim4056KuoInit,
                dim4057KuoInit,
                dim4058KuoInit,
                dim4059KuoInit,
                dim4060KuoInit,
                dim4061KuoInit,
                dim4062KuoInit,
                dim4063KuoInit,
                dim4064KuoInit,
                dim4065KuoInit,
                dim4066KuoInit,
                dim4067KuoInit,
                dim4068KuoInit,
                dim4069KuoInit,
                dim4070KuoInit,
                dim4071KuoInit,
                dim4072KuoInit,
                dim4073KuoInit,
                dim4074KuoInit,
                dim4075KuoInit,
                dim4076KuoInit,
                dim4077KuoInit,
                dim4078KuoInit,
                dim4079KuoInit,
                dim4080KuoInit,
                dim4081KuoInit,
                dim4082KuoInit,
                dim4083KuoInit,
                dim4084KuoInit,
                dim4085KuoInit,
                dim4086KuoInit,
                dim4087KuoInit,
                dim4088KuoInit,
                dim4089KuoInit,
                dim4090KuoInit,
                dim4091KuoInit,
                dim4092KuoInit,
                dim4093KuoInit,
                dim4094KuoInit,
                dim4095KuoInit,
                dim4096KuoInit,
                dim4097KuoInit,
                dim4098KuoInit,
                dim4099KuoInit,
                dim4100KuoInit,
                dim4101KuoInit,
                dim4102KuoInit,
                dim4103KuoInit,
                dim4104KuoInit,
                dim4105KuoInit,
                dim4106KuoInit,
                dim4107KuoInit,
                dim4108KuoInit,
                dim4109KuoInit,
                dim4110KuoInit,
                dim4111KuoInit,
                dim4112KuoInit,
                dim4113KuoInit,
                dim4114KuoInit,
                dim4115KuoInit,
                dim4116KuoInit,
                dim4117KuoInit,
                dim4118KuoInit,
                dim4119KuoInit,
                dim4120KuoInit,
                dim4121KuoInit,
                dim4122KuoInit,
                dim4123KuoInit,
                dim4124KuoInit,
                dim4125KuoInit,
                dim4126KuoInit,
                dim4127KuoInit,
                dim4128KuoInit,
                dim4129KuoInit,
                dim4130KuoInit,
                dim4131KuoInit,
                dim4132KuoInit,
                dim4133KuoInit,
                dim4134KuoInit,
                dim4135KuoInit,
                dim4136KuoInit,
                dim4137KuoInit,
                dim4138KuoInit,
                dim4139KuoInit,
                dim4140KuoInit,
                dim4141KuoInit,
                dim4142KuoInit,
                dim4143KuoInit,
                dim4144KuoInit,
                dim4145KuoInit,
                dim4146KuoInit,
                dim4147KuoInit,
                dim4148KuoInit,
                dim4149KuoInit,
                dim4150KuoInit,
                dim4151KuoInit,
                dim4152KuoInit,
                dim4153KuoInit,
                dim4154KuoInit,
                dim4155KuoInit,
                dim4156KuoInit,
                dim4157KuoInit,
                dim4158KuoInit,
                dim4159KuoInit,
                dim4160KuoInit,
                dim4161KuoInit,
                dim4162KuoInit,
                dim4163KuoInit,
                dim4164KuoInit,
                dim4165KuoInit,
                dim4166KuoInit,
                dim4167KuoInit,
                dim4168KuoInit,
                dim4169KuoInit,
                dim4170KuoInit,
                dim4171KuoInit,
                dim4172KuoInit,
                dim4173KuoInit,
                dim4174KuoInit,
                dim4175KuoInit,
                dim4176KuoInit,
                dim4177KuoInit,
                dim4178KuoInit,
                dim4179KuoInit,
                dim4180KuoInit,
                dim4181KuoInit,
                dim4182KuoInit,
                dim4183KuoInit,
                dim4184KuoInit,
                dim4185KuoInit,
                dim4186KuoInit,
                dim4187KuoInit,
                dim4188KuoInit,
                dim4189KuoInit,
                dim4190KuoInit,
                dim4191KuoInit,
                dim4192KuoInit,
                dim4193KuoInit,
                dim4194KuoInit,
                dim4195KuoInit,
                dim4196KuoInit,
                dim4197KuoInit,
                dim4198KuoInit,
                dim4199KuoInit,
                dim4200KuoInit,
                dim4201KuoInit,
                dim4202KuoInit,
                dim4203KuoInit,
                dim4204KuoInit,
                dim4205KuoInit,
                dim4206KuoInit,
                dim4207KuoInit,
                dim4208KuoInit,
                dim4209KuoInit,
                dim4210KuoInit,
                dim4211KuoInit,
                dim4212KuoInit,
                dim4213KuoInit,
                dim4214KuoInit,
                dim4215KuoInit,
                dim4216KuoInit,
                dim4217KuoInit,
                dim4218KuoInit,
                dim4219KuoInit,
                dim4220KuoInit,
                dim4221KuoInit,
                dim4222KuoInit,
                dim4223KuoInit,
                dim4224KuoInit,
                dim4225KuoInit,
                dim4226KuoInit,
                dim4227KuoInit,
                dim4228KuoInit,
                dim4229KuoInit,
                dim4230KuoInit,
                dim4231KuoInit,
                dim4232KuoInit,
                dim4233KuoInit,
                dim4234KuoInit,
                dim4235KuoInit,
                dim4236KuoInit,
                dim4237KuoInit,
                dim4238KuoInit,
                dim4239KuoInit,
                dim4240KuoInit,
                dim4241KuoInit,
                dim4242KuoInit,
                dim4243KuoInit,
                dim4244KuoInit,
                dim4245KuoInit,
                dim4246KuoInit,
                dim4247KuoInit,
                dim4248KuoInit,
                dim4249KuoInit,
                dim4250KuoInit,
                dim4251KuoInit,
                dim4252KuoInit,
                dim4253KuoInit,
                dim4254KuoInit,
                dim4255KuoInit,
                dim4256KuoInit,
                dim4257KuoInit,
                dim4258KuoInit,
                dim4259KuoInit,
                dim4260KuoInit,
                dim4261KuoInit,
                dim4262KuoInit,
                dim4263KuoInit,
                dim4264KuoInit,
                dim4265KuoInit,
                dim4266KuoInit,
                dim4267KuoInit,
                dim4268KuoInit,
                dim4269KuoInit,
                dim4270KuoInit,
                dim4271KuoInit,
                dim4272KuoInit,
                dim4273KuoInit,
                dim4274KuoInit,
                dim4275KuoInit,
                dim4276KuoInit,
                dim4277KuoInit,
                dim4278KuoInit,
                dim4279KuoInit,
                dim4280KuoInit,
                dim4281KuoInit,
                dim4282KuoInit,
                dim4283KuoInit,
                dim4284KuoInit,
                dim4285KuoInit,
                dim4286KuoInit,
                dim4287KuoInit,
                dim4288KuoInit,
                dim4289KuoInit,
                dim4290KuoInit,
                dim4291KuoInit,
                dim4292KuoInit,
                dim4293KuoInit,
                dim4294KuoInit,
                dim4295KuoInit,
                dim4296KuoInit,
                dim4297KuoInit,
                dim4298KuoInit,
                dim4299KuoInit,
                dim4300KuoInit,
                dim4301KuoInit,
                dim4302KuoInit,
                dim4303KuoInit,
                dim4304KuoInit,
                dim4305KuoInit,
                dim4306KuoInit,
                dim4307KuoInit,
                dim4308KuoInit,
                dim4309KuoInit,
                dim4310KuoInit,
                dim4311KuoInit,
                dim4312KuoInit,
                dim4313KuoInit,
                dim4314KuoInit,
                dim4315KuoInit,
                dim4316KuoInit,
                dim4317KuoInit,
                dim4318KuoInit,
                dim4319KuoInit,
                dim4320KuoInit,
                dim4321KuoInit,
                dim4322KuoInit,
                dim4323KuoInit,
                dim4324KuoInit,
                dim4325KuoInit,
                dim4326KuoInit,
                dim4327KuoInit,
                dim4328KuoInit,
                dim4329KuoInit,
                dim4330KuoInit,
                dim4331KuoInit,
                dim4332KuoInit,
                dim4333KuoInit,
                dim4334KuoInit,
                dim4335KuoInit,
                dim4336KuoInit,
                dim4337KuoInit,
                dim4338KuoInit,
                dim4339KuoInit,
                dim4340KuoInit,
                dim4341KuoInit,
                dim4342KuoInit,
                dim4343KuoInit,
                dim4344KuoInit,
                dim4345KuoInit,
                dim4346KuoInit,
                dim4347KuoInit,
                dim4348KuoInit,
                dim4349KuoInit,
                dim4350KuoInit,
                dim4351KuoInit,
                dim4352KuoInit,
                dim4353KuoInit,
                dim4354KuoInit,
                dim4355KuoInit,
                dim4356KuoInit,
                dim4357KuoInit,
                dim4358KuoInit,
                dim4359KuoInit,
                dim4360KuoInit,
                dim4361KuoInit,
                dim4362KuoInit,
                dim4363KuoInit,
                dim4364KuoInit,
                dim4365KuoInit,
                dim4366KuoInit,
                dim4367KuoInit,
                dim4368KuoInit,
                dim4369KuoInit,
                dim4370KuoInit,
                dim4371KuoInit,
                dim4372KuoInit,
                dim4373KuoInit,
                dim4374KuoInit,
                dim4375KuoInit,
                dim4376KuoInit,
                dim4377KuoInit,
                dim4378KuoInit,
                dim4379KuoInit,
                dim4380KuoInit,
                dim4381KuoInit,
                dim4382KuoInit,
                dim4383KuoInit,
                dim4384KuoInit,
                dim4385KuoInit,
                dim4386KuoInit,
                dim4387KuoInit,
                dim4388KuoInit,
                dim4389KuoInit,
                dim4390KuoInit,
                dim4391KuoInit,
                dim4392KuoInit,
                dim4393KuoInit,
                dim4394KuoInit,
                dim4395KuoInit,
                dim4396KuoInit,
                dim4397KuoInit,
                dim4398KuoInit,
                dim4399KuoInit,
                dim4400KuoInit,
                dim4401KuoInit,
                dim4402KuoInit,
                dim4403KuoInit,
                dim4404KuoInit,
                dim4405KuoInit,
                dim4406KuoInit,
                dim4407KuoInit,
                dim4408KuoInit,
                dim4409KuoInit,
                dim4410KuoInit,
                dim4411KuoInit,
                dim4412KuoInit,
                dim4413KuoInit,
                dim4414KuoInit,
                dim4415KuoInit,
                dim4416KuoInit,
                dim4417KuoInit,
                dim4418KuoInit,
                dim4419KuoInit,
                dim4420KuoInit,
                dim4421KuoInit,
                dim4422KuoInit,
                dim4423KuoInit,
                dim4424KuoInit,
                dim4425KuoInit,
                dim4426KuoInit,
                dim4427KuoInit,
                dim4428KuoInit,
                dim4429KuoInit,
                dim4430KuoInit,
                dim4431KuoInit,
                dim4432KuoInit,
                dim4433KuoInit,
                dim4434KuoInit,
                dim4435KuoInit,
                dim4436KuoInit,
                dim4437KuoInit,
                dim4438KuoInit,
                dim4439KuoInit,
                dim4440KuoInit,
                dim4441KuoInit,
                dim4442KuoInit,
                dim4443KuoInit,
                dim4444KuoInit,
                dim4445KuoInit,
                dim4446KuoInit,
                dim4447KuoInit,
                dim4448KuoInit,
                dim4449KuoInit,
                dim4450KuoInit,
                dim4451KuoInit,
                dim4452KuoInit,
                dim4453KuoInit,
                dim4454KuoInit,
                dim4455KuoInit,
                dim4456KuoInit,
                dim4457KuoInit,
                dim4458KuoInit,
                dim4459KuoInit,
                dim4460KuoInit,
                dim4461KuoInit,
                dim4462KuoInit,
                dim4463KuoInit,
                dim4464KuoInit,
                dim4465KuoInit,
                dim4466KuoInit,
                dim4467KuoInit,
                dim4468KuoInit,
                dim4469KuoInit,
                dim4470KuoInit,
                dim4471KuoInit,
                dim4472KuoInit,
                dim4473KuoInit,
                dim4474KuoInit,
                dim4475KuoInit,
                dim4476KuoInit,
                dim4477KuoInit,
                dim4478KuoInit,
                dim4479KuoInit,
                dim4480KuoInit,
                dim4481KuoInit,
                dim4482KuoInit,
                dim4483KuoInit,
                dim4484KuoInit,
                dim4485KuoInit,
                dim4486KuoInit,
                dim4487KuoInit,
                dim4488KuoInit,
                dim4489KuoInit,
                dim4490KuoInit,
                dim4491KuoInit,
                dim4492KuoInit,
                dim4493KuoInit,
                dim4494KuoInit,
                dim4495KuoInit,
                dim4496KuoInit,
                dim4497KuoInit,
                dim4498KuoInit,
                dim4499KuoInit,
                dim4500KuoInit,
                dim4501KuoInit,
                dim4502KuoInit,
                dim4503KuoInit,
                dim4504KuoInit,
                dim4505KuoInit,
                dim4506KuoInit,
                dim4507KuoInit,
                dim4508KuoInit,
                dim4509KuoInit,
                dim4510KuoInit,
                dim4511KuoInit,
                dim4512KuoInit,
                dim4513KuoInit,
                dim4514KuoInit,
                dim4515KuoInit,
                dim4516KuoInit,
                dim4517KuoInit,
                dim4518KuoInit,
                dim4519KuoInit,
                dim4520KuoInit,
                dim4521KuoInit,
                dim4522KuoInit,
                dim4523KuoInit,
                dim4524KuoInit,
                dim4525KuoInit,
                dim4526KuoInit,
                dim4527KuoInit,
                dim4528KuoInit,
                dim4529KuoInit,
                dim4530KuoInit,
                dim4531KuoInit,
                dim4532KuoInit,
                dim4533KuoInit,
                dim4534KuoInit,
                dim4535KuoInit,
                dim4536KuoInit,
                dim4537KuoInit,
                dim4538KuoInit,
                dim4539KuoInit,
                dim4540KuoInit,
                dim4541KuoInit,
                dim4542KuoInit,
                dim4543KuoInit,
                dim4544KuoInit,
                dim4545KuoInit,
                dim4546KuoInit,
                dim4547KuoInit,
                dim4548KuoInit,
                dim4549KuoInit,
                dim4550KuoInit,
                dim4551KuoInit,
                dim4552KuoInit,
                dim4553KuoInit,
                dim4554KuoInit,
                dim4555KuoInit,
                dim4556KuoInit,
                dim4557KuoInit,
                dim4558KuoInit,
                dim4559KuoInit,
                dim4560KuoInit,
                dim4561KuoInit,
                dim4562KuoInit,
                dim4563KuoInit,
                dim4564KuoInit,
                dim4565KuoInit,
                dim4566KuoInit,
                dim4567KuoInit,
                dim4568KuoInit,
                dim4569KuoInit,
                dim4570KuoInit,
                dim4571KuoInit,
                dim4572KuoInit,
                dim4573KuoInit,
                dim4574KuoInit,
                dim4575KuoInit,
                dim4576KuoInit,
                dim4577KuoInit,
                dim4578KuoInit,
                dim4579KuoInit,
                dim4580KuoInit,
                dim4581KuoInit,
                dim4582KuoInit,
                dim4583KuoInit,
                dim4584KuoInit,
                dim4585KuoInit,
                dim4586KuoInit,
                dim4587KuoInit,
                dim4588KuoInit,
                dim4589KuoInit,
                dim4590KuoInit,
                dim4591KuoInit,
                dim4592KuoInit,
                dim4593KuoInit,
                dim4594KuoInit,
                dim4595KuoInit,
                dim4596KuoInit,
                dim4597KuoInit,
                dim4598KuoInit,
                dim4599KuoInit,
                dim4600KuoInit,
                dim4601KuoInit,
                dim4602KuoInit,
                dim4603KuoInit,
                dim4604KuoInit,
                dim4605KuoInit,
                dim4606KuoInit,
                dim4607KuoInit,
                dim4608KuoInit,
                dim4609KuoInit,
                dim4610KuoInit,
                dim4611KuoInit,
                dim4612KuoInit,
                dim4613KuoInit,
                dim4614KuoInit,
                dim4615KuoInit,
                dim4616KuoInit,
                dim4617KuoInit,
                dim4618KuoInit,
                dim4619KuoInit,
                dim4620KuoInit,
                dim4621KuoInit,
                dim4622KuoInit,
                dim4623KuoInit,
                dim4624KuoInit,
                dim4625KuoInit,
                dim4626KuoInit,
                dim4627KuoInit,
                dim4628KuoInit,
                dim4629KuoInit,
                dim4630KuoInit,
                dim4631KuoInit,
                dim4632KuoInit,
                dim4633KuoInit,
                dim4634KuoInit,
                dim4635KuoInit,
                dim4636KuoInit,
                dim4637KuoInit,
                dim4638KuoInit,
                dim4639KuoInit,
                dim4640KuoInit,
                dim4641KuoInit,
                dim4642KuoInit,
                dim4643KuoInit,
                dim4644KuoInit,
                dim4645KuoInit,
                dim4646KuoInit,
                dim4647KuoInit,
                dim4648KuoInit,
                dim4649KuoInit,
                dim4650KuoInit,
                dim4651KuoInit,
                dim4652KuoInit,
                dim4653KuoInit,
                dim4654KuoInit,
                dim4655KuoInit,
                dim4656KuoInit,
                dim4657KuoInit,
                dim4658KuoInit,
                dim4659KuoInit,
                dim4660KuoInit,
                dim4661KuoInit,
                dim4662KuoInit,
                dim4663KuoInit,
                dim4664KuoInit,
                dim4665KuoInit,
                dim4666KuoInit,
                dim4667KuoInit,
                dim4668KuoInit,
                dim4669KuoInit,
                dim4670KuoInit,
                dim4671KuoInit,
                dim4672KuoInit,
                dim4673KuoInit,
                dim4674KuoInit,
                dim4675KuoInit,
                dim4676KuoInit,
                dim4677KuoInit,
                dim4678KuoInit,
                dim4679KuoInit,
                dim4680KuoInit,
                dim4681KuoInit,
                dim4682KuoInit,
                dim4683KuoInit,
                dim4684KuoInit,
                dim4685KuoInit,
                dim4686KuoInit,
                dim4687KuoInit,
                dim4688KuoInit,
                dim4689KuoInit,
                dim4690KuoInit,
                dim4691KuoInit,
                dim4692KuoInit,
                dim4693KuoInit,
                dim4694KuoInit,
                dim4695KuoInit,
                dim4696KuoInit,
                dim4697KuoInit,
                dim4698KuoInit,
                dim4699KuoInit,
                dim4700KuoInit,
                dim4701KuoInit,
                dim4702KuoInit,
                dim4703KuoInit,
                dim4704KuoInit,
                dim4705KuoInit,
                dim4706KuoInit,
                dim4707KuoInit,
                dim4708KuoInit,
                dim4709KuoInit,
                dim4710KuoInit,
                dim4711KuoInit,
                dim4712KuoInit,
                dim4713KuoInit,
                dim4714KuoInit,
                dim4715KuoInit,
                dim4716KuoInit,
                dim4717KuoInit,
                dim4718KuoInit,
                dim4719KuoInit,
                dim4720KuoInit,
                dim4721KuoInit,
                dim4722KuoInit,
                dim4723KuoInit,
                dim4724KuoInit,
                dim4725KuoInit,
                dim4726KuoInit,
                dim4727KuoInit,
                dim4728KuoInit,
                dim4729KuoInit,
                dim4730KuoInit,
                dim4731KuoInit,
                dim4732KuoInit,
                dim4733KuoInit,
                dim4734KuoInit,
                dim4735KuoInit,
                dim4736KuoInit,
                dim4737KuoInit,
                dim4738KuoInit,
                dim4739KuoInit,
                dim4740KuoInit,
                dim4741KuoInit,
                dim4742KuoInit,
                dim4743KuoInit,
                dim4744KuoInit,
                dim4745KuoInit,
                dim4746KuoInit,
                dim4747KuoInit,
                dim4748KuoInit,
                dim4749KuoInit,
                dim4750KuoInit,
                dim4751KuoInit,
                dim4752KuoInit,
                dim4753KuoInit,
                dim4754KuoInit,
                dim4755KuoInit,
                dim4756KuoInit,
                dim4757KuoInit,
                dim4758KuoInit,
                dim4759KuoInit,
                dim4760KuoInit,
                dim4761KuoInit,
                dim4762KuoInit,
                dim4763KuoInit,
                dim4764KuoInit,
                dim4765KuoInit,
                dim4766KuoInit,
                dim4767KuoInit,
                dim4768KuoInit,
                dim4769KuoInit,
                dim4770KuoInit,
                dim4771KuoInit,
                dim4772KuoInit,
                dim4773KuoInit,
                dim4774KuoInit,
                dim4775KuoInit,
                dim4776KuoInit,
                dim4777KuoInit,
                dim4778KuoInit,
                dim4779KuoInit,
                dim4780KuoInit,
                dim4781KuoInit,
                dim4782KuoInit,
                dim4783KuoInit,
                dim4784KuoInit,
                dim4785KuoInit,
                dim4786KuoInit,
                dim4787KuoInit,
                dim4788KuoInit,
                dim4789KuoInit,
                dim4790KuoInit,
                dim4791KuoInit,
                dim4792KuoInit,
                dim4793KuoInit,
                dim4794KuoInit,
                dim4795KuoInit,
                dim4796KuoInit,
                dim4797KuoInit,
                dim4798KuoInit,
                dim4799KuoInit,
                dim4800KuoInit,
                dim4801KuoInit,
                dim4802KuoInit,
                dim4803KuoInit,
                dim4804KuoInit,
                dim4805KuoInit,
                dim4806KuoInit,
                dim4807KuoInit,
                dim4808KuoInit,
                dim4809KuoInit,
                dim4810KuoInit,
                dim4811KuoInit,
                dim4812KuoInit,
                dim4813KuoInit,
                dim4814KuoInit,
                dim4815KuoInit,
                dim4816KuoInit,
                dim4817KuoInit,
                dim4818KuoInit,
                dim4819KuoInit,
                dim4820KuoInit,
                dim4821KuoInit,
                dim4822KuoInit,
                dim4823KuoInit,
                dim4824KuoInit,
                dim4825KuoInit,
                dim4826KuoInit,
                dim4827KuoInit,
                dim4828KuoInit,
                dim4829KuoInit,
                dim4830KuoInit,
                dim4831KuoInit,
                dim4832KuoInit,
                dim4833KuoInit,
                dim4834KuoInit,
                dim4835KuoInit,
                dim4836KuoInit,
                dim4837KuoInit,
                dim4838KuoInit,
                dim4839KuoInit,
                dim4840KuoInit,
                dim4841KuoInit,
                dim4842KuoInit,
                dim4843KuoInit,
                dim4844KuoInit,
                dim4845KuoInit,
                dim4846KuoInit,
                dim4847KuoInit,
                dim4848KuoInit,
                dim4849KuoInit,
                dim4850KuoInit,
                dim4851KuoInit,
                dim4852KuoInit,
                dim4853KuoInit,
                dim4854KuoInit,
                dim4855KuoInit,
                dim4856KuoInit,
                dim4857KuoInit,
                dim4858KuoInit,
                dim4859KuoInit,
                dim4860KuoInit,
                dim4861KuoInit,
                dim4862KuoInit,
                dim4863KuoInit,
                dim4864KuoInit,
                dim4865KuoInit,
                dim4866KuoInit,
                dim4867KuoInit,
                dim4868KuoInit,
                dim4869KuoInit,
                dim4870KuoInit,
                dim4871KuoInit,
                dim4872KuoInit,
                dim4873KuoInit,
                dim4874KuoInit,
                dim4875KuoInit,
                dim4876KuoInit,
                dim4877KuoInit,
                dim4878KuoInit,
                dim4879KuoInit,
                dim4880KuoInit,
                dim4881KuoInit,
                dim4882KuoInit,
                dim4883KuoInit,
                dim4884KuoInit,
                dim4885KuoInit,
                dim4886KuoInit,
                dim4887KuoInit,
                dim4888KuoInit,
                dim4889KuoInit,
                dim4890KuoInit,
                dim4891KuoInit,
                dim4892KuoInit,
                dim4893KuoInit,
                dim4894KuoInit,
                dim4895KuoInit,
                dim4896KuoInit,
                dim4897KuoInit,
                dim4898KuoInit,
                dim4899KuoInit,
                dim4900KuoInit,
                dim4901KuoInit,
                dim4902KuoInit,
                dim4903KuoInit,
                dim4904KuoInit,
                dim4905KuoInit,
                dim4906KuoInit,
                dim4907KuoInit,
                dim4908KuoInit,
                dim4909KuoInit,
                dim4910KuoInit,
                dim4911KuoInit,
                dim4912KuoInit,
                dim4913KuoInit,
                dim4914KuoInit,
                dim4915KuoInit,
                dim4916KuoInit,
                dim4917KuoInit,
                dim4918KuoInit,
                dim4919KuoInit,
                dim4920KuoInit,
                dim4921KuoInit,
                dim4922KuoInit,
                dim4923KuoInit,
                dim4924KuoInit,
                dim4925KuoInit,

            };

            const std::uint32_t dim1Kuo2Init[]  =   {   1   ,0 };
            const std::uint32_t dim2Kuo2Init[]  =   {   1   ,   1   ,0 };
            const std::uint32_t dim3Kuo2Init[]  =   {   1   ,   1   ,   1   ,0 };
            const std::uint32_t dim4Kuo2Init[]  =   {   1   ,   3   ,   1   ,0 };
            const std::uint32_t dim5Kuo2Init[]  =   {   1   ,   3   ,   7   ,   1   ,0 };
            const std::uint32_t dim6Kuo2Init[]  =   {   1   ,   1   ,   3   ,   7   ,0 };
            const std::uint32_t dim7Kuo2Init[]  =   {   1   ,   3   ,   1   ,   7   ,   23  ,0 };
            const std::uint32_t dim8Kuo2Init[]  =   {   1   ,   1   ,   5   ,   1   ,   27  ,0 };
            const std::uint32_t dim9Kuo2Init[]  =   {   1   ,   3   ,   5   ,   3   ,   25  ,0 };
            const std::uint32_t dim10Kuo2Init[] =   {   1   ,   1   ,   5   ,   9   ,   21  ,0 };
            const std::uint32_t dim11Kuo2Init[] =   {   1   ,   1   ,   3   ,   13  ,   27  ,0 };
            const std::uint32_t dim12Kuo2Init[] =   {   1   ,   3   ,   7   ,   11  ,   3   ,0 };
            const std::uint32_t dim13Kuo2Init[] =   {   1   ,   3   ,   1   ,   13  ,   31  ,   47  ,0 };
            const std::uint32_t dim14Kuo2Init[] =   {   1   ,   3   ,   3   ,   5   ,   13  ,   17  ,0 };
            const std::uint32_t dim15Kuo2Init[] =   {   1   ,   1   ,   7   ,   3   ,   13  ,   51  ,0 };
            const std::uint32_t dim16Kuo2Init[] =   {   1   ,   3   ,   3   ,   11  ,   7   ,   63  ,0 };
            const std::uint32_t dim17Kuo2Init[] =   {   1   ,   1   ,   1   ,   7   ,   3   ,   53  ,0 };
            const std::uint32_t dim18Kuo2Init[] =   {   1   ,   3   ,   5   ,   11  ,   3   ,   43  ,0 };
            const std::uint32_t dim19Kuo2Init[] =   {   1   ,   1   ,   7   ,   5   ,   19  ,   59  ,   59  ,0 };
            const std::uint32_t dim20Kuo2Init[] =   {   1   ,   1   ,   7   ,   9   ,   15  ,   25  ,   63  ,0 };
            const std::uint32_t dim21Kuo2Init[] =   {   1   ,   3   ,   7   ,   7   ,   27  ,   5   ,   17  ,0 };
            const std::uint32_t dim22Kuo2Init[] =   {   1   ,   3   ,   1   ,   5   ,   7   ,   51  ,   69  ,0 };
            const std::uint32_t dim23Kuo2Init[] =   {   1   ,   3   ,   3   ,   11  ,   23  ,   5   ,   35  ,0 };
            const std::uint32_t dim24Kuo2Init[] =   {   1   ,   1   ,   5   ,   1   ,   3   ,   17  ,   59  ,0 };
            const std::uint32_t dim25Kuo2Init[] =   {   1   ,   3   ,   7   ,   7   ,   3   ,   51  ,   57  ,0 };
            const std::uint32_t dim26Kuo2Init[] =   {   1   ,   3   ,   7   ,   11  ,   17  ,   1   ,   17  ,0 };
            const std::uint32_t dim27Kuo2Init[] =   {   1   ,   1   ,   1   ,   11  ,   25  ,   45  ,   3   ,0 };
            const std::uint32_t dim28Kuo2Init[] =   {   1   ,   1   ,   5   ,   15  ,   23  ,   53  ,   79  ,0 };
            const std::uint32_t dim29Kuo2Init[] =   {   1   ,   3   ,   3   ,   3   ,   19  ,   31  ,   39  ,0 };
            const std::uint32_t dim30Kuo2Init[] =   {   1   ,   1   ,   1   ,   9   ,   9   ,   21  ,   23  ,0 };
            const std::uint32_t dim31Kuo2Init[] =   {   1   ,   1   ,   3   ,   5   ,   31  ,   13  ,   97  ,0 };
            const std::uint32_t dim32Kuo2Init[] =   {   1   ,   1   ,   1   ,   15  ,   9   ,   39  ,   3   ,0 };
            const std::uint32_t dim33Kuo2Init[] =   {   1   ,   3   ,   1   ,   1   ,   27  ,   55  ,   37  ,0 };
            const std::uint32_t dim34Kuo2Init[] =   {   1   ,   3   ,   7   ,   11  ,   21  ,   49  ,   17  ,0 };
            const std::uint32_t dim35Kuo2Init[] =   {   1   ,   3   ,   3   ,   9   ,   31  ,   37  ,   95  ,0 };
            const std::uint32_t dim36Kuo2Init[] =   {   1   ,   1   ,   1   ,   1   ,   7   ,   35  ,   95  ,0 };
            const std::uint32_t dim37Kuo2Init[] =   {   1   ,   1   ,   5   ,   15  ,   15  ,   61  ,   11  ,   211 ,0 };
            const std::uint32_t dim38Kuo2Init[] =   {   1   ,   1   ,   7   ,   7   ,   29  ,   33  ,   127 ,   171 ,0 };
            const std::uint32_t dim39Kuo2Init[] =   {   1   ,   3   ,   5   ,   9   ,   17  ,   27  ,   85  ,   95  ,0 };
            const std::uint32_t dim40Kuo2Init[] =   {   1   ,   3   ,   7   ,   1   ,   25  ,   43  ,   35  ,   21  ,0 };
            const std::uint32_t dim41Kuo2Init[] =   {   1   ,   3   ,   5   ,   15  ,   9   ,   17  ,   43  ,   253 ,0 };
            const std::uint32_t dim42Kuo2Init[] =   {   1   ,   1   ,   5   ,   11  ,   27  ,   45  ,   37  ,   147 ,0 };
            const std::uint32_t dim43Kuo2Init[] =   {   1   ,   1   ,   7   ,   5   ,   7   ,   35  ,   29  ,   191 ,0 };
            const std::uint32_t dim44Kuo2Init[] =   {   1   ,   3   ,   1   ,   1   ,   15  ,   33  ,   21  ,   125 ,0 };
            const std::uint32_t dim45Kuo2Init[] =   {   1   ,   1   ,   1   ,   7   ,   31  ,   41  ,   33  ,   11  ,0 };
            const std::uint32_t dim46Kuo2Init[] =   {   1   ,   1   ,   7   ,   7   ,   27  ,   9   ,   111 ,   209 ,0 };
            const std::uint32_t dim47Kuo2Init[] =   {   1   ,   3   ,   7   ,   15  ,   1   ,   57  ,   63  ,   43  ,0 };
            const std::uint32_t dim48Kuo2Init[] =   {   1   ,   3   ,   3   ,   13  ,   1   ,   51  ,   5   ,   51  ,0 };
            const std::uint32_t dim49Kuo2Init[] =   {   1   ,   3   ,   5   ,   3   ,   27  ,   17  ,   103 ,   247 ,0 };
            const std::uint32_t dim50Kuo2Init[] =   {   1   ,   3   ,   7   ,   7   ,   11  ,   27  ,   51  ,   103 ,0 };
            const std::uint32_t dim51Kuo2Init[] =   {   1   ,   3   ,   3   ,   1   ,   23  ,   21  ,   65  ,   135 ,0 };
            const std::uint32_t dim52Kuo2Init[] =   {   1   ,   1   ,   7   ,   9   ,   1   ,   7   ,   71  ,   251 ,0 };
            const std::uint32_t dim53Kuo2Init[] =   {   1   ,   3   ,   1   ,   5   ,   11  ,   31  ,   43  ,   129 ,   225 ,0 };
            const std::uint32_t dim54Kuo2Init[] =   {   1   ,   1   ,   1   ,   5   ,   15  ,   15  ,   127 ,   225 ,   439 ,0 };
            const std::uint32_t dim55Kuo2Init[] =   {   1   ,   1   ,   3   ,   13  ,   27  ,   45  ,   103 ,   65  ,   313 ,0 };
            const std::uint32_t dim56Kuo2Init[] =   {   1   ,   3   ,   3   ,   15  ,   13  ,   31  ,   27  ,   231 ,   183 ,0 };
            const std::uint32_t dim57Kuo2Init[] =   {   1   ,   1   ,   3   ,   7   ,   23  ,   5   ,   15  ,   75  ,   159 ,0 };
            const std::uint32_t dim58Kuo2Init[] =   {   1   ,   1   ,   5   ,   15  ,   21  ,   3   ,   99  ,   23  ,   465 ,0 };
            const std::uint32_t dim59Kuo2Init[] =   {   1   ,   3   ,   7   ,   5   ,   23  ,   47  ,   119 ,   103 ,   271 ,0 };
            const std::uint32_t dim60Kuo2Init[] =   {   1   ,   3   ,   1   ,   11  ,   25  ,   13  ,   83  ,   5   ,   21  ,0 };
            const std::uint32_t dim61Kuo2Init[] =   {   1   ,   3   ,   5   ,   3   ,   7   ,   41  ,   123 ,   87  ,   243 ,0 };
            const std::uint32_t dim62Kuo2Init[] =   {   1   ,   1   ,   3   ,   11  ,   3   ,   7   ,   91  ,   227 ,   349 ,0 };
            const std::uint32_t dim63Kuo2Init[] =   {   1   ,   1   ,   1   ,   9   ,   29  ,   23  ,   31  ,   175 ,   145 ,0 };
            const std::uint32_t dim64Kuo2Init[] =   {   1   ,   1   ,   7   ,   7   ,   13  ,   25  ,   67  ,   59  ,   109 ,0 };
            const std::uint32_t dim65Kuo2Init[] =   {   1   ,   3   ,   7   ,   11  ,   25  ,   49  ,   23  ,   55  ,   135 ,0 };
            const std::uint32_t dim66Kuo2Init[] =   {   1   ,   3   ,   5   ,   7   ,   27  ,   61  ,   5   ,   193 ,   375 ,0 };
            const std::uint32_t dim67Kuo2Init[]     =   {   1   ,   1   ,   5   ,   9   ,   23  ,   27  ,   41  ,   239 ,   383 ,0 };
            const std::uint32_t dim68Kuo2Init[]     =   {   1   ,   1   ,   3   ,   15  ,   3   ,   43  ,   81  ,   77  ,   91  ,0 };
            const std::uint32_t dim69Kuo2Init[]     =   {   1   ,   1   ,   1   ,   13  ,   29  ,   17  ,   23  ,   105 ,   393 ,0 };
            const std::uint32_t dim70Kuo2Init[]     =   {   1   ,   3   ,   3   ,   3   ,   27  ,   41  ,   89  ,   79  ,   295 ,0 };
            const std::uint32_t dim71Kuo2Init[]     =   {   1   ,   3   ,   3   ,   5   ,   27  ,   63  ,   29  ,   189 ,   505 ,0 };
            const std::uint32_t dim72Kuo2Init[]     =   {   1   ,   1   ,   3   ,   7   ,   23  ,   63  ,   117 ,   75  ,   165 ,0 };
            const std::uint32_t dim73Kuo2Init[]     =   {   1   ,   1   ,   5   ,   13  ,   1   ,   47  ,   123 ,   159 ,   485 ,0 };
            const std::uint32_t dim74Kuo2Init[]     =   {   1   ,   3   ,   5   ,   1   ,   23  ,   27  ,   125 ,   45  ,   351 ,0 };
            const std::uint32_t dim75Kuo2Init[]     =   {   1   ,   3   ,   1   ,   5   ,   11  ,   33  ,   75  ,   17  ,   85  ,0 };
            const std::uint32_t dim76Kuo2Init[]     =   {   1   ,   3   ,   7   ,   9   ,   23  ,   31  ,   33  ,   91  ,   131 ,0 };
            const std::uint32_t dim77Kuo2Init[]     =   {   1   ,   1   ,   3   ,   7   ,   23  ,   31  ,   89  ,   243 ,   229 ,0 };
            const std::uint32_t dim78Kuo2Init[]     =   {   1   ,   1   ,   7   ,   15  ,   3   ,   9   ,   97  ,   59  ,   159 ,0 };
            const std::uint32_t dim79Kuo2Init[]     =   {   1   ,   3   ,   3   ,   9   ,   23  ,   1   ,   105 ,   217 ,   491 ,0 };
            const std::uint32_t dim80Kuo2Init[]     =   {   1   ,   3   ,   7   ,   13  ,   19  ,   3   ,   95  ,   149 ,   169 ,0 };
            const std::uint32_t dim81Kuo2Init[]     =   {   1   ,   1   ,   5   ,   11  ,   29  ,   57  ,   7   ,   69  ,   33  ,0 };
            const std::uint32_t dim82Kuo2Init[]     =   {   1   ,   1   ,   7   ,   7   ,   23  ,   1   ,   17  ,   3   ,   325 ,0 };
            const std::uint32_t dim83Kuo2Init[]     =   {   1   ,   3   ,   1   ,   7   ,   23  ,   7   ,   49  ,   251 ,   501 ,0 };
            const std::uint32_t dim84Kuo2Init[]     =   {   1   ,   1   ,   5   ,   9   ,   13  ,   59  ,   51  ,   15  ,   231 ,0 };
            const std::uint32_t dim85Kuo2Init[]     =   {   1   ,   1   ,   1   ,   7   ,   13  ,   43  ,   21  ,   227 ,   165 ,0 };
            const std::uint32_t dim86Kuo2Init[]     =   {   1   ,   1   ,   5   ,   1   ,   17  ,   59  ,   85  ,   13  ,   81  ,0 };
            const std::uint32_t dim87Kuo2Init[]     =   {   1   ,   1   ,   5   ,   11  ,   25  ,   39  ,   109 ,   149 ,   89  ,0 };
            const std::uint32_t dim88Kuo2Init[]     =   {   1   ,   3   ,   1   ,   13  ,   3   ,   47  ,   85  ,   1   ,   241 ,0 };
            const std::uint32_t dim89Kuo2Init[]     =   {   1   ,   1   ,   7   ,   7   ,   29  ,   25  ,   71  ,   13  ,   221 ,0 };
            const std::uint32_t dim90Kuo2Init[]     =   {   1   ,   1   ,   3   ,   5   ,   1   ,   3   ,   17  ,   241 ,   227 ,0 };
            const std::uint32_t dim91Kuo2Init[]     =   {   1   ,   3   ,   1   ,   7   ,   3   ,   23  ,   127 ,   209 ,   139 ,0 };
            const std::uint32_t dim92Kuo2Init[]     =   {   1   ,   1   ,   3   ,   5   ,   31  ,   39  ,   55  ,   193 ,   27  ,0 };
            const std::uint32_t dim93Kuo2Init[]     =   {   1   ,   3   ,   5   ,   3   ,   5   ,   19  ,   71  ,   161 ,   255 ,0 };
            const std::uint32_t dim94Kuo2Init[]     =   {   1   ,   3   ,   3   ,   7   ,   17  ,   27  ,   105 ,   13  ,   131 ,0 };
            const std::uint32_t dim95Kuo2Init[]     =   {   1   ,   1   ,   3   ,   1   ,   23  ,   7   ,   43  ,   171 ,   503 ,0 };
            const std::uint32_t dim96Kuo2Init[]     =   {   1   ,   3   ,   5   ,   7   ,   7   ,   11  ,   9   ,   243 ,   173 ,0 };
            const std::uint32_t dim97Kuo2Init[]     =   {   1   ,   1   ,   7   ,   13  ,   23  ,   3   ,   119 ,   243 ,   189 ,0 };
            const std::uint32_t dim98Kuo2Init[]     =   {   1   ,   1   ,   3   ,   11  ,   17  ,   55  ,   53  ,   159 ,   339 ,0 };
            const std::uint32_t dim99Kuo2Init[]     =   {   1   ,   3   ,   3   ,   11  ,   5   ,   17  ,   69  ,   103 ,   453 ,0 };
            const std::uint32_t dim100Kuo2Init[]        =   {   1   ,   3   ,   7   ,   7   ,   9   ,   41  ,   31  ,   165 ,   117 ,0 };
            const std::uint32_t dim101Kuo2Init[]        =   {   1   ,   1   ,   5   ,   3   ,   5   ,   39  ,   79  ,   141 ,   205 ,   483 ,0 };
            const std::uint32_t dim102Kuo2Init[]        =   {   1   ,   3   ,   1   ,   3   ,   3   ,   59  ,   57  ,   189 ,   279 ,   769 ,0 };
            const std::uint32_t dim103Kuo2Init[]        =   {   1   ,   1   ,   3   ,   13  ,   25  ,   21  ,   107 ,   61  ,   329 ,   695 ,0 };
            const std::uint32_t dim104Kuo2Init[]        =   {   1   ,   3   ,   5   ,   15  ,   3   ,   61  ,   71  ,   161 ,   55  ,   757 ,0 };
            const std::uint32_t dim105Kuo2Init[]        =   {   1   ,   1   ,   1   ,   11  ,   9   ,   17  ,   121 ,   41  ,   177 ,   261 ,0 };
            const std::uint32_t dim106Kuo2Init[]        =   {   1   ,   1   ,   5   ,   3   ,   25  ,   49  ,   55  ,   119 ,   171 ,   213 ,0 };
            const std::uint32_t dim107Kuo2Init[]        =   {   1   ,   3   ,   3   ,   13  ,   21  ,   35  ,   73  ,   33  ,   43  ,   673 ,0 };
            const std::uint32_t dim108Kuo2Init[]        =   {   1   ,   3   ,   5   ,   7   ,   25  ,   5   ,   7   ,   93  ,   485 ,   635 ,0 };
            const std::uint32_t dim109Kuo2Init[]        =   {   1   ,   1   ,   5   ,   1   ,   5   ,   55  ,   17  ,   33  ,   67  ,   553 ,0 };
            const std::uint32_t dim110Kuo2Init[]        =   {   1   ,   1   ,   7   ,   1   ,   15  ,   31  ,   67  ,   219 ,   241 ,   233 ,0 };
            const std::uint32_t dim111Kuo2Init[]        =   {   1   ,   1   ,   3   ,   7   ,   9   ,   33  ,   77  ,   115 ,   401 ,   617 ,0 };
            const std::uint32_t dim112Kuo2Init[]        =   {   1   ,   1   ,   3   ,   3   ,   1   ,   11  ,   79  ,   49  ,   327 ,   287 ,0 };
            const std::uint32_t dim113Kuo2Init[]        =   {   1   ,   3   ,   5   ,   15  ,   19  ,   49  ,   115 ,   73  ,   193 ,   615 ,0 };
            const std::uint32_t dim114Kuo2Init[]        =   {   1   ,   3   ,   5   ,   13  ,   15  ,   41  ,   17  ,   133 ,   369 ,   783 ,0 };
            const std::uint32_t dim115Kuo2Init[]        =   {   1   ,   1   ,   7   ,   13  ,   9   ,   15  ,   59  ,   43  ,   129 ,   337 ,0 };
            const std::uint32_t dim116Kuo2Init[]        =   {   1   ,   1   ,   3   ,   11  ,   13  ,   41  ,   35  ,   111 ,   385 ,   243 ,0 };
            const std::uint32_t dim117Kuo2Init[]        =   {   1   ,   3   ,   5   ,   11  ,   7   ,   25  ,   79  ,   9   ,   5   ,   159 ,0 };
            const std::uint32_t dim118Kuo2Init[]        =   {   1   ,   3   ,   3   ,   1   ,   7   ,   17  ,   31  ,   3   ,   27  ,   829 ,0 };
            const std::uint32_t dim119Kuo2Init[]        =   {   1   ,   3   ,   3   ,   15  ,   27  ,   33  ,   13  ,   29  ,   223 ,   545 ,0 };
            const std::uint32_t dim120Kuo2Init[]        =   {   1   ,   1   ,   5   ,   1   ,   7   ,   7   ,   31  ,   103 ,   307 ,   315 ,0 };
            const std::uint32_t dim121Kuo2Init[]        =   {   1   ,   3   ,   7   ,   9   ,   15  ,   9   ,   61  ,   75  ,   99  ,   173 ,0 };
            const std::uint32_t dim122Kuo2Init[]        =   {   1   ,   3   ,   3   ,   15  ,   21  ,   31  ,   49  ,   45  ,   301 ,   593 ,0 };
            const std::uint32_t dim123Kuo2Init[]        =   {   1   ,   3   ,   1   ,   11  ,   3   ,   1   ,   37  ,   109 ,   413 ,   517 ,0 };
            const std::uint32_t dim124Kuo2Init[]        =   {   1   ,   3   ,   1   ,   15  ,   1   ,   47  ,   45  ,   189 ,   331 ,   3   ,0 };
            const std::uint32_t dim125Kuo2Init[]        =   {   1   ,   3   ,   7   ,   5   ,   3   ,   47  ,   107 ,   141 ,   257 ,   189 ,0 };
            const std::uint32_t dim126Kuo2Init[]        =   {   1   ,   1   ,   1   ,   11  ,   5   ,   31  ,   49  ,   35  ,   139 ,   895 ,0 };
            const std::uint32_t dim127Kuo2Init[]        =   {   1   ,   3   ,   3   ,   7   ,   17  ,   23  ,   47  ,   229 ,   225 ,   393 ,0 };
            const std::uint32_t dim128Kuo2Init[]        =   {   1   ,   1   ,   1   ,   11  ,   17  ,   39  ,   125 ,   223 ,   251 ,   95  ,0 };
            const std::uint32_t dim129Kuo2Init[]        =   {   1   ,   3   ,   7   ,   9   ,   31  ,   1   ,   29  ,   81  ,   301 ,   309 ,0 };
            const std::uint32_t dim130Kuo2Init[]        =   {   1   ,   1   ,   1   ,   5   ,   29  ,   3   ,   5   ,   7   ,   481 ,   989 ,0 };
            const std::uint32_t dim131Kuo2Init[]        =   {   1   ,   1   ,   1   ,   5   ,   19  ,   29  ,   103 ,   103 ,   385 ,   541 ,0 };
            const std::uint32_t dim132Kuo2Init[]        =   {   1   ,   3   ,   7   ,   13  ,   31  ,   53  ,   27  ,   51  ,   305 ,   345 ,0 };
            const std::uint32_t dim133Kuo2Init[]        =   {   1   ,   3   ,   5   ,   5   ,   19  ,   51  ,   41  ,   15  ,   31  ,   761 ,0 };
            const std::uint32_t dim134Kuo2Init[]        =   {   1   ,   1   ,   5   ,   3   ,   25  ,   21  ,   93  ,   205 ,   129 ,   179 ,0 };
            const std::uint32_t dim135Kuo2Init[]        =   {   1   ,   3   ,   7   ,   11  ,   5   ,   31  ,   29  ,   143 ,   103 ,   227 ,0 };
            const std::uint32_t dim136Kuo2Init[]        =   {   1   ,   3   ,   1   ,   11  ,   29  ,   47  ,   97  ,   217 ,   13  ,   897 ,0 };
            const std::uint32_t dim137Kuo2Init[]        =   {   1   ,   1   ,   3   ,   13  ,   15  ,   39  ,   85  ,   181 ,   471 ,   853 ,0 };
            const std::uint32_t dim138Kuo2Init[]        =   {   1   ,   3   ,   1   ,   11  ,   11  ,   21  ,   5   ,   233 ,   415 ,   897 ,0 };
            const std::uint32_t dim139Kuo2Init[]        =   {   1   ,   1   ,   5   ,   7   ,   3   ,   19  ,   103 ,   27  ,   353 ,   775 ,0 };
            const std::uint32_t dim140Kuo2Init[]        =   {   1   ,   3   ,   3   ,   1   ,   21  ,   57  ,   123 ,   27  ,   61  ,   719 ,0 };
            const std::uint32_t dim141Kuo2Init[]        =   {   1   ,   1   ,   3   ,   13  ,   5   ,   57  ,   87  ,   77  ,   301 ,   633 ,0 };
            const std::uint32_t dim142Kuo2Init[]        =   {   1   ,   3   ,   7   ,   5   ,   21  ,   59  ,   19  ,   177 ,   147 ,   357 ,0 };
            const std::uint32_t dim143Kuo2Init[]        =   {   1   ,   1   ,   5   ,   1   ,   5   ,   57  ,   43  ,   249 ,   475 ,   189 ,0 };
            const std::uint32_t dim144Kuo2Init[]        =   {   1   ,   3   ,   7   ,   9   ,   15  ,   49  ,   29  ,   75  ,   75  ,   839 ,0 };
            const std::uint32_t dim145Kuo2Init[]        =   {   1   ,   1   ,   3   ,   7   ,   23  ,   47  ,   17  ,   83  ,   275 ,   917 ,0 };
            const std::uint32_t dim146Kuo2Init[]        =   {   1   ,   3   ,   7   ,   1   ,   23  ,   17  ,   35  ,   237 ,   357 ,   363 ,0 };
            const std::uint32_t dim147Kuo2Init[]        =   {   1   ,   1   ,   3   ,   1   ,   17  ,   35  ,   85  ,   215 ,   405 ,   469 ,0 };
            const std::uint32_t dim148Kuo2Init[]        =   {   1   ,   3   ,   1   ,   9   ,   21  ,   21  ,   103 ,   205 ,   79  ,   431 ,0 };
            const std::uint32_t dim149Kuo2Init[]        =   {   1   ,   1   ,   3   ,   1   ,   7   ,   13  ,   127 ,   233 ,   93  ,   215 ,0 };
            const std::uint32_t dim150Kuo2Init[]        =   {   1   ,   3   ,   1   ,   11  ,   13  ,   19  ,   87  ,   219 ,   49  ,   133 ,0 };
            const std::uint32_t dim151Kuo2Init[]        =   {   1   ,   3   ,   7   ,   3   ,   27  ,   51  ,   125 ,   235 ,   159 ,   981 ,0 };
            const std::uint32_t dim152Kuo2Init[]        =   {   1   ,   1   ,   3   ,   7   ,   29  ,   37  ,   3   ,   189 ,   419 ,   329 ,0 };
            const std::uint32_t dim153Kuo2Init[]        =   {   1   ,   1   ,   5   ,   13  ,   9   ,   61  ,   125 ,   29  ,   111 ,   751 ,0 };
            const std::uint32_t dim154Kuo2Init[]        =   {   1   ,   1   ,   3   ,   5   ,   5   ,   43  ,   59  ,   15  ,   445 ,   803 ,0 };
            const std::uint32_t dim155Kuo2Init[]        =   {   1   ,   1   ,   7   ,   15  ,   25  ,   55  ,   37  ,   231 ,   287 ,   97  ,0 };
            const std::uint32_t dim156Kuo2Init[]        =   {   1   ,   1   ,   1   ,   1   ,   13  ,   5   ,   97  ,   25  ,   53  ,   579 ,0 };
            const std::uint32_t dim157Kuo2Init[]        =   {   1   ,   3   ,   5   ,   13  ,   27  ,   63  ,   17  ,   197 ,   285 ,   741 ,0 };
            const std::uint32_t dim158Kuo2Init[]        =   {   1   ,   1   ,   5   ,   3   ,   7   ,   31  ,   13  ,   167 ,   235 ,   965 ,0 };
            const std::uint32_t dim159Kuo2Init[]        =   {   1   ,   3   ,   5   ,   7   ,   3   ,   35  ,   97  ,   131 ,   89  ,   313 ,0 };
            const std::uint32_t dim160Kuo2Init[]        =   {   1   ,   1   ,   3   ,   13  ,   23  ,   3   ,   91  ,   155 ,   249 ,   829 ,0 };
            const std::uint32_t dim161Kuo2Init[]        =   {   1   ,   3   ,   7   ,   13  ,   1   ,   41  ,   51  ,   233 ,   233 ,   163 ,   1357    ,0 };
            const std::uint32_t dim162Kuo2Init[]        =   {   1   ,   3   ,   1   ,   3   ,   13  ,   3   ,   55  ,   9   ,   511 ,   441 ,   811 ,0 };
            const std::uint32_t dim163Kuo2Init[]        =   {   1   ,   3   ,   5   ,   5   ,   11  ,   57  ,   45  ,   65  ,   397 ,   199 ,   1195    ,0 };
            const std::uint32_t dim164Kuo2Init[]        =   {   1   ,   3   ,   5   ,   11  ,   11  ,   15  ,   95  ,   163 ,   319 ,   727 ,   1793    ,0 };
            const std::uint32_t dim165Kuo2Init[]        =   {   1   ,   1   ,   5   ,   7   ,   31  ,   47  ,   49  ,   177 ,   229 ,   719 ,   241 ,0 };
            const std::uint32_t dim166Kuo2Init[]        =   {   1   ,   3   ,   1   ,   13  ,   9   ,   25  ,   69  ,   67  ,   151 ,   369 ,   1205    ,0 };
            const std::uint32_t dim167Kuo2Init[]        =   {   1   ,   1   ,   7   ,   3   ,   9   ,   39  ,   99  ,   109 ,   111 ,   787 ,   181 ,0 };
            const std::uint32_t dim168Kuo2Init[]        =   {   1   ,   1   ,   3   ,   11  ,   23  ,   1   ,   49  ,   111 ,   45  ,   293 ,   1603    ,0 };
            const std::uint32_t dim169Kuo2Init[]        =   {   1   ,   1   ,   1   ,   3   ,   5   ,   45  ,   11  ,   197 ,   357 ,   109 ,   1291    ,0 };
            const std::uint32_t dim170Kuo2Init[]        =   {   1   ,   3   ,   5   ,   11  ,   5   ,   25  ,   91  ,   91  ,   339 ,   559 ,   311 ,0 };
            const std::uint32_t dim171Kuo2Init[]        =   {   1   ,   3   ,   3   ,   3   ,   21  ,   37  ,   69  ,   129 ,   205 ,   333 ,   165 ,0 };
            const std::uint32_t dim172Kuo2Init[]        =   {   1   ,   1   ,   1   ,   15  ,   9   ,   19  ,   115 ,   153 ,   23  ,   381 ,   1727    ,0 };
            const std::uint32_t dim173Kuo2Init[]        =   {   1   ,   1   ,   3   ,   1   ,   3   ,   35  ,   77  ,   217 ,   133 ,   943 ,   169 ,0 };
            const std::uint32_t dim174Kuo2Init[]        =   {   1   ,   1   ,   5   ,   9   ,   1   ,   39  ,   67  ,   217 ,   143 ,   529 ,   769 ,0 };
            const std::uint32_t dim175Kuo2Init[]        =   {   1   ,   1   ,   3   ,   3   ,   9   ,   9   ,   9   ,   203 ,   425 ,   601 ,   1389    ,0 };
            const std::uint32_t dim176Kuo2Init[]        =   {   1   ,   3   ,   7   ,   3   ,   15  ,   19  ,   109 ,   31  ,   417 ,   127 ,   1109    ,0 };
            const std::uint32_t dim177Kuo2Init[]        =   {   1   ,   3   ,   1   ,   15  ,   1   ,   37  ,   75  ,   199 ,   419 ,   917 ,   1929    ,0 };
            const std::uint32_t dim178Kuo2Init[]        =   {   1   ,   3   ,   3   ,   9   ,   21  ,   37  ,   23  ,   165 ,   67  ,   39  ,   1685    ,0 };
            const std::uint32_t dim179Kuo2Init[]        =   {   1   ,   3   ,   3   ,   7   ,   3   ,   25  ,   75  ,   67  ,   451 ,   889 ,   1015    ,0 };
            const std::uint32_t dim180Kuo2Init[]        =   {   1   ,   3   ,   1   ,   1   ,   27  ,   37  ,   39  ,   7   ,   411 ,   391 ,   463 ,0 };
            const std::uint32_t dim181Kuo2Init[]        =   {   1   ,   1   ,   7   ,   15  ,   25  ,   19  ,   55  ,   131 ,   245 ,   887 ,   971 ,0 };
            const std::uint32_t dim182Kuo2Init[]        =   {   1   ,   3   ,   1   ,   9   ,   19  ,   9   ,   9   ,   31  ,   143 ,   647 ,   39  ,0 };
            const std::uint32_t dim183Kuo2Init[]        =   {   1   ,   3   ,   7   ,   1   ,   27  ,   7   ,   107 ,   179 ,   327 ,   947 ,   953 ,0 };
            const std::uint32_t dim184Kuo2Init[]        =   {   1   ,   3   ,   7   ,   13  ,   23  ,   31  ,   65  ,   29  ,   157 ,   67  ,   2009    ,0 };
            const std::uint32_t dim185Kuo2Init[]        =   {   1   ,   3   ,   5   ,   13  ,   19  ,   31  ,   19  ,   249 ,   385 ,   209 ,   281 ,0 };
            const std::uint32_t dim186Kuo2Init[]        =   {   1   ,   1   ,   7   ,   15  ,   3   ,   63  ,   1   ,   97  ,   349 ,   1007    ,   1463    ,0 };
            const std::uint32_t dim187Kuo2Init[]        =   {   1   ,   3   ,   3   ,   11  ,   25  ,   3   ,   21  ,   195 ,   213 ,   1013    ,   637 ,0 };
            const std::uint32_t dim188Kuo2Init[]        =   {   1   ,   3   ,   1   ,   1   ,   27  ,   7   ,   95  ,   215 ,   473 ,   1023    ,   231 ,0 };
            const std::uint32_t dim189Kuo2Init[]        =   {   1   ,   3   ,   3   ,   11  ,   15  ,   15  ,   45  ,   55  ,   63  ,   693 ,   845 ,0 };
            const std::uint32_t dim190Kuo2Init[]        =   {   1   ,   1   ,   3   ,   1   ,   27  ,   3   ,   63  ,   139 ,   139 ,   729 ,   861 ,0 };
            const std::uint32_t dim191Kuo2Init[]        =   {   1   ,   1   ,   5   ,   3   ,   31  ,   37  ,   125 ,   175 ,   311 ,   951 ,   1745    ,0 };
            const std::uint32_t dim192Kuo2Init[]        =   {   1   ,   1   ,   1   ,   11  ,   1   ,   19  ,   7   ,   203 ,   301 ,   403 ,   1293    ,0 };
            const std::uint32_t dim193Kuo2Init[]        =   {   1   ,   3   ,   1   ,   5   ,   13  ,   39  ,   27  ,   155 ,   27  ,   725 ,   993 ,0 };
            const std::uint32_t dim194Kuo2Init[]        =   {   1   ,   3   ,   5   ,   1   ,   5   ,   57  ,   19  ,   225 ,   407 ,   713 ,   1687    ,0 };
            const std::uint32_t dim195Kuo2Init[]        =   {   1   ,   1   ,   1   ,   1   ,   29  ,   23  ,   83  ,   191 ,   469 ,   105 ,   311 ,0 };
            const std::uint32_t dim196Kuo2Init[]        =   {   1   ,   1   ,   1   ,   11  ,   5   ,   17  ,   111 ,   5   ,   395 ,   183 ,   1167    ,0 };
            const std::uint32_t dim197Kuo2Init[]        =   {   1   ,   3   ,   1   ,   9   ,   1   ,   41  ,   3   ,   49  ,   253 ,   735 ,   693 ,0 };
            const std::uint32_t dim198Kuo2Init[]        =   {   1   ,   1   ,   5   ,   3   ,   21  ,   11  ,   43  ,   33  ,   225 ,   291 ,   1581    ,0 };
            const std::uint32_t dim199Kuo2Init[]        =   {   1   ,   1   ,   1   ,   1   ,   5   ,   29  ,   43  ,   85  ,   465 ,   879 ,   1161    ,0 };
            const std::uint32_t dim200Kuo2Init[]        =   {   1   ,   3   ,   1   ,   7   ,   11  ,   43  ,   61  ,   41  ,   287 ,   655 ,   1417    ,0 };
            const std::uint32_t dim201Kuo2Init[]        =   {   1   ,   3   ,   1   ,   15  ,   21  ,   13  ,   85  ,   69  ,   353 ,   1005    ,   1109    ,0 };
            const std::uint32_t dim202Kuo2Init[]        =   {   1   ,   1   ,   7   ,   1   ,   3   ,   29  ,   115 ,   227 ,   473 ,   877 ,   443 ,0 };
            const std::uint32_t dim203Kuo2Init[]        =   {   1   ,   3   ,   3   ,   13  ,   13  ,   57  ,   95  ,   91  ,   473 ,   667 ,   1551    ,0 };
            const std::uint32_t dim204Kuo2Init[]        =   {   1   ,   3   ,   3   ,   3   ,   13  ,   5   ,   45  ,   219 ,   371 ,   843 ,   95  ,0 };
            const std::uint32_t dim205Kuo2Init[]        =   {   1   ,   3   ,   7   ,   1   ,   17  ,   45  ,   93  ,   63  ,   235 ,   37  ,   1081    ,0 };
            const std::uint32_t dim206Kuo2Init[]        =   {   1   ,   3   ,   3   ,   1   ,   17  ,   21  ,   5   ,   91  ,   433 ,   321 ,   645 ,0 };
            const std::uint32_t dim207Kuo2Init[]        =   {   1   ,   1   ,   7   ,   11  ,   9   ,   5   ,   33  ,   189 ,   205 ,   51  ,   259 ,0 };
            const std::uint32_t dim208Kuo2Init[]        =   {   1   ,   1   ,   7   ,   3   ,   17  ,   9   ,   11  ,   235 ,   477 ,   419 ,   721 ,0 };
            const std::uint32_t dim209Kuo2Init[]        =   {   1   ,   1   ,   1   ,   15  ,   21  ,   49  ,   25  ,   103 ,   25  ,   273 ,   1159    ,0 };
            const std::uint32_t dim210Kuo2Init[]        =   {   1   ,   1   ,   1   ,   15  ,   29  ,   7   ,   97  ,   47  ,   219 ,   979 ,   961 ,0 };
            const std::uint32_t dim211Kuo2Init[]        =   {   1   ,   1   ,   7   ,   13  ,   3   ,   9   ,   103 ,   179 ,   471 ,   841 ,   1265    ,0 };
            const std::uint32_t dim212Kuo2Init[]        =   {   1   ,   1   ,   7   ,   15  ,   11  ,   33  ,   57  ,   181 ,   125 ,   307 ,   535 ,0 };
            const std::uint32_t dim213Kuo2Init[]        =   {   1   ,   1   ,   7   ,   15  ,   21  ,   27  ,   15  ,   65  ,   235 ,   45  ,   1169    ,0 };
            const std::uint32_t dim214Kuo2Init[]        =   {   1   ,   3   ,   1   ,   5   ,   9   ,   59  ,   123 ,   25  ,   391 ,   253 ,   1801    ,0 };
            const std::uint32_t dim215Kuo2Init[]        =   {   1   ,   3   ,   1   ,   1   ,   13  ,   17  ,   85  ,   207 ,   417 ,   179 ,   951 ,0 };
            const std::uint32_t dim216Kuo2Init[]        =   {   1   ,   1   ,   1   ,   15  ,   27  ,   13  ,   51  ,   169 ,   351 ,   351 ,   1255    ,0 };
            const std::uint32_t dim217Kuo2Init[]        =   {   1   ,   3   ,   7   ,   13  ,   21  ,   63  ,   93  ,   27  ,   277 ,   999 ,   1381    ,0 };
            const std::uint32_t dim218Kuo2Init[]        =   {   1   ,   1   ,   5   ,   9   ,   21  ,   11  ,   99  ,   199 ,   281 ,   281 ,   373 ,0 };
            const std::uint32_t dim219Kuo2Init[]        =   {   1   ,   1   ,   5   ,   1   ,   1   ,   41  ,   17  ,   43  ,   411 ,   315 ,   1953    ,0 };
            const std::uint32_t dim220Kuo2Init[]        =   {   1   ,   1   ,   5   ,   11  ,   25  ,   49  ,   7   ,   61  ,   359 ,   989 ,   1165    ,0 };
            const std::uint32_t dim221Kuo2Init[]        =   {   1   ,   1   ,   5   ,   1   ,   21  ,   23  ,   77  ,   51  ,   501 ,   579 ,   1969    ,0 };
            const std::uint32_t dim222Kuo2Init[]        =   {   1   ,   3   ,   7   ,   3   ,   15  ,   43  ,   89  ,   107 ,   331 ,   723 ,   771 ,0 };
            const std::uint32_t dim223Kuo2Init[]        =   {   1   ,   1   ,   3   ,   15  ,   3   ,   57  ,   41  ,   241 ,   183 ,   579 ,   1577    ,0 };
            const std::uint32_t dim224Kuo2Init[]        =   {   1   ,   3   ,   7   ,   3   ,   29  ,   31  ,   31  ,   121 ,   87  ,   1009    ,   235 ,0 };
            const std::uint32_t dim225Kuo2Init[]        =   {   1   ,   3   ,   3   ,   1   ,   25  ,   11  ,   67  ,   33  ,   275 ,   297 ,   1143    ,0 };
            const std::uint32_t dim226Kuo2Init[]        =   {   1   ,   1   ,   7   ,   13  ,   17  ,   29  ,   99  ,   39  ,   111 ,   29  ,   881 ,0 };
            const std::uint32_t dim227Kuo2Init[]        =   {   1   ,   1   ,   7   ,   1   ,   7   ,   25  ,   27  ,   107 ,   169 ,   77  ,   1037    ,0 };
            const std::uint32_t dim228Kuo2Init[]        =   {   1   ,   3   ,   1   ,   15  ,   17  ,   59  ,   105 ,   87  ,   295 ,   253 ,   1847    ,0 };
            const std::uint32_t dim229Kuo2Init[]        =   {   1   ,   1   ,   7   ,   11  ,   25  ,   57  ,   75  ,   129 ,   379 ,   95  ,   381 ,0 };
            const std::uint32_t dim230Kuo2Init[]        =   {   1   ,   1   ,   7   ,   11  ,   19  ,   51  ,   69  ,   23  ,   443 ,   89  ,   1245    ,0 };
            const std::uint32_t dim231Kuo2Init[]        =   {   1   ,   3   ,   7   ,   15  ,   3   ,   43  ,   71  ,   173 ,   435 ,   125 ,   1039    ,0 };
            const std::uint32_t dim232Kuo2Init[]        =   {   1   ,   1   ,   1   ,   13  ,   27  ,   37  ,   101 ,   97  ,   201 ,   187 ,   243 ,0 };
            const std::uint32_t dim233Kuo2Init[]        =   {   1   ,   1   ,   3   ,   15  ,   13  ,   37  ,   11  ,   81  ,   233 ,   701 ,   1629    ,0 };
            const std::uint32_t dim234Kuo2Init[]        =   {   1   ,   1   ,   3   ,   11  ,   21  ,   43  ,   37  ,   233 ,   129 ,   281 ,   511 ,0 };
            const std::uint32_t dim235Kuo2Init[]        =   {   1   ,   3   ,   7   ,   3   ,   17  ,   7   ,   89  ,   19  ,   59  ,   339 ,   337 ,0 };
            const std::uint32_t dim236Kuo2Init[]        =   {   1   ,   3   ,   7   ,   13  ,   27  ,   31  ,   97  ,   197 ,   485 ,   367 ,   1169    ,0 };
            const std::uint32_t dim237Kuo2Init[]        =   {   1   ,   1   ,   7   ,   13  ,   9   ,   5   ,   93  ,   93  ,   289 ,   79  ,   57  ,0 };
            const std::uint32_t dim238Kuo2Init[]        =   {   1   ,   3   ,   5   ,   13  ,   23  ,   61  ,   99  ,   201 ,   115 ,   583 ,   1271    ,0 };
            const std::uint32_t dim239Kuo2Init[]        =   {   1   ,   3   ,   3   ,   15  ,   9   ,   55  ,   1   ,   197 ,   149 ,   919 ,   805 ,0 };
            const std::uint32_t dim240Kuo2Init[]        =   {   1   ,   1   ,   1   ,   5   ,   29  ,   43  ,   119 ,   55  ,   397 ,   973 ,   1843    ,0 };
            const std::uint32_t dim241Kuo2Init[]        =   {   1   ,   3   ,   1   ,   1   ,   5   ,   55  ,   99  ,   223 ,   323 ,   543 ,   1851    ,0 };
            const std::uint32_t dim242Kuo2Init[]        =   {   1   ,   1   ,   1   ,   15  ,   1   ,   31  ,   17  ,   107 ,   303 ,   675 ,   1093    ,0 };
            const std::uint32_t dim243Kuo2Init[]        =   {   1   ,   1   ,   5   ,   11  ,   9   ,   19  ,   61  ,   123 ,   411 ,   65  ,   317 ,0 };
            const std::uint32_t dim244Kuo2Init[]        =   {   1   ,   3   ,   5   ,   5   ,   9   ,   15  ,   35  ,   181 ,   467 ,   289 ,   85  ,0 };
            const std::uint32_t dim245Kuo2Init[]        =   {   1   ,   1   ,   1   ,   13  ,   19  ,   59  ,   75  ,   167 ,   507 ,   249 ,   259 ,0 };
            const std::uint32_t dim246Kuo2Init[]        =   {   1   ,   3   ,   5   ,   3   ,   13  ,   7   ,   53  ,   87  ,   97  ,   667 ,   1493    ,0 };
            const std::uint32_t dim247Kuo2Init[]        =   {   1   ,   1   ,   7   ,   1   ,   17  ,   35  ,   109 ,   21  ,   437 ,   225 ,   155 ,0 };
            const std::uint32_t dim248Kuo2Init[]        =   {   1   ,   3   ,   7   ,   11  ,   3   ,   25  ,   51  ,   29  ,   499 ,   987 ,   223 ,0 };
            const std::uint32_t dim249Kuo2Init[]        =   {   1   ,   1   ,   7   ,   7   ,   23  ,   57  ,   13  ,   23  ,   335 ,   627 ,   887 ,0 };
            const std::uint32_t dim250Kuo2Init[]        =   {   1   ,   1   ,   7   ,   3   ,   15  ,   45  ,   89  ,   217 ,   393 ,   235 ,   969 ,0 };
            const std::uint32_t dim251Kuo2Init[]        =   {   1   ,   3   ,   3   ,   7   ,   19  ,   47  ,   1   ,   193 ,   229 ,   45  ,   1617    ,0 };
            const std::uint32_t dim252Kuo2Init[]        =   {   1   ,   3   ,   1   ,   9   ,   29  ,   63  ,   15  ,   57  ,   509 ,   147 ,   323 ,0 };
            const std::uint32_t dim253Kuo2Init[]        =   {   1   ,   3   ,   5   ,   9   ,   9   ,   33  ,   77  ,   83  ,   109 ,   335 ,   481 ,0 };
            const std::uint32_t dim254Kuo2Init[]        =   {   1   ,   1   ,   3   ,   1   ,   7   ,   47  ,   69  ,   3   ,   23  ,   243 ,   1787    ,0 };
            const std::uint32_t dim255Kuo2Init[]        =   {   1   ,   3   ,   7   ,   7   ,   7   ,   13  ,   77  ,   211 ,   349 ,   383 ,   1793    ,0 };
            const std::uint32_t dim256Kuo2Init[]        =   {   1   ,   1   ,   5   ,   11  ,   9   ,   9   ,   1   ,   173 ,   263 ,   965 ,   993 ,0 };
            const std::uint32_t dim257Kuo2Init[]        =   {   1   ,   3   ,   3   ,   1   ,   11  ,   57  ,   85  ,   1   ,   293 ,   921 ,   1711    ,0 };
            const std::uint32_t dim258Kuo2Init[]        =   {   1   ,   3   ,   3   ,   13  ,   29  ,   25  ,   13  ,   143 ,   373 ,   575 ,   1985    ,0 };
            const std::uint32_t dim259Kuo2Init[]        =   {   1   ,   3   ,   1   ,   13  ,   1   ,   9   ,   71  ,   135 ,   117 ,   989 ,   1331    ,0 };
            const std::uint32_t dim260Kuo2Init[]        =   {   1   ,   3   ,   3   ,   13  ,   29  ,   21  ,   47  ,   225 ,   199 ,   107 ,   117 ,0 };
            const std::uint32_t dim261Kuo2Init[]        =   {   1   ,   1   ,   7   ,   13  ,   25  ,   5   ,   57  ,   135 ,   397 ,   411 ,   1275    ,0 };
            const std::uint32_t dim262Kuo2Init[]        =   {   1   ,   1   ,   3   ,   1   ,   11  ,   19  ,   39  ,   9   ,   165 ,   813 ,   871 ,0 };
            const std::uint32_t dim263Kuo2Init[]        =   {   1   ,   3   ,   1   ,   11  ,   29  ,   1   ,   71  ,   35  ,   361 ,   331 ,   773 ,0 };
            const std::uint32_t dim264Kuo2Init[]        =   {   1   ,   1   ,   3   ,   9   ,   23  ,   23  ,   73  ,   7   ,   505 ,   183 ,   563 ,0 };
            const std::uint32_t dim265Kuo2Init[]        =   {   1   ,   3   ,   5   ,   9   ,   25  ,   35  ,   123 ,   111 ,   221 ,   1   ,   873 ,0 };
            const std::uint32_t dim266Kuo2Init[]        =   {   1   ,   1   ,   3   ,   3   ,   15  ,   43  ,   53  ,   71  ,   339 ,   321 ,   1973    ,0 };
            const std::uint32_t dim267Kuo2Init[]        =   {   1   ,   1   ,   5   ,   13  ,   13  ,   57  ,   27  ,   151 ,   337 ,   739 ,   1205    ,0 };
            const std::uint32_t dim268Kuo2Init[]        =   {   1   ,   3   ,   5   ,   13  ,   23  ,   3   ,   111 ,   101 ,   37  ,   523 ,   659 ,0 };
            const std::uint32_t dim269Kuo2Init[]        =   {   1   ,   3   ,   5   ,   13  ,   23  ,   53  ,   53  ,   91  ,   505 ,   779 ,   759 ,0 };
            const std::uint32_t dim270Kuo2Init[]        =   {   1   ,   1   ,   5   ,   7   ,   21  ,   43  ,   91  ,   213 ,   163 ,   29  ,   137 ,0 };
            const std::uint32_t dim271Kuo2Init[]        =   {   1   ,   1   ,   1   ,   3   ,   21  ,   37  ,   97  ,   241 ,   77  ,   169 ,   1255    ,0 };
            const std::uint32_t dim272Kuo2Init[]        =   {   1   ,   3   ,   3   ,   1   ,   5   ,   31  ,   119 ,   127 ,   137 ,   915 ,   1705    ,0 };
            const std::uint32_t dim273Kuo2Init[]        =   {   1   ,   3   ,   3   ,   13  ,   5   ,   47  ,   117 ,   171 ,   67  ,   285 ,   225 ,0 };
            const std::uint32_t dim274Kuo2Init[]        =   {   1   ,   1   ,   7   ,   9   ,   3   ,   35  ,   25  ,   25  ,   147 ,   537 ,   1703    ,0 };
            const std::uint32_t dim275Kuo2Init[]        =   {   1   ,   3   ,   5   ,   3   ,   27  ,   41  ,   57  ,   71  ,   383 ,   763 ,   431 ,0 };
            const std::uint32_t dim276Kuo2Init[]        =   {   1   ,   3   ,   3   ,   1   ,   17  ,   9   ,   105 ,   119 ,   243 ,   459 ,   881 ,0 };
            const std::uint32_t dim277Kuo2Init[]        =   {   1   ,   3   ,   5   ,   15  ,   13  ,   45  ,   49  ,   41  ,   117 ,   473 ,   1701    ,0 };
            const std::uint32_t dim278Kuo2Init[]        =   {   1   ,   1   ,   3   ,   11  ,   13  ,   5   ,   77  ,   17  ,   11  ,   1019    ,   353 ,0 };
            const std::uint32_t dim279Kuo2Init[]        =   {   1   ,   3   ,   1   ,   11  ,   31  ,   35  ,   87  ,   195 ,   371 ,   169 ,   1075    ,0 };
            const std::uint32_t dim280Kuo2Init[]        =   {   1   ,   3   ,   5   ,   1   ,   1   ,   1   ,   65  ,   177 ,   35  ,   497 ,   103 ,0 };
            const std::uint32_t dim281Kuo2Init[]        =   {   1   ,   1   ,   3   ,   1   ,   31  ,   21  ,   77  ,   153 ,   139 ,   663 ,   443 ,0 };
            const std::uint32_t dim282Kuo2Init[]        =   {   1   ,   1   ,   1   ,   1   ,   31  ,   25  ,   21  ,   87  ,   345 ,   13  ,   301 ,0 };
            const std::uint32_t dim283Kuo2Init[]        =   {   1   ,   1   ,   1   ,   7   ,   7   ,   1   ,   95  ,   5   ,   429 ,   551 ,   1011    ,0 };
            const std::uint32_t dim284Kuo2Init[]        =   {   1   ,   3   ,   5   ,   15  ,   23  ,   63  ,   119 ,   185 ,   463 ,   371 ,   567 ,0 };
            const std::uint32_t dim285Kuo2Init[]        =   {   1   ,   1   ,   5   ,   5   ,   21  ,   21  ,   33  ,   141 ,   181 ,   885 ,   717 ,0 };
            const std::uint32_t dim286Kuo2Init[]        =   {   1   ,   1   ,   1   ,   5   ,   11  ,   35  ,   37  ,   231 ,   67  ,   951 ,   1721    ,0 };
            const std::uint32_t dim287Kuo2Init[]        =   {   1   ,   3   ,   7   ,   9   ,   13  ,   29  ,   113 ,   55  ,   27  ,   625 ,   285 ,0 };
            const std::uint32_t dim288Kuo2Init[]        =   {   1   ,   1   ,   7   ,   5   ,   19  ,   45  ,   5   ,   233 ,   133 ,   401 ,   99  ,0 };
            const std::uint32_t dim289Kuo2Init[]        =   {   1   ,   1   ,   5   ,   1   ,   7   ,   49  ,   127 ,   173 ,   187 ,   513 ,   171 ,0 };
            const std::uint32_t dim290Kuo2Init[]        =   {   1   ,   1   ,   7   ,   3   ,   17  ,   59  ,   51  ,   81  ,   197 ,   1021    ,   763 ,0 };
            const std::uint32_t dim291Kuo2Init[]        =   {   1   ,   1   ,   3   ,   1   ,   9   ,   51  ,   31  ,   149 ,   397 ,   929 ,   81  ,0 };
            const std::uint32_t dim292Kuo2Init[]        =   {   1   ,   1   ,   7   ,   9   ,   29  ,   29  ,   21  ,   191 ,   107 ,   9   ,   807 ,0 };
            const std::uint32_t dim293Kuo2Init[]        =   {   1   ,   1   ,   5   ,   3   ,   15  ,   3   ,   125 ,   105 ,   225 ,   571 ,   33  ,0 };
            const std::uint32_t dim294Kuo2Init[]        =   {   1   ,   1   ,   5   ,   15  ,   31  ,   61  ,   113 ,   7   ,   59  ,   829 ,   1259    ,0 };
            const std::uint32_t dim295Kuo2Init[]        =   {   1   ,   3   ,   1   ,   5   ,   29  ,   27  ,   33  ,   145 ,   211 ,   837 ,   749 ,0 };
            const std::uint32_t dim296Kuo2Init[]        =   {   1   ,   1   ,   1   ,   1   ,   27  ,   15  ,   25  ,   197 ,   51  ,   71  ,   813 ,0 };
            const std::uint32_t dim297Kuo2Init[]        =   {   1   ,   1   ,   1   ,   3   ,   27  ,   59  ,   1   ,   163 ,   467 ,   991 ,   1489    ,0 };
            const std::uint32_t dim298Kuo2Init[]        =   {   1   ,   3   ,   3   ,   13  ,   1   ,   27  ,   105 ,   225 ,   403 ,   803 ,   409 ,0 };
            const std::uint32_t dim299Kuo2Init[]        =   {   1   ,   1   ,   5   ,   3   ,   7   ,   31  ,   99  ,   55  ,   275 ,   487 ,   983 ,0 };
            const std::uint32_t dim300Kuo2Init[]        =   {   1   ,   1   ,   1   ,   5   ,   27  ,   63  ,   107 ,   161 ,   491 ,   887 ,   825 ,0 };
            const std::uint32_t dim301Kuo2Init[]        =   {   1   ,   1   ,   5   ,   15  ,   15  ,   19  ,   87  ,   165 ,   55  ,   477 ,   1641    ,0 };
            const std::uint32_t dim302Kuo2Init[]        =   {   1   ,   3   ,   5   ,   7   ,   21  ,   49  ,   105 ,   151 ,   251 ,   385 ,   1265    ,0 };
            const std::uint32_t dim303Kuo2Init[]        =   {   1   ,   1   ,   5   ,   3   ,   5   ,   43  ,   47  ,   213 ,   387 ,   523 ,   1547    ,0 };
            const std::uint32_t dim304Kuo2Init[]        =   {   1   ,   3   ,   1   ,   11  ,   15  ,   55  ,   93  ,   167 ,   377 ,   201 ,   1031    ,0 };
            const std::uint32_t dim305Kuo2Init[]        =   {   1   ,   1   ,   7   ,   7   ,   9   ,   27  ,   35  ,   251 ,   425 ,   27  ,   1527    ,0 };
            const std::uint32_t dim306Kuo2Init[]        =   {   1   ,   1   ,   7   ,   7   ,   15  ,   55  ,   123 ,   21  ,   53  ,   77  ,   345 ,0 };
            const std::uint32_t dim307Kuo2Init[]        =   {   1   ,   1   ,   5   ,   15  ,   13  ,   11  ,   75  ,   101 ,   75  ,   217 ,   219 ,0 };
            const std::uint32_t dim308Kuo2Init[]        =   {   1   ,   1   ,   3   ,   9   ,   1   ,   29  ,   117 ,   209 ,   301 ,   803 ,   1487    ,0 };
            const std::uint32_t dim309Kuo2Init[]        =   {   1   ,   3   ,   5   ,   3   ,   31  ,   57  ,   63  ,   171 ,   59  ,   591 ,   1323    ,0 };
            const std::uint32_t dim310Kuo2Init[]        =   {   1   ,   3   ,   7   ,   11  ,   19  ,   27  ,   111 ,   87  ,   439 ,   1023    ,   691 ,0 };
            const std::uint32_t dim311Kuo2Init[]        =   {   1   ,   3   ,   7   ,   13  ,   15  ,   57  ,   11  ,   249 ,   383 ,   291 ,   1221    ,0 };
            const std::uint32_t dim312Kuo2Init[]        =   {   1   ,   1   ,   3   ,   13  ,   23  ,   43  ,   31  ,   75  ,   293 ,   701 ,   1065    ,0 };
            const std::uint32_t dim313Kuo2Init[]        =   {   1   ,   1   ,   5   ,   5   ,   9   ,   53  ,   115 ,   235 ,   389 ,   907 ,   1883    ,0 };
            const std::uint32_t dim314Kuo2Init[]        =   {   1   ,   1   ,   1   ,   11  ,   17  ,   31  ,   111 ,   187 ,   483 ,   323 ,   307 ,0 };
            const std::uint32_t dim315Kuo2Init[]        =   {   1   ,   1   ,   3   ,   1   ,   23  ,   33  ,   25  ,   27  ,   267 ,   231 ,   467 ,0 };
            const std::uint32_t dim316Kuo2Init[]        =   {   1   ,   3   ,   1   ,   1   ,   29  ,   15  ,   1   ,   151 ,   369 ,   943 ,   1293    ,0 };
            const std::uint32_t dim317Kuo2Init[]        =   {   1   ,   1   ,   1   ,   15  ,   31  ,   9   ,   1   ,   223 ,   7   ,   99  ,   1725    ,0 };
            const std::uint32_t dim318Kuo2Init[]        =   {   1   ,   1   ,   1   ,   1   ,   13  ,   3   ,   103 ,   177 ,   61  ,   939 ,   1321    ,0 };
            const std::uint32_t dim319Kuo2Init[]        =   {   1   ,   3   ,   3   ,   7   ,   29  ,   45  ,   63  ,   119 ,   467 ,   1011    ,   1687    ,0 };
            const std::uint32_t dim320Kuo2Init[]        =   {   1   ,   3   ,   5   ,   13  ,   13  ,   51  ,   69  ,   113 ,   231 ,   807 ,   863 ,0 };
            const std::uint32_t dim321Kuo2Init[]        =   {   1   ,   1   ,   1   ,   13  ,   13  ,   57  ,   121 ,   219 ,   77  ,   959 ,   1883    ,0 };
            const std::uint32_t dim322Kuo2Init[]        =   {   1   ,   1   ,   3   ,   13  ,   25  ,   19  ,   83  ,   139 ,   31  ,   3   ,   367 ,0 };
            const std::uint32_t dim323Kuo2Init[]        =   {   1   ,   3   ,   7   ,   13  ,   19  ,   49  ,   45  ,   47  ,   197 ,   253 ,   1769    ,0 };
            const std::uint32_t dim324Kuo2Init[]        =   {   1   ,   3   ,   1   ,   5   ,   13  ,   59  ,   65  ,   23  ,   31  ,   127 ,   1693    ,0 };
            const std::uint32_t dim325Kuo2Init[]        =   {   1   ,   1   ,   7   ,   5   ,   15  ,   33  ,   85  ,   59  ,   483 ,   87  ,   1109    ,0 };
            const std::uint32_t dim326Kuo2Init[]        =   {   1   ,   1   ,   1   ,   13  ,   29  ,   39  ,   87  ,   109 ,   223 ,   927 ,   723 ,0 };
            const std::uint32_t dim327Kuo2Init[]        =   {   1   ,   1   ,   7   ,   11  ,   29  ,   19  ,   13  ,   73  ,   479 ,   989 ,   767 ,0 };
            const std::uint32_t dim328Kuo2Init[]        =   {   1   ,   3   ,   1   ,   15  ,   27  ,   33  ,   119 ,   237 ,   117 ,   181 ,   1719    ,0 };
            const std::uint32_t dim329Kuo2Init[]        =   {   1   ,   1   ,   7   ,   9   ,   1   ,   55  ,   115 ,   91  ,   355 ,   21  ,   531 ,0 };
            const std::uint32_t dim330Kuo2Init[]        =   {   1   ,   1   ,   5   ,   7   ,   29  ,   23  ,   41  ,   227 ,   455 ,   587 ,   523 ,0 };
            const std::uint32_t dim331Kuo2Init[]        =   {   1   ,   3   ,   5   ,   9   ,   31  ,   21  ,   105 ,   139 ,   69  ,   907 ,   1195    ,0 };
            const std::uint32_t dim332Kuo2Init[]        =   {   1   ,   1   ,   1   ,   13  ,   11  ,   63  ,   33  ,   161 ,   133 ,   493 ,   1055    ,0 };
            const std::uint32_t dim333Kuo2Init[]        =   {   1   ,   1   ,   7   ,   15  ,   19  ,   37  ,   37  ,   145 ,   321 ,   781 ,   575 ,0 };
            const std::uint32_t dim334Kuo2Init[]        =   {   1   ,   1   ,   5   ,   5   ,   29  ,   17  ,   109 ,   193 ,   271 ,   831 ,   915 ,0 };
            const std::uint32_t dim335Kuo2Init[]        =   {   1   ,   3   ,   3   ,   11  ,   17  ,   63  ,   57  ,   245 ,   347 ,   647 ,   321 ,0 };
            const std::uint32_t dim336Kuo2Init[]        =   {   1   ,   3   ,   5   ,   7   ,   15  ,   15  ,   45  ,   11  ,   383 ,   231 ,   267 ,0 };
            const std::uint32_t dim337Kuo2Init[]        =   {   1   ,   3   ,   5   ,   13  ,   15  ,   45  ,   67  ,   135 ,   135 ,   247 ,   1261    ,   205 ,0 };
            const std::uint32_t dim338Kuo2Init[]        =   {   1   ,   1   ,   7   ,   5   ,   13  ,   37  ,   63  ,   179 ,   43  ,   679 ,   1127    ,   779 ,0 };
            const std::uint32_t dim339Kuo2Init[]        =   {   1   ,   3   ,   7   ,   15  ,   7   ,   11  ,   105 ,   207 ,   93  ,   127 ,   907 ,   3931    ,0 };
            const std::uint32_t dim340Kuo2Init[]        =   {   1   ,   3   ,   7   ,   3   ,   29  ,   45  ,   53  ,   91  ,   97  ,   175 ,   1847    ,   1119    ,0 };
            const std::uint32_t dim341Kuo2Init[]        =   {   1   ,   3   ,   7   ,   13  ,   29  ,   25  ,   49  ,   245 ,   39  ,   651 ,   1353    ,   481 ,0 };
            const std::uint32_t dim342Kuo2Init[]        =   {   1   ,   1   ,   5   ,   13  ,   13  ,   49  ,   119 ,   85  ,   101 ,   361 ,   1163    ,   2693    ,0 };
            const std::uint32_t dim343Kuo2Init[]        =   {   1   ,   1   ,   7   ,   11  ,   3   ,   13  ,   23  ,   95  ,   169 ,   1005    ,   1911    ,   849 ,0 };
            const std::uint32_t dim344Kuo2Init[]        =   {   1   ,   3   ,   7   ,   15  ,   1   ,   25  ,   45  ,   111 ,   3   ,   683 ,   1383    ,   1387    ,0 };
            const std::uint32_t dim345Kuo2Init[]        =   {   1   ,   3   ,   1   ,   3   ,   19  ,   37  ,   97  ,   183 ,   27  ,   971 ,   853 ,   255 ,0 };
            const std::uint32_t dim346Kuo2Init[]        =   {   1   ,   3   ,   5   ,   7   ,   7   ,   61  ,   19  ,   163 ,   161 ,   921 ,   1561    ,   841 ,0 };
            const std::uint32_t dim347Kuo2Init[]        =   {   1   ,   1   ,   3   ,   7   ,   3   ,   17  ,   43  ,   185 ,   231 ,   513 ,   1499    ,   695 ,0 };
            const std::uint32_t dim348Kuo2Init[]        =   {   1   ,   3   ,   1   ,   13  ,   27  ,   17  ,   123 ,   155 ,   13  ,   873 ,   21  ,   1687    ,0 };
            const std::uint32_t dim349Kuo2Init[]        =   {   1   ,   1   ,   5   ,   11  ,   7   ,   15  ,   83  ,   103 ,   489 ,   529 ,   1331    ,   3783    ,0 };
            const std::uint32_t dim350Kuo2Init[]        =   {   1   ,   1   ,   7   ,   13  ,   11  ,   45  ,   11  ,   105 ,   341 ,   39  ,   1697    ,   2701    ,0 };
            const std::uint32_t dim351Kuo2Init[]        =   {   1   ,   1   ,   1   ,   15  ,   1   ,   37  ,   119 ,   179 ,   471 ,   343 ,   927 ,   2469    ,0 };
            const std::uint32_t dim352Kuo2Init[]        =   {   1   ,   1   ,   3   ,   9   ,   29  ,   57  ,   59  ,   133 ,   309 ,   587 ,   1775    ,   1811    ,0 };
            const std::uint32_t dim353Kuo2Init[]        =   {   1   ,   1   ,   5   ,   15  ,   7   ,   51  ,   25  ,   151 ,   173 ,   961 ,   1449    ,   2215    ,0 };
            const std::uint32_t dim354Kuo2Init[]        =   {   1   ,   3   ,   1   ,   5   ,   21  ,   49  ,   113 ,   199 ,   433 ,   563 ,   849 ,   2741    ,0 };
            const std::uint32_t dim355Kuo2Init[]        =   {   1   ,   3   ,   7   ,   9   ,   19  ,   7   ,   3   ,   95  ,   259 ,   919 ,   1939    ,   2747    ,0 };
            const std::uint32_t dim356Kuo2Init[]        =   {   1   ,   3   ,   5   ,   1   ,   19  ,   35  ,   83  ,   95  ,   359 ,   85  ,   677 ,   805 ,0 };
            const std::uint32_t dim357Kuo2Init[]        =   {   1   ,   3   ,   1   ,   9   ,   19  ,   37  ,   63  ,   43  ,   251 ,   301 ,   1217    ,   3361    ,0 };
            const std::uint32_t dim358Kuo2Init[]        =   {   1   ,   1   ,   3   ,   7   ,   5   ,   33  ,   45  ,   15  ,   191 ,   49  ,   1511    ,   157 ,0 };
            const std::uint32_t dim359Kuo2Init[]        =   {   1   ,   3   ,   3   ,   3   ,   7   ,   3   ,   1   ,   241 ,   239 ,   229 ,   103 ,   215 ,0 };
            const std::uint32_t dim360Kuo2Init[]        =   {   1   ,   3   ,   3   ,   3   ,   29  ,   27  ,   31  ,   61  ,   331 ,   847 ,   1699    ,   923 ,0 };
            const std::uint32_t dim361Kuo2Init[]        =   {   1   ,   3   ,   1   ,   5   ,   11  ,   15  ,   81  ,   97  ,   411 ,   471 ,   1521    ,   73  ,0 };
            const std::uint32_t dim362Kuo2Init[]        =   {   1   ,   1   ,   7   ,   7   ,   7   ,   17  ,   95  ,   245 ,   415 ,   31  ,   259 ,   1835    ,0 };
            const std::uint32_t dim363Kuo2Init[]        =   {   1   ,   1   ,   1   ,   1   ,   23  ,   55  ,   27  ,   201 ,   21  ,   651 ,   1965    ,   1723    ,0 };
            const std::uint32_t dim364Kuo2Init[]        =   {   1   ,   1   ,   7   ,   11  ,   19  ,   43  ,   33  ,   7   ,   1   ,   635 ,   1651    ,   1041    ,0 };
            const std::uint32_t dim365Kuo2Init[]        =   {   1   ,   1   ,   1   ,   15  ,   29  ,   11  ,   31  ,   11  ,   29  ,   935 ,   715 ,   1115    ,0 };
            const std::uint32_t dim366Kuo2Init[]        =   {   1   ,   1   ,   3   ,   3   ,   23  ,   51  ,   115 ,   55  ,   45  ,   135 ,   913 ,   3181    ,0 };
            const std::uint32_t dim367Kuo2Init[]        =   {   1   ,   3   ,   7   ,   5   ,   15  ,   23  ,   39  ,   145 ,   51  ,   243 ,   1705    ,   3889    ,0 };
            const std::uint32_t dim368Kuo2Init[]        =   {   1   ,   1   ,   7   ,   5   ,   27  ,   43  ,   63  ,   15  ,   365 ,   299 ,   1413    ,   1553    ,0 };
            const std::uint32_t dim369Kuo2Init[]        =   {   1   ,   3   ,   1   ,   1   ,   19  ,   41  ,   123 ,   123 ,   331 ,   487 ,   2033    ,   1849    ,0 };
            const std::uint32_t dim370Kuo2Init[]        =   {   1   ,   3   ,   5   ,   13  ,   21  ,   27  ,   91  ,   225 ,   387 ,   529 ,   1529    ,   1855    ,0 };
            const std::uint32_t dim371Kuo2Init[]        =   {   1   ,   3   ,   5   ,   13  ,   23  ,   51  ,   27  ,   213 ,   55  ,   619 ,   773 ,   2037    ,0 };
            const std::uint32_t dim372Kuo2Init[]        =   {   1   ,   3   ,   3   ,   1   ,   11  ,   9   ,   125 ,   205 ,   255 ,   813 ,   925 ,   2031    ,0 };
            const std::uint32_t dim373Kuo2Init[]        =   {   1   ,   3   ,   5   ,   9   ,   23  ,   45  ,   43  ,   197 ,   475 ,   487 ,   79  ,   3649    ,0 };
            const std::uint32_t dim374Kuo2Init[]        =   {   1   ,   1   ,   1   ,   1   ,   5   ,   53  ,   97  ,   243 ,   433 ,   75  ,   467 ,   1213    ,0 };
            const std::uint32_t dim375Kuo2Init[]        =   {   1   ,   1   ,   5   ,   7   ,   5   ,   53  ,   15  ,   91  ,   405 ,   791 ,   1293    ,   1517    ,0 };
            const std::uint32_t dim376Kuo2Init[]        =   {   1   ,   1   ,   1   ,   3   ,   17  ,   27  ,   19  ,   81  ,   227 ,   935 ,   1511    ,   3709    ,0 };
            const std::uint32_t dim377Kuo2Init[]        =   {   1   ,   1   ,   5   ,   11  ,   17  ,   41  ,   125 ,   131 ,   295 ,   867 ,   1291    ,   2833    ,0 };
            const std::uint32_t dim378Kuo2Init[]        =   {   1   ,   3   ,   7   ,   13  ,   3   ,   11  ,   63  ,   159 ,   341 ,   143 ,   1779    ,   1441    ,0 };
            const std::uint32_t dim379Kuo2Init[]        =   {   1   ,   1   ,   7   ,   3   ,   29  ,   3   ,   103 ,   7   ,   145 ,   589 ,   723 ,   663 ,0 };
            const std::uint32_t dim380Kuo2Init[]        =   {   1   ,   1   ,   7   ,   15  ,   5   ,   25  ,   105 ,   129 ,   277 ,   163 ,   349 ,   219 ,0 };
            const std::uint32_t dim381Kuo2Init[]        =   {   1   ,   3   ,   1   ,   9   ,   21  ,   27  ,   127 ,   167 ,   285 ,   135 ,   1493    ,   3825    ,0 };
            const std::uint32_t dim382Kuo2Init[]        =   {   1   ,   3   ,   1   ,   1   ,   7   ,   41  ,   95  ,   255 ,   273 ,   75  ,   383 ,   15  ,0 };
            const std::uint32_t dim383Kuo2Init[]        =   {   1   ,   3   ,   5   ,   7   ,   21  ,   19  ,   67  ,   19  ,   465 ,   899 ,   1515    ,   425 ,0 };
            const std::uint32_t dim384Kuo2Init[]        =   {   1   ,   1   ,   5   ,   15  ,   17  ,   45  ,   31  ,   227 ,   229 ,   271 ,   1169    ,   3915    ,0 };
            const std::uint32_t dim385Kuo2Init[]        =   {   1   ,   3   ,   7   ,   11  ,   7   ,   23  ,   117 ,   195 ,   435 ,   171 ,   777 ,   3473    ,0 };
            const std::uint32_t dim386Kuo2Init[]        =   {   1   ,   1   ,   3   ,   3   ,   27  ,   7   ,   99  ,   11  ,   361 ,   129 ,   717 ,   1241    ,0 };
            const std::uint32_t dim387Kuo2Init[]        =   {   1   ,   1   ,   5   ,   9   ,   27  ,   1   ,   11  ,   115 ,   15  ,   561 ,   1989    ,   3857    ,0 };
            const std::uint32_t dim388Kuo2Init[]        =   {   1   ,   1   ,   1   ,   5   ,   29  ,   55  ,   23  ,   83  ,   45  ,   427 ,   987 ,   3627    ,0 };
            const std::uint32_t dim389Kuo2Init[]        =   {   1   ,   1   ,   1   ,   9   ,   5   ,   59  ,   119 ,   77  ,   297 ,   129 ,   1675    ,   2621    ,0 };
            const std::uint32_t dim390Kuo2Init[]        =   {   1   ,   1   ,   5   ,   11  ,   27  ,   49  ,   69  ,   115 ,   453 ,   863 ,   811 ,   535 ,0 };
            const std::uint32_t dim391Kuo2Init[]        =   {   1   ,   1   ,   5   ,   9   ,   21  ,   43  ,   109 ,   207 ,   5   ,   987 ,   1747    ,   47  ,0 };
            const std::uint32_t dim392Kuo2Init[]        =   {   1   ,   3   ,   5   ,   5   ,   27  ,   31  ,   67  ,   133 ,   153 ,   137 ,   1167    ,   325 ,0 };
            const std::uint32_t dim393Kuo2Init[]        =   {   1   ,   1   ,   3   ,   15  ,   9   ,   7   ,   51  ,   221 ,   317 ,   917 ,   1589    ,   1701    ,0 };
            const std::uint32_t dim394Kuo2Init[]        =   {   1   ,   1   ,   3   ,   11  ,   7   ,   21  ,   3   ,   235 ,   237 ,   853 ,   1883    ,   2733    ,0 };
            const std::uint32_t dim395Kuo2Init[]        =   {   1   ,   3   ,   7   ,   1   ,   9   ,   59  ,   69  ,   71  ,   191 ,   507 ,   1387    ,   2643    ,0 };
            const std::uint32_t dim396Kuo2Init[]        =   {   1   ,   1   ,   1   ,   7   ,   13  ,   17  ,   59  ,   115 ,   401 ,   373 ,   431 ,   2895    ,0 };
            const std::uint32_t dim397Kuo2Init[]        =   {   1   ,   3   ,   7   ,   7   ,   31  ,   23  ,   51  ,   173 ,   425 ,   823 ,   1375    ,   1675    ,0 };
            const std::uint32_t dim398Kuo2Init[]        =   {   1   ,   3   ,   1   ,   13  ,   1   ,   57  ,   57  ,   203 ,   275 ,   825 ,   969 ,   1357    ,0 };
            const std::uint32_t dim399Kuo2Init[]        =   {   1   ,   3   ,   1   ,   1   ,   31  ,   39  ,   125 ,   49  ,   11  ,   255 ,   373 ,   805 ,0 };
            const std::uint32_t dim400Kuo2Init[]        =   {   1   ,   3   ,   7   ,   1   ,   7   ,   59  ,   43  ,   143 ,   447 ,   73  ,   1979    ,   3401    ,0 };
            const std::uint32_t dim401Kuo2Init[]        =   {   1   ,   3   ,   7   ,   15  ,   29  ,   31  ,   11  ,   49  ,   241 ,   157 ,   1147    ,   1049    ,0 };
            const std::uint32_t dim402Kuo2Init[]        =   {   1   ,   1   ,   3   ,   11  ,   19  ,   39  ,   41  ,   145 ,   219 ,   811 ,   425 ,   3561    ,0 };
            const std::uint32_t dim403Kuo2Init[]        =   {   1   ,   1   ,   3   ,   13  ,   23  ,   49  ,   123 ,   3   ,   423 ,   661 ,   329 ,   3883    ,0 };
            const std::uint32_t dim404Kuo2Init[]        =   {   1   ,   3   ,   1   ,   15  ,   21  ,   21  ,   5   ,   105 ,   19  ,   171 ,   1187    ,   1451    ,0 };
            const std::uint32_t dim405Kuo2Init[]        =   {   1   ,   1   ,   7   ,   3   ,   27  ,   7   ,   31  ,   25  ,   339 ,   107 ,   827 ,   2813    ,0 };
            const std::uint32_t dim406Kuo2Init[]        =   {   1   ,   1   ,   3   ,   3   ,   7   ,   9   ,   5   ,   241 ,   419 ,   19  ,   303 ,   1327    ,0 };
            const std::uint32_t dim407Kuo2Init[]        =   {   1   ,   3   ,   3   ,   5   ,   1   ,   17  ,   105 ,   143 ,   345 ,   953 ,   857 ,   2241    ,0 };
            const std::uint32_t dim408Kuo2Init[]        =   {   1   ,   3   ,   7   ,   5   ,   11  ,   63  ,   39  ,   49  ,   3   ,   601 ,   1491    ,   3095    ,0 };
            const std::uint32_t dim409Kuo2Init[]        =   {   1   ,   1   ,   5   ,   1   ,   27  ,   35  ,   25  ,   231 ,   265 ,   27  ,   83  ,   511 ,0 };
            const std::uint32_t dim410Kuo2Init[]        =   {   1   ,   3   ,   5   ,   3   ,   29  ,   1   ,   119 ,   39  ,   81  ,   551 ,   1709    ,   2105    ,0 };
            const std::uint32_t dim411Kuo2Init[]        =   {   1   ,   3   ,   1   ,   5   ,   29  ,   31  ,   99  ,   93  ,   391 ,   691 ,   411 ,   637 ,0 };
            const std::uint32_t dim412Kuo2Init[]        =   {   1   ,   3   ,   5   ,   1   ,   21  ,   53  ,   81  ,   171 ,   303 ,   987 ,   1235    ,   1559    ,0 };
            const std::uint32_t dim413Kuo2Init[]        =   {   1   ,   3   ,   3   ,   5   ,   7   ,   63  ,   51  ,   89  ,   257 ,   489 ,   275 ,   2309    ,0 };
            const std::uint32_t dim414Kuo2Init[]        =   {   1   ,   3   ,   1   ,   5   ,   5   ,   33  ,   25  ,   55  ,   241 ,   259 ,   1213    ,   2409    ,0 };
            const std::uint32_t dim415Kuo2Init[]        =   {   1   ,   3   ,   7   ,   3   ,   11  ,   57  ,   85  ,   209 ,   329 ,   611 ,   45  ,   1183    ,0 };
            const std::uint32_t dim416Kuo2Init[]        =   {   1   ,   3   ,   3   ,   15  ,   3   ,   15  ,   31  ,   27  ,   363 ,   291 ,   1063    ,   229 ,0 };
            const std::uint32_t dim417Kuo2Init[]        =   {   1   ,   3   ,   1   ,   1   ,   1   ,   3   ,   47  ,   189 ,   287 ,   337 ,   879 ,   1881    ,0 };
            const std::uint32_t dim418Kuo2Init[]        =   {   1   ,   1   ,   3   ,   5   ,   9   ,   11  ,   65  ,   237 ,   499 ,   431 ,   1677    ,   2503    ,0 };
            const std::uint32_t dim419Kuo2Init[]        =   {   1   ,   3   ,   1   ,   15  ,   3   ,   17  ,   101 ,   23  ,   367 ,   643 ,   1485    ,   1625    ,0 };
            const std::uint32_t dim420Kuo2Init[]        =   {   1   ,   3   ,   3   ,   13  ,   9   ,   3   ,   87  ,   11  ,   137 ,   835 ,   1095    ,   891 ,0 };
            const std::uint32_t dim421Kuo2Init[]        =   {   1   ,   1   ,   5   ,   7   ,   15  ,   3   ,   49  ,   253 ,   29  ,   159 ,   315 ,   2133    ,0 };
            const std::uint32_t dim422Kuo2Init[]        =   {   1   ,   1   ,   3   ,   15  ,   11  ,   11  ,   17  ,   37  ,   287 ,   35  ,   813 ,   2715    ,0 };
            const std::uint32_t dim423Kuo2Init[]        =   {   1   ,   1   ,   1   ,   9   ,   3   ,   51  ,   57  ,   205 ,   385 ,   157 ,   811 ,   627 ,0 };
            const std::uint32_t dim424Kuo2Init[]        =   {   1   ,   3   ,   7   ,   15  ,   13  ,   33  ,   65  ,   117 ,   339 ,   805 ,   19  ,   3775    ,0 };
            const std::uint32_t dim425Kuo2Init[]        =   {   1   ,   3   ,   5   ,   5   ,   9   ,   5   ,   25  ,   177 ,   469 ,   599 ,   1527    ,   3799    ,0 };
            const std::uint32_t dim426Kuo2Init[]        =   {   1   ,   1   ,   3   ,   9   ,   1   ,   45  ,   65  ,   69  ,   121 ,   263 ,   1355    ,   1205    ,0 };
            const std::uint32_t dim427Kuo2Init[]        =   {   1   ,   1   ,   3   ,   3   ,   3   ,   33  ,   121 ,   163 ,   95  ,   137 ,   1393    ,   4017    ,0 };
            const std::uint32_t dim428Kuo2Init[]        =   {   1   ,   3   ,   7   ,   7   ,   19  ,   27  ,   17  ,   239 ,   253 ,   305 ,   1929    ,   1725    ,0 };
            const std::uint32_t dim429Kuo2Init[]        =   {   1   ,   3   ,   5   ,   7   ,   5   ,   19  ,   115 ,   95  ,   93  ,   87  ,   1379    ,   3295    ,0 };
            const std::uint32_t dim430Kuo2Init[]        =   {   1   ,   3   ,   3   ,   3   ,   5   ,   51  ,   7   ,   171 ,   153 ,   329 ,   1627    ,   3503    ,0 };
            const std::uint32_t dim431Kuo2Init[]        =   {   1   ,   1   ,   5   ,   9   ,   27  ,   15  ,   91  ,   99  ,   433 ,   689 ,   1551    ,   1827    ,0 };
            const std::uint32_t dim432Kuo2Init[]        =   {   1   ,   3   ,   3   ,   11  ,   17  ,   35  ,   29  ,   203 ,   171 ,   513 ,   771 ,   2011    ,0 };
            const std::uint32_t dim433Kuo2Init[]        =   {   1   ,   3   ,   5   ,   11  ,   29  ,   57  ,   69  ,   239 ,   87  ,   477 ,   187 ,   4079    ,0 };
            const std::uint32_t dim434Kuo2Init[]        =   {   1   ,   1   ,   1   ,   11  ,   9   ,   25  ,   37  ,   41  ,   113 ,   339 ,   1347    ,   3475    ,0 };
            const std::uint32_t dim435Kuo2Init[]        =   {   1   ,   3   ,   1   ,   15  ,   17  ,   17  ,   53  ,   17  ,   327 ,   123 ,   915 ,   655 ,0 };
            const std::uint32_t dim436Kuo2Init[]        =   {   1   ,   1   ,   5   ,   13  ,   29  ,   3   ,   85  ,   173 ,   139 ,   51  ,   929 ,   3407    ,0 };
            const std::uint32_t dim437Kuo2Init[]        =   {   1   ,   3   ,   5   ,   3   ,   25  ,   13  ,   19  ,   91  ,   285 ,   309 ,   105 ,   2331    ,0 };
            const std::uint32_t dim438Kuo2Init[]        =   {   1   ,   3   ,   7   ,   7   ,   13  ,   23  ,   103 ,   7   ,   435 ,   571 ,   731 ,   431 ,0 };
            const std::uint32_t dim439Kuo2Init[]        =   {   1   ,   1   ,   3   ,   11  ,   23  ,   3   ,   29  ,   25  ,   369 ,   941 ,   2031    ,   2311    ,0 };
            const std::uint32_t dim440Kuo2Init[]        =   {   1   ,   3   ,   5   ,   3   ,   11  ,   49  ,   69  ,   61  ,   267 ,   241 ,   1221    ,   1533    ,0 };
            const std::uint32_t dim441Kuo2Init[]        =   {   1   ,   3   ,   3   ,   5   ,   17  ,   43  ,   27  ,   191 ,   201 ,   653 ,   933 ,   2571    ,0 };
            const std::uint32_t dim442Kuo2Init[]        =   {   1   ,   1   ,   1   ,   13  ,   1   ,   7   ,   117 ,   179 ,   61  ,   1003    ,   379 ,   2359    ,0 };
            const std::uint32_t dim443Kuo2Init[]        =   {   1   ,   3   ,   5   ,   15  ,   9   ,   53  ,   23  ,   217 ,   237 ,   647 ,   377 ,   677 ,0 };
            const std::uint32_t dim444Kuo2Init[]        =   {   1   ,   1   ,   1   ,   1   ,   15  ,   55  ,   73  ,   1   ,   119 ,   679 ,   203 ,   309 ,0 };
            const std::uint32_t dim445Kuo2Init[]        =   {   1   ,   1   ,   5   ,   15  ,   11  ,   13  ,   15  ,   211 ,   105 ,   655 ,   739 ,   1439    ,0 };
            const std::uint32_t dim446Kuo2Init[]        =   {   1   ,   3   ,   5   ,   5   ,   9   ,   41  ,   87  ,   237 ,   65  ,   837 ,   1127    ,   2539    ,0 };
            const std::uint32_t dim447Kuo2Init[]        =   {   1   ,   1   ,   3   ,   9   ,   3   ,   57  ,   23  ,   55  ,   359 ,   909 ,   969 ,   1437    ,0 };
            const std::uint32_t dim448Kuo2Init[]        =   {   1   ,   1   ,   1   ,   9   ,   23  ,   57  ,   23  ,   127 ,   139 ,   961 ,   1985    ,   2785    ,0 };
            const std::uint32_t dim449Kuo2Init[]        =   {   1   ,   3   ,   7   ,   1   ,   31  ,   7   ,   65  ,   215 ,   305 ,   245 ,   971 ,   139 ,0 };
            const std::uint32_t dim450Kuo2Init[]        =   {   1   ,   3   ,   3   ,   11  ,   3   ,   3   ,   29  ,   173 ,   189 ,   807 ,   219 ,   2807    ,0 };
            const std::uint32_t dim451Kuo2Init[]        =   {   1   ,   3   ,   5   ,   7   ,   25  ,   39  ,   7   ,   157 ,   397 ,   773 ,   461 ,   3051    ,0 };
            const std::uint32_t dim452Kuo2Init[]        =   {   1   ,   3   ,   7   ,   7   ,   9   ,   7   ,   33  ,   19  ,   127 ,   177 ,   189 ,   1247    ,0 };
            const std::uint32_t dim453Kuo2Init[]        =   {   1   ,   3   ,   5   ,   3   ,   5   ,   13  ,   77  ,   219 ,   339 ,   969 ,   1193    ,   2545    ,0 };
            const std::uint32_t dim454Kuo2Init[]        =   {   1   ,   3   ,   3   ,   13  ,   29  ,   45  ,   123 ,   9   ,   335 ,   985 ,   1923    ,   2449    ,0 };
            const std::uint32_t dim455Kuo2Init[]        =   {   1   ,   3   ,   1   ,   9   ,   7   ,   43  ,   29  ,   83  ,   153 ,   381 ,   1849    ,   2563    ,0 };
            const std::uint32_t dim456Kuo2Init[]        =   {   1   ,   3   ,   3   ,   1   ,   29  ,   31  ,   107 ,   151 ,   171 ,   137 ,   1749    ,   1541    ,0 };
            const std::uint32_t dim457Kuo2Init[]        =   {   1   ,   3   ,   7   ,   1   ,   13  ,   53  ,   27  ,   119 ,   295 ,   879 ,   1113    ,   1293    ,0 };
            const std::uint32_t dim458Kuo2Init[]        =   {   1   ,   1   ,   7   ,   9   ,   19  ,   25  ,   127 ,   215 ,   271 ,   521 ,   1093    ,   1595    ,0 };
            const std::uint32_t dim459Kuo2Init[]        =   {   1   ,   1   ,   5   ,   11  ,   11  ,   9   ,   35  ,   55  ,   447 ,   513 ,   1415    ,   2427    ,0 };
            const std::uint32_t dim460Kuo2Init[]        =   {   1   ,   3   ,   1   ,   5   ,   19  ,   19  ,   19  ,   111 ,   73  ,   895 ,   1879    ,   3679    ,0 };
            const std::uint32_t dim461Kuo2Init[]        =   {   1   ,   1   ,   7   ,   13  ,   13  ,   55  ,   65  ,   131 ,   461 ,   775 ,   1817    ,   1795    ,0 };
            const std::uint32_t dim462Kuo2Init[]        =   {   1   ,   3   ,   7   ,   9   ,   31  ,   41  ,   119 ,   75  ,   419 ,   319 ,   1463    ,   3491    ,0 };
            const std::uint32_t dim463Kuo2Init[]        =   {   1   ,   1   ,   7   ,   7   ,   27  ,   33  ,   71  ,   223 ,   381 ,   181 ,   541 ,   1695    ,0 };
            const std::uint32_t dim464Kuo2Init[]        =   {   1   ,   3   ,   7   ,   5   ,   29  ,   53  ,   109 ,   109 ,   35  ,   607 ,   559 ,   4045    ,0 };
            const std::uint32_t dim465Kuo2Init[]        =   {   1   ,   3   ,   1   ,   13  ,   11  ,   9   ,   9   ,   91  ,   85  ,   41  ,   1155    ,   3989    ,0 };
            const std::uint32_t dim466Kuo2Init[]        =   {   1   ,   1   ,   3   ,   15  ,   23  ,   13  ,   3   ,   243 ,   443 ,   671 ,   1461    ,   3329    ,0 };
            const std::uint32_t dim467Kuo2Init[]        =   {   1   ,   1   ,   1   ,   1   ,   27  ,   25  ,   37  ,   153 ,   299 ,   51  ,   371 ,   1269    ,0 };
            const std::uint32_t dim468Kuo2Init[]        =   {   1   ,   3   ,   7   ,   11  ,   13  ,   51  ,   85  ,   177 ,   489 ,   867 ,   779 ,   3423    ,0 };
            const std::uint32_t dim469Kuo2Init[]        =   {   1   ,   1   ,   7   ,   1   ,   25  ,   51  ,   105 ,   117 ,   105 ,   743 ,   67  ,   2889    ,0 };
            const std::uint32_t dim470Kuo2Init[]        =   {   1   ,   1   ,   3   ,   3   ,   29  ,   31  ,   65  ,   11  ,   87  ,   647 ,   193 ,   1229    ,0 };
            const std::uint32_t dim471Kuo2Init[]        =   {   1   ,   3   ,   5   ,   9   ,   19  ,   19  ,   19  ,   193 ,   441 ,   947 ,   1385    ,   1321    ,0 };
            const std::uint32_t dim472Kuo2Init[]        =   {   1   ,   1   ,   1   ,   9   ,   9   ,   31  ,   109 ,   77  ,   449 ,   775 ,   187 ,   2609    ,0 };
            const std::uint32_t dim473Kuo2Init[]        =   {   1   ,   1   ,   1   ,   13  ,   31  ,   57  ,   121 ,   251 ,   9   ,   673 ,   473 ,   755 ,0 };
            const std::uint32_t dim474Kuo2Init[]        =   {   1   ,   3   ,   3   ,   7   ,   25  ,   21  ,   93  ,   183 ,   277 ,   167 ,   1305    ,   897 ,0 };
            const std::uint32_t dim475Kuo2Init[]        =   {   1   ,   1   ,   5   ,   5   ,   29  ,   15  ,   29  ,   67  ,   193 ,   525 ,   851 ,   2287    ,0 };
            const std::uint32_t dim476Kuo2Init[]        =   {   1   ,   1   ,   5   ,   9   ,   7   ,   53  ,   117 ,   203 ,   89  ,   221 ,   235 ,   2783    ,0 };
            const std::uint32_t dim477Kuo2Init[]        =   {   1   ,   3   ,   5   ,   13  ,   7   ,   25  ,   69  ,   25  ,   329 ,   151 ,   1721    ,   1279    ,0 };
            const std::uint32_t dim478Kuo2Init[]        =   {   1   ,   1   ,   1   ,   7   ,   15  ,   9   ,   119 ,   75  ,   95  ,   297 ,   1149    ,   1385    ,0 };
            const std::uint32_t dim479Kuo2Init[]        =   {   1   ,   3   ,   3   ,   15  ,   23  ,   1   ,   109 ,   81  ,   249 ,   189 ,   737 ,   1809    ,0 };
            const std::uint32_t dim480Kuo2Init[]        =   {   1   ,   1   ,   7   ,   5   ,   29  ,   53  ,   77  ,   79  ,   339 ,   625 ,   1131    ,   2539    ,0 };
            const std::uint32_t dim481Kuo2Init[]        =   {   1   ,   1   ,   7   ,   15  ,   23  ,   35  ,   39  ,   25  ,   287 ,   321 ,   151 ,   193 ,   6637    ,0 };
            const std::uint32_t dim482Kuo2Init[]        =   {   1   ,   3   ,   5   ,   9   ,   15  ,   31  ,   31  ,   111 ,   393 ,   97  ,   407 ,   1087    ,   1413    ,0 };
            const std::uint32_t dim483Kuo2Init[]        =   {   1   ,   1   ,   1   ,   13  ,   21  ,   63  ,   71  ,   193 ,   443 ,   541 ,   1989    ,   2979    ,   7087    ,0 };
            const std::uint32_t dim484Kuo2Init[]        =   {   1   ,   3   ,   3   ,   1   ,   11  ,   41  ,   19  ,   219 ,   497 ,   273 ,   1293    ,   2233    ,   2967    ,0 };
            const std::uint32_t dim485Kuo2Init[]        =   {   1   ,   1   ,   5   ,   7   ,   23  ,   15  ,   119 ,   245 ,   223 ,   773 ,   1261    ,   1623    ,   8067    ,0 };
            const std::uint32_t dim486Kuo2Init[]        =   {   1   ,   1   ,   1   ,   15  ,   3   ,   39  ,   39  ,   11  ,   141 ,   347 ,   1473    ,   3503    ,   3595    ,0 };
            const std::uint32_t dim487Kuo2Init[]        =   {   1   ,   1   ,   1   ,   5   ,   27  ,   15  ,   81  ,   159 ,   279 ,   907 ,   143 ,   3195    ,   7127    ,0 };
            const std::uint32_t dim488Kuo2Init[]        =   {   1   ,   1   ,   1   ,   9   ,   27  ,   29  ,   109 ,   29  ,   147 ,   255 ,   1851    ,   677 ,   2883    ,0 };
            const std::uint32_t dim489Kuo2Init[]        =   {   1   ,   1   ,   5   ,   1   ,   1   ,   23  ,   3   ,   107 ,   9   ,   757 ,   319 ,   949 ,   3887    ,0 };
            const std::uint32_t dim490Kuo2Init[]        =   {   1   ,   1   ,   7   ,   1   ,   13  ,   41  ,   21  ,   9   ,   53  ,   179 ,   1273    ,   17  ,   5195    ,0 };
            const std::uint32_t dim491Kuo2Init[]        =   {   1   ,   3   ,   3   ,   15  ,   9   ,   41  ,   121 ,   13  ,   245 ,   415 ,   2041    ,   3813    ,   6807    ,0 };
            const std::uint32_t dim492Kuo2Init[]        =   {   1   ,   3   ,   5   ,   13  ,   7   ,   5   ,   43  ,   137 ,   191 ,   855 ,   735 ,   3711    ,   2459    ,0 };
            const std::uint32_t dim493Kuo2Init[]        =   {   1   ,   3   ,   3   ,   13  ,   15  ,   53  ,   13  ,   245 ,   217 ,   159 ,   271 ,   261 ,   7383    ,0 };
            const std::uint32_t dim494Kuo2Init[]        =   {   1   ,   3   ,   1   ,   9   ,   1   ,   39  ,   79  ,   73  ,   349 ,   367 ,   51  ,   155 ,   53  ,0 };
            const std::uint32_t dim495Kuo2Init[]        =   {   1   ,   1   ,   7   ,   5   ,   11  ,   19  ,   99  ,   131 ,   217 ,   729 ,   1481    ,   4015    ,   6109    ,0 };
            const std::uint32_t dim496Kuo2Init[]        =   {   1   ,   3   ,   1   ,   3   ,   9   ,   7   ,   55  ,   119 ,   285 ,   803 ,   427 ,   3755    ,   3153    ,0 };
            const std::uint32_t dim497Kuo2Init[]        =   {   1   ,   1   ,   7   ,   13  ,   25  ,   3   ,   111 ,   51  ,   1   ,   995 ,   657 ,   1551    ,   3633    ,0 };
            const std::uint32_t dim498Kuo2Init[]        =   {   1   ,   3   ,   3   ,   1   ,   29  ,   49  ,   15  ,   219 ,   295 ,   335 ,   191 ,   611 ,   1151    ,0 };
            const std::uint32_t dim499Kuo2Init[]        =   {   1   ,   3   ,   3   ,   3   ,   5   ,   37  ,   115 ,   199 ,   143 ,   11  ,   1487    ,   3841    ,   4669    ,0 };
            const std::uint32_t dim500Kuo2Init[]        =   {   1   ,   1   ,   3   ,   5   ,   23  ,   33  ,   67  ,   51  ,   433 ,   351 ,   1467    ,   2935    ,   4135    ,0 };
            const std::uint32_t dim501Kuo2Init[]        =   {   1   ,   3   ,   3   ,   15  ,   3   ,   57  ,   55  ,   7   ,   487 ,   983 ,   1481    ,   799 ,   6141    ,0 };
            const std::uint32_t dim502Kuo2Init[]        =   {   1   ,   3   ,   5   ,   3   ,   23  ,   1   ,   37  ,   117 ,   131 ,   55  ,   449 ,   637 ,   693 ,0 };
            const std::uint32_t dim503Kuo2Init[]        =   {   1   ,   3   ,   1   ,   9   ,   11  ,   7   ,   43  ,   149 ,   463 ,   349 ,   1773    ,   643 ,   765 ,0 };
            const std::uint32_t dim504Kuo2Init[]        =   {   1   ,   3   ,   1   ,   1   ,   25  ,   39  ,   1   ,   33  ,   209 ,   131 ,   157 ,   2695    ,   623 ,0 };
            const std::uint32_t dim505Kuo2Init[]        =   {   1   ,   1   ,   1   ,   7   ,   15  ,   41  ,   105 ,   51  ,   465 ,   453 ,   1091    ,   905 ,   4831    ,0 };
            const std::uint32_t dim506Kuo2Init[]        =   {   1   ,   3   ,   7   ,   9   ,   1   ,   39  ,   45  ,   117 ,   481 ,   481 ,   87  ,   1869    ,   7063    ,0 };
            const std::uint32_t dim507Kuo2Init[]        =   {   1   ,   1   ,   7   ,   1   ,   27  ,   1   ,   87  ,   75  ,   295 ,   287 ,   163 ,   911 ,   1725    ,0 };
            const std::uint32_t dim508Kuo2Init[]        =   {   1   ,   3   ,   3   ,   9   ,   31  ,   61  ,   75  ,   53  ,   63  ,   179 ,   1941    ,   555 ,   1303    ,0 };
            const std::uint32_t dim509Kuo2Init[]        =   {   1   ,   3   ,   3   ,   9   ,   31  ,   37  ,   9   ,   51  ,   381 ,   639 ,   595 ,   731 ,   7531    ,0 };
            const std::uint32_t dim510Kuo2Init[]        =   {   1   ,   3   ,   1   ,   1   ,   3   ,   25  ,   59  ,   19  ,   187 ,   235 ,   173 ,   893 ,   4845    ,0 };
            const std::uint32_t dim511Kuo2Init[]        =   {   1   ,   1   ,   7   ,   7   ,   1   ,   23  ,   9   ,   9   ,   493 ,   643 ,   53  ,   179 ,   6993    ,0 };
            const std::uint32_t dim512Kuo2Init[]        =   {   1   ,   1   ,   1   ,   1   ,   25  ,   55  ,   81  ,   63  ,   67  ,   967 ,   957 ,   1025    ,   8033    ,0 };
            const std::uint32_t dim513Kuo2Init[]        =   {   1   ,   3   ,   1   ,   7   ,   5   ,   43  ,   67  ,   127 ,   103 ,   241 ,   77  ,   43  ,   5173    ,0 };
            const std::uint32_t dim514Kuo2Init[]        =   {   1   ,   1   ,   3   ,   7   ,   9   ,   25  ,   17  ,   231 ,   315 ,   699 ,   787 ,   591 ,   7257    ,0 };
            const std::uint32_t dim515Kuo2Init[]        =   {   1   ,   3   ,   1   ,   15  ,   21  ,   19  ,   7   ,   179 ,   335 ,   701 ,   323 ,   121 ,   4733    ,0 };
            const std::uint32_t dim516Kuo2Init[]        =   {   1   ,   1   ,   3   ,   7   ,   11  ,   59  ,   75  ,   147 ,   391 ,   535 ,   1841    ,   3025    ,   5621    ,0 };
            const std::uint32_t dim517Kuo2Init[]        =   {   1   ,   1   ,   3   ,   7   ,   21  ,   25  ,   101 ,   71  ,   195 ,   495 ,   1241    ,   2229    ,   2865    ,0 };
            const std::uint32_t dim518Kuo2Init[]        =   {   1   ,   3   ,   1   ,   5   ,   19  ,   55  ,   93  ,   41  ,   287 ,   787 ,   929 ,   3161    ,   4247    ,0 };
            const std::uint32_t dim519Kuo2Init[]        =   {   1   ,   3   ,   3   ,   11  ,   25  ,   31  ,   79  ,   225 ,   189 ,   187 ,   595 ,   465 ,   7169    ,0 };
            const std::uint32_t dim520Kuo2Init[]        =   {   1   ,   1   ,   3   ,   13  ,   25  ,   37  ,   7   ,   87  ,   511 ,   451 ,   1681    ,   1911    ,   5269    ,0 };
            const std::uint32_t dim521Kuo2Init[]        =   {   1   ,   3   ,   3   ,   13  ,   21  ,   31  ,   117 ,   73  ,   391 ,   127 ,   1201    ,   189 ,   6621    ,0 };
            const std::uint32_t dim522Kuo2Init[]        =   {   1   ,   3   ,   1   ,   7   ,   9   ,   49  ,   77  ,   91  ,   197 ,   889 ,   119 ,   1335    ,   4833    ,0 };
            const std::uint32_t dim523Kuo2Init[]        =   {   1   ,   1   ,   7   ,   3   ,   11  ,   61  ,   103 ,   19  ,   345 ,   937 ,   1393    ,   963 ,   2283    ,0 };
            const std::uint32_t dim524Kuo2Init[]        =   {   1   ,   1   ,   1   ,   9   ,   3   ,   3   ,   113 ,   189 ,   383 ,   727 ,   781 ,   3515    ,   5045    ,0 };
            const std::uint32_t dim525Kuo2Init[]        =   {   1   ,   1   ,   7   ,   15  ,   27  ,   45  ,   65  ,   137 ,   5   ,   185 ,   1561    ,   2063    ,   761 ,0 };
            const std::uint32_t dim526Kuo2Init[]        =   {   1   ,   1   ,   3   ,   9   ,   17  ,   5   ,   71  ,   209 ,   387 ,   693 ,   773 ,   2105    ,   1265    ,0 };
            const std::uint32_t dim527Kuo2Init[]        =   {   1   ,   1   ,   3   ,   11  ,   9   ,   49  ,   53  ,   53  ,   7   ,   5   ,   543 ,   1605    ,   265 ,0 };
            const std::uint32_t dim528Kuo2Init[]        =   {   1   ,   3   ,   3   ,   3   ,   23  ,   21  ,   27  ,   187 ,   495 ,   101 ,   517 ,   853 ,   2801    ,0 };
            const std::uint32_t dim529Kuo2Init[]        =   {   1   ,   3   ,   5   ,   1   ,   7   ,   61  ,   47  ,   113 ,   375 ,   307 ,   255 ,   3341    ,   3663    ,0 };
            const std::uint32_t dim530Kuo2Init[]        =   {   1   ,   1   ,   1   ,   1   ,   19  ,   9   ,   33  ,   235 ,   413 ,   999 ,   1889    ,   3633    ,   745 ,0 };
            const std::uint32_t dim531Kuo2Init[]        =   {   1   ,   1   ,   1   ,   7   ,   27  ,   27  ,   19  ,   57  ,   1   ,   639 ,   831 ,   3481    ,   395 ,0 };
            const std::uint32_t dim532Kuo2Init[]        =   {   1   ,   3   ,   3   ,   5   ,   19  ,   55  ,   27  ,   215 ,   319 ,   855 ,   1597    ,   1539    ,   4359    ,0 };
            const std::uint32_t dim533Kuo2Init[]        =   {   1   ,   3   ,   7   ,   11  ,   3   ,   35  ,   5   ,   3   ,   341 ,   795 ,   315 ,   935 ,   2417    ,0 };
            const std::uint32_t dim534Kuo2Init[]        =   {   1   ,   1   ,   1   ,   3   ,   25  ,   55  ,   53  ,   143 ,   361 ,   203 ,   863 ,   2491    ,   4701    ,0 };
            const std::uint32_t dim535Kuo2Init[]        =   {   1   ,   1   ,   5   ,   9   ,   19  ,   9   ,   29  ,   153 ,   387 ,   373 ,   647 ,   2825    ,   1391    ,0 };
            const std::uint32_t dim536Kuo2Init[]        =   {   1   ,   1   ,   3   ,   9   ,   1   ,   37  ,   103 ,   17  ,   347 ,   577 ,   181 ,   2863    ,   6525    ,0 };
            const std::uint32_t dim537Kuo2Init[]        =   {   1   ,   1   ,   1   ,   3   ,   17  ,   19  ,   41  ,   61  ,   49  ,   75  ,   1243    ,   33  ,   7725    ,0 };
            const std::uint32_t dim538Kuo2Init[]        =   {   1   ,   3   ,   1   ,   9   ,   7   ,   23  ,   107 ,   227 ,   225 ,   139 ,   451 ,   1303    ,   5657    ,0 };
            const std::uint32_t dim539Kuo2Init[]        =   {   1   ,   3   ,   5   ,   11  ,   27  ,   37  ,   95  ,   195 ,   261 ,   827 ,   817 ,   2555    ,   8189    ,0 };
            const std::uint32_t dim540Kuo2Init[]        =   {   1   ,   3   ,   1   ,   11  ,   13  ,   17  ,   73  ,   113 ,   287 ,   73  ,   977 ,   2815    ,   4281    ,0 };
            const std::uint32_t dim541Kuo2Init[]        =   {   1   ,   1   ,   5   ,   7   ,   23  ,   7   ,   103 ,   41  ,   237 ,   745 ,   1645    ,   2041    ,   6063    ,0 };
            const std::uint32_t dim542Kuo2Init[]        =   {   1   ,   1   ,   3   ,   15  ,   17  ,   1   ,   63  ,   115 ,   303 ,   175 ,   1511    ,   3027    ,   1265    ,0 };
            const std::uint32_t dim543Kuo2Init[]        =   {   1   ,   3   ,   5   ,   3   ,   29  ,   57  ,   1   ,   51  ,   127 ,   539 ,   1171    ,   3567    ,   6409    ,0 };
            const std::uint32_t dim544Kuo2Init[]        =   {   1   ,   1   ,   1   ,   9   ,   29  ,   63  ,   85  ,   127 ,   375 ,   453 ,   539 ,   563 ,   5709    ,0 };
            const std::uint32_t dim545Kuo2Init[]        =   {   1   ,   1   ,   1   ,   7   ,   29  ,   31  ,   109 ,   159 ,   15  ,   621 ,   1593    ,   3793    ,   4503    ,0 };
            const std::uint32_t dim546Kuo2Init[]        =   {   1   ,   1   ,   3   ,   3   ,   17  ,   27  ,   59  ,   9   ,   263 ,   705 ,   909 ,   643 ,   4967    ,0 };
            const std::uint32_t dim547Kuo2Init[]        =   {   1   ,   3   ,   5   ,   7   ,   23  ,   13  ,   37  ,   179 ,   439 ,   77  ,   1055    ,   3129    ,   371 ,0 };
            const std::uint32_t dim548Kuo2Init[]        =   {   1   ,   3   ,   1   ,   11  ,   25  ,   1   ,   123 ,   109 ,   27  ,   393 ,   1729    ,   3597    ,   5197    ,0 };
            const std::uint32_t dim549Kuo2Init[]        =   {   1   ,   3   ,   5   ,   11  ,   15  ,   9   ,   25  ,   19  ,   1   ,   927 ,   39  ,   925 ,   87  ,0 };
            const std::uint32_t dim550Kuo2Init[]        =   {   1   ,   3   ,   5   ,   1   ,   9   ,   7   ,   85  ,   95  ,   497 ,   487 ,   311 ,   2109    ,   259 ,0 };
            const std::uint32_t dim551Kuo2Init[]        =   {   1   ,   3   ,   5   ,   1   ,   5   ,   59  ,   75  ,   243 ,   179 ,   975 ,   187 ,   415 ,   1161    ,0 };
            const std::uint32_t dim552Kuo2Init[]        =   {   1   ,   3   ,   3   ,   13  ,   11  ,   61  ,   109 ,   129 ,   71  ,   917 ,   523 ,   1189    ,   4857    ,0 };
            const std::uint32_t dim553Kuo2Init[]        =   {   1   ,   3   ,   1   ,   1   ,   3   ,   57  ,   15  ,   79  ,   265 ,   839 ,   559 ,   729 ,   2737    ,0 };
            const std::uint32_t dim554Kuo2Init[]        =   {   1   ,   1   ,   7   ,   9   ,   21  ,   45  ,   69  ,   245 ,   331 ,   197 ,   1947    ,   3145    ,   6927    ,0 };
            const std::uint32_t dim555Kuo2Init[]        =   {   1   ,   3   ,   7   ,   7   ,   31  ,   41  ,   73  ,   59  ,   93  ,   565 ,   1885    ,   3803    ,   7013    ,0 };
            const std::uint32_t dim556Kuo2Init[]        =   {   1   ,   1   ,   1   ,   13  ,   23  ,   19  ,   107 ,   77  ,   449 ,   965 ,   99  ,   1215    ,   4699    ,0 };
            const std::uint32_t dim557Kuo2Init[]        =   {   1   ,   1   ,   3   ,   13  ,   11  ,   3   ,   37  ,   209 ,   221 ,   197 ,   1913    ,   631 ,   1621    ,0 };
            const std::uint32_t dim558Kuo2Init[]        =   {   1   ,   1   ,   5   ,   9   ,   27  ,   51  ,   61  ,   249 ,   269 ,   507 ,   1005    ,   2471    ,   4621    ,0 };
            const std::uint32_t dim559Kuo2Init[]        =   {   1   ,   3   ,   5   ,   1   ,   3   ,   49  ,   69  ,   227 ,   289 ,   261 ,   1103    ,   389 ,   4883    ,0 };
            const std::uint32_t dim560Kuo2Init[]        =   {   1   ,   1   ,   5   ,   3   ,   29  ,   35  ,   43  ,   167 ,   451 ,   1017    ,   865 ,   1507    ,   7387    ,0 };
            const std::uint32_t dim561Kuo2Init[]        =   {   1   ,   1   ,   3   ,   15  ,   13  ,   1   ,   53  ,   9   ,   23  ,   581 ,   627 ,   3823    ,   6767    ,0 };
            const std::uint32_t dim562Kuo2Init[]        =   {   1   ,   3   ,   1   ,   7   ,   3   ,   21  ,   115 ,   73  ,   353 ,   725 ,   1971    ,   1623    ,   7359    ,0 };
            const std::uint32_t dim563Kuo2Init[]        =   {   1   ,   1   ,   3   ,   5   ,   17  ,   15  ,   37  ,   219 ,   187 ,   699 ,   1463    ,   1563    ,   2785    ,0 };
            const std::uint32_t dim564Kuo2Init[]        =   {   1   ,   3   ,   7   ,   13  ,   11  ,   43  ,   9   ,   49  ,   125 ,   681 ,   499 ,   2127    ,   6613    ,0 };
            const std::uint32_t dim565Kuo2Init[]        =   {   1   ,   3   ,   5   ,   11  ,   5   ,   21  ,   115 ,   227 ,   305 ,   247 ,   1947    ,   853 ,   5357    ,0 };
            const std::uint32_t dim566Kuo2Init[]        =   {   1   ,   3   ,   1   ,   9   ,   29  ,   37  ,   1   ,   181 ,   427 ,   435 ,   1757    ,   1535    ,   4383    ,0 };
            const std::uint32_t dim567Kuo2Init[]        =   {   1   ,   3   ,   1   ,   15  ,   15  ,   41  ,   123 ,   7   ,   367 ,   767 ,   777 ,   3455    ,   7739    ,0 };
            const std::uint32_t dim568Kuo2Init[]        =   {   1   ,   1   ,   5   ,   9   ,   13  ,   3   ,   5   ,   79  ,   3   ,   121 ,   1113    ,   1731    ,   501 ,0 };
            const std::uint32_t dim569Kuo2Init[]        =   {   1   ,   1   ,   3   ,   13  ,   1   ,   13  ,   127 ,   215 ,   329 ,   381 ,   205 ,   2391    ,   581 ,0 };
            const std::uint32_t dim570Kuo2Init[]        =   {   1   ,   1   ,   3   ,   7   ,   7   ,   19  ,   9   ,   23  ,   463 ,   455 ,   1921    ,   763 ,   5077    ,0 };
            const std::uint32_t dim571Kuo2Init[]        =   {   1   ,   1   ,   3   ,   3   ,   13  ,   23  ,   65  ,   7   ,   337 ,   603 ,   1243    ,   2161    ,   5883    ,0 };
            const std::uint32_t dim572Kuo2Init[]        =   {   1   ,   3   ,   5   ,   1   ,   15  ,   23  ,   73  ,   151 ,   243 ,   847 ,   1189    ,   1663    ,   2011    ,0 };
            const std::uint32_t dim573Kuo2Init[]        =   {   1   ,   1   ,   7   ,   7   ,   11  ,   17  ,   91  ,   219 ,   127 ,   317 ,   1807    ,   1369    ,   7433    ,0 };
            const std::uint32_t dim574Kuo2Init[]        =   {   1   ,   3   ,   5   ,   9   ,   31  ,   49  ,   65  ,   47  ,   11  ,   541 ,   55  ,   2743    ,   4987    ,0 };
            const std::uint32_t dim575Kuo2Init[]        =   {   1   ,   3   ,   7   ,   13  ,   23  ,   23  ,   51  ,   129 ,   111 ,   319 ,   1195    ,   1593    ,   4407    ,0 };
            const std::uint32_t dim576Kuo2Init[]        =   {   1   ,   3   ,   1   ,   7   ,   21  ,   25  ,   35  ,   187 ,   409 ,   981 ,   293 ,   873 ,   7447    ,0 };
            const std::uint32_t dim577Kuo2Init[]        =   {   1   ,   3   ,   1   ,   9   ,   3   ,   11  ,   25  ,   75  ,   347 ,   907 ,   1645    ,   2997    ,   5953    ,0 };
            const std::uint32_t dim578Kuo2Init[]        =   {   1   ,   3   ,   7   ,   7   ,   25  ,   49  ,   99  ,   37  ,   45  ,   81  ,   95  ,   2637    ,   1337    ,0 };
            const std::uint32_t dim579Kuo2Init[]        =   {   1   ,   3   ,   5   ,   3   ,   29  ,   35  ,   85  ,   167 ,   503 ,   257 ,   1101    ,   2647    ,   1469    ,0 };
            const std::uint32_t dim580Kuo2Init[]        =   {   1   ,   3   ,   5   ,   1   ,   27  ,   17  ,   93  ,   197 ,   485 ,   899 ,   1201    ,   3633    ,   1289    ,0 };
            const std::uint32_t dim581Kuo2Init[]        =   {   1   ,   3   ,   1   ,   7   ,   5   ,   17  ,   53  ,   167 ,   353 ,   1023    ,   1063    ,   2221    ,   3635    ,0 };
            const std::uint32_t dim582Kuo2Init[]        =   {   1   ,   1   ,   5   ,   11  ,   9   ,   43  ,   123 ,   241 ,   77  ,   657 ,   1789    ,   235 ,   2105    ,0 };
            const std::uint32_t dim583Kuo2Init[]        =   {   1   ,   1   ,   5   ,   9   ,   9   ,   53  ,   109 ,   185 ,   443 ,   803 ,   115 ,   2079    ,   7839    ,0 };
            const std::uint32_t dim584Kuo2Init[]        =   {   1   ,   1   ,   1   ,   13  ,   29  ,   29  ,   35  ,   235 ,   253 ,   529 ,   153 ,   1613    ,   6723    ,0 };
            const std::uint32_t dim585Kuo2Init[]        =   {   1   ,   3   ,   1   ,   13  ,   11  ,   31  ,   81  ,   177 ,   135 ,   659 ,   605 ,   1253    ,   5077    ,0 };
            const std::uint32_t dim586Kuo2Init[]        =   {   1   ,   3   ,   5   ,   3   ,   25  ,   53  ,   87  ,   183 ,   285 ,   639 ,   657 ,   2307    ,   5477    ,0 };
            const std::uint32_t dim587Kuo2Init[]        =   {   1   ,   1   ,   7   ,   7   ,   9   ,   35  ,   31  ,   83  ,   165 ,   735 ,   1445    ,   3935    ,   515 ,0 };
            const std::uint32_t dim588Kuo2Init[]        =   {   1   ,   3   ,   5   ,   1   ,   13  ,   59  ,   99  ,   191 ,   187 ,   375 ,   959 ,   1145    ,   1487    ,0 };
            const std::uint32_t dim589Kuo2Init[]        =   {   1   ,   3   ,   7   ,   3   ,   1   ,   1   ,   127 ,   127 ,   101 ,   583 ,   121 ,   2879    ,   63  ,0 };
            const std::uint32_t dim590Kuo2Init[]        =   {   1   ,   3   ,   7   ,   11  ,   13  ,   1   ,   125 ,   81  ,   31  ,   177 ,   107 ,   2339    ,   755 ,0 };
            const std::uint32_t dim591Kuo2Init[]        =   {   1   ,   1   ,   3   ,   13  ,   7   ,   33  ,   9   ,   247 ,   395 ,   255 ,   1817    ,   1509    ,   5401    ,0 };
            const std::uint32_t dim592Kuo2Init[]        =   {   1   ,   1   ,   7   ,   7   ,   27  ,   19  ,   87  ,   167 ,   425 ,   1019    ,   1419    ,   4025    ,   5483    ,0 };
            const std::uint32_t dim593Kuo2Init[]        =   {   1   ,   3   ,   7   ,   7   ,   5   ,   49  ,   97  ,   65  ,   355 ,   207 ,   323 ,   2367    ,   171 ,0 };
            const std::uint32_t dim594Kuo2Init[]        =   {   1   ,   3   ,   7   ,   5   ,   23  ,   5   ,   125 ,   131 ,   115 ,   585 ,   1533    ,   3489    ,   507 ,0 };
            const std::uint32_t dim595Kuo2Init[]        =   {   1   ,   3   ,   3   ,   15  ,   29  ,   51  ,   79  ,   239 ,   289 ,   909 ,   1339    ,   857 ,   1661    ,0 };
            const std::uint32_t dim596Kuo2Init[]        =   {   1   ,   3   ,   5   ,   11  ,   23  ,   1   ,   65  ,   123 ,   439 ,   349 ,   1593    ,   1913    ,   433 ,0 };
            const std::uint32_t dim597Kuo2Init[]        =   {   1   ,   1   ,   7   ,   5   ,   27  ,   45  ,   59  ,   33  ,   375 ,   553 ,   1955    ,   731 ,   4335    ,0 };
            const std::uint32_t dim598Kuo2Init[]        =   {   1   ,   1   ,   3   ,   7   ,   25  ,   63  ,   51  ,   183 ,   67  ,   783 ,   885 ,   3385    ,   7109    ,0 };
            const std::uint32_t dim599Kuo2Init[]        =   {   1   ,   3   ,   7   ,   9   ,   3   ,   43  ,   105 ,   145 ,   123 ,   503 ,   203 ,   1029    ,   6713    ,0 };
            const std::uint32_t dim600Kuo2Init[]        =   {   1   ,   3   ,   7   ,   7   ,   11  ,   49  ,   113 ,   69  ,   489 ,   649 ,   1393    ,   1475    ,   6663    ,0 };
            const std::uint32_t dim601Kuo2Init[]        =   {   1   ,   1   ,   5   ,   11  ,   13  ,   5   ,   105 ,   21  ,   451 ,   137 ,   2029    ,   1459    ,   7981    ,0 };
            const std::uint32_t dim602Kuo2Init[]        =   {   1   ,   1   ,   7   ,   5   ,   7   ,   17  ,   3   ,   213 ,   255 ,   867 ,   89  ,   2437    ,   1151    ,0 };
            const std::uint32_t dim603Kuo2Init[]        =   {   1   ,   1   ,   7   ,   9   ,   19  ,   23  ,   115 ,   161 ,   257 ,   419 ,   1133    ,   1291    ,   243 ,0 };
            const std::uint32_t dim604Kuo2Init[]        =   {   1   ,   3   ,   5   ,   7   ,   27  ,   45  ,   23  ,   157 ,   371 ,   219 ,   1001    ,   343 ,   2419    ,0 };
            const std::uint32_t dim605Kuo2Init[]        =   {   1   ,   3   ,   1   ,   1   ,   21  ,   59  ,   91  ,   153 ,   19  ,   469 ,   1923    ,   2439    ,   3837    ,0 };
            const std::uint32_t dim606Kuo2Init[]        =   {   1   ,   3   ,   7   ,   3   ,   23  ,   29  ,   57  ,   201 ,   209 ,   249 ,   63  ,   2929    ,   2719    ,0 };
            const std::uint32_t dim607Kuo2Init[]        =   {   1   ,   1   ,   5   ,   3   ,   11  ,   3   ,   75  ,   91  ,   157 ,   557 ,   1775    ,   387 ,   803 ,0 };
            const std::uint32_t dim608Kuo2Init[]        =   {   1   ,   3   ,   3   ,   3   ,   27  ,   57  ,   69  ,   135 ,   317 ,   897 ,   1417    ,   1853    ,   747 ,0 };
            const std::uint32_t dim609Kuo2Init[]        =   {   1   ,   1   ,   7   ,   11  ,   15  ,   19  ,   115 ,   219 ,   57  ,   925 ,   1869    ,   609 ,   1631    ,0 };
            const std::uint32_t dim610Kuo2Init[]        =   {   1   ,   1   ,   1   ,   11  ,   29  ,   21  ,   45  ,   19  ,   91  ,   271 ,   971 ,   2569    ,   423 ,0 };
            const std::uint32_t dim611Kuo2Init[]        =   {   1   ,   3   ,   3   ,   13  ,   5   ,   9   ,   5   ,   101 ,   147 ,   777 ,   1647    ,   457 ,   4053    ,0 };
            const std::uint32_t dim612Kuo2Init[]        =   {   1   ,   1   ,   5   ,   9   ,   9   ,   25  ,   13  ,   175 ,   53  ,   467 ,   1555    ,   2969    ,   1669    ,0 };
            const std::uint32_t dim613Kuo2Init[]        =   {   1   ,   1   ,   1   ,   7   ,   21  ,   49  ,   1   ,   49  ,   317 ,   505 ,   1495    ,   1053    ,   2293    ,0 };
            const std::uint32_t dim614Kuo2Init[]        =   {   1   ,   1   ,   1   ,   3   ,   15  ,   43  ,   91  ,   207 ,   211 ,   725 ,   2039    ,   803 ,   4029    ,0 };
            const std::uint32_t dim615Kuo2Init[]        =   {   1   ,   1   ,   7   ,   13  ,   17  ,   45  ,   39  ,   125 ,   129 ,   169 ,   47  ,   2105    ,   1749    ,0 };
            const std::uint32_t dim616Kuo2Init[]        =   {   1   ,   3   ,   7   ,   11  ,   19  ,   13  ,   5   ,   105 ,   203 ,   611 ,   147 ,   2291    ,   1823    ,0 };
            const std::uint32_t dim617Kuo2Init[]        =   {   1   ,   1   ,   5   ,   1   ,   5   ,   15  ,   15  ,   35  ,   33  ,   467 ,   59  ,   2435    ,   3141    ,0 };
            const std::uint32_t dim618Kuo2Init[]        =   {   1   ,   3   ,   1   ,   5   ,   29  ,   43  ,   35  ,   3   ,   173 ,   619 ,   1595    ,   347 ,   2513    ,0 };
            const std::uint32_t dim619Kuo2Init[]        =   {   1   ,   3   ,   3   ,   1   ,   23  ,   37  ,   3   ,   123 ,   301 ,   403 ,   1603    ,   2345    ,   1031    ,0 };
            const std::uint32_t dim620Kuo2Init[]        =   {   1   ,   3   ,   5   ,   9   ,   23  ,   55  ,   23  ,   19  ,   497 ,   501 ,   99  ,   1925    ,   6243    ,0 };
            const std::uint32_t dim621Kuo2Init[]        =   {   1   ,   3   ,   5   ,   1   ,   21  ,   37  ,   83  ,   59  ,   285 ,   107 ,   1909    ,   3647    ,   8041    ,0 };
            const std::uint32_t dim622Kuo2Init[]        =   {   1   ,   3   ,   5   ,   1   ,   7   ,   11  ,   91  ,   1   ,   357 ,   643 ,   1319    ,   2895    ,   2193    ,0 };
            const std::uint32_t dim623Kuo2Init[]        =   {   1   ,   1   ,   5   ,   9   ,   27  ,   29  ,   25  ,   125 ,   433 ,   525 ,   1511    ,   585 ,   5263    ,0 };
            const std::uint32_t dim624Kuo2Init[]        =   {   1   ,   3   ,   1   ,   11  ,   13  ,   49  ,   79  ,   37  ,   165 ,   923 ,   749 ,   2207    ,   4673    ,0 };
            const std::uint32_t dim625Kuo2Init[]        =   {   1   ,   1   ,   5   ,   9   ,   29  ,   37  ,   51  ,   3   ,   133 ,   859 ,   153 ,   1199    ,   2269    ,0 };
            const std::uint32_t dim626Kuo2Init[]        =   {   1   ,   1   ,   7   ,   5   ,   9   ,   57  ,   101 ,   231 ,   383 ,   245 ,   1997    ,   2661    ,   6069    ,0 };
            const std::uint32_t dim627Kuo2Init[]        =   {   1   ,   1   ,   7   ,   7   ,   25  ,   61  ,   25  ,   185 ,   247 ,   509 ,   1953    ,   3309    ,   4879    ,0 };
            const std::uint32_t dim628Kuo2Init[]        =   {   1   ,   1   ,   3   ,   7   ,   19  ,   61  ,   95  ,   105 ,   355 ,   219 ,   103 ,   249 ,   579 ,0 };
            const std::uint32_t dim629Kuo2Init[]        =   {   1   ,   3   ,   7   ,   15  ,   7   ,   3   ,   51  ,   143 ,   273 ,   203 ,   353 ,   1587    ,   2239    ,0 };
            const std::uint32_t dim630Kuo2Init[]        =   {   1   ,   3   ,   3   ,   9   ,   27  ,   47  ,   123 ,   185 ,   337 ,   183 ,   983 ,   2313    ,   815 ,0 };
            const std::uint32_t dim631Kuo2Init[]        =   {   1   ,   1   ,   5   ,   15  ,   19  ,   19  ,   3   ,   199 ,   247 ,   151 ,   1911    ,   301 ,   5311    ,0 };
            const std::uint32_t dim632Kuo2Init[]        =   {   1   ,   1   ,   1   ,   3   ,   7   ,   63  ,   61  ,   151 ,   297 ,   541 ,   1457    ,   2945    ,   5703    ,0 };
            const std::uint32_t dim633Kuo2Init[]        =   {   1   ,   3   ,   7   ,   5   ,   31  ,   1   ,   109 ,   179 ,   197 ,   109 ,   695 ,   2429    ,   3483    ,0 };
            const std::uint32_t dim634Kuo2Init[]        =   {   1   ,   3   ,   7   ,   1   ,   27  ,   25  ,   27  ,   113 ,   455 ,   655 ,   1813    ,   2341    ,   4785    ,0 };
            const std::uint32_t dim635Kuo2Init[]        =   {   1   ,   1   ,   5   ,   15  ,   9   ,   47  ,   105 ,   15  ,   75  ,   901 ,   1539    ,   2599    ,   1013    ,0 };
            const std::uint32_t dim636Kuo2Init[]        =   {   1   ,   3   ,   1   ,   11  ,   17  ,   17  ,   29  ,   219 ,   121 ,   383 ,   1575    ,   3153    ,   6151    ,0 };
            const std::uint32_t dim637Kuo2Init[]        =   {   1   ,   1   ,   1   ,   3   ,   29  ,   51  ,   35  ,   95  ,   89  ,   279 ,   1255    ,   2967    ,   455 ,0 };
            const std::uint32_t dim638Kuo2Init[]        =   {   1   ,   3   ,   5   ,   15  ,   3   ,   3   ,   15  ,   181 ,   91  ,   169 ,   1703    ,   777 ,   6539    ,0 };
            const std::uint32_t dim639Kuo2Init[]        =   {   1   ,   1   ,   3   ,   13  ,   15  ,   29  ,   115 ,   225 ,   179 ,   271 ,   737 ,   2425    ,   3149    ,0 };
            const std::uint32_t dim640Kuo2Init[]        =   {   1   ,   3   ,   7   ,   3   ,   13  ,   29  ,   1   ,   169 ,   35  ,   145 ,   725 ,   3679    ,   2593    ,0 };
            const std::uint32_t dim641Kuo2Init[]        =   {   1   ,   1   ,   7   ,   9   ,   11  ,   1   ,   51  ,   65  ,   283 ,   791 ,   449 ,   1387    ,   7347    ,0 };
            const std::uint32_t dim642Kuo2Init[]        =   {   1   ,   3   ,   1   ,   13  ,   21  ,   23  ,   79  ,   207 ,   425 ,   839 ,   737 ,   243 ,   6761    ,0 };
            const std::uint32_t dim643Kuo2Init[]        =   {   1   ,   3   ,   3   ,   5   ,   11  ,   25  ,   93  ,   119 ,   245 ,   539 ,   405 ,   1925    ,   1595    ,0 };
            const std::uint32_t dim644Kuo2Init[]        =   {   1   ,   3   ,   7   ,   15  ,   5   ,   19  ,   97  ,   225 ,   471 ,   801 ,   379 ,   923 ,   1961    ,0 };
            const std::uint32_t dim645Kuo2Init[]        =   {   1   ,   3   ,   7   ,   15  ,   25  ,   49  ,   41  ,   237 ,   11  ,   983 ,   1889    ,   3947    ,   2579    ,0 };
            const std::uint32_t dim646Kuo2Init[]        =   {   1   ,   3   ,   5   ,   13  ,   3   ,   39  ,   51  ,   131 ,   477 ,   699 ,   1101    ,   1289    ,   7683    ,0 };
            const std::uint32_t dim647Kuo2Init[]        =   {   1   ,   1   ,   7   ,   1   ,   23  ,   39  ,   99  ,   167 ,   53  ,   333 ,   1059    ,   2947    ,   2097    ,0 };
            const std::uint32_t dim648Kuo2Init[]        =   {   1   ,   1   ,   5   ,   15  ,   9   ,   55  ,   33  ,   121 ,   485 ,   767 ,   793 ,   1015    ,   7657    ,0 };
            const std::uint32_t dim649Kuo2Init[]        =   {   1   ,   1   ,   7   ,   13  ,   15  ,   57  ,   5   ,   39  ,   197 ,   67  ,   1471    ,   841 ,   1797    ,0 };
            const std::uint32_t dim650Kuo2Init[]        =   {   1   ,   3   ,   5   ,   3   ,   15  ,   17  ,   11  ,   139 ,   21  ,   827 ,   465 ,   1341    ,   1115    ,0 };
            const std::uint32_t dim651Kuo2Init[]        =   {   1   ,   3   ,   7   ,   11  ,   7   ,   3   ,   29  ,   107 ,   79  ,   19  ,   493 ,   1705    ,   4631    ,0 };
            const std::uint32_t dim652Kuo2Init[]        =   {   1   ,   1   ,   7   ,   1   ,   9   ,   61  ,   79  ,   23  ,   83  ,   863 ,   1189    ,   2653    ,   2139    ,0 };
            const std::uint32_t dim653Kuo2Init[]        =   {   1   ,   1   ,   7   ,   7   ,   7   ,   39  ,   105 ,   147 ,   293 ,   799 ,   781 ,   1085    ,   1405    ,0 };
            const std::uint32_t dim654Kuo2Init[]        =   {   1   ,   3   ,   3   ,   13  ,   27  ,   55  ,   89  ,   73  ,   255 ,   845 ,   485 ,   739 ,   4937    ,0 };
            const std::uint32_t dim655Kuo2Init[]        =   {   1   ,   3   ,   1   ,   5   ,   19  ,   41  ,   93  ,   125 ,   203 ,   789 ,   1447    ,   189 ,   4743    ,0 };
            const std::uint32_t dim656Kuo2Init[]        =   {   1   ,   3   ,   3   ,   11  ,   9   ,   9   ,   51  ,   237 ,   353 ,   313 ,   101 ,   873 ,   5605    ,0 };
            const std::uint32_t dim657Kuo2Init[]        =   {   1   ,   3   ,   1   ,   5   ,   1   ,   33  ,   67  ,   29  ,   361 ,   945 ,   5   ,   305 ,   1461    ,0 };
            const std::uint32_t dim658Kuo2Init[]        =   {   1   ,   1   ,   7   ,   3   ,   5   ,   31  ,   47  ,   145 ,   369 ,   419 ,   415 ,   2645    ,   4665    ,0 };
            const std::uint32_t dim659Kuo2Init[]        =   {   1   ,   1   ,   1   ,   1   ,   9   ,   35  ,   3   ,   67  ,   233 ,   991 ,   1683    ,   1145    ,   6283    ,0 };
            const std::uint32_t dim660Kuo2Init[]        =   {   1   ,   1   ,   1   ,   7   ,   13  ,   43  ,   95  ,   141 ,   415 ,   219 ,   1877    ,   2763    ,   3975    ,0 };
            const std::uint32_t dim661Kuo2Init[]        =   {   1   ,   1   ,   3   ,   9   ,   25  ,   1   ,   125 ,   139 ,   31  ,   791 ,   2033    ,   2477    ,   297 ,0 };
            const std::uint32_t dim662Kuo2Init[]        =   {   1   ,   1   ,   3   ,   7   ,   13  ,   53  ,   29  ,   53  ,   341 ,   905 ,   1953    ,   593 ,   3121    ,0 };
            const std::uint32_t dim663Kuo2Init[]        =   {   1   ,   3   ,   3   ,   5   ,   21  ,   45  ,   97  ,   231 ,   377 ,   117 ,   1449    ,   1159    ,   1831    ,0 };
            const std::uint32_t dim664Kuo2Init[]        =   {   1   ,   3   ,   7   ,   3   ,   13  ,   25  ,   33  ,   15  ,   479 ,   141 ,   1101    ,   1611    ,   2145    ,0 };
            const std::uint32_t dim665Kuo2Init[]        =   {   1   ,   3   ,   5   ,   13  ,   19  ,   33  ,   85  ,   215 ,   107 ,   273 ,   1361    ,   1103    ,   3461    ,0 };
            const std::uint32_t dim666Kuo2Init[]        =   {   1   ,   3   ,   5   ,   9   ,   7   ,   29  ,   91  ,   55  ,   239 ,   971 ,   1389    ,   301 ,   6011    ,0 };
            const std::uint32_t dim667Kuo2Init[]        =   {   1   ,   3   ,   3   ,   3   ,   31  ,   39  ,   73  ,   131 ,   53  ,   583 ,   1387    ,   3827    ,   5621    ,0 };
            const std::uint32_t dim668Kuo2Init[]        =   {   1   ,   1   ,   7   ,   1   ,   21  ,   47  ,   39  ,   99  ,   95  ,   915 ,   1281    ,   675 ,   4147    ,0 };
            const std::uint32_t dim669Kuo2Init[]        =   {   1   ,   3   ,   7   ,   13  ,   19  ,   17  ,   121 ,   151 ,   163 ,   447 ,   1741    ,   2563    ,   957 ,0 };
            const std::uint32_t dim670Kuo2Init[]        =   {   1   ,   3   ,   1   ,   11  ,   19  ,   19  ,   9   ,   31  ,   105 ,   829 ,   1957    ,   3327    ,   2923    ,0 };
            const std::uint32_t dim671Kuo2Init[]        =   {   1   ,   1   ,   1   ,   1   ,   29  ,   49  ,   67  ,   135 ,   165 ,   203 ,   691 ,   4043    ,   4973    ,0 };
            const std::uint32_t dim672Kuo2Init[]        =   {   1   ,   3   ,   3   ,   15  ,   17  ,   57  ,   53  ,   123 ,   311 ,   169 ,   1705    ,   3853    ,   3243    ,0 };
            const std::uint32_t dim673Kuo2Init[]        =   {   1   ,   1   ,   7   ,   5   ,   11  ,   51  ,   39  ,   215 ,   209 ,   353 ,   1857    ,   369 ,   1793    ,0 };
            const std::uint32_t dim674Kuo2Init[]        =   {   1   ,   1   ,   1   ,   3   ,   1   ,   55  ,   19  ,   145 ,   283 ,   471 ,   929 ,   3207    ,   5819    ,0 };
            const std::uint32_t dim675Kuo2Init[]        =   {   1   ,   1   ,   3   ,   13  ,   21  ,   23  ,   49  ,   241 ,   53  ,   153 ,   591 ,   949 ,   859 ,0 };
            const std::uint32_t dim676Kuo2Init[]        =   {   1   ,   3   ,   1   ,   5   ,   21  ,   13  ,   105 ,   147 ,   29  ,   407 ,   589 ,   1659    ,   5265    ,0 };
            const std::uint32_t dim677Kuo2Init[]        =   {   1   ,   1   ,   1   ,   9   ,   19  ,   27  ,   83  ,   175 ,   329 ,   459 ,   1401    ,   2195    ,   5997    ,0 };
            const std::uint32_t dim678Kuo2Init[]        =   {   1   ,   1   ,   5   ,   1   ,   29  ,   39  ,   33  ,   73  ,   363 ,   143 ,   617 ,   1507    ,   5871    ,0 };
            const std::uint32_t dim679Kuo2Init[]        =   {   1   ,   1   ,   1   ,   7   ,   29  ,   23  ,   19  ,   51  ,   331 ,   299 ,   1883    ,   1973    ,   1969    ,0 };
            const std::uint32_t dim680Kuo2Init[]        =   {   1   ,   3   ,   7   ,   13  ,   1   ,   49  ,   25  ,   43  ,   17  ,   297 ,   683 ,   1189    ,   6049    ,0 };
            const std::uint32_t dim681Kuo2Init[]        =   {   1   ,   3   ,   1   ,   15  ,   23  ,   25  ,   29  ,   231 ,   425 ,   501 ,   1787    ,   3223    ,   5789    ,0 };
            const std::uint32_t dim682Kuo2Init[]        =   {   1   ,   3   ,   7   ,   1   ,   1   ,   3   ,   23  ,   231 ,   377 ,   485 ,   1469    ,   1089    ,   1539    ,0 };
            const std::uint32_t dim683Kuo2Init[]        =   {   1   ,   1   ,   5   ,   5   ,   29  ,   25  ,   93  ,   51  ,   249 ,   25  ,   1355    ,   23  ,   2961    ,0 };
            const std::uint32_t dim684Kuo2Init[]        =   {   1   ,   3   ,   5   ,   13  ,   11  ,   55  ,   117 ,   221 ,   137 ,   941 ,   1127    ,   735 ,   4835    ,0 };
            const std::uint32_t dim685Kuo2Init[]        =   {   1   ,   3   ,   3   ,   15  ,   5   ,   53  ,   35  ,   245 ,   31  ,   985 ,   2035    ,   163 ,   5223    ,0 };
            const std::uint32_t dim686Kuo2Init[]        =   {   1   ,   1   ,   7   ,   7   ,   27  ,   25  ,   17  ,   113 ,   187 ,   283 ,   723 ,   2703    ,   4873    ,0 };
            const std::uint32_t dim687Kuo2Init[]        =   {   1   ,   1   ,   1   ,   1   ,   3   ,   61  ,   81  ,   125 ,   335 ,   997 ,   975 ,   2371    ,   1829    ,0 };
            const std::uint32_t dim688Kuo2Init[]        =   {   1   ,   3   ,   1   ,   15  ,   21  ,   9   ,   67  ,   55  ,   109 ,   657 ,   837 ,   1737    ,   5147    ,0 };
            const std::uint32_t dim689Kuo2Init[]        =   {   1   ,   1   ,   3   ,   3   ,   19  ,   41  ,   117 ,   39  ,   441 ,   985 ,   955 ,   1467    ,   7297    ,0 };
            const std::uint32_t dim690Kuo2Init[]        =   {   1   ,   1   ,   7   ,   7   ,   23  ,   1   ,   11  ,   11  ,   221 ,   539 ,   1807    ,   1887    ,   7921    ,0 };
            const std::uint32_t dim691Kuo2Init[]        =   {   1   ,   3   ,   3   ,   1   ,   27  ,   45  ,   73  ,   39  ,   217 ,   233 ,   2015    ,   1209    ,   7101    ,0 };
            const std::uint32_t dim692Kuo2Init[]        =   {   1   ,   3   ,   1   ,   11  ,   19  ,   57  ,   85  ,   45  ,   395 ,   23  ,   405 ,   2723    ,   653 ,0 };
            const std::uint32_t dim693Kuo2Init[]        =   {   1   ,   1   ,   5   ,   15  ,   3   ,   43  ,   95  ,   149 ,   395 ,   359 ,   1067    ,   3571    ,   6219    ,0 };
            const std::uint32_t dim694Kuo2Init[]        =   {   1   ,   1   ,   5   ,   5   ,   15  ,   3   ,   33  ,   181 ,   427 ,   565 ,   103 ,   261 ,   2375    ,0 };
            const std::uint32_t dim695Kuo2Init[]        =   {   1   ,   3   ,   3   ,   15  ,   1   ,   3   ,   89  ,   239 ,   461 ,   675 ,   1149    ,   819 ,   3481    ,0 };
            const std::uint32_t dim696Kuo2Init[]        =   {   1   ,   1   ,   5   ,   9   ,   23  ,   57  ,   1   ,   147 ,   245 ,   941 ,   1425    ,   2403    ,   7915    ,0 };
            const std::uint32_t dim697Kuo2Init[]        =   {   1   ,   3   ,   1   ,   13  ,   3   ,   25  ,   43  ,   205 ,   295 ,   799 ,   1845    ,   2695    ,   3183    ,0 };
            const std::uint32_t dim698Kuo2Init[]        =   {   1   ,   3   ,   1   ,   15  ,   11  ,   19  ,   111 ,   83  ,   479 ,   927 ,   709 ,   2739    ,   1233    ,0 };
            const std::uint32_t dim699Kuo2Init[]        =   {   1   ,   3   ,   7   ,   13  ,   25  ,   41  ,   49  ,   39  ,   63  ,   265 ,   717 ,   3843    ,   3091    ,0 };
            const std::uint32_t dim700Kuo2Init[]        =   {   1   ,   3   ,   1   ,   5   ,   27  ,   11  ,   55  ,   31  ,   103 ,   263 ,   759 ,   1969    ,   1301    ,0 };
            const std::uint32_t dim701Kuo2Init[]        =   {   1   ,   1   ,   7   ,   15  ,   15  ,   33  ,   61  ,   93  ,   177 ,   645 ,   387 ,   3999    ,   4511    ,0 };
            const std::uint32_t dim702Kuo2Init[]        =   {   1   ,   1   ,   7   ,   9   ,   5   ,   43  ,   87  ,   125 ,   443 ,   825 ,   1423    ,   1575    ,   2661    ,0 };
            const std::uint32_t dim703Kuo2Init[]        =   {   1   ,   3   ,   1   ,   5   ,   3   ,   59  ,   59  ,   91  ,   63  ,   805 ,   1461    ,   4009    ,   4235    ,0 };
            const std::uint32_t dim704Kuo2Init[]        =   {   1   ,   1   ,   3   ,   7   ,   15  ,   13  ,   95  ,   179 ,   479 ,   735 ,   1075    ,   4089    ,   4807    ,0 };
            const std::uint32_t dim705Kuo2Init[]        =   {   1   ,   3   ,   1   ,   3   ,   23  ,   63  ,   63  ,   77  ,   299 ,   939 ,   661 ,   1007    ,   3299    ,0 };
            const std::uint32_t dim706Kuo2Init[]        =   {   1   ,   1   ,   5   ,   3   ,   7   ,   49  ,   1   ,   217 ,   87  ,   561 ,   275 ,   3137    ,   4355    ,0 };
            const std::uint32_t dim707Kuo2Init[]        =   {   1   ,   3   ,   5   ,   9   ,   21  ,   25  ,   49  ,   199 ,   207 ,   513 ,   231 ,   3053    ,   8023    ,0 };
            const std::uint32_t dim708Kuo2Init[]        =   {   1   ,   1   ,   5   ,   1   ,   19  ,   39  ,   79  ,   225 ,   213 ,   719 ,   577 ,   3885    ,   7151    ,0 };
            const std::uint32_t dim709Kuo2Init[]        =   {   1   ,   3   ,   1   ,   7   ,   9   ,   7   ,   9   ,   63  ,   185 ,   877 ,   253 ,   1401    ,   7665    ,0 };
            const std::uint32_t dim710Kuo2Init[]        =   {   1   ,   1   ,   7   ,   15  ,   7   ,   9   ,   33  ,   79  ,   241 ,   727 ,   681 ,   2195    ,   5285    ,0 };
            const std::uint32_t dim711Kuo2Init[]        =   {   1   ,   3   ,   3   ,   9   ,   21  ,   27  ,   9   ,   17  ,   277 ,   365 ,   1497    ,   2323    ,   1215    ,0 };
            const std::uint32_t dim712Kuo2Init[]        =   {   1   ,   1   ,   3   ,   3   ,   29  ,   23  ,   63  ,   209 ,   487 ,   243 ,   1137    ,   45  ,   3949    ,0 };
            const std::uint32_t dim713Kuo2Init[]        =   {   1   ,   1   ,   1   ,   15  ,   1   ,   33  ,   29  ,   245 ,   25  ,   497 ,   809 ,   4017    ,   2149    ,0 };
            const std::uint32_t dim714Kuo2Init[]        =   {   1   ,   3   ,   3   ,   3   ,   25  ,   11  ,   117 ,   129 ,   23  ,   547 ,   175 ,   463 ,   2731    ,0 };
            const std::uint32_t dim715Kuo2Init[]        =   {   1   ,   3   ,   3   ,   3   ,   5   ,   47  ,   69  ,   197 ,   131 ,   101 ,   1003    ,   1573    ,   3629    ,0 };
            const std::uint32_t dim716Kuo2Init[]        =   {   1   ,   1   ,   1   ,   9   ,   7   ,   33  ,   63  ,   53  ,   159 ,   1009    ,   963 ,   203 ,   3395    ,0 };
            const std::uint32_t dim717Kuo2Init[]        =   {   1   ,   3   ,   1   ,   1   ,   9   ,   11  ,   95  ,   73  ,   359 ,   357 ,   421 ,   1169    ,   7317    ,0 };
            const std::uint32_t dim718Kuo2Init[]        =   {   1   ,   3   ,   5   ,   15  ,   27  ,   57  ,   105 ,   109 ,   457 ,   161 ,   901 ,   2239    ,   2143    ,0 };
            const std::uint32_t dim719Kuo2Init[]        =   {   1   ,   1   ,   3   ,   7   ,   7   ,   61  ,   11  ,   211 ,   7   ,   515 ,   895 ,   1341    ,   2603    ,0 };
            const std::uint32_t dim720Kuo2Init[]        =   {   1   ,   3   ,   3   ,   3   ,   7   ,   15  ,   67  ,   237 ,   5   ,   345 ,   1631    ,   923 ,   4269    ,0 };
            const std::uint32_t dim721Kuo2Init[]        =   {   1   ,   1   ,   1   ,   15  ,   15  ,   27  ,   73  ,   7   ,   359 ,   49  ,   381 ,   2415    ,   1979    ,0 };
            const std::uint32_t dim722Kuo2Init[]        =   {   1   ,   3   ,   7   ,   7   ,   15  ,   33  ,   1   ,   39  ,   19  ,   171 ,   93  ,   1815    ,   2675    ,0 };
            const std::uint32_t dim723Kuo2Init[]        =   {   1   ,   3   ,   7   ,   9   ,   13  ,   37  ,   85  ,   75  ,   395 ,   767 ,   1855    ,   3413    ,   1845    ,0 };
            const std::uint32_t dim724Kuo2Init[]        =   {   1   ,   3   ,   5   ,   15  ,   7   ,   59  ,   33  ,   235 ,   455 ,   21  ,   237 ,   3103    ,   6065    ,0 };
            const std::uint32_t dim725Kuo2Init[]        =   {   1   ,   1   ,   3   ,   3   ,   29  ,   9   ,   67  ,   173 ,   303 ,   9   ,   1899    ,   3799    ,   63  ,0 };
            const std::uint32_t dim726Kuo2Init[]        =   {   1   ,   1   ,   3   ,   5   ,   15  ,   53  ,   13  ,   149 ,   45  ,   223 ,   823 ,   1351    ,   4517    ,0 };
            const std::uint32_t dim727Kuo2Init[]        =   {   1   ,   3   ,   3   ,   15  ,   21  ,   59  ,   81  ,   185 ,   245 ,   589 ,   1149    ,   3351    ,   4879    ,0 };
            const std::uint32_t dim728Kuo2Init[]        =   {   1   ,   1   ,   1   ,   1   ,   11  ,   29  ,   17  ,   57  ,   199 ,   941 ,   1497    ,   227 ,   6271    ,0 };
            const std::uint32_t dim729Kuo2Init[]        =   {   1   ,   3   ,   5   ,   7   ,   13  ,   35  ,   97  ,   247 ,   439 ,   687 ,   1821    ,   1583    ,   5919    ,0 };
            const std::uint32_t dim730Kuo2Init[]        =   {   1   ,   1   ,   3   ,   7   ,   27  ,   25  ,   123 ,   129 ,   15  ,   497 ,   1491    ,   171 ,   6369    ,0 };
            const std::uint32_t dim731Kuo2Init[]        =   {   1   ,   3   ,   1   ,   1   ,   25  ,   27  ,   63  ,   27  ,   261 ,   707 ,   579 ,   2599    ,   5925    ,0 };
            const std::uint32_t dim732Kuo2Init[]        =   {   1   ,   1   ,   3   ,   9   ,   9   ,   39  ,   63  ,   141 ,   293 ,   601 ,   573 ,   445 ,   1003    ,0 };
            const std::uint32_t dim733Kuo2Init[]        =   {   1   ,   3   ,   3   ,   15  ,   7   ,   25  ,   21  ,   189 ,   137 ,   13  ,   1923    ,   1019    ,   7219    ,0 };
            const std::uint32_t dim734Kuo2Init[]        =   {   1   ,   3   ,   5   ,   9   ,   27  ,   45  ,   13  ,   251 ,   403 ,   781 ,   2009    ,   239 ,   4777    ,0 };
            const std::uint32_t dim735Kuo2Init[]        =   {   1   ,   1   ,   5   ,   3   ,   21  ,   35  ,   93  ,   89  ,   249 ,   473 ,   1241    ,   2485    ,   291 ,0 };
            const std::uint32_t dim736Kuo2Init[]        =   {   1   ,   3   ,   7   ,   15  ,   5   ,   53  ,   45  ,   213 ,   41  ,   393 ,   529 ,   599 ,   4993    ,0 };
            const std::uint32_t dim737Kuo2Init[]        =   {   1   ,   3   ,   7   ,   5   ,   29  ,   29  ,   9   ,   163 ,   27  ,   617 ,   2015    ,   117 ,   6065    ,0 };
            const std::uint32_t dim738Kuo2Init[]        =   {   1   ,   1   ,   7   ,   3   ,   9   ,   19  ,   31  ,   67  ,   395 ,   1003    ,   1907    ,   1165    ,   3375    ,0 };
            const std::uint32_t dim739Kuo2Init[]        =   {   1   ,   1   ,   7   ,   1   ,   1   ,   37  ,   41  ,   131 ,   397 ,   181 ,   481 ,   2691    ,   6519    ,0 };
            const std::uint32_t dim740Kuo2Init[]        =   {   1   ,   3   ,   5   ,   3   ,   9   ,   31  ,   127 ,   145 ,   435 ,   149 ,   597 ,   3611    ,   7715    ,0 };
            const std::uint32_t dim741Kuo2Init[]        =   {   1   ,   1   ,   3   ,   9   ,   27  ,   33  ,   37  ,   165 ,   167 ,   699 ,   1313    ,   3599    ,   827 ,0 };
            const std::uint32_t dim742Kuo2Init[]        =   {   1   ,   1   ,   1   ,   9   ,   15  ,   3   ,   21  ,   123 ,   319 ,   1009    ,   901 ,   819 ,   823 ,0 };
            const std::uint32_t dim743Kuo2Init[]        =   {   1   ,   1   ,   7   ,   9   ,   29  ,   27  ,   101 ,   33  ,   341 ,   449 ,   607 ,   2807    ,   5553    ,0 };
            const std::uint32_t dim744Kuo2Init[]        =   {   1   ,   3   ,   5   ,   3   ,   21  ,   25  ,   41  ,   105 ,   255 ,   339 ,   1971    ,   175 ,   47  ,0 };
            const std::uint32_t dim745Kuo2Init[]        =   {   1   ,   1   ,   3   ,   5   ,   5   ,   3   ,   21  ,   73  ,   111 ,   293 ,   1283    ,   2531    ,   7609    ,0 };
            const std::uint32_t dim746Kuo2Init[]        =   {   1   ,   3   ,   7   ,   3   ,   29  ,   47  ,   83  ,   165 ,   249 ,   281 ,   175 ,   1043    ,   4143    ,0 };
            const std::uint32_t dim747Kuo2Init[]        =   {   1   ,   3   ,   1   ,   15  ,   27  ,   59  ,   3   ,   101 ,   343 ,   813 ,   1559    ,   553 ,   7801    ,0 };
            const std::uint32_t dim748Kuo2Init[]        =   {   1   ,   1   ,   7   ,   15  ,   1   ,   9   ,   77  ,   205 ,   151 ,   255 ,   701 ,   2653    ,   2079    ,0 };
            const std::uint32_t dim749Kuo2Init[]        =   {   1   ,   3   ,   3   ,   3   ,   13  ,   39  ,   37  ,   161 ,   499 ,   657 ,   1557    ,   3969    ,   3489    ,0 };
            const std::uint32_t dim750Kuo2Init[]        =   {   1   ,   1   ,   1   ,   15  ,   9   ,   27  ,   41  ,   253 ,   119 ,   583 ,   73  ,   3255    ,   6067    ,0 };
            const std::uint32_t dim751Kuo2Init[]        =   {   1   ,   1   ,   7   ,   7   ,   27  ,   43  ,   53  ,   99  ,   245 ,   169 ,   659 ,   81  ,   2943    ,0 };
            const std::uint32_t dim752Kuo2Init[]        =   {   1   ,   1   ,   1   ,   11  ,   27  ,   13  ,   41  ,   217 ,   493 ,   145 ,   835 ,   3745    ,   97  ,0 };
            const std::uint32_t dim753Kuo2Init[]        =   {   1   ,   3   ,   1   ,   9   ,   7   ,   13  ,   117 ,   113 ,   197 ,   503 ,   953 ,   2433    ,   7663    ,0 };
            const std::uint32_t dim754Kuo2Init[]        =   {   1   ,   3   ,   5   ,   5   ,   9   ,   47  ,   101 ,   47  ,   187 ,   469 ,   69  ,   4031    ,   6231    ,0 };
            const std::uint32_t dim755Kuo2Init[]        =   {   1   ,   1   ,   1   ,   3   ,   27  ,   27  ,   47  ,   219 ,   11  ,   201 ,   1267    ,   2703    ,   6711    ,0 };
            const std::uint32_t dim756Kuo2Init[]        =   {   1   ,   3   ,   7   ,   7   ,   27  ,   27  ,   97  ,   101 ,   7   ,   541 ,   105 ,   3821    ,   7533    ,0 };
            const std::uint32_t dim757Kuo2Init[]        =   {   1   ,   3   ,   5   ,   13  ,   21  ,   17  ,   99  ,   213 ,   347 ,   595 ,   519 ,   1113    ,   5427    ,0 };
            const std::uint32_t dim758Kuo2Init[]        =   {   1   ,   1   ,   7   ,   13  ,   31  ,   1   ,   25  ,   111 ,   387 ,   27  ,   99  ,   119 ,   3265    ,0 };
            const std::uint32_t dim759Kuo2Init[]        =   {   1   ,   1   ,   7   ,   15  ,   11  ,   43  ,   19  ,   177 ,   11  ,   943 ,   3   ,   623 ,   4223    ,0 };
            const std::uint32_t dim760Kuo2Init[]        =   {   1   ,   3   ,   7   ,   3   ,   31  ,   59  ,   21  ,   241 ,   375 ,   703 ,   1465    ,   2375    ,   2853    ,0 };
            const std::uint32_t dim761Kuo2Init[]        =   {   1   ,   1   ,   7   ,   15  ,   1   ,   49  ,   51  ,   161 ,   397 ,   583 ,   913 ,   985 ,   5519    ,0 };
            const std::uint32_t dim762Kuo2Init[]        =   {   1   ,   3   ,   1   ,   3   ,   13  ,   37  ,   23  ,   165 ,   223 ,   427 ,   129 ,   1553    ,   4145    ,0 };
            const std::uint32_t dim763Kuo2Init[]        =   {   1   ,   3   ,   3   ,   3   ,   1   ,   23  ,   47  ,   237 ,   371 ,   315 ,   1631    ,   2037    ,   61  ,0 };
            const std::uint32_t dim764Kuo2Init[]        =   {   1   ,   3   ,   5   ,   15  ,   23  ,   59  ,   71  ,   237 ,   487 ,   443 ,   1475    ,   3065    ,   2453    ,0 };
            const std::uint32_t dim765Kuo2Init[]        =   {   1   ,   1   ,   3   ,   13  ,   25  ,   57  ,   71  ,   3   ,   247 ,   145 ,   2011    ,   553 ,   7565    ,0 };
            const std::uint32_t dim766Kuo2Init[]        =   {   1   ,   1   ,   1   ,   9   ,   21  ,   1   ,   61  ,   91  ,   3   ,   807 ,   1795    ,   2665    ,   473 ,0 };
            const std::uint32_t dim767Kuo2Init[]        =   {   1   ,   3   ,   7   ,   11  ,   9   ,   7   ,   123 ,   233 ,   249 ,   825 ,   1505    ,   3599    ,   6653    ,0 };
            const std::uint32_t dim768Kuo2Init[]        =   {   1   ,   1   ,   3   ,   15  ,   11  ,   37  ,   119 ,   63  ,   233 ,   541 ,   1373    ,   765 ,   4913    ,0 };
            const std::uint32_t dim769Kuo2Init[]        =   {   1   ,   1   ,   1   ,   9   ,   5   ,   15  ,   77  ,   65  ,   321 ,   613 ,   1857    ,   3699    ,   1   ,0 };
            const std::uint32_t dim770Kuo2Init[]        =   {   1   ,   3   ,   1   ,   15  ,   13  ,   37  ,   123 ,   9   ,   105 ,   121 ,   893 ,   1009    ,   7871    ,0 };
            const std::uint32_t dim771Kuo2Init[]        =   {   1   ,   3   ,   5   ,   1   ,   23  ,   61  ,   29  ,   223 ,   209 ,   605 ,   409 ,   875 ,   5233    ,0 };
            const std::uint32_t dim772Kuo2Init[]        =   {   1   ,   1   ,   3   ,   11  ,   5   ,   61  ,   9   ,   85  ,   361 ,   613 ,   1555    ,   2323    ,   5119    ,0 };
            const std::uint32_t dim773Kuo2Init[]        =   {   1   ,   1   ,   1   ,   1   ,   17  ,   49  ,   67  ,   191 ,   247 ,   873 ,   1283    ,   171 ,   1689    ,0 };
            const std::uint32_t dim774Kuo2Init[]        =   {   1   ,   3   ,   3   ,   13  ,   17  ,   17  ,   45  ,   73  ,   175 ,   243 ,   97  ,   315 ,   1429    ,0 };
            const std::uint32_t dim775Kuo2Init[]        =   {   1   ,   3   ,   5   ,   5   ,   13  ,   1   ,   113 ,   87  ,   241 ,   199 ,   145 ,   3823    ,   5965    ,0 };
            const std::uint32_t dim776Kuo2Init[]        =   {   1   ,   3   ,   3   ,   7   ,   7   ,   47  ,   115 ,   139 ,   239 ,   547 ,   109 ,   2251    ,   6987    ,0 };
            const std::uint32_t dim777Kuo2Init[]        =   {   1   ,   3   ,   1   ,   11  ,   3   ,   59  ,   111 ,   225 ,   385 ,   887 ,   425 ,   1879    ,   4535    ,0 };
            const std::uint32_t dim778Kuo2Init[]        =   {   1   ,   1   ,   3   ,   9   ,   27  ,   35  ,   55  ,   125 ,   379 ,   529 ,   191 ,   1657    ,   2835    ,0 };
            const std::uint32_t dim779Kuo2Init[]        =   {   1   ,   1   ,   7   ,   11  ,   25  ,   11  ,   85  ,   21  ,   65  ,   377 ,   1989    ,   1963    ,   6985    ,0 };
            const std::uint32_t dim780Kuo2Init[]        =   {   1   ,   3   ,   7   ,   11  ,   15  ,   59  ,   91  ,   51  ,   145 ,   627 ,   1617    ,   3029    ,   3621    ,0 };
            const std::uint32_t dim781Kuo2Init[]        =   {   1   ,   3   ,   7   ,   11  ,   29  ,   9   ,   15  ,   189 ,   495 ,   997 ,   467 ,   343 ,   7615    ,0 };
            const std::uint32_t dim782Kuo2Init[]        =   {   1   ,   1   ,   7   ,   7   ,   17  ,   37  ,   89  ,   31  ,   355 ,   323 ,   1361    ,   3785    ,   643 ,0 };
            const std::uint32_t dim783Kuo2Init[]        =   {   1   ,   1   ,   7   ,   1   ,   27  ,   19  ,   15  ,   5   ,   383 ,   1023    ,   923 ,   3283    ,   2997    ,0 };
            const std::uint32_t dim784Kuo2Init[]        =   {   1   ,   3   ,   7   ,   15  ,   11  ,   41  ,   117 ,   255 ,   407 ,   117 ,   495 ,   99  ,   7687    ,0 };
            const std::uint32_t dim785Kuo2Init[]        =   {   1   ,   1   ,   1   ,   9   ,   9   ,   29  ,   109 ,   103 ,   81  ,   237 ,   1547    ,   3083    ,   2449    ,0 };
            const std::uint32_t dim786Kuo2Init[]        =   {   1   ,   3   ,   5   ,   1   ,   19  ,   57  ,   43  ,   215 ,   251 ,   417 ,   1719    ,   3767    ,   1543    ,0 };
            const std::uint32_t dim787Kuo2Init[]        =   {   1   ,   3   ,   7   ,   11  ,   15  ,   9   ,   1   ,   171 ,   439 ,   637 ,   1709    ,   1483    ,   4111    ,0 };
            const std::uint32_t dim788Kuo2Init[]        =   {   1   ,   3   ,   1   ,   5   ,   25  ,   31  ,   101 ,   101 ,   301 ,   169 ,   803 ,   2119    ,   5035    ,0 };
            const std::uint32_t dim789Kuo2Init[]        =   {   1   ,   1   ,   7   ,   5   ,   21  ,   57  ,   59  ,   149 ,   31  ,   1023    ,   1063    ,   2465    ,   1517    ,0 };
            const std::uint32_t dim790Kuo2Init[]        =   {   1   ,   1   ,   5   ,   5   ,   7   ,   29  ,   101 ,   19  ,   49  ,   187 ,   715 ,   843 ,   1553    ,0 };
            const std::uint32_t dim791Kuo2Init[]        =   {   1   ,   3   ,   3   ,   5   ,   21  ,   43  ,   27  ,   203 ,   125 ,   629 ,   1395    ,   15  ,   7647    ,0 };
            const std::uint32_t dim792Kuo2Init[]        =   {   1   ,   1   ,   3   ,   11  ,   27  ,   49  ,   69  ,   135 ,   447 ,   503 ,   1589    ,   209 ,   791 ,0 };
            const std::uint32_t dim793Kuo2Init[]        =   {   1   ,   3   ,   1   ,   15  ,   17  ,   57  ,   27  ,   55  ,   237 ,   223 ,   949 ,   2119    ,   3221    ,0 };
            const std::uint32_t dim794Kuo2Init[]        =   {   1   ,   3   ,   3   ,   9   ,   3   ,   37  ,   43  ,   49  ,   41  ,   899 ,   1657    ,   2463    ,   1303    ,0 };
            const std::uint32_t dim795Kuo2Init[]        =   {   1   ,   1   ,   7   ,   13  ,   27  ,   27  ,   19  ,   93  ,   139 ,   745 ,   889 ,   951 ,   6925    ,0 };
            const std::uint32_t dim796Kuo2Init[]        =   {   1   ,   3   ,   1   ,   13  ,   15  ,   33  ,   97  ,   217 ,   333 ,   295 ,   683 ,   397 ,   3889    ,0 };
            const std::uint32_t dim797Kuo2Init[]        =   {   1   ,   3   ,   5   ,   15  ,   17  ,   57  ,   47  ,   173 ,   15  ,   77  ,   863 ,   1441    ,   6851    ,0 };
            const std::uint32_t dim798Kuo2Init[]        =   {   1   ,   3   ,   5   ,   7   ,   3   ,   43  ,   21  ,   37  ,   349 ,   1021    ,   725 ,   1985    ,   481 ,0 };
            const std::uint32_t dim799Kuo2Init[]        =   {   1   ,   1   ,   1   ,   13  ,   9   ,   45  ,   85  ,   177 ,   15  ,   915 ,   187 ,   15  ,   6621    ,0 };
            const std::uint32_t dim800Kuo2Init[]        =   {   1   ,   3   ,   5   ,   11  ,   5   ,   29  ,   113 ,   95  ,   461 ,   607 ,   1637    ,   1897    ,   721 ,0 };
            const std::uint32_t dim801Kuo2Init[]        =   {   1   ,   3   ,   1   ,   11  ,   13  ,   23  ,   55  ,   169 ,   29  ,   803 ,   1433    ,   2113    ,   7255    ,0 };
            const std::uint32_t dim802Kuo2Init[]        =   {   1   ,   1   ,   5   ,   3   ,   31  ,   1   ,   45  ,   251 ,   129 ,   267 ,   1489    ,   427 ,   4993    ,0 };
            const std::uint32_t dim803Kuo2Init[]        =   {   1   ,   1   ,   1   ,   9   ,   9   ,   11  ,   19  ,   31  ,   493 ,   195 ,   1545    ,   2681    ,   2187    ,0 };
            const std::uint32_t dim804Kuo2Init[]        =   {   1   ,   3   ,   1   ,   7   ,   3   ,   51  ,   121 ,   149 ,   325 ,   921 ,   241 ,   999 ,   6039    ,0 };
            const std::uint32_t dim805Kuo2Init[]        =   {   1   ,   3   ,   3   ,   15  ,   17  ,   37  ,   41  ,   157 ,   209 ,   587 ,   1351    ,   2353    ,   1197    ,0 };
            const std::uint32_t dim806Kuo2Init[]        =   {   1   ,   1   ,   5   ,   13  ,   13  ,   55  ,   45  ,   3   ,   475 ,   9   ,   11  ,   3175    ,   2185    ,0 };
            const std::uint32_t dim807Kuo2Init[]        =   {   1   ,   3   ,   5   ,   13  ,   31  ,   33  ,   63  ,   149 ,   463 ,   493 ,   1483    ,   1457    ,   6051    ,0 };
            const std::uint32_t dim808Kuo2Init[]        =   {   1   ,   1   ,   1   ,   3   ,   3   ,   11  ,   119 ,   177 ,   207 ,   631 ,   105 ,   263 ,   2533    ,0 };
            const std::uint32_t dim809Kuo2Init[]        =   {   1   ,   1   ,   1   ,   15  ,   23  ,   27  ,   73  ,   77  ,   143 ,   523 ,   1883    ,   3289    ,   1685    ,0 };
            const std::uint32_t dim810Kuo2Init[]        =   {   1   ,   3   ,   1   ,   5   ,   21  ,   31  ,   25  ,   183 ,   71  ,   679 ,   1697    ,   3473    ,   4233    ,0 };
            const std::uint32_t dim811Kuo2Init[]        =   {   1   ,   1   ,   7   ,   15  ,   9   ,   13  ,   103 ,   125 ,   223 ,   83  ,   1255    ,   2755    ,   1447    ,0 };
            const std::uint32_t dim812Kuo2Init[]        =   {   1   ,   3   ,   5   ,   15  ,   15  ,   51  ,   69  ,   101 ,   369 ,   463 ,   1515    ,   3485    ,   1871    ,0 };
            const std::uint32_t dim813Kuo2Init[]        =   {   1   ,   3   ,   5   ,   7   ,   21  ,   31  ,   55  ,   223 ,   477 ,   995 ,   147 ,   387 ,   7917    ,0 };
            const std::uint32_t dim814Kuo2Init[]        =   {   1   ,   3   ,   5   ,   5   ,   7   ,   31  ,   73  ,   243 ,   283 ,   949 ,   705 ,   449 ,   3309    ,0 };
            const std::uint32_t dim815Kuo2Init[]        =   {   1   ,   1   ,   5   ,   9   ,   15  ,   5   ,   25  ,   219 ,   379 ,   1013    ,   1683    ,   703 ,   4855    ,0 };
            const std::uint32_t dim816Kuo2Init[]        =   {   1   ,   1   ,   7   ,   15  ,   25  ,   15  ,   99  ,   217 ,   265 ,   851 ,   149 ,   1557    ,   8107    ,0 };
            const std::uint32_t dim817Kuo2Init[]        =   {   1   ,   3   ,   3   ,   5   ,   1   ,   59  ,   35  ,   119 ,   245 ,   9   ,   765 ,   833 ,   1707    ,0 };
            const std::uint32_t dim818Kuo2Init[]        =   {   1   ,   1   ,   1   ,   13  ,   23  ,   49  ,   25  ,   153 ,   215 ,   365 ,   1943    ,   2975    ,   1301    ,0 };
            const std::uint32_t dim819Kuo2Init[]        =   {   1   ,   3   ,   5   ,   7   ,   15  ,   45  ,   25  ,   215 ,   225 ,   431 ,   1161    ,   2389    ,   1969    ,0 };
            const std::uint32_t dim820Kuo2Init[]        =   {   1   ,   3   ,   5   ,   9   ,   19  ,   31  ,   121 ,   189 ,   331 ,   23  ,   419 ,   3171    ,   6241    ,0 };
            const std::uint32_t dim821Kuo2Init[]        =   {   1   ,   1   ,   5   ,   5   ,   17  ,   39  ,   69  ,   215 ,   307 ,   827 ,   557 ,   3251    ,   3211    ,0 };
            const std::uint32_t dim822Kuo2Init[]        =   {   1   ,   1   ,   3   ,   11  ,   31  ,   27  ,   23  ,   119 ,   463 ,   605 ,   453 ,   1573    ,   1981    ,0 };
            const std::uint32_t dim823Kuo2Init[]        =   {   1   ,   1   ,   5   ,   11  ,   1   ,   15  ,   37  ,   111 ,   481 ,   331 ,   1481    ,   1013    ,   3259    ,0 };
            const std::uint32_t dim824Kuo2Init[]        =   {   1   ,   1   ,   1   ,   11  ,   21  ,   39  ,   25  ,   183 ,   351 ,   553 ,   3   ,   3969    ,   2551    ,0 };
            const std::uint32_t dim825Kuo2Init[]        =   {   1   ,   3   ,   7   ,   1   ,   19  ,   5   ,   3   ,   55  ,   483 ,   373 ,   1529    ,   535 ,   4215    ,0 };
            const std::uint32_t dim826Kuo2Init[]        =   {   1   ,   1   ,   3   ,   1   ,   25  ,   61  ,   89  ,   197 ,   465 ,   493 ,   661 ,   2361    ,   4211    ,0 };
            const std::uint32_t dim827Kuo2Init[]        =   {   1   ,   3   ,   1   ,   9   ,   29  ,   61  ,   59  ,   175 ,   389 ,   973 ,   1763    ,   4077    ,   6211    ,0 };
            const std::uint32_t dim828Kuo2Init[]        =   {   1   ,   3   ,   1   ,   7   ,   11  ,   41  ,   117 ,   75  ,   291 ,   125 ,   273 ,   5   ,   8169    ,0 };
            const std::uint32_t dim829Kuo2Init[]        =   {   1   ,   1   ,   5   ,   11  ,   21  ,   53  ,   121 ,   31  ,   451 ,   631 ,   1901    ,   4059    ,   6801    ,0 };
            const std::uint32_t dim830Kuo2Init[]        =   {   1   ,   3   ,   7   ,   3   ,   13  ,   33  ,   51  ,   247 ,   409 ,   881 ,   935 ,   1927    ,   1559    ,0 };
            const std::uint32_t dim831Kuo2Init[]        =   {   1   ,   1   ,   3   ,   13  ,   15  ,   51  ,   105 ,   209 ,   159 ,   333 ,   325 ,   3699    ,   5461    ,0 };
            const std::uint32_t dim832Kuo2Init[]        =   {   1   ,   3   ,   3   ,   5   ,   17  ,   7   ,   47  ,   57  ,   59  ,   673 ,   611 ,   253 ,   1531    ,0 };
            const std::uint32_t dim833Kuo2Init[]        =   {   1   ,   1   ,   7   ,   1   ,   19  ,   27  ,   15  ,   189 ,   319 ,   649 ,   1593    ,   875 ,   8187    ,0 };
            const std::uint32_t dim834Kuo2Init[]        =   {   1   ,   1   ,   1   ,   3   ,   15  ,   17  ,   81  ,   183 ,   409 ,   433 ,   679 ,   1881    ,   7827    ,0 };
            const std::uint32_t dim835Kuo2Init[]        =   {   1   ,   1   ,   3   ,   9   ,   23  ,   37  ,   83  ,   235 ,   225 ,   599 ,   1979    ,   2871    ,   1353    ,0 };
            const std::uint32_t dim836Kuo2Init[]        =   {   1   ,   1   ,   7   ,   7   ,   27  ,   11  ,   93  ,   115 ,   339 ,   233 ,   1733    ,   2071    ,   3187    ,0 };
            const std::uint32_t dim837Kuo2Init[]        =   {   1   ,   1   ,   1   ,   7   ,   27  ,   47  ,   61  ,   73  ,   361 ,   621 ,   1907    ,   3103    ,   1873    ,0 };
            const std::uint32_t dim838Kuo2Init[]        =   {   1   ,   1   ,   1   ,   9   ,   9   ,   13  ,   67  ,   161 ,   21  ,   953 ,   1101    ,   2255    ,   4841    ,0 };
            const std::uint32_t dim839Kuo2Init[]        =   {   1   ,   3   ,   7   ,   7   ,   29  ,   39  ,   31  ,   73  ,   351 ,   401 ,   441 ,   4085    ,   2829    ,0 };
            const std::uint32_t dim840Kuo2Init[]        =   {   1   ,   1   ,   5   ,   15  ,   9   ,   23  ,   127 ,   111 ,   309 ,   955 ,   623 ,   1995    ,   1961    ,0 };
            const std::uint32_t dim841Kuo2Init[]        =   {   1   ,   3   ,   5   ,   9   ,   3   ,   3   ,   27  ,   91  ,   287 ,   73  ,   1449    ,   1347    ,   8069    ,0 };
            const std::uint32_t dim842Kuo2Init[]        =   {   1   ,   1   ,   5   ,   3   ,   9   ,   49  ,   87  ,   3   ,   59  ,   193 ,   1999    ,   2295    ,   2247    ,0 };
            const std::uint32_t dim843Kuo2Init[]        =   {   1   ,   3   ,   3   ,   3   ,   21  ,   21  ,   97  ,   47  ,   195 ,   65  ,   1281    ,   1411    ,   6503    ,0 };
            const std::uint32_t dim844Kuo2Init[]        =   {   1   ,   1   ,   7   ,   13  ,   1   ,   11  ,   85  ,   195 ,   429 ,   71  ,   1053    ,   3623    ,   2921    ,0 };
            const std::uint32_t dim845Kuo2Init[]        =   {   1   ,   3   ,   1   ,   5   ,   17  ,   15  ,   105 ,   155 ,   291 ,   889 ,   1997    ,   3629    ,   7025    ,0 };
            const std::uint32_t dim846Kuo2Init[]        =   {   1   ,   1   ,   3   ,   7   ,   9   ,   3   ,   79  ,   41  ,   21  ,   819 ,   1665    ,   4021    ,   7057    ,0 };
            const std::uint32_t dim847Kuo2Init[]        =   {   1   ,   1   ,   3   ,   1   ,   1   ,   23  ,   73  ,   5   ,   75  ,   435 ,   889 ,   2577    ,   697 ,0 };
            const std::uint32_t dim848Kuo2Init[]        =   {   1   ,   3   ,   7   ,   1   ,   1   ,   5   ,   77  ,   183 ,   109 ,   159 ,   1463    ,   2689    ,   7799    ,0 };
            const std::uint32_t dim849Kuo2Init[]        =   {   1   ,   1   ,   1   ,   13  ,   29  ,   55  ,   123 ,   247 ,   509 ,   909 ,   247 ,   3053    ,   7301    ,0 };
            const std::uint32_t dim850Kuo2Init[]        =   {   1   ,   1   ,   5   ,   13  ,   7   ,   23  ,   43  ,   177 ,   59  ,   643 ,   1517    ,   1869    ,   3269    ,0 };
            const std::uint32_t dim851Kuo2Init[]        =   {   1   ,   3   ,   1   ,   9   ,   7   ,   43  ,   3   ,   13  ,   387 ,   893 ,   1013    ,   7   ,   7481    ,0 };
            const std::uint32_t dim852Kuo2Init[]        =   {   1   ,   1   ,   1   ,   1   ,   9   ,   35  ,   111 ,   199 ,   77  ,   375 ,   981 ,   3475    ,   2339    ,0 };
            const std::uint32_t dim853Kuo2Init[]        =   {   1   ,   3   ,   5   ,   7   ,   5   ,   13  ,   27  ,   5   ,   113 ,   65  ,   1785    ,   1517    ,   8027    ,0 };
            const std::uint32_t dim854Kuo2Init[]        =   {   1   ,   3   ,   7   ,   5   ,   25  ,   47  ,   15  ,   7   ,   45  ,   441 ,   7   ,   1601    ,   6543    ,0 };
            const std::uint32_t dim855Kuo2Init[]        =   {   1   ,   1   ,   7   ,   3   ,   17  ,   59  ,   71  ,   93  ,   441 ,   763 ,   769 ,   1977    ,   287 ,0 };
            const std::uint32_t dim856Kuo2Init[]        =   {   1   ,   1   ,   7   ,   11  ,   29  ,   23  ,   61  ,   199 ,   469 ,   757 ,   1473    ,   2625    ,   5909    ,0 };
            const std::uint32_t dim857Kuo2Init[]        =   {   1   ,   1   ,   5   ,   11  ,   27  ,   47  ,   41  ,   91  ,   457 ,   1003    ,   217 ,   401 ,   8113    ,0 };
            const std::uint32_t dim858Kuo2Init[]        =   {   1   ,   1   ,   5   ,   7   ,   1   ,   33  ,   43  ,   45  ,   169 ,   485 ,   191 ,   615 ,   5141    ,0 };
            const std::uint32_t dim859Kuo2Init[]        =   {   1   ,   3   ,   1   ,   5   ,   5   ,   53  ,   19  ,   185 ,   189 ,   681 ,   1685    ,   661 ,   6825    ,0 };
            const std::uint32_t dim860Kuo2Init[]        =   {   1   ,   3   ,   3   ,   1   ,   1   ,   7   ,   47  ,   27  ,   275 ,   63  ,   1029    ,   449 ,   4665    ,0 };
            const std::uint32_t dim861Kuo2Init[]        =   {   1   ,   3   ,   3   ,   1   ,   3   ,   31  ,   1   ,   77  ,   275 ,   871 ,   1031    ,   1025    ,   4683    ,0 };
            const std::uint32_t dim862Kuo2Init[]        =   {   1   ,   1   ,   3   ,   3   ,   9   ,   35  ,   39  ,   43  ,   363 ,   129 ,   431 ,   1351    ,   8037    ,0 };
            const std::uint32_t dim863Kuo2Init[]        =   {   1   ,   1   ,   5   ,   3   ,   3   ,   39  ,   29  ,   99  ,   441 ,   819 ,   175 ,   3503    ,   4911    ,0 };
            const std::uint32_t dim864Kuo2Init[]        =   {   1   ,   3   ,   5   ,   13  ,   9   ,   17  ,   87  ,   5   ,   311 ,   307 ,   659 ,   2795    ,   4055    ,0 };
            const std::uint32_t dim865Kuo2Init[]        =   {   1   ,   1   ,   3   ,   13  ,   13  ,   51  ,   69  ,   99  ,   65  ,   257 ,   87  ,   1407    ,   3157    ,0 };
            const std::uint32_t dim866Kuo2Init[]        =   {   1   ,   1   ,   5   ,   9   ,   19  ,   41  ,   97  ,   231 ,   85  ,   743 ,   637 ,   755 ,   6209    ,0 };
            const std::uint32_t dim867Kuo2Init[]        =   {   1   ,   1   ,   5   ,   15  ,   21  ,   63  ,   81  ,   35  ,   477 ,   39  ,   873 ,   3679    ,   6477    ,0 };
            const std::uint32_t dim868Kuo2Init[]        =   {   1   ,   1   ,   7   ,   13  ,   23  ,   37  ,   115 ,   87  ,   171 ,   33  ,   1779    ,   3169    ,   3205    ,0 };
            const std::uint32_t dim869Kuo2Init[]        =   {   1   ,   3   ,   7   ,   11  ,   9   ,   41  ,   111 ,   9   ,   5   ,   441 ,   1677    ,   311 ,   1019    ,0 };
            const std::uint32_t dim870Kuo2Init[]        =   {   1   ,   1   ,   5   ,   15  ,   7   ,   23  ,   7   ,   181 ,   461 ,   357 ,   187 ,   3461    ,   6689    ,0 };
            const std::uint32_t dim871Kuo2Init[]        =   {   1   ,   1   ,   3   ,   11  ,   15  ,   37  ,   101 ,   125 ,   271 ,   205 ,   57  ,   3361    ,   3965    ,0 };
            const std::uint32_t dim872Kuo2Init[]        =   {   1   ,   3   ,   3   ,   9   ,   25  ,   41  ,   97  ,   133 ,   39  ,   383 ,   669 ,   4007    ,   25  ,0 };
            const std::uint32_t dim873Kuo2Init[]        =   {   1   ,   3   ,   7   ,   13  ,   17  ,   13  ,   79  ,   61  ,   145 ,   567 ,   1079    ,   287 ,   467 ,0 };
            const std::uint32_t dim874Kuo2Init[]        =   {   1   ,   1   ,   5   ,   1   ,   7   ,   47  ,   97  ,   131 ,   119 ,   1013    ,   1991    ,   741 ,   27  ,0 };
            const std::uint32_t dim875Kuo2Init[]        =   {   1   ,   3   ,   5   ,   9   ,   23  ,   21  ,   71  ,   209 ,   239 ,   801 ,   133 ,   2891    ,   1141    ,0 };
            const std::uint32_t dim876Kuo2Init[]        =   {   1   ,   1   ,   7   ,   9   ,   17  ,   11  ,   109 ,   251 ,   127 ,   447 ,   1257    ,   3831    ,   1511    ,0 };
            const std::uint32_t dim877Kuo2Init[]        =   {   1   ,   3   ,   1   ,   13  ,   21  ,   9   ,   69  ,   241 ,   61  ,   521 ,   1281    ,   3499    ,   4001    ,0 };
            const std::uint32_t dim878Kuo2Init[]        =   {   1   ,   1   ,   5   ,   15  ,   5   ,   23  ,   117 ,   111 ,   159 ,   861 ,   295 ,   3403    ,   981 ,0 };
            const std::uint32_t dim879Kuo2Init[]        =   {   1   ,   3   ,   3   ,   5   ,   3   ,   37  ,   85  ,   129 ,   281 ,   261 ,   1753    ,   1399    ,   43  ,0 };
            const std::uint32_t dim880Kuo2Init[]        =   {   1   ,   1   ,   5   ,   5   ,   3   ,   49  ,   67  ,   221 ,   3   ,   143 ,   617 ,   2579    ,   373 ,0 };
            const std::uint32_t dim881Kuo2Init[]        =   {   1   ,   3   ,   5   ,   11  ,   29  ,   49  ,   59  ,   47  ,   21  ,   725 ,   655 ,   3467    ,   2375    ,0 };
            const std::uint32_t dim882Kuo2Init[]        =   {   1   ,   3   ,   3   ,   13  ,   15  ,   43  ,   19  ,   185 ,   411 ,   299 ,   1351    ,   3543    ,   5429    ,0 };
            const std::uint32_t dim883Kuo2Init[]        =   {   1   ,   1   ,   5   ,   11  ,   19  ,   63  ,   19  ,   167 ,   439 ,   627 ,   1729    ,   245 ,   193 ,0 };
            const std::uint32_t dim884Kuo2Init[]        =   {   1   ,   1   ,   3   ,   1   ,   5   ,   5   ,   115 ,   127 ,   295 ,   321 ,   1167    ,   3187    ,   6165    ,0 };
            const std::uint32_t dim885Kuo2Init[]        =   {   1   ,   3   ,   1   ,   9   ,   9   ,   51  ,   87  ,   205 ,   211 ,   427 ,   1817    ,   3169    ,   1469    ,0 };
            const std::uint32_t dim886Kuo2Init[]        =   {   1   ,   3   ,   1   ,   15  ,   27  ,   57  ,   15  ,   199 ,   87  ,   361 ,   583 ,   2467    ,   1367    ,0 };
            const std::uint32_t dim887Kuo2Init[]        =   {   1   ,   1   ,   1   ,   11  ,   27  ,   7   ,   53  ,   173 ,   505 ,   839 ,   929 ,   3977    ,   7667    ,0 };
            const std::uint32_t dim888Kuo2Init[]        =   {   1   ,   3   ,   3   ,   13  ,   7   ,   37  ,   51  ,   109 ,   249 ,   233 ,   899 ,   3991    ,   6667    ,0 };
            const std::uint32_t dim889Kuo2Init[]        =   {   1   ,   3   ,   1   ,   11  ,   17  ,   23  ,   105 ,   213 ,   425 ,   175 ,   869 ,   3185    ,   6301    ,0 };
            const std::uint32_t dim890Kuo2Init[]        =   {   1   ,   1   ,   5   ,   5   ,   17  ,   47  ,   5   ,   135 ,   497 ,   227 ,   1135    ,   689 ,   5047    ,0 };
            const std::uint32_t dim891Kuo2Init[]        =   {   1   ,   3   ,   3   ,   11  ,   5   ,   49  ,   29  ,   177 ,   325 ,   727 ,   1719    ,   1805    ,   3361    ,0 };
            const std::uint32_t dim892Kuo2Init[]        =   {   1   ,   1   ,   3   ,   3   ,   11  ,   7   ,   87  ,   169 ,   27  ,   137 ,   1835    ,   1377    ,   4915    ,0 };
            const std::uint32_t dim893Kuo2Init[]        =   {   1   ,   3   ,   5   ,   5   ,   21  ,   53  ,   99  ,   137 ,   133 ,   599 ,   479 ,   2859    ,   6731    ,0 };
            const std::uint32_t dim894Kuo2Init[]        =   {   1   ,   1   ,   5   ,   5   ,   15  ,   15  ,   31  ,   239 ,   183 ,   167 ,   1799    ,   1533    ,   309 ,0 };
            const std::uint32_t dim895Kuo2Init[]        =   {   1   ,   3   ,   5   ,   15  ,   23  ,   51  ,   85  ,   133 ,   51  ,   991 ,   899 ,   3777    ,   2231    ,0 };
            const std::uint32_t dim896Kuo2Init[]        =   {   1   ,   1   ,   3   ,   1   ,   15  ,   19  ,   29  ,   5   ,   415 ,   531 ,   253 ,   49  ,   7197    ,0 };
            const std::uint32_t dim897Kuo2Init[]        =   {   1   ,   1   ,   5   ,   15  ,   21  ,   23  ,   41  ,   213 ,   189 ,   579 ,   1181    ,   3425    ,   8037    ,0 };
            const std::uint32_t dim898Kuo2Init[]        =   {   1   ,   1   ,   5   ,   13  ,   9   ,   63  ,   21  ,   195 ,   71  ,   137 ,   1283    ,   2895    ,   3301    ,0 };
            const std::uint32_t dim899Kuo2Init[]        =   {   1   ,   1   ,   7   ,   1   ,   11  ,   5   ,   103 ,   183 ,   403 ,   177 ,   1561    ,   201 ,   2843    ,0 };
            const std::uint32_t dim900Kuo2Init[]        =   {   1   ,   3   ,   3   ,   9   ,   19  ,   15  ,   85  ,   123 ,   273 ,   891 ,   493 ,   3761    ,   557 ,0 };
            const std::uint32_t dim901Kuo2Init[]        =   {   1   ,   3   ,   7   ,   9   ,   9   ,   23  ,   123 ,   243 ,   71  ,   137 ,   1937    ,   3199    ,   6865    ,0 };
            const std::uint32_t dim902Kuo2Init[]        =   {   1   ,   1   ,   1   ,   15  ,   15  ,   55  ,   119 ,   203 ,   449 ,   969 ,   181 ,   2573    ,   3261    ,0 };
            const std::uint32_t dim903Kuo2Init[]        =   {   1   ,   1   ,   1   ,   9   ,   29  ,   9   ,   87  ,   117 ,   85  ,   369 ,   911 ,   1203    ,   7287    ,0 };
            const std::uint32_t dim904Kuo2Init[]        =   {   1   ,   1   ,   1   ,   7   ,   1   ,   35  ,   9   ,   85  ,   253 ,   123 ,   67  ,   2089    ,   4693    ,0 };
            const std::uint32_t dim905Kuo2Init[]        =   {   1   ,   3   ,   5   ,   15  ,   11  ,   13  ,   43  ,   97  ,   407 ,   1011    ,   1839    ,   525 ,   6809    ,0 };
            const std::uint32_t dim906Kuo2Init[]        =   {   1   ,   3   ,   3   ,   7   ,   11  ,   49  ,   5   ,   29  ,   299 ,   35  ,   1883    ,   763 ,   3099    ,0 };
            const std::uint32_t dim907Kuo2Init[]        =   {   1   ,   3   ,   3   ,   13  ,   31  ,   5   ,   61  ,   79  ,   409 ,   1001    ,   1057    ,   1673    ,   4689    ,0 };
            const std::uint32_t dim908Kuo2Init[]        =   {   1   ,   1   ,   3   ,   7   ,   23  ,   53  ,   23  ,   243 ,   335 ,   847 ,   1011    ,   659 ,   3739    ,0 };
            const std::uint32_t dim909Kuo2Init[]        =   {   1   ,   3   ,   5   ,   1   ,   15  ,   55  ,   15  ,   161 ,   417 ,   225 ,   227 ,   3933    ,   5625    ,0 };
            const std::uint32_t dim910Kuo2Init[]        =   {   1   ,   3   ,   7   ,   11  ,   25  ,   1   ,   75  ,   33  ,   401 ,   777 ,   1999    ,   1649    ,   1269    ,0 };
            const std::uint32_t dim911Kuo2Init[]        =   {   1   ,   3   ,   5   ,   5   ,   3   ,   1   ,   13  ,   99  ,   447 ,   579 ,   225 ,   3851    ,   5379    ,0 };
            const std::uint32_t dim912Kuo2Init[]        =   {   1   ,   1   ,   3   ,   13  ,   19  ,   33  ,   39  ,   93  ,   133 ,   889 ,   113 ,   3983    ,   1115    ,0 };
            const std::uint32_t dim913Kuo2Init[]        =   {   1   ,   3   ,   5   ,   13  ,   1   ,   47  ,   113 ,   231 ,   461 ,   653 ,   1965    ,   849 ,   4513    ,0 };
            const std::uint32_t dim914Kuo2Init[]        =   {   1   ,   1   ,   3   ,   1   ,   23  ,   7   ,   105 ,   115 ,   463 ,   385 ,   1355    ,   1417    ,   6341    ,0 };
            const std::uint32_t dim915Kuo2Init[]        =   {   1   ,   1   ,   5   ,   7   ,   9   ,   27  ,   123 ,   193 ,   5   ,   735 ,   733 ,   2385    ,   6569    ,0 };
            const std::uint32_t dim916Kuo2Init[]        =   {   1   ,   3   ,   1   ,   11  ,   13  ,   51  ,   53  ,   15  ,   289 ,   433 ,   951 ,   3657    ,   5239    ,0 };
            const std::uint32_t dim917Kuo2Init[]        =   {   1   ,   1   ,   7   ,   3   ,   7   ,   59  ,   69  ,   57  ,   471 ,   247 ,   259 ,   2617    ,   47  ,0 };
            const std::uint32_t dim918Kuo2Init[]        =   {   1   ,   3   ,   7   ,   13  ,   5   ,   41  ,   45  ,   67  ,   363 ,   295 ,   1715    ,   3567    ,   2457    ,0 };
            const std::uint32_t dim919Kuo2Init[]        =   {   1   ,   1   ,   5   ,   3   ,   21  ,   19  ,   79  ,   37  ,   273 ,   613 ,   475 ,   3989    ,   3779    ,0 };
            const std::uint32_t dim920Kuo2Init[]        =   {   1   ,   1   ,   5   ,   3   ,   21  ,   11  ,   53  ,   117 ,   367 ,   295 ,   1027    ,   2579    ,   2717    ,0 };
            const std::uint32_t dim921Kuo2Init[]        =   {   1   ,   1   ,   5   ,   7   ,   29  ,   1   ,   47  ,   185 ,   377 ,   267 ,   1375    ,   801 ,   5967    ,0 };
            const std::uint32_t dim922Kuo2Init[]        =   {   1   ,   3   ,   3   ,   3   ,   15  ,   5   ,   51  ,   183 ,   249 ,   789 ,   785 ,   1459    ,   7865    ,0 };
            const std::uint32_t dim923Kuo2Init[]        =   {   1   ,   3   ,   5   ,   5   ,   31  ,   17  ,   89  ,   9   ,   247 ,   67  ,   1259    ,   3099    ,   2805    ,0 };
            const std::uint32_t dim924Kuo2Init[]        =   {   1   ,   3   ,   3   ,   11  ,   31  ,   51  ,   55  ,   37  ,   201 ,   779 ,   1235    ,   1905    ,   1995    ,0 };
            const std::uint32_t dim925Kuo2Init[]        =   {   1   ,   3   ,   1   ,   1   ,   27  ,   31  ,   25  ,   37  ,   443 ,   399 ,   1911    ,   3951    ,   4311    ,0 };
            const std::uint32_t dim926Kuo2Init[]        =   {   1   ,   3   ,   3   ,   11  ,   11  ,   13  ,   69  ,   209 ,   295 ,   431 ,   573 ,   1781    ,   7767    ,0 };
            const std::uint32_t dim927Kuo2Init[]        =   {   1   ,   3   ,   1   ,   3   ,   23  ,   55  ,   57  ,   29  ,   137 ,   407 ,   1339    ,   1411    ,   123 ,0 };
            const std::uint32_t dim928Kuo2Init[]        =   {   1   ,   3   ,   3   ,   13  ,   5   ,   15  ,   7   ,   29  ,   353 ,   143 ,   133 ,   2351    ,   1555    ,0 };
            const std::uint32_t dim929Kuo2Init[]        =   {   1   ,   1   ,   7   ,   9   ,   17  ,   53  ,   61  ,   197 ,   245 ,   327 ,   147 ,   3231    ,   1825    ,0 };
            const std::uint32_t dim930Kuo2Init[]        =   {   1   ,   3   ,   5   ,   3   ,   27  ,   55  ,   31  ,   15  ,   429 ,   703 ,   1863    ,   3697    ,   2169    ,0 };
            const std::uint32_t dim931Kuo2Init[]        =   {   1   ,   3   ,   3   ,   1   ,   19  ,   45  ,   61  ,   179 ,   471 ,   219 ,   1127    ,   3521    ,   8065    ,0 };
            const std::uint32_t dim932Kuo2Init[]        =   {   1   ,   3   ,   5   ,   5   ,   17  ,   21  ,   77  ,   117 ,   331 ,   979 ,   175 ,   3155    ,   1589    ,0 };
            const std::uint32_t dim933Kuo2Init[]        =   {   1   ,   3   ,   1   ,   9   ,   13  ,   41  ,   25  ,   221 ,   115 ,   333 ,   1851    ,   543 ,   5479    ,0 };
            const std::uint32_t dim934Kuo2Init[]        =   {   1   ,   3   ,   3   ,   13  ,   25  ,   35  ,   113 ,   107 ,   21  ,   85  ,   815 ,   3013    ,   8067    ,0 };
            const std::uint32_t dim935Kuo2Init[]        =   {   1   ,   1   ,   3   ,   9   ,   23  ,   37  ,   55  ,   193 ,   301 ,   463 ,   1361    ,   3455    ,   5745    ,0 };
            const std::uint32_t dim936Kuo2Init[]        =   {   1   ,   3   ,   5   ,   7   ,   3   ,   63  ,   73  ,   83  ,   35  ,   709 ,   719 ,   1133    ,   6711    ,0 };
            const std::uint32_t dim937Kuo2Init[]        =   {   1   ,   1   ,   5   ,   7   ,   11  ,   7   ,   67  ,   199 ,   285 ,   527 ,   1181    ,   39  ,   5639    ,0 };
            const std::uint32_t dim938Kuo2Init[]        =   {   1   ,   3   ,   3   ,   3   ,   17  ,   13  ,   33  ,   213 ,   97  ,   499 ,   1651    ,   3369    ,   6001    ,0 };
            const std::uint32_t dim939Kuo2Init[]        =   {   1   ,   1   ,   3   ,   1   ,   15  ,   37  ,   67  ,   31  ,   225 ,   205 ,   1009    ,   2579    ,   331 ,0 };
            const std::uint32_t dim940Kuo2Init[]        =   {   1   ,   1   ,   7   ,   1   ,   29  ,   3   ,   91  ,   153 ,   395 ,   89  ,   2019    ,   1297    ,   7035    ,0 };
            const std::uint32_t dim941Kuo2Init[]        =   {   1   ,   3   ,   3   ,   5   ,   29  ,   31  ,   65  ,   137 ,   289 ,   351 ,   677 ,   3305    ,   5073    ,0 };
            const std::uint32_t dim942Kuo2Init[]        =   {   1   ,   1   ,   3   ,   13  ,   15  ,   21  ,   43  ,   227 ,   399 ,   921 ,   123 ,   3199    ,   6925    ,0 };
            const std::uint32_t dim943Kuo2Init[]        =   {   1   ,   1   ,   7   ,   13  ,   17  ,   11  ,   107 ,   251 ,   55  ,   525 ,   869 ,   209 ,   6209    ,0 };
            const std::uint32_t dim944Kuo2Init[]        =   {   1   ,   1   ,   3   ,   11  ,   29  ,   39  ,   123 ,   171 ,   223 ,   441 ,   525 ,   2583    ,   71  ,0 };
            const std::uint32_t dim945Kuo2Init[]        =   {   1   ,   3   ,   7   ,   9   ,   5   ,   3   ,   3   ,   205 ,   119 ,   631 ,   1997    ,   3105    ,   6483    ,0 };
            const std::uint32_t dim946Kuo2Init[]        =   {   1   ,   1   ,   7   ,   7   ,   23  ,   37  ,   79  ,   245 ,   401 ,   241 ,   1471    ,   2941    ,   4389    ,0 };
            const std::uint32_t dim947Kuo2Init[]        =   {   1   ,   3   ,   1   ,   13  ,   25  ,   7   ,   43  ,   215 ,   155 ,   805 ,   1497    ,   387 ,   2045    ,0 };
            const std::uint32_t dim948Kuo2Init[]        =   {   1   ,   1   ,   3   ,   3   ,   7   ,   37  ,   115 ,   39  ,   139 ,   555 ,   1325    ,   2351    ,   6045    ,0 };
            const std::uint32_t dim949Kuo2Init[]        =   {   1   ,   1   ,   5   ,   7   ,   3   ,   53  ,   35  ,   103 ,   505 ,   361 ,   457 ,   2495    ,   1325    ,0 };
            const std::uint32_t dim950Kuo2Init[]        =   {   1   ,   3   ,   7   ,   13  ,   21  ,   33  ,   39  ,   81  ,   465 ,   601 ,   1131    ,   2977    ,   1409    ,0 };
            const std::uint32_t dim951Kuo2Init[]        =   {   1   ,   1   ,   5   ,   5   ,   25  ,   1   ,   21  ,   241 ,   255 ,   663 ,   1509    ,   2455    ,   5705    ,0 };
            const std::uint32_t dim952Kuo2Init[]        =   {   1   ,   1   ,   7   ,   13  ,   1   ,   47  ,   91  ,   195 ,   195 ,   503 ,   1931    ,   1681    ,   5131    ,0 };
            const std::uint32_t dim953Kuo2Init[]        =   {   1   ,   1   ,   3   ,   9   ,   27  ,   37  ,   103 ,   21  ,   237 ,   677 ,   1949    ,   357 ,   2781    ,0 };
            const std::uint32_t dim954Kuo2Init[]        =   {   1   ,   3   ,   7   ,   9   ,   29  ,   51  ,   107 ,   49  ,   251 ,   433 ,   1235    ,   4041    ,   2971    ,0 };
            const std::uint32_t dim955Kuo2Init[]        =   {   1   ,   3   ,   3   ,   1   ,   19  ,   37  ,   113 ,   75  ,   365 ,   145 ,   93  ,   1185    ,   1871    ,0 };
            const std::uint32_t dim956Kuo2Init[]        =   {   1   ,   1   ,   5   ,   5   ,   25  ,   15  ,   113 ,   239 ,   27  ,   321 ,   1351    ,   1441    ,   3333    ,0 };
            const std::uint32_t dim957Kuo2Init[]        =   {   1   ,   1   ,   5   ,   13  ,   31  ,   35  ,   103 ,   83  ,   111 ,   573 ,   59  ,   3753    ,   5667    ,0 };
            const std::uint32_t dim958Kuo2Init[]        =   {   1   ,   1   ,   5   ,   13  ,   1   ,   43  ,   75  ,   115 ,   397 ,   187 ,   1669    ,   3837    ,   5219    ,0 };
            const std::uint32_t dim959Kuo2Init[]        =   {   1   ,   1   ,   3   ,   1   ,   23  ,   13  ,   65  ,   145 ,   271 ,   909 ,   1517    ,   1659    ,   7975    ,0 };
            const std::uint32_t dim960Kuo2Init[]        =   {   1   ,   1   ,   7   ,   15  ,   21  ,   23  ,   1   ,   33  ,   37  ,   313 ,   687 ,   2375    ,   555 ,0 };
            const std::uint32_t dim961Kuo2Init[]        =   {   1   ,   1   ,   7   ,   13  ,   1   ,   35  ,   11  ,   157 ,   295 ,   403 ,   1295    ,   3301    ,   4805    ,0 };
            const std::uint32_t dim962Kuo2Init[]        =   {   1   ,   3   ,   1   ,   13  ,   9   ,   27  ,   3   ,   111 ,   133 ,   395 ,   981 ,   2399    ,   7009    ,0 };
            const std::uint32_t dim963Kuo2Init[]        =   {   1   ,   1   ,   7   ,   15  ,   23  ,   11  ,   75  ,   31  ,   5   ,   599 ,   1589    ,   2243    ,   3263    ,0 };
            const std::uint32_t dim964Kuo2Init[]        =   {   1   ,   1   ,   3   ,   9   ,   7   ,   49  ,   31  ,   5   ,   457 ,   93  ,   221 ,   2463    ,   2287    ,0 };
            const std::uint32_t dim965Kuo2Init[]        =   {   1   ,   1   ,   5   ,   3   ,   9   ,   31  ,   49  ,   5   ,   481 ,   145 ,   53  ,   2477    ,   5569    ,0 };
            const std::uint32_t dim966Kuo2Init[]        =   {   1   ,   1   ,   1   ,   1   ,   19  ,   47  ,   59  ,   83  ,   19  ,   887 ,   335 ,   2305    ,   6265    ,0 };
            const std::uint32_t dim967Kuo2Init[]        =   {   1   ,   3   ,   7   ,   15  ,   27  ,   15  ,   93  ,   37  ,   213 ,   17  ,   311 ,   3159    ,   6911    ,0 };
            const std::uint32_t dim968Kuo2Init[]        =   {   1   ,   1   ,   3   ,   9   ,   19  ,   47  ,   93  ,   31  ,   489 ,   731 ,   1905    ,   1675    ,   1   ,0 };
            const std::uint32_t dim969Kuo2Init[]        =   {   1   ,   1   ,   1   ,   7   ,   9   ,   3   ,   17  ,   185 ,   203 ,   963 ,   521 ,   2797    ,   7511    ,0 };
            const std::uint32_t dim970Kuo2Init[]        =   {   1   ,   3   ,   7   ,   11  ,   31  ,   27  ,   47  ,   147 ,   467 ,   505 ,   1991    ,   2247    ,   4207    ,0 };
            const std::uint32_t dim971Kuo2Init[]        =   {   1   ,   3   ,   1   ,   5   ,   9   ,   11  ,   89  ,   199 ,   359 ,   723 ,   1203    ,   1511    ,   7915    ,0 };
            const std::uint32_t dim972Kuo2Init[]        =   {   1   ,   3   ,   5   ,   9   ,   27  ,   63  ,   93  ,   19  ,   305 ,   641 ,   997 ,   1725    ,   5681    ,0 };
            const std::uint32_t dim973Kuo2Init[]        =   {   1   ,   3   ,   3   ,   3   ,   13  ,   19  ,   9   ,   43  ,   99  ,   111 ,   1353    ,   935 ,   7765    ,0 };
            const std::uint32_t dim974Kuo2Init[]        =   {   1   ,   3   ,   1   ,   9   ,   5   ,   39  ,   109 ,   79  ,   497 ,   351 ,   1345    ,   3019    ,   5909    ,0 };
            const std::uint32_t dim975Kuo2Init[]        =   {   1   ,   1   ,   3   ,   1   ,   13  ,   29  ,   11  ,   199 ,   31  ,   443 ,   1587    ,   3397    ,   7045    ,0 };
            const std::uint32_t dim976Kuo2Init[]        =   {   1   ,   1   ,   1   ,   11  ,   7   ,   9   ,   49  ,   107 ,   153 ,   207 ,   887 ,   2135    ,   1389    ,0 };
            const std::uint32_t dim977Kuo2Init[]        =   {   1   ,   1   ,   1   ,   3   ,   29  ,   53  ,   111 ,   143 ,   421 ,   521 ,   1099    ,   1709    ,   7027    ,0 };
            const std::uint32_t dim978Kuo2Init[]        =   {   1   ,   1   ,   5   ,   5   ,   5   ,   19  ,   127 ,   99  ,   501 ,   819 ,   1729    ,   1701    ,   5829    ,0 };
            const std::uint32_t dim979Kuo2Init[]        =   {   1   ,   3   ,   7   ,   5   ,   7   ,   15  ,   43  ,   49  ,   223 ,   793 ,   889 ,   793 ,   271 ,0 };
            const std::uint32_t dim980Kuo2Init[]        =   {   1   ,   3   ,   5   ,   11  ,   27  ,   27  ,   55  ,   69  ,   185 ,   511 ,   951 ,   2821    ,   5357    ,0 };
            const std::uint32_t dim981Kuo2Init[]        =   {   1   ,   3   ,   7   ,   13  ,   17  ,   19  ,   31  ,   9   ,   401 ,   397 ,   829 ,   1063    ,   693 ,0 };
            const std::uint32_t dim982Kuo2Init[]        =   {   1   ,   1   ,   7   ,   9   ,   21  ,   13  ,   75  ,   13  ,   327 ,   929 ,   955 ,   1421    ,   2809    ,0 };
            const std::uint32_t dim983Kuo2Init[]        =   {   1   ,   1   ,   3   ,   15  ,   17  ,   5   ,   115 ,   231 ,   29  ,   23  ,   1743    ,   779 ,   5083    ,0 };
            const std::uint32_t dim984Kuo2Init[]        =   {   1   ,   1   ,   7   ,   11  ,   9   ,   51  ,   93  ,   3   ,   155 ,   111 ,   243 ,   3889    ,   6733    ,0 };
            const std::uint32_t dim985Kuo2Init[]        =   {   1   ,   1   ,   5   ,   9   ,   29  ,   63  ,   119 ,   145 ,   391 ,   1021    ,   503 ,   555 ,   4657    ,0 };
            const std::uint32_t dim986Kuo2Init[]        =   {   1   ,   1   ,   1   ,   15  ,   15  ,   41  ,   69  ,   131 ,   365 ,   195 ,   1809    ,   2773    ,   4067    ,0 };
            const std::uint32_t dim987Kuo2Init[]        =   {   1   ,   1   ,   1   ,   15  ,   5   ,   3   ,   119 ,   63  ,   243 ,   759 ,   2037    ,   3443    ,   5771    ,0 };
            const std::uint32_t dim988Kuo2Init[]        =   {   1   ,   3   ,   5   ,   5   ,   1   ,   1   ,   21  ,   163 ,   481 ,   781 ,   769 ,   3031    ,   2707    ,0 };
            const std::uint32_t dim989Kuo2Init[]        =   {   1   ,   1   ,   5   ,   7   ,   15  ,   29  ,   3   ,   119 ,   13  ,   977 ,   1759    ,   2327    ,   3961    ,0 };
            const std::uint32_t dim990Kuo2Init[]        =   {   1   ,   1   ,   3   ,   1   ,   9   ,   25  ,   55  ,   131 ,   335 ,   289 ,   1049    ,   3589    ,   3131    ,0 };
            const std::uint32_t dim991Kuo2Init[]        =   {   1   ,   1   ,   7   ,   1   ,   27  ,   55  ,   113 ,   97  ,   249 ,   817 ,   1497    ,   3773    ,   6183    ,0 };
            const std::uint32_t dim992Kuo2Init[]        =   {   1   ,   3   ,   3   ,   7   ,   3   ,   15  ,   11  ,   157 ,   201 ,   145 ,   1741    ,   721 ,   4945    ,0 };
            const std::uint32_t dim993Kuo2Init[]        =   {   1   ,   1   ,   7   ,   3   ,   19  ,   9   ,   123 ,   151 ,   169 ,   841 ,   65  ,   2463    ,   5357    ,0 };
            const std::uint32_t dim994Kuo2Init[]        =   {   1   ,   3   ,   1   ,   11  ,   5   ,   31  ,   123 ,   69  ,   93  ,   541 ,   131 ,   1469    ,   5791    ,0 };
            const std::uint32_t dim995Kuo2Init[]        =   {   1   ,   3   ,   5   ,   1   ,   25  ,   23  ,   115 ,   69  ,   333 ,   457 ,   17  ,   1155    ,   523 ,0 };
            const std::uint32_t dim996Kuo2Init[]        =   {   1   ,   3   ,   5   ,   11  ,   11  ,   51  ,   21  ,   145 ,   209 ,   557 ,   1109    ,   2293    ,   4631    ,0 };
            const std::uint32_t dim997Kuo2Init[]        =   {   1   ,   1   ,   7   ,   5   ,   11  ,   21  ,   107 ,   41  ,   409 ,   485 ,   1745    ,   3471    ,   1699    ,0 };
            const std::uint32_t dim998Kuo2Init[]        =   {   1   ,   1   ,   3   ,   7   ,   5   ,   47  ,   65  ,   79  ,   299 ,   191 ,   381 ,   3803    ,   6499    ,0 };
            const std::uint32_t dim999Kuo2Init[]        =   {   1   ,   3   ,   3   ,   7   ,   19  ,   11  ,   73  ,   69  ,   461 ,   777 ,   1871    ,   47  ,   1281    ,0 };
            const std::uint32_t dim1000Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   13  ,   39  ,   63  ,   103 ,   103 ,   845 ,   1023    ,   3241    ,   1291    ,0 };
            const std::uint32_t dim1001Kuo2Init[]       =   {   1   ,   1   ,   5   ,   13  ,   3   ,   11  ,   103 ,   135 ,   403 ,   801 ,   847 ,   371 ,   6243    ,0 };
            const std::uint32_t dim1002Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   21  ,   57  ,   19  ,   205 ,   33  ,   399 ,   777 ,   2981    ,   2365    ,0 };
            const std::uint32_t dim1003Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   17  ,   11  ,   105 ,   23  ,   243 ,   581 ,   1391    ,   1509    ,   8009    ,0 };
            const std::uint32_t dim1004Kuo2Init[]       =   {   1   ,   3   ,   3   ,   3   ,   11  ,   13  ,   85  ,   107 ,   181 ,   89  ,   1323    ,   3059    ,   5097    ,0 };
            const std::uint32_t dim1005Kuo2Init[]       =   {   1   ,   1   ,   1   ,   15  ,   1   ,   29  ,   57  ,   221 ,   389 ,   127 ,   841 ,   1727    ,   6217    ,0 };
            const std::uint32_t dim1006Kuo2Init[]       =   {   1   ,   3   ,   1   ,   9   ,   25  ,   51  ,   89  ,   67  ,   257 ,   921 ,   621 ,   1523    ,   3449    ,0 };
            const std::uint32_t dim1007Kuo2Init[]       =   {   1   ,   3   ,   5   ,   5   ,   25  ,   15  ,   25  ,   47  ,   29  ,   775 ,   1925    ,   3819    ,   8063    ,0 };
            const std::uint32_t dim1008Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   25  ,   55  ,   89  ,   75  ,   47  ,   135 ,   1155    ,   1923    ,   2241    ,0 };
            const std::uint32_t dim1009Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   29  ,   5   ,   55  ,   43  ,   355 ,   879 ,   127 ,   3565    ,   2583    ,0 };
            const std::uint32_t dim1010Kuo2Init[]       =   {   1   ,   1   ,   3   ,   13  ,   23  ,   47  ,   27  ,   63  ,   217 ,   119 ,   357 ,   423 ,   5897    ,0 };
            const std::uint32_t dim1011Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   23  ,   1   ,   89  ,   255 ,   381 ,   175 ,   1069    ,   3809    ,   1743    ,0 };
            const std::uint32_t dim1012Kuo2Init[]       =   {   1   ,   1   ,   7   ,   3   ,   7   ,   35  ,   47  ,   159 ,   347 ,   543 ,   187 ,   1103    ,   5019    ,0 };
            const std::uint32_t dim1013Kuo2Init[]       =   {   1   ,   1   ,   1   ,   7   ,   19  ,   3   ,   89  ,   15  ,   487 ,   541 ,   625 ,   1711    ,   3713    ,0 };
            const std::uint32_t dim1014Kuo2Init[]       =   {   1   ,   1   ,   5   ,   15  ,   17  ,   61  ,   13  ,   45  ,   359 ,   107 ,   1487    ,   121 ,   6919    ,0 };
            const std::uint32_t dim1015Kuo2Init[]       =   {   1   ,   3   ,   3   ,   3   ,   1   ,   5   ,   99  ,   255 ,   147 ,   737 ,   1675    ,   4069    ,   7685    ,0 };
            const std::uint32_t dim1016Kuo2Init[]       =   {   1   ,   3   ,   7   ,   1   ,   5   ,   33  ,   39  ,   217 ,   255 ,   833 ,   661 ,   3411    ,   7273    ,0 };
            const std::uint32_t dim1017Kuo2Init[]       =   {   1   ,   3   ,   3   ,   5   ,   9   ,   41  ,   25  ,   223 ,   319 ,   45  ,   687 ,   3861    ,   2603    ,0 };
            const std::uint32_t dim1018Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   15  ,   43  ,   61  ,   163 ,   45  ,   835 ,   545 ,   561 ,   4895    ,0 };
            const std::uint32_t dim1019Kuo2Init[]       =   {   1   ,   3   ,   7   ,   3   ,   21  ,   61  ,   65  ,   119 ,   337 ,   609 ,   1185    ,   2863    ,   1431    ,0 };
            const std::uint32_t dim1020Kuo2Init[]       =   {   1   ,   1   ,   3   ,   3   ,   29  ,   49  ,   51  ,   173 ,   107 ,   21  ,   1655    ,   1333    ,   4703    ,0 };
            const std::uint32_t dim1021Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   27  ,   23  ,   111 ,   77  ,   3   ,   789 ,   943 ,   3089    ,   2865    ,0 };
            const std::uint32_t dim1022Kuo2Init[]       =   {   1   ,   3   ,   1   ,   1   ,   5   ,   7   ,   85  ,   209 ,   317 ,   241 ,   1159    ,   2193    ,   229 ,0 };
            const std::uint32_t dim1023Kuo2Init[]       =   {   1   ,   1   ,   3   ,   13  ,   23  ,   27  ,   115 ,   111 ,   265 ,   427 ,   1457    ,   2281    ,   2235    ,0 };
            const std::uint32_t dim1024Kuo2Init[]       =   {   1   ,   3   ,   1   ,   13  ,   5   ,   51  ,   21  ,   125 ,   335 ,   359 ,   1189    ,   1095    ,   6843    ,0 };
            const std::uint32_t dim1025Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   5   ,   17  ,   93  ,   43  ,   297 ,   109 ,   1721    ,   3991    ,   6861    ,0 };
            const std::uint32_t dim1026Kuo2Init[]       =   {   1   ,   3   ,   7   ,   7   ,   23  ,   45  ,   61  ,   149 ,   89  ,   1009    ,   937 ,   2477    ,   1617    ,0 };
            const std::uint32_t dim1027Kuo2Init[]       =   {   1   ,   1   ,   3   ,   1   ,   23  ,   19  ,   21  ,   29  ,   481 ,   771 ,   261 ,   2377    ,   2323    ,0 };
            const std::uint32_t dim1028Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   29  ,   21  ,   99  ,   159 ,   219 ,   983 ,   1169    ,   667 ,   3073    ,0 };
            const std::uint32_t dim1029Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   7   ,   61  ,   69  ,   197 ,   29  ,   3   ,   1767    ,   2113    ,   689 ,0 };
            const std::uint32_t dim1030Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   9   ,   37  ,   45  ,   11  ,   405 ,   243 ,   661 ,   2545    ,   5185    ,0 };
            const std::uint32_t dim1031Kuo2Init[]       =   {   1   ,   1   ,   7   ,   3   ,   7   ,   23  ,   13  ,   193 ,   91  ,   551 ,   1963    ,   2663    ,   7605    ,0 };
            const std::uint32_t dim1032Kuo2Init[]       =   {   1   ,   1   ,   1   ,   1   ,   27  ,   17  ,   79  ,   251 ,   103 ,   33  ,   45  ,   2517    ,   3611    ,0 };
            const std::uint32_t dim1033Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   19  ,   57  ,   15  ,   175 ,   77  ,   299 ,   1805    ,   3331    ,   1365    ,0 };
            const std::uint32_t dim1034Kuo2Init[]       =   {   1   ,   1   ,   3   ,   5   ,   31  ,   59  ,   51  ,   85  ,   359 ,   197 ,   679 ,   3017    ,   7929    ,0 };
            const std::uint32_t dim1035Kuo2Init[]       =   {   1   ,   3   ,   7   ,   13  ,   15  ,   19  ,   71  ,   31  ,   69  ,   353 ,   489 ,   1167    ,   337 ,0 };
            const std::uint32_t dim1036Kuo2Init[]       =   {   1   ,   1   ,   3   ,   13  ,   5   ,   33  ,   35  ,   33  ,   345 ,   63  ,   1775    ,   3475    ,   1375    ,0 };
            const std::uint32_t dim1037Kuo2Init[]       =   {   1   ,   1   ,   3   ,   1   ,   29  ,   53  ,   109 ,   3   ,   191 ,   1011    ,   1043    ,   3057    ,   4757    ,0 };
            const std::uint32_t dim1038Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   3   ,   21  ,   101 ,   137 ,   155 ,   959 ,   683 ,   1407    ,   1239    ,0 };
            const std::uint32_t dim1039Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   3   ,   9   ,   117 ,   81  ,   143 ,   753 ,   561 ,   871 ,   2417    ,0 };
            const std::uint32_t dim1040Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   25  ,   11  ,   33  ,   173 ,   321 ,   487 ,   33  ,   551 ,   6613    ,0 };
            const std::uint32_t dim1041Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   3   ,   29  ,   9   ,   133 ,   251 ,   561 ,   975 ,   3153    ,   1115    ,0 };
            const std::uint32_t dim1042Kuo2Init[]       =   {   1   ,   3   ,   5   ,   3   ,   1   ,   11  ,   89  ,   145 ,   33  ,   967 ,   365 ,   3661    ,   2917    ,0 };
            const std::uint32_t dim1043Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   21  ,   55  ,   49  ,   139 ,   507 ,   405 ,   99  ,   2819    ,   6541    ,0 };
            const std::uint32_t dim1044Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   13  ,   41  ,   77  ,   53  ,   185 ,   995 ,   2045    ,   1659    ,   1081    ,0 };
            const std::uint32_t dim1045Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   5   ,   29  ,   25  ,   111 ,   173 ,   793 ,   953 ,   2825    ,   673 ,0 };
            const std::uint32_t dim1046Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   13  ,   3   ,   73  ,   39  ,   143 ,   603 ,   253 ,   2879    ,   3827    ,0 };
            const std::uint32_t dim1047Kuo2Init[]       =   {   1   ,   3   ,   1   ,   11  ,   3   ,   35  ,   93  ,   237 ,   401 ,   1005    ,   1047    ,   3065    ,   6285    ,0 };
            const std::uint32_t dim1048Kuo2Init[]       =   {   1   ,   3   ,   1   ,   13  ,   7   ,   7   ,   17  ,   65  ,   107 ,   971 ,   999 ,   623 ,   6491    ,0 };
            const std::uint32_t dim1049Kuo2Init[]       =   {   1   ,   3   ,   3   ,   11  ,   31  ,   1   ,   83  ,   111 ,   255 ,   969 ,   871 ,   3459    ,   2419    ,0 };
            const std::uint32_t dim1050Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   3   ,   49  ,   99  ,   27  ,   253 ,   937 ,   1237    ,   343 ,   6133    ,0 };
            const std::uint32_t dim1051Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   31  ,   7   ,   83  ,   75  ,   77  ,   583 ,   847 ,   2263    ,   1925    ,0 };
            const std::uint32_t dim1052Kuo2Init[]       =   {   1   ,   1   ,   3   ,   11  ,   3   ,   37  ,   119 ,   229 ,   411 ,   953 ,   1087    ,   3005    ,   1521    ,0 };
            const std::uint32_t dim1053Kuo2Init[]       =   {   1   ,   3   ,   7   ,   13  ,   5   ,   53  ,   125 ,   207 ,   297 ,   465 ,   1989    ,   1769    ,   5113    ,0 };
            const std::uint32_t dim1054Kuo2Init[]       =   {   1   ,   3   ,   5   ,   11  ,   13  ,   13  ,   9   ,   105 ,   303 ,   641 ,   997 ,   929 ,   393 ,0 };
            const std::uint32_t dim1055Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   21  ,   21  ,   125 ,   49  ,   509 ,   993 ,   317 ,   2367    ,   2775    ,0 };
            const std::uint32_t dim1056Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   15  ,   1   ,   91  ,   101 ,   339 ,   625 ,   1521    ,   2285    ,   1847    ,0 };
            const std::uint32_t dim1057Kuo2Init[]       =   {   1   ,   1   ,   5   ,   15  ,   15  ,   31  ,   57  ,   253 ,   407 ,   715 ,   1143    ,   3707    ,   5105    ,0 };
            const std::uint32_t dim1058Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   21  ,   1   ,   77  ,   139 ,   499 ,   777 ,   349 ,   1647    ,   1389    ,0 };
            const std::uint32_t dim1059Kuo2Init[]       =   {   1   ,   3   ,   5   ,   5   ,   11  ,   55  ,   29  ,   209 ,   491 ,   823 ,   1961    ,   3833    ,   5825    ,0 };
            const std::uint32_t dim1060Kuo2Init[]       =   {   1   ,   1   ,   7   ,   11  ,   3   ,   21  ,   43  ,   147 ,   83  ,   245 ,   139 ,   3585    ,   975 ,0 };
            const std::uint32_t dim1061Kuo2Init[]       =   {   1   ,   1   ,   1   ,   3   ,   19  ,   9   ,   19  ,   251 ,   163 ,   85  ,   239 ,   2573    ,   1079    ,0 };
            const std::uint32_t dim1062Kuo2Init[]       =   {   1   ,   1   ,   5   ,   13  ,   27  ,   35  ,   27  ,   191 ,   279 ,   589 ,   1737    ,   2759    ,   1691    ,0 };
            const std::uint32_t dim1063Kuo2Init[]       =   {   1   ,   1   ,   7   ,   3   ,   17  ,   5   ,   47  ,   173 ,   183 ,   713 ,   667 ,   3683    ,   2167    ,0 };
            const std::uint32_t dim1064Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   25  ,   41  ,   29  ,   125 ,   173 ,   325 ,   1341    ,   481 ,   365 ,0 };
            const std::uint32_t dim1065Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   27  ,   61  ,   23  ,   11  ,   265 ,   255 ,   801 ,   921 ,   7145    ,0 };
            const std::uint32_t dim1066Kuo2Init[]       =   {   1   ,   3   ,   5   ,   5   ,   27  ,   49  ,   27  ,   245 ,   253 ,   787 ,   1451    ,   2349    ,   2125    ,0 };
            const std::uint32_t dim1067Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   13  ,   31  ,   61  ,   215 ,   339 ,   315 ,   377 ,   1121    ,   2667    ,0 };
            const std::uint32_t dim1068Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   31  ,   63  ,   27  ,   115 ,   367 ,   939 ,   437 ,   1771    ,   1219    ,0 };
            const std::uint32_t dim1069Kuo2Init[]       =   {   1   ,   1   ,   3   ,   5   ,   3   ,   7   ,   33  ,   147 ,   177 ,   249 ,   649 ,   2505    ,   4705    ,0 };
            const std::uint32_t dim1070Kuo2Init[]       =   {   1   ,   3   ,   1   ,   9   ,   11  ,   31  ,   23  ,   237 ,   223 ,   311 ,   493 ,   1255    ,   2121    ,0 };
            const std::uint32_t dim1071Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   5   ,   43  ,   51  ,   1   ,   425 ,   115 ,   1487    ,   373 ,   3765    ,0 };
            const std::uint32_t dim1072Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   3   ,   11  ,   125 ,   31  ,   375 ,   73  ,   673 ,   1933    ,   7763    ,0 };
            const std::uint32_t dim1073Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   31  ,   43  ,   67  ,   177 ,   33  ,   693 ,   185 ,   137 ,   4869    ,0 };
            const std::uint32_t dim1074Kuo2Init[]       =   {   1   ,   1   ,   1   ,   9   ,   21  ,   53  ,   111 ,   41  ,   249 ,   845 ,   193 ,   2519    ,   4745    ,0 };
            const std::uint32_t dim1075Kuo2Init[]       =   {   1   ,   3   ,   5   ,   3   ,   11  ,   15  ,   11  ,   249 ,   325 ,   561 ,   411 ,   71  ,   6973    ,0 };
            const std::uint32_t dim1076Kuo2Init[]       =   {   1   ,   1   ,   7   ,   5   ,   5   ,   13  ,   31  ,   113 ,   149 ,   475 ,   869 ,   627 ,   2789    ,0 };
            const std::uint32_t dim1077Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   7   ,   23  ,   49  ,   65  ,   201 ,   111 ,   1061    ,   393 ,   2101    ,0 };
            const std::uint32_t dim1078Kuo2Init[]       =   {   1   ,   1   ,   3   ,   5   ,   23  ,   47  ,   49  ,   111 ,   315 ,   227 ,   1985    ,   3579    ,   875 ,0 };
            const std::uint32_t dim1079Kuo2Init[]       =   {   1   ,   3   ,   5   ,   5   ,   21  ,   17  ,   101 ,   135 ,   475 ,   505 ,   51  ,   3203    ,   1735    ,0 };
            const std::uint32_t dim1080Kuo2Init[]       =   {   1   ,   1   ,   7   ,   15  ,   19  ,   41  ,   53  ,   197 ,   117 ,   315 ,   1663    ,   143 ,   1081    ,0 };
            const std::uint32_t dim1081Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   5   ,   29  ,   87  ,   39  ,   235 ,   675 ,   1101    ,   1257    ,   4045    ,0 };
            const std::uint32_t dim1082Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   25  ,   49  ,   63  ,   125 ,   447 ,   181 ,   357 ,   3017    ,   6861    ,0 };
            const std::uint32_t dim1083Kuo2Init[]       =   {   1   ,   1   ,   5   ,   15  ,   31  ,   21  ,   61  ,   197 ,   133 ,   85  ,   913 ,   3031    ,   855 ,0 };
            const std::uint32_t dim1084Kuo2Init[]       =   {   1   ,   1   ,   5   ,   7   ,   31  ,   45  ,   111 ,   243 ,   277 ,   569 ,   1311    ,   125 ,   3417    ,0 };
            const std::uint32_t dim1085Kuo2Init[]       =   {   1   ,   1   ,   3   ,   11  ,   9   ,   49  ,   127 ,   151 ,   407 ,   407 ,   915 ,   1831    ,   4093    ,0 };
            const std::uint32_t dim1086Kuo2Init[]       =   {   1   ,   3   ,   5   ,   11  ,   3   ,   47  ,   69  ,   97  ,   315 ,   993 ,   845 ,   67  ,   39  ,0 };
            const std::uint32_t dim1087Kuo2Init[]       =   {   1   ,   3   ,   3   ,   11  ,   1   ,   5   ,   105 ,   115 ,   293 ,   187 ,   1369    ,   3039    ,   6833    ,0 };
            const std::uint32_t dim1088Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   23  ,   19  ,   15  ,   59  ,   139 ,   523 ,   1599    ,   1773    ,   8059    ,0 };
            const std::uint32_t dim1089Kuo2Init[]       =   {   1   ,   1   ,   1   ,   13  ,   3   ,   9   ,   39  ,   205 ,   115 ,   35  ,   1737    ,   2713    ,   3263    ,0 };
            const std::uint32_t dim1090Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   11  ,   41  ,   71  ,   61  ,   329 ,   11  ,   1069    ,   2565    ,   6359    ,0 };
            const std::uint32_t dim1091Kuo2Init[]       =   {   1   ,   3   ,   7   ,   9   ,   1   ,   57  ,   5   ,   17  ,   117 ,   37  ,   827 ,   3449    ,   1297    ,0 };
            const std::uint32_t dim1092Kuo2Init[]       =   {   1   ,   1   ,   5   ,   1   ,   29  ,   49  ,   3   ,   7   ,   145 ,   183 ,   1777    ,   2351    ,   6675    ,0 };
            const std::uint32_t dim1093Kuo2Init[]       =   {   1   ,   1   ,   5   ,   7   ,   5   ,   57  ,   97  ,   61  ,   197 ,   713 ,   695 ,   2385    ,   1917    ,0 };
            const std::uint32_t dim1094Kuo2Init[]       =   {   1   ,   3   ,   1   ,   11  ,   21  ,   49  ,   41  ,   133 ,   307 ,   473 ,   1983    ,   3693    ,   3241    ,0 };
            const std::uint32_t dim1095Kuo2Init[]       =   {   1   ,   1   ,   5   ,   1   ,   3   ,   59  ,   47  ,   141 ,   49  ,   531 ,   1237    ,   3085    ,   5651    ,0 };
            const std::uint32_t dim1096Kuo2Init[]       =   {   1   ,   1   ,   5   ,   1   ,   17  ,   21  ,   3   ,   101 ,   169 ,   475 ,   473 ,   255 ,   6637    ,0 };
            const std::uint32_t dim1097Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   19  ,   25  ,   71  ,   251 ,   327 ,   715 ,   1945    ,   1123    ,   4911    ,0 };
            const std::uint32_t dim1098Kuo2Init[]       =   {   1   ,   1   ,   5   ,   3   ,   15  ,   55  ,   127 ,   221 ,   163 ,   281 ,   1391    ,   4083    ,   7995    ,0 };
            const std::uint32_t dim1099Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   27  ,   7   ,   65  ,   143 ,   433 ,   599 ,   1971    ,   2169    ,   813 ,0 };
            const std::uint32_t dim1100Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   9   ,   49  ,   107 ,   103 ,   381 ,   1005    ,   705 ,   2385    ,   5007    ,0 };
            const std::uint32_t dim1101Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   15  ,   45  ,   41  ,   175 ,   137 ,   1019    ,   1869    ,   2337    ,   3433    ,0 };
            const std::uint32_t dim1102Kuo2Init[]       =   {   1   ,   3   ,   7   ,   15  ,   15  ,   51  ,   89  ,   193 ,   325 ,   391 ,   197 ,   2607    ,   6717    ,0 };
            const std::uint32_t dim1103Kuo2Init[]       =   {   1   ,   3   ,   7   ,   1   ,   15  ,   11  ,   113 ,   245 ,   255 ,   481 ,   237 ,   3205    ,   4551    ,0 };
            const std::uint32_t dim1104Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   11  ,   19  ,   93  ,   97  ,   67  ,   793 ,   1165    ,   989 ,   4643    ,0 };
            const std::uint32_t dim1105Kuo2Init[]       =   {   1   ,   1   ,   1   ,   15  ,   17  ,   51  ,   63  ,   37  ,   353 ,   745 ,   1439    ,   2599    ,   2771    ,0 };
            const std::uint32_t dim1106Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   7   ,   3   ,   87  ,   245 ,   257 ,   399 ,   311 ,   3063    ,   3801    ,0 };
            const std::uint32_t dim1107Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   13  ,   3   ,   83  ,   39  ,   165 ,   827 ,   1581    ,   2491    ,   2067    ,0 };
            const std::uint32_t dim1108Kuo2Init[]       =   {   1   ,   3   ,   3   ,   3   ,   21  ,   3   ,   21  ,   95  ,   505 ,   971 ,   1599    ,   2479    ,   4155    ,0 };
            const std::uint32_t dim1109Kuo2Init[]       =   {   1   ,   3   ,   1   ,   11  ,   11  ,   57  ,   115 ,   83  ,   473 ,   457 ,   2015    ,   1855    ,   1851    ,0 };
            const std::uint32_t dim1110Kuo2Init[]       =   {   1   ,   3   ,   7   ,   11  ,   29  ,   7   ,   73  ,   203 ,   445 ,   771 ,   1225    ,   3587    ,   245 ,0 };
            const std::uint32_t dim1111Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   13  ,   53  ,   79  ,   245 ,   347 ,   277 ,   779 ,   653 ,   6213    ,   7661    ,0 };
            const std::uint32_t dim1112Kuo2Init[]       =   {   1   ,   3   ,   5   ,   3   ,   17  ,   43  ,   31  ,   251 ,   177 ,   337 ,   157 ,   3171    ,   3813    ,   7787    ,0 };
            const std::uint32_t dim1113Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   23  ,   9   ,   7   ,   45  ,   65  ,   517 ,   1449    ,   1943    ,   4995    ,   2403    ,0 };
            const std::uint32_t dim1114Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   19  ,   45  ,   71  ,   91  ,   491 ,   113 ,   1041    ,   717 ,   681 ,   13331   ,0 };
            const std::uint32_t dim1115Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   15  ,   35  ,   19  ,   25  ,   119 ,   677 ,   1355    ,   3065    ,   6325    ,   7821    ,0 };
            const std::uint32_t dim1116Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   27  ,   63  ,   41  ,   117 ,   271 ,   327 ,   1731    ,   3501    ,   4489    ,   11119   ,0 };
            const std::uint32_t dim1117Kuo2Init[]       =   {   1   ,   1   ,   3   ,   5   ,   11  ,   35  ,   51  ,   79  ,   347 ,   905 ,   857 ,   3647    ,   4773    ,   15111   ,0 };
            const std::uint32_t dim1118Kuo2Init[]       =   {   1   ,   3   ,   7   ,   3   ,   21  ,   3   ,   19  ,   147 ,   429 ,   275 ,   1813    ,   1937    ,   4489    ,   7993    ,0 };
            const std::uint32_t dim1119Kuo2Init[]       =   {   1   ,   3   ,   7   ,   9   ,   27  ,   59  ,   77  ,   179 ,   209 ,   897 ,   807 ,   1121    ,   7575    ,   9769    ,0 };
            const std::uint32_t dim1120Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   15  ,   39  ,   81  ,   183 ,   213 ,   419 ,   125 ,   1943    ,   5621    ,   9073    ,0 };
            const std::uint32_t dim1121Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   11  ,   41  ,   111 ,   169 ,   31  ,   807 ,   1277    ,   3293    ,   3233    ,   409 ,0 };
            const std::uint32_t dim1122Kuo2Init[]       =   {   1   ,   1   ,   3   ,   11  ,   31  ,   11  ,   39  ,   69  ,   429 ,   185 ,   1523    ,   469 ,   5453    ,   12453   ,0 };
            const std::uint32_t dim1123Kuo2Init[]       =   {   1   ,   1   ,   5   ,   13  ,   15  ,   59  ,   5   ,   179 ,   457 ,   803 ,   1503    ,   633 ,   7591    ,   8861    ,0 };
            const std::uint32_t dim1124Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   19  ,   47  ,   15  ,   37  ,   271 ,   361 ,   1403    ,   2043    ,   6671    ,   4171    ,0 };
            const std::uint32_t dim1125Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   3   ,   37  ,   107 ,   29  ,   505 ,   465 ,   955 ,   2431    ,   5899    ,   11363   ,0 };
            const std::uint32_t dim1126Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   11  ,   49  ,   71  ,   191 ,   197 ,   365 ,   757 ,   309 ,   3881    ,   9427    ,0 };
            const std::uint32_t dim1127Kuo2Init[]       =   {   1   ,   1   ,   7   ,   13  ,   11  ,   9   ,   3   ,   109 ,   403 ,   403 ,   867 ,   325 ,   329 ,   13675   ,0 };
            const std::uint32_t dim1128Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   13  ,   61  ,   33  ,   125 ,   431 ,   797 ,   565 ,   4065    ,   6375    ,   10343   ,0 };
            const std::uint32_t dim1129Kuo2Init[]       =   {   1   ,   1   ,   1   ,   1   ,   23  ,   59  ,   45  ,   103 ,   231 ,   829 ,   1197    ,   1547    ,   2319    ,   13541   ,0 };
            const std::uint32_t dim1130Kuo2Init[]       =   {   1   ,   1   ,   7   ,   13  ,   17  ,   59  ,   119 ,   51  ,   305 ,   153 ,   571 ,   1323    ,   6427    ,   12291   ,0 };
            const std::uint32_t dim1131Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   21  ,   17  ,   27  ,   223 ,   311 ,   1015    ,   1925    ,   1497    ,   6407    ,   15517   ,0 };
            const std::uint32_t dim1132Kuo2Init[]       =   {   1   ,   3   ,   1   ,   15  ,   13  ,   63  ,   99  ,   163 ,   35  ,   583 ,   787 ,   2679    ,   4991    ,   5933    ,0 };
            const std::uint32_t dim1133Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   31  ,   43  ,   77  ,   141 ,   153 ,   455 ,   745 ,   1377    ,   7363    ,   7301    ,0 };
            const std::uint32_t dim1134Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   23  ,   49  ,   1   ,   149 ,   393 ,   483 ,   1577    ,   1885    ,   7483    ,   9769    ,0 };
            const std::uint32_t dim1135Kuo2Init[]       =   {   1   ,   1   ,   7   ,   11  ,   23  ,   5   ,   103 ,   143 ,   35  ,   899 ,   2001    ,   2643    ,   2533    ,   7827    ,0 };
            const std::uint32_t dim1136Kuo2Init[]       =   {   1   ,   3   ,   5   ,   5   ,   13  ,   49  ,   121 ,   113 ,   75  ,   271 ,   1111    ,   535 ,   1255    ,   6977    ,0 };
            const std::uint32_t dim1137Kuo2Init[]       =   {   1   ,   1   ,   1   ,   3   ,   25  ,   53  ,   11  ,   151 ,   107 ,   985 ,   1933    ,   2791    ,   4101    ,   14515   ,0 };
            const std::uint32_t dim1138Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   29  ,   39  ,   73  ,   103 ,   139 ,   65  ,   573 ,   3909    ,   2645    ,   9603    ,0 };
            const std::uint32_t dim1139Kuo2Init[]       =   {   1   ,   3   ,   7   ,   9   ,   3   ,   31  ,   45  ,   79  ,   195 ,   749 ,   65  ,   4041    ,   3915    ,   3137    ,0 };
            const std::uint32_t dim1140Kuo2Init[]       =   {   1   ,   3   ,   3   ,   13  ,   5   ,   37  ,   87  ,   211 ,   61  ,   237 ,   1903    ,   755 ,   4077    ,   14791   ,0 };
            const std::uint32_t dim1141Kuo2Init[]       =   {   1   ,   1   ,   7   ,   5   ,   3   ,   63  ,   63  ,   45  ,   357 ,   887 ,   1511    ,   2503    ,   6669    ,   3163    ,0 };
            const std::uint32_t dim1142Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   17  ,   29  ,   113 ,   117 ,   487 ,   369 ,   1337    ,   3129    ,   3517    ,   2107    ,0 };
            const std::uint32_t dim1143Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   7   ,   13  ,   15  ,   203 ,   421 ,   267 ,   1049    ,   1645    ,   2047    ,   11733   ,0 };
            const std::uint32_t dim1144Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   17  ,   27  ,   5   ,   101 ,   109 ,   651 ,   601 ,   673 ,   67  ,   8539    ,0 };
            const std::uint32_t dim1145Kuo2Init[]       =   {   1   ,   1   ,   5   ,   13  ,   9   ,   53  ,   85  ,   165 ,   197 ,   979 ,   925 ,   419 ,   4631    ,   15269   ,0 };
            const std::uint32_t dim1146Kuo2Init[]       =   {   1   ,   3   ,   7   ,   15  ,   5   ,   5   ,   61  ,   205 ,   257 ,   279 ,   81  ,   4059    ,   2375    ,   12821   ,0 };
            const std::uint32_t dim1147Kuo2Init[]       =   {   1   ,   3   ,   1   ,   11  ,   27  ,   41  ,   39  ,   41  ,   75  ,   1017    ,   529 ,   2709    ,   3385    ,   3879    ,0 };
            const std::uint32_t dim1148Kuo2Init[]       =   {   1   ,   3   ,   1   ,   13  ,   25  ,   63  ,   125 ,   137 ,   27  ,   839 ,   617 ,   2129    ,   711 ,   3955    ,0 };
            const std::uint32_t dim1149Kuo2Init[]       =   {   1   ,   3   ,   5   ,   5   ,   27  ,   19  ,   27  ,   51  ,   369 ,   593 ,   605 ,   2471    ,   6995    ,   5957    ,0 };
            const std::uint32_t dim1150Kuo2Init[]       =   {   1   ,   3   ,   3   ,   5   ,   9   ,   11  ,   63  ,   157 ,   447 ,   713 ,   1145    ,   2013    ,   3061    ,   13763   ,0 };
            const std::uint32_t dim1151Kuo2Init[]       =   {   1   ,   1   ,   5   ,   1   ,   15  ,   51  ,   49  ,   185 ,   337 ,   109 ,   1335    ,   841 ,   7005    ,   8969    ,0 };
            const std::uint32_t dim1152Kuo2Init[]       =   {   1   ,   1   ,   5   ,   15  ,   17  ,   25  ,   31  ,   135 ,   43  ,   469 ,   1895    ,   3369    ,   6981    ,   8515    ,0 };
            const std::uint32_t dim1153Kuo2Init[]       =   {   1   ,   1   ,   5   ,   9   ,   21  ,   11  ,   117 ,   79  ,   39  ,   63  ,   1355    ,   2309    ,   4409    ,   6463    ,0 };
            const std::uint32_t dim1154Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   11  ,   55  ,   55  ,   75  ,   251 ,   209 ,   1715    ,   697 ,   2199    ,   2155    ,0 };
            const std::uint32_t dim1155Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   31  ,   29  ,   55  ,   23  ,   391 ,   1011    ,   1701    ,   787 ,   8165    ,   1315    ,0 };
            const std::uint32_t dim1156Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   23  ,   55  ,   125 ,   15  ,   77  ,   107 ,   2043    ,   1501    ,   727 ,   13693   ,0 };
            const std::uint32_t dim1157Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   27  ,   37  ,   47  ,   247 ,   227 ,   595 ,   175 ,   3459    ,   395 ,   9903    ,0 };
            const std::uint32_t dim1158Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   7   ,   7   ,   61  ,   81  ,   405 ,   117 ,   51  ,   3715    ,   2757    ,   2797    ,0 };
            const std::uint32_t dim1159Kuo2Init[]       =   {   1   ,   1   ,   1   ,   15  ,   15  ,   25  ,   9   ,   109 ,   497 ,   395 ,   777 ,   1187    ,   7451    ,   15959   ,0 };
            const std::uint32_t dim1160Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   7   ,   23  ,   69  ,   27  ,   97  ,   145 ,   1165    ,   993 ,   235 ,   1785    ,0 };
            const std::uint32_t dim1161Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   17  ,   49  ,   73  ,   27  ,   223 ,   83  ,   295 ,   1425    ,   4817    ,   7325    ,0 };
            const std::uint32_t dim1162Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   25  ,   13  ,   69  ,   119 ,   483 ,   635 ,   1105    ,   2547    ,   457 ,   5607    ,0 };
            const std::uint32_t dim1163Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   13  ,   29  ,   69  ,   7   ,   223 ,   95  ,   1255    ,   459 ,   4633    ,   12609   ,0 };
            const std::uint32_t dim1164Kuo2Init[]       =   {   1   ,   1   ,   1   ,   1   ,   15  ,   57  ,   105 ,   161 ,   429 ,   615 ,   201 ,   2601    ,   3169    ,   3163    ,0 };
            const std::uint32_t dim1165Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   5   ,   5   ,   127 ,   129 ,   457 ,   59  ,   459 ,   3731    ,   2069    ,   9147    ,0 };
            const std::uint32_t dim1166Kuo2Init[]       =   {   1   ,   1   ,   1   ,   7   ,   25  ,   45  ,   101 ,   111 ,   119 ,   739 ,   157 ,   3967    ,   6427    ,   2845    ,0 };
            const std::uint32_t dim1167Kuo2Init[]       =   {   1   ,   3   ,   1   ,   9   ,   15  ,   15  ,   105 ,   147 ,   119 ,   815 ,   1263    ,   2201    ,   5413    ,   15255   ,0 };
            const std::uint32_t dim1168Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   15  ,   47  ,   87  ,   131 ,   451 ,   805 ,   1043    ,   2917    ,   5495    ,   5103    ,0 };
            const std::uint32_t dim1169Kuo2Init[]       =   {   1   ,   1   ,   3   ,   11  ,   29  ,   35  ,   33  ,   135 ,   509 ,   425 ,   723 ,   1947    ,   7237    ,   8941    ,0 };
            const std::uint32_t dim1170Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   5   ,   39  ,   83  ,   83  ,   353 ,   685 ,   195 ,   385 ,   2431    ,   8753    ,0 };
            const std::uint32_t dim1171Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   25  ,   45  ,   3   ,   129 ,   413 ,   1005    ,   625 ,   3503    ,   5473    ,   3577    ,0 };
            const std::uint32_t dim1172Kuo2Init[]       =   {   1   ,   1   ,   3   ,   13  ,   7   ,   37  ,   29  ,   163 ,   397 ,   671 ,   1043    ,   3581    ,   465 ,   9521    ,0 };
            const std::uint32_t dim1173Kuo2Init[]       =   {   1   ,   1   ,   3   ,   5   ,   31  ,   21  ,   111 ,   95  ,   385 ,   787 ,   1205    ,   795 ,   4779    ,   11421   ,0 };
            const std::uint32_t dim1174Kuo2Init[]       =   {   1   ,   1   ,   1   ,   3   ,   25  ,   15  ,   51  ,   149 ,   423 ,   907 ,   863 ,   1535    ,   5809    ,   1069    ,0 };
            const std::uint32_t dim1175Kuo2Init[]       =   {   1   ,   3   ,   5   ,   5   ,   19  ,   57  ,   51  ,   49  ,   39  ,   349 ,   1453    ,   3091    ,   4861    ,   8771    ,0 };
            const std::uint32_t dim1176Kuo2Init[]       =   {   1   ,   1   ,   5   ,   15  ,   1   ,   45  ,   93  ,   85  ,   511 ,   607 ,   793 ,   1023    ,   1525    ,   535 ,0 };
            const std::uint32_t dim1177Kuo2Init[]       =   {   1   ,   3   ,   3   ,   11  ,   7   ,   53  ,   83  ,   139 ,   173 ,   947 ,   1381    ,   433 ,   5821    ,   4173    ,0 };
            const std::uint32_t dim1178Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   27  ,   17  ,   17  ,   237 ,   427 ,   295 ,   929 ,   1539    ,   2373    ,   6671    ,0 };
            const std::uint32_t dim1179Kuo2Init[]       =   {   1   ,   1   ,   1   ,   1   ,   9   ,   53  ,   87  ,   129 ,   443 ,   729 ,   1067    ,   359 ,   789 ,   7637    ,0 };
            const std::uint32_t dim1180Kuo2Init[]       =   {   1   ,   1   ,   1   ,   7   ,   7   ,   23  ,   71  ,   115 ,   343 ,   207 ,   889 ,   3561    ,   475 ,   3437    ,0 };
            const std::uint32_t dim1181Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   17  ,   31  ,   85  ,   135 ,   155 ,   269 ,   575 ,   537 ,   5305    ,   979 ,0 };
            const std::uint32_t dim1182Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   19  ,   41  ,   61  ,   103 ,   49  ,   93  ,   733 ,   1791    ,   3577    ,   1763    ,0 };
            const std::uint32_t dim1183Kuo2Init[]       =   {   1   ,   1   ,   3   ,   3   ,   27  ,   23  ,   3   ,   143 ,   341 ,   847 ,   1859    ,   995 ,   5277    ,   5025    ,0 };
            const std::uint32_t dim1184Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   7   ,   29  ,   37  ,   201 ,   359 ,   255 ,   1543    ,   3735    ,   1217    ,   7251    ,0 };
            const std::uint32_t dim1185Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   27  ,   45  ,   15  ,   187 ,   181 ,   571 ,   1345    ,   1473    ,   519 ,   7499    ,0 };
            const std::uint32_t dim1186Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   11  ,   11  ,   75  ,   179 ,   455 ,   495 ,   283 ,   2995    ,   1515    ,   5497    ,0 };
            const std::uint32_t dim1187Kuo2Init[]       =   {   1   ,   1   ,   7   ,   3   ,   11  ,   19  ,   91  ,   165 ,   175 ,   967 ,   1719    ,   739 ,   103 ,   15259   ,0 };
            const std::uint32_t dim1188Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   7   ,   5   ,   121 ,   65  ,   83  ,   687 ,   837 ,   2303    ,   1953    ,   15419   ,0 };
            const std::uint32_t dim1189Kuo2Init[]       =   {   1   ,   3   ,   1   ,   13  ,   31  ,   39  ,   43  ,   69  ,   129 ,   815 ,   1419    ,   3179    ,   595 ,   14471   ,0 };
            const std::uint32_t dim1190Kuo2Init[]       =   {   1   ,   1   ,   5   ,   9   ,   9   ,   33  ,   75  ,   141 ,   271 ,   259 ,   91  ,   553 ,   7521    ,   9591    ,0 };
            const std::uint32_t dim1191Kuo2Init[]       =   {   1   ,   1   ,   5   ,   1   ,   27  ,   55  ,   125 ,   41  ,   103 ,   161 ,   9   ,   1339    ,   3205    ,   973 ,0 };
            const std::uint32_t dim1192Kuo2Init[]       =   {   1   ,   1   ,   3   ,   3   ,   13  ,   15  ,   93  ,   179 ,   435 ,   667 ,   1365    ,   169 ,   4685    ,   16175   ,0 };
            const std::uint32_t dim1193Kuo2Init[]       =   {   1   ,   1   ,   5   ,   9   ,   17  ,   55  ,   45  ,   237 ,   291 ,   837 ,   1019    ,   2983    ,   1679    ,   13583   ,0 };
            const std::uint32_t dim1194Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   3   ,   37  ,   37  ,   239 ,   265 ,   117 ,   1239    ,   529 ,   4855    ,   11423   ,0 };
            const std::uint32_t dim1195Kuo2Init[]       =   {   1   ,   3   ,   5   ,   3   ,   11  ,   11  ,   121 ,   81  ,   55  ,   35  ,   1551    ,   775 ,   6973    ,   13525   ,0 };
            const std::uint32_t dim1196Kuo2Init[]       =   {   1   ,   3   ,   3   ,   11  ,   15  ,   19  ,   49  ,   117 ,   269 ,   147 ,   1891    ,   2975    ,   1779    ,   9327    ,0 };
            const std::uint32_t dim1197Kuo2Init[]       =   {   1   ,   1   ,   1   ,   7   ,   9   ,   39  ,   111 ,   131 ,   179 ,   629 ,   1807    ,   3327    ,   1535    ,   2845    ,0 };
            const std::uint32_t dim1198Kuo2Init[]       =   {   1   ,   3   ,   7   ,   13  ,   11  ,   59  ,   125 ,   41  ,   13  ,   637 ,   1679    ,   487 ,   4655    ,   8045    ,0 };
            const std::uint32_t dim1199Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   17  ,   15  ,   63  ,   105 ,   271 ,   205 ,   283 ,   3427    ,   1921    ,   12729   ,0 };
            const std::uint32_t dim1200Kuo2Init[]       =   {   1   ,   1   ,   3   ,   5   ,   13  ,   57  ,   23  ,   141 ,   261 ,   829 ,   1149    ,   945 ,   4191    ,   13277   ,0 };
            const std::uint32_t dim1201Kuo2Init[]       =   {   1   ,   1   ,   5   ,   7   ,   13  ,   59  ,   79  ,   221 ,   473 ,   803 ,   2027    ,   437 ,   7823    ,   14225   ,0 };
            const std::uint32_t dim1202Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   15  ,   21  ,   53  ,   69  ,   13  ,   479 ,   193 ,   1031    ,   4911    ,   12011   ,0 };
            const std::uint32_t dim1203Kuo2Init[]       =   {   1   ,   1   ,   5   ,   7   ,   25  ,   7   ,   99  ,   81  ,   21  ,   247 ,   1019    ,   2537    ,   3647    ,   8211    ,0 };
            const std::uint32_t dim1204Kuo2Init[]       =   {   1   ,   3   ,   7   ,   15  ,   27  ,   47  ,   105 ,   141 ,   49  ,   65  ,   525 ,   1717    ,   1339    ,   9079    ,0 };
            const std::uint32_t dim1205Kuo2Init[]       =   {   1   ,   1   ,   7   ,   3   ,   27  ,   1   ,   31  ,   135 ,   175 ,   997 ,   1517    ,   1139    ,   7975    ,   14941   ,0 };
            const std::uint32_t dim1206Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   9   ,   5   ,   77  ,   175 ,   333 ,   975 ,   873 ,   523 ,   2967    ,   9463    ,0 };
            const std::uint32_t dim1207Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   5   ,   61  ,   17  ,   141 ,   405 ,   591 ,   711 ,   1077    ,   2875    ,   8827    ,0 };
            const std::uint32_t dim1208Kuo2Init[]       =   {   1   ,   3   ,   1   ,   11  ,   9   ,   13  ,   29  ,   9   ,   443 ,   717 ,   2019    ,   1031    ,   6459    ,   6673    ,0 };
            const std::uint32_t dim1209Kuo2Init[]       =   {   1   ,   1   ,   3   ,   5   ,   7   ,   51  ,   45  ,   163 ,   113 ,   705 ,   1411    ,   3861    ,   527 ,   6119    ,0 };
            const std::uint32_t dim1210Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   9   ,   43  ,   57  ,   79  ,   221 ,   131 ,   1543    ,   2243    ,   5277    ,   6249    ,0 };
            const std::uint32_t dim1211Kuo2Init[]       =   {   1   ,   1   ,   1   ,   7   ,   15  ,   63  ,   89  ,   11  ,   211 ,   245 ,   89  ,   219 ,   241 ,   545 ,0 };
            const std::uint32_t dim1212Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   31  ,   21  ,   97  ,   43  ,   457 ,   941 ,   363 ,   3275    ,   4731    ,   3167    ,0 };
            const std::uint32_t dim1213Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   31  ,   45  ,   15  ,   119 ,   283 ,   645 ,   1239    ,   3835    ,   5317    ,   4643    ,0 };
            const std::uint32_t dim1214Kuo2Init[]       =   {   1   ,   1   ,   5   ,   3   ,   23  ,   31  ,   49  ,   67  ,   487 ,   935 ,   1899    ,   2545    ,   8135    ,   12609   ,0 };
            const std::uint32_t dim1215Kuo2Init[]       =   {   1   ,   3   ,   7   ,   9   ,   21  ,   63  ,   15  ,   233 ,   463 ,   763 ,   327 ,   2585    ,   4399    ,   14643   ,0 };
            const std::uint32_t dim1216Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   13  ,   5   ,   95  ,   11  ,   239 ,   507 ,   955 ,   569 ,   6443    ,   3009    ,0 };
            const std::uint32_t dim1217Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   31  ,   27  ,   99  ,   251 ,   487 ,   383 ,   1117    ,   2231    ,   6541    ,   10409   ,0 };
            const std::uint32_t dim1218Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   23  ,   37  ,   81  ,   149 ,   127 ,   341 ,   1749    ,   207 ,   2257    ,   2659    ,0 };
            const std::uint32_t dim1219Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   15  ,   7   ,   59  ,   63  ,   187 ,   719 ,   1295    ,   3509    ,   2293    ,   4959    ,0 };
            const std::uint32_t dim1220Kuo2Init[]       =   {   1   ,   1   ,   5   ,   13  ,   3   ,   49  ,   27  ,   17  ,   261 ,   463 ,   1719    ,   793 ,   4365    ,   4041    ,0 };
            const std::uint32_t dim1221Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   7   ,   37  ,   19  ,   133 ,   197 ,   789 ,   383 ,   1005    ,   7353    ,   2431    ,0 };
            const std::uint32_t dim1222Kuo2Init[]       =   {   1   ,   1   ,   1   ,   13  ,   21  ,   11  ,   27  ,   247 ,   309 ,   103 ,   1707    ,   2555    ,   2731    ,   11755   ,0 };
            const std::uint32_t dim1223Kuo2Init[]       =   {   1   ,   3   ,   1   ,   15  ,   13  ,   45  ,   119 ,   233 ,   387 ,   781 ,   851 ,   3207    ,   5251    ,   9741    ,0 };
            const std::uint32_t dim1224Kuo2Init[]       =   {   1   ,   3   ,   7   ,   15  ,   3   ,   17  ,   13  ,   217 ,   245 ,   267 ,   55  ,   3065    ,   3733    ,   2577    ,0 };
            const std::uint32_t dim1225Kuo2Init[]       =   {   1   ,   1   ,   7   ,   13  ,   11  ,   25  ,   7   ,   219 ,   209 ,   295 ,   1725    ,   359 ,   5489    ,   1057    ,0 };
            const std::uint32_t dim1226Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   7   ,   1   ,   93  ,   33  ,   485 ,   977 ,   1113    ,   3049    ,   7015    ,   14275   ,0 };
            const std::uint32_t dim1227Kuo2Init[]       =   {   1   ,   3   ,   3   ,   13  ,   15  ,   9   ,   115 ,   113 ,   221 ,   1   ,   875 ,   1485    ,   3523    ,   6817    ,0 };
            const std::uint32_t dim1228Kuo2Init[]       =   {   1   ,   1   ,   5   ,   15  ,   3   ,   41  ,   113 ,   5   ,   7   ,   1023    ,   349 ,   1901    ,   1223    ,   11355   ,0 };
            const std::uint32_t dim1229Kuo2Init[]       =   {   1   ,   3   ,   7   ,   13  ,   27  ,   59  ,   113 ,   123 ,   81  ,   795 ,   803 ,   955 ,   7101    ,   7715    ,0 };
            const std::uint32_t dim1230Kuo2Init[]       =   {   1   ,   1   ,   1   ,   15  ,   15  ,   19  ,   123 ,   183 ,   341 ,   9   ,   943 ,   549 ,   1261    ,   8305    ,0 };
            const std::uint32_t dim1231Kuo2Init[]       =   {   1   ,   1   ,   3   ,   5   ,   25  ,   45  ,   109 ,   239 ,   399 ,   405 ,   1859    ,   3721    ,   2023    ,   12543   ,0 };
            const std::uint32_t dim1232Kuo2Init[]       =   {   1   ,   3   ,   1   ,   11  ,   11  ,   51  ,   119 ,   83  ,   189 ,   119 ,   51  ,   3601    ,   1589    ,   3821    ,0 };
            const std::uint32_t dim1233Kuo2Init[]       =   {   1   ,   3   ,   3   ,   3   ,   9   ,   41  ,   13  ,   91  ,   329 ,   625 ,   1837    ,   2539    ,   5603    ,   2135    ,0 };
            const std::uint32_t dim1234Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   5   ,   59  ,   125 ,   133 ,   321 ,   759 ,   237 ,   3299    ,   4663    ,   15767   ,0 };
            const std::uint32_t dim1235Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   29  ,   3   ,   45  ,   37  ,   69  ,   437 ,   1321    ,   3545    ,   373 ,   3349    ,0 };
            const std::uint32_t dim1236Kuo2Init[]       =   {   1   ,   1   ,   1   ,   13  ,   13  ,   47  ,   87  ,   33  ,   93  ,   639 ,   673 ,   1675    ,   5997    ,   9049    ,0 };
            const std::uint32_t dim1237Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   31  ,   27  ,   33  ,   175 ,   71  ,   509 ,   229 ,   2959    ,   7929    ,   7551    ,0 };
            const std::uint32_t dim1238Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   17  ,   41  ,   101 ,   119 ,   51  ,   297 ,   595 ,   41  ,   7919    ,   6173    ,0 };
            const std::uint32_t dim1239Kuo2Init[]       =   {   1   ,   3   ,   5   ,   11  ,   11  ,   63  ,   17  ,   177 ,   349 ,   327 ,   531 ,   783 ,   4025    ,   3367    ,0 };
            const std::uint32_t dim1240Kuo2Init[]       =   {   1   ,   3   ,   1   ,   13  ,   11  ,   31  ,   97  ,   137 ,   117 ,   981 ,   3   ,   2873    ,   6399    ,   5055    ,0 };
            const std::uint32_t dim1241Kuo2Init[]       =   {   1   ,   3   ,   7   ,   11  ,   9   ,   63  ,   53  ,   237 ,   255 ,   161 ,   1709    ,   3591    ,   2569    ,   8687    ,0 };
            const std::uint32_t dim1242Kuo2Init[]       =   {   1   ,   3   ,   3   ,   11  ,   23  ,   9   ,   97  ,   143 ,   403 ,   597 ,   1651    ,   933 ,   1351    ,   3675    ,0 };
            const std::uint32_t dim1243Kuo2Init[]       =   {   1   ,   1   ,   1   ,   9   ,   23  ,   11  ,   93  ,   103 ,   245 ,   797 ,   723 ,   4029    ,   4313    ,   14217   ,0 };
            const std::uint32_t dim1244Kuo2Init[]       =   {   1   ,   1   ,   1   ,   3   ,   13  ,   51  ,   77  ,   237 ,   109 ,   933 ,   449 ,   429 ,   6991    ,   13475   ,0 };
            const std::uint32_t dim1245Kuo2Init[]       =   {   1   ,   3   ,   1   ,   1   ,   29  ,   63  ,   65  ,   63  ,   129 ,   693 ,   1441    ,   3877    ,   3015    ,   7817    ,0 };
            const std::uint32_t dim1246Kuo2Init[]       =   {   1   ,   1   ,   7   ,   3   ,   7   ,   57  ,   63  ,   129 ,   15  ,   257 ,   739 ,   3395    ,   1473    ,   12735   ,0 };
            const std::uint32_t dim1247Kuo2Init[]       =   {   1   ,   1   ,   1   ,   9   ,   23  ,   21  ,   123 ,   81  ,   297 ,   899 ,   1719    ,   3523    ,   4895    ,   12503   ,0 };
            const std::uint32_t dim1248Kuo2Init[]       =   {   1   ,   1   ,   3   ,   1   ,   9   ,   3   ,   61  ,   7   ,   251 ,   1003    ,   289 ,   1321    ,   7041    ,   6811    ,0 };
            const std::uint32_t dim1249Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   3   ,   9   ,   87  ,   13  ,   363 ,   713 ,   673 ,   717 ,   1449    ,   6869    ,0 };
            const std::uint32_t dim1250Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   25  ,   53  ,   115 ,   111 ,   499 ,   425 ,   1037    ,   3751    ,   5767    ,   10047   ,0 };
            const std::uint32_t dim1251Kuo2Init[]       =   {   1   ,   3   ,   7   ,   11  ,   23  ,   43  ,   75  ,   101 ,   105 ,   115 ,   887 ,   3747    ,   149 ,   5513    ,0 };
            const std::uint32_t dim1252Kuo2Init[]       =   {   1   ,   3   ,   1   ,   9   ,   7   ,   43  ,   125 ,   63  ,   3   ,   365 ,   1345    ,   821 ,   731 ,   14007   ,0 };
            const std::uint32_t dim1253Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   29  ,   49  ,   55  ,   37  ,   343 ,   481 ,   1319    ,   1167    ,   4835    ,   10549   ,0 };
            const std::uint32_t dim1254Kuo2Init[]       =   {   1   ,   1   ,   7   ,   13  ,   11  ,   33  ,   123 ,   91  ,   301 ,   765 ,   1037    ,   2935    ,   1213    ,   10141   ,0 };
            const std::uint32_t dim1255Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   21  ,   55  ,   57  ,   79  ,   187 ,   977 ,   297 ,   63  ,   3431    ,   10597   ,0 };
            const std::uint32_t dim1256Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   5   ,   25  ,   33  ,   25  ,   477 ,   105 ,   1757    ,   2051    ,   1263    ,   15421   ,0 };
            const std::uint32_t dim1257Kuo2Init[]       =   {   1   ,   3   ,   5   ,   11  ,   5   ,   39  ,   63  ,   209 ,   223 ,   497 ,   785 ,   2127    ,   4293    ,   7583    ,0 };
            const std::uint32_t dim1258Kuo2Init[]       =   {   1   ,   1   ,   5   ,   3   ,   9   ,   23  ,   107 ,   125 ,   319 ,   143 ,   947 ,   1135    ,   4391    ,   6297    ,0 };
            const std::uint32_t dim1259Kuo2Init[]       =   {   1   ,   3   ,   7   ,   15  ,   19  ,   21  ,   103 ,   161 ,   5   ,   739 ,   1537    ,   2697    ,   1827    ,   8287    ,0 };
            const std::uint32_t dim1260Kuo2Init[]       =   {   1   ,   1   ,   7   ,   3   ,   29  ,   37  ,   117 ,   199 ,   35  ,   683 ,   1539    ,   2915    ,   8129    ,   14785   ,0 };
            const std::uint32_t dim1261Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   7   ,   35  ,   39  ,   181 ,   111 ,   165 ,   1919    ,   1583    ,   4219    ,   179 ,0 };
            const std::uint32_t dim1262Kuo2Init[]       =   {   1   ,   3   ,   3   ,   11  ,   15  ,   5   ,   13  ,   123 ,   93  ,   615 ,   1811    ,   3235    ,   4533    ,   2423    ,0 };
            const std::uint32_t dim1263Kuo2Init[]       =   {   1   ,   1   ,   1   ,   15  ,   25  ,   17  ,   21  ,   37  ,   5   ,   413 ,   1681    ,   2297    ,   5571    ,   6037    ,0 };
            const std::uint32_t dim1264Kuo2Init[]       =   {   1   ,   1   ,   1   ,   9   ,   27  ,   21  ,   7   ,   139 ,   235 ,   163 ,   1809    ,   783 ,   507 ,   8867    ,0 };
            const std::uint32_t dim1265Kuo2Init[]       =   {   1   ,   3   ,   7   ,   9   ,   23  ,   57  ,   1   ,   55  ,   311 ,   687 ,   1987    ,   463 ,   5639    ,   4795    ,0 };
            const std::uint32_t dim1266Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   11  ,   55  ,   31  ,   77  ,   277 ,   447 ,   799 ,   993 ,   489 ,   3539    ,0 };
            const std::uint32_t dim1267Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   27  ,   19  ,   23  ,   207 ,   11  ,   81  ,   1539    ,   1051    ,   1155    ,   11475   ,0 };
            const std::uint32_t dim1268Kuo2Init[]       =   {   1   ,   1   ,   5   ,   1   ,   23  ,   63  ,   23  ,   247 ,   261 ,   789 ,   1305    ,   3003    ,   1033    ,   1883    ,0 };
            const std::uint32_t dim1269Kuo2Init[]       =   {   1   ,   1   ,   5   ,   15  ,   1   ,   35  ,   1   ,   147 ,   51  ,   513 ,   35  ,   3285    ,   7461    ,   13733   ,0 };
            const std::uint32_t dim1270Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   29  ,   25  ,   107 ,   91  ,   355 ,   213 ,   203 ,   2371    ,   1383    ,   14285   ,0 };
            const std::uint32_t dim1271Kuo2Init[]       =   {   1   ,   3   ,   7   ,   13  ,   11  ,   35  ,   109 ,   171 ,   229 ,   209 ,   375 ,   2911    ,   1943    ,   7037    ,0 };
            const std::uint32_t dim1272Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   21  ,   39  ,   113 ,   5   ,   167 ,   769 ,   2047    ,   3083    ,   7421    ,   14085   ,0 };
            const std::uint32_t dim1273Kuo2Init[]       =   {   1   ,   3   ,   7   ,   13  ,   13  ,   27  ,   83  ,   67  ,   171 ,   671 ,   1675    ,   2473    ,   3241    ,   15283   ,0 };
            const std::uint32_t dim1274Kuo2Init[]       =   {   1   ,   1   ,   1   ,   7   ,   5   ,   27  ,   23  ,   171 ,   443 ,   243 ,   217 ,   3349    ,   1919    ,   2345    ,0 };
            const std::uint32_t dim1275Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   7   ,   1   ,   41  ,   25  ,   47  ,   835 ,   1071    ,   3091    ,   6133    ,   7249    ,0 };
            const std::uint32_t dim1276Kuo2Init[]       =   {   1   ,   1   ,   7   ,   15  ,   27  ,   41  ,   3   ,   153 ,   479 ,   447 ,   1457    ,   2267    ,   3781    ,   9851    ,0 };
            const std::uint32_t dim1277Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   25  ,   1   ,   125 ,   129 ,   231 ,   505 ,   1709    ,   3117    ,   6069    ,   3103    ,0 };
            const std::uint32_t dim1278Kuo2Init[]       =   {   1   ,   3   ,   3   ,   13  ,   9   ,   53  ,   73  ,   93  ,   185 ,   1007    ,   1883    ,   3087    ,   7453    ,   13335   ,0 };
            const std::uint32_t dim1279Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   7   ,   51  ,   65  ,   189 ,   397 ,   73  ,   377 ,   2593    ,   6703    ,   16145   ,0 };
            const std::uint32_t dim1280Kuo2Init[]       =   {   1   ,   1   ,   7   ,   3   ,   17  ,   55  ,   93  ,   251 ,   29  ,   937 ,   223 ,   721 ,   3275    ,   11881   ,0 };
            const std::uint32_t dim1281Kuo2Init[]       =   {   1   ,   3   ,   7   ,   1   ,   1   ,   45  ,   99  ,   117 ,   279 ,   87  ,   2015    ,   3681    ,   5625    ,   5191    ,0 };
            const std::uint32_t dim1282Kuo2Init[]       =   {   1   ,   3   ,   7   ,   9   ,   7   ,   63  ,   23  ,   83  ,   277 ,   959 ,   693 ,   3945    ,   4551    ,   13711   ,0 };
            const std::uint32_t dim1283Kuo2Init[]       =   {   1   ,   3   ,   1   ,   1   ,   23  ,   57  ,   127 ,   7   ,   323 ,   545 ,   1909    ,   2399    ,   4483    ,   12165   ,0 };
            const std::uint32_t dim1284Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   23  ,   37  ,   39  ,   213 ,   45  ,   949 ,   661 ,   397 ,   189 ,   2835    ,0 };
            const std::uint32_t dim1285Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   17  ,   11  ,   97  ,   141 ,   389 ,   137 ,   907 ,   3939    ,   1205    ,   9751    ,0 };
            const std::uint32_t dim1286Kuo2Init[]       =   {   1   ,   1   ,   5   ,   9   ,   25  ,   45  ,   53  ,   101 ,   43  ,   503 ,   777 ,   1327    ,   8127    ,   1977    ,0 };
            const std::uint32_t dim1287Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   19  ,   15  ,   71  ,   193 ,   443 ,   817 ,   1507    ,   291 ,   3781    ,   5841    ,0 };
            const std::uint32_t dim1288Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   25  ,   41  ,   121 ,   17  ,   471 ,   357 ,   1193    ,   3079    ,   2025    ,   773 ,0 };
            const std::uint32_t dim1289Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   5   ,   31  ,   123 ,   35  ,   103 ,   439 ,   1199    ,   1887    ,   6923    ,   9439    ,0 };
            const std::uint32_t dim1290Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   7   ,   35  ,   1   ,   151 ,   467 ,   573 ,   517 ,   3681    ,   4563    ,   3143    ,0 };
            const std::uint32_t dim1291Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   19  ,   61  ,   43  ,   57  ,   217 ,   113 ,   1045    ,   3773    ,   1197    ,   14627   ,0 };
            const std::uint32_t dim1292Kuo2Init[]       =   {   1   ,   3   ,   7   ,   11  ,   7   ,   51  ,   71  ,   31  ,   71  ,   143 ,   319 ,   2979    ,   849 ,   14403   ,0 };
            const std::uint32_t dim1293Kuo2Init[]       =   {   1   ,   1   ,   1   ,   15  ,   17  ,   25  ,   119 ,   253 ,   13  ,   959 ,   1217    ,   261 ,   2853    ,   10449   ,0 };
            const std::uint32_t dim1294Kuo2Init[]       =   {   1   ,   3   ,   7   ,   15  ,   23  ,   19  ,   71  ,   205 ,   63  ,   915 ,   317 ,   1637    ,   1963    ,   10047   ,0 };
            const std::uint32_t dim1295Kuo2Init[]       =   {   1   ,   1   ,   5   ,   9   ,   21  ,   57  ,   119 ,   223 ,   169 ,   87  ,   593 ,   2871    ,   1201    ,   4531    ,0 };
            const std::uint32_t dim1296Kuo2Init[]       =   {   1   ,   3   ,   5   ,   3   ,   7   ,   11  ,   25  ,   129 ,   469 ,   199 ,   323 ,   4021    ,   2983    ,   1459    ,0 };
            const std::uint32_t dim1297Kuo2Init[]       =   {   1   ,   3   ,   1   ,   1   ,   7   ,   39  ,   41  ,   75  ,   75  ,   113 ,   985 ,   3353    ,   5393    ,   7055    ,0 };
            const std::uint32_t dim1298Kuo2Init[]       =   {   1   ,   3   ,   3   ,   11  ,   19  ,   55  ,   37  ,   235 ,   221 ,   197 ,   1041    ,   3447    ,   8045    ,   801 ,0 };
            const std::uint32_t dim1299Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   9   ,   19  ,   3   ,   221 ,   265 ,   963 ,   1815    ,   469 ,   2929    ,   10711   ,0 };
            const std::uint32_t dim1300Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   27  ,   11  ,   59  ,   57  ,   91  ,   235 ,   1465    ,   825 ,   6429    ,   15537   ,0 };
            const std::uint32_t dim1301Kuo2Init[]       =   {   1   ,   1   ,   1   ,   1   ,   19  ,   21  ,   47  ,   235 ,   223 ,   761 ,   173 ,   3793    ,   2197    ,   10919   ,0 };
            const std::uint32_t dim1302Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   11  ,   61  ,   19  ,   121 ,   51  ,   617 ,   441 ,   1889    ,   6225    ,   3317    ,0 };
            const std::uint32_t dim1303Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   25  ,   27  ,   65  ,   163 ,   165 ,   7   ,   1303    ,   3275    ,   173 ,   6923    ,0 };
            const std::uint32_t dim1304Kuo2Init[]       =   {   1   ,   3   ,   1   ,   13  ,   23  ,   39  ,   35  ,   105 ,   267 ,   679 ,   1675    ,   2837    ,   1213    ,   14985   ,0 };
            const std::uint32_t dim1305Kuo2Init[]       =   {   1   ,   1   ,   5   ,   1   ,   21  ,   39  ,   1   ,   229 ,   101 ,   421 ,   513 ,   571 ,   7195    ,   9975    ,0 };
            const std::uint32_t dim1306Kuo2Init[]       =   {   1   ,   1   ,   1   ,   1   ,   13  ,   23  ,   97  ,   157 ,   1   ,   969 ,   2011    ,   295 ,   6775    ,   7397    ,0 };
            const std::uint32_t dim1307Kuo2Init[]       =   {   1   ,   1   ,   5   ,   5   ,   15  ,   9   ,   63  ,   21  ,   435 ,   51  ,   1279    ,   1309    ,   4303    ,   15771   ,0 };
            const std::uint32_t dim1308Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   3   ,   43  ,   121 ,   59  ,   365 ,   437 ,   215 ,   2899    ,   761 ,   1369    ,0 };
            const std::uint32_t dim1309Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   17  ,   25  ,   29  ,   149 ,   291 ,   117 ,   247 ,   2779    ,   7379    ,   11671   ,0 };
            const std::uint32_t dim1310Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   7   ,   3   ,   87  ,   213 ,   467 ,   91  ,   145 ,   1241    ,   1557    ,   6427    ,0 };
            const std::uint32_t dim1311Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   3   ,   51  ,   1   ,   61  ,   259 ,   535 ,   399 ,   3101    ,   5781    ,   14635   ,0 };
            const std::uint32_t dim1312Kuo2Init[]       =   {   1   ,   3   ,   3   ,   11  ,   21  ,   17  ,   127 ,   117 ,   203 ,   825 ,   1481    ,   3979    ,   3605    ,   10537   ,0 };
            const std::uint32_t dim1313Kuo2Init[]       =   {   1   ,   1   ,   5   ,   13  ,   15  ,   5   ,   119 ,   79  ,   439 ,   209 ,   1811    ,   3199    ,   7933    ,   1677    ,0 };
            const std::uint32_t dim1314Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   9   ,   9   ,   111 ,   103 ,   145 ,   839 ,   187 ,   2937    ,   6871    ,   10573   ,0 };
            const std::uint32_t dim1315Kuo2Init[]       =   {   1   ,   3   ,   1   ,   9   ,   19  ,   7   ,   39  ,   37  ,   209 ,   83  ,   1143    ,   3767    ,   6013    ,   8829    ,0 };
            const std::uint32_t dim1316Kuo2Init[]       =   {   1   ,   1   ,   7   ,   5   ,   31  ,   39  ,   97  ,   167 ,   323 ,   343 ,   999 ,   2179    ,   6683    ,   4079    ,0 };
            const std::uint32_t dim1317Kuo2Init[]       =   {   1   ,   1   ,   1   ,   7   ,   1   ,   31  ,   5   ,   109 ,   391 ,   17  ,   1943    ,   2753    ,   3825    ,   327 ,0 };
            const std::uint32_t dim1318Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   9   ,   19  ,   49  ,   137 ,   421 ,   669 ,   829 ,   3261    ,   3995    ,   4347    ,0 };
            const std::uint32_t dim1319Kuo2Init[]       =   {   1   ,   3   ,   5   ,   3   ,   25  ,   43  ,   51  ,   97  ,   315 ,   1021    ,   183 ,   87  ,   6465    ,   15415   ,0 };
            const std::uint32_t dim1320Kuo2Init[]       =   {   1   ,   3   ,   1   ,   1   ,   15  ,   61  ,   111 ,   249 ,   99  ,   1001    ,   791 ,   869 ,   7017    ,   5943    ,0 };
            const std::uint32_t dim1321Kuo2Init[]       =   {   1   ,   3   ,   7   ,   3   ,   3   ,   7   ,   51  ,   127 ,   275 ,   683 ,   1055    ,   3727    ,   1273    ,   3007    ,0 };
            const std::uint32_t dim1322Kuo2Init[]       =   {   1   ,   3   ,   1   ,   15  ,   19  ,   33  ,   113 ,   167 ,   473 ,   287 ,   233 ,   905 ,   2213    ,   12233   ,0 };
            const std::uint32_t dim1323Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   3   ,   45  ,   83  ,   107 ,   7   ,   651 ,   603 ,   2663    ,   5261    ,   15521   ,0 };
            const std::uint32_t dim1324Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   19  ,   49  ,   51  ,   81  ,   101 ,   23  ,   1345    ,   17  ,   4215    ,   7089    ,0 };
            const std::uint32_t dim1325Kuo2Init[]       =   {   1   ,   3   ,   5   ,   5   ,   7   ,   7   ,   65  ,   221 ,   7   ,   513 ,   1567    ,   4041    ,   6339    ,   8665    ,0 };
            const std::uint32_t dim1326Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   15  ,   61  ,   91  ,   29  ,   85  ,   903 ,   1805    ,   1957    ,   63  ,   13941   ,0 };
            const std::uint32_t dim1327Kuo2Init[]       =   {   1   ,   1   ,   1   ,   1   ,   29  ,   19  ,   31  ,   21  ,   43  ,   353 ,   1419    ,   3999    ,   6651    ,   1897    ,0 };
            const std::uint32_t dim1328Kuo2Init[]       =   {   1   ,   1   ,   3   ,   13  ,   31  ,   7   ,   65  ,   57  ,   25  ,   1015    ,   1969    ,   1547    ,   4815    ,   4183    ,0 };
            const std::uint32_t dim1329Kuo2Init[]       =   {   1   ,   1   ,   7   ,   11  ,   25  ,   37  ,   91  ,   163 ,   287 ,   283 ,   1531    ,   149 ,   7799    ,   15  ,0 };
            const std::uint32_t dim1330Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   23  ,   25  ,   71  ,   7   ,   439 ,   645 ,   843 ,   315 ,   4577    ,   6703    ,0 };
            const std::uint32_t dim1331Kuo2Init[]       =   {   1   ,   1   ,   5   ,   15  ,   13  ,   39  ,   57  ,   115 ,   91  ,   475 ,   2003    ,   3787    ,   4053    ,   13299   ,0 };
            const std::uint32_t dim1332Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   1   ,   53  ,   53  ,   83  ,   7   ,   133 ,   1523    ,   347 ,   3569    ,   6495    ,0 };
            const std::uint32_t dim1333Kuo2Init[]       =   {   1   ,   1   ,   7   ,   13  ,   15  ,   53  ,   31  ,   153 ,   181 ,   465 ,   687 ,   3375    ,   3393    ,   565 ,0 };
            const std::uint32_t dim1334Kuo2Init[]       =   {   1   ,   3   ,   3   ,   3   ,   19  ,   21  ,   95  ,   45  ,   399 ,   1   ,   213 ,   2003    ,   221 ,   11961   ,0 };
            const std::uint32_t dim1335Kuo2Init[]       =   {   1   ,   1   ,   5   ,   13  ,   27  ,   29  ,   35  ,   55  ,   239 ,   999 ,   23  ,   2645    ,   5399    ,   865 ,0 };
            const std::uint32_t dim1336Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   5   ,   3   ,   43  ,   217 ,   321 ,   159 ,   1611    ,   495 ,   435 ,   6989    ,0 };
            const std::uint32_t dim1337Kuo2Init[]       =   {   1   ,   1   ,   5   ,   1   ,   27  ,   15  ,   29  ,   109 ,   385 ,   449 ,   651 ,   1551    ,   5983    ,   12985   ,0 };
            const std::uint32_t dim1338Kuo2Init[]       =   {   1   ,   3   ,   5   ,   11  ,   27  ,   35  ,   11  ,   155 ,   279 ,   5   ,   389 ,   1157    ,   2401    ,   12485   ,0 };
            const std::uint32_t dim1339Kuo2Init[]       =   {   1   ,   1   ,   3   ,   3   ,   7   ,   7   ,   3   ,   185 ,   469 ,   995 ,   271 ,   2315    ,   3269    ,   909 ,0 };
            const std::uint32_t dim1340Kuo2Init[]       =   {   1   ,   3   ,   5   ,   3   ,   27  ,   31  ,   111 ,   47  ,   351 ,   17  ,   1321    ,   3973    ,   457 ,   15773   ,0 };
            const std::uint32_t dim1341Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   19  ,   59  ,   71  ,   215 ,   93  ,   235 ,   1985    ,   1149    ,   1887    ,   2963    ,0 };
            const std::uint32_t dim1342Kuo2Init[]       =   {   1   ,   3   ,   5   ,   3   ,   3   ,   3   ,   87  ,   205 ,   187 ,   373 ,   1557    ,   311 ,   5807    ,   13343   ,0 };
            const std::uint32_t dim1343Kuo2Init[]       =   {   1   ,   1   ,   7   ,   13  ,   19  ,   17  ,   31  ,   113 ,   183 ,   31  ,   1117    ,   3241    ,   4781    ,   15071   ,0 };
            const std::uint32_t dim1344Kuo2Init[]       =   {   1   ,   3   ,   5   ,   5   ,   3   ,   25  ,   33  ,   93  ,   473 ,   353 ,   1005    ,   2385    ,   649 ,   5219    ,0 };
            const std::uint32_t dim1345Kuo2Init[]       =   {   1   ,   1   ,   3   ,   5   ,   25  ,   37  ,   39  ,   109 ,   511 ,   1005    ,   641 ,   3597    ,   7601    ,   613 ,0 };
            const std::uint32_t dim1346Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   3   ,   17  ,   69  ,   145 ,   147 ,   321 ,   849 ,   3057    ,   7299    ,   12343   ,0 };
            const std::uint32_t dim1347Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   11  ,   35  ,   19  ,   179 ,   337 ,   53  ,   679 ,   4009    ,   769 ,   2899    ,0 };
            const std::uint32_t dim1348Kuo2Init[]       =   {   1   ,   1   ,   7   ,   11  ,   19  ,   47  ,   61  ,   11  ,   349 ,   769 ,   445 ,   2051    ,   5653    ,   7143    ,0 };
            const std::uint32_t dim1349Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   3   ,   39  ,   53  ,   193 ,   313 ,   299 ,   1579    ,   2237    ,   661 ,   6047    ,0 };
            const std::uint32_t dim1350Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   29  ,   17  ,   9   ,   225 ,   143 ,   285 ,   1169    ,   3109    ,   927 ,   5257    ,0 };
            const std::uint32_t dim1351Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   5   ,   27  ,   107 ,   253 ,   439 ,   1017    ,   253 ,   3437    ,   5435    ,   13479   ,0 };
            const std::uint32_t dim1352Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   9   ,   61  ,   111 ,   75  ,   241 ,   451 ,   1361    ,   2853    ,   5457    ,   15853   ,0 };
            const std::uint32_t dim1353Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   15  ,   23  ,   21  ,   115 ,   505 ,   265 ,   131 ,   1277    ,   2545    ,   8955    ,0 };
            const std::uint32_t dim1354Kuo2Init[]       =   {   1   ,   1   ,   1   ,   1   ,   17  ,   43  ,   3   ,   253 ,   315 ,   19  ,   787 ,   1477    ,   2529    ,   6527    ,0 };
            const std::uint32_t dim1355Kuo2Init[]       =   {   1   ,   1   ,   1   ,   7   ,   17  ,   31  ,   87  ,   121 ,   201 ,   367 ,   265 ,   3899    ,   1961    ,   12761   ,0 };
            const std::uint32_t dim1356Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   9   ,   55  ,   101 ,   163 ,   39  ,   351 ,   1877    ,   2481    ,   3265    ,   15575   ,0 };
            const std::uint32_t dim1357Kuo2Init[]       =   {   1   ,   1   ,   3   ,   5   ,   29  ,   19  ,   21  ,   39  ,   187 ,   401 ,   547 ,   2477    ,   995 ,   3339    ,0 };
            const std::uint32_t dim1358Kuo2Init[]       =   {   1   ,   3   ,   3   ,   5   ,   19  ,   25  ,   59  ,   247 ,   389 ,   733 ,   1867    ,   3401    ,   5115    ,   12791   ,0 };
            const std::uint32_t dim1359Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   11  ,   39  ,   29  ,   239 ,   157 ,   145 ,   1553    ,   3419    ,   5787    ,   3983    ,0 };
            const std::uint32_t dim1360Kuo2Init[]       =   {   1   ,   1   ,   1   ,   15  ,   23  ,   47  ,   99  ,   71  ,   335 ,   749 ,   875 ,   5   ,   8049    ,   4585    ,0 };
            const std::uint32_t dim1361Kuo2Init[]       =   {   1   ,   3   ,   7   ,   11  ,   19  ,   17  ,   25  ,   23  ,   243 ,   171 ,   929 ,   1981    ,   363 ,   13631   ,0 };
            const std::uint32_t dim1362Kuo2Init[]       =   {   1   ,   1   ,   1   ,   1   ,   19  ,   43  ,   101 ,   199 ,   157 ,   431 ,   1127    ,   3261    ,   4063    ,   10569   ,0 };
            const std::uint32_t dim1363Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   15  ,   43  ,   1   ,   199 ,   281 ,   841 ,   1643    ,   2827    ,   6997    ,   11309   ,0 };
            const std::uint32_t dim1364Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   5   ,   53  ,   127 ,   147 ,   141 ,   319 ,   1605    ,   3717    ,   6519    ,   15315   ,0 };
            const std::uint32_t dim1365Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   31  ,   5   ,   39  ,   221 ,   91  ,   521 ,   527 ,   3253    ,   2877    ,   1439    ,0 };
            const std::uint32_t dim1366Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   9   ,   61  ,   69  ,   27  ,   393 ,   557 ,   1949    ,   3035    ,   3717    ,   5099    ,0 };
            const std::uint32_t dim1367Kuo2Init[]       =   {   1   ,   3   ,   7   ,   3   ,   19  ,   43  ,   77  ,   161 ,   469 ,   721 ,   73  ,   685 ,   1681    ,   5581    ,0 };
            const std::uint32_t dim1368Kuo2Init[]       =   {   1   ,   1   ,   7   ,   5   ,   27  ,   3   ,   119 ,   223 ,   255 ,   905 ,   501 ,   1809    ,   5591    ,   29  ,0 };
            const std::uint32_t dim1369Kuo2Init[]       =   {   1   ,   1   ,   3   ,   11  ,   13  ,   1   ,   13  ,   103 ,   305 ,   679 ,   1485    ,   4077    ,   1419    ,   7893    ,0 };
            const std::uint32_t dim1370Kuo2Init[]       =   {   1   ,   1   ,   1   ,   15  ,   21  ,   7   ,   39  ,   49  ,   451 ,   291 ,   93  ,   3563    ,   5071    ,   15353   ,0 };
            const std::uint32_t dim1371Kuo2Init[]       =   {   1   ,   3   ,   7   ,   9   ,   19  ,   53  ,   57  ,   149 ,   171 ,   377 ,   1903    ,   235 ,   2181    ,   8207    ,0 };
            const std::uint32_t dim1372Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   23  ,   25  ,   63  ,   53  ,   23  ,   263 ,   1681    ,   3305    ,   461 ,   9875    ,0 };
            const std::uint32_t dim1373Kuo2Init[]       =   {   1   ,   1   ,   3   ,   5   ,   5   ,   15  ,   71  ,   217 ,   493 ,   323 ,   1451    ,   1629    ,   7677    ,   15945   ,0 };
            const std::uint32_t dim1374Kuo2Init[]       =   {   1   ,   1   ,   5   ,   9   ,   31  ,   53  ,   95  ,   37  ,   357 ,   61  ,   1601    ,   3565    ,   3705    ,   6617    ,0 };
            const std::uint32_t dim1375Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   17  ,   33  ,   81  ,   119 ,   233 ,   219 ,   1429    ,   2183    ,   771 ,   7199    ,0 };
            const std::uint32_t dim1376Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   27  ,   17  ,   7   ,   17  ,   281 ,   959 ,   1065    ,   3489    ,   6665    ,   14469   ,0 };
            const std::uint32_t dim1377Kuo2Init[]       =   {   1   ,   3   ,   1   ,   15  ,   21  ,   15  ,   99  ,   77  ,   437 ,   571 ,   207 ,   609 ,   7287    ,   9395    ,0 };
            const std::uint32_t dim1378Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   1   ,   49  ,   39  ,   189 ,   111 ,   65  ,   1345    ,   2559    ,   7835    ,   9869    ,0 };
            const std::uint32_t dim1379Kuo2Init[]       =   {   1   ,   1   ,   1   ,   1   ,   27  ,   17  ,   93  ,   83  ,   339 ,   465 ,   1445    ,   3557    ,   6489    ,   6985    ,0 };
            const std::uint32_t dim1380Kuo2Init[]       =   {   1   ,   1   ,   5   ,   3   ,   1   ,   7   ,   35  ,   39  ,   491 ,   563 ,   1815    ,   2513    ,   5523    ,   12691   ,0 };
            const std::uint32_t dim1381Kuo2Init[]       =   {   1   ,   1   ,   3   ,   5   ,   3   ,   31  ,   127 ,   91  ,   87  ,   447 ,   1237    ,   3419    ,   6979    ,   6311    ,0 };
            const std::uint32_t dim1382Kuo2Init[]       =   {   1   ,   1   ,   7   ,   3   ,   25  ,   61  ,   45  ,   219 ,   455 ,   859 ,   781 ,   2991    ,   6585    ,   11511   ,0 };
            const std::uint32_t dim1383Kuo2Init[]       =   {   1   ,   3   ,   3   ,   13  ,   15  ,   37  ,   77  ,   211 ,   403 ,   349 ,   35  ,   2785    ,   4439    ,   5715    ,0 };
            const std::uint32_t dim1384Kuo2Init[]       =   {   1   ,   1   ,   3   ,   1   ,   1   ,   19  ,   45  ,   37  ,   459 ,   839 ,   17  ,   3223    ,   6411    ,   9209    ,0 };
            const std::uint32_t dim1385Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   27  ,   43  ,   63  ,   241 ,   455 ,   593 ,   1855    ,   3689    ,   7825    ,   10197   ,0 };
            const std::uint32_t dim1386Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   5   ,   17  ,   71  ,   209 ,   57  ,   991 ,   617 ,   3097    ,   5431    ,   2057    ,0 };
            const std::uint32_t dim1387Kuo2Init[]       =   {   1   ,   1   ,   5   ,   15  ,   31  ,   21  ,   119 ,   53  ,   447 ,   969 ,   335 ,   3793    ,   3225    ,   9809    ,0 };
            const std::uint32_t dim1388Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   17  ,   51  ,   17  ,   7   ,   257 ,   221 ,   119 ,   2631    ,   6395    ,   8495    ,0 };
            const std::uint32_t dim1389Kuo2Init[]       =   {   1   ,   3   ,   1   ,   15  ,   31  ,   13  ,   3   ,   9   ,   479 ,   233 ,   1051    ,   1953    ,   7863    ,   5969    ,0 };
            const std::uint32_t dim1390Kuo2Init[]       =   {   1   ,   3   ,   1   ,   9   ,   13  ,   49  ,   57  ,   161 ,   65  ,   871 ,   2021    ,   3337    ,   7071    ,   12969   ,0 };
            const std::uint32_t dim1391Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   1   ,   53  ,   3   ,   77  ,   487 ,   207 ,   1761    ,   847 ,   3131    ,   1933    ,0 };
            const std::uint32_t dim1392Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   7   ,   21  ,   55  ,   217 ,   167 ,   113 ,   1029    ,   2761    ,   2063    ,   5267    ,0 };
            const std::uint32_t dim1393Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   15  ,   57  ,   119 ,   9   ,   211 ,   93  ,   209 ,   2905    ,   2589    ,   12341   ,0 };
            const std::uint32_t dim1394Kuo2Init[]       =   {   1   ,   3   ,   1   ,   15  ,   25  ,   7   ,   41  ,   87  ,   451 ,   613 ,   353 ,   2619    ,   6015    ,   14003   ,0 };
            const std::uint32_t dim1395Kuo2Init[]       =   {   1   ,   3   ,   3   ,   11  ,   23  ,   5   ,   3   ,   145 ,   471 ,   685 ,   3   ,   3431    ,   2843    ,   11725   ,0 };
            const std::uint32_t dim1396Kuo2Init[]       =   {   1   ,   3   ,   7   ,   11  ,   13  ,   45  ,   73  ,   45  ,   169 ,   395 ,   1279    ,   2589    ,   1419    ,   14965   ,0 };
            const std::uint32_t dim1397Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   25  ,   23  ,   77  ,   149 ,   27  ,   441 ,   1391    ,   1853    ,   3993    ,   15507   ,0 };
            const std::uint32_t dim1398Kuo2Init[]       =   {   1   ,   1   ,   1   ,   7   ,   21  ,   33  ,   39  ,   59  ,   161 ,   399 ,   447 ,   1249    ,   5407    ,   11825   ,0 };
            const std::uint32_t dim1399Kuo2Init[]       =   {   1   ,   1   ,   5   ,   3   ,   25  ,   53  ,   37  ,   237 ,   91  ,   625 ,   1195    ,   1161    ,   7005    ,   7831    ,0 };
            const std::uint32_t dim1400Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   7   ,   63  ,   37  ,   101 ,   399 ,   645 ,   545 ,   3419    ,   6619    ,   2179    ,0 };
            const std::uint32_t dim1401Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   11  ,   51  ,   103 ,   207 ,   267 ,   909 ,   1975    ,   2279    ,   1991    ,   1891    ,0 };
            const std::uint32_t dim1402Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   27  ,   45  ,   9   ,   1   ,   423 ,   197 ,   697 ,   2765    ,   2653    ,   2613    ,0 };
            const std::uint32_t dim1403Kuo2Init[]       =   {   1   ,   3   ,   7   ,   1   ,   27  ,   13  ,   45  ,   47  ,   493 ,   131 ,   565 ,   1363    ,   4921    ,   10023   ,0 };
            const std::uint32_t dim1404Kuo2Init[]       =   {   1   ,   3   ,   7   ,   1   ,   7   ,   47  ,   99  ,   107 ,   343 ,   933 ,   1017    ,   3931    ,   1329    ,   2833    ,0 };
            const std::uint32_t dim1405Kuo2Init[]       =   {   1   ,   1   ,   3   ,   1   ,   13  ,   9   ,   5   ,   131 ,   475 ,   537 ,   1857    ,   2579    ,   6377    ,   14363   ,0 };
            const std::uint32_t dim1406Kuo2Init[]       =   {   1   ,   1   ,   5   ,   5   ,   15  ,   7   ,   87  ,   39  ,   51  ,   563 ,   1145    ,   3639    ,   4261    ,   9585    ,0 };
            const std::uint32_t dim1407Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   3   ,   61  ,   23  ,   223 ,   221 ,   165 ,   315 ,   2475    ,   7907    ,   10171   ,0 };
            const std::uint32_t dim1408Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   23  ,   57  ,   121 ,   171 ,   439 ,   101 ,   261 ,   1115    ,   1291    ,   2951    ,0 };
            const std::uint32_t dim1409Kuo2Init[]       =   {   1   ,   1   ,   1   ,   9   ,   15  ,   23  ,   81  ,   189 ,   301 ,   515 ,   297 ,   915 ,   763 ,   11037   ,0 };
            const std::uint32_t dim1410Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   17  ,   45  ,   33  ,   101 ,   65  ,   687 ,   2011    ,   1821    ,   6891    ,   7321    ,0 };
            const std::uint32_t dim1411Kuo2Init[]       =   {   1   ,   3   ,   5   ,   5   ,   9   ,   61  ,   11  ,   69  ,   345 ,   211 ,   393 ,   331 ,   3953    ,   13987   ,0 };
            const std::uint32_t dim1412Kuo2Init[]       =   {   1   ,   1   ,   5   ,   15  ,   9   ,   23  ,   11  ,   45  ,   325 ,   1019    ,   1499    ,   831 ,   127 ,   9237    ,0 };
            const std::uint32_t dim1413Kuo2Init[]       =   {   1   ,   1   ,   5   ,   5   ,   19  ,   9   ,   53  ,   213 ,   417 ,   761 ,   1275    ,   2117    ,   465 ,   15195   ,0 };
            const std::uint32_t dim1414Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   25  ,   53  ,   57  ,   95  ,   31  ,   791 ,   345 ,   3769    ,   3487    ,   4269    ,0 };
            const std::uint32_t dim1415Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   17  ,   9   ,   127 ,   203 ,   67  ,   435 ,   281 ,   3857    ,   819 ,   11235   ,0 };
            const std::uint32_t dim1416Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   23  ,   45  ,   127 ,   197 ,   501 ,   11  ,   1125    ,   2781    ,   7979    ,   1699    ,0 };
            const std::uint32_t dim1417Kuo2Init[]       =   {   1   ,   3   ,   3   ,   13  ,   21  ,   21  ,   57  ,   125 ,   225 ,   593 ,   27  ,   539 ,   7989    ,   9597    ,0 };
            const std::uint32_t dim1418Kuo2Init[]       =   {   1   ,   3   ,   7   ,   7   ,   29  ,   27  ,   57  ,   19  ,   51  ,   981 ,   205 ,   169 ,   5713    ,   4777    ,0 };
            const std::uint32_t dim1419Kuo2Init[]       =   {   1   ,   3   ,   7   ,   7   ,   1   ,   59  ,   57  ,   61  ,   145 ,   683 ,   1043    ,   11  ,   5277    ,   5095    ,0 };
            const std::uint32_t dim1420Kuo2Init[]       =   {   1   ,   1   ,   1   ,   3   ,   7   ,   39  ,   123 ,   251 ,   259 ,   295 ,   1333    ,   395 ,   5463    ,   11593   ,0 };
            const std::uint32_t dim1421Kuo2Init[]       =   {   1   ,   1   ,   7   ,   15  ,   1   ,   9   ,   71  ,   79  ,   299 ,   1007    ,   1403    ,   237 ,   4845    ,   10521   ,0 };
            const std::uint32_t dim1422Kuo2Init[]       =   {   1   ,   1   ,   5   ,   5   ,   11  ,   51  ,   45  ,   51  ,   489 ,   865 ,   511 ,   1415    ,   7867    ,   4235    ,0 };
            const std::uint32_t dim1423Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   23  ,   31  ,   83  ,   77  ,   461 ,   111 ,   1985    ,   3401    ,   271 ,   9763    ,0 };
            const std::uint32_t dim1424Kuo2Init[]       =   {   1   ,   3   ,   5   ,   11  ,   19  ,   53  ,   45  ,   135 ,   171 ,   593 ,   1761    ,   1019    ,   7715    ,   9835    ,0 };
            const std::uint32_t dim1425Kuo2Init[]       =   {   1   ,   1   ,   3   ,   5   ,   21  ,   47  ,   95  ,   1   ,   419 ,   547 ,   447 ,   3475    ,   7829    ,   12019   ,0 };
            const std::uint32_t dim1426Kuo2Init[]       =   {   1   ,   3   ,   7   ,   13  ,   15  ,   29  ,   21  ,   197 ,   491 ,   997 ,   453 ,   3415    ,   745 ,   11259   ,0 };
            const std::uint32_t dim1427Kuo2Init[]       =   {   1   ,   1   ,   3   ,   11  ,   19  ,   39  ,   99  ,   83  ,   35  ,   941 ,   1175    ,   2749    ,   4181    ,   8791    ,0 };
            const std::uint32_t dim1428Kuo2Init[]       =   {   1   ,   1   ,   5   ,   7   ,   23  ,   3   ,   101 ,   11  ,   81  ,   291 ,   1815    ,   3391    ,   7615    ,   1305    ,0 };
            const std::uint32_t dim1429Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   27  ,   35  ,   71  ,   185 ,   87  ,   939 ,   1025    ,   1577    ,   5919    ,   5335    ,0 };
            const std::uint32_t dim1430Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   3   ,   31  ,   23  ,   213 ,   371 ,   595 ,   2003    ,   647 ,   909 ,   7503    ,0 };
            const std::uint32_t dim1431Kuo2Init[]       =   {   1   ,   1   ,   5   ,   9   ,   31  ,   63  ,   125 ,   113 ,   273 ,   985 ,   1049    ,   1819    ,   2773    ,   6495    ,0 };
            const std::uint32_t dim1432Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   21  ,   7   ,   87  ,   207 ,   455 ,   403 ,   677 ,   175 ,   531 ,   10467   ,0 };
            const std::uint32_t dim1433Kuo2Init[]       =   {   1   ,   1   ,   5   ,   1   ,   3   ,   45  ,   109 ,   75  ,   429 ,   983 ,   423 ,   3491    ,   7949    ,   15253   ,0 };
            const std::uint32_t dim1434Kuo2Init[]       =   {   1   ,   1   ,   3   ,   1   ,   23  ,   27  ,   91  ,   5   ,   235 ,   121 ,   1087    ,   325 ,   5191    ,   8271    ,0 };
            const std::uint32_t dim1435Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   29  ,   63  ,   91  ,   129 ,   305 ,   827 ,   1311    ,   2765    ,   253 ,   1495    ,0 };
            const std::uint32_t dim1436Kuo2Init[]       =   {   1   ,   3   ,   1   ,   15  ,   21  ,   45  ,   7   ,   21  ,   169 ,   275 ,   629 ,   589 ,   4623    ,   5491    ,0 };
            const std::uint32_t dim1437Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   13  ,   45  ,   127 ,   105 ,   377 ,   49  ,   1161    ,   489 ,   595 ,   7041    ,0 };
            const std::uint32_t dim1438Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   31  ,   61  ,   91  ,   1   ,   35  ,   189 ,   1479    ,   2041    ,   1585    ,   13009   ,0 };
            const std::uint32_t dim1439Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   23  ,   47  ,   69  ,   47  ,   361 ,   375 ,   77  ,   3777    ,   5769    ,   9925    ,0 };
            const std::uint32_t dim1440Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   5   ,   13  ,   31  ,   119 ,   411 ,   735 ,   839 ,   2919    ,   543 ,   12929   ,0 };
            const std::uint32_t dim1441Kuo2Init[]       =   {   1   ,   3   ,   5   ,   11  ,   19  ,   5   ,   29  ,   185 ,   115 ,   841 ,   507 ,   1433    ,   5091    ,   3593    ,0 };
            const std::uint32_t dim1442Kuo2Init[]       =   {   1   ,   3   ,   1   ,   13  ,   15  ,   19  ,   23  ,   83  ,   319 ,   99  ,   785 ,   697 ,   3703    ,   8733    ,0 };
            const std::uint32_t dim1443Kuo2Init[]       =   {   1   ,   3   ,   5   ,   3   ,   7   ,   31  ,   53  ,   213 ,   287 ,   797 ,   1807    ,   879 ,   4227    ,   12013   ,0 };
            const std::uint32_t dim1444Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   23  ,   53  ,   91  ,   173 ,   253 ,   971 ,   1017    ,   2185    ,   4911    ,   15359   ,0 };
            const std::uint32_t dim1445Kuo2Init[]       =   {   1   ,   3   ,   7   ,   3   ,   17  ,   27  ,   77  ,   225 ,   97  ,   199 ,   607 ,   1615    ,   963 ,   671 ,0 };
            const std::uint32_t dim1446Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   9   ,   61  ,   3   ,   105 ,   455 ,   953 ,   455 ,   3925    ,   3947    ,   7873    ,0 };
            const std::uint32_t dim1447Kuo2Init[]       =   {   1   ,   3   ,   7   ,   7   ,   3   ,   49  ,   121 ,   109 ,   239 ,   855 ,   789 ,   3627    ,   3873    ,   6785    ,0 };
            const std::uint32_t dim1448Kuo2Init[]       =   {   1   ,   1   ,   5   ,   5   ,   29  ,   35  ,   99  ,   159 ,   17  ,   221 ,   855 ,   2081    ,   2791    ,   11413   ,0 };
            const std::uint32_t dim1449Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   23  ,   53  ,   75  ,   93  ,   207 ,   189 ,   2035    ,   1829    ,   7581    ,   1425    ,0 };
            const std::uint32_t dim1450Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   3   ,   61  ,   61  ,   237 ,   53  ,   875 ,   1617    ,   727 ,   2683    ,   15797   ,0 };
            const std::uint32_t dim1451Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   23  ,   3   ,   105 ,   107 ,   353 ,   579 ,   119 ,   3041    ,   3005    ,   15581   ,0 };
            const std::uint32_t dim1452Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   31  ,   15  ,   89  ,   215 ,   161 ,   39  ,   629 ,   2873    ,   1635    ,   1029    ,0 };
            const std::uint32_t dim1453Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   15  ,   25  ,   53  ,   27  ,   167 ,   497 ,   1795    ,   1283    ,   7869    ,   15821   ,0 };
            const std::uint32_t dim1454Kuo2Init[]       =   {   1   ,   3   ,   7   ,   3   ,   27  ,   39  ,   111 ,   29  ,   445 ,   365 ,   273 ,   2183    ,   475 ,   12503   ,0 };
            const std::uint32_t dim1455Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   9   ,   13  ,   25  ,   115 ,   419 ,   387 ,   1663    ,   3445    ,   157 ,   10549   ,0 };
            const std::uint32_t dim1456Kuo2Init[]       =   {   1   ,   1   ,   5   ,   13  ,   23  ,   39  ,   7   ,   247 ,   127 ,   285 ,   675 ,   1785    ,   1823    ,   10183   ,0 };
            const std::uint32_t dim1457Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   31  ,   39  ,   93  ,   19  ,   125 ,   453 ,   1963    ,   2619    ,   6195    ,   2231    ,0 };
            const std::uint32_t dim1458Kuo2Init[]       =   {   1   ,   1   ,   7   ,   3   ,   31  ,   51  ,   59  ,   19  ,   15  ,   251 ,   749 ,   2469    ,   369 ,   15413   ,0 };
            const std::uint32_t dim1459Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   19  ,   59  ,   111 ,   255 ,   91  ,   89  ,   1447    ,   353 ,   6701    ,   7955    ,0 };
            const std::uint32_t dim1460Kuo2Init[]       =   {   1   ,   1   ,   7   ,   3   ,   3   ,   21  ,   115 ,   159 ,   489 ,   609 ,   1993    ,   2961    ,   3117    ,   3977    ,0 };
            const std::uint32_t dim1461Kuo2Init[]       =   {   1   ,   3   ,   7   ,   13  ,   13  ,   13  ,   57  ,   41  ,   5   ,   337 ,   2005    ,   2587    ,   3873    ,   12829   ,0 };
            const std::uint32_t dim1462Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   9   ,   3   ,   39  ,   165 ,   155 ,   353 ,   985 ,   2221    ,   2973    ,   6331    ,0 };
            const std::uint32_t dim1463Kuo2Init[]       =   {   1   ,   3   ,   3   ,   5   ,   3   ,   15  ,   121 ,   191 ,   367 ,   513 ,   1765    ,   3957    ,   3113    ,   10669   ,0 };
            const std::uint32_t dim1464Kuo2Init[]       =   {   1   ,   3   ,   7   ,   1   ,   13  ,   41  ,   63  ,   241 ,   405 ,   43  ,   1211    ,   1499    ,   1095    ,   11867   ,0 };
            const std::uint32_t dim1465Kuo2Init[]       =   {   1   ,   3   ,   7   ,   15  ,   17  ,   17  ,   63  ,   197 ,   377 ,   981 ,   1615    ,   2407    ,   6669    ,   411 ,0 };
            const std::uint32_t dim1466Kuo2Init[]       =   {   1   ,   1   ,   3   ,   1   ,   3   ,   39  ,   85  ,   15  ,   9   ,   747 ,   423 ,   3103    ,   7341    ,   10953   ,0 };
            const std::uint32_t dim1467Kuo2Init[]       =   {   1   ,   1   ,   7   ,   13  ,   25  ,   9   ,   17  ,   137 ,   267 ,   405 ,   1819    ,   641 ,   7305    ,   13971   ,0 };
            const std::uint32_t dim1468Kuo2Init[]       =   {   1   ,   3   ,   5   ,   5   ,   19  ,   45  ,   121 ,   65  ,   385 ,   715 ,   267 ,   1841    ,   6317    ,   5827    ,0 };
            const std::uint32_t dim1469Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   11  ,   31  ,   57  ,   123 ,   107 ,   913 ,   669 ,   1053    ,   1213    ,   8791    ,0 };
            const std::uint32_t dim1470Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   21  ,   3   ,   57  ,   227 ,   401 ,   443 ,   1847    ,   3523    ,   4717    ,   2505    ,0 };
            const std::uint32_t dim1471Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   29  ,   41  ,   67  ,   217 ,   431 ,   37  ,   1775    ,   297 ,   1921    ,   8715    ,0 };
            const std::uint32_t dim1472Kuo2Init[]       =   {   1   ,   3   ,   7   ,   7   ,   27  ,   35  ,   113 ,   57  ,   23  ,   927 ,   141 ,   1363    ,   4209    ,   4399    ,0 };
            const std::uint32_t dim1473Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   19  ,   51  ,   107 ,   189 ,   463 ,   695 ,   1931    ,   1541    ,   1285    ,   15703   ,0 };
            const std::uint32_t dim1474Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   29  ,   43  ,   109 ,   117 ,   389 ,   7   ,   1129    ,   1945    ,   6987    ,   799 ,0 };
            const std::uint32_t dim1475Kuo2Init[]       =   {   1   ,   1   ,   1   ,   13  ,   9   ,   7   ,   119 ,   61  ,   385 ,   315 ,   1953    ,   1745    ,   8117    ,   15863   ,0 };
            const std::uint32_t dim1476Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   21  ,   55  ,   95  ,   113 ,   293 ,   899 ,   1327    ,   161 ,   6613    ,   14949   ,0 };
            const std::uint32_t dim1477Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   19  ,   21  ,   89  ,   5   ,   477 ,   441 ,   1477    ,   1995    ,   6633    ,   5523    ,0 };
            const std::uint32_t dim1478Kuo2Init[]       =   {   1   ,   3   ,   3   ,   11  ,   15  ,   27  ,   17  ,   239 ,   263 ,   267 ,   1729    ,   3583    ,   4117    ,   13637   ,0 };
            const std::uint32_t dim1479Kuo2Init[]       =   {   1   ,   1   ,   5   ,   5   ,   11  ,   53  ,   15  ,   201 ,   401 ,   845 ,   741 ,   2803    ,   3087    ,   9001    ,0 };
            const std::uint32_t dim1480Kuo2Init[]       =   {   1   ,   3   ,   3   ,   11  ,   17  ,   21  ,   65  ,   109 ,   163 ,   251 ,   1487    ,   1541    ,   481 ,   10545   ,0 };
            const std::uint32_t dim1481Kuo2Init[]       =   {   1   ,   3   ,   3   ,   13  ,   21  ,   61  ,   71  ,   121 ,   331 ,   551 ,   1237    ,   805 ,   3799    ,   1437    ,0 };
            const std::uint32_t dim1482Kuo2Init[]       =   {   1   ,   3   ,   1   ,   11  ,   21  ,   29  ,   61  ,   161 ,   193 ,   745 ,   935 ,   1013    ,   3507    ,   6091    ,0 };
            const std::uint32_t dim1483Kuo2Init[]       =   {   1   ,   3   ,   7   ,   15  ,   5   ,   59  ,   99  ,   147 ,   467 ,   625 ,   1873    ,   3459    ,   5749    ,   10571   ,0 };
            const std::uint32_t dim1484Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   9   ,   21  ,   57  ,   63  ,   205 ,   891 ,   1963    ,   2271    ,   6303    ,   9565    ,0 };
            const std::uint32_t dim1485Kuo2Init[]       =   {   1   ,   1   ,   1   ,   1   ,   17  ,   55  ,   21  ,   105 ,   181 ,   763 ,   763 ,   337 ,   2283    ,   5203    ,0 };
            const std::uint32_t dim1486Kuo2Init[]       =   {   1   ,   3   ,   3   ,   11  ,   25  ,   33  ,   7   ,   107 ,   329 ,   49  ,   31  ,   995 ,   757 ,   9781    ,0 };
            const std::uint32_t dim1487Kuo2Init[]       =   {   1   ,   3   ,   7   ,   13  ,   17  ,   19  ,   107 ,   189 ,   359 ,   709 ,   819 ,   3943    ,   1891    ,   12173   ,0 };
            const std::uint32_t dim1488Kuo2Init[]       =   {   1   ,   1   ,   7   ,   5   ,   3   ,   55  ,   121 ,   37  ,   493 ,   579 ,   2021    ,   3129    ,   6519    ,   14569   ,0 };
            const std::uint32_t dim1489Kuo2Init[]       =   {   1   ,   1   ,   5   ,   15  ,   17  ,   3   ,   59  ,   75  ,   453 ,   323 ,   1559    ,   3695    ,   7711    ,   7665    ,0 };
            const std::uint32_t dim1490Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   9   ,   35  ,   121 ,   179 ,   345 ,   973 ,   337 ,   3655    ,   3815    ,   6317    ,0 };
            const std::uint32_t dim1491Kuo2Init[]       =   {   1   ,   3   ,   7   ,   7   ,   9   ,   27  ,   59  ,   253 ,   9   ,   221 ,   587 ,   1087    ,   7295    ,   12193   ,0 };
            const std::uint32_t dim1492Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   27  ,   1   ,   105 ,   99  ,   49  ,   555 ,   2019    ,   2863    ,   5211    ,   2485    ,0 };
            const std::uint32_t dim1493Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   25  ,   55  ,   23  ,   221 ,   501 ,   671 ,   11  ,   1801    ,   6485    ,   14983   ,0 };
            const std::uint32_t dim1494Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   27  ,   45  ,   69  ,   159 ,   77  ,   541 ,   1441    ,   2043    ,   5609    ,   6799    ,0 };
            const std::uint32_t dim1495Kuo2Init[]       =   {   1   ,   1   ,   5   ,   3   ,   21  ,   31  ,   7   ,   197 ,   511 ,   299 ,   1523    ,   3341    ,   301 ,   8639    ,0 };
            const std::uint32_t dim1496Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   9   ,   59  ,   63  ,   253 ,   191 ,   653 ,   383 ,   1239    ,   7839    ,   3699    ,0 };
            const std::uint32_t dim1497Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   13  ,   33  ,   73  ,   209 ,   125 ,   939 ,   1507    ,   3527    ,   6039    ,   14027   ,0 };
            const std::uint32_t dim1498Kuo2Init[]       =   {   1   ,   1   ,   3   ,   13  ,   13  ,   21  ,   5   ,   15  ,   301 ,   625 ,   713 ,   2867    ,   3129    ,   4939    ,0 };
            const std::uint32_t dim1499Kuo2Init[]       =   {   1   ,   1   ,   1   ,   13  ,   23  ,   5   ,   115 ,   69  ,   101 ,   327 ,   563 ,   2623    ,   6491    ,   7381    ,0 };
            const std::uint32_t dim1500Kuo2Init[]       =   {   1   ,   1   ,   5   ,   7   ,   9   ,   53  ,   1   ,   91  ,   53  ,   823 ,   281 ,   2281    ,   6509    ,   2515    ,0 };
            const std::uint32_t dim1501Kuo2Init[]       =   {   1   ,   1   ,   5   ,   5   ,   13  ,   61  ,   105 ,   183 ,   39  ,   493 ,   773 ,   1815    ,   1549    ,   7511    ,0 };
            const std::uint32_t dim1502Kuo2Init[]       =   {   1   ,   1   ,   3   ,   13  ,   29  ,   27  ,   97  ,   205 ,   425 ,   13  ,   1227    ,   625 ,   137 ,   6785    ,0 };
            const std::uint32_t dim1503Kuo2Init[]       =   {   1   ,   3   ,   7   ,   11  ,   13  ,   29  ,   105 ,   85  ,   251 ,   151 ,   1515    ,   3137    ,   8051    ,   14333   ,0 };
            const std::uint32_t dim1504Kuo2Init[]       =   {   1   ,   3   ,   7   ,   9   ,   25  ,   59  ,   99  ,   43  ,   435 ,   361 ,   297 ,   449 ,   5633    ,   5813    ,0 };
            const std::uint32_t dim1505Kuo2Init[]       =   {   1   ,   3   ,   1   ,   13  ,   17  ,   45  ,   113 ,   79  ,   315 ,   781 ,   785 ,   3463    ,   1299    ,   5959    ,0 };
            const std::uint32_t dim1506Kuo2Init[]       =   {   1   ,   1   ,   7   ,   15  ,   19  ,   47  ,   35  ,   13  ,   487 ,   227 ,   1965    ,   4035    ,   4285    ,   14395   ,0 };
            const std::uint32_t dim1507Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   9   ,   41  ,   91  ,   127 ,   101 ,   519 ,   1147    ,   3851    ,   7929    ,   1807    ,0 };
            const std::uint32_t dim1508Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   19  ,   63  ,   45  ,   75  ,   437 ,   309 ,   1327    ,   3913    ,   5961    ,   2825    ,0 };
            const std::uint32_t dim1509Kuo2Init[]       =   {   1   ,   1   ,   1   ,   15  ,   11  ,   1   ,   77  ,   11  ,   105 ,   499 ,   859 ,   2403    ,   4453    ,   12297   ,0 };
            const std::uint32_t dim1510Kuo2Init[]       =   {   1   ,   1   ,   5   ,   5   ,   9   ,   33  ,   87  ,   85  ,   167 ,   35  ,   501 ,   1027    ,   4489    ,   10513   ,0 };
            const std::uint32_t dim1511Kuo2Init[]       =   {   1   ,   1   ,   7   ,   13  ,   5   ,   3   ,   75  ,   75  ,   417 ,   319 ,   423 ,   1107    ,   371 ,   12493   ,0 };
            const std::uint32_t dim1512Kuo2Init[]       =   {   1   ,   3   ,   7   ,   7   ,   15  ,   57  ,   7   ,   105 ,   95  ,   287 ,   1865    ,   2795    ,   5187    ,   543 ,0 };
            const std::uint32_t dim1513Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   1   ,   3   ,   121 ,   99  ,   299 ,   415 ,   47  ,   997 ,   2939    ,   8529    ,0 };
            const std::uint32_t dim1514Kuo2Init[]       =   {   1   ,   1   ,   7   ,   11  ,   23  ,   17  ,   101 ,   209 ,   267 ,   459 ,   1965    ,   2153    ,   6361    ,   9553    ,0 };
            const std::uint32_t dim1515Kuo2Init[]       =   {   1   ,   1   ,   3   ,   5   ,   1   ,   9   ,   7   ,   17  ,   109 ,   245 ,   701 ,   2161    ,   2109    ,   3301    ,0 };
            const std::uint32_t dim1516Kuo2Init[]       =   {   1   ,   3   ,   5   ,   3   ,   13  ,   21  ,   113 ,   159 ,   261 ,   467 ,   127 ,   437 ,   8071    ,   11647   ,0 };
            const std::uint32_t dim1517Kuo2Init[]       =   {   1   ,   3   ,   1   ,   15  ,   29  ,   63  ,   93  ,   31  ,   189 ,   881 ,   17  ,   2689    ,   1273    ,   4991    ,0 };
            const std::uint32_t dim1518Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   31  ,   23  ,   39  ,   177 ,   505 ,   207 ,   67  ,   2897    ,   315 ,   5981    ,0 };
            const std::uint32_t dim1519Kuo2Init[]       =   {   1   ,   3   ,   5   ,   5   ,   31  ,   19  ,   87  ,   237 ,   119 ,   439 ,   1893    ,   3079    ,   3709    ,   15051   ,0 };
            const std::uint32_t dim1520Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   31  ,   35  ,   125 ,   173 ,   197 ,   765 ,   1419    ,   465 ,   1919    ,   2641    ,0 };
            const std::uint32_t dim1521Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   19  ,   15  ,   49  ,   255 ,   447 ,   939 ,   137 ,   2371    ,   6617    ,   79  ,0 };
            const std::uint32_t dim1522Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   11  ,   29  ,   81  ,   81  ,   327 ,   593 ,   135 ,   415 ,   2417    ,   8671    ,0 };
            const std::uint32_t dim1523Kuo2Init[]       =   {   1   ,   1   ,   7   ,   11  ,   11  ,   35  ,   9   ,   143 ,   311 ,   57  ,   557 ,   793 ,   6597    ,   12979   ,0 };
            const std::uint32_t dim1524Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   27  ,   1   ,   105 ,   149 ,   417 ,   605 ,   431 ,   2419    ,   4113    ,   5651    ,0 };
            const std::uint32_t dim1525Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   1   ,   45  ,   63  ,   119 ,   167 ,   607 ,   961 ,   2561    ,   7839    ,   13343   ,0 };
            const std::uint32_t dim1526Kuo2Init[]       =   {   1   ,   1   ,   5   ,   15  ,   11  ,   47  ,   75  ,   209 ,   175 ,   219 ,   443 ,   1311    ,   3383    ,   14073   ,0 };
            const std::uint32_t dim1527Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   17  ,   49  ,   97  ,   3   ,   343 ,   515 ,   129 ,   2243    ,   1567    ,   6119    ,0 };
            const std::uint32_t dim1528Kuo2Init[]       =   {   1   ,   1   ,   3   ,   13  ,   3   ,   31  ,   111 ,   173 ,   97  ,   211 ,   69  ,   1771    ,   3039    ,   10305   ,0 };
            const std::uint32_t dim1529Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   7   ,   27  ,   5   ,   163 ,   277 ,   959 ,   1287    ,   3603    ,   2617    ,   12883   ,0 };
            const std::uint32_t dim1530Kuo2Init[]       =   {   1   ,   1   ,   7   ,   5   ,   7   ,   63  ,   25  ,   235 ,   301 ,   575 ,   1979    ,   1519    ,   5765    ,   6331    ,0 };
            const std::uint32_t dim1531Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   23  ,   35  ,   43  ,   171 ,   481 ,   559 ,   1495    ,   665 ,   6325    ,   2733    ,0 };
            const std::uint32_t dim1532Kuo2Init[]       =   {   1   ,   1   ,   7   ,   5   ,   3   ,   55  ,   99  ,   141 ,   37  ,   757 ,   11  ,   911 ,   2523    ,   11031   ,0 };
            const std::uint32_t dim1533Kuo2Init[]       =   {   1   ,   1   ,   5   ,   7   ,   17  ,   9   ,   91  ,   9   ,   141 ,   693 ,   581 ,   2151    ,   3527    ,   11575   ,0 };
            const std::uint32_t dim1534Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   19  ,   31  ,   23  ,   59  ,   215 ,   873 ,   161 ,   1719    ,   509 ,   4509    ,0 };
            const std::uint32_t dim1535Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   17  ,   29  ,   57  ,   31  ,   233 ,   109 ,   865 ,   759 ,   3289    ,   11595   ,0 };
            const std::uint32_t dim1536Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   5   ,   61  ,   17  ,   69  ,   413 ,   95  ,   41  ,   1375    ,   1959    ,   11945   ,0 };
            const std::uint32_t dim1537Kuo2Init[]       =   {   1   ,   3   ,   7   ,   1   ,   25  ,   3   ,   77  ,   9   ,   301 ,   117 ,   255 ,   3169    ,   3493    ,   5503    ,0 };
            const std::uint32_t dim1538Kuo2Init[]       =   {   1   ,   1   ,   5   ,   3   ,   31  ,   1   ,   87  ,   211 ,   45  ,   185 ,   329 ,   3883    ,   3621    ,   4007    ,0 };
            const std::uint32_t dim1539Kuo2Init[]       =   {   1   ,   1   ,   5   ,   15  ,   11  ,   5   ,   123 ,   131 ,   479 ,   981 ,   921 ,   3557    ,   5897    ,   9387    ,0 };
            const std::uint32_t dim1540Kuo2Init[]       =   {   1   ,   1   ,   3   ,   3   ,   9   ,   43  ,   25  ,   57  ,   151 ,   975 ,   403 ,   727 ,   1155    ,   13495   ,0 };
            const std::uint32_t dim1541Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   29  ,   59  ,   31  ,   169 ,   201 ,   1007    ,   1017    ,   3121    ,   3989    ,   7835    ,0 };
            const std::uint32_t dim1542Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   19  ,   7   ,   103 ,   137 ,   135 ,   855 ,   179 ,   2859    ,   6959    ,   9749    ,0 };
            const std::uint32_t dim1543Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   3   ,   3   ,   121 ,   231 ,   461 ,   511 ,   1203    ,   2105    ,   6379    ,   6809    ,0 };
            const std::uint32_t dim1544Kuo2Init[]       =   {   1   ,   1   ,   7   ,   15  ,   29  ,   5   ,   19  ,   215 ,   13  ,   813 ,   1421    ,   1725    ,   7809    ,   2379    ,0 };
            const std::uint32_t dim1545Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   9   ,   55  ,   127 ,   129 ,   95  ,   449 ,   1607    ,   4043    ,   5175    ,   6063    ,0 };
            const std::uint32_t dim1546Kuo2Init[]       =   {   1   ,   1   ,   1   ,   9   ,   17  ,   31  ,   103 ,   107 ,   89  ,   5   ,   1747    ,   3405    ,   5739    ,   1959    ,0 };
            const std::uint32_t dim1547Kuo2Init[]       =   {   1   ,   3   ,   1   ,   15  ,   5   ,   43  ,   41  ,   15  ,   453 ,   691 ,   739 ,   3755    ,   6597    ,   9737    ,0 };
            const std::uint32_t dim1548Kuo2Init[]       =   {   1   ,   1   ,   3   ,   5   ,   27  ,   55  ,   111 ,   19  ,   349 ,   753 ,   1667    ,   3683    ,   4617    ,   12663   ,0 };
            const std::uint32_t dim1549Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   29  ,   57  ,   111 ,   187 ,   45  ,   957 ,   2001    ,   2743    ,   2813    ,   3831    ,0 };
            const std::uint32_t dim1550Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   13  ,   63  ,   25  ,   59  ,   169 ,   577 ,   301 ,   1535    ,   5355    ,   15835   ,0 };
            const std::uint32_t dim1551Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   7   ,   25  ,   101 ,   249 ,   59  ,   217 ,   557 ,   2565    ,   5103    ,   13787   ,0 };
            const std::uint32_t dim1552Kuo2Init[]       =   {   1   ,   3   ,   7   ,   9   ,   5   ,   31  ,   97  ,   19  ,   435 ,   205 ,   1217    ,   3659    ,   7687    ,   8381    ,0 };
            const std::uint32_t dim1553Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   7   ,   33  ,   41  ,   89  ,   243 ,   769 ,   1915    ,   2235    ,   757 ,   367 ,0 };
            const std::uint32_t dim1554Kuo2Init[]       =   {   1   ,   1   ,   1   ,   15  ,   3   ,   11  ,   103 ,   41  ,   79  ,   585 ,   1661    ,   1739    ,   2075    ,   15113   ,0 };
            const std::uint32_t dim1555Kuo2Init[]       =   {   1   ,   1   ,   5   ,   5   ,   5   ,   53  ,   103 ,   167 ,   387 ,   591 ,   317 ,   2539    ,   3763    ,   3341    ,0 };
            const std::uint32_t dim1556Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   31  ,   29  ,   69  ,   43  ,   257 ,   471 ,   435 ,   3895    ,   445 ,   10941   ,0 };
            const std::uint32_t dim1557Kuo2Init[]       =   {   1   ,   1   ,   1   ,   9   ,   13  ,   63  ,   3   ,   167 ,   447 ,   569 ,   949 ,   2289    ,   6383    ,   5887    ,0 };
            const std::uint32_t dim1558Kuo2Init[]       =   {   1   ,   1   ,   5   ,   5   ,   11  ,   31  ,   35  ,   9   ,   383 ,   933 ,   519 ,   3773    ,   4987    ,   2737    ,0 };
            const std::uint32_t dim1559Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   15  ,   17  ,   121 ,   109 ,   299 ,   579 ,   683 ,   1365    ,   2471    ,   14275   ,0 };
            const std::uint32_t dim1560Kuo2Init[]       =   {   1   ,   1   ,   1   ,   9   ,   19  ,   9   ,   17  ,   229 ,   405 ,   545 ,   1923    ,   991 ,   473 ,   11233   ,0 };
            const std::uint32_t dim1561Kuo2Init[]       =   {   1   ,   1   ,   3   ,   13  ,   13  ,   1   ,   101 ,   241 ,   51  ,   885 ,   1835    ,   1095    ,   2917    ,   15167   ,0 };
            const std::uint32_t dim1562Kuo2Init[]       =   {   1   ,   3   ,   5   ,   3   ,   31  ,   35  ,   127 ,   17  ,   153 ,   415 ,   769 ,   299 ,   7791    ,   8697    ,0 };
            const std::uint32_t dim1563Kuo2Init[]       =   {   1   ,   3   ,   3   ,   3   ,   23  ,   35  ,   77  ,   237 ,   427 ,   611 ,   2025    ,   3201    ,   7855    ,   789 ,0 };
            const std::uint32_t dim1564Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   9   ,   25  ,   123 ,   215 ,   387 ,   939 ,   471 ,   1123    ,   6747    ,   14803   ,0 };
            const std::uint32_t dim1565Kuo2Init[]       =   {   1   ,   1   ,   5   ,   15  ,   1   ,   55  ,   85  ,   249 ,   315 ,   253 ,   1705    ,   35  ,   7351    ,   11255   ,0 };
            const std::uint32_t dim1566Kuo2Init[]       =   {   1   ,   3   ,   5   ,   3   ,   7   ,   15  ,   5   ,   167 ,   351 ,   145 ,   1891    ,   2691    ,   3035    ,   873 ,0 };
            const std::uint32_t dim1567Kuo2Init[]       =   {   1   ,   3   ,   1   ,   15  ,   19  ,   33  ,   85  ,   241 ,   259 ,   625 ,   615 ,   97  ,   5977    ,   4777    ,0 };
            const std::uint32_t dim1568Kuo2Init[]       =   {   1   ,   3   ,   7   ,   9   ,   19  ,   17  ,   9   ,   197 ,   141 ,   5   ,   355 ,   3001    ,   6903    ,   13809   ,0 };
            const std::uint32_t dim1569Kuo2Init[]       =   {   1   ,   1   ,   7   ,   13  ,   9   ,   39  ,   79  ,   43  ,   465 ,   49  ,   849 ,   1509    ,   5251    ,   11239   ,0 };
            const std::uint32_t dim1570Kuo2Init[]       =   {   1   ,   1   ,   7   ,   3   ,   5   ,   21  ,   37  ,   159 ,   461 ,   1015    ,   329 ,   4095    ,   2513    ,   6213    ,0 };
            const std::uint32_t dim1571Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   7   ,   19  ,   127 ,   15  ,   61  ,   439 ,   1381    ,   677 ,   2851    ,   1635    ,0 };
            const std::uint32_t dim1572Kuo2Init[]       =   {   1   ,   1   ,   3   ,   5   ,   17  ,   19  ,   125 ,   171 ,   175 ,   441 ,   1153    ,   2445    ,   2907    ,   13089   ,0 };
            const std::uint32_t dim1573Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   17  ,   59  ,   53  ,   81  ,   5   ,   685 ,   1257    ,   3179    ,   5067    ,   10131   ,0 };
            const std::uint32_t dim1574Kuo2Init[]       =   {   1   ,   1   ,   5   ,   3   ,   9   ,   47  ,   25  ,   111 ,   235 ,   117 ,   65  ,   2565    ,   865 ,   15173   ,0 };
            const std::uint32_t dim1575Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   27  ,   5   ,   55  ,   155 ,   221 ,   451 ,   1823    ,   1277    ,   1397    ,   15715   ,0 };
            const std::uint32_t dim1576Kuo2Init[]       =   {   1   ,   1   ,   1   ,   15  ,   17  ,   5   ,   115 ,   209 ,   393 ,   973 ,   177 ,   825 ,   3315    ,   8333    ,0 };
            const std::uint32_t dim1577Kuo2Init[]       =   {   1   ,   1   ,   3   ,   13  ,   23  ,   47  ,   121 ,   47  ,   379 ,   433 ,   807 ,   3723    ,   2595    ,   14727   ,0 };
            const std::uint32_t dim1578Kuo2Init[]       =   {   1   ,   1   ,   3   ,   5   ,   29  ,   59  ,   39  ,   205 ,   327 ,   999 ,   1897    ,   3441    ,   5355    ,   12881   ,0 };
            const std::uint32_t dim1579Kuo2Init[]       =   {   1   ,   1   ,   3   ,   3   ,   27  ,   63  ,   57  ,   175 ,   225 ,   353 ,   675 ,   2955    ,   6581    ,   2735    ,0 };
            const std::uint32_t dim1580Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   11  ,   55  ,   55  ,   191 ,   239 ,   579 ,   1355    ,   2449    ,   563 ,   9757    ,0 };
            const std::uint32_t dim1581Kuo2Init[]       =   {   1   ,   1   ,   7   ,   5   ,   1   ,   49  ,   35  ,   19  ,   25  ,   783 ,   1453    ,   1063    ,   4811    ,   1449    ,0 };
            const std::uint32_t dim1582Kuo2Init[]       =   {   1   ,   3   ,   1   ,   13  ,   11  ,   63  ,   17  ,   203 ,   479 ,   133 ,   1951    ,   385 ,   6803    ,   13453   ,0 };
            const std::uint32_t dim1583Kuo2Init[]       =   {   1   ,   3   ,   7   ,   9   ,   21  ,   19  ,   15  ,   125 ,   397 ,   109 ,   1903    ,   4053    ,   6449    ,   8821    ,0 };
            const std::uint32_t dim1584Kuo2Init[]       =   {   1   ,   3   ,   7   ,   15  ,   1   ,   33  ,   45  ,   161 ,   43  ,   729 ,   397 ,   4093    ,   8123    ,   3123    ,0 };
            const std::uint32_t dim1585Kuo2Init[]       =   {   1   ,   3   ,   7   ,   7   ,   3   ,   35  ,   3   ,   183 ,   231 ,   351 ,   1381    ,   1251    ,   3423    ,   3361    ,0 };
            const std::uint32_t dim1586Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   23  ,   11  ,   71  ,   137 ,   323 ,   809 ,   827 ,   1573    ,   4483    ,   8691    ,0 };
            const std::uint32_t dim1587Kuo2Init[]       =   {   1   ,   3   ,   7   ,   7   ,   17  ,   29  ,   121 ,   47  ,   139 ,   687 ,   95  ,   1507    ,   2009    ,   1679    ,0 };
            const std::uint32_t dim1588Kuo2Init[]       =   {   1   ,   3   ,   7   ,   9   ,   25  ,   53  ,   127 ,   137 ,   295 ,   863 ,   299 ,   1831    ,   5359    ,   4787    ,0 };
            const std::uint32_t dim1589Kuo2Init[]       =   {   1   ,   3   ,   1   ,   9   ,   29  ,   3   ,   83  ,   35  ,   367 ,   675 ,   1511    ,   381 ,   6675    ,   897 ,0 };
            const std::uint32_t dim1590Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   1   ,   15  ,   57  ,   199 ,   349 ,   873 ,   1059    ,   3767    ,   841 ,   16259   ,0 };
            const std::uint32_t dim1591Kuo2Init[]       =   {   1   ,   3   ,   7   ,   3   ,   13  ,   5   ,   47  ,   203 ,   211 ,   899 ,   1107    ,   743 ,   6825    ,   8703    ,0 };
            const std::uint32_t dim1592Kuo2Init[]       =   {   1   ,   3   ,   7   ,   11  ,   31  ,   41  ,   11  ,   59  ,   59  ,   859 ,   787 ,   977 ,   2223    ,   15921   ,0 };
            const std::uint32_t dim1593Kuo2Init[]       =   {   1   ,   3   ,   5   ,   5   ,   31  ,   11  ,   39  ,   105 ,   109 ,   487 ,   1459    ,   2935    ,   3723    ,   4697    ,0 };
            const std::uint32_t dim1594Kuo2Init[]       =   {   1   ,   3   ,   3   ,   13  ,   9   ,   17  ,   39  ,   239 ,   183 ,   885 ,   123 ,   387 ,   2369    ,   16179   ,0 };
            const std::uint32_t dim1595Kuo2Init[]       =   {   1   ,   1   ,   1   ,   7   ,   25  ,   47  ,   23  ,   29  ,   95  ,   331 ,   2005    ,   633 ,   649 ,   1623    ,0 };
            const std::uint32_t dim1596Kuo2Init[]       =   {   1   ,   1   ,   3   ,   13  ,   9   ,   21  ,   41  ,   125 ,   287 ,   309 ,   1421    ,   1637    ,   2611    ,   2259    ,0 };
            const std::uint32_t dim1597Kuo2Init[]       =   {   1   ,   1   ,   3   ,   3   ,   11  ,   27  ,   117 ,   93  ,   419 ,   521 ,   1699    ,   233 ,   1967    ,   14147   ,0 };
            const std::uint32_t dim1598Kuo2Init[]       =   {   1   ,   1   ,   3   ,   11  ,   25  ,   21  ,   61  ,   15  ,   415 ,   693 ,   1685    ,   1727    ,   961 ,   3887    ,0 };
            const std::uint32_t dim1599Kuo2Init[]       =   {   1   ,   3   ,   7   ,   9   ,   15  ,   39  ,   41  ,   19  ,   237 ,   231 ,   1605    ,   2641    ,   6047    ,   10235   ,0 };
            const std::uint32_t dim1600Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   5   ,   49  ,   113 ,   133 ,   499 ,   545 ,   467 ,   683 ,   579 ,   8123    ,0 };
            const std::uint32_t dim1601Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   11  ,   31  ,   121 ,   229 ,   225 ,   135 ,   85  ,   1389    ,   5317    ,   13453   ,0 };
            const std::uint32_t dim1602Kuo2Init[]       =   {   1   ,   3   ,   7   ,   9   ,   17  ,   51  ,   77  ,   141 ,   413 ,   805 ,   1759    ,   1139    ,   5847    ,   16153   ,0 };
            const std::uint32_t dim1603Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   23  ,   29  ,   79  ,   235 ,   113 ,   981 ,   1147    ,   219 ,   2609    ,   1089    ,0 };
            const std::uint32_t dim1604Kuo2Init[]       =   {   1   ,   1   ,   5   ,   7   ,   5   ,   45  ,   123 ,   123 ,   335 ,   409 ,   115 ,   971 ,   827 ,   427 ,0 };
            const std::uint32_t dim1605Kuo2Init[]       =   {   1   ,   3   ,   7   ,   13  ,   13  ,   45  ,   41  ,   173 ,   261 ,   151 ,   1199    ,   2803    ,   5801    ,   2449    ,0 };
            const std::uint32_t dim1606Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   5   ,   17  ,   9   ,   91  ,   475 ,   505 ,   1983    ,   2539    ,   339 ,   16365   ,0 };
            const std::uint32_t dim1607Kuo2Init[]       =   {   1   ,   1   ,   7   ,   5   ,   25  ,   31  ,   77  ,   53  ,   293 ,   735 ,   1423    ,   165 ,   4363    ,   5923    ,0 };
            const std::uint32_t dim1608Kuo2Init[]       =   {   1   ,   1   ,   1   ,   15  ,   7   ,   51  ,   117 ,   91  ,   347 ,   677 ,   1059    ,   2861    ,   3583    ,   11995   ,0 };
            const std::uint32_t dim1609Kuo2Init[]       =   {   1   ,   3   ,   3   ,   13  ,   27  ,   27  ,   123 ,   251 ,   47  ,   885 ,   2015    ,   1089    ,   4077    ,   8591    ,0 };
            const std::uint32_t dim1610Kuo2Init[]       =   {   1   ,   1   ,   7   ,   11  ,   17  ,   41  ,   97  ,   47  ,   201 ,   789 ,   881 ,   1565    ,   1169    ,   10967   ,0 };
            const std::uint32_t dim1611Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   25  ,   43  ,   45  ,   237 ,   73  ,   909 ,   1041    ,   1025    ,   3217    ,   9347    ,0 };
            const std::uint32_t dim1612Kuo2Init[]       =   {   1   ,   1   ,   1   ,   3   ,   7   ,   59  ,   51  ,   177 ,   223 ,   125 ,   63  ,   3311    ,   3171    ,   8725    ,0 };
            const std::uint32_t dim1613Kuo2Init[]       =   {   1   ,   1   ,   1   ,   1   ,   31  ,   25  ,   55  ,   117 ,   493 ,   419 ,   1749    ,   2799    ,   6943    ,   12427   ,0 };
            const std::uint32_t dim1614Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   1   ,   59  ,   123 ,   239 ,   239 ,   589 ,   667 ,   1029    ,   1357    ,   6801    ,0 };
            const std::uint32_t dim1615Kuo2Init[]       =   {   1   ,   1   ,   7   ,   15  ,   21  ,   7   ,   43  ,   103 ,   159 ,   685 ,   1435    ,   529 ,   4225    ,   5051    ,0 };
            const std::uint32_t dim1616Kuo2Init[]       =   {   1   ,   3   ,   1   ,   13  ,   29  ,   21  ,   19  ,   229 ,   369 ,   317 ,   1681    ,   685 ,   5301    ,   11107   ,0 };
            const std::uint32_t dim1617Kuo2Init[]       =   {   1   ,   3   ,   7   ,   9   ,   17  ,   13  ,   117 ,   21  ,   203 ,   123 ,   1933    ,   3981    ,   5133    ,   11729   ,0 };
            const std::uint32_t dim1618Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   29  ,   5   ,   119 ,   27  ,   135 ,   913 ,   1891    ,   2785    ,   6311    ,   8439    ,0 };
            const std::uint32_t dim1619Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   3   ,   31  ,   95  ,   55  ,   89  ,   541 ,   609 ,   773 ,   6513    ,   10015   ,0 };
            const std::uint32_t dim1620Kuo2Init[]       =   {   1   ,   3   ,   7   ,   1   ,   25  ,   27  ,   71  ,   153 ,   215 ,   921 ,   29  ,   2103    ,   1605    ,   59  ,0 };
            const std::uint32_t dim1621Kuo2Init[]       =   {   1   ,   1   ,   3   ,   5   ,   15  ,   31  ,   65  ,   35  ,   221 ,   571 ,   873 ,   1271    ,   5399    ,   15659   ,0 };
            const std::uint32_t dim1622Kuo2Init[]       =   {   1   ,   3   ,   5   ,   3   ,   31  ,   31  ,   127 ,   251 ,   379 ,   801 ,   905 ,   1661    ,   225 ,   11939   ,0 };
            const std::uint32_t dim1623Kuo2Init[]       =   {   1   ,   3   ,   1   ,   15  ,   31  ,   59  ,   51  ,   117 ,   325 ,   491 ,   1801    ,   669 ,   2867    ,   5325    ,0 };
            const std::uint32_t dim1624Kuo2Init[]       =   {   1   ,   1   ,   5   ,   13  ,   1   ,   15  ,   3   ,   105 ,   81  ,   229 ,   573 ,   3047    ,   6373    ,   11947   ,0 };
            const std::uint32_t dim1625Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   7   ,   51  ,   83  ,   103 ,   277 ,   5   ,   1189    ,   89  ,   7173    ,   1617    ,0 };
            const std::uint32_t dim1626Kuo2Init[]       =   {   1   ,   1   ,   5   ,   3   ,   11  ,   13  ,   5   ,   205 ,   179 ,   23  ,   1327    ,   3049    ,   23  ,   5123    ,0 };
            const std::uint32_t dim1627Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   7   ,   23  ,   117 ,   133 ,   449 ,   265 ,   1087    ,   1565    ,   7185    ,   7099    ,0 };
            const std::uint32_t dim1628Kuo2Init[]       =   {   1   ,   1   ,   3   ,   5   ,   7   ,   13  ,   31  ,   197 ,   29  ,   659 ,   1485    ,   2395    ,   3239    ,   5837    ,0 };
            const std::uint32_t dim1629Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   15  ,   53  ,   67  ,   107 ,   103 ,   675 ,   253 ,   471 ,   283 ,   1221    ,0 };
            const std::uint32_t dim1630Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   17  ,   17  ,   65  ,   165 ,   141 ,   839 ,   217 ,   3779    ,   1151    ,   3551    ,0 };
            const std::uint32_t dim1631Kuo2Init[]       =   {   1   ,   1   ,   7   ,   13  ,   13  ,   23  ,   57  ,   241 ,   253 ,   565 ,   371 ,   3713    ,   4539    ,   1033    ,0 };
            const std::uint32_t dim1632Kuo2Init[]       =   {   1   ,   1   ,   7   ,   11  ,   17  ,   11  ,   121 ,   193 ,   9   ,   33  ,   695 ,   1361    ,   6433    ,   895 ,0 };
            const std::uint32_t dim1633Kuo2Init[]       =   {   1   ,   1   ,   1   ,   3   ,   15  ,   11  ,   87  ,   87  ,   419 ,   605 ,   163 ,   377 ,   3729    ,   4309    ,0 };
            const std::uint32_t dim1634Kuo2Init[]       =   {   1   ,   3   ,   5   ,   3   ,   17  ,   43  ,   13  ,   99  ,   409 ,   919 ,   1347    ,   1407    ,   1723    ,   11317   ,0 };
            const std::uint32_t dim1635Kuo2Init[]       =   {   1   ,   1   ,   1   ,   9   ,   1   ,   21  ,   111 ,   225 ,   191 ,   65  ,   1231    ,   27  ,   387 ,   12225   ,0 };
            const std::uint32_t dim1636Kuo2Init[]       =   {   1   ,   1   ,   3   ,   11  ,   19  ,   63  ,   61  ,   103 ,   31  ,   241 ,   1807    ,   3101    ,   7275    ,   2333    ,0 };
            const std::uint32_t dim1637Kuo2Init[]       =   {   1   ,   1   ,   7   ,   5   ,   31  ,   41  ,   115 ,   77  ,   347 ,   85  ,   69  ,   1911    ,   7345    ,   15269   ,0 };
            const std::uint32_t dim1638Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   25  ,   41  ,   105 ,   5   ,   161 ,   721 ,   1667    ,   1285    ,   6197    ,   14823   ,0 };
            const std::uint32_t dim1639Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   15  ,   33  ,   43  ,   155 ,   269 ,   215 ,   663 ,   3425    ,   7725    ,   15307   ,0 };
            const std::uint32_t dim1640Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   23  ,   43  ,   71  ,   79  ,   163 ,   167 ,   1207    ,   741 ,   141 ,   8269    ,0 };
            const std::uint32_t dim1641Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   21  ,   21  ,   39  ,   181 ,   379 ,   383 ,   343 ,   1685    ,   1713    ,   10377   ,0 };
            const std::uint32_t dim1642Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   3   ,   17  ,   45  ,   11  ,   351 ,   111 ,   229 ,   3241    ,   6953    ,   7143    ,0 };
            const std::uint32_t dim1643Kuo2Init[]       =   {   1   ,   1   ,   7   ,   13  ,   15  ,   57  ,   87  ,   247 ,   361 ,   943 ,   801 ,   1861    ,   5705    ,   14499   ,0 };
            const std::uint32_t dim1644Kuo2Init[]       =   {   1   ,   1   ,   5   ,   7   ,   11  ,   9   ,   89  ,   235 ,   235 ,   225 ,   1053    ,   2909    ,   993 ,   15471   ,0 };
            const std::uint32_t dim1645Kuo2Init[]       =   {   1   ,   3   ,   3   ,   11  ,   15  ,   47  ,   73  ,   13  ,   477 ,   703 ,   1353    ,   3633    ,   4059    ,   16367   ,0 };
            const std::uint32_t dim1646Kuo2Init[]       =   {   1   ,   1   ,   5   ,   15  ,   9   ,   39  ,   49  ,   141 ,   181 ,   917 ,   1331    ,   427 ,   7455    ,   13753   ,0 };
            const std::uint32_t dim1647Kuo2Init[]       =   {   1   ,   3   ,   1   ,   13  ,   11  ,   7   ,   113 ,   101 ,   473 ,   851 ,   771 ,   1287    ,   8157    ,   2113    ,0 };
            const std::uint32_t dim1648Kuo2Init[]       =   {   1   ,   3   ,   1   ,   15  ,   23  ,   33  ,   87  ,   5   ,   245 ,   853 ,   1433    ,   85  ,   5655    ,   11579   ,0 };
            const std::uint32_t dim1649Kuo2Init[]       =   {   1   ,   1   ,   5   ,   15  ,   19  ,   59  ,   103 ,   249 ,   247 ,   589 ,   797 ,   2733    ,   6603    ,   2065    ,0 };
            const std::uint32_t dim1650Kuo2Init[]       =   {   1   ,   1   ,   1   ,   7   ,   25  ,   63  ,   105 ,   183 ,   497 ,   25  ,   739 ,   521 ,   7327    ,   12711   ,0 };
            const std::uint32_t dim1651Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   27  ,   13  ,   63  ,   23  ,   417 ,   303 ,   155 ,   2227    ,   5621    ,   1643    ,0 };
            const std::uint32_t dim1652Kuo2Init[]       =   {   1   ,   1   ,   5   ,   9   ,   29  ,   13  ,   75  ,   199 ,   353 ,   577 ,   1715    ,   3939    ,   2659    ,   5969    ,0 };
            const std::uint32_t dim1653Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   11  ,   37  ,   55  ,   185 ,   435 ,   763 ,   333 ,   3243    ,   7553    ,   9741    ,0 };
            const std::uint32_t dim1654Kuo2Init[]       =   {   1   ,   3   ,   7   ,   13  ,   7   ,   1   ,   65  ,   243 ,   443 ,   869 ,   769 ,   4027    ,   4831    ,   7333    ,0 };
            const std::uint32_t dim1655Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   31  ,   23  ,   93  ,   117 ,   323 ,   157 ,   811 ,   1543    ,   449 ,   8371    ,0 };
            const std::uint32_t dim1656Kuo2Init[]       =   {   1   ,   3   ,   1   ,   9   ,   27  ,   25  ,   87  ,   223 ,   467 ,   761 ,   547 ,   2381    ,   411 ,   14035   ,0 };
            const std::uint32_t dim1657Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   31  ,   27  ,   127 ,   11  ,   243 ,   263 ,   255 ,   831 ,   6801    ,   10923   ,0 };
            const std::uint32_t dim1658Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   23  ,   11  ,   77  ,   5   ,   255 ,   699 ,   13  ,   3883    ,   4703    ,   2785    ,0 };
            const std::uint32_t dim1659Kuo2Init[]       =   {   1   ,   3   ,   1   ,   1   ,   25  ,   37  ,   47  ,   75  ,   79  ,   881 ,   1505    ,   2825    ,   2477    ,   1963    ,0 };
            const std::uint32_t dim1660Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   29  ,   39  ,   33  ,   151 ,   153 ,   869 ,   65  ,   107 ,   7173    ,   5059    ,0 };
            const std::uint32_t dim1661Kuo2Init[]       =   {   1   ,   1   ,   5   ,   13  ,   29  ,   41  ,   61  ,   37  ,   353 ,   429 ,   587 ,   2431    ,   3711    ,   14149   ,0 };
            const std::uint32_t dim1662Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   13  ,   23  ,   29  ,   157 ,   427 ,   353 ,   1485    ,   879 ,   3851    ,   15775   ,0 };
            const std::uint32_t dim1663Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   7   ,   17  ,   91  ,   225 ,   275 ,   923 ,   1383    ,   2587    ,   7545    ,   7203    ,0 };
            const std::uint32_t dim1664Kuo2Init[]       =   {   1   ,   1   ,   5   ,   3   ,   3   ,   57  ,   75  ,   97  ,   233 ,   233 ,   1547    ,   1915    ,   1229    ,   8559    ,0 };
            const std::uint32_t dim1665Kuo2Init[]       =   {   1   ,   3   ,   3   ,   11  ,   11  ,   63  ,   15  ,   121 ,   209 ,   31  ,   171 ,   1117    ,   2373    ,   7545    ,0 };
            const std::uint32_t dim1666Kuo2Init[]       =   {   1   ,   1   ,   1   ,   3   ,   27  ,   7   ,   89  ,   155 ,   7   ,   829 ,   537 ,   3639    ,   1721    ,   8199    ,0 };
            const std::uint32_t dim1667Kuo2Init[]       =   {   1   ,   1   ,   1   ,   1   ,   5   ,   43  ,   59  ,   245 ,   321 ,   869 ,   785 ,   367 ,   2693    ,   8603    ,0 };
            const std::uint32_t dim1668Kuo2Init[]       =   {   1   ,   1   ,   3   ,   1   ,   23  ,   17  ,   19  ,   79  ,   303 ,   919 ,   1119    ,   303 ,   907 ,   9033    ,0 };
            const std::uint32_t dim1669Kuo2Init[]       =   {   1   ,   3   ,   1   ,   15  ,   17  ,   43  ,   1   ,   207 ,   395 ,   251 ,   727 ,   1341    ,   2073    ,   16319   ,0 };
            const std::uint32_t dim1670Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   3   ,   31  ,   97  ,   111 ,   161 ,   947 ,   1509    ,   2143    ,   4773    ,   3569    ,0 };
            const std::uint32_t dim1671Kuo2Init[]       =   {   1   ,   3   ,   7   ,   3   ,   5   ,   33  ,   19  ,   149 ,   233 ,   221 ,   517 ,   21  ,   7651    ,   14987   ,0 };
            const std::uint32_t dim1672Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   19  ,   1   ,   39  ,   253 ,   311 ,   681 ,   897 ,   2777    ,   5181    ,   6985    ,0 };
            const std::uint32_t dim1673Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   3   ,   39  ,   75  ,   225 ,   491 ,   631 ,   513 ,   935 ,   2775    ,   6405    ,0 };
            const std::uint32_t dim1674Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   29  ,   57  ,   67  ,   67  ,   53  ,   955 ,   1297    ,   3871    ,   131 ,   7317    ,0 };
            const std::uint32_t dim1675Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   31  ,   55  ,   53  ,   179 ,   305 ,   625 ,   1097    ,   1203    ,   1973    ,   2807    ,0 };
            const std::uint32_t dim1676Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   5   ,   47  ,   25  ,   7   ,   279 ,   751 ,   1149    ,   2871    ,   2985    ,   11941   ,0 };
            const std::uint32_t dim1677Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   21  ,   47  ,   29  ,   23  ,   419 ,   181 ,   517 ,   1261    ,   2329    ,   11667   ,0 };
            const std::uint32_t dim1678Kuo2Init[]       =   {   1   ,   1   ,   1   ,   3   ,   5   ,   53  ,   61  ,   1   ,   273 ,   165 ,   1227    ,   2901    ,   2739    ,   2453    ,0 };
            const std::uint32_t dim1679Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   1   ,   21  ,   89  ,   27  ,   487 ,   167 ,   717 ,   3653    ,   3971    ,   7825    ,0 };
            const std::uint32_t dim1680Kuo2Init[]       =   {   1   ,   1   ,   3   ,   5   ,   3   ,   43  ,   19  ,   221 ,   21  ,   329 ,   1415    ,   1137    ,   1073    ,   2869    ,0 };
            const std::uint32_t dim1681Kuo2Init[]       =   {   1   ,   1   ,   7   ,   13  ,   27  ,   61  ,   65  ,   93  ,   469 ,   975 ,   5   ,   3919    ,   7565    ,   13885   ,0 };
            const std::uint32_t dim1682Kuo2Init[]       =   {   1   ,   1   ,   5   ,   9   ,   9   ,   9   ,   111 ,   97  ,   35  ,   595 ,   997 ,   797 ,   5963    ,   12977   ,0 };
            const std::uint32_t dim1683Kuo2Init[]       =   {   1   ,   3   ,   7   ,   11  ,   5   ,   1   ,   125 ,   169 ,   393 ,   127 ,   1297    ,   3853    ,   1177    ,   10553   ,0 };
            const std::uint32_t dim1684Kuo2Init[]       =   {   1   ,   1   ,   3   ,   13  ,   11  ,   53  ,   55  ,   119 ,   41  ,   895 ,   1379    ,   1955    ,   7059    ,   143 ,0 };
            const std::uint32_t dim1685Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   1   ,   9   ,   49  ,   165 ,   479 ,   247 ,   1555    ,   2199    ,   6695    ,   8983    ,0 };
            const std::uint32_t dim1686Kuo2Init[]       =   {   1   ,   3   ,   3   ,   3   ,   17  ,   53  ,   47  ,   97  ,   301 ,   649 ,   1121    ,   7   ,   1335    ,   11535   ,0 };
            const std::uint32_t dim1687Kuo2Init[]       =   {   1   ,   3   ,   1   ,   1   ,   25  ,   49  ,   5   ,   227 ,   335 ,   401 ,   651 ,   3089    ,   823 ,   3159    ,0 };
            const std::uint32_t dim1688Kuo2Init[]       =   {   1   ,   1   ,   5   ,   7   ,   7   ,   25  ,   79  ,   15  ,   79  ,   381 ,   991 ,   2319    ,   6087    ,   5919    ,0 };
            const std::uint32_t dim1689Kuo2Init[]       =   {   1   ,   3   ,   7   ,   3   ,   17  ,   53  ,   99  ,   237 ,   305 ,   411 ,   1751    ,   753 ,   4785    ,   57  ,0 };
            const std::uint32_t dim1690Kuo2Init[]       =   {   1   ,   1   ,   5   ,   7   ,   15  ,   27  ,   91  ,   159 ,   451 ,   877 ,   715 ,   1183    ,   3619    ,   4521    ,0 };
            const std::uint32_t dim1691Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   25  ,   9   ,   9   ,   1   ,   421 ,   707 ,   1619    ,   1423    ,   7183    ,   687 ,0 };
            const std::uint32_t dim1692Kuo2Init[]       =   {   1   ,   3   ,   7   ,   3   ,   3   ,   49  ,   79  ,   249 ,   299 ,   559 ,   1619    ,   2071    ,   8135    ,   1975    ,0 };
            const std::uint32_t dim1693Kuo2Init[]       =   {   1   ,   3   ,   1   ,   9   ,   29  ,   63  ,   67  ,   93  ,   373 ,   505 ,   193 ,   791 ,   5761    ,   8329    ,0 };
            const std::uint32_t dim1694Kuo2Init[]       =   {   1   ,   1   ,   3   ,   3   ,   7   ,   33  ,   33  ,   233 ,   507 ,   471 ,   1369    ,   3355    ,   27  ,   6389    ,0 };
            const std::uint32_t dim1695Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   21  ,   13  ,   25  ,   249 ,   39  ,   305 ,   827 ,   3559    ,   937 ,   6079    ,0 };
            const std::uint32_t dim1696Kuo2Init[]       =   {   1   ,   1   ,   1   ,   13  ,   25  ,   29  ,   115 ,   165 ,   65  ,   217 ,   1519    ,   3117    ,   3211    ,   7211    ,0 };
            const std::uint32_t dim1697Kuo2Init[]       =   {   1   ,   1   ,   1   ,   3   ,   21  ,   17  ,   55  ,   117 ,   61  ,   807 ,   1821    ,   703 ,   3403    ,   14181   ,0 };
            const std::uint32_t dim1698Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   3   ,   5   ,   65  ,   199 ,   399 ,   695 ,   1527    ,   1187    ,   7887    ,   15437   ,0 };
            const std::uint32_t dim1699Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   23  ,   47  ,   43  ,   49  ,   377 ,   893 ,   423 ,   3745    ,   4291    ,   2579    ,0 };
            const std::uint32_t dim1700Kuo2Init[]       =   {   1   ,   3   ,   3   ,   13  ,   15  ,   13  ,   19  ,   235 ,   209 ,   963 ,   1331    ,   1559    ,   5631    ,   2411    ,0 };
            const std::uint32_t dim1701Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   3   ,   47  ,   5   ,   179 ,   483 ,   163 ,   123 ,   1241    ,   5767    ,   4361    ,0 };
            const std::uint32_t dim1702Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   15  ,   25  ,   123 ,   13  ,   313 ,   959 ,   1845    ,   3949    ,   7395    ,   5727    ,0 };
            const std::uint32_t dim1703Kuo2Init[]       =   {   1   ,   3   ,   7   ,   7   ,   21  ,   35  ,   67  ,   209 ,   229 ,   213 ,   1403    ,   561 ,   4229    ,   13611   ,0 };
            const std::uint32_t dim1704Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   17  ,   45  ,   93  ,   5   ,   493 ,   779 ,   1357    ,   243 ,   2067    ,   4621    ,0 };
            const std::uint32_t dim1705Kuo2Init[]       =   {   1   ,   3   ,   7   ,   1   ,   19  ,   29  ,   11  ,   219 ,   247 ,   133 ,   443 ,   1331    ,   5027    ,   6953    ,0 };
            const std::uint32_t dim1706Kuo2Init[]       =   {   1   ,   1   ,   7   ,   5   ,   29  ,   41  ,   21  ,   95  ,   175 ,   761 ,   1425    ,   2471    ,   4597    ,   7071    ,0 };
            const std::uint32_t dim1707Kuo2Init[]       =   {   1   ,   3   ,   7   ,   15  ,   25  ,   5   ,   49  ,   153 ,   415 ,   703 ,   321 ,   3727    ,   4541    ,   9711    ,0 };
            const std::uint32_t dim1708Kuo2Init[]       =   {   1   ,   3   ,   5   ,   5   ,   21  ,   49  ,   15  ,   41  ,   203 ,   909 ,   953 ,   1587    ,   6323    ,   12589   ,0 };
            const std::uint32_t dim1709Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   29  ,   21  ,   59  ,   245 ,   287 ,   411 ,   1211    ,   2527    ,   5247    ,   11691   ,0 };
            const std::uint32_t dim1710Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   5   ,   29  ,   25  ,   123 ,   29  ,   613 ,   627 ,   269 ,   6479    ,   817 ,0 };
            const std::uint32_t dim1711Kuo2Init[]       =   {   1   ,   3   ,   5   ,   3   ,   23  ,   11  ,   15  ,   177 ,   421 ,   803 ,   273 ,   3145    ,   7211    ,   7141    ,0 };
            const std::uint32_t dim1712Kuo2Init[]       =   {   1   ,   1   ,   7   ,   13  ,   13  ,   37  ,   59  ,   81  ,   57  ,   349 ,   833 ,   871 ,   1343    ,   8911    ,0 };
            const std::uint32_t dim1713Kuo2Init[]       =   {   1   ,   3   ,   5   ,   3   ,   23  ,   11  ,   33  ,   39  ,   123 ,   77  ,   259 ,   2667    ,   2121    ,   203 ,0 };
            const std::uint32_t dim1714Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   5   ,   57  ,   31  ,   101 ,   463 ,   633 ,   1351    ,   2209    ,   5235    ,   8591    ,0 };
            const std::uint32_t dim1715Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   1   ,   35  ,   39  ,   121 ,   155 ,   847 ,   1355    ,   2161    ,   3073    ,   5873    ,0 };
            const std::uint32_t dim1716Kuo2Init[]       =   {   1   ,   3   ,   7   ,   11  ,   19  ,   23  ,   29  ,   233 ,   501 ,   321 ,   1131    ,   641 ,   4023    ,   11955   ,0 };
            const std::uint32_t dim1717Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   13  ,   39  ,   119 ,   157 ,   261 ,   167 ,   511 ,   2349    ,   1489    ,   11523   ,0 };
            const std::uint32_t dim1718Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   27  ,   3   ,   19  ,   165 ,   229 ,   591 ,   1975    ,   3411    ,   4453    ,   3291    ,0 };
            const std::uint32_t dim1719Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   11  ,   41  ,   61  ,   117 ,   505 ,   347 ,   957 ,   2545    ,   1123    ,   16229   ,0 };
            const std::uint32_t dim1720Kuo2Init[]       =   {   1   ,   1   ,   5   ,   15  ,   1   ,   21  ,   101 ,   123 ,   341 ,   613 ,   451 ,   3731    ,   8031    ,   1611    ,0 };
            const std::uint32_t dim1721Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   27  ,   1   ,   53  ,   69  ,   509 ,   751 ,   407 ,   2777    ,   1319    ,   10897   ,0 };
            const std::uint32_t dim1722Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   7   ,   5   ,   127 ,   91  ,   17  ,   699 ,   1761    ,   2083    ,   4587    ,   10747   ,0 };
            const std::uint32_t dim1723Kuo2Init[]       =   {   1   ,   3   ,   5   ,   11  ,   1   ,   57  ,   107 ,   245 ,   89  ,   899 ,   1765    ,   3521    ,   4933    ,   721 ,0 };
            const std::uint32_t dim1724Kuo2Init[]       =   {   1   ,   1   ,   1   ,   1   ,   27  ,   49  ,   113 ,   201 ,   491 ,   921 ,   417 ,   3541    ,   5889    ,   8417    ,0 };
            const std::uint32_t dim1725Kuo2Init[]       =   {   1   ,   3   ,   5   ,   11  ,   1   ,   37  ,   5   ,   43  ,   337 ,   883 ,   1351    ,   351 ,   269 ,   5501    ,0 };
            const std::uint32_t dim1726Kuo2Init[]       =   {   1   ,   3   ,   5   ,   5   ,   9   ,   11  ,   127 ,   87  ,   463 ,   999 ,   635 ,   2355    ,   763 ,   11959   ,0 };
            const std::uint32_t dim1727Kuo2Init[]       =   {   1   ,   3   ,   1   ,   15  ,   25  ,   21  ,   111 ,   241 ,   31  ,   35  ,   1869    ,   2913    ,   5963    ,   9989    ,0 };
            const std::uint32_t dim1728Kuo2Init[]       =   {   1   ,   1   ,   7   ,   13  ,   23  ,   57  ,   7   ,   225 ,   115 ,   649 ,   395 ,   515 ,   5335    ,   10829   ,0 };
            const std::uint32_t dim1729Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   21  ,   21  ,   51  ,   1   ,   39  ,   927 ,   681 ,   1341    ,   7703    ,   631 ,0 };
            const std::uint32_t dim1730Kuo2Init[]       =   {   1   ,   1   ,   3   ,   13  ,   25  ,   35  ,   101 ,   215 ,   15  ,   207 ,   137 ,   409 ,   6239    ,   11609   ,0 };
            const std::uint32_t dim1731Kuo2Init[]       =   {   1   ,   3   ,   1   ,   15  ,   11  ,   47  ,   17  ,   131 ,   405 ,   633 ,   35  ,   3335    ,   821 ,   4681    ,0 };
            const std::uint32_t dim1732Kuo2Init[]       =   {   1   ,   1   ,   1   ,   9   ,   17  ,   17  ,   105 ,   81  ,   449 ,   421 ,   707 ,   1041    ,   3991    ,   2943    ,0 };
            const std::uint32_t dim1733Kuo2Init[]       =   {   1   ,   1   ,   1   ,   1   ,   29  ,   55  ,   43  ,   161 ,   449 ,   163 ,   1295    ,   2583    ,   1405    ,   14211   ,0 };
            const std::uint32_t dim1734Kuo2Init[]       =   {   1   ,   1   ,   1   ,   7   ,   15  ,   41  ,   125 ,   65  ,   347 ,   753 ,   1245    ,   2343    ,   733 ,   2269    ,0 };
            const std::uint32_t dim1735Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   15  ,   25  ,   107 ,   35  ,   369 ,   395 ,   939 ,   427 ,   5201    ,   15761   ,0 };
            const std::uint32_t dim1736Kuo2Init[]       =   {   1   ,   1   ,   3   ,   13  ,   29  ,   11  ,   9   ,   53  ,   393 ,   855 ,   483 ,   3773    ,   3491    ,   14857   ,0 };
            const std::uint32_t dim1737Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   25  ,   55  ,   25  ,   9   ,   161 ,   307 ,   1381    ,   2129    ,   1923    ,   8779    ,0 };
            const std::uint32_t dim1738Kuo2Init[]       =   {   1   ,   1   ,   5   ,   1   ,   5   ,   1   ,   99  ,   205 ,   207 ,   607 ,   639 ,   29  ,   8045    ,   7159    ,0 };
            const std::uint32_t dim1739Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   29  ,   55  ,   15  ,   133 ,   217 ,   425 ,   1331    ,   2337    ,   2209    ,   1839    ,0 };
            const std::uint32_t dim1740Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   25  ,   1   ,   47  ,   135 ,   433 ,   647 ,   1693    ,   3983    ,   975 ,   14725   ,0 };
            const std::uint32_t dim1741Kuo2Init[]       =   {   1   ,   3   ,   7   ,   13  ,   29  ,   41  ,   115 ,   227 ,   505 ,   17  ,   2041    ,   247 ,   7409    ,   12353   ,0 };
            const std::uint32_t dim1742Kuo2Init[]       =   {   1   ,   1   ,   1   ,   13  ,   19  ,   29  ,   25  ,   175 ,   189 ,   581 ,   877 ,   2775    ,   737 ,   223 ,0 };
            const std::uint32_t dim1743Kuo2Init[]       =   {   1   ,   3   ,   7   ,   11  ,   27  ,   61  ,   21  ,   209 ,   51  ,   653 ,   631 ,   3723    ,   7471    ,   11083   ,0 };
            const std::uint32_t dim1744Kuo2Init[]       =   {   1   ,   3   ,   1   ,   9   ,   9   ,   41  ,   33  ,   61  ,   97  ,   551 ,   1029    ,   663 ,   5373    ,   8443    ,0 };
            const std::uint32_t dim1745Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   9   ,   39  ,   85  ,   103 ,   95  ,   865 ,   269 ,   1243    ,   5709    ,   3969    ,0 };
            const std::uint32_t dim1746Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   9   ,   17  ,   75  ,   199 ,   3   ,   681 ,   1447    ,   1663    ,   7139    ,   10459   ,0 };
            const std::uint32_t dim1747Kuo2Init[]       =   {   1   ,   1   ,   1   ,   15  ,   3   ,   21  ,   99  ,   203 ,   161 ,   669 ,   611 ,   771 ,   7773    ,   6069    ,0 };
            const std::uint32_t dim1748Kuo2Init[]       =   {   1   ,   3   ,   3   ,   3   ,   17  ,   13  ,   111 ,   93  ,   35  ,   119 ,   113 ,   1169    ,   4891    ,   7753    ,0 };
            const std::uint32_t dim1749Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   17  ,   7   ,   91  ,   39  ,   293 ,   443 ,   1819    ,   275 ,   7699    ,   8043    ,0 };
            const std::uint32_t dim1750Kuo2Init[]       =   {   1   ,   1   ,   3   ,   13  ,   21  ,   37  ,   93  ,   165 ,   281 ,   515 ,   1913    ,   839 ,   2177    ,   4907    ,0 };
            const std::uint32_t dim1751Kuo2Init[]       =   {   1   ,   3   ,   5   ,   11  ,   17  ,   23  ,   59  ,   161 ,   99  ,   371 ,   1223    ,   2815    ,   4019    ,   9225    ,0 };
            const std::uint32_t dim1752Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   31  ,   31  ,   31  ,   111 ,   441 ,   585 ,   393 ,   1665    ,   1421    ,   7305    ,0 };
            const std::uint32_t dim1753Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   19  ,   29  ,   81  ,   71  ,   223 ,   759 ,   2035    ,   1027    ,   2725    ,   4869    ,0 };
            const std::uint32_t dim1754Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   19  ,   13  ,   33  ,   139 ,   457 ,   321 ,   793 ,   2043    ,   4823    ,   10819   ,0 };
            const std::uint32_t dim1755Kuo2Init[]       =   {   1   ,   3   ,   3   ,   5   ,   27  ,   9   ,   93  ,   141 ,   269 ,   177 ,   545 ,   1977    ,   1049    ,   8445    ,0 };
            const std::uint32_t dim1756Kuo2Init[]       =   {   1   ,   1   ,   7   ,   3   ,   3   ,   25  ,   11  ,   75  ,   241 ,   641 ,   523 ,   2255    ,   6649    ,   2191    ,0 };
            const std::uint32_t dim1757Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   31  ,   31  ,   109 ,   235 ,   345 ,   291 ,   127 ,   2015    ,   7745    ,   4527    ,0 };
            const std::uint32_t dim1758Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   3   ,   55  ,   107 ,   51  ,   145 ,   545 ,   1601    ,   1973    ,   4083    ,   3297    ,0 };
            const std::uint32_t dim1759Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   21  ,   29  ,   31  ,   147 ,   245 ,   229 ,   1387    ,   2763    ,   769 ,   513 ,0 };
            const std::uint32_t dim1760Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   3   ,   41  ,   119 ,   61  ,   401 ,   361 ,   443 ,   3663    ,   3691    ,   1851    ,0 };
            const std::uint32_t dim1761Kuo2Init[]       =   {   1   ,   3   ,   5   ,   5   ,   17  ,   7   ,   55  ,   159 ,   121 ,   841 ,   913 ,   3507    ,   5989    ,   15807   ,0 };
            const std::uint32_t dim1762Kuo2Init[]       =   {   1   ,   1   ,   3   ,   13  ,   5   ,   39  ,   65  ,   3   ,   261 ,   159 ,   439 ,   739 ,   6899    ,   61  ,0 };
            const std::uint32_t dim1763Kuo2Init[]       =   {   1   ,   1   ,   5   ,   13  ,   13  ,   43  ,   111 ,   17  ,   1   ,   503 ,   587 ,   1943    ,   7773    ,   14015   ,0 };
            const std::uint32_t dim1764Kuo2Init[]       =   {   1   ,   3   ,   1   ,   1   ,   5   ,   43  ,   55  ,   7   ,   171 ,   637 ,   39  ,   2341    ,   3027    ,   8521    ,0 };
            const std::uint32_t dim1765Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   15  ,   49  ,   103 ,   157 ,   187 ,   773 ,   1391    ,   21  ,   5909    ,   14537   ,0 };
            const std::uint32_t dim1766Kuo2Init[]       =   {   1   ,   1   ,   5   ,   13  ,   1   ,   29  ,   63  ,   249 ,   473 ,   351 ,   705 ,   1999    ,   4135    ,   9683    ,0 };
            const std::uint32_t dim1767Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   5   ,   7   ,   77  ,   179 ,   347 ,   101 ,   1055    ,   549 ,   297 ,   3195    ,0 };
            const std::uint32_t dim1768Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   19  ,   51  ,   15  ,   247 ,   269 ,   545 ,   43  ,   2647    ,   1245    ,   6051    ,0 };
            const std::uint32_t dim1769Kuo2Init[]       =   {   1   ,   1   ,   5   ,   1   ,   9   ,   19  ,   45  ,   81  ,   145 ,   369 ,   1505    ,   1973    ,   3203    ,   10947   ,0 };
            const std::uint32_t dim1770Kuo2Init[]       =   {   1   ,   3   ,   5   ,   3   ,   11  ,   51  ,   113 ,   173 ,   121 ,   923 ,   969 ,   4005    ,   247 ,   1729    ,0 };
            const std::uint32_t dim1771Kuo2Init[]       =   {   1   ,   1   ,   7   ,   13  ,   1   ,   51  ,   111 ,   125 ,   163 ,   307 ,   1183    ,   1865    ,   2517    ,   9017    ,0 };
            const std::uint32_t dim1772Kuo2Init[]       =   {   1   ,   1   ,   5   ,   13  ,   7   ,   9   ,   115 ,   191 ,   53  ,   891 ,   1703    ,   2507    ,   3103    ,   12511   ,0 };
            const std::uint32_t dim1773Kuo2Init[]       =   {   1   ,   1   ,   3   ,   11  ,   9   ,   19  ,   3   ,   213 ,   421 ,   299 ,   1341    ,   3313    ,   637 ,   4977    ,0 };
            const std::uint32_t dim1774Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   21  ,   7   ,   89  ,   185 ,   337 ,   105 ,   415 ,   375 ,   4357    ,   16305   ,0 };
            const std::uint32_t dim1775Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   23  ,   25  ,   55  ,   19  ,   253 ,   879 ,   1779    ,   2451    ,   3485    ,   3383    ,0 };
            const std::uint32_t dim1776Kuo2Init[]       =   {   1   ,   3   ,   7   ,   7   ,   25  ,   33  ,   77  ,   67  ,   211 ,   571 ,   2029    ,   161 ,   3747    ,   11275   ,0 };
            const std::uint32_t dim1777Kuo2Init[]       =   {   1   ,   1   ,   3   ,   3   ,   15  ,   33  ,   55  ,   121 ,   97  ,   5   ,   907 ,   1869    ,   8171    ,   1553    ,0 };
            const std::uint32_t dim1778Kuo2Init[]       =   {   1   ,   1   ,   1   ,   9   ,   3   ,   33  ,   21  ,   165 ,   181 ,   211 ,   437 ,   1887    ,   895 ,   11549   ,0 };
            const std::uint32_t dim1779Kuo2Init[]       =   {   1   ,   3   ,   5   ,   3   ,   5   ,   7   ,   103 ,   95  ,   477 ,   585 ,   1307    ,   1017    ,   4115    ,   6011    ,0 };
            const std::uint32_t dim1780Kuo2Init[]       =   {   1   ,   1   ,   3   ,   11  ,   25  ,   45  ,   67  ,   239 ,   171 ,   869 ,   285 ,   2495    ,   4091    ,   15037   ,0 };
            const std::uint32_t dim1781Kuo2Init[]       =   {   1   ,   1   ,   3   ,   13  ,   5   ,   41  ,   103 ,   17  ,   283 ,   833 ,   179 ,   1183    ,   3323    ,   9777    ,0 };
            const std::uint32_t dim1782Kuo2Init[]       =   {   1   ,   3   ,   3   ,   5   ,   13  ,   29  ,   111 ,   37  ,   245 ,   329 ,   677 ,   4039    ,   2533    ,   3759    ,0 };
            const std::uint32_t dim1783Kuo2Init[]       =   {   1   ,   1   ,   7   ,   15  ,   23  ,   63  ,   115 ,   243 ,   347 ,   869 ,   587 ,   3073    ,   7727    ,   399 ,0 };
            const std::uint32_t dim1784Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   5   ,   57  ,   49  ,   39  ,   463 ,   417 ,   1183    ,   1007    ,   3823    ,   15299   ,0 };
            const std::uint32_t dim1785Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   23  ,   41  ,   65  ,   207 ,   151 ,   919 ,   1495    ,   2841    ,   1453    ,   6273    ,0 };
            const std::uint32_t dim1786Kuo2Init[]       =   {   1   ,   1   ,   1   ,   1   ,   15  ,   19  ,   51  ,   193 ,   187 ,   711 ,   11  ,   1291    ,   143 ,   15375   ,0 };
            const std::uint32_t dim1787Kuo2Init[]       =   {   1   ,   1   ,   3   ,   13  ,   25  ,   19  ,   3   ,   113 ,   157 ,   699 ,   1699    ,   1793    ,   29  ,   1869    ,0 };
            const std::uint32_t dim1788Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   7   ,   37  ,   25  ,   73  ,   353 ,   443 ,   1517    ,   2621    ,   489 ,   15411   ,0 };
            const std::uint32_t dim1789Kuo2Init[]       =   {   1   ,   1   ,   1   ,   1   ,   7   ,   9   ,   91  ,   67  ,   471 ,   395 ,   1417    ,   431 ,   4793    ,   9517    ,0 };
            const std::uint32_t dim1790Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   31  ,   15  ,   63  ,   67  ,   109 ,   537 ,   1543    ,   1021    ,   2549    ,   13587   ,0 };
            const std::uint32_t dim1791Kuo2Init[]       =   {   1   ,   1   ,   1   ,   3   ,   7   ,   63  ,   127 ,   141 ,   23  ,   281 ,   523 ,   283 ,   347 ,   2095    ,0 };
            const std::uint32_t dim1792Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   21  ,   21  ,   71  ,   97  ,   357 ,   887 ,   1785    ,   3471    ,   3187    ,   12163   ,0 };
            const std::uint32_t dim1793Kuo2Init[]       =   {   1   ,   3   ,   3   ,   3   ,   25  ,   23  ,   127 ,   135 ,   199 ,   661 ,   7   ,   3279    ,   91  ,   11879   ,0 };
            const std::uint32_t dim1794Kuo2Init[]       =   {   1   ,   1   ,   7   ,   5   ,   29  ,   51  ,   41  ,   5   ,   387 ,   901 ,   233 ,   1559    ,   511 ,   7735    ,0 };
            const std::uint32_t dim1795Kuo2Init[]       =   {   1   ,   1   ,   5   ,   9   ,   3   ,   13  ,   45  ,   119 ,   177 ,   381 ,   1363    ,   3627    ,   259 ,   771 ,0 };
            const std::uint32_t dim1796Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   5   ,   31  ,   73  ,   151 ,   487 ,   371 ,   1543    ,   1183    ,   697 ,   10225   ,0 };
            const std::uint32_t dim1797Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   29  ,   39  ,   125 ,   245 ,   373 ,   43  ,   583 ,   233 ,   5799    ,   7865    ,0 };
            const std::uint32_t dim1798Kuo2Init[]       =   {   1   ,   1   ,   7   ,   13  ,   17  ,   41  ,   47  ,   7   ,   161 ,   717 ,   947 ,   2421    ,   1983    ,   12963   ,0 };
            const std::uint32_t dim1799Kuo2Init[]       =   {   1   ,   3   ,   3   ,   3   ,   31  ,   19  ,   11  ,   131 ,   217 ,   533 ,   1407    ,   421 ,   163 ,   5849    ,0 };
            const std::uint32_t dim1800Kuo2Init[]       =   {   1   ,   1   ,   3   ,   13  ,   31  ,   49  ,   77  ,   33  ,   335 ,   627 ,   1135    ,   4021    ,   6609    ,   819 ,0 };
            const std::uint32_t dim1801Kuo2Init[]       =   {   1   ,   3   ,   5   ,   5   ,   17  ,   51  ,   27  ,   83  ,   153 ,   469 ,   85  ,   2725    ,   4297    ,   8869    ,0 };
            const std::uint32_t dim1802Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   29  ,   7   ,   93  ,   53  ,   251 ,   579 ,   1243    ,   2689    ,   4655    ,   9247    ,0 };
            const std::uint32_t dim1803Kuo2Init[]       =   {   1   ,   3   ,   1   ,   13  ,   9   ,   35  ,   59  ,   213 ,   181 ,   409 ,   1177    ,   3783    ,   6339    ,   339 ,0 };
            const std::uint32_t dim1804Kuo2Init[]       =   {   1   ,   1   ,   1   ,   7   ,   25  ,   55  ,   111 ,   133 ,   481 ,   757 ,   1683    ,   2193    ,   681 ,   12141   ,0 };
            const std::uint32_t dim1805Kuo2Init[]       =   {   1   ,   1   ,   3   ,   13  ,   11  ,   1   ,   57  ,   137 ,   359 ,   325 ,   67  ,   3069    ,   1125    ,   8305    ,0 };
            const std::uint32_t dim1806Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   21  ,   11  ,   79  ,   195 ,   335 ,   85  ,   1749    ,   1859    ,   4253    ,   6391    ,0 };
            const std::uint32_t dim1807Kuo2Init[]       =   {   1   ,   1   ,   3   ,   13  ,   17  ,   55  ,   23  ,   119 ,   159 ,   843 ,   1677    ,   1725    ,   1139    ,   2051    ,0 };
            const std::uint32_t dim1808Kuo2Init[]       =   {   1   ,   3   ,   1   ,   11  ,   31  ,   35  ,   11  ,   49  ,   497 ,   807 ,   191 ,   3889    ,   7811    ,   13217   ,0 };
            const std::uint32_t dim1809Kuo2Init[]       =   {   1   ,   3   ,   1   ,   9   ,   29  ,   63  ,   117 ,   161 ,   191 ,   371 ,   245 ,   219 ,   1559    ,   13303   ,0 };
            const std::uint32_t dim1810Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   5   ,   19  ,   37  ,   231 ,   381 ,   323 ,   233 ,   3973    ,   6531    ,   8807    ,0 };
            const std::uint32_t dim1811Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   3   ,   43  ,   35  ,   103 ,   291 ,   363 ,   531 ,   1129    ,   3321    ,   3167    ,0 };
            const std::uint32_t dim1812Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   25  ,   9   ,   47  ,   139 ,   143 ,   155 ,   2005    ,   1573    ,   2007    ,   6483    ,0 };
            const std::uint32_t dim1813Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   25  ,   3   ,   125 ,   19  ,   255 ,   699 ,   1651    ,   1449    ,   3753    ,   12873   ,0 };
            const std::uint32_t dim1814Kuo2Init[]       =   {   1   ,   1   ,   7   ,   5   ,   7   ,   7   ,   63  ,   31  ,   255 ,   991 ,   1029    ,   1635    ,   4941    ,   7891    ,0 };
            const std::uint32_t dim1815Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   3   ,   13  ,   59  ,   73  ,   429 ,   931 ,   53  ,   711 ,   3305    ,   7621    ,0 };
            const std::uint32_t dim1816Kuo2Init[]       =   {   1   ,   3   ,   3   ,   5   ,   15  ,   55  ,   103 ,   159 ,   185 ,   365 ,   1283    ,   1171    ,   6659    ,   2547    ,0 };
            const std::uint32_t dim1817Kuo2Init[]       =   {   1   ,   1   ,   5   ,   5   ,   25  ,   33  ,   91  ,   87  ,   323 ,   235 ,   1997    ,   1397    ,   6777    ,   10065   ,0 };
            const std::uint32_t dim1818Kuo2Init[]       =   {   1   ,   3   ,   1   ,   1   ,   7   ,   35  ,   19  ,   5   ,   327 ,   163 ,   651 ,   215 ,   7965    ,   1143    ,0 };
            const std::uint32_t dim1819Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   7   ,   13  ,   69  ,   129 ,   277 ,   665 ,   1763    ,   33  ,   8145    ,   7131    ,0 };
            const std::uint32_t dim1820Kuo2Init[]       =   {   1   ,   3   ,   3   ,   13  ,   17  ,   25  ,   111 ,   247 ,   91  ,   537 ,   325 ,   2627    ,   1777    ,   2861    ,0 };
            const std::uint32_t dim1821Kuo2Init[]       =   {   1   ,   3   ,   3   ,   3   ,   29  ,   15  ,   87  ,   41  ,   103 ,   957 ,   105 ,   757 ,   2635    ,   4825    ,0 };
            const std::uint32_t dim1822Kuo2Init[]       =   {   1   ,   1   ,   3   ,   11  ,   21  ,   43  ,   73  ,   143 ,   31  ,   913 ,   1579    ,   1725    ,   6679    ,   2491    ,0 };
            const std::uint32_t dim1823Kuo2Init[]       =   {   1   ,   3   ,   1   ,   11  ,   1   ,   31  ,   93  ,   231 ,   327 ,   177 ,   921 ,   2715    ,   8015    ,   3295    ,0 };
            const std::uint32_t dim1824Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   5   ,   47  ,   59  ,   1   ,   105 ,   991 ,   1581    ,   115 ,   1957    ,   10753   ,0 };
            const std::uint32_t dim1825Kuo2Init[]       =   {   1   ,   3   ,   7   ,   9   ,   13  ,   31  ,   65  ,   241 ,   353 ,   613 ,   1065    ,   1201    ,   7267    ,   2099    ,0 };
            const std::uint32_t dim1826Kuo2Init[]       =   {   1   ,   3   ,   7   ,   11  ,   5   ,   55  ,   121 ,   45  ,   279 ,   765 ,   1263    ,   993 ,   5047    ,   12059   ,0 };
            const std::uint32_t dim1827Kuo2Init[]       =   {   1   ,   1   ,   7   ,   3   ,   25  ,   27  ,   13  ,   123 ,   357 ,   339 ,   1299    ,   297 ,   361 ,   4951    ,0 };
            const std::uint32_t dim1828Kuo2Init[]       =   {   1   ,   3   ,   5   ,   3   ,   13  ,   43  ,   117 ,   237 ,   3   ,   463 ,   911 ,   3447    ,   7463    ,   5985    ,0 };
            const std::uint32_t dim1829Kuo2Init[]       =   {   1   ,   3   ,   1   ,   15  ,   13  ,   1   ,   21  ,   213 ,   115 ,   291 ,   1317    ,   2201    ,   7939    ,   16135   ,0 };
            const std::uint32_t dim1830Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   13  ,   15  ,   55  ,   51  ,   203 ,   277 ,   71  ,   1025    ,   4237    ,   301 ,0 };
            const std::uint32_t dim1831Kuo2Init[]       =   {   1   ,   1   ,   5   ,   5   ,   17  ,   31  ,   95  ,   25  ,   7   ,   519 ,   1971    ,   3069    ,   1937    ,   5693    ,0 };
            const std::uint32_t dim1832Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   11  ,   17  ,   31  ,   111 ,   219 ,   199 ,   303 ,   2527    ,   4185    ,   13185   ,0 };
            const std::uint32_t dim1833Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   11  ,   17  ,   105 ,   147 ,   51  ,   885 ,   675 ,   3035    ,   4245    ,   3257    ,0 };
            const std::uint32_t dim1834Kuo2Init[]       =   {   1   ,   3   ,   3   ,   5   ,   9   ,   17  ,   37  ,   139 ,   251 ,   85  ,   361 ,   2569    ,   2727    ,   14111   ,0 };
            const std::uint32_t dim1835Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   31  ,   5   ,   101 ,   1   ,   475 ,   645 ,   1515    ,   2713    ,   2771    ,   2981    ,0 };
            const std::uint32_t dim1836Kuo2Init[]       =   {   1   ,   3   ,   3   ,   13  ,   21  ,   21  ,   31  ,   117 ,   511 ,   525 ,   1105    ,   2881    ,   6361    ,   6991    ,0 };
            const std::uint32_t dim1837Kuo2Init[]       =   {   1   ,   1   ,   5   ,   5   ,   15  ,   5   ,   47  ,   11  ,   391 ,   239 ,   65  ,   1545    ,   691 ,   3973    ,0 };
            const std::uint32_t dim1838Kuo2Init[]       =   {   1   ,   3   ,   1   ,   1   ,   9   ,   3   ,   91  ,   49  ,   505 ,   353 ,   1593    ,   4009    ,   2535    ,   4947    ,0 };
            const std::uint32_t dim1839Kuo2Init[]       =   {   1   ,   3   ,   1   ,   13  ,   15  ,   27  ,   45  ,   255 ,   503 ,   487 ,   613 ,   3453    ,   655 ,   10083   ,0 };
            const std::uint32_t dim1840Kuo2Init[]       =   {   1   ,   1   ,   1   ,   9   ,   23  ,   17  ,   39  ,   219 ,   281 ,   669 ,   867 ,   773 ,   2555    ,   12565   ,0 };
            const std::uint32_t dim1841Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   21  ,   29  ,   61  ,   85  ,   441 ,   273 ,   1889    ,   1441    ,   6291    ,   2599    ,0 };
            const std::uint32_t dim1842Kuo2Init[]       =   {   1   ,   1   ,   1   ,   7   ,   1   ,   7   ,   95  ,   9   ,   105 ,   77  ,   463 ,   701 ,   6001    ,   13491   ,0 };
            const std::uint32_t dim1843Kuo2Init[]       =   {   1   ,   3   ,   7   ,   3   ,   29  ,   57  ,   61  ,   123 ,   105 ,   909 ,   1925    ,   1255    ,   7069    ,   3049    ,0 };
            const std::uint32_t dim1844Kuo2Init[]       =   {   1   ,   1   ,   3   ,   11  ,   15  ,   37  ,   23  ,   25  ,   359 ,   743 ,   1599    ,   575 ,   4095    ,   11539   ,0 };
            const std::uint32_t dim1845Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   17  ,   33  ,   59  ,   245 ,   119 ,   457 ,   147 ,   1027    ,   4051    ,   507 ,0 };
            const std::uint32_t dim1846Kuo2Init[]       =   {   1   ,   3   ,   1   ,   11  ,   25  ,   59  ,   97  ,   37  ,   199 ,   247 ,   985 ,   635 ,   3501    ,   11213   ,0 };
            const std::uint32_t dim1847Kuo2Init[]       =   {   1   ,   1   ,   5   ,   7   ,   21  ,   19  ,   17  ,   181 ,   183 ,   331 ,   817 ,   1069    ,   3863    ,   7547    ,0 };
            const std::uint32_t dim1848Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   11  ,   25  ,   121 ,   127 ,   105 ,   57  ,   689 ,   701 ,   1527    ,   5301    ,0 };
            const std::uint32_t dim1849Kuo2Init[]       =   {   1   ,   1   ,   7   ,   3   ,   25  ,   59  ,   67  ,   103 ,   265 ,   649 ,   957 ,   3073    ,   3047    ,   12881   ,0 };
            const std::uint32_t dim1850Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   17  ,   15  ,   103 ,   37  ,   359 ,   665 ,   1677    ,   2563    ,   7079    ,   2577    ,0 };
            const std::uint32_t dim1851Kuo2Init[]       =   {   1   ,   1   ,   1   ,   13  ,   21  ,   43  ,   117 ,   187 ,   447 ,   711 ,   749 ,   643 ,   183 ,   13053   ,0 };
            const std::uint32_t dim1852Kuo2Init[]       =   {   1   ,   3   ,   7   ,   3   ,   15  ,   45  ,   23  ,   169 ,   481 ,   841 ,   625 ,   3241    ,   7739    ,   13463   ,0 };
            const std::uint32_t dim1853Kuo2Init[]       =   {   1   ,   3   ,   7   ,   9   ,   7   ,   11  ,   9   ,   73  ,   57  ,   595 ,   1981    ,   3499    ,   53  ,   3445    ,0 };
            const std::uint32_t dim1854Kuo2Init[]       =   {   1   ,   3   ,   3   ,   11  ,   17  ,   13  ,   61  ,   139 ,   445 ,   287 ,   705 ,   3157    ,   7503    ,   15279   ,0 };
            const std::uint32_t dim1855Kuo2Init[]       =   {   1   ,   3   ,   5   ,   5   ,   15  ,   5   ,   15  ,   117 ,   177 ,   517 ,   1907    ,   399 ,   1613    ,   9495    ,0 };
            const std::uint32_t dim1856Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   19  ,   37  ,   81  ,   179 ,   473 ,   477 ,   551 ,   1235    ,   6503    ,   14401   ,0 };
            const std::uint32_t dim1857Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   1   ,   21  ,   29  ,   181 ,   25  ,   349 ,   1915    ,   1047    ,   6645    ,   5153    ,0 };
            const std::uint32_t dim1858Kuo2Init[]       =   {   1   ,   3   ,   1   ,   11  ,   31  ,   31  ,   13  ,   165 ,   147 ,   995 ,   1767    ,   4013    ,   4993    ,   51  ,0 };
            const std::uint32_t dim1859Kuo2Init[]       =   {   1   ,   1   ,   3   ,   11  ,   19  ,   33  ,   47  ,   179 ,   465 ,   811 ,   1535    ,   2555    ,   1843    ,   10877   ,0 };
            const std::uint32_t dim1860Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   25  ,   13  ,   49  ,   105 ,   39  ,   893 ,   1729    ,   1297    ,   6071    ,   685 ,0 };
            const std::uint32_t dim1861Kuo2Init[]       =   {   1   ,   1   ,   3   ,   5   ,   3   ,   17  ,   69  ,   141 ,   83  ,   393 ,   1377    ,   3401    ,   1749    ,   10307   ,0 };
            const std::uint32_t dim1862Kuo2Init[]       =   {   1   ,   3   ,   7   ,   7   ,   5   ,   43  ,   27  ,   39  ,   61  ,   119 ,   829 ,   2105    ,   8155    ,   1647    ,0 };
            const std::uint32_t dim1863Kuo2Init[]       =   {   1   ,   1   ,   1   ,   3   ,   7   ,   61  ,   83  ,   253 ,   129 ,   459 ,   1241    ,   569 ,   7457    ,   3635    ,0 };
            const std::uint32_t dim1864Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   21  ,   17  ,   97  ,   213 ,   463 ,   549 ,   1219    ,   3685    ,   3721    ,   8659    ,0 };
            const std::uint32_t dim1865Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   19  ,   53  ,   45  ,   151 ,   15  ,   483 ,   1077    ,   1811    ,   4861    ,   9979    ,0 };
            const std::uint32_t dim1866Kuo2Init[]       =   {   1   ,   1   ,   5   ,   13  ,   7   ,   21  ,   11  ,   117 ,   267 ,   723 ,   573 ,   3335    ,   6331    ,   3255    ,0 };
            const std::uint32_t dim1867Kuo2Init[]       =   {   1   ,   3   ,   5   ,   3   ,   23  ,   17  ,   83  ,   171 ,   501 ,   249 ,   1937    ,   593 ,   3757    ,   6035    ,   30841   ,0 };
            const std::uint32_t dim1868Kuo2Init[]       =   {   1   ,   3   ,   7   ,   1   ,   13  ,   15  ,   19  ,   33  ,   191 ,   509 ,   1461    ,   2105    ,   2175    ,   10593   ,   27199   ,0 };
            const std::uint32_t dim1869Kuo2Init[]       =   {   1   ,   3   ,   3   ,   3   ,   9   ,   7   ,   7   ,   51  ,   199 ,   339 ,   393 ,   2543    ,   4269    ,   2447    ,   17671   ,0 };
            const std::uint32_t dim1870Kuo2Init[]       =   {   1   ,   3   ,   1   ,   1   ,   17  ,   3   ,   71  ,   119 ,   15  ,   333 ,   1313    ,   2609    ,   1077    ,   2493    ,   23109   ,0 };
            const std::uint32_t dim1871Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   7   ,   45  ,   69  ,   69  ,   241 ,   995 ,   1111    ,   2141    ,   5467    ,   5003    ,   11135   ,0 };
            const std::uint32_t dim1872Kuo2Init[]       =   {   1   ,   1   ,   7   ,   11  ,   21  ,   1   ,   25  ,   35  ,   445 ,   379 ,   449 ,   3703    ,   3281    ,   3433    ,   5207    ,0 };
            const std::uint32_t dim1873Kuo2Init[]       =   {   1   ,   3   ,   3   ,   5   ,   15  ,   49  ,   119 ,   11  ,   331 ,   681 ,   1209    ,   161 ,   7969    ,   11115   ,   4775    ,0 };
            const std::uint32_t dim1874Kuo2Init[]       =   {   1   ,   3   ,   7   ,   15  ,   1   ,   1   ,   61  ,   131 ,   141 ,   849 ,   2035    ,   125 ,   2457    ,   9209    ,   18411   ,0 };
            const std::uint32_t dim1875Kuo2Init[]       =   {   1   ,   1   ,   5   ,   5   ,   25  ,   17  ,   91  ,   255 ,   137 ,   815 ,   1803    ,   3521    ,   181 ,   15683   ,   32099   ,0 };
            const std::uint32_t dim1876Kuo2Init[]       =   {   1   ,   3   ,   1   ,   11  ,   29  ,   13  ,   91  ,   129 ,   167 ,   323 ,   823 ,   3717    ,   473 ,   7617    ,   5431    ,0 };
            const std::uint32_t dim1877Kuo2Init[]       =   {   1   ,   1   ,   5   ,   9   ,   17  ,   41  ,   65  ,   5   ,   57  ,   441 ,   765 ,   2761    ,   5033    ,   14551   ,   28223   ,0 };
            const std::uint32_t dim1878Kuo2Init[]       =   {   1   ,   3   ,   1   ,   1   ,   11  ,   11  ,   35  ,   109 ,   197 ,   349 ,   1495    ,   4057    ,   5255    ,   8327    ,   29281   ,0 };
            const std::uint32_t dim1879Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   27  ,   33  ,   7   ,   133 ,   439 ,   329 ,   655 ,   2459    ,   5369    ,   14681   ,   12271   ,0 };
            const std::uint32_t dim1880Kuo2Init[]       =   {   1   ,   1   ,   1   ,   13  ,   29  ,   11  ,   15  ,   71  ,   117 ,   849 ,   285 ,   3779    ,   1181    ,   6315    ,   23627   ,0 };
            const std::uint32_t dim1881Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   15  ,   33  ,   93  ,   133 ,   239 ,   169 ,   197 ,   3005    ,   1035    ,   6771    ,   10881   ,0 };
            const std::uint32_t dim1882Kuo2Init[]       =   {   1   ,   3   ,   3   ,   13  ,   29  ,   13  ,   69  ,   157 ,   275 ,   335 ,   1977    ,   461 ,   8087    ,   10027   ,   6377    ,0 };
            const std::uint32_t dim1883Kuo2Init[]       =   {   1   ,   3   ,   1   ,   15  ,   25  ,   23  ,   107 ,   125 ,   27  ,   455 ,   207 ,   3425    ,   5319    ,   4861    ,   4853    ,0 };
            const std::uint32_t dim1884Kuo2Init[]       =   {   1   ,   1   ,   5   ,   15  ,   17  ,   49  ,   3   ,   129 ,   401 ,   451 ,   363 ,   553 ,   3999    ,   8115    ,   25621   ,0 };
            const std::uint32_t dim1885Kuo2Init[]       =   {   1   ,   3   ,   3   ,   3   ,   9   ,   63  ,   71  ,   219 ,   331 ,   43  ,   1369    ,   3821    ,   5189    ,   8799    ,   19413   ,0 };
            const std::uint32_t dim1886Kuo2Init[]       =   {   1   ,   1   ,   3   ,   13  ,   31  ,   19  ,   57  ,   127 ,   229 ,   429 ,   535 ,   591 ,   1135    ,   12559   ,   4219    ,0 };
            const std::uint32_t dim1887Kuo2Init[]       =   {   1   ,   1   ,   7   ,   3   ,   11  ,   41  ,   49  ,   45  ,   423 ,   299 ,   571 ,   1907    ,   1755    ,   10813   ,   14199   ,0 };
            const std::uint32_t dim1888Kuo2Init[]       =   {   1   ,   3   ,   1   ,   1   ,   1   ,   41  ,   53  ,   139 ,   345 ,   521 ,   1051    ,   691 ,   7367    ,   923 ,   2171    ,0 };
            const std::uint32_t dim1889Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   23  ,   39  ,   21  ,   241 ,   433 ,   269 ,   1733    ,   3455    ,   8171    ,   585 ,   9035    ,0 };
            const std::uint32_t dim1890Kuo2Init[]       =   {   1   ,   1   ,   3   ,   3   ,   15  ,   31  ,   39  ,   75  ,   223 ,   827 ,   1799    ,   2699    ,   6927    ,   4251    ,   16799   ,0 };
            const std::uint32_t dim1891Kuo2Init[]       =   {   1   ,   1   ,   7   ,   11  ,   25  ,   17  ,   5   ,   199 ,   265 ,   953 ,   1609    ,   185 ,   5069    ,   10061   ,   31235   ,0 };
            const std::uint32_t dim1892Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   11  ,   17  ,   125 ,   149 ,   29  ,   149 ,   1241    ,   3975    ,   2915    ,   13847   ,   8245    ,0 };
            const std::uint32_t dim1893Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   19  ,   7   ,   115 ,   127 ,   325 ,   147 ,   505 ,   3199    ,   2261    ,   15309   ,   1925    ,0 };
            const std::uint32_t dim1894Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   19  ,   27  ,   45  ,   131 ,   35  ,   69  ,   275 ,   2895    ,   8131    ,   6311    ,   15507   ,0 };
            const std::uint32_t dim1895Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   5   ,   35  ,   115 ,   39  ,   343 ,   491 ,   199 ,   985 ,   7767    ,   13183   ,   23341   ,0 };
            const std::uint32_t dim1896Kuo2Init[]       =   {   1   ,   3   ,   3   ,   3   ,   17  ,   19  ,   125 ,   237 ,   393 ,   1   ,   1763    ,   2129    ,   2221    ,   4993    ,   23023   ,0 };
            const std::uint32_t dim1897Kuo2Init[]       =   {   1   ,   1   ,   5   ,   13  ,   1   ,   39  ,   53  ,   77  ,   43  ,   665 ,   173 ,   1923    ,   5071    ,   2713    ,   28507   ,0 };
            const std::uint32_t dim1898Kuo2Init[]       =   {   1   ,   1   ,   3   ,   5   ,   7   ,   57  ,   77  ,   19  ,   9   ,   441 ,   1941    ,   475 ,   4059    ,   3977    ,   25689   ,0 };
            const std::uint32_t dim1899Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   23  ,   49  ,   35  ,   139 ,   189 ,   431 ,   1077    ,   1057    ,   1565    ,   5597    ,   23755   ,0 };
            const std::uint32_t dim1900Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   7   ,   5   ,   121 ,   69  ,   277 ,   797 ,   1879    ,   3479    ,   3023    ,   1781    ,   31307   ,0 };
            const std::uint32_t dim1901Kuo2Init[]       =   {   1   ,   1   ,   5   ,   15  ,   5   ,   23  ,   75  ,   181 ,   97  ,   491 ,   399 ,   63  ,   3211    ,   7099    ,   14597   ,0 };
            const std::uint32_t dim1902Kuo2Init[]       =   {   1   ,   3   ,   1   ,   11  ,   9   ,   3   ,   85  ,   159 ,   143 ,   13  ,   599 ,   3685    ,   4291    ,   11457   ,   24571   ,0 };
            const std::uint32_t dim1903Kuo2Init[]       =   {   1   ,   3   ,   7   ,   9   ,   23  ,   45  ,   17  ,   197 ,   351 ,   997 ,   1789    ,   3965    ,   1163    ,   9027    ,   28843   ,0 };
            const std::uint32_t dim1904Kuo2Init[]       =   {   1   ,   1   ,   5   ,   15  ,   25  ,   13  ,   93  ,   141 ,   395 ,   905 ,   933 ,   3169    ,   7551    ,   1775    ,   22043   ,0 };
            const std::uint32_t dim1905Kuo2Init[]       =   {   1   ,   3   ,   3   ,   11  ,   17  ,   47  ,   115 ,   211 ,   157 ,   887 ,   1829    ,   767 ,   6821    ,   5243    ,   26423   ,0 };
            const std::uint32_t dim1906Kuo2Init[]       =   {   1   ,   1   ,   1   ,   1   ,   15  ,   33  ,   27  ,   239 ,   405 ,   5   ,   861 ,   1909    ,   1261    ,   1921    ,   32245   ,0 };
            const std::uint32_t dim1907Kuo2Init[]       =   {   1   ,   1   ,   1   ,   15  ,   5   ,   15  ,   21  ,   251 ,   489 ,   789 ,   507 ,   321 ,   6429    ,   1885    ,   23139   ,0 };
            const std::uint32_t dim1908Kuo2Init[]       =   {   1   ,   1   ,   1   ,   13  ,   19  ,   61  ,   59  ,   201 ,   69  ,   933 ,   83  ,   1657    ,   1331    ,   16183   ,   23085   ,0 };
            const std::uint32_t dim1909Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   29  ,   59  ,   61  ,   149 ,   95  ,   897 ,   1107    ,   2853    ,   5271    ,   7069    ,   3759    ,0 };
            const std::uint32_t dim1910Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   17  ,   53  ,   71  ,   183 ,   29  ,   353 ,   1621    ,   4015    ,   6395    ,   8737    ,   12507   ,0 };
            const std::uint32_t dim1911Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   23  ,   31  ,   77  ,   187 ,   429 ,   59  ,   117 ,   641 ,   1039    ,   15113   ,   1177    ,0 };
            const std::uint32_t dim1912Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   17  ,   9   ,   73  ,   37  ,   177 ,   901 ,   573 ,   2503    ,   5865    ,   13939   ,   10123   ,0 };
            const std::uint32_t dim1913Kuo2Init[]       =   {   1   ,   3   ,   1   ,   1   ,   7   ,   21  ,   55  ,   255 ,   85  ,   993 ,   583 ,   3345    ,   3211    ,   6027    ,   18677   ,0 };
            const std::uint32_t dim1914Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   27  ,   37  ,   111 ,   235 ,   281 ,   363 ,   121 ,   3749    ,   7381    ,   14959   ,   22997   ,0 };
            const std::uint32_t dim1915Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   13  ,   19  ,   47  ,   203 ,   157 ,   975 ,   1173    ,   1389    ,   1021    ,   6481    ,   547 ,0 };
            const std::uint32_t dim1916Kuo2Init[]       =   {   1   ,   3   ,   5   ,   11  ,   7   ,   51  ,   121 ,   99  ,   289 ,   303 ,   1759    ,   571 ,   3585    ,   2263    ,   21231   ,0 };
            const std::uint32_t dim1917Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   9   ,   7   ,   25  ,   39  ,   443 ,   635 ,   1597    ,   2095    ,   6739    ,   16367   ,   11285   ,0 };
            const std::uint32_t dim1918Kuo2Init[]       =   {   1   ,   1   ,   1   ,   9   ,   5   ,   47  ,   107 ,   223 ,   389 ,   25  ,   1353    ,   501 ,   8025    ,   7269    ,   23617   ,0 };
            const std::uint32_t dim1919Kuo2Init[]       =   {   1   ,   1   ,   5   ,   5   ,   23  ,   25  ,   59  ,   133 ,   387 ,   761 ,   835 ,   105 ,   45  ,   5469    ,   13461   ,0 };
            const std::uint32_t dim1920Kuo2Init[]       =   {   1   ,   1   ,   3   ,   11  ,   5   ,   33  ,   121 ,   149 ,   121 ,   881 ,   603 ,   3455    ,   7667    ,   3039    ,   8471    ,0 };
            const std::uint32_t dim1921Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   17  ,   41  ,   1   ,   109 ,   67  ,   511 ,   617 ,   1139    ,   7605    ,   12211   ,   8603    ,0 };
            const std::uint32_t dim1922Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   13  ,   27  ,   5   ,   163 ,   17  ,   889 ,   199 ,   77  ,   5233    ,   6383    ,   15787   ,0 };
            const std::uint32_t dim1923Kuo2Init[]       =   {   1   ,   1   ,   1   ,   13  ,   5   ,   27  ,   45  ,   47  ,   213 ,   473 ,   1101    ,   623 ,   6169    ,   3139    ,   27561   ,0 };
            const std::uint32_t dim1924Kuo2Init[]       =   {   1   ,   1   ,   3   ,   13  ,   15  ,   63  ,   79  ,   51  ,   47  ,   227 ,   1771    ,   3167    ,   2975    ,   16075   ,   9117    ,0 };
            const std::uint32_t dim1925Kuo2Init[]       =   {   1   ,   1   ,   5   ,   5   ,   29  ,   9   ,   87  ,   213 ,   349 ,   763 ,   1341    ,   1299    ,   1183    ,   4763    ,   14869   ,0 };
            const std::uint32_t dim1926Kuo2Init[]       =   {   1   ,   3   ,   7   ,   1   ,   23  ,   3   ,   37  ,   99  ,   341 ,   67  ,   1273    ,   3383    ,   7805    ,   8373    ,   19401   ,0 };
            const std::uint32_t dim1927Kuo2Init[]       =   {   1   ,   3   ,   3   ,   3   ,   7   ,   25  ,   23  ,   231 ,   291 ,   591 ,   291 ,   1077    ,   7291    ,   9763    ,   515 ,0 };
            const std::uint32_t dim1928Kuo2Init[]       =   {   1   ,   1   ,   1   ,   3   ,   9   ,   49  ,   99  ,   127 ,   501 ,   375 ,   995 ,   1883    ,   6229    ,   1141    ,   16513   ,0 };
            const std::uint32_t dim1929Kuo2Init[]       =   {   1   ,   1   ,   1   ,   13  ,   21  ,   35  ,   43  ,   39  ,   405 ,   283 ,   1555    ,   3189    ,   4999    ,   139 ,   11031   ,0 };
            const std::uint32_t dim1930Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   25  ,   3   ,   29  ,   89  ,   71  ,   975 ,   435 ,   2513    ,   4667    ,   14859   ,   22495   ,0 };
            const std::uint32_t dim1931Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   27  ,   45  ,   29  ,   145 ,   97  ,   149 ,   341 ,   3253    ,   5385    ,   8099    ,   169 ,0 };
            const std::uint32_t dim1932Kuo2Init[]       =   {   1   ,   1   ,   1   ,   3   ,   17  ,   49  ,   73  ,   31  ,   291 ,   191 ,   959 ,   3139    ,   6221    ,   423 ,   5247    ,0 };
            const std::uint32_t dim1933Kuo2Init[]       =   {   1   ,   3   ,   7   ,   3   ,   11  ,   23  ,   25  ,   65  ,   291 ,   877 ,   15  ,   437 ,   3883    ,   6545    ,   16327   ,0 };
            const std::uint32_t dim1934Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   21  ,   53  ,   35  ,   143 ,   433 ,   117 ,   1135    ,   467 ,   6825    ,   16041   ,   3351    ,0 };
            const std::uint32_t dim1935Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   11  ,   57  ,   105 ,   147 ,   443 ,   1   ,   1879    ,   2963    ,   4041    ,   8929    ,   219 ,0 };
            const std::uint32_t dim1936Kuo2Init[]       =   {   1   ,   3   ,   3   ,   11  ,   13  ,   59  ,   57  ,   175 ,   151 ,   1015    ,   629 ,   1549    ,   4161    ,   16147   ,   25857   ,0 };
            const std::uint32_t dim1937Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   15  ,   27  ,   19  ,   111 ,   495 ,   7   ,   1219    ,   2679    ,   3257    ,   7111    ,   23187   ,0 };
            const std::uint32_t dim1938Kuo2Init[]       =   {   1   ,   1   ,   1   ,   7   ,   5   ,   3   ,   37  ,   247 ,   43  ,   223 ,   1681    ,   225 ,   6573    ,   7523    ,   14433   ,0 };
            const std::uint32_t dim1939Kuo2Init[]       =   {   1   ,   1   ,   3   ,   3   ,   7   ,   31  ,   71  ,   141 ,   341 ,   319 ,   653 ,   3463    ,   963 ,   10133   ,   27313   ,0 };
            const std::uint32_t dim1940Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   3   ,   61  ,   71  ,   9   ,   253 ,   69  ,   527 ,   2927    ,   1637    ,   15141   ,   32423   ,0 };
            const std::uint32_t dim1941Kuo2Init[]       =   {   1   ,   3   ,   3   ,   3   ,   21  ,   41  ,   119 ,   175 ,   363 ,   629 ,   909 ,   439 ,   8043    ,   12489   ,   18635   ,0 };
            const std::uint32_t dim1942Kuo2Init[]       =   {   1   ,   1   ,   5   ,   3   ,   11  ,   19  ,   73  ,   87  ,   133 ,   947 ,   537 ,   803 ,   965 ,   9139    ,   7429    ,0 };
            const std::uint32_t dim1943Kuo2Init[]       =   {   1   ,   1   ,   7   ,   3   ,   9   ,   45  ,   113 ,   213 ,   499 ,   493 ,   811 ,   389 ,   5323    ,   409 ,   17147   ,0 };
            const std::uint32_t dim1944Kuo2Init[]       =   {   1   ,   3   ,   1   ,   1   ,   9   ,   29  ,   61  ,   231 ,   55  ,   625 ,   1917    ,   3157    ,   4635    ,   11441   ,   24799   ,0 };
            const std::uint32_t dim1945Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   15  ,   11  ,   93  ,   245 ,   247 ,   405 ,   1123    ,   2639    ,   1739    ,   11957   ,   19131   ,0 };
            const std::uint32_t dim1946Kuo2Init[]       =   {   1   ,   3   ,   5   ,   3   ,   19  ,   7   ,   47  ,   241 ,   97  ,   635 ,   1871    ,   2609    ,   5529    ,   11591   ,   13895   ,0 };
            const std::uint32_t dim1947Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   11  ,   45  ,   11  ,   13  ,   109 ,   141 ,   83  ,   2109    ,   3259    ,   7441    ,   25881   ,0 };
            const std::uint32_t dim1948Kuo2Init[]       =   {   1   ,   1   ,   7   ,   13  ,   21  ,   61  ,   73  ,   129 ,   393 ,   175 ,   699 ,   2551    ,   4761    ,   13133   ,   9993    ,0 };
            const std::uint32_t dim1949Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   31  ,   17  ,   85  ,   57  ,   457 ,   383 ,   1099    ,   1819    ,   503 ,   1389    ,   28341   ,0 };
            const std::uint32_t dim1950Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   3   ,   17  ,   41  ,   33  ,   245 ,   815 ,   31  ,   2259    ,   1293    ,   9051    ,   13241   ,0 };
            const std::uint32_t dim1951Kuo2Init[]       =   {   1   ,   3   ,   7   ,   7   ,   23  ,   15  ,   81  ,   77  ,   193 ,   201 ,   785 ,   1271    ,   3061    ,   4429    ,   26665   ,0 };
            const std::uint32_t dim1952Kuo2Init[]       =   {   1   ,   1   ,   5   ,   15  ,   29  ,   23  ,   43  ,   227 ,   119 ,   843 ,   55  ,   1837    ,   51  ,   13115   ,   27725   ,0 };
            const std::uint32_t dim1953Kuo2Init[]       =   {   1   ,   3   ,   1   ,   11  ,   1   ,   33  ,   25  ,   233 ,   43  ,   367 ,   705 ,   2323    ,   2721    ,   12845   ,   29415   ,0 };
            const std::uint32_t dim1954Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   25  ,   23  ,   5   ,   233 ,   507 ,   267 ,   607 ,   3009    ,   5035    ,   1069    ,   30735   ,0 };
            const std::uint32_t dim1955Kuo2Init[]       =   {   1   ,   1   ,   7   ,   5   ,   27  ,   5   ,   69  ,   5   ,   371 ,   951 ,   657 ,   421 ,   5707    ,   10455   ,   10961   ,0 };
            const std::uint32_t dim1956Kuo2Init[]       =   {   1   ,   1   ,   3   ,   11  ,   13  ,   13  ,   71  ,   113 ,   381 ,   619 ,   1713    ,   315 ,   7903    ,   4737    ,   24747   ,0 };
            const std::uint32_t dim1957Kuo2Init[]       =   {   1   ,   3   ,   5   ,   11  ,   15  ,   21  ,   39  ,   221 ,   9   ,   263 ,   1697    ,   3189    ,   7095    ,   7769    ,   10915   ,0 };
            const std::uint32_t dim1958Kuo2Init[]       =   {   1   ,   1   ,   1   ,   1   ,   17  ,   47  ,   77  ,   27  ,   377 ,   79  ,   1245    ,   1233    ,   3761    ,   3667    ,   12785   ,0 };
            const std::uint32_t dim1959Kuo2Init[]       =   {   1   ,   1   ,   3   ,   13  ,   11  ,   9   ,   89  ,   57  ,   339 ,   845 ,   393 ,   1717    ,   3415    ,   5725    ,   28655   ,0 };
            const std::uint32_t dim1960Kuo2Init[]       =   {   1   ,   3   ,   7   ,   3   ,   11  ,   61  ,   89  ,   37  ,   59  ,   117 ,   883 ,   1911    ,   4513    ,   561 ,   31273   ,0 };
            const std::uint32_t dim1961Kuo2Init[]       =   {   1   ,   1   ,   1   ,   13  ,   21  ,   29  ,   9   ,   147 ,   109 ,   783 ,   1647    ,   2147    ,   7285    ,   4035    ,   8181    ,0 };
            const std::uint32_t dim1962Kuo2Init[]       =   {   1   ,   3   ,   1   ,   13  ,   29  ,   15  ,   95  ,   71  ,   319 ,   489 ,   601 ,   1731    ,   7927    ,   9115    ,   32607   ,0 };
            const std::uint32_t dim1963Kuo2Init[]       =   {   1   ,   1   ,   3   ,   13  ,   1   ,   59  ,   53  ,   193 ,   105 ,   653 ,   249 ,   3285    ,   7817    ,   4157    ,   13299   ,0 };
            const std::uint32_t dim1964Kuo2Init[]       =   {   1   ,   1   ,   7   ,   15  ,   5   ,   63  ,   5   ,   111 ,   427 ,   781 ,   1077    ,   1267    ,   7253    ,   4883    ,   24539   ,0 };
            const std::uint32_t dim1965Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   15  ,   13  ,   97  ,   187 ,   175 ,   617 ,   931 ,   3675    ,   8085    ,   14433   ,   22179   ,0 };
            const std::uint32_t dim1966Kuo2Init[]       =   {   1   ,   3   ,   3   ,   13  ,   29  ,   29  ,   7   ,   45  ,   295 ,   185 ,   15  ,   3171    ,   5701    ,   11099   ,   8663    ,0 };
            const std::uint32_t dim1967Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   21  ,   47  ,   37  ,   189 ,   447 ,   123 ,   1979    ,   3633    ,   4875    ,   12667   ,   2349    ,0 };
            const std::uint32_t dim1968Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   17  ,   37  ,   97  ,   167 ,   207 ,   347 ,   499 ,   129 ,   3131    ,   6649    ,   10051   ,0 };
            const std::uint32_t dim1969Kuo2Init[]       =   {   1   ,   3   ,   7   ,   13  ,   21  ,   21  ,   15  ,   125 ,   405 ,   175 ,   89  ,   3299    ,   1321    ,   15595   ,   26015   ,0 };
            const std::uint32_t dim1970Kuo2Init[]       =   {   1   ,   1   ,   5   ,   1   ,   25  ,   21  ,   11  ,   25  ,   351 ,   1011    ,   753 ,   1813    ,   2229    ,   9675    ,   10073   ,0 };
            const std::uint32_t dim1971Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   21  ,   49  ,   61  ,   241 ,   303 ,   833 ,   653 ,   259 ,   4397    ,   545 ,   24857   ,0 };
            const std::uint32_t dim1972Kuo2Init[]       =   {   1   ,   1   ,   5   ,   5   ,   27  ,   61  ,   99  ,   181 ,   415 ,   945 ,   763 ,   1207    ,   5413    ,   11447   ,   11117   ,0 };
            const std::uint32_t dim1973Kuo2Init[]       =   {   1   ,   1   ,   3   ,   3   ,   27  ,   11  ,   5   ,   197 ,   211 ,   971 ,   1991    ,   4007    ,   2337    ,   2683    ,   27371   ,0 };
            const std::uint32_t dim1974Kuo2Init[]       =   {   1   ,   1   ,   5   ,   3   ,   5   ,   39  ,   25  ,   59  ,   223 ,   117 ,   1543    ,   2527    ,   2673    ,   15411   ,   8769    ,0 };
            const std::uint32_t dim1975Kuo2Init[]       =   {   1   ,   3   ,   7   ,   11  ,   31  ,   7   ,   33  ,   7   ,   319 ,   679 ,   685 ,   953 ,   491 ,   251 ,   16333   ,0 };
            const std::uint32_t dim1976Kuo2Init[]       =   {   1   ,   1   ,   5   ,   5   ,   1   ,   15  ,   69  ,   87  ,   447 ,   363 ,   1883    ,   937 ,   2691    ,   14777   ,   19757   ,0 };
            const std::uint32_t dim1977Kuo2Init[]       =   {   1   ,   1   ,   1   ,   1   ,   11  ,   51  ,   21  ,   183 ,   143 ,   577 ,   819 ,   3693    ,   5421    ,   9105    ,   10465   ,0 };
            const std::uint32_t dim1978Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   7   ,   7   ,   25  ,   131 ,   63  ,   881 ,   931 ,   2039    ,   1371    ,   7479    ,   7009    ,0 };
            const std::uint32_t dim1979Kuo2Init[]       =   {   1   ,   1   ,   5   ,   5   ,   17  ,   37  ,   121 ,   101 ,   133 ,   829 ,   495 ,   1031    ,   6843    ,   13863   ,   6543    ,0 };
            const std::uint32_t dim1980Kuo2Init[]       =   {   1   ,   1   ,   1   ,   9   ,   5   ,   53  ,   15  ,   11  ,   215 ,   295 ,   1401    ,   1633    ,   395 ,   201 ,   18941   ,0 };
            const std::uint32_t dim1981Kuo2Init[]       =   {   1   ,   3   ,   7   ,   7   ,   21  ,   39  ,   107 ,   153 ,   139 ,   557 ,   683 ,   1993    ,   3495    ,   9929    ,   12067   ,0 };
            const std::uint32_t dim1982Kuo2Init[]       =   {   1   ,   3   ,   3   ,   13  ,   27  ,   57  ,   63  ,   151 ,   13  ,   827 ,   1079    ,   1209    ,   5631    ,   9627    ,   4765    ,0 };
            const std::uint32_t dim1983Kuo2Init[]       =   {   1   ,   1   ,   3   ,   13  ,   9   ,   9   ,   75  ,   209 ,   437 ,   475 ,   1905    ,   3021    ,   7097    ,   10637   ,   13301   ,0 };
            const std::uint32_t dim1984Kuo2Init[]       =   {   1   ,   1   ,   3   ,   1   ,   21  ,   43  ,   45  ,   7   ,   467 ,   825 ,   1189    ,   1525    ,   3295    ,   2575    ,   12071   ,0 };
            const std::uint32_t dim1985Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   25  ,   57  ,   23  ,   243 ,   79  ,   39  ,   881 ,   467 ,   4183    ,   13881   ,   26719   ,0 };
            const std::uint32_t dim1986Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   27  ,   41  ,   79  ,   223 ,   443 ,   489 ,   1531    ,   3671    ,   7905    ,   9593    ,   175 ,0 };
            const std::uint32_t dim1987Kuo2Init[]       =   {   1   ,   3   ,   3   ,   5   ,   1   ,   25  ,   89  ,   151 ,   165 ,   681 ,   1099    ,   665 ,   1209    ,   13617   ,   15259   ,0 };
            const std::uint32_t dim1988Kuo2Init[]       =   {   1   ,   3   ,   3   ,   3   ,   17  ,   25  ,   13  ,   85  ,   179 ,   335 ,   951 ,   4085    ,   3251    ,   15061   ,   14609   ,0 };
            const std::uint32_t dim1989Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   15  ,   25  ,   89  ,   135 ,   27  ,   323 ,   1143    ,   7   ,   3569    ,   6841    ,   9243    ,0 };
            const std::uint32_t dim1990Kuo2Init[]       =   {   1   ,   1   ,   7   ,   5   ,   13  ,   43  ,   83  ,   23  ,   477 ,   229 ,   1623    ,   2641    ,   1235    ,   681 ,   17379   ,0 };
            const std::uint32_t dim1991Kuo2Init[]       =   {   1   ,   3   ,   1   ,   13  ,   1   ,   17  ,   77  ,   125 ,   121 ,   253 ,   1329    ,   1081    ,   1191    ,   7477    ,   13441   ,0 };
            const std::uint32_t dim1992Kuo2Init[]       =   {   1   ,   1   ,   7   ,   15  ,   5   ,   61  ,   23  ,   251 ,   407 ,   373 ,   1399    ,   1907    ,   4145    ,   15997   ,   12069   ,0 };
            const std::uint32_t dim1993Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   9   ,   27  ,   85  ,   209 ,   21  ,   225 ,   745 ,   1405    ,   813 ,   1605    ,   17463   ,0 };
            const std::uint32_t dim1994Kuo2Init[]       =   {   1   ,   1   ,   7   ,   5   ,   19  ,   47  ,   111 ,   215 ,   335 ,   211 ,   1437    ,   425 ,   2325    ,   15761   ,   13937   ,0 };
            const std::uint32_t dim1995Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   31  ,   21  ,   113 ,   89  ,   369 ,   165 ,   1673    ,   3143    ,   6765    ,   13897   ,   15295   ,0 };
            const std::uint32_t dim1996Kuo2Init[]       =   {   1   ,   3   ,   1   ,   1   ,   23  ,   57  ,   97  ,   9   ,   219 ,   513 ,   1001    ,   1903    ,   6033    ,   4561    ,   8157    ,0 };
            const std::uint32_t dim1997Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   17  ,   59  ,   125 ,   93  ,   397 ,   277 ,   1273    ,   529 ,   3881    ,   3345    ,   32553   ,0 };
            const std::uint32_t dim1998Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   29  ,   3   ,   73  ,   201 ,   129 ,   747 ,   1417    ,   77  ,   4399    ,   10283   ,   3677    ,0 };
            const std::uint32_t dim1999Kuo2Init[]       =   {   1   ,   3   ,   5   ,   11  ,   15  ,   13  ,   15  ,   193 ,   139 ,   683 ,   839 ,   1849    ,   1229    ,   7903    ,   15797   ,0 };
            const std::uint32_t dim2000Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   19  ,   37  ,   103 ,   173 ,   63  ,   269 ,   1125    ,   425 ,   1235    ,   4193    ,   10095   ,0 };
            const std::uint32_t dim2001Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   31  ,   33  ,   101 ,   71  ,   333 ,   565 ,   651 ,   1741    ,   3613    ,   2641    ,   27201   ,0 };
            const std::uint32_t dim2002Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   9   ,   43  ,   111 ,   231 ,   383 ,   221 ,   1239    ,   1927    ,   715 ,   7663    ,   24709   ,0 };
            const std::uint32_t dim2003Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   3   ,   41  ,   117 ,   129 ,   53  ,   527 ,   1973    ,   3377    ,   2803    ,   10855   ,   9405    ,0 };
            const std::uint32_t dim2004Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   15  ,   61  ,   29  ,   75  ,   141 ,   517 ,   255 ,   1797    ,   1291    ,   13859   ,   10255   ,0 };
            const std::uint32_t dim2005Kuo2Init[]       =   {   1   ,   1   ,   5   ,   9   ,   1   ,   55  ,   99  ,   133 ,   9   ,   793 ,   1525    ,   2565    ,   1755    ,   7293    ,   27221   ,0 };
            const std::uint32_t dim2006Kuo2Init[]       =   {   1   ,   3   ,   7   ,   1   ,   19  ,   25  ,   113 ,   47  ,   117 ,   285 ,   1937    ,   513 ,   75  ,   2149    ,   25369   ,0 };
            const std::uint32_t dim2007Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   3   ,   45  ,   1   ,   145 ,   501 ,   197 ,   423 ,   1131    ,   4649    ,   11027   ,   25237   ,0 };
            const std::uint32_t dim2008Kuo2Init[]       =   {   1   ,   1   ,   1   ,   9   ,   29  ,   49  ,   17  ,   85  ,   137 ,   765 ,   649 ,   809 ,   103 ,   7537    ,   5603    ,0 };
            const std::uint32_t dim2009Kuo2Init[]       =   {   1   ,   3   ,   1   ,   13  ,   23  ,   63  ,   85  ,   83  ,   135 ,   495 ,   2023    ,   2331    ,   1743    ,   16221   ,   2421    ,0 };
            const std::uint32_t dim2010Kuo2Init[]       =   {   1   ,   1   ,   1   ,   3   ,   25  ,   15  ,   75  ,   123 ,   309 ,   729 ,   481 ,   2335    ,   6963    ,   16309   ,   24593   ,0 };
            const std::uint32_t dim2011Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   1   ,   3   ,   41  ,   57  ,   353 ,   821 ,   1439    ,   3445    ,   2295    ,   15269   ,   15821   ,0 };
            const std::uint32_t dim2012Kuo2Init[]       =   {   1   ,   3   ,   7   ,   1   ,   19  ,   41  ,   107 ,   159 ,   361 ,   1017    ,   1435    ,   2593    ,   3849    ,   1139    ,   5059    ,0 };
            const std::uint32_t dim2013Kuo2Init[]       =   {   1   ,   1   ,   7   ,   5   ,   23  ,   63  ,   23  ,   67  ,   263 ,   939 ,   1167    ,   3367    ,   2003    ,   7903    ,   1361    ,0 };
            const std::uint32_t dim2014Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   11  ,   21  ,   109 ,   135 ,   219 ,   183 ,   1303    ,   2023    ,   6471    ,   8203    ,   21717   ,0 };
            const std::uint32_t dim2015Kuo2Init[]       =   {   1   ,   3   ,   3   ,   11  ,   11  ,   7   ,   109 ,   183 ,   313 ,   701 ,   1661    ,   2215    ,   7993    ,   6097    ,   15583   ,0 };
            const std::uint32_t dim2016Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   5   ,   55  ,   85  ,   123 ,   507 ,   303 ,   1701    ,   767 ,   313 ,   12517   ,   10969   ,0 };
            const std::uint32_t dim2017Kuo2Init[]       =   {   1   ,   3   ,   1   ,   15  ,   1   ,   31  ,   97  ,   249 ,   407 ,   829 ,   693 ,   135 ,   5929    ,   13287   ,   23105   ,0 };
            const std::uint32_t dim2018Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   23  ,   45  ,   13  ,   209 ,   365 ,   715 ,   827 ,   1451    ,   3817    ,   9039    ,   8601    ,0 };
            const std::uint32_t dim2019Kuo2Init[]       =   {   1   ,   1   ,   5   ,   3   ,   3   ,   5   ,   41  ,   175 ,   65  ,   467 ,   179 ,   1941    ,   2261    ,   14143   ,   10277   ,0 };
            const std::uint32_t dim2020Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   15  ,   61  ,   37  ,   231 ,   275 ,   69  ,   7   ,   417 ,   8131    ,   12569   ,   16275   ,0 };
            const std::uint32_t dim2021Kuo2Init[]       =   {   1   ,   1   ,   7   ,   11  ,   3   ,   49  ,   1   ,   243 ,   237 ,   303 ,   2033    ,   1501    ,   8059    ,   1479    ,   1675    ,0 };
            const std::uint32_t dim2022Kuo2Init[]       =   {   1   ,   1   ,   3   ,   5   ,   21  ,   49  ,   87  ,   5   ,   235 ,   343 ,   1635    ,   3459    ,   3961    ,   14433   ,   10965   ,0 };
            const std::uint32_t dim2023Kuo2Init[]       =   {   1   ,   1   ,   7   ,   13  ,   29  ,   5   ,   105 ,   167 ,   57  ,   247 ,   1683    ,   1011    ,   2071    ,   10681   ,   679 ,0 };
            const std::uint32_t dim2024Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   11  ,   31  ,   39  ,   19  ,   501 ,   945 ,   2043    ,   3591    ,   657 ,   8087    ,   21159   ,0 };
            const std::uint32_t dim2025Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   7   ,   23  ,   3   ,   5   ,   35  ,   101 ,   409 ,   3769    ,   7163    ,   739 ,   28421   ,0 };
            const std::uint32_t dim2026Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   23  ,   61  ,   65  ,   105 ,   303 ,   765 ,   1483    ,   883 ,   5743    ,   13479   ,   21489   ,0 };
            const std::uint32_t dim2027Kuo2Init[]       =   {   1   ,   1   ,   7   ,   13  ,   11  ,   5   ,   17  ,   237 ,   105 ,   539 ,   1237    ,   2727    ,   3781    ,   13195   ,   17029   ,0 };
            const std::uint32_t dim2028Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   15  ,   23  ,   47  ,   129 ,   485 ,   797 ,   705 ,   931 ,   3865    ,   5029    ,   27847   ,0 };
            const std::uint32_t dim2029Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   23  ,   61  ,   77  ,   221 ,   155 ,   429 ,   1933    ,   3007    ,   8001    ,   2137    ,   15737   ,0 };
            const std::uint32_t dim2030Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   3   ,   57  ,   79  ,   95  ,   419 ,   953 ,   449 ,   1843    ,   6893    ,   1061    ,   28427   ,0 };
            const std::uint32_t dim2031Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   19  ,   9   ,   39  ,   5   ,   189 ,   3   ,   181 ,   3091    ,   4215    ,   14881   ,   18273   ,0 };
            const std::uint32_t dim2032Kuo2Init[]       =   {   1   ,   1   ,   3   ,   13  ,   17  ,   63  ,   27  ,   49  ,   483 ,   947 ,   173 ,   3667    ,   3529    ,   15343   ,   23189   ,0 };
            const std::uint32_t dim2033Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   17  ,   51  ,   37  ,   245 ,   177 ,   231 ,   689 ,   29  ,   1029    ,   12397   ,   26265   ,0 };
            const std::uint32_t dim2034Kuo2Init[]       =   {   1   ,   3   ,   1   ,   13  ,   15  ,   35  ,   55  ,   5   ,   303 ,   559 ,   1853    ,   3859    ,   1879    ,   3167    ,   6903    ,0 };
            const std::uint32_t dim2035Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   9   ,   47  ,   59  ,   163 ,   373 ,   621 ,   1349    ,   2661    ,   1787    ,   13611   ,   28199   ,0 };
            const std::uint32_t dim2036Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   15  ,   55  ,   93  ,   193 ,   267 ,   325 ,   1705    ,   155 ,   3001    ,   407 ,   20829   ,0 };
            const std::uint32_t dim2037Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   13  ,   9   ,   65  ,   123 ,   325 ,   313 ,   25  ,   991 ,   2227    ,   6597    ,   30453   ,0 };
            const std::uint32_t dim2038Kuo2Init[]       =   {   1   ,   1   ,   5   ,   1   ,   23  ,   51  ,   61  ,   229 ,   27  ,   285 ,   1185    ,   1943    ,   7603    ,   10565   ,   22741   ,0 };
            const std::uint32_t dim2039Kuo2Init[]       =   {   1   ,   3   ,   7   ,   3   ,   17  ,   43  ,   21  ,   153 ,   359 ,   437 ,   1275    ,   3589    ,   1089    ,   3941    ,   16777   ,0 };
            const std::uint32_t dim2040Kuo2Init[]       =   {   1   ,   3   ,   5   ,   3   ,   19  ,   43  ,   127 ,   213 ,   181 ,   255 ,   929 ,   2553    ,   1101    ,   231 ,   2977    ,0 };
            const std::uint32_t dim2041Kuo2Init[]       =   {   1   ,   3   ,   7   ,   11  ,   7   ,   49  ,   39  ,   209 ,   141 ,   691 ,   1903    ,   1211    ,   687 ,   13107   ,   17055   ,0 };
            const std::uint32_t dim2042Kuo2Init[]       =   {   1   ,   1   ,   5   ,   1   ,   15  ,   21  ,   65  ,   209 ,   305 ,   65  ,   1383    ,   2247    ,   5813    ,   8961    ,   16281   ,0 };
            const std::uint32_t dim2043Kuo2Init[]       =   {   1   ,   3   ,   7   ,   11  ,   27  ,   1   ,   71  ,   97  ,   129 ,   317 ,   601 ,   981 ,   1947    ,   8897    ,   23489   ,0 };
            const std::uint32_t dim2044Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   17  ,   35  ,   57  ,   37  ,   243 ,   217 ,   703 ,   3159    ,   4791    ,   1365    ,   14885   ,0 };
            const std::uint32_t dim2045Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   7   ,   43  ,   59  ,   253 ,   141 ,   537 ,   547 ,   955 ,   5351    ,   13087   ,   5465    ,0 };
            const std::uint32_t dim2046Kuo2Init[]       =   {   1   ,   1   ,   5   ,   9   ,   15  ,   53  ,   47  ,   105 ,   55  ,   1017    ,   819 ,   3355    ,   3653    ,   11051   ,   29509   ,0 };
            const std::uint32_t dim2047Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   17  ,   39  ,   13  ,   125 ,   161 ,   985 ,   1753    ,   1327    ,   7635    ,   11045   ,   3935    ,0 };
            const std::uint32_t dim2048Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   1   ,   19  ,   55  ,   227 ,   111 ,   347 ,   85  ,   3871    ,   7153    ,   10527   ,   3137    ,0 };
            const std::uint32_t dim2049Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   13  ,   7   ,   35  ,   25  ,   17  ,   269 ,   611 ,   1523    ,   3539    ,   15611   ,   11837   ,0 };
            const std::uint32_t dim2050Kuo2Init[]       =   {   1   ,   1   ,   5   ,   7   ,   29  ,   13  ,   109 ,   253 ,   355 ,   25  ,   243 ,   1433    ,   7463    ,   10149   ,   31469   ,0 };
            const std::uint32_t dim2051Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   1   ,   51  ,   85  ,   27  ,   137 ,   299 ,   1943    ,   3805    ,   2661    ,   8091    ,   385 ,0 };
            const std::uint32_t dim2052Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   19  ,   39  ,   103 ,   89  ,   285 ,   305 ,   1157    ,   149 ,   6661    ,   1423    ,   27163   ,0 };
            const std::uint32_t dim2053Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   25  ,   35  ,   7   ,   227 ,   125 ,   811 ,   1867    ,   1851    ,   5271    ,   11405   ,   21457   ,0 };
            const std::uint32_t dim2054Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   31  ,   19  ,   103 ,   239 ,   301 ,   395 ,   1737    ,   3467    ,   7153    ,   12437   ,   25795   ,0 };
            const std::uint32_t dim2055Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   25  ,   43  ,   69  ,   155 ,   437 ,   9   ,   863 ,   2497    ,   6857    ,   3947    ,   12231   ,0 };
            const std::uint32_t dim2056Kuo2Init[]       =   {   1   ,   3   ,   7   ,   11  ,   3   ,   63  ,   27  ,   207 ,   87  ,   727 ,   791 ,   1663    ,   8121    ,   13149   ,   3927    ,0 };
            const std::uint32_t dim2057Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   9   ,   19  ,   123 ,   131 ,   415 ,   565 ,   1571    ,   1085    ,   2989    ,   13693   ,   32487   ,0 };
            const std::uint32_t dim2058Kuo2Init[]       =   {   1   ,   3   ,   7   ,   9   ,   11  ,   27  ,   117 ,   63  ,   255 ,   297 ,   1147    ,   1501    ,   3435    ,   5861    ,   21351   ,0 };
            const std::uint32_t dim2059Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   19  ,   5   ,   115 ,   89  ,   153 ,   705 ,   1233    ,   1803    ,   7237    ,   983 ,   9299    ,0 };
            const std::uint32_t dim2060Kuo2Init[]       =   {   1   ,   3   ,   3   ,   13  ,   21  ,   13  ,   89  ,   135 ,   5   ,   221 ,   191 ,   2611    ,   6007    ,   9177    ,   11101   ,0 };
            const std::uint32_t dim2061Kuo2Init[]       =   {   1   ,   3   ,   7   ,   15  ,   9   ,   43  ,   123 ,   123 ,   301 ,   233 ,   1727    ,   3973    ,   5241    ,   13437   ,   24507   ,0 };
            const std::uint32_t dim2062Kuo2Init[]       =   {   1   ,   3   ,   3   ,   5   ,   19  ,   29  ,   33  ,   127 ,   185 ,   319 ,   1767    ,   1133    ,   95  ,   7745    ,   32213   ,0 };
            const std::uint32_t dim2063Kuo2Init[]       =   {   1   ,   3   ,   7   ,   11  ,   13  ,   1   ,   91  ,   189 ,   75  ,   91  ,   583 ,   2317    ,   5257    ,   12133   ,   1951    ,0 };
            const std::uint32_t dim2064Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   23  ,   23  ,   65  ,   7   ,   157 ,   143 ,   781 ,   997 ,   2357    ,   4907    ,   16797   ,0 };
            const std::uint32_t dim2065Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   5   ,   43  ,   45  ,   131 ,   331 ,   253 ,   1975    ,   415 ,   2571    ,   14905   ,   9595    ,0 };
            const std::uint32_t dim2066Kuo2Init[]       =   {   1   ,   3   ,   7   ,   11  ,   1   ,   11  ,   95  ,   133 ,   393 ,   117 ,   833 ,   2661    ,   1683    ,   14333   ,   26279   ,0 };
            const std::uint32_t dim2067Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   23  ,   51  ,   57  ,   9   ,   63  ,   377 ,   2043    ,   1967    ,   7039    ,   13783   ,   16075   ,0 };
            const std::uint32_t dim2068Kuo2Init[]       =   {   1   ,   3   ,   5   ,   5   ,   13  ,   49  ,   65  ,   59  ,   449 ,   665 ,   2017    ,   375 ,   3781    ,   15139   ,   26341   ,0 };
            const std::uint32_t dim2069Kuo2Init[]       =   {   1   ,   1   ,   7   ,   13  ,   15  ,   63  ,   83  ,   229 ,   465 ,   319 ,   469 ,   951 ,   2405    ,   15357   ,   6051    ,0 };
            const std::uint32_t dim2070Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   15  ,   37  ,   97  ,   37  ,   89  ,   717 ,   449 ,   1821    ,   3319    ,   4957    ,   5455    ,0 };
            const std::uint32_t dim2071Kuo2Init[]       =   {   1   ,   1   ,   5   ,   3   ,   3   ,   7   ,   55  ,   39  ,   131 ,   497 ,   349 ,   4083    ,   6695    ,   14939   ,   13979   ,0 };
            const std::uint32_t dim2072Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   15  ,   45  ,   109 ,   239 ,   415 ,   453 ,   729 ,   835 ,   4585    ,   12751   ,   8595    ,0 };
            const std::uint32_t dim2073Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   29  ,   1   ,   13  ,   85  ,   185 ,   419 ,   1269    ,   981 ,   5079    ,   2723    ,   5275    ,0 };
            const std::uint32_t dim2074Kuo2Init[]       =   {   1   ,   1   ,   7   ,   11  ,   7   ,   41  ,   121 ,   75  ,   91  ,   943 ,   1487    ,   995 ,   6815    ,   15881   ,   27113   ,0 };
            const std::uint32_t dim2075Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   1   ,   53  ,   83  ,   209 ,   327 ,   547 ,   1505    ,   1517    ,   6105    ,   5903    ,   13823   ,0 };
            const std::uint32_t dim2076Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   25  ,   1   ,   33  ,   61  ,   249 ,   367 ,   1733    ,   3351    ,   273 ,   10053   ,   27115   ,0 };
            const std::uint32_t dim2077Kuo2Init[]       =   {   1   ,   3   ,   3   ,   11  ,   29  ,   27  ,   75  ,   143 ,   103 ,   509 ,   813 ,   1881    ,   2631    ,   933 ,   31141   ,0 };
            const std::uint32_t dim2078Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   31  ,   9   ,   27  ,   69  ,   291 ,   927 ,   183 ,   1755    ,   7383    ,   7721    ,   4405    ,0 };
            const std::uint32_t dim2079Kuo2Init[]       =   {   1   ,   3   ,   1   ,   11  ,   25  ,   23  ,   89  ,   99  ,   101 ,   725 ,   1791    ,   2669    ,   7055    ,   6703    ,   27507   ,0 };
            const std::uint32_t dim2080Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   1   ,   41  ,   23  ,   103 ,   123 ,   863 ,   1643    ,   947 ,   1349    ,   549 ,   29299   ,0 };
            const std::uint32_t dim2081Kuo2Init[]       =   {   1   ,   1   ,   3   ,   3   ,   9   ,   53  ,   67  ,   187 ,   203 ,   565 ,   1455    ,   645 ,   7983    ,   5311    ,   8827    ,0 };
            const std::uint32_t dim2082Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   11  ,   29  ,   35  ,   207 ,   449 ,   537 ,   245 ,   945 ,   4067    ,   10961   ,   27301   ,0 };
            const std::uint32_t dim2083Kuo2Init[]       =   {   1   ,   3   ,   1   ,   13  ,   3   ,   23  ,   15  ,   171 ,   439 ,   217 ,   1245    ,   3301    ,   289 ,   6895    ,   30095   ,0 };
            const std::uint32_t dim2084Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   21  ,   47  ,   71  ,   191 ,   425 ,   11  ,   1831    ,   3111    ,   7399    ,   13689   ,   28163   ,0 };
            const std::uint32_t dim2085Kuo2Init[]       =   {   1   ,   1   ,   5   ,   15  ,   5   ,   61  ,   97  ,   41  ,   451 ,   459 ,   1007    ,   2439    ,   5613    ,   7985    ,   9255    ,0 };
            const std::uint32_t dim2086Kuo2Init[]       =   {   1   ,   1   ,   1   ,   1   ,   9   ,   57  ,   61  ,   143 ,   3   ,   753 ,   1839    ,   2623    ,   5261    ,   6169    ,   13195   ,0 };
            const std::uint32_t dim2087Kuo2Init[]       =   {   1   ,   1   ,   1   ,   3   ,   19  ,   23  ,   15  ,   31  ,   481 ,   123 ,   653 ,   2763    ,   5663    ,   12771   ,   7469    ,0 };
            const std::uint32_t dim2088Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   17  ,   55  ,   111 ,   181 ,   293 ,   9   ,   41  ,   3625    ,   2865    ,   9109    ,   14261   ,0 };
            const std::uint32_t dim2089Kuo2Init[]       =   {   1   ,   1   ,   5   ,   15  ,   27  ,   13  ,   45  ,   109 ,   321 ,   609 ,   551 ,   4071    ,   6467    ,   8245    ,   6889    ,0 };
            const std::uint32_t dim2090Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   23  ,   15  ,   75  ,   9   ,   261 ,   189 ,   287 ,   2479    ,   2319    ,   2647    ,   3415    ,0 };
            const std::uint32_t dim2091Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   31  ,   47  ,   45  ,   73  ,   439 ,   789 ,   687 ,   3205    ,   863 ,   2471    ,   27997   ,0 };
            const std::uint32_t dim2092Kuo2Init[]       =   {   1   ,   3   ,   3   ,   13  ,   17  ,   47  ,   111 ,   205 ,   307 ,   299 ,   439 ,   965 ,   6093    ,   3215    ,   29381   ,0 };
            const std::uint32_t dim2093Kuo2Init[]       =   {   1   ,   1   ,   7   ,   11  ,   11  ,   31  ,   119 ,   93  ,   385 ,   149 ,   843 ,   3081    ,   6793    ,   4427    ,   23967   ,0 };
            const std::uint32_t dim2094Kuo2Init[]       =   {   1   ,   3   ,   7   ,   11  ,   7   ,   9   ,   27  ,   135 ,   465 ,   169 ,   1229    ,   1491    ,   3527    ,   13801   ,   13187   ,0 };
            const std::uint32_t dim2095Kuo2Init[]       =   {   1   ,   3   ,   7   ,   1   ,   27  ,   43  ,   9   ,   213 ,   95  ,   273 ,   1067    ,   1819    ,   4087    ,   15955   ,   7865    ,0 };
            const std::uint32_t dim2096Kuo2Init[]       =   {   1   ,   1   ,   3   ,   5   ,   25  ,   53  ,   49  ,   15  ,   159 ,   713 ,   203 ,   1599    ,   4807    ,   7275    ,   20589   ,0 };
            const std::uint32_t dim2097Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   9   ,   33  ,   5   ,   41  ,   289 ,   611 ,   153 ,   1019    ,   5571    ,   8459    ,   2903    ,0 };
            const std::uint32_t dim2098Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   5   ,   9   ,   9   ,   245 ,   205 ,   821 ,   73  ,   2907    ,   2061    ,   10255   ,   24837   ,0 };
            const std::uint32_t dim2099Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   3   ,   29  ,   79  ,   139 ,   57  ,   181 ,   741 ,   667 ,   3251    ,   15741   ,   2349    ,0 };
            const std::uint32_t dim2100Kuo2Init[]       =   {   1   ,   1   ,   7   ,   11  ,   15  ,   31  ,   63  ,   115 ,   475 ,   801 ,   195 ,   155 ,   2167    ,   9215    ,   11041   ,0 };
            const std::uint32_t dim2101Kuo2Init[]       =   {   1   ,   3   ,   7   ,   3   ,   7   ,   45  ,   17  ,   151 ,   353 ,   751 ,   373 ,   1523    ,   6271    ,   10307   ,   637 ,0 };
            const std::uint32_t dim2102Kuo2Init[]       =   {   1   ,   1   ,   1   ,   13  ,   15  ,   59  ,   99  ,   143 ,   261 ,   349 ,   327 ,   3931    ,   3365    ,   12179   ,   3017    ,0 };
            const std::uint32_t dim2103Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   27  ,   13  ,   105 ,   127 ,   177 ,   857 ,   405 ,   185 ,   5793    ,   8043    ,   11671   ,0 };
            const std::uint32_t dim2104Kuo2Init[]       =   {   1   ,   1   ,   7   ,   5   ,   9   ,   51  ,   127 ,   47  ,   421 ,   687 ,   961 ,   1413    ,   6619    ,   3459    ,   9093    ,0 };
            const std::uint32_t dim2105Kuo2Init[]       =   {   1   ,   1   ,   7   ,   11  ,   15  ,   45  ,   7   ,   123 ,   479 ,   55  ,   491 ,   2901    ,   5183    ,   6081    ,   31719   ,0 };
            const std::uint32_t dim2106Kuo2Init[]       =   {   1   ,   3   ,   3   ,   13  ,   3   ,   49  ,   29  ,   147 ,   453 ,   659 ,   753 ,   233 ,   251 ,   12445   ,   6573    ,0 };
            const std::uint32_t dim2107Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   7   ,   41  ,   3   ,   59  ,   187 ,   37  ,   1503    ,   4079    ,   5687    ,   16213   ,   9573    ,0 };
            const std::uint32_t dim2108Kuo2Init[]       =   {   1   ,   3   ,   7   ,   13  ,   19  ,   49  ,   75  ,   173 ,   219 ,   889 ,   859 ,   2021    ,   2249    ,   4031    ,   29485   ,0 };
            const std::uint32_t dim2109Kuo2Init[]       =   {   1   ,   3   ,   7   ,   9   ,   3   ,   21  ,   37  ,   79  ,   277 ,   307 ,   465 ,   1219    ,   4099    ,   5285    ,   27883   ,0 };
            const std::uint32_t dim2110Kuo2Init[]       =   {   1   ,   3   ,   5   ,   3   ,   19  ,   49  ,   97  ,   7   ,   483 ,   995 ,   775 ,   883 ,   2011    ,   16321   ,   31869   ,0 };
            const std::uint32_t dim2111Kuo2Init[]       =   {   1   ,   3   ,   7   ,   1   ,   25  ,   59  ,   113 ,   177 ,   507 ,   911 ,   1251    ,   571 ,   917 ,   2655    ,   31463   ,0 };
            const std::uint32_t dim2112Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   15  ,   23  ,   47  ,   79  ,   401 ,   245 ,   317 ,   1033    ,   3377    ,   2605    ,   13021   ,0 };
            const std::uint32_t dim2113Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   3   ,   1   ,   41  ,   253 ,   507 ,   283 ,   707 ,   1305    ,   2353    ,   5721    ,   15469   ,0 };
            const std::uint32_t dim2114Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   25  ,   25  ,   15  ,   79  ,   193 ,   235 ,   1981    ,   2059    ,   2057    ,   1647    ,   5443    ,0 };
            const std::uint32_t dim2115Kuo2Init[]       =   {   1   ,   1   ,   1   ,   3   ,   7   ,   37  ,   51  ,   169 ,   163 ,   223 ,   457 ,   1841    ,   857 ,   15847   ,   27369   ,0 };
            const std::uint32_t dim2116Kuo2Init[]       =   {   1   ,   1   ,   3   ,   11  ,   23  ,   49  ,   93  ,   89  ,   347 ,   213 ,   615 ,   1305    ,   885 ,   6195    ,   6659    ,0 };
            const std::uint32_t dim2117Kuo2Init[]       =   {   1   ,   3   ,   7   ,   9   ,   9   ,   27  ,   3   ,   217 ,   337 ,   977 ,   1109    ,   1915    ,   677 ,   8927    ,   4449    ,0 };
            const std::uint32_t dim2118Kuo2Init[]       =   {   1   ,   1   ,   7   ,   5   ,   11  ,   39  ,   23  ,   189 ,   467 ,   735 ,   817 ,   2269    ,   5959    ,   2933    ,   15667   ,0 };
            const std::uint32_t dim2119Kuo2Init[]       =   {   1   ,   1   ,   5   ,   5   ,   21  ,   33  ,   21  ,   241 ,   75  ,   751 ,   671 ,   3053    ,   7865    ,   4261    ,   13455   ,0 };
            const std::uint32_t dim2120Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   25  ,   11  ,   21  ,   149 ,   429 ,   275 ,   1815    ,   1153    ,   4471    ,   14993   ,   3543    ,0 };
            const std::uint32_t dim2121Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   3   ,   47  ,   9   ,   113 ,   423 ,   205 ,   1905    ,   57  ,   6157    ,   6335    ,   7425    ,0 };
            const std::uint32_t dim2122Kuo2Init[]       =   {   1   ,   1   ,   7   ,   11  ,   17  ,   13  ,   97  ,   99  ,   145 ,   319 ,   945 ,   1559    ,   3379    ,   12559   ,   22479   ,0 };
            const std::uint32_t dim2123Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   3   ,   47  ,   105 ,   251 ,   87  ,   293 ,   1191    ,   2211    ,   4631    ,   8443    ,   11789   ,0 };
            const std::uint32_t dim2124Kuo2Init[]       =   {   1   ,   1   ,   1   ,   3   ,   5   ,   1   ,   41  ,   115 ,   331 ,   401 ,   1649    ,   179 ,   1639    ,   16241   ,   18481   ,0 };
            const std::uint32_t dim2125Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   15  ,   33  ,   117 ,   121 ,   81  ,   807 ,   1897    ,   1731    ,   2793    ,   12531   ,   8863    ,0 };
            const std::uint32_t dim2126Kuo2Init[]       =   {   1   ,   3   ,   1   ,   13  ,   1   ,   41  ,   83  ,   5   ,   331 ,   423 ,   855 ,   1327    ,   5799    ,   3679    ,   21461   ,0 };
            const std::uint32_t dim2127Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   19  ,   37  ,   75  ,   39  ,   413 ,   123 ,   1073    ,   2299    ,   5379    ,   12805   ,   3527    ,0 };
            const std::uint32_t dim2128Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   7   ,   17  ,   25  ,   227 ,   383 ,   501 ,   673 ,   2609    ,   1843    ,   3367    ,   9901    ,0 };
            const std::uint32_t dim2129Kuo2Init[]       =   {   1   ,   1   ,   7   ,   11  ,   25  ,   29  ,   95  ,   33  ,   431 ,   257 ,   1013    ,   3755    ,   2813    ,   15247   ,   1045    ,0 };
            const std::uint32_t dim2130Kuo2Init[]       =   {   1   ,   1   ,   7   ,   3   ,   15  ,   25  ,   79  ,   67  ,   175 ,   697 ,   1867    ,   1967    ,   8023    ,   2017    ,   15449   ,0 };
            const std::uint32_t dim2131Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   21  ,   25  ,   67  ,   177 ,   479 ,   81  ,   495 ,   3531    ,   1997    ,   5169    ,   15861   ,0 };
            const std::uint32_t dim2132Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   7   ,   23  ,   57  ,   97  ,   7   ,   917 ,   1969    ,   3421    ,   2149    ,   11379   ,   1035    ,0 };
            const std::uint32_t dim2133Kuo2Init[]       =   {   1   ,   1   ,   5   ,   9   ,   5   ,   45  ,   51  ,   29  ,   289 ,   49  ,   1311    ,   4005    ,   3619    ,   12337   ,   7693    ,0 };
            const std::uint32_t dim2134Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   25  ,   9   ,   11  ,   23  ,   281 ,   517 ,   1309    ,   2719    ,   3133    ,   529 ,   21795   ,0 };
            const std::uint32_t dim2135Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   5   ,   43  ,   79  ,   87  ,   389 ,   189 ,   547 ,   3161    ,   4765    ,   10751   ,   15557   ,0 };
            const std::uint32_t dim2136Kuo2Init[]       =   {   1   ,   3   ,   1   ,   13  ,   29  ,   11  ,   5   ,   75  ,   453 ,   323 ,   999 ,   341 ,   6991    ,   14803   ,   31057   ,0 };
            const std::uint32_t dim2137Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   7   ,   3   ,   81  ,   201 ,   195 ,   221 ,   1949    ,   2205    ,   2273    ,   12029   ,   21089   ,0 };
            const std::uint32_t dim2138Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   25  ,   53  ,   7   ,   135 ,   7   ,   179 ,   797 ,   567 ,   1459    ,   9773    ,   2839    ,0 };
            const std::uint32_t dim2139Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   31  ,   27  ,   41  ,   253 ,   273 ,   749 ,   1605    ,   2259    ,   7171    ,   11861   ,   11769   ,0 };
            const std::uint32_t dim2140Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   13  ,   49  ,   25  ,   131 ,   397 ,   783 ,   1849    ,   3585    ,   2727    ,   8213    ,   14849   ,0 };
            const std::uint32_t dim2141Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   25  ,   35  ,   121 ,   159 ,   27  ,   305 ,   1841    ,   1893    ,   829 ,   11659   ,   9859    ,0 };
            const std::uint32_t dim2142Kuo2Init[]       =   {   1   ,   1   ,   5   ,   5   ,   3   ,   11  ,   79  ,   49  ,   95  ,   755 ,   1011    ,   2247    ,   5731    ,   12975   ,   20241   ,0 };
            const std::uint32_t dim2143Kuo2Init[]       =   {   1   ,   1   ,   5   ,   3   ,   25  ,   5   ,   103 ,   35  ,   337 ,   619 ,   35  ,   3655    ,   5137    ,   4867    ,   6055    ,0 };
            const std::uint32_t dim2144Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   15  ,   35  ,   67  ,   113 ,   381 ,   1001    ,   177 ,   3981    ,   1059    ,   4433    ,   26845   ,0 };
            const std::uint32_t dim2145Kuo2Init[]       =   {   1   ,   3   ,   7   ,   9   ,   19  ,   3   ,   107 ,   161 ,   109 ,   129 ,   1447    ,   4053    ,   7435    ,   3483    ,   7595    ,0 };
            const std::uint32_t dim2146Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   13  ,   25  ,   19  ,   137 ,   149 ,   191 ,   719 ,   1279    ,   6129    ,   6367    ,   9335    ,0 };
            const std::uint32_t dim2147Kuo2Init[]       =   {   1   ,   3   ,   5   ,   11  ,   19  ,   55  ,   19  ,   191 ,   31  ,   341 ,   485 ,   1165    ,   501 ,   11771   ,   17423   ,0 };
            const std::uint32_t dim2148Kuo2Init[]       =   {   1   ,   3   ,   7   ,   1   ,   21  ,   35  ,   115 ,   163 ,   99  ,   581 ,   1769    ,   1887    ,   6349    ,   13467   ,   10503   ,0 };
            const std::uint32_t dim2149Kuo2Init[]       =   {   1   ,   1   ,   7   ,   3   ,   23  ,   21  ,   105 ,   255 ,   501 ,   171 ,   1689    ,   1747    ,   2603    ,   11783   ,   7633    ,0 };
            const std::uint32_t dim2150Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   9   ,   45  ,   65  ,   95  ,   47  ,   163 ,   1597    ,   2693    ,   7407    ,   8155    ,   13645   ,0 };
            const std::uint32_t dim2151Kuo2Init[]       =   {   1   ,   1   ,   1   ,   1   ,   9   ,   5   ,   105 ,   55  ,   217 ,   773 ,   43  ,   741 ,   1093    ,   8087    ,   8003    ,0 };
            const std::uint32_t dim2152Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   19  ,   29  ,   127 ,   29  ,   23  ,   27  ,   2011    ,   623 ,   2649    ,   2979    ,   269 ,0 };
            const std::uint32_t dim2153Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   3   ,   17  ,   121 ,   85  ,   313 ,   333 ,   89  ,   1   ,   1147    ,   15909   ,   24017   ,0 };
            const std::uint32_t dim2154Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   17  ,   53  ,   89  ,   27  ,   219 ,   451 ,   629 ,   2539    ,   4151    ,   4811    ,   17057   ,0 };
            const std::uint32_t dim2155Kuo2Init[]       =   {   1   ,   1   ,   1   ,   3   ,   31  ,   47  ,   127 ,   63  ,   85  ,   387 ,   61  ,   685 ,   1103    ,   1257    ,   19305   ,0 };
            const std::uint32_t dim2156Kuo2Init[]       =   {   1   ,   3   ,   7   ,   11  ,   25  ,   7   ,   39  ,   209 ,   449 ,   667 ,   227 ,   605 ,   987 ,   1699    ,   11001   ,0 };
            const std::uint32_t dim2157Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   23  ,   35  ,   15  ,   193 ,   25  ,   1021    ,   1371    ,   3015    ,   7837    ,   14087   ,   21779   ,0 };
            const std::uint32_t dim2158Kuo2Init[]       =   {   1   ,   1   ,   5   ,   1   ,   1   ,   25  ,   25  ,   241 ,   493 ,   901 ,   1261    ,   261 ,   6959    ,   16013   ,   2849    ,0 };
            const std::uint32_t dim2159Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   13  ,   27  ,   85  ,   41  ,   139 ,   567 ,   753 ,   3255    ,   5633    ,   15687   ,   3019    ,0 };
            const std::uint32_t dim2160Kuo2Init[]       =   {   1   ,   1   ,   3   ,   11  ,   19  ,   61  ,   43  ,   153 ,   299 ,   931 ,   1481    ,   203 ,   593 ,   5019    ,   28309   ,0 };
            const std::uint32_t dim2161Kuo2Init[]       =   {   1   ,   3   ,   7   ,   7   ,   9   ,   11  ,   107 ,   243 ,   227 ,   69  ,   605 ,   3761    ,   1091    ,   4503    ,   21203   ,0 };
            const std::uint32_t dim2162Kuo2Init[]       =   {   1   ,   3   ,   5   ,   11  ,   11  ,   55  ,   47  ,   167 ,   291 ,   883 ,   1411    ,   3099    ,   1099    ,   11619   ,   9781    ,0 };
            const std::uint32_t dim2163Kuo2Init[]       =   {   1   ,   3   ,   7   ,   15  ,   23  ,   53  ,   109 ,   247 ,   459 ,   793 ,   839 ,   3069    ,   1829    ,   5151    ,   26255   ,0 };
            const std::uint32_t dim2164Kuo2Init[]       =   {   1   ,   3   ,   1   ,   15  ,   11  ,   31  ,   73  ,   193 ,   341 ,   791 ,   187 ,   3787    ,   4481    ,   11435   ,   715 ,0 };
            const std::uint32_t dim2165Kuo2Init[]       =   {   1   ,   3   ,   1   ,   13  ,   13  ,   61  ,   79  ,   193 ,   455 ,   571 ,   1277    ,   1565    ,   7385    ,   4393    ,   27447   ,0 };
            const std::uint32_t dim2166Kuo2Init[]       =   {   1   ,   3   ,   7   ,   3   ,   13  ,   35  ,   39  ,   89  ,   335 ,   701 ,   1423    ,   2441    ,   2895    ,   2795    ,   28511   ,0 };
            const std::uint32_t dim2167Kuo2Init[]       =   {   1   ,   3   ,   1   ,   1   ,   9   ,   27  ,   39  ,   163 ,   127 ,   163 ,   1881    ,   1995    ,   2629    ,   4541    ,   1669    ,0 };
            const std::uint32_t dim2168Kuo2Init[]       =   {   1   ,   1   ,   5   ,   3   ,   5   ,   53  ,   29  ,   223 ,   433 ,   643 ,   1035    ,   2339    ,   5947    ,   3047    ,   27409   ,0 };
            const std::uint32_t dim2169Kuo2Init[]       =   {   1   ,   3   ,   1   ,   15  ,   5   ,   35  ,   47  ,   49  ,   347 ,   579 ,   551 ,   2285    ,   3171    ,   8041    ,   8223    ,0 };
            const std::uint32_t dim2170Kuo2Init[]       =   {   1   ,   1   ,   1   ,   1   ,   1   ,   57  ,   51  ,   219 ,   339 ,   95  ,   1585    ,   2811    ,   4771    ,   1475    ,   7919    ,0 };
            const std::uint32_t dim2171Kuo2Init[]       =   {   1   ,   3   ,   7   ,   3   ,   21  ,   11  ,   51  ,   143 ,   111 ,   475 ,   1669    ,   3717    ,   6579    ,   7161    ,   9491    ,0 };
            const std::uint32_t dim2172Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   1   ,   17  ,   15  ,   179 ,   485 ,   587 ,   571 ,   3259    ,   3299    ,   207 ,   2121    ,0 };
            const std::uint32_t dim2173Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   27  ,   19  ,   23  ,   47  ,   289 ,   997 ,   523 ,   3183    ,   8087    ,   2621    ,   31471   ,0 };
            const std::uint32_t dim2174Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   23  ,   21  ,   125 ,   181 ,   393 ,   177 ,   419 ,   2809    ,   6727    ,   1063    ,   10889   ,0 };
            const std::uint32_t dim2175Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   19  ,   29  ,   115 ,   149 ,   439 ,   125 ,   7   ,   2173    ,   6691    ,   4063    ,   8193    ,0 };
            const std::uint32_t dim2176Kuo2Init[]       =   {   1   ,   1   ,   3   ,   11  ,   3   ,   17  ,   9   ,   251 ,   493 ,   977 ,   1713    ,   2711    ,   4377    ,   3171    ,   22195   ,0 };
            const std::uint32_t dim2177Kuo2Init[]       =   {   1   ,   1   ,   3   ,   1   ,   17  ,   63  ,   73  ,   141 ,   323 ,   875 ,   713 ,   2133    ,   3283    ,   10039   ,   11431   ,0 };
            const std::uint32_t dim2178Kuo2Init[]       =   {   1   ,   1   ,   7   ,   5   ,   29  ,   33  ,   63  ,   19  ,   191 ,   915 ,   1523    ,   3505    ,   2431    ,   9531    ,   5253    ,0 };
            const std::uint32_t dim2179Kuo2Init[]       =   {   1   ,   3   ,   5   ,   5   ,   15  ,   25  ,   81  ,   97  ,   455 ,   141 ,   1947    ,   2001    ,   6015    ,   11439   ,   29725   ,0 };
            const std::uint32_t dim2180Kuo2Init[]       =   {   1   ,   1   ,   1   ,   1   ,   7   ,   35  ,   71  ,   205 ,   485 ,   495 ,   345 ,   1991    ,   6905    ,   12535   ,   2209    ,0 };
            const std::uint32_t dim2181Kuo2Init[]       =   {   1   ,   1   ,   7   ,   15  ,   27  ,   23  ,   19  ,   119 ,   347 ,   519 ,   423 ,   1567    ,   7783    ,   15095   ,   23609   ,0 };
            const std::uint32_t dim2182Kuo2Init[]       =   {   1   ,   3   ,   7   ,   1   ,   23  ,   13  ,   23  ,   239 ,   199 ,   575 ,   1149    ,   771 ,   3779    ,   12437   ,   32301   ,0 };
            const std::uint32_t dim2183Kuo2Init[]       =   {   1   ,   3   ,   5   ,   3   ,   31  ,   55  ,   87  ,   111 ,   233 ,   633 ,   1037    ,   4053    ,   2007    ,   15197   ,   31531   ,0 };
            const std::uint32_t dim2184Kuo2Init[]       =   {   1   ,   1   ,   1   ,   7   ,   3   ,   47  ,   11  ,   169 ,   293 ,   959 ,   903 ,   2129    ,   1049    ,   1311    ,   4027    ,0 };
            const std::uint32_t dim2185Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   1   ,   15  ,   37  ,   79  ,   299 ,   989 ,   969 ,   2699    ,   4531    ,   8455    ,   30613   ,0 };
            const std::uint32_t dim2186Kuo2Init[]       =   {   1   ,   3   ,   1   ,   15  ,   13  ,   25  ,   57  ,   237 ,   117 ,   659 ,   517 ,   1821    ,   4755    ,   6745    ,   13269   ,0 };
            const std::uint32_t dim2187Kuo2Init[]       =   {   1   ,   3   ,   7   ,   11  ,   3   ,   27  ,   53  ,   197 ,   285 ,   897 ,   5   ,   675 ,   255 ,   5999    ,   7629    ,0 };
            const std::uint32_t dim2188Kuo2Init[]       =   {   1   ,   3   ,   7   ,   7   ,   21  ,   21  ,   71  ,   117 ,   347 ,   251 ,   1025    ,   2455    ,   7177    ,   9135    ,   15569   ,0 };
            const std::uint32_t dim2189Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   25  ,   7   ,   113 ,   229 ,   243 ,   173 ,   1903    ,   427 ,   2743    ,   2245    ,   12783   ,0 };
            const std::uint32_t dim2190Kuo2Init[]       =   {   1   ,   1   ,   1   ,   15  ,   11  ,   53  ,   45  ,   209 ,   181 ,   147 ,   183 ,   3133    ,   4793    ,   14731   ,   16491   ,0 };
            const std::uint32_t dim2191Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   27  ,   45  ,   77  ,   211 ,   89  ,   555 ,   1829    ,   4073    ,   839 ,   12079   ,   27745   ,0 };
            const std::uint32_t dim2192Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   1   ,   29  ,   17  ,   65  ,   47  ,   995 ,   85  ,   69  ,   641 ,   4139    ,   1221    ,0 };
            const std::uint32_t dim2193Kuo2Init[]       =   {   1   ,   3   ,   3   ,   3   ,   11  ,   57  ,   11  ,   69  ,   285 ,   837 ,   1129    ,   3465    ,   323 ,   4599    ,   6593    ,0 };
            const std::uint32_t dim2194Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   19  ,   27  ,   1   ,   197 ,   259 ,   315 ,   567 ,   613 ,   5385    ,   4495    ,   13507   ,0 };
            const std::uint32_t dim2195Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   13  ,   63  ,   3   ,   81  ,   363 ,   67  ,   1025    ,   1403    ,   4469    ,   9881    ,   3563    ,0 };
            const std::uint32_t dim2196Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   23  ,   1   ,   103 ,   51  ,   445 ,   1017    ,   361 ,   811 ,   4555    ,   6013    ,   25117   ,0 };
            const std::uint32_t dim2197Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   21  ,   33  ,   73  ,   13  ,   155 ,   419 ,   371 ,   499 ,   3003    ,   7577    ,   19191   ,0 };
            const std::uint32_t dim2198Kuo2Init[]       =   {   1   ,   1   ,   1   ,   13  ,   19  ,   57  ,   91  ,   251 ,   157 ,   551 ,   1529    ,   2649    ,   7785    ,   4357    ,   18533   ,0 };
            const std::uint32_t dim2199Kuo2Init[]       =   {   1   ,   1   ,   1   ,   15  ,   29  ,   23  ,   33  ,   139 ,   495 ,   87  ,   1291    ,   1441    ,   819 ,   321 ,   24597   ,0 };
            const std::uint32_t dim2200Kuo2Init[]       =   {   1   ,   1   ,   5   ,   7   ,   11  ,   21  ,   127 ,   135 ,   395 ,   511 ,   213 ,   4043    ,   5869    ,   5733    ,   23157   ,0 };
            const std::uint32_t dim2201Kuo2Init[]       =   {   1   ,   3   ,   5   ,   5   ,   1   ,   61  ,   99  ,   155 ,   415 ,   111 ,   1335    ,   241 ,   1935    ,   7457    ,   7127    ,0 };
            const std::uint32_t dim2202Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   25  ,   43  ,   69  ,   97  ,   423 ,   989 ,   1433    ,   107 ,   7253    ,   6543    ,   1685    ,0 };
            const std::uint32_t dim2203Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   9   ,   51  ,   77  ,   69  ,   1   ,   75  ,   1859    ,   3735    ,   1199    ,   13725   ,   6689    ,0 };
            const std::uint32_t dim2204Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   13  ,   7   ,   103 ,   91  ,   465 ,   675 ,   1221    ,   2853    ,   6785    ,   7113    ,   12671   ,0 };
            const std::uint32_t dim2205Kuo2Init[]       =   {   1   ,   3   ,   1   ,   15  ,   9   ,   9   ,   75  ,   17  ,   357 ,   559 ,   1021    ,   1023    ,   779 ,   10805   ,   12707   ,0 };
            const std::uint32_t dim2206Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   19  ,   41  ,   25  ,   209 ,   61  ,   225 ,   533 ,   2661    ,   6735    ,   4877    ,   20085   ,0 };
            const std::uint32_t dim2207Kuo2Init[]       =   {   1   ,   1   ,   5   ,   7   ,   29  ,   35  ,   61  ,   21  ,   203 ,   689 ,   1431    ,   2009    ,   3475    ,   2103    ,   19457   ,0 };
            const std::uint32_t dim2208Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   7   ,   51  ,   119 ,   115 ,   357 ,   969 ,   779 ,   2407    ,   1669    ,   4671    ,   21945   ,0 };
            const std::uint32_t dim2209Kuo2Init[]       =   {   1   ,   1   ,   5   ,   13  ,   5   ,   33  ,   125 ,   61  ,   123 ,   569 ,   7   ,   2389    ,   3325    ,   15701   ,   16931   ,0 };
            const std::uint32_t dim2210Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   13  ,   29  ,   7   ,   205 ,   397 ,   861 ,   1035    ,   675 ,   5963    ,   9229    ,   14537   ,0 };
            const std::uint32_t dim2211Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   13  ,   41  ,   69  ,   25  ,   461 ,   745 ,   189 ,   3239    ,   4515    ,   2717    ,   22815   ,0 };
            const std::uint32_t dim2212Kuo2Init[]       =   {   1   ,   1   ,   1   ,   7   ,   29  ,   47  ,   49  ,   91  ,   403 ,   325 ,   1241    ,   2295    ,   6371    ,   6791    ,   911 ,0 };
            const std::uint32_t dim2213Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   13  ,   47  ,   83  ,   161 ,   371 ,   779 ,   1935    ,   3445    ,   735 ,   1963    ,   17267   ,0 };
            const std::uint32_t dim2214Kuo2Init[]       =   {   1   ,   3   ,   7   ,   7   ,   19  ,   59  ,   41  ,   217 ,   71  ,   407 ,   1639    ,   4081    ,   8011    ,   4805    ,   1847    ,0 };
            const std::uint32_t dim2215Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   21  ,   11  ,   113 ,   151 ,   269 ,   119 ,   615 ,   2657    ,   1835    ,   16071   ,   7475    ,0 };
            const std::uint32_t dim2216Kuo2Init[]       =   {   1   ,   1   ,   1   ,   13  ,   13  ,   53  ,   121 ,   231 ,   419 ,   439 ,   1287    ,   3043    ,   8187    ,   4355    ,   16377   ,0 };
            const std::uint32_t dim2217Kuo2Init[]       =   {   1   ,   1   ,   1   ,   3   ,   1   ,   51  ,   69  ,   49  ,   403 ,   549 ,   659 ,   501 ,   7497    ,   9461    ,   8813    ,0 };
            const std::uint32_t dim2218Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   15  ,   13  ,   11  ,   65  ,   241 ,   77  ,   675 ,   2077    ,   927 ,   11841   ,   2527    ,0 };
            const std::uint32_t dim2219Kuo2Init[]       =   {   1   ,   1   ,   5   ,   9   ,   23  ,   35  ,   113 ,   33  ,   497 ,   1001    ,   1105    ,   2157    ,   1209    ,   7821    ,   20345   ,0 };
            const std::uint32_t dim2220Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   23  ,   39  ,   81  ,   151 ,   259 ,   491 ,   1129    ,   1115    ,   4501    ,   5513    ,   20347   ,0 };
            const std::uint32_t dim2221Kuo2Init[]       =   {   1   ,   1   ,   5   ,   1   ,   11  ,   59  ,   55  ,   195 ,   157 ,   915 ,   35  ,   489 ,   2805    ,   9059    ,   14757   ,0 };
            const std::uint32_t dim2222Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   9   ,   21  ,   91  ,   59  ,   425 ,   127 ,   1939    ,   2763    ,   1243    ,   4303    ,   4549    ,0 };
            const std::uint32_t dim2223Kuo2Init[]       =   {   1   ,   1   ,   5   ,   13  ,   19  ,   29  ,   127 ,   251 ,   91  ,   419 ,   333 ,   2943    ,   1649    ,   8653    ,   32401   ,0 };
            const std::uint32_t dim2224Kuo2Init[]       =   {   1   ,   3   ,   1   ,   11  ,   13  ,   13  ,   73  ,   153 ,   131 ,   675 ,   1235    ,   1565    ,   2153    ,   3999    ,   3075    ,0 };
            const std::uint32_t dim2225Kuo2Init[]       =   {   1   ,   1   ,   5   ,   13  ,   1   ,   29  ,   111 ,   229 ,   23  ,   649 ,   1017    ,   2257    ,   1967    ,   9839    ,   21179   ,0 };
            const std::uint32_t dim2226Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   13  ,   59  ,   39  ,   243 ,   453 ,   51  ,   801 ,   727 ,   5391    ,   11987   ,   12431   ,0 };
            const std::uint32_t dim2227Kuo2Init[]       =   {   1   ,   1   ,   7   ,   5   ,   9   ,   7   ,   59  ,   203 ,   177 ,   255 ,   1525    ,   1869    ,   5187    ,   135 ,   11205   ,0 };
            const std::uint32_t dim2228Kuo2Init[]       =   {   1   ,   1   ,   5   ,   5   ,   17  ,   49  ,   115 ,   101 ,   45  ,   385 ,   1751    ,   883 ,   7437    ,   3839    ,   7997    ,0 };
            const std::uint32_t dim2229Kuo2Init[]       =   {   1   ,   1   ,   1   ,   13  ,   11  ,   17  ,   99  ,   127 ,   457 ,   333 ,   395 ,   1387    ,   4533    ,   2247    ,   5999    ,0 };
            const std::uint32_t dim2230Kuo2Init[]       =   {   1   ,   3   ,   7   ,   7   ,   15  ,   61  ,   103 ,   217 ,   175 ,   133 ,   1721    ,   1735    ,   8083    ,   14973   ,   20891   ,0 };
            const std::uint32_t dim2231Kuo2Init[]       =   {   1   ,   1   ,   1   ,   13  ,   31  ,   35  ,   69  ,   53  ,   191 ,   671 ,   1339    ,   1677    ,   4463    ,   1951    ,   28129   ,0 };
            const std::uint32_t dim2232Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   19  ,   13  ,   73  ,   171 ,   481 ,   981 ,   343 ,   1831    ,   2967    ,   1801    ,   9923    ,0 };
            const std::uint32_t dim2233Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   9   ,   29  ,   57  ,   113 ,   425 ,   705 ,   673 ,   3749    ,   1883    ,   12295   ,   9669    ,0 };
            const std::uint32_t dim2234Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   13  ,   35  ,   23  ,   35  ,   303 ,   281 ,   773 ,   3053    ,   3841    ,   7943    ,   5023    ,0 };
            const std::uint32_t dim2235Kuo2Init[]       =   {   1   ,   1   ,   7   ,   15  ,   11  ,   27  ,   85  ,   163 ,   349 ,   289 ,   297 ,   3043    ,   6469    ,   12029   ,   8087    ,0 };
            const std::uint32_t dim2236Kuo2Init[]       =   {   1   ,   1   ,   5   ,   15  ,   27  ,   47  ,   3   ,   51  ,   87  ,   583 ,   893 ,   971 ,   6859    ,   7459    ,   6931    ,0 };
            const std::uint32_t dim2237Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   21  ,   57  ,   65  ,   141 ,   129 ,   345 ,   745 ,   2281    ,   4753    ,   2899    ,   1891    ,0 };
            const std::uint32_t dim2238Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   7   ,   3   ,   87  ,   127 ,   133 ,   243 ,   241 ,   557 ,   6537    ,   1645    ,   24843   ,0 };
            const std::uint32_t dim2239Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   7   ,   37  ,   91  ,   9   ,   337 ,   787 ,   1833    ,   3259    ,   1335    ,   6365    ,   30259   ,0 };
            const std::uint32_t dim2240Kuo2Init[]       =   {   1   ,   1   ,   1   ,   9   ,   7   ,   3   ,   127 ,   41  ,   41  ,   377 ,   1633    ,   3031    ,   4483    ,   12555   ,   23921   ,0 };
            const std::uint32_t dim2241Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   21  ,   9   ,   77  ,   243 ,   373 ,   289 ,   715 ,   2323    ,   2549    ,   8891    ,   22603   ,0 };
            const std::uint32_t dim2242Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   19  ,   53  ,   81  ,   83  ,   111 ,   593 ,   1041    ,   499 ,   5849    ,   1261    ,   9561    ,0 };
            const std::uint32_t dim2243Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   11  ,   45  ,   13  ,   217 ,   309 ,   249 ,   1597    ,   2829    ,   2185    ,   11919   ,   22975   ,0 };
            const std::uint32_t dim2244Kuo2Init[]       =   {   1   ,   1   ,   1   ,   3   ,   31  ,   3   ,   69  ,   105 ,   449 ,   339 ,   1705    ,   551 ,   1701    ,   1163    ,   22551   ,0 };
            const std::uint32_t dim2245Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   29  ,   23  ,   115 ,   119 ,   25  ,   425 ,   225 ,   1379    ,   1443    ,   9549    ,   31083   ,0 };
            const std::uint32_t dim2246Kuo2Init[]       =   {   1   ,   1   ,   7   ,   11  ,   31  ,   37  ,   121 ,   29  ,   367 ,   171 ,   1611    ,   3147    ,   4887    ,   15191   ,   27943   ,0 };
            const std::uint32_t dim2247Kuo2Init[]       =   {   1   ,   1   ,   5   ,   1   ,   25  ,   11  ,   39  ,   137 ,   251 ,   557 ,   1833    ,   2803    ,   2081    ,   819 ,   12493   ,0 };
            const std::uint32_t dim2248Kuo2Init[]       =   {   1   ,   1   ,   1   ,   3   ,   17  ,   19  ,   87  ,   123 ,   333 ,   215 ,   685 ,   1235    ,   2327    ,   5927    ,   16909   ,0 };
            const std::uint32_t dim2249Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   5   ,   31  ,   127 ,   205 ,   197 ,   671 ,   1101    ,   1767    ,   7871    ,   4157    ,   31301   ,0 };
            const std::uint32_t dim2250Kuo2Init[]       =   {   1   ,   1   ,   5   ,   5   ,   17  ,   5   ,   23  ,   175 ,   363 ,   831 ,   563 ,   2599    ,   7081    ,   11695   ,   10301   ,0 };
            const std::uint32_t dim2251Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   21  ,   55  ,   97  ,   163 ,   443 ,   533 ,   1889    ,   1431    ,   6671    ,   14699   ,   26863   ,0 };
            const std::uint32_t dim2252Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   27  ,   15  ,   7   ,   215 ,   7   ,   557 ,   819 ,   3855    ,   619 ,   10185   ,   23715   ,0 };
            const std::uint32_t dim2253Kuo2Init[]       =   {   1   ,   3   ,   7   ,   1   ,   17  ,   23  ,   25  ,   59  ,   369 ,   675 ,   463 ,   809 ,   8097    ,   9263    ,   8907    ,0 };
            const std::uint32_t dim2254Kuo2Init[]       =   {   1   ,   1   ,   1   ,   3   ,   1   ,   29  ,   63  ,   65  ,   103 ,   659 ,   1883    ,   1141    ,   641 ,   6083    ,   16237   ,0 };
            const std::uint32_t dim2255Kuo2Init[]       =   {   1   ,   1   ,   1   ,   3   ,   5   ,   41  ,   13  ,   143 ,   349 ,   811 ,   1645    ,   1871    ,   3385    ,   12795   ,   25105   ,0 };
            const std::uint32_t dim2256Kuo2Init[]       =   {   1   ,   1   ,   1   ,   15  ,   17  ,   7   ,   73  ,   195 ,   439 ,   85  ,   1701    ,   3989    ,   1619    ,   5319    ,   20593   ,0 };
            const std::uint32_t dim2257Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   1   ,   9   ,   61  ,   223 ,   441 ,   543 ,   765 ,   3477    ,   2569    ,   6061    ,   25353   ,0 };
            const std::uint32_t dim2258Kuo2Init[]       =   {   1   ,   1   ,   3   ,   11  ,   29  ,   63  ,   9   ,   149 ,   307 ,   705 ,   871 ,   2975    ,   4145    ,   431 ,   14483   ,0 };
            const std::uint32_t dim2259Kuo2Init[]       =   {   1   ,   1   ,   1   ,   3   ,   11  ,   7   ,   103 ,   85  ,   389 ,   719 ,   1201    ,   3139    ,   2941    ,   13867   ,   1915    ,0 };
            const std::uint32_t dim2260Kuo2Init[]       =   {   1   ,   1   ,   3   ,   3   ,   21  ,   27  ,   65  ,   59  ,   223 ,   335 ,   1845    ,   1315    ,   3619    ,   1851    ,   4313    ,0 };
            const std::uint32_t dim2261Kuo2Init[]       =   {   1   ,   3   ,   7   ,   13  ,   21  ,   21  ,   19  ,   181 ,   39  ,   89  ,   1703    ,   791 ,   597 ,   3349    ,   14387   ,0 };
            const std::uint32_t dim2262Kuo2Init[]       =   {   1   ,   3   ,   5   ,   3   ,   9   ,   19  ,   49  ,   253 ,   61  ,   313 ,   1763    ,   629 ,   1951    ,   16157   ,   14435   ,0 };
            const std::uint32_t dim2263Kuo2Init[]       =   {   1   ,   1   ,   5   ,   13  ,   23  ,   41  ,   45  ,   107 ,   111 ,   287 ,   1829    ,   33  ,   5433    ,   7283    ,   20573   ,0 };
            const std::uint32_t dim2264Kuo2Init[]       =   {   1   ,   3   ,   3   ,   5   ,   17  ,   43  ,   117 ,   55  ,   275 ,   763 ,   1581    ,   2349    ,   1219    ,   16145   ,   545 ,0 };
            const std::uint32_t dim2265Kuo2Init[]       =   {   1   ,   1   ,   5   ,   3   ,   13  ,   23  ,   65  ,   97  ,   347 ,   169 ,   1371    ,   2373    ,   4577    ,   14667   ,   5713    ,0 };
            const std::uint32_t dim2266Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   1   ,   43  ,   17  ,   87  ,   287 ,   943 ,   1257    ,   3383    ,   2389    ,   3349    ,   11641   ,0 };
            const std::uint32_t dim2267Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   27  ,   37  ,   127 ,   27  ,   239 ,   5   ,   575 ,   1811    ,   7185    ,   10233   ,   20519   ,0 };
            const std::uint32_t dim2268Kuo2Init[]       =   {   1   ,   3   ,   1   ,   13  ,   21  ,   33  ,   91  ,   147 ,   351 ,   283 ,   1765    ,   3497    ,   3113    ,   7635    ,   21229   ,0 };
            const std::uint32_t dim2269Kuo2Init[]       =   {   1   ,   3   ,   7   ,   3   ,   19  ,   39  ,   47  ,   135 ,   495 ,   401 ,   843 ,   551 ,   5239    ,   6525    ,   32339   ,0 };
            const std::uint32_t dim2270Kuo2Init[]       =   {   1   ,   3   ,   3   ,   3   ,   1   ,   37  ,   61  ,   243 ,   491 ,   139 ,   613 ,   685 ,   3027    ,   8053    ,   4935    ,0 };
            const std::uint32_t dim2271Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   13  ,   43  ,   25  ,   117 ,   43  ,   161 ,   747 ,   3005    ,   5445    ,   7559    ,   31029   ,0 };
            const std::uint32_t dim2272Kuo2Init[]       =   {   1   ,   1   ,   1   ,   1   ,   9   ,   31  ,   107 ,   57  ,   121 ,   733 ,   1813    ,   2057    ,   2473    ,   1769    ,   14649   ,0 };
            const std::uint32_t dim2273Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   7   ,   53  ,   105 ,   163 ,   401 ,   391 ,   849 ,   2359    ,   6819    ,   13905   ,   17267   ,0 };
            const std::uint32_t dim2274Kuo2Init[]       =   {   1   ,   1   ,   5   ,   7   ,   23  ,   9   ,   31  ,   39  ,   7   ,   767 ,   153 ,   2969    ,   5539    ,   6581    ,   30515   ,0 };
            const std::uint32_t dim2275Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   3   ,   63  ,   73  ,   167 ,   485 ,   837 ,   403 ,   193 ,   2707    ,   2017    ,   743 ,0 };
            const std::uint32_t dim2276Kuo2Init[]       =   {   1   ,   1   ,   5   ,   15  ,   17  ,   59  ,   115 ,   115 ,   463 ,   203 ,   607 ,   343 ,   577 ,   6985    ,   8797    ,0 };
            const std::uint32_t dim2277Kuo2Init[]       =   {   1   ,   1   ,   7   ,   3   ,   19  ,   61  ,   33  ,   245 ,   337 ,   105 ,   597 ,   807 ,   1669    ,   5447    ,   15173   ,0 };
            const std::uint32_t dim2278Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   27  ,   51  ,   67  ,   135 ,   151 ,   215 ,   217 ,   221 ,   6467    ,   3693    ,   4563    ,0 };
            const std::uint32_t dim2279Kuo2Init[]       =   {   1   ,   1   ,   1   ,   3   ,   1   ,   5   ,   91  ,   223 ,   491 ,   783 ,   287 ,   4067    ,   6747    ,   2489    ,   11513   ,0 };
            const std::uint32_t dim2280Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   25  ,   15  ,   9   ,   3   ,   445 ,   893 ,   399 ,   2073    ,   3715    ,   2493    ,   7761    ,0 };
            const std::uint32_t dim2281Kuo2Init[]       =   {   1   ,   3   ,   1   ,   11  ,   5   ,   41  ,   121 ,   107 ,   15  ,   547 ,   1417    ,   1275    ,   7255    ,   14979   ,   26993   ,0 };
            const std::uint32_t dim2282Kuo2Init[]       =   {   1   ,   1   ,   5   ,   5   ,   29  ,   41  ,   115 ,   195 ,   305 ,   887 ,   335 ,   3919    ,   6607    ,   15783   ,   21457   ,0 };
            const std::uint32_t dim2283Kuo2Init[]       =   {   1   ,   1   ,   7   ,   15  ,   11  ,   43  ,   53  ,   19  ,   37  ,   219 ,   1905    ,   1153    ,   4783    ,   11817   ,   11119   ,0 };
            const std::uint32_t dim2284Kuo2Init[]       =   {   1   ,   1   ,   5   ,   13  ,   31  ,   57  ,   73  ,   237 ,   443 ,   755 ,   1141    ,   793 ,   8177    ,   9053    ,   25949   ,0 };
            const std::uint32_t dim2285Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   9   ,   11  ,   1   ,   151 ,   249 ,   701 ,   523 ,   2383    ,   647 ,   7979    ,   28965   ,0 };
            const std::uint32_t dim2286Kuo2Init[]       =   {   1   ,   3   ,   1   ,   9   ,   7   ,   47  ,   47  ,   117 ,   239 ,   213 ,   1747    ,   3093    ,   3111    ,   6689    ,   22451   ,0 };
            const std::uint32_t dim2287Kuo2Init[]       =   {   1   ,   1   ,   3   ,   1   ,   21  ,   43  ,   111 ,   97  ,   323 ,   733 ,   1051    ,   3567    ,   1217    ,   3731    ,   15475   ,0 };
            const std::uint32_t dim2288Kuo2Init[]       =   {   1   ,   3   ,   1   ,   9   ,   29  ,   13  ,   63  ,   151 ,   469 ,   211 ,   927 ,   1893    ,   7741    ,   9733    ,   5777    ,0 };
            const std::uint32_t dim2289Kuo2Init[]       =   {   1   ,   1   ,   1   ,   15  ,   17  ,   49  ,   65  ,   81  ,   325 ,   847 ,   193 ,   3777    ,   4979    ,   1621    ,   17401   ,0 };
            const std::uint32_t dim2290Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   27  ,   31  ,   37  ,   185 ,   339 ,   731 ,   1317    ,   527 ,   1889    ,   10609   ,   27419   ,0 };
            const std::uint32_t dim2291Kuo2Init[]       =   {   1   ,   1   ,   3   ,   13  ,   27  ,   45  ,   85  ,   193 ,   293 ,   909 ,   205 ,   2245    ,   2845    ,   11575   ,   21997   ,0 };
            const std::uint32_t dim2292Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   13  ,   63  ,   49  ,   97  ,   343 ,   331 ,   2015    ,   2117    ,   6367    ,   13501   ,   12029   ,0 };
            const std::uint32_t dim2293Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   15  ,   9   ,   61  ,   41  ,   355 ,   327 ,   1285    ,   571 ,   3437    ,   10489   ,   24383   ,0 };
            const std::uint32_t dim2294Kuo2Init[]       =   {   1   ,   1   ,   7   ,   13  ,   23  ,   13  ,   7   ,   127 ,   329 ,   323 ,   2037    ,   31  ,   407 ,   11301   ,   28027   ,0 };
            const std::uint32_t dim2295Kuo2Init[]       =   {   1   ,   1   ,   3   ,   1   ,   23  ,   61  ,   99  ,   237 ,   15  ,   257 ,   1575    ,   2077    ,   6507    ,   3365    ,   21885   ,0 };
            const std::uint32_t dim2296Kuo2Init[]       =   {   1   ,   3   ,   5   ,   11  ,   15  ,   61  ,   111 ,   25  ,   309 ,   853 ,   1203    ,   2943    ,   4875    ,   9233    ,   197 ,0 };
            const std::uint32_t dim2297Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   5   ,   15  ,   17  ,   97  ,   213 ,   991 ,   867 ,   2291    ,   8129    ,   9381    ,   787 ,0 };
            const std::uint32_t dim2298Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   31  ,   45  ,   105 ,   35  ,   403 ,   595 ,   1007    ,   3633    ,   5167    ,   11245   ,   6643    ,0 };
            const std::uint32_t dim2299Kuo2Init[]       =   {   1   ,   3   ,   5   ,   5   ,   1   ,   51  ,   121 ,   161 ,   109 ,   369 ,   447 ,   213 ,   4879    ,   5639    ,   7233    ,0 };
            const std::uint32_t dim2300Kuo2Init[]       =   {   1   ,   1   ,   7   ,   5   ,   3   ,   27  ,   35  ,   143 ,   489 ,   435 ,   1483    ,   3261    ,   7427    ,   3105    ,   5297    ,0 };
            const std::uint32_t dim2301Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   11  ,   1   ,   75  ,   63  ,   367 ,   523 ,   291 ,   1429    ,   5509    ,   8641    ,   6847    ,0 };
            const std::uint32_t dim2302Kuo2Init[]       =   {   1   ,   1   ,   7   ,   13  ,   5   ,   59  ,   69  ,   81  ,   359 ,   905 ,   723 ,   3449    ,   3961    ,   16231   ,   19789   ,0 };
            const std::uint32_t dim2303Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   13  ,   53  ,   119 ,   129 ,   87  ,   325 ,   415 ,   3313    ,   6045    ,   5293    ,   21325   ,0 };
            const std::uint32_t dim2304Kuo2Init[]       =   {   1   ,   1   ,   3   ,   3   ,   3   ,   45  ,   73  ,   109 ,   337 ,   185 ,   781 ,   3277    ,   2575    ,   15999   ,   8309    ,0 };
            const std::uint32_t dim2305Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   15  ,   59  ,   35  ,   77  ,   441 ,   635 ,   627 ,   183 ,   4599    ,   8749    ,   24149   ,0 };
            const std::uint32_t dim2306Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   23  ,   51  ,   31  ,   23  ,   367 ,   473 ,   27  ,   1021    ,   2587    ,   3063    ,   32563   ,0 };
            const std::uint32_t dim2307Kuo2Init[]       =   {   1   ,   1   ,   7   ,   5   ,   9   ,   57  ,   45  ,   147 ,   95  ,   233 ,   1349    ,   1497    ,   7103    ,   4049    ,   905 ,0 };
            const std::uint32_t dim2308Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   9   ,   21  ,   89  ,   59  ,   379 ,   467 ,   1619    ,   809 ,   3947    ,   1715    ,   9841    ,0 };
            const std::uint32_t dim2309Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   23  ,   41  ,   43  ,   213 ,   429 ,   825 ,   279 ,   1117    ,   659 ,   13157   ,   3977    ,0 };
            const std::uint32_t dim2310Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   1   ,   57  ,   79  ,   87  ,   285 ,   693 ,   1947    ,   3417    ,   4241    ,   8595    ,   18075   ,0 };
            const std::uint32_t dim2311Kuo2Init[]       =   {   1   ,   1   ,   1   ,   1   ,   11  ,   19  ,   9   ,   79  ,   407 ,   475 ,   655 ,   2925    ,   2919    ,   6343    ,   19637   ,0 };
            const std::uint32_t dim2312Kuo2Init[]       =   {   1   ,   3   ,   3   ,   13  ,   1   ,   41  ,   107 ,   185 ,   29  ,   169 ,   915 ,   3535    ,   3543    ,   8015    ,   7097    ,0 };
            const std::uint32_t dim2313Kuo2Init[]       =   {   1   ,   1   ,   3   ,   11  ,   29  ,   1   ,   25  ,   199 ,   129 ,   471 ,   1335    ,   3413    ,   7373    ,   9881    ,   32595   ,0 };
            const std::uint32_t dim2314Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   25  ,   13  ,   95  ,   23  ,   145 ,   775 ,   1873    ,   2347    ,   323 ,   10021   ,   20551   ,0 };
            const std::uint32_t dim2315Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   3   ,   35  ,   25  ,   79  ,   279 ,   251 ,   245 ,   2917    ,   1147    ,   9525    ,   9473    ,0 };
            const std::uint32_t dim2316Kuo2Init[]       =   {   1   ,   3   ,   3   ,   11  ,   25  ,   35  ,   115 ,   13  ,   191 ,   447 ,   1041    ,   3437    ,   5941    ,   903 ,   26727   ,0 };
            const std::uint32_t dim2317Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   27  ,   49  ,   29  ,   169 ,   167 ,   685 ,   931 ,   1705    ,   4513    ,   16217   ,   8545    ,0 };
            const std::uint32_t dim2318Kuo2Init[]       =   {   1   ,   3   ,   5   ,   3   ,   5   ,   55  ,   55  ,   113 ,   129 ,   491 ,   1583    ,   2103    ,   2233    ,   12669   ,   2809    ,0 };
            const std::uint32_t dim2319Kuo2Init[]       =   {   1   ,   1   ,   1   ,   7   ,   7   ,   57  ,   47  ,   43  ,   91  ,   415 ,   1903    ,   1067    ,   4281    ,   16095   ,   19919   ,0 };
            const std::uint32_t dim2320Kuo2Init[]       =   {   1   ,   3   ,   7   ,   7   ,   29  ,   7   ,   65  ,   19  ,   119 ,   473 ,   493 ,   2861    ,   7765    ,   15057   ,   13809   ,0 };
            const std::uint32_t dim2321Kuo2Init[]       =   {   1   ,   1   ,   5   ,   9   ,   3   ,   49  ,   83  ,   73  ,   135 ,   971 ,   1233    ,   3623    ,   7351    ,   15255   ,   29921   ,0 };
            const std::uint32_t dim2322Kuo2Init[]       =   {   1   ,   3   ,   3   ,   11  ,   29  ,   53  ,   5   ,   57  ,   41  ,   215 ,   477 ,   1851    ,   2219    ,   16289   ,   23801   ,0 };
            const std::uint32_t dim2323Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   9   ,   29  ,   55  ,   37  ,   415 ,   537 ,   1459    ,   431 ,   4559    ,   5569    ,   2031    ,0 };
            const std::uint32_t dim2324Kuo2Init[]       =   {   1   ,   1   ,   5   ,   1   ,   5   ,   15  ,   47  ,   159 ,   369 ,   677 ,   691 ,   2647    ,   6243    ,   15909   ,   17725   ,0 };
            const std::uint32_t dim2325Kuo2Init[]       =   {   1   ,   1   ,   5   ,   9   ,   13  ,   43  ,   45  ,   167 ,   503 ,   939 ,   1609    ,   1123    ,   2799    ,   3903    ,   27007   ,0 };
            const std::uint32_t dim2326Kuo2Init[]       =   {   1   ,   3   ,   1   ,   13  ,   19  ,   43  ,   95  ,   247 ,   475 ,   193 ,   1513    ,   885 ,   5391    ,   7041    ,   13473   ,0 };
            const std::uint32_t dim2327Kuo2Init[]       =   {   1   ,   1   ,   7   ,   13  ,   25  ,   61  ,   3   ,   237 ,   473 ,   671 ,   101 ,   1129    ,   787 ,   14697   ,   909 ,0 };
            const std::uint32_t dim2328Kuo2Init[]       =   {   1   ,   1   ,   7   ,   15  ,   25  ,   3   ,   53  ,   81  ,   147 ,   27  ,   1691    ,   2093    ,   2627    ,   9523    ,   16021   ,0 };
            const std::uint32_t dim2329Kuo2Init[]       =   {   1   ,   1   ,   7   ,   15  ,   11  ,   17  ,   35  ,   39  ,   187 ,   119 ,   541 ,   485 ,   3997    ,   16067   ,   12707   ,0 };
            const std::uint32_t dim2330Kuo2Init[]       =   {   1   ,   3   ,   7   ,   9   ,   17  ,   5   ,   57  ,   31  ,   75  ,   637 ,   1521    ,   3435    ,   387 ,   9325    ,   8165    ,0 };
            const std::uint32_t dim2331Kuo2Init[]       =   {   1   ,   1   ,   7   ,   3   ,   17  ,   33  ,   65  ,   55  ,   193 ,   55  ,   777 ,   151 ,   7605    ,   6927    ,   22731   ,0 };
            const std::uint32_t dim2332Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   9   ,   21  ,   33  ,   29  ,   395 ,   179 ,   445 ,   895 ,   203 ,   14665   ,   28945   ,0 };
            const std::uint32_t dim2333Kuo2Init[]       =   {   1   ,   3   ,   3   ,   11  ,   25  ,   63  ,   35  ,   51  ,   261 ,   83  ,   1227    ,   2897    ,   8157    ,   11703   ,   21067   ,0 };
            const std::uint32_t dim2334Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   15  ,   59  ,   1   ,   115 ,   225 ,   427 ,   397 ,   2113    ,   8117    ,   9387    ,   15817   ,0 };
            const std::uint32_t dim2335Kuo2Init[]       =   {   1   ,   1   ,   5   ,   3   ,   25  ,   23  ,   15  ,   3   ,   227 ,   341 ,   449 ,   217 ,   3583    ,   5617    ,   5215    ,0 };
            const std::uint32_t dim2336Kuo2Init[]       =   {   1   ,   3   ,   1   ,   9   ,   15  ,   61  ,   29  ,   241 ,   245 ,   857 ,   217 ,   1253    ,   2643    ,   435 ,   11991   ,0 };
            const std::uint32_t dim2337Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   27  ,   17  ,   89  ,   123 ,   121 ,   97  ,   1749    ,   3341    ,   2279    ,   1067    ,   28845   ,0 };
            const std::uint32_t dim2338Kuo2Init[]       =   {   1   ,   1   ,   1   ,   13  ,   17  ,   21  ,   27  ,   153 ,   135 ,   831 ,   361 ,   3487    ,   7221    ,   9343    ,   26523   ,0 };
            const std::uint32_t dim2339Kuo2Init[]       =   {   1   ,   1   ,   7   ,   15  ,   11  ,   59  ,   115 ,   103 ,   425 ,   221 ,   1485    ,   3471    ,   773 ,   14989   ,   1193    ,0 };
            const std::uint32_t dim2340Kuo2Init[]       =   {   1   ,   1   ,   7   ,   11  ,   1   ,   19  ,   113 ,   115 ,   149 ,   429 ,   1695    ,   409 ,   2343    ,   11843   ,   16319   ,0 };
            const std::uint32_t dim2341Kuo2Init[]       =   {   1   ,   1   ,   1   ,   9   ,   29  ,   5   ,   37  ,   29  ,   197 ,   331 ,   2033    ,   1319    ,   5667    ,   1311    ,   3563    ,0 };
            const std::uint32_t dim2342Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   13  ,   7   ,   73  ,   25  ,   391 ,   245 ,   1447    ,   4001    ,   7059    ,   3091    ,   27423   ,0 };
            const std::uint32_t dim2343Kuo2Init[]       =   {   1   ,   1   ,   5   ,   13  ,   21  ,   1   ,   125 ,   201 ,   103 ,   349 ,   1123    ,   2067    ,   7007    ,   12927   ,   27169   ,0 };
            const std::uint32_t dim2344Kuo2Init[]       =   {   1   ,   3   ,   3   ,   5   ,   25  ,   49  ,   73  ,   31  ,   55  ,   659 ,   1407    ,   3433    ,   6513    ,   151 ,   18409   ,0 };
            const std::uint32_t dim2345Kuo2Init[]       =   {   1   ,   1   ,   5   ,   13  ,   5   ,   19  ,   57  ,   73  ,   197 ,   69  ,   1477    ,   2763    ,   5691    ,   6639    ,   23613   ,0 };
            const std::uint32_t dim2346Kuo2Init[]       =   {   1   ,   3   ,   5   ,   5   ,   17  ,   47  ,   49  ,   77  ,   275 ,   341 ,   2017    ,   3257    ,   111 ,   925 ,   549 ,0 };
            const std::uint32_t dim2347Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   29  ,   7   ,   27  ,   195 ,   411 ,   435 ,   1689    ,   1537    ,   3381    ,   11521   ,   4505    ,0 };
            const std::uint32_t dim2348Kuo2Init[]       =   {   1   ,   1   ,   1   ,   15  ,   13  ,   23  ,   97  ,   189 ,   285 ,   351 ,   1371    ,   3161    ,   2337    ,   5239    ,   31675   ,0 };
            const std::uint32_t dim2349Kuo2Init[]       =   {   1   ,   1   ,   5   ,   3   ,   27  ,   57  ,   105 ,   197 ,   423 ,   109 ,   1967    ,   3363    ,   1925    ,   14261   ,   13569   ,0 };
            const std::uint32_t dim2350Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   21  ,   15  ,   7   ,   45  ,   411 ,   905 ,   1323    ,   3225    ,   5867    ,   2281    ,   13213   ,0 };
            const std::uint32_t dim2351Kuo2Init[]       =   {   1   ,   3   ,   7   ,   9   ,   29  ,   51  ,   41  ,   97  ,   393 ,   381 ,   1765    ,   1159    ,   965 ,   6013    ,   12541   ,0 };
            const std::uint32_t dim2352Kuo2Init[]       =   {   1   ,   1   ,   7   ,   5   ,   13  ,   35  ,   107 ,   231 ,   135 ,   745 ,   259 ,   2999    ,   1291    ,   14025   ,   2065    ,0 };
            const std::uint32_t dim2353Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   13  ,   29  ,   65  ,   91  ,   101 ,   469 ,   1337    ,   2717    ,   1781    ,   10019   ,   23097   ,0 };
            const std::uint32_t dim2354Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   3   ,   11  ,   23  ,   253 ,   175 ,   35  ,   1651    ,   3713    ,   3575    ,   4837    ,   10385   ,0 };
            const std::uint32_t dim2355Kuo2Init[]       =   {   1   ,   3   ,   1   ,   11  ,   13  ,   57  ,   33  ,   39  ,   55  ,   717 ,   679 ,   2417    ,   3665    ,   7753    ,   27659   ,0 };
            const std::uint32_t dim2356Kuo2Init[]       =   {   1   ,   3   ,   1   ,   15  ,   25  ,   9   ,   93  ,   205 ,   369 ,   567 ,   1525    ,   3797    ,   6047    ,   407 ,   2155    ,0 };
            const std::uint32_t dim2357Kuo2Init[]       =   {   1   ,   3   ,   7   ,   3   ,   5   ,   47  ,   15  ,   227 ,   325 ,   837 ,   1849    ,   3577    ,   1427    ,   5629    ,   17023   ,0 };
            const std::uint32_t dim2358Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   17  ,   23  ,   43  ,   231 ,   23  ,   95  ,   423 ,   2225    ,   8051    ,   6775    ,   4087    ,0 };
            const std::uint32_t dim2359Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   11  ,   45  ,   87  ,   213 ,   187 ,   159 ,   377 ,   3269    ,   2393    ,   7587    ,   8027    ,0 };
            const std::uint32_t dim2360Kuo2Init[]       =   {   1   ,   1   ,   5   ,   3   ,   5   ,   25  ,   115 ,   19  ,   229 ,   13  ,   935 ,   3269    ,   3877    ,   8081    ,   20583   ,0 };
            const std::uint32_t dim2361Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   31  ,   47  ,   21  ,   179 ,   503 ,   43  ,   915 ,   2987    ,   323 ,   15843   ,   18869   ,0 };
            const std::uint32_t dim2362Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   25  ,   9   ,   27  ,   169 ,   431 ,   495 ,   65  ,   3999    ,   4363    ,   8677    ,   12049   ,0 };
            const std::uint32_t dim2363Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   17  ,   37  ,   123 ,   197 ,   185 ,   501 ,   1471    ,   149 ,   4649    ,   2337    ,   10279   ,0 };
            const std::uint32_t dim2364Kuo2Init[]       =   {   1   ,   1   ,   7   ,   13  ,   11  ,   11  ,   3   ,   103 ,   43  ,   97  ,   349 ,   3515    ,   2621    ,   11587   ,   26495   ,0 };
            const std::uint32_t dim2365Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   3   ,   19  ,   99  ,   135 ,   355 ,   265 ,   1719    ,   2533    ,   4313    ,   11301   ,   18415   ,0 };
            const std::uint32_t dim2366Kuo2Init[]       =   {   1   ,   3   ,   7   ,   9   ,   1   ,   55  ,   115 ,   251 ,   293 ,   903 ,   931 ,   3687    ,   5019    ,   14277   ,   589 ,0 };
            const std::uint32_t dim2367Kuo2Init[]       =   {   1   ,   1   ,   3   ,   5   ,   31  ,   5   ,   123 ,   179 ,   51  ,   135 ,   9   ,   2779    ,   8143    ,   10033   ,   31473   ,0 };
            const std::uint32_t dim2368Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   3   ,   39  ,   87  ,   235 ,   289 ,   907 ,   1211    ,   453 ,   611 ,   4009    ,   25787   ,0 };
            const std::uint32_t dim2369Kuo2Init[]       =   {   1   ,   3   ,   7   ,   9   ,   27  ,   7   ,   47  ,   123 ,   333 ,   713 ,   1349    ,   1345    ,   1641    ,   5935    ,   19127   ,0 };
            const std::uint32_t dim2370Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   13  ,   17  ,   47  ,   235 ,   329 ,   955 ,   1761    ,   1957    ,   3611    ,   9705    ,   20307   ,0 };
            const std::uint32_t dim2371Kuo2Init[]       =   {   1   ,   1   ,   7   ,   15  ,   15  ,   59  ,   45  ,   17  ,   57  ,   871 ,   407 ,   943 ,   1881    ,   12929   ,   2181    ,0 };
            const std::uint32_t dim2372Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   7   ,   43  ,   41  ,   193 ,   29  ,   675 ,   1449    ,   2121    ,   1681    ,   13951   ,   21659   ,0 };
            const std::uint32_t dim2373Kuo2Init[]       =   {   1   ,   1   ,   5   ,   3   ,   21  ,   53  ,   63  ,   75  ,   7   ,   793 ,   245 ,   349 ,   4801    ,   4057    ,   13269   ,0 };
            const std::uint32_t dim2374Kuo2Init[]       =   {   1   ,   1   ,   3   ,   13  ,   23  ,   9   ,   109 ,   167 ,   165 ,   573 ,   685 ,   129 ,   1781    ,   10331   ,   9429    ,0 };
            const std::uint32_t dim2375Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   29  ,   43  ,   109 ,   25  ,   461 ,   991 ,   1509    ,   39  ,   6959    ,   13245   ,   18505   ,0 };
            const std::uint32_t dim2376Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   25  ,   43  ,   57  ,   61  ,   399 ,   787 ,   1479    ,   1613    ,   4295    ,   4189    ,   1371    ,0 };
            const std::uint32_t dim2377Kuo2Init[]       =   {   1   ,   3   ,   3   ,   13  ,   27  ,   57  ,   49  ,   139 ,   189 ,   683 ,   115 ,   963 ,   5833    ,   3249    ,   28785   ,0 };
            const std::uint32_t dim2378Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   3   ,   29  ,   41  ,   49  ,   341 ,   299 ,   1195    ,   57  ,   5791    ,   4409    ,   17733   ,0 };
            const std::uint32_t dim2379Kuo2Init[]       =   {   1   ,   1   ,   5   ,   7   ,   11  ,   21  ,   115 ,   145 ,   207 ,   41  ,   1531    ,   1897    ,   2627    ,   3653    ,   267 ,0 };
            const std::uint32_t dim2380Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   1   ,   3   ,   5   ,   79  ,   449 ,   281 ,   1711    ,   2863    ,   6267    ,   14863   ,   29957   ,0 };
            const std::uint32_t dim2381Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   15  ,   63  ,   127 ,   123 ,   457 ,   523 ,   1409    ,   2709    ,   4543    ,   13071   ,   17751   ,0 };
            const std::uint32_t dim2382Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   7   ,   61  ,   21  ,   139 ,   481 ,   747 ,   107 ,   1041    ,   359 ,   7683    ,   30327   ,0 };
            const std::uint32_t dim2383Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   3   ,   25  ,   7   ,   113 ,   39  ,   853 ,   1461    ,   2655    ,   2601    ,   7619    ,   2923    ,0 };
            const std::uint32_t dim2384Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   19  ,   25  ,   5   ,   27  ,   439 ,   407 ,   1281    ,   2487    ,   2275    ,   8793    ,   119 ,0 };
            const std::uint32_t dim2385Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   11  ,   37  ,   55  ,   131 ,   227 ,   79  ,   117 ,   2367    ,   1495    ,   15873   ,   24341   ,0 };
            const std::uint32_t dim2386Kuo2Init[]       =   {   1   ,   3   ,   1   ,   1   ,   11  ,   21  ,   35  ,   167 ,   413 ,   645 ,   1139    ,   2535    ,   8167    ,   5937    ,   29047   ,0 };
            const std::uint32_t dim2387Kuo2Init[]       =   {   1   ,   3   ,   7   ,   1   ,   5   ,   43  ,   31  ,   5   ,   419 ,   577 ,   1333    ,   1599    ,   3745    ,   10219   ,   27501   ,0 };
            const std::uint32_t dim2388Kuo2Init[]       =   {   1   ,   3   ,   1   ,   13  ,   21  ,   35  ,   115 ,   105 ,   187 ,   567 ,   1303    ,   1637    ,   3681    ,   14089   ,   12705   ,0 };
            const std::uint32_t dim2389Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   19  ,   61  ,   65  ,   115 ,   395 ,   501 ,   1015    ,   2117    ,   7647    ,   3077    ,   15265   ,0 };
            const std::uint32_t dim2390Kuo2Init[]       =   {   1   ,   3   ,   1   ,   1   ,   29  ,   11  ,   21  ,   177 ,   15  ,   193 ,   1177    ,   1225    ,   6251    ,   9983    ,   12599   ,0 };
            const std::uint32_t dim2391Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   5   ,   27  ,   27  ,   249 ,   197 ,   125 ,   571 ,   277 ,   4659    ,   14943   ,   19805   ,0 };
            const std::uint32_t dim2392Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   27  ,   37  ,   75  ,   235 ,   249 ,   191 ,   1123    ,   1355    ,   4249    ,   14971   ,   11349   ,0 };
            const std::uint32_t dim2393Kuo2Init[]       =   {   1   ,   1   ,   5   ,   9   ,   31  ,   19  ,   7   ,   91  ,   87  ,   515 ,   293 ,   1289    ,   2495    ,   11311   ,   3939    ,0 };
            const std::uint32_t dim2394Kuo2Init[]       =   {   1   ,   1   ,   5   ,   15  ,   15  ,   51  ,   43  ,   231 ,   401 ,   557 ,   689 ,   1103    ,   457 ,   3493    ,   22193   ,0 };
            const std::uint32_t dim2395Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   25  ,   39  ,   125 ,   91  ,   373 ,   331 ,   39  ,   35  ,   2397    ,   5043    ,   32061   ,0 };
            const std::uint32_t dim2396Kuo2Init[]       =   {   1   ,   1   ,   3   ,   11  ,   13  ,   37  ,   61  ,   27  ,   349 ,   377 ,   1589    ,   3711    ,   6551    ,   4795    ,   5507    ,0 };
            const std::uint32_t dim2397Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   25  ,   49  ,   107 ,   189 ,   371 ,   363 ,   1011    ,   2133    ,   6923    ,   2441    ,   8295    ,0 };
            const std::uint32_t dim2398Kuo2Init[]       =   {   1   ,   1   ,   3   ,   11  ,   3   ,   11  ,   27  ,   9   ,   193 ,   979 ,   867 ,   3085    ,   3783    ,   14851   ,   11565   ,0 };
            const std::uint32_t dim2399Kuo2Init[]       =   {   1   ,   1   ,   3   ,   1   ,   1   ,   55  ,   17  ,   239 ,   351 ,   373 ,   939 ,   2115    ,   3697    ,   7881    ,   6603    ,0 };
            const std::uint32_t dim2400Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   23  ,   17  ,   81  ,   143 ,   497 ,   875 ,   939 ,   3193    ,   7023    ,   3327    ,   29327   ,0 };
            const std::uint32_t dim2401Kuo2Init[]       =   {   1   ,   3   ,   7   ,   13  ,   27  ,   61  ,   1   ,   127 ,   369 ,   471 ,   1511    ,   2227    ,   565 ,   4121    ,   11155   ,0 };
            const std::uint32_t dim2402Kuo2Init[]       =   {   1   ,   3   ,   3   ,   5   ,   5   ,   53  ,   77  ,   185 ,   11  ,   801 ,   1289    ,   975 ,   5191    ,   3733    ,   18489   ,0 };
            const std::uint32_t dim2403Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   19  ,   19  ,   67  ,   9   ,   121 ,   473 ,   377 ,   3771    ,   7561    ,   5751    ,   26295   ,0 };
            const std::uint32_t dim2404Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   19  ,   41  ,   7   ,   227 ,   465 ,   803 ,   1979    ,   281 ,   1337    ,   7973    ,   20341   ,0 };
            const std::uint32_t dim2405Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   9   ,   5   ,   123 ,   45  ,   65  ,   801 ,   373 ,   2093    ,   1473    ,   14503   ,   1401    ,0 };
            const std::uint32_t dim2406Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   29  ,   39  ,   123 ,   17  ,   253 ,   649 ,   1755    ,   4081    ,   3415    ,   8805    ,   28635   ,0 };
            const std::uint32_t dim2407Kuo2Init[]       =   {   1   ,   3   ,   1   ,   1   ,   23  ,   7   ,   57  ,   163 ,   93  ,   829 ,   93  ,   1767    ,   1073    ,   14825   ,   21505   ,0 };
            const std::uint32_t dim2408Kuo2Init[]       =   {   1   ,   1   ,   7   ,   13  ,   21  ,   59  ,   59  ,   229 ,   175 ,   485 ,   621 ,   3785    ,   4949    ,   12281   ,   14569   ,0 };
            const std::uint32_t dim2409Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   7   ,   51  ,   123 ,   221 ,   119 ,   61  ,   1271    ,   1857    ,   3505    ,   14413   ,   20975   ,0 };
            const std::uint32_t dim2410Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   17  ,   51  ,   67  ,   123 ,   121 ,   379 ,   605 ,   3361    ,   5557    ,   9127    ,   15251   ,0 };
            const std::uint32_t dim2411Kuo2Init[]       =   {   1   ,   3   ,   7   ,   9   ,   27  ,   11  ,   33  ,   33  ,   439 ,   347 ,   1305    ,   11  ,   6839    ,   493 ,   771 ,0 };
            const std::uint32_t dim2412Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   5   ,   13  ,   7   ,   131 ,   129 ,   865 ,   1115    ,   2651    ,   1567    ,   783 ,   15073   ,0 };
            const std::uint32_t dim2413Kuo2Init[]       =   {   1   ,   1   ,   3   ,   11  ,   11  ,   13  ,   95  ,   115 ,   361 ,   1009    ,   413 ,   2671    ,   6267    ,   5393    ,   18963   ,0 };
            const std::uint32_t dim2414Kuo2Init[]       =   {   1   ,   3   ,   1   ,   9   ,   27  ,   11  ,   33  ,   183 ,   343 ,   113 ,   1323    ,   3197    ,   3889    ,   8533    ,   31493   ,0 };
            const std::uint32_t dim2415Kuo2Init[]       =   {   1   ,   3   ,   3   ,   11  ,   11  ,   21  ,   93  ,   35  ,   177 ,   133 ,   539 ,   679 ,   6263    ,   8619    ,   2751    ,0 };
            const std::uint32_t dim2416Kuo2Init[]       =   {   1   ,   1   ,   3   ,   1   ,   27  ,   31  ,   21  ,   157 ,   365 ,   635 ,   1279    ,   575 ,   2245    ,   11597   ,   3899    ,0 };
            const std::uint32_t dim2417Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   7   ,   45  ,   15  ,   237 ,   191 ,   541 ,   1631    ,   1459    ,   1973    ,   15333   ,   30419   ,0 };
            const std::uint32_t dim2418Kuo2Init[]       =   {   1   ,   3   ,   1   ,   13  ,   3   ,   47  ,   103 ,   101 ,   423 ,   739 ,   947 ,   3225    ,   783 ,   14771   ,   20183   ,0 };
            const std::uint32_t dim2419Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   23  ,   19  ,   21  ,   245 ,   341 ,   907 ,   745 ,   1913    ,   1545    ,   7801    ,   9995    ,0 };
            const std::uint32_t dim2420Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   7   ,   47  ,   55  ,   15  ,   193 ,   123 ,   73  ,   427 ,   6415    ,   6611    ,   6317    ,0 };
            const std::uint32_t dim2421Kuo2Init[]       =   {   1   ,   1   ,   1   ,   7   ,   3   ,   17  ,   27  ,   5   ,   295 ,   453 ,   1503    ,   2327    ,   4209    ,   3663    ,   16843   ,0 };
            const std::uint32_t dim2422Kuo2Init[]       =   {   1   ,   1   ,   1   ,   3   ,   25  ,   19  ,   41  ,   161 ,   333 ,   153 ,   999 ,   1129    ,   103 ,   9471    ,   12707   ,0 };
            const std::uint32_t dim2423Kuo2Init[]       =   {   1   ,   3   ,   3   ,   3   ,   21  ,   37  ,   73  ,   159 ,   179 ,   913 ,   691 ,   755 ,   3033    ,   1999    ,   15459   ,0 };
            const std::uint32_t dim2424Kuo2Init[]       =   {   1   ,   1   ,   5   ,   13  ,   1   ,   3   ,   67  ,   131 ,   119 ,   769 ,   747 ,   1047    ,   6751    ,   2753    ,   22611   ,0 };
            const std::uint32_t dim2425Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   11  ,   1   ,   27  ,   81  ,   423 ,   691 ,   357 ,   3679    ,   2467    ,   15107   ,   13029   ,0 };
            const std::uint32_t dim2426Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   21  ,   21  ,   109 ,   69  ,   319 ,   283 ,   1831    ,   1403    ,   5531    ,   14461   ,   14057   ,0 };
            const std::uint32_t dim2427Kuo2Init[]       =   {   1   ,   3   ,   7   ,   13  ,   21  ,   33  ,   77  ,   149 ,   495 ,   361 ,   401 ,   3313    ,   1849    ,   14009   ,   5933    ,0 };
            const std::uint32_t dim2428Kuo2Init[]       =   {   1   ,   3   ,   7   ,   15  ,   11  ,   3   ,   33  ,   181 ,   21  ,   437 ,   1843    ,   3591    ,   589 ,   1721    ,   27495   ,0 };
            const std::uint32_t dim2429Kuo2Init[]       =   {   1   ,   1   ,   1   ,   9   ,   25  ,   61  ,   103 ,   25  ,   71  ,   471 ,   219 ,   3623    ,   1517    ,   15471   ,   23179   ,0 };
            const std::uint32_t dim2430Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   7   ,   59  ,   99  ,   143 ,   387 ,   231 ,   241 ,   1215    ,   3785    ,   13543   ,   27469   ,0 };
            const std::uint32_t dim2431Kuo2Init[]       =   {   1   ,   3   ,   1   ,   11  ,   25  ,   61  ,   93  ,   171 ,   421 ,   515 ,   1761    ,   1399    ,   7791    ,   291 ,   28455   ,0 };
            const std::uint32_t dim2432Kuo2Init[]       =   {   1   ,   1   ,   3   ,   11  ,   1   ,   23  ,   117 ,   251 ,   467 ,   445 ,   737 ,   2637    ,   4183    ,   8561    ,   24977   ,0 };
            const std::uint32_t dim2433Kuo2Init[]       =   {   1   ,   3   ,   5   ,   11  ,   11  ,   35  ,   111 ,   209 ,   415 ,   485 ,   1609    ,   1113    ,   3329    ,   15365   ,   1999    ,0 };
            const std::uint32_t dim2434Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   19  ,   17  ,   43  ,   67  ,   191 ,   711 ,   395 ,   921 ,   2511    ,   8417    ,   4071    ,0 };
            const std::uint32_t dim2435Kuo2Init[]       =   {   1   ,   3   ,   3   ,   11  ,   9   ,   5   ,   89  ,   115 ,   451 ,   533 ,   1057    ,   1835    ,   2137    ,   9253    ,   19217   ,0 };
            const std::uint32_t dim2436Kuo2Init[]       =   {   1   ,   3   ,   7   ,   11  ,   9   ,   45  ,   119 ,   89  ,   485 ,   109 ,   1755    ,   709 ,   7729    ,   14659   ,   19203   ,0 };
            const std::uint32_t dim2437Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   11  ,   7   ,   107 ,   113 ,   305 ,   431 ,   481 ,   2965    ,   6195    ,   2369    ,   14843   ,0 };
            const std::uint32_t dim2438Kuo2Init[]       =   {   1   ,   3   ,   1   ,   13  ,   5   ,   37  ,   11  ,   193 ,   135 ,   697 ,   665 ,   3085    ,   4691    ,   3799    ,   11915   ,0 };
            const std::uint32_t dim2439Kuo2Init[]       =   {   1   ,   1   ,   1   ,   9   ,   1   ,   47  ,   23  ,   143 ,   255 ,   93  ,   615 ,   2039    ,   6591    ,   14479   ,   24963   ,0 };
            const std::uint32_t dim2440Kuo2Init[]       =   {   1   ,   3   ,   3   ,   11  ,   15  ,   11  ,   75  ,   57  ,   151 ,   29  ,   1073    ,   2763    ,   5613    ,   15703   ,   2447    ,0 };
            const std::uint32_t dim2441Kuo2Init[]       =   {   1   ,   1   ,   5   ,   9   ,   19  ,   15  ,   79  ,   113 ,   359 ,   997 ,   1799    ,   695 ,   7075    ,   10091   ,   15271   ,0 };
            const std::uint32_t dim2442Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   3   ,   63  ,   45  ,   253 ,   257 ,   739 ,   1759    ,   317 ,   1955    ,   1283    ,   11127   ,0 };
            const std::uint32_t dim2443Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   29  ,   37  ,   67  ,   177 ,   203 ,   497 ,   947 ,   2339    ,   2401    ,   9199    ,   22331   ,0 };
            const std::uint32_t dim2444Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   23  ,   15  ,   67  ,   131 ,   213 ,   21  ,   1167    ,   1729    ,   3297    ,   337 ,   12253   ,0 };
            const std::uint32_t dim2445Kuo2Init[]       =   {   1   ,   3   ,   3   ,   11  ,   21  ,   7   ,   69  ,   79  ,   297 ,   401 ,   1491    ,   1655    ,   2525    ,   4871    ,   17919   ,0 };
            const std::uint32_t dim2446Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   5   ,   15  ,   113 ,   45  ,   205 ,   317 ,   109 ,   2793    ,   4975    ,   5563    ,   3649    ,0 };
            const std::uint32_t dim2447Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   13  ,   59  ,   17  ,   63  ,   311 ,   161 ,   419 ,   1693    ,   2937    ,   8671    ,   24741   ,0 };
            const std::uint32_t dim2448Kuo2Init[]       =   {   1   ,   1   ,   5   ,   3   ,   17  ,   21  ,   103 ,   105 ,   117 ,   211 ,   941 ,   385 ,   6455    ,   9069    ,   10147   ,0 };
            const std::uint32_t dim2449Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   5   ,   13  ,   43  ,   155 ,   89  ,   747 ,   359 ,   219 ,   6597    ,   5175    ,   24585   ,0 };
            const std::uint32_t dim2450Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   7   ,   45  ,   17  ,   169 ,   421 ,   161 ,   207 ,   2033    ,   4805    ,   2737    ,   7799    ,0 };
            const std::uint32_t dim2451Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   15  ,   55  ,   55  ,   219 ,   441 ,   409 ,   443 ,   3363    ,   6895    ,   16339   ,   16091   ,0 };
            const std::uint32_t dim2452Kuo2Init[]       =   {   1   ,   1   ,   3   ,   5   ,   3   ,   23  ,   17  ,   217 ,   93  ,   799 ,   1419    ,   3405    ,   7911    ,   15609   ,   25461   ,0 };
            const std::uint32_t dim2453Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   29  ,   19  ,   17  ,   97  ,   319 ,   743 ,   1773    ,   2513    ,   2395    ,   1885    ,   6835    ,0 };
            const std::uint32_t dim2454Kuo2Init[]       =   {   1   ,   3   ,   3   ,   3   ,   25  ,   41  ,   79  ,   191 ,   175 ,   319 ,   1903    ,   2281    ,   5709    ,   2817    ,   14213   ,0 };
            const std::uint32_t dim2455Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   21  ,   55  ,   9   ,   51  ,   223 ,   519 ,   225 ,   2543    ,   4183    ,   283 ,   599 ,0 };
            const std::uint32_t dim2456Kuo2Init[]       =   {   1   ,   1   ,   1   ,   15  ,   23  ,   39  ,   21  ,   171 ,   167 ,   739 ,   1779    ,   3469    ,   8121    ,   7013    ,   23445   ,0 };
            const std::uint32_t dim2457Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   9   ,   5   ,   55  ,   253 ,   43  ,   397 ,   927 ,   237 ,   4459    ,   12817   ,   29563   ,0 };
            const std::uint32_t dim2458Kuo2Init[]       =   {   1   ,   3   ,   7   ,   3   ,   3   ,   57  ,   113 ,   221 ,   391 ,   365 ,   311 ,   1027    ,   3369    ,   7637    ,   25765   ,0 };
            const std::uint32_t dim2459Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   19  ,   3   ,   91  ,   161 ,   421 ,   961 ,   1237    ,   4063    ,   2573    ,   483 ,   3375    ,0 };
            const std::uint32_t dim2460Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   19  ,   35  ,   119 ,   211 ,   489 ,   649 ,   1233    ,   447 ,   3727    ,   15541   ,   4769    ,0 };
            const std::uint32_t dim2461Kuo2Init[]       =   {   1   ,   3   ,   7   ,   15  ,   7   ,   1   ,   15  ,   103 ,   81  ,   59  ,   1953    ,   3729    ,   6451    ,   15051   ,   17421   ,0 };
            const std::uint32_t dim2462Kuo2Init[]       =   {   1   ,   1   ,   3   ,   11  ,   11  ,   41  ,   73  ,   63  ,   485 ,   47  ,   585 ,   3503    ,   4787    ,   12445   ,   8513    ,0 };
            const std::uint32_t dim2463Kuo2Init[]       =   {   1   ,   1   ,   5   ,   1   ,   29  ,   35  ,   37  ,   99  ,   443 ,   171 ,   1455    ,   1705    ,   5587    ,   8791    ,   6269    ,0 };
            const std::uint32_t dim2464Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   19  ,   23  ,   103 ,   19  ,   307 ,   615 ,   2037    ,   3289    ,   1453    ,   12955   ,   28069   ,0 };
            const std::uint32_t dim2465Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   21  ,   57  ,   89  ,   29  ,   419 ,   681 ,   1413    ,   3375    ,   7341    ,   14825   ,   18251   ,0 };
            const std::uint32_t dim2466Kuo2Init[]       =   {   1   ,   3   ,   5   ,   11  ,   21  ,   49  ,   67  ,   69  ,   47  ,   33  ,   449 ,   1831    ,   1125    ,   1011    ,   16223   ,0 };
            const std::uint32_t dim2467Kuo2Init[]       =   {   1   ,   1   ,   3   ,   5   ,   17  ,   11  ,   67  ,   237 ,   299 ,   843 ,   1177    ,   1825    ,   1109    ,   12157   ,   9347    ,0 };
            const std::uint32_t dim2468Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   21  ,   63  ,   47  ,   239 ,   219 ,   319 ,   1505    ,   393 ,   143 ,   5009    ,   9017    ,0 };
            const std::uint32_t dim2469Kuo2Init[]       =   {   1   ,   3   ,   5   ,   11  ,   1   ,   25  ,   21  ,   1   ,   15  ,   947 ,   1533    ,   1201    ,   3929    ,   7943    ,   9335    ,0 };
            const std::uint32_t dim2470Kuo2Init[]       =   {   1   ,   1   ,   1   ,   15  ,   29  ,   45  ,   29  ,   119 ,   419 ,   793 ,   345 ,   789 ,   6415    ,   5481    ,   31111   ,0 };
            const std::uint32_t dim2471Kuo2Init[]       =   {   1   ,   1   ,   1   ,   1   ,   19  ,   59  ,   3   ,   199 ,   247 ,   905 ,   1347    ,   4021    ,   1913    ,   15315   ,   15265   ,0 };
            const std::uint32_t dim2472Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   23  ,   63  ,   1   ,   87  ,   455 ,   1013    ,   789 ,   603 ,   7027    ,   11527   ,   17571   ,0 };
            const std::uint32_t dim2473Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   13  ,   27  ,   95  ,   61  ,   343 ,   201 ,   997 ,   2153    ,   3239    ,   2475    ,   9827    ,0 };
            const std::uint32_t dim2474Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   29  ,   49  ,   77  ,   245 ,   167 ,   873 ,   1467    ,   2475    ,   3951    ,   10253   ,   8345    ,0 };
            const std::uint32_t dim2475Kuo2Init[]       =   {   1   ,   1   ,   1   ,   15  ,   5   ,   41  ,   71  ,   81  ,   491 ,   971 ,   1955    ,   1901    ,   4383    ,   13961   ,   3745    ,0 };
            const std::uint32_t dim2476Kuo2Init[]       =   {   1   ,   1   ,   1   ,   7   ,   21  ,   31  ,   11  ,   247 ,   47  ,   251 ,   509 ,   739 ,   2745    ,   14531   ,   19633   ,0 };
            const std::uint32_t dim2477Kuo2Init[]       =   {   1   ,   1   ,   7   ,   13  ,   31  ,   47  ,   105 ,   167 ,   443 ,   623 ,   503 ,   3283    ,   1935    ,   2627    ,   19807   ,0 };
            const std::uint32_t dim2478Kuo2Init[]       =   {   1   ,   1   ,   7   ,   3   ,   21  ,   9   ,   67  ,   39  ,   263 ,   395 ,   407 ,   3813    ,   5033    ,   14647   ,   11963   ,0 };
            const std::uint32_t dim2479Kuo2Init[]       =   {   1   ,   1   ,   1   ,   9   ,   3   ,   29  ,   9   ,   101 ,   313 ,   861 ,   529 ,   1171    ,   7943    ,   13701   ,   16497   ,0 };
            const std::uint32_t dim2480Kuo2Init[]       =   {   1   ,   1   ,   5   ,   15  ,   9   ,   3   ,   29  ,   53  ,   379 ,   721 ,   1777    ,   2767    ,   7591    ,   8923    ,   16909   ,0 };
            const std::uint32_t dim2481Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   19  ,   7   ,   103 ,   189 ,   325 ,   995 ,   1419    ,   333 ,   4053    ,   10441   ,   1287    ,0 };
            const std::uint32_t dim2482Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   1   ,   1   ,   53  ,   31  ,   425 ,   477 ,   695 ,   389 ,   6523    ,   7565    ,   95  ,0 };
            const std::uint32_t dim2483Kuo2Init[]       =   {   1   ,   1   ,   7   ,   15  ,   1   ,   5   ,   75  ,   211 ,   487 ,   641 ,   287 ,   3709    ,   2257    ,   12017   ,   31921   ,0 };
            const std::uint32_t dim2484Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   31  ,   7   ,   33  ,   177 ,   349 ,   257 ,   1383    ,   303 ,   469 ,   10941   ,   16211   ,0 };
            const std::uint32_t dim2485Kuo2Init[]       =   {   1   ,   1   ,   5   ,   1   ,   7   ,   21  ,   89  ,   229 ,   237 ,   447 ,   1805    ,   3271    ,   7073    ,   3401    ,   7143    ,0 };
            const std::uint32_t dim2486Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   11  ,   35  ,   127 ,   139 ,   497 ,   629 ,   543 ,   77  ,   2505    ,   8781    ,   30445   ,0 };
            const std::uint32_t dim2487Kuo2Init[]       =   {   1   ,   1   ,   7   ,   13  ,   1   ,   27  ,   59  ,   125 ,   399 ,   37  ,   597 ,   431 ,   4531    ,   7525    ,   2629    ,0 };
            const std::uint32_t dim2488Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   25  ,   27  ,   75  ,   221 ,   269 ,   587 ,   669 ,   1807    ,   5437    ,   12715   ,   22419   ,0 };
            const std::uint32_t dim2489Kuo2Init[]       =   {   1   ,   1   ,   5   ,   7   ,   31  ,   29  ,   7   ,   135 ,   493 ,   1011    ,   1273    ,   3899    ,   6069    ,   9657    ,   21375   ,0 };
            const std::uint32_t dim2490Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   3   ,   13  ,   123 ,   39  ,   37  ,   397 ,   1023    ,   2733    ,   2275    ,   8415    ,   12011   ,0 };
            const std::uint32_t dim2491Kuo2Init[]       =   {   1   ,   1   ,   5   ,   3   ,   1   ,   63  ,   115 ,   191 ,   159 ,   283 ,   7   ,   1073    ,   5609    ,   13113   ,   1755    ,0 };
            const std::uint32_t dim2492Kuo2Init[]       =   {   1   ,   1   ,   3   ,   5   ,   11  ,   35  ,   83  ,   91  ,   315 ,   823 ,   1961    ,   1023    ,   4191    ,   1013    ,   24451   ,0 };
            const std::uint32_t dim2493Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   31  ,   13  ,   121 ,   213 ,   289 ,   763 ,   297 ,   3405    ,   4987    ,   13713   ,   16853   ,0 };
            const std::uint32_t dim2494Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   9   ,   57  ,   53  ,   171 ,   203 ,   71  ,   1973    ,   3555    ,   5079    ,   16173   ,   6399    ,0 };
            const std::uint32_t dim2495Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   21  ,   51  ,   105 ,   237 ,   491 ,   465 ,   597 ,   3055    ,   1657    ,   131 ,   19281   ,0 };
            const std::uint32_t dim2496Kuo2Init[]       =   {   1   ,   1   ,   7   ,   15  ,   15  ,   41  ,   1   ,   61  ,   3   ,   879 ,   1985    ,   651 ,   3945    ,   6979    ,   793 ,0 };
            const std::uint32_t dim2497Kuo2Init[]       =   {   1   ,   1   ,   1   ,   3   ,   15  ,   45  ,   51  ,   23  ,   1   ,   265 ,   1345    ,   3967    ,   1419    ,   247 ,   9225    ,0 };
            const std::uint32_t dim2498Kuo2Init[]       =   {   1   ,   1   ,   5   ,   5   ,   19  ,   31  ,   107 ,   73  ,   331 ,   135 ,   1645    ,   3465    ,   6809    ,   12793   ,   15589   ,0 };
            const std::uint32_t dim2499Kuo2Init[]       =   {   1   ,   1   ,   1   ,   1   ,   29  ,   47  ,   103 ,   133 ,   15  ,   113 ,   717 ,   891 ,   1967    ,   6063    ,   24975   ,0 };
            const std::uint32_t dim2500Kuo2Init[]       =   {   1   ,   1   ,   3   ,   1   ,   17  ,   39  ,   3   ,   103 ,   373 ,   379 ,   267 ,   131 ,   473 ,   10475   ,   18595   ,0 };
            const std::uint32_t dim2501Kuo2Init[]       =   {   1   ,   1   ,   3   ,   3   ,   27  ,   51  ,   17  ,   227 ,   425 ,   29  ,   969 ,   1515    ,   7045    ,   5869    ,   2031    ,0 };
            const std::uint32_t dim2502Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   17  ,   59  ,   69  ,   21  ,   119 ,   359 ,   1805    ,   1225    ,   1969    ,   14601   ,   7175    ,0 };
            const std::uint32_t dim2503Kuo2Init[]       =   {   1   ,   3   ,   7   ,   9   ,   5   ,   23  ,   89  ,   89  ,   269 ,   159 ,   2017    ,   269 ,   4247    ,   14369   ,   4413    ,0 };
            const std::uint32_t dim2504Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   19  ,   35  ,   67  ,   243 ,   71  ,   653 ,   1673    ,   647 ,   1171    ,   16167   ,   15223   ,0 };
            const std::uint32_t dim2505Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   19  ,   37  ,   27  ,   69  ,   253 ,   233 ,   933 ,   649 ,   5449    ,   10651   ,   24709   ,0 };
            const std::uint32_t dim2506Kuo2Init[]       =   {   1   ,   1   ,   5   ,   15  ,   13  ,   39  ,   113 ,   253 ,   351 ,   281 ,   309 ,   2351    ,   2225    ,   14121   ,   24059   ,0 };
            const std::uint32_t dim2507Kuo2Init[]       =   {   1   ,   3   ,   1   ,   9   ,   13  ,   43  ,   115 ,   137 ,   107 ,   921 ,   37  ,   1743    ,   183 ,   5037    ,   4649    ,0 };
            const std::uint32_t dim2508Kuo2Init[]       =   {   1   ,   1   ,   5   ,   15  ,   23  ,   11  ,   121 ,   161 ,   337 ,   155 ,   1053    ,   2907    ,   1163    ,   12929   ,   9065    ,0 };
            const std::uint32_t dim2509Kuo2Init[]       =   {   1   ,   1   ,   3   ,   1   ,   1   ,   23  ,   85  ,   253 ,   245 ,   359 ,   1881    ,   581 ,   381 ,   15877   ,   15781   ,0 };
            const std::uint32_t dim2510Kuo2Init[]       =   {   1   ,   3   ,   5   ,   11  ,   17  ,   49  ,   33  ,   133 ,   247 ,   339 ,   969 ,   3347    ,   1791    ,   16115   ,   10821   ,0 };
            const std::uint32_t dim2511Kuo2Init[]       =   {   1   ,   3   ,   1   ,   9   ,   31  ,   41  ,   31  ,   103 ,   79  ,   339 ,   1311    ,   2609    ,   7455    ,   4543    ,   14765   ,0 };
            const std::uint32_t dim2512Kuo2Init[]       =   {   1   ,   3   ,   7   ,   13  ,   13  ,   25  ,   75  ,   219 ,   443 ,   543 ,   9   ,   1101    ,   6833    ,   2091    ,   20729   ,0 };
            const std::uint32_t dim2513Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   3   ,   51  ,   125 ,   137 ,   107 ,   123 ,   1113    ,   3735    ,   655 ,   6897    ,   32047   ,0 };
            const std::uint32_t dim2514Kuo2Init[]       =   {   1   ,   1   ,   3   ,   1   ,   17  ,   49  ,   31  ,   87  ,   399 ,   405 ,   1497    ,   1199    ,   6135    ,   6889    ,   23913   ,0 };
            const std::uint32_t dim2515Kuo2Init[]       =   {   1   ,   1   ,   1   ,   13  ,   17  ,   59  ,   87  ,   153 ,   183 ,   539 ,   1231    ,   569 ,   1877    ,   11605   ,   9301    ,0 };
            const std::uint32_t dim2516Kuo2Init[]       =   {   1   ,   3   ,   1   ,   9   ,   15  ,   57  ,   41  ,   247 ,   107 ,   1019    ,   1423    ,   49  ,   3093    ,   1667    ,   28241   ,0 };
            const std::uint32_t dim2517Kuo2Init[]       =   {   1   ,   1   ,   1   ,   1   ,   19  ,   9   ,   41  ,   79  ,   383 ,   83  ,   1091    ,   457 ,   7245    ,   3639    ,   24411   ,0 };
            const std::uint32_t dim2518Kuo2Init[]       =   {   1   ,   3   ,   7   ,   11  ,   31  ,   23  ,   71  ,   157 ,   327 ,   973 ,   39  ,   1303    ,   3519    ,   6071    ,   19297   ,0 };
            const std::uint32_t dim2519Kuo2Init[]       =   {   1   ,   1   ,   7   ,   13  ,   27  ,   17  ,   105 ,   245 ,   83  ,   825 ,   33  ,   2331    ,   6469    ,   5547    ,   5409    ,0 };
            const std::uint32_t dim2520Kuo2Init[]       =   {   1   ,   3   ,   1   ,   9   ,   21  ,   1   ,   105 ,   161 ,   269 ,   767 ,   2039    ,   941 ,   5063    ,   2763    ,   31333   ,0 };
            const std::uint32_t dim2521Kuo2Init[]       =   {   1   ,   3   ,   1   ,   1   ,   17  ,   33  ,   37  ,   185 ,   505 ,   979 ,   239 ,   3001    ,   1441    ,   7803    ,   23377   ,0 };
            const std::uint32_t dim2522Kuo2Init[]       =   {   1   ,   1   ,   3   ,   3   ,   23  ,   5   ,   63  ,   249 ,   409 ,   501 ,   1177    ,   655 ,   5109    ,   309 ,   3791    ,0 };
            const std::uint32_t dim2523Kuo2Init[]       =   {   1   ,   1   ,   5   ,   1   ,   11  ,   37  ,   67  ,   5   ,   399 ,   479 ,   1119    ,   295 ,   2343    ,   11141   ,   28209   ,0 };
            const std::uint32_t dim2524Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   3   ,   17  ,   75  ,   93  ,   69  ,   957 ,   1851    ,   2297    ,   6757    ,   9401    ,   15847   ,0 };
            const std::uint32_t dim2525Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   5   ,   39  ,   75  ,   143 ,   235 ,   411 ,   1309    ,   1327    ,   863 ,   5579    ,   5153    ,0 };
            const std::uint32_t dim2526Kuo2Init[]       =   {   1   ,   1   ,   7   ,   13  ,   23  ,   3   ,   39  ,   7   ,   257 ,   941 ,   1441    ,   2931    ,   1651    ,   4669    ,   16193   ,0 };
            const std::uint32_t dim2527Kuo2Init[]       =   {   1   ,   1   ,   1   ,   15  ,   27  ,   43  ,   51  ,   197 ,   369 ,   531 ,   397 ,   387 ,   3021    ,   8885    ,   21943   ,0 };
            const std::uint32_t dim2528Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   25  ,   49  ,   9   ,   227 ,   501 ,   687 ,   131 ,   2899    ,   7175    ,   11359   ,   19997   ,0 };
            const std::uint32_t dim2529Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   23  ,   1   ,   51  ,   53  ,   437 ,   331 ,   1503    ,   3345    ,   5909    ,   439 ,   4771    ,0 };
            const std::uint32_t dim2530Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   13  ,   13  ,   101 ,   71  ,   345 ,   675 ,   653 ,   2297    ,   1099    ,   11115   ,   28917   ,0 };
            const std::uint32_t dim2531Kuo2Init[]       =   {   1   ,   1   ,   3   ,   5   ,   5   ,   23  ,   69  ,   155 ,   133 ,   527 ,   1443    ,   1099    ,   2395    ,   2213    ,   16533   ,0 };
            const std::uint32_t dim2532Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   9   ,   37  ,   75  ,   17  ,   397 ,   919 ,   1223    ,   491 ,   4719    ,   3915    ,   30101   ,0 };
            const std::uint32_t dim2533Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   7   ,   51  ,   105 ,   31  ,   5   ,   149 ,   1275    ,   1381    ,   1963    ,   14737   ,   30975   ,0 };
            const std::uint32_t dim2534Kuo2Init[]       =   {   1   ,   1   ,   7   ,   5   ,   1   ,   51  ,   49  ,   21  ,   371 ,   293 ,   159 ,   3681    ,   7979    ,   15611   ,   255 ,0 };
            const std::uint32_t dim2535Kuo2Init[]       =   {   1   ,   1   ,   1   ,   7   ,   27  ,   53  ,   51  ,   135 ,   181 ,   419 ,   757 ,   2913    ,   941 ,   5863    ,   19619   ,0 };
            const std::uint32_t dim2536Kuo2Init[]       =   {   1   ,   1   ,   7   ,   5   ,   19  ,   1   ,   115 ,   113 ,   29  ,   355 ,   1203    ,   279 ,   7967    ,   12419   ,   1003    ,0 };
            const std::uint32_t dim2537Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   1   ,   63  ,   109 ,   215 ,   285 ,   801 ,   1995    ,   3771    ,   4113    ,   11973   ,   16507   ,0 };
            const std::uint32_t dim2538Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   19  ,   55  ,   107 ,   139 ,   95  ,   139 ,   1595    ,   929 ,   7023    ,   15245   ,   30163   ,0 };
            const std::uint32_t dim2539Kuo2Init[]       =   {   1   ,   1   ,   1   ,   13  ,   19  ,   1   ,   33  ,   23  ,   325 ,   245 ,   1671    ,   3065    ,   6767    ,   13583   ,   4683    ,0 };
            const std::uint32_t dim2540Kuo2Init[]       =   {   1   ,   1   ,   7   ,   5   ,   17  ,   55  ,   33  ,   235 ,   119 ,   715 ,   83  ,   1089    ,   5943    ,   11897   ,   13259   ,0 };
            const std::uint32_t dim2541Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   25  ,   27  ,   111 ,   225 ,   99  ,   917 ,   731 ,   2617    ,   7915    ,   7283    ,   357 ,0 };
            const std::uint32_t dim2542Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   13  ,   9   ,   127 ,   251 ,   189 ,   573 ,   1897    ,   2147    ,   2641    ,   13191   ,   3847    ,0 };
            const std::uint32_t dim2543Kuo2Init[]       =   {   1   ,   3   ,   7   ,   1   ,   19  ,   49  ,   49  ,   231 ,   321 ,   67  ,   1067    ,   2267    ,   7873    ,   2825    ,   445 ,0 };
            const std::uint32_t dim2544Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   27  ,   55  ,   23  ,   155 ,   103 ,   969 ,   1929    ,   2171    ,   5601    ,   1267    ,   31897   ,0 };
            const std::uint32_t dim2545Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   3   ,   27  ,   107 ,   7   ,   61  ,   601 ,   1957    ,   4075    ,   2955    ,   7717    ,   10473   ,0 };
            const std::uint32_t dim2546Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   31  ,   25  ,   111 ,   11  ,   391 ,   727 ,   243 ,   1471    ,   143 ,   16161   ,   5591    ,0 };
            const std::uint32_t dim2547Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   11  ,   43  ,   117 ,   117 ,   173 ,   933 ,   163 ,   1571    ,   1901    ,   3201    ,   1151    ,0 };
            const std::uint32_t dim2548Kuo2Init[]       =   {   1   ,   3   ,   5   ,   3   ,   17  ,   13  ,   47  ,   217 ,   351 ,   777 ,   607 ,   401 ,   3485    ,   8679    ,   20357   ,0 };
            const std::uint32_t dim2549Kuo2Init[]       =   {   1   ,   1   ,   7   ,   15  ,   5   ,   13  ,   37  ,   7   ,   469 ,   413 ,   1343    ,   947 ,   5883    ,   6125    ,   14803   ,0 };
            const std::uint32_t dim2550Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   1   ,   61  ,   7   ,   67  ,   229 ,   931 ,   1997    ,   3067    ,   3507    ,   11675   ,   31837   ,0 };
            const std::uint32_t dim2551Kuo2Init[]       =   {   1   ,   1   ,   5   ,   1   ,   5   ,   35  ,   43  ,   65  ,   101 ,   75  ,   629 ,   1149    ,   625 ,   1865    ,   5215    ,0 };
            const std::uint32_t dim2552Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   17  ,   61  ,   47  ,   29  ,   277 ,   861 ,   1901    ,   35  ,   1405    ,   4393    ,   26899   ,0 };
            const std::uint32_t dim2553Kuo2Init[]       =   {   1   ,   1   ,   5   ,   13  ,   13  ,   11  ,   21  ,   27  ,   473 ,   145 ,   867 ,   2781    ,   2865    ,   2793    ,   3265    ,0 };
            const std::uint32_t dim2554Kuo2Init[]       =   {   1   ,   1   ,   7   ,   11  ,   11  ,   31  ,   41  ,   119 ,   243 ,   989 ,   2047    ,   1455    ,   8037    ,   11633   ,   31199   ,0 };
            const std::uint32_t dim2555Kuo2Init[]       =   {   1   ,   1   ,   7   ,   5   ,   29  ,   19  ,   1   ,   89  ,   63  ,   41  ,   323 ,   2135    ,   2091    ,   15061   ,   29039   ,0 };
            const std::uint32_t dim2556Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   9   ,   53  ,   15  ,   191 ,   229 ,   487 ,   1287    ,   1163    ,   6985    ,   881 ,   4789    ,0 };
            const std::uint32_t dim2557Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   11  ,   57  ,   89  ,   205 ,   355 ,   551 ,   1643    ,   1565    ,   4181    ,   10805   ,   29359   ,0 };
            const std::uint32_t dim2558Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   31  ,   3   ,   103 ,   165 ,   37  ,   195 ,   245 ,   1225    ,   2811    ,   14785   ,   9307    ,0 };
            const std::uint32_t dim2559Kuo2Init[]       =   {   1   ,   1   ,   7   ,   5   ,   19  ,   31  ,   47  ,   115 ,   361 ,   1019    ,   1517    ,   4079    ,   3717    ,   11301   ,   12051   ,0 };
            const std::uint32_t dim2560Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   31  ,   21  ,   57  ,   27  ,   353 ,   623 ,   1217    ,   3079    ,   5429    ,   8645    ,   10773   ,0 };
            const std::uint32_t dim2561Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   3   ,   11  ,   55  ,   209 ,   239 ,   509 ,   959 ,   2091    ,   123 ,   11365   ,   26593   ,0 };
            const std::uint32_t dim2562Kuo2Init[]       =   {   1   ,   1   ,   5   ,   9   ,   7   ,   19  ,   51  ,   179 ,   103 ,   901 ,   1717    ,   1837    ,   4327    ,   9753    ,   24147   ,0 };
            const std::uint32_t dim2563Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   9   ,   63  ,   19  ,   103 ,   265 ,   893 ,   1519    ,   4063    ,   7951    ,   15601   ,   15019   ,0 };
            const std::uint32_t dim2564Kuo2Init[]       =   {   1   ,   1   ,   3   ,   1   ,   19  ,   29  ,   15  ,   11  ,   235 ,   785 ,   77  ,   3957    ,   4829    ,   9903    ,   8483    ,0 };
            const std::uint32_t dim2565Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   27  ,   33  ,   25  ,   103 ,   387 ,   131 ,   1555    ,   301 ,   1471    ,   11331   ,   15091   ,0 };
            const std::uint32_t dim2566Kuo2Init[]       =   {   1   ,   3   ,   3   ,   13  ,   25  ,   63  ,   75  ,   245 ,   189 ,   527 ,   1829    ,   1943    ,   407 ,   15219   ,   24453   ,0 };
            const std::uint32_t dim2567Kuo2Init[]       =   {   1   ,   3   ,   1   ,   11  ,   29  ,   27  ,   35  ,   5   ,   215 ,   949 ,   97  ,   3843    ,   7911    ,   15947   ,   25037   ,0 };
            const std::uint32_t dim2568Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   29  ,   49  ,   43  ,   245 ,   257 ,   741 ,   1067    ,   2405    ,   3793    ,   3787    ,   22921   ,0 };
            const std::uint32_t dim2569Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   29  ,   29  ,   39  ,   25  ,   485 ,   257 ,   1003    ,   77  ,   1617    ,   5151    ,   29595   ,0 };
            const std::uint32_t dim2570Kuo2Init[]       =   {   1   ,   1   ,   3   ,   5   ,   9   ,   39  ,   61  ,   59  ,   197 ,   501 ,   527 ,   3371    ,   1739    ,   5697    ,   11857   ,0 };
            const std::uint32_t dim2571Kuo2Init[]       =   {   1   ,   1   ,   1   ,   15  ,   31  ,   27  ,   41  ,   91  ,   11  ,   373 ,   627 ,   361 ,   8001    ,   12231   ,   5715    ,0 };
            const std::uint32_t dim2572Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   31  ,   27  ,   67  ,   203 ,   95  ,   221 ,   1911    ,   1045    ,   1311    ,   11633   ,   5375    ,0 };
            const std::uint32_t dim2573Kuo2Init[]       =   {   1   ,   1   ,   5   ,   15  ,   31  ,   49  ,   59  ,   185 ,   285 ,   173 ,   1351    ,   1665    ,   5941    ,   2075    ,   26087   ,0 };
            const std::uint32_t dim2574Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   23  ,   33  ,   95  ,   171 ,   71  ,   743 ,   11  ,   33  ,   1263    ,   1595    ,   18281   ,0 };
            const std::uint32_t dim2575Kuo2Init[]       =   {   1   ,   1   ,   1   ,   7   ,   13  ,   59  ,   99  ,   245 ,   497 ,   951 ,   1195    ,   1503    ,   6069    ,   2293    ,   31661   ,0 };
            const std::uint32_t dim2576Kuo2Init[]       =   {   1   ,   3   ,   5   ,   3   ,   3   ,   3   ,   29  ,   3   ,   197 ,   697 ,   105 ,   435 ,   4583    ,   5407    ,   32727   ,0 };
            const std::uint32_t dim2577Kuo2Init[]       =   {   1   ,   3   ,   7   ,   1   ,   9   ,   41  ,   77  ,   199 ,   495 ,   999 ,   1791    ,   2183    ,   2819    ,   10771   ,   6957    ,0 };
            const std::uint32_t dim2578Kuo2Init[]       =   {   1   ,   1   ,   7   ,   15  ,   27  ,   13  ,   51  ,   33  ,   243 ,   947 ,   835 ,   2251    ,   1751    ,   10319   ,   3269    ,0 };
            const std::uint32_t dim2579Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   17  ,   59  ,   125 ,   151 ,   113 ,   889 ,   21  ,   3839    ,   1475    ,   10643   ,   3291    ,0 };
            const std::uint32_t dim2580Kuo2Init[]       =   {   1   ,   3   ,   7   ,   3   ,   27  ,   55  ,   101 ,   13  ,   177 ,   967 ,   35  ,   3081    ,   3559    ,   6539    ,   13557   ,0 };
            const std::uint32_t dim2581Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   27  ,   7   ,   107 ,   147 ,   455 ,   605 ,   1589    ,   2325    ,   6891    ,   10431   ,   18227   ,0 };
            const std::uint32_t dim2582Kuo2Init[]       =   {   1   ,   1   ,   3   ,   3   ,   27  ,   13  ,   121 ,   249 ,   205 ,   359 ,   1909    ,   4011    ,   6833    ,   11583   ,   8705    ,0 };
            const std::uint32_t dim2583Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   21  ,   47  ,   77  ,   103 ,   173 ,   637 ,   1921    ,   991 ,   6471    ,   6053    ,   1963    ,0 };
            const std::uint32_t dim2584Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   11  ,   9   ,   71  ,   161 ,   253 ,   1   ,   973 ,   3079    ,   4887    ,   10045   ,   20467   ,0 };
            const std::uint32_t dim2585Kuo2Init[]       =   {   1   ,   1   ,   5   ,   13  ,   27  ,   45  ,   11  ,   147 ,   79  ,   375 ,   533 ,   43  ,   7217    ,   9393    ,   20773   ,0 };
            const std::uint32_t dim2586Kuo2Init[]       =   {   1   ,   1   ,   5   ,   3   ,   21  ,   47  ,   107 ,   83  ,   505 ,   463 ,   967 ,   3437    ,   3051    ,   11239   ,   20271   ,0 };
            const std::uint32_t dim2587Kuo2Init[]       =   {   1   ,   1   ,   1   ,   15  ,   7   ,   9   ,   97  ,   143 ,   483 ,   393 ,   39  ,   447 ,   7779    ,   11037   ,   23283   ,0 };
            const std::uint32_t dim2588Kuo2Init[]       =   {   1   ,   3   ,   1   ,   1   ,   31  ,   59  ,   85  ,   231 ,   209 ,   297 ,   353 ,   2577    ,   6209    ,   6691    ,   2941    ,0 };
            const std::uint32_t dim2589Kuo2Init[]       =   {   1   ,   1   ,   7   ,   3   ,   19  ,   7   ,   81  ,   41  ,   419 ,   987 ,   1221    ,   2151    ,   5297    ,   1601    ,   1289    ,0 };
            const std::uint32_t dim2590Kuo2Init[]       =   {   1   ,   3   ,   3   ,   13  ,   25  ,   13  ,   57  ,   199 ,   101 ,   157 ,   1273    ,   159 ,   5417    ,   5153    ,   30529   ,0 };
            const std::uint32_t dim2591Kuo2Init[]       =   {   1   ,   1   ,   5   ,   1   ,   31  ,   41  ,   67  ,   71  ,   95  ,   929 ,   133 ,   3007    ,   6837    ,   7863    ,   23759   ,0 };
            const std::uint32_t dim2592Kuo2Init[]       =   {   1   ,   1   ,   5   ,   3   ,   13  ,   59  ,   35  ,   11  ,   187 ,   251 ,   1119    ,   1517    ,   1433    ,   15475   ,   17981   ,0 };
            const std::uint32_t dim2593Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   5   ,   37  ,   11  ,   39  ,   111 ,   775 ,   761 ,   2853    ,   2283    ,   203 ,   22563   ,0 };
            const std::uint32_t dim2594Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   5   ,   45  ,   119 ,   81  ,   125 ,   481 ,   547 ,   3659    ,   5583    ,   6577    ,   17239   ,0 };
            const std::uint32_t dim2595Kuo2Init[]       =   {   1   ,   3   ,   3   ,   13  ,   9   ,   25  ,   43  ,   103 ,   283 ,   637 ,   715 ,   3841    ,   5633    ,   503 ,   21933   ,0 };
            const std::uint32_t dim2596Kuo2Init[]       =   {   1   ,   3   ,   1   ,   13  ,   21  ,   39  ,   1   ,   215 ,   235 ,   171 ,   1377    ,   2131    ,   2907    ,   11311   ,   11337   ,0 };
            const std::uint32_t dim2597Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   27  ,   19  ,   73  ,   83  ,   325 ,   451 ,   1779    ,   1665    ,   555 ,   7729    ,   26757   ,0 };
            const std::uint32_t dim2598Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   9   ,   29  ,   123 ,   177 ,   289 ,   553 ,   1323    ,   2531    ,   4071    ,   7395    ,   25847   ,0 };
            const std::uint32_t dim2599Kuo2Init[]       =   {   1   ,   1   ,   7   ,   13  ,   1   ,   1   ,   29  ,   125 ,   253 ,   179 ,   1905    ,   821 ,   5329    ,   6181    ,   18445   ,0 };
            const std::uint32_t dim2600Kuo2Init[]       =   {   1   ,   1   ,   1   ,   9   ,   15  ,   19  ,   59  ,   227 ,   63  ,   637 ,   1315    ,   2611    ,   1163    ,   6451    ,   8919    ,0 };
            const std::uint32_t dim2601Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   23  ,   39  ,   57  ,   143 ,   9   ,   811 ,   1101    ,   609 ,   1281    ,   9457    ,   14999   ,0 };
            const std::uint32_t dim2602Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   5   ,   31  ,   21  ,   31  ,   33  ,   271 ,   381 ,   1179    ,   4039    ,   14033   ,   19741   ,0 };
            const std::uint32_t dim2603Kuo2Init[]       =   {   1   ,   3   ,   7   ,   15  ,   9   ,   41  ,   91  ,   247 ,   59  ,   201 ,   1837    ,   2609    ,   5481    ,   15479   ,   32253   ,0 };
            const std::uint32_t dim2604Kuo2Init[]       =   {   1   ,   1   ,   3   ,   5   ,   15  ,   53  ,   7   ,   193 ,   451 ,   935 ,   701 ,   177 ,   7943    ,   5687    ,   15725   ,0 };
            const std::uint32_t dim2605Kuo2Init[]       =   {   1   ,   3   ,   1   ,   13  ,   19  ,   9   ,   33  ,   173 ,   229 ,   993 ,   1637    ,   905 ,   5665    ,   9083    ,   10737   ,0 };
            const std::uint32_t dim2606Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   17  ,   33  ,   3   ,   145 ,   213 ,   317 ,   1135    ,   3281    ,   4169    ,   4601    ,   30347   ,0 };
            const std::uint32_t dim2607Kuo2Init[]       =   {   1   ,   1   ,   1   ,   3   ,   23  ,   1   ,   49  ,   173 ,   351 ,   827 ,   937 ,   2423    ,   6443    ,   6413    ,   20383   ,0 };
            const std::uint32_t dim2608Kuo2Init[]       =   {   1   ,   3   ,   5   ,   3   ,   21  ,   9   ,   7   ,   29  ,   293 ,   489 ,   339 ,   2403    ,   6303    ,   12283   ,   18047   ,0 };
            const std::uint32_t dim2609Kuo2Init[]       =   {   1   ,   1   ,   7   ,   11  ,   23  ,   25  ,   49  ,   135 ,   389 ,   821 ,   17  ,   169 ,   4265    ,   5203    ,   3893    ,0 };
            const std::uint32_t dim2610Kuo2Init[]       =   {   1   ,   1   ,   3   ,   3   ,   27  ,   63  ,   109 ,   165 ,   141 ,   129 ,   1441    ,   1443    ,   3991    ,   1639    ,   31461   ,0 };
            const std::uint32_t dim2611Kuo2Init[]       =   {   1   ,   3   ,   7   ,   7   ,   25  ,   15  ,   85  ,   217 ,   223 ,   537 ,   1671    ,   2865    ,   4157    ,   8353    ,   18335   ,0 };
            const std::uint32_t dim2612Kuo2Init[]       =   {   1   ,   3   ,   5   ,   11  ,   19  ,   19  ,   95  ,   159 ,   161 ,   599 ,   1059    ,   2065    ,   7159    ,   11273   ,   17501   ,0 };
            const std::uint32_t dim2613Kuo2Init[]       =   {   1   ,   3   ,   7   ,   3   ,   15  ,   29  ,   5   ,   97  ,   95  ,   65  ,   1913    ,   1221    ,   329 ,   11601   ,   27033   ,0 };
            const std::uint32_t dim2614Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   25  ,   39  ,   103 ,   139 ,   379 ,   547 ,   1415    ,   4027    ,   559 ,   2101    ,   6133    ,0 };
            const std::uint32_t dim2615Kuo2Init[]       =   {   1   ,   1   ,   7   ,   15  ,   21  ,   47  ,   115 ,   171 ,   17  ,   559 ,   1757    ,   745 ,   2573    ,   13969   ,   4193    ,0 };
            const std::uint32_t dim2616Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   19  ,   15  ,   37  ,   131 ,   199 ,   377 ,   67  ,   2455    ,   6807    ,   3365    ,   19697   ,0 };
            const std::uint32_t dim2617Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   25  ,   59  ,   9   ,   61  ,   369 ,   285 ,   231 ,   2911    ,   1817    ,   2125    ,   27637   ,0 };
            const std::uint32_t dim2618Kuo2Init[]       =   {   1   ,   3   ,   1   ,   13  ,   25  ,   55  ,   61  ,   153 ,   507 ,   105 ,   149 ,   1589    ,   7167    ,   12363   ,   10257   ,0 };
            const std::uint32_t dim2619Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   9   ,   23  ,   109 ,   29  ,   167 ,   463 ,   101 ,   979 ,   3671    ,   10165   ,   12553   ,0 };
            const std::uint32_t dim2620Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   21  ,   49  ,   103 ,   217 ,   269 ,   761 ,   915 ,   3529    ,   125 ,   429 ,   24131   ,0 };
            const std::uint32_t dim2621Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   27  ,   61  ,   73  ,   13  ,   339 ,   1023    ,   967 ,   3883    ,   5515    ,   5893    ,   26183   ,0 };
            const std::uint32_t dim2622Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   5   ,   39  ,   87  ,   183 ,   141 ,   147 ,   779 ,   1733    ,   6137    ,   5985    ,   1335    ,0 };
            const std::uint32_t dim2623Kuo2Init[]       =   {   1   ,   3   ,   5   ,   11  ,   23  ,   9   ,   61  ,   67  ,   235 ,   823 ,   1129    ,   401 ,   3049    ,   5593    ,   5193    ,0 };
            const std::uint32_t dim2624Kuo2Init[]       =   {   1   ,   1   ,   3   ,   3   ,   27  ,   39  ,   27  ,   111 ,   81  ,   27  ,   283 ,   4081    ,   6511    ,   6785    ,   20953   ,0 };
            const std::uint32_t dim2625Kuo2Init[]       =   {   1   ,   3   ,   7   ,   7   ,   17  ,   49  ,   93  ,   85  ,   327 ,   287 ,   1473    ,   3769    ,   2229    ,   12221   ,   27355   ,0 };
            const std::uint32_t dim2626Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   15  ,   15  ,   71  ,   105 ,   139 ,   137 ,   1139    ,   859 ,   7923    ,   581 ,   7697    ,0 };
            const std::uint32_t dim2627Kuo2Init[]       =   {   1   ,   3   ,   7   ,   15  ,   29  ,   45  ,   17  ,   159 ,   233 ,   345 ,   1827    ,   2261    ,   6773    ,   5435    ,   17961   ,0 };
            const std::uint32_t dim2628Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   21  ,   15  ,   33  ,   229 ,   71  ,   709 ,   1757    ,   1479    ,   7289    ,   15629   ,   24041   ,0 };
            const std::uint32_t dim2629Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   27  ,   9   ,   103 ,   115 ,   137 ,   911 ,   603 ,   3615    ,   7671    ,   2439    ,   10041   ,0 };
            const std::uint32_t dim2630Kuo2Init[]       =   {   1   ,   1   ,   5   ,   5   ,   21  ,   59  ,   67  ,   193 ,   249 ,   781 ,   761 ,   403 ,   6299    ,   527 ,   8533    ,0 };
            const std::uint32_t dim2631Kuo2Init[]       =   {   1   ,   3   ,   3   ,   3   ,   5   ,   61  ,   71  ,   183 ,   151 ,   801 ,   1645    ,   2789    ,   5911    ,   11681   ,   5907    ,0 };
            const std::uint32_t dim2632Kuo2Init[]       =   {   1   ,   1   ,   5   ,   7   ,   9   ,   19  ,   53  ,   239 ,   259 ,   273 ,   679 ,   2101    ,   1525    ,   2139    ,   30353   ,0 };
            const std::uint32_t dim2633Kuo2Init[]       =   {   1   ,   1   ,   3   ,   1   ,   31  ,   25  ,   37  ,   225 ,   287 ,   31  ,   433 ,   2407    ,   1717    ,   6669    ,   10743   ,0 };
            const std::uint32_t dim2634Kuo2Init[]       =   {   1   ,   3   ,   1   ,   13  ,   31  ,   13  ,   89  ,   225 ,   173 ,   723 ,   651 ,   3315    ,   6457    ,   9387    ,   7759    ,0 };
            const std::uint32_t dim2635Kuo2Init[]       =   {   1   ,   1   ,   5   ,   7   ,   3   ,   25  ,   45  ,   79  ,   11  ,   843 ,   2031    ,   2827    ,   5029    ,   1359    ,   23489   ,0 };
            const std::uint32_t dim2636Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   7   ,   1   ,   53  ,   135 ,   327 ,   13  ,   1051    ,   2911    ,   5553    ,   6557    ,   16415   ,0 };
            const std::uint32_t dim2637Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   19  ,   19  ,   57  ,   147 ,   43  ,   503 ,   1899    ,   1709    ,   5589    ,   4251    ,   10871   ,0 };
            const std::uint32_t dim2638Kuo2Init[]       =   {   1   ,   1   ,   5   ,   7   ,   1   ,   41  ,   83  ,   51  ,   89  ,   1015    ,   1441    ,   1735    ,   7217    ,   11431   ,   29623   ,0 };
            const std::uint32_t dim2639Kuo2Init[]       =   {   1   ,   3   ,   7   ,   7   ,   29  ,   45  ,   73  ,   233 ,   399 ,   553 ,   961 ,   2053    ,   3537    ,   4015    ,   19963   ,0 };
            const std::uint32_t dim2640Kuo2Init[]       =   {   1   ,   1   ,   5   ,   3   ,   21  ,   5   ,   1   ,   105 ,   341 ,   355 ,   849 ,   2235    ,   2801    ,   13749   ,   17933   ,0 };
            const std::uint32_t dim2641Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   25  ,   57  ,   29  ,   233 ,   485 ,   807 ,   1005    ,   1933    ,   3897    ,   1267    ,   30807   ,0 };
            const std::uint32_t dim2642Kuo2Init[]       =   {   1   ,   1   ,   7   ,   15  ,   31  ,   53  ,   49  ,   31  ,   325 ,   335 ,   671 ,   1183    ,   2955    ,   3   ,   31739   ,0 };
            const std::uint32_t dim2643Kuo2Init[]       =   {   1   ,   1   ,   5   ,   3   ,   17  ,   41  ,   19  ,   73  ,   215 ,   227 ,   1251    ,   907 ,   3303    ,   5343    ,   30385   ,0 };
            const std::uint32_t dim2644Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   15  ,   61  ,   123 ,   61  ,   27  ,   759 ,   645 ,   2571    ,   411 ,   13925   ,   29905   ,0 };
            const std::uint32_t dim2645Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   7   ,   55  ,   81  ,   241 ,   497 ,   1005    ,   1593    ,   2479    ,   25  ,   10627   ,   14043   ,0 };
            const std::uint32_t dim2646Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   19  ,   33  ,   87  ,   63  ,   441 ,   773 ,   1367    ,   2945    ,   4897    ,   14209   ,   6667    ,0 };
            const std::uint32_t dim2647Kuo2Init[]       =   {   1   ,   1   ,   7   ,   15  ,   31  ,   59  ,   121 ,   153 ,   111 ,   329 ,   833 ,   2031    ,   4063    ,   13775   ,   9033    ,0 };
            const std::uint32_t dim2648Kuo2Init[]       =   {   1   ,   3   ,   1   ,   11  ,   3   ,   33  ,   47  ,   65  ,   329 ,   149 ,   1509    ,   3617    ,   1381    ,   9003    ,   4953    ,0 };
            const std::uint32_t dim2649Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   7   ,   59  ,   39  ,   173 ,   157 ,   741 ,   343 ,   1039    ,   1695    ,   12077   ,   13203   ,0 };
            const std::uint32_t dim2650Kuo2Init[]       =   {   1   ,   3   ,   7   ,   1   ,   17  ,   21  ,   21  ,   5   ,   65  ,   163 ,   711 ,   2251    ,   4761    ,   11895   ,   15571   ,0 };
            const std::uint32_t dim2651Kuo2Init[]       =   {   1   ,   3   ,   7   ,   7   ,   7   ,   59  ,   31  ,   227 ,   283 ,   223 ,   163 ,   2639    ,   3037    ,   14423   ,   21507   ,0 };
            const std::uint32_t dim2652Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   9   ,   37  ,   5   ,   149 ,   395 ,   491 ,   711 ,   447 ,   5657    ,   443 ,   7183    ,0 };
            const std::uint32_t dim2653Kuo2Init[]       =   {   1   ,   1   ,   5   ,   9   ,   17  ,   61  ,   31  ,   229 ,   207 ,   755 ,   199 ,   1585    ,   2771    ,   1499    ,   4911    ,0 };
            const std::uint32_t dim2654Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   1   ,   1   ,   53  ,   185 ,   407 ,   57  ,   525 ,   543 ,   5009    ,   1825    ,   8583    ,0 };
            const std::uint32_t dim2655Kuo2Init[]       =   {   1   ,   1   ,   1   ,   3   ,   13  ,   49  ,   85  ,   175 ,   261 ,   653 ,   665 ,   3173    ,   4709    ,   11547   ,   14881   ,0 };
            const std::uint32_t dim2656Kuo2Init[]       =   {   1   ,   1   ,   1   ,   3   ,   21  ,   47  ,   21  ,   33  ,   265 ,   171 ,   765 ,   3871    ,   3577    ,   15135   ,   13483   ,0 };
            const std::uint32_t dim2657Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   29  ,   5   ,   109 ,   3   ,   249 ,   379 ,   1259    ,   677 ,   1177    ,   13061   ,   31985   ,0 };
            const std::uint32_t dim2658Kuo2Init[]       =   {   1   ,   3   ,   7   ,   3   ,   15  ,   25  ,   123 ,   93  ,   193 ,   419 ,   1173    ,   2493    ,   2937    ,   14909   ,   3147    ,0 };
            const std::uint32_t dim2659Kuo2Init[]       =   {   1   ,   3   ,   3   ,   3   ,   9   ,   59  ,   55  ,   95  ,   93  ,   319 ,   1281    ,   587 ,   8065    ,   15697   ,   32101   ,0 };
            const std::uint32_t dim2660Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   25  ,   61  ,   105 ,   199 ,   101 ,   255 ,   849 ,   377 ,   3245    ,   8139    ,   8383    ,0 };
            const std::uint32_t dim2661Kuo2Init[]       =   {   1   ,   1   ,   5   ,   9   ,   3   ,   47  ,   79  ,   155 ,   15  ,   661 ,   1417    ,   87  ,   4225    ,   13241   ,   15971   ,0 };
            const std::uint32_t dim2662Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   13  ,   39  ,   101 ,   79  ,   271 ,   21  ,   1983    ,   2821    ,   4177    ,   14081   ,   31219   ,0 };
            const std::uint32_t dim2663Kuo2Init[]       =   {   1   ,   1   ,   1   ,   7   ,   15  ,   51  ,   123 ,   17  ,   29  ,   123 ,   1131    ,   147 ,   4191    ,   6729    ,   19359   ,0 };
            const std::uint32_t dim2664Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   17  ,   39  ,   47  ,   215 ,   219 ,   643 ,   1877    ,   3965    ,   5799    ,   16131   ,   24675   ,0 };
            const std::uint32_t dim2665Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   11  ,   53  ,   57  ,   133 ,   289 ,   33  ,   1631    ,   2037    ,   6699    ,   14153   ,   25309   ,0 };
            const std::uint32_t dim2666Kuo2Init[]       =   {   1   ,   3   ,   7   ,   7   ,   9   ,   17  ,   125 ,   123 ,   91  ,   15  ,   1279    ,   297 ,   2583    ,   11141   ,   7257    ,0 };
            const std::uint32_t dim2667Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   13  ,   9   ,   83  ,   117 ,   365 ,   533 ,   343 ,   121 ,   7553    ,   14417   ,   23239   ,0 };
            const std::uint32_t dim2668Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   5   ,   27  ,   97  ,   229 ,   321 ,   123 ,   1669    ,   621 ,   4937    ,   683 ,   31061   ,0 };
            const std::uint32_t dim2669Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   1   ,   23  ,   63  ,   21  ,   271 ,   695 ,   601 ,   113 ,   6331    ,   8837    ,   16721   ,0 };
            const std::uint32_t dim2670Kuo2Init[]       =   {   1   ,   3   ,   7   ,   13  ,   15  ,   41  ,   53  ,   115 ,   225 ,   5   ,   1315    ,   2285    ,   3815    ,   5949    ,   4263    ,0 };
            const std::uint32_t dim2671Kuo2Init[]       =   {   1   ,   1   ,   1   ,   9   ,   21  ,   41  ,   25  ,   47  ,   9   ,   423 ,   1171    ,   2515    ,   3461    ,   13273   ,   13059   ,0 };
            const std::uint32_t dim2672Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   5   ,   29  ,   111 ,   15  ,   505 ,   347 ,   347 ,   2521    ,   4583    ,   5729    ,   11645   ,0 };
            const std::uint32_t dim2673Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   9   ,   15  ,   57  ,   211 ,   163 ,   749 ,   1549    ,   1015    ,   441 ,   16025   ,   28943   ,0 };
            const std::uint32_t dim2674Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   15  ,   27  ,   111 ,   79  ,   131 ,   831 ,   2045    ,   1937    ,   6969    ,   11223   ,   22711   ,0 };
            const std::uint32_t dim2675Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   3   ,   37  ,   37  ,   221 ,   143 ,   955 ,   1387    ,   3483    ,   5845    ,   13411   ,   16225   ,0 };
            const std::uint32_t dim2676Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   7   ,   13  ,   75  ,   57  ,   357 ,   109 ,   241 ,   165 ,   1845    ,   213 ,   8337    ,0 };
            const std::uint32_t dim2677Kuo2Init[]       =   {   1   ,   3   ,   1   ,   15  ,   5   ,   41  ,   109 ,   129 ,   91  ,   459 ,   1237    ,   467 ,   8015    ,   14499   ,   19897   ,0 };
            const std::uint32_t dim2678Kuo2Init[]       =   {   1   ,   1   ,   5   ,   7   ,   23  ,   45  ,   73  ,   135 ,   161 ,   921 ,   127 ,   3723    ,   1795    ,   4047    ,   16607   ,0 };
            const std::uint32_t dim2679Kuo2Init[]       =   {   1   ,   3   ,   1   ,   9   ,   21  ,   17  ,   13  ,   133 ,   251 ,   927 ,   1551    ,   3087    ,   317 ,   2989    ,   30481   ,0 };
            const std::uint32_t dim2680Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   15  ,   51  ,   17  ,   77  ,   345 ,   833 ,   983 ,   2855    ,   383 ,   10873   ,   20019   ,0 };
            const std::uint32_t dim2681Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   3   ,   9   ,   65  ,   115 ,   449 ,   375 ,   27  ,   2053    ,   175 ,   6793    ,   9761    ,0 };
            const std::uint32_t dim2682Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   17  ,   7   ,   51  ,   207 ,   389 ,   995 ,   1663    ,   3697    ,   5539    ,   13495   ,   4053    ,0 };
            const std::uint32_t dim2683Kuo2Init[]       =   {   1   ,   1   ,   1   ,   13  ,   5   ,   25  ,   125 ,   139 ,   123 ,   433 ,   1323    ,   273 ,   6061    ,   7145    ,   13929   ,0 };
            const std::uint32_t dim2684Kuo2Init[]       =   {   1   ,   3   ,   7   ,   3   ,   3   ,   1   ,   65  ,   217 ,   203 ,   887 ,   121 ,   961 ,   2843    ,   16171   ,   8433    ,0 };
            const std::uint32_t dim2685Kuo2Init[]       =   {   1   ,   1   ,   3   ,   1   ,   21  ,   25  ,   93  ,   237 ,   203 ,   721 ,   1135    ,   751 ,   7193    ,   7453    ,   29593   ,0 };
            const std::uint32_t dim2686Kuo2Init[]       =   {   1   ,   1   ,   5   ,   13  ,   27  ,   41  ,   125 ,   31  ,   145 ,   69  ,   1865    ,   471 ,   6031    ,   6589    ,   16185   ,0 };
            const std::uint32_t dim2687Kuo2Init[]       =   {   1   ,   1   ,   5   ,   1   ,   13  ,   39  ,   15  ,   251 ,   125 ,   781 ,   1635    ,   231 ,   7503    ,   12647   ,   9493    ,0 };
            const std::uint32_t dim2688Kuo2Init[]       =   {   1   ,   1   ,   3   ,   11  ,   31  ,   35  ,   39  ,   49  ,   279 ,   281 ,   285 ,   1707    ,   607 ,   3405    ,   5803    ,0 };
            const std::uint32_t dim2689Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   29  ,   61  ,   43  ,   15  ,   413 ,   759 ,   159 ,   2027    ,   4065    ,   9501    ,   31597   ,0 };
            const std::uint32_t dim2690Kuo2Init[]       =   {   1   ,   1   ,   5   ,   3   ,   21  ,   19  ,   25  ,   31  ,   21  ,   139 ,   1273    ,   871 ,   423 ,   13737   ,   1633    ,0 };
            const std::uint32_t dim2691Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   9   ,   15  ,   15  ,   247 ,   459 ,   49  ,   2047    ,   289 ,   7457    ,   13367   ,   3343    ,0 };
            const std::uint32_t dim2692Kuo2Init[]       =   {   1   ,   3   ,   7   ,   1   ,   5   ,   43  ,   49  ,   115 ,   201 ,   131 ,   297 ,   2069    ,   801 ,   7599    ,   675 ,0 };
            const std::uint32_t dim2693Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   11  ,   19  ,   41  ,   135 ,   107 ,   325 ,   431 ,   2459    ,   7629    ,   3407    ,   19635   ,0 };
            const std::uint32_t dim2694Kuo2Init[]       =   {   1   ,   1   ,   7   ,   15  ,   1   ,   45  ,   89  ,   249 ,   463 ,   319 ,   1577    ,   549 ,   3623    ,   7053    ,   23037   ,0 };
            const std::uint32_t dim2695Kuo2Init[]       =   {   1   ,   3   ,   1   ,   11  ,   27  ,   23  ,   123 ,   63  ,   219 ,   77  ,   179 ,   3283    ,   2887    ,   14023   ,   28277   ,0 };
            const std::uint32_t dim2696Kuo2Init[]       =   {   1   ,   3   ,   1   ,   9   ,   29  ,   47  ,   39  ,   61  ,   413 ,   327 ,   1529    ,   593 ,   7779    ,   14857   ,   14165   ,0 };
            const std::uint32_t dim2697Kuo2Init[]       =   {   1   ,   3   ,   5   ,   3   ,   29  ,   15  ,   73  ,   231 ,   141 ,   435 ,   1835    ,   1023    ,   289 ,   1859    ,   1069    ,0 };
            const std::uint32_t dim2698Kuo2Init[]       =   {   1   ,   3   ,   3   ,   3   ,   9   ,   35  ,   1   ,   153 ,   111 ,   521 ,   461 ,   3001    ,   5401    ,   9529    ,   19845   ,0 };
            const std::uint32_t dim2699Kuo2Init[]       =   {   1   ,   1   ,   1   ,   15  ,   17  ,   43  ,   49  ,   227 ,   87  ,   199 ,   179 ,   1619    ,   6093    ,   15695   ,   30739   ,0 };
            const std::uint32_t dim2700Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   17  ,   53  ,   67  ,   199 ,   263 ,   931 ,   413 ,   1019    ,   679 ,   15483   ,   22211   ,0 };
            const std::uint32_t dim2701Kuo2Init[]       =   {   1   ,   1   ,   7   ,   3   ,   19  ,   7   ,   55  ,   111 ,   499 ,   587 ,   1685    ,   1007    ,   5147    ,   6097    ,   31801   ,0 };
            const std::uint32_t dim2702Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   17  ,   15  ,   41  ,   167 ,   495 ,   439 ,   1161    ,   3737    ,   5957    ,   4151    ,   26597   ,0 };
            const std::uint32_t dim2703Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   17  ,   35  ,   103 ,   205 ,   83  ,   613 ,   1541    ,   2825    ,   2773    ,   14487   ,   177 ,0 };
            const std::uint32_t dim2704Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   11  ,   31  ,   1   ,   93  ,   87  ,   917 ,   1209    ,   1489    ,   4063    ,   7811    ,   31291   ,0 };
            const std::uint32_t dim2705Kuo2Init[]       =   {   1   ,   1   ,   5   ,   9   ,   27  ,   25  ,   15  ,   121 ,   51  ,   207 ,   567 ,   2091    ,   6177    ,   121 ,   15305   ,0 };
            const std::uint32_t dim2706Kuo2Init[]       =   {   1   ,   3   ,   7   ,   13  ,   17  ,   27  ,   13  ,   31  ,   443 ,   487 ,   863 ,   3253    ,   4961    ,   2695    ,   6427    ,0 };
            const std::uint32_t dim2707Kuo2Init[]       =   {   1   ,   3   ,   7   ,   15  ,   23  ,   23  ,   85  ,   229 ,   123 ,   151 ,   519 ,   2581    ,   4073    ,   5915    ,   23715   ,0 };
            const std::uint32_t dim2708Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   19  ,   41  ,   33  ,   71  ,   511 ,   683 ,   1387    ,   2975    ,   5069    ,   4327    ,   25881   ,0 };
            const std::uint32_t dim2709Kuo2Init[]       =   {   1   ,   1   ,   7   ,   3   ,   9   ,   25  ,   29  ,   73  ,   55  ,   323 ,   483 ,   1509    ,   4895    ,   5151    ,   13095   ,0 };
            const std::uint32_t dim2710Kuo2Init[]       =   {   1   ,   3   ,   7   ,   3   ,   7   ,   19  ,   95  ,   163 ,   239 ,   721 ,   747 ,   3965    ,   6943    ,   11771   ,   5991    ,0 };
            const std::uint32_t dim2711Kuo2Init[]       =   {   1   ,   3   ,   1   ,   9   ,   27  ,   11  ,   5   ,   9   ,   291 ,   987 ,   313 ,   129 ,   4147    ,   1005    ,   25719   ,0 };
            const std::uint32_t dim2712Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   7   ,   25  ,   85  ,   197 ,   177 ,   759 ,   1083    ,   2615    ,   3647    ,   11873   ,   17035   ,0 };
            const std::uint32_t dim2713Kuo2Init[]       =   {   1   ,   3   ,   1   ,   13  ,   13  ,   11  ,   29  ,   45  ,   103 ,   319 ,   1325    ,   2987    ,   7253    ,   3967    ,   32547   ,0 };
            const std::uint32_t dim2714Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   11  ,   27  ,   103 ,   75  ,   113 ,   741 ,   175 ,   2715    ,   1595    ,   7899    ,   261 ,0 };
            const std::uint32_t dim2715Kuo2Init[]       =   {   1   ,   1   ,   3   ,   5   ,   3   ,   39  ,   113 ,   19  ,   301 ,   19  ,   1369    ,   2759    ,   467 ,   10387   ,   15763   ,0 };
            const std::uint32_t dim2716Kuo2Init[]       =   {   1   ,   1   ,   5   ,   5   ,   5   ,   23  ,   47  ,   21  ,   69  ,   57  ,   1183    ,   2725    ,   2329    ,   4829    ,   22769   ,0 };
            const std::uint32_t dim2717Kuo2Init[]       =   {   1   ,   3   ,   3   ,   13  ,   1   ,   39  ,   111 ,   11  ,   133 ,   143 ,   465 ,   1551    ,   2969    ,   2353    ,   9381    ,0 };
            const std::uint32_t dim2718Kuo2Init[]       =   {   1   ,   3   ,   7   ,   3   ,   29  ,   19  ,   75  ,   97  ,   139 ,   325 ,   189 ,   477 ,   5687    ,   11105   ,   17325   ,0 };
            const std::uint32_t dim2719Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   25  ,   51  ,   53  ,   177 ,   41  ,   677 ,   233 ,   467 ,   4977    ,   8055    ,   30257   ,0 };
            const std::uint32_t dim2720Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   29  ,   49  ,   23  ,   247 ,   167 ,   229 ,   719 ,   1583    ,   3451    ,   11901   ,   10991   ,0 };
            const std::uint32_t dim2721Kuo2Init[]       =   {   1   ,   1   ,   1   ,   13  ,   5   ,   39  ,   35  ,   247 ,   185 ,   409 ,   1481    ,   3993    ,   2023    ,   9251    ,   1253    ,0 };
            const std::uint32_t dim2722Kuo2Init[]       =   {   1   ,   1   ,   3   ,   13  ,   27  ,   35  ,   49  ,   251 ,   359 ,   161 ,   1535    ,   3277    ,   1483    ,   8045    ,   22373   ,0 };
            const std::uint32_t dim2723Kuo2Init[]       =   {   1   ,   1   ,   1   ,   7   ,   3   ,   63  ,   103 ,   7   ,   141 ,   305 ,   1803    ,   3429    ,   6819    ,   3389    ,   12915   ,0 };
            const std::uint32_t dim2724Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   15  ,   7   ,   19  ,   121 ,   421 ,   633 ,   1619    ,   1225    ,   4061    ,   13649   ,   25537   ,0 };
            const std::uint32_t dim2725Kuo2Init[]       =   {   1   ,   3   ,   7   ,   13  ,   5   ,   49  ,   117 ,   97  ,   85  ,   13  ,   55  ,   2991    ,   6215    ,   15087   ,   29311   ,0 };
            const std::uint32_t dim2726Kuo2Init[]       =   {   1   ,   1   ,   7   ,   13  ,   29  ,   37  ,   23  ,   75  ,   11  ,   899 ,   1519    ,   2151    ,   235 ,   7121    ,   20881   ,0 };
            const std::uint32_t dim2727Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   7   ,   9   ,   97  ,   57  ,   307 ,   791 ,   745 ,   881 ,   6627    ,   1639    ,   22029   ,0 };
            const std::uint32_t dim2728Kuo2Init[]       =   {   1   ,   3   ,   7   ,   11  ,   31  ,   25  ,   67  ,   153 ,   397 ,   115 ,   1951    ,   553 ,   2511    ,   853 ,   22771   ,0 };
            const std::uint32_t dim2729Kuo2Init[]       =   {   1   ,   1   ,   7   ,   13  ,   13  ,   33  ,   3   ,   49  ,   281 ,   847 ,   395 ,   2671    ,   7173    ,   11035   ,   2809    ,0 };
            const std::uint32_t dim2730Kuo2Init[]       =   {   1   ,   3   ,   7   ,   11  ,   7   ,   13  ,   21  ,   93  ,   279 ,   453 ,   1793    ,   1183    ,   4071    ,   11357   ,   15871   ,0 };
            const std::uint32_t dim2731Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   31  ,   27  ,   87  ,   115 ,   373 ,   519 ,   1691    ,   3339    ,   5319    ,   10765   ,   3497    ,0 };
            const std::uint32_t dim2732Kuo2Init[]       =   {   1   ,   3   ,   5   ,   11  ,   27  ,   13  ,   73  ,   111 ,   349 ,   889 ,   1447    ,   1733    ,   7701    ,   9263    ,   27267   ,0 };
            const std::uint32_t dim2733Kuo2Init[]       =   {   1   ,   1   ,   1   ,   13  ,   15  ,   25  ,   31  ,   187 ,   227 ,   119 ,   955 ,   1233    ,   2749    ,   8477    ,   12031   ,0 };
            const std::uint32_t dim2734Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   19  ,   13  ,   89  ,   151 ,   61  ,   267 ,   1833    ,   3023    ,   8177    ,   12863   ,   13851   ,0 };
            const std::uint32_t dim2735Kuo2Init[]       =   {   1   ,   1   ,   7   ,   11  ,   11  ,   19  ,   65  ,   223 ,   175 ,   893 ,   1515    ,   2323    ,   6725    ,   747 ,   10299   ,0 };
            const std::uint32_t dim2736Kuo2Init[]       =   {   1   ,   1   ,   1   ,   15  ,   3   ,   17  ,   109 ,   119 ,   371 ,   193 ,   1289    ,   219 ,   463 ,   9043    ,   31471   ,0 };
            const std::uint32_t dim2737Kuo2Init[]       =   {   1   ,   1   ,   1   ,   3   ,   9   ,   9   ,   71  ,   185 ,   81  ,   849 ,   917 ,   2495    ,   4065    ,   14161   ,   14287   ,0 };
            const std::uint32_t dim2738Kuo2Init[]       =   {   1   ,   1   ,   5   ,   3   ,   5   ,   59  ,   111 ,   133 ,   351 ,   247 ,   1035    ,   3277    ,   3865    ,   5879    ,   16537   ,0 };
            const std::uint32_t dim2739Kuo2Init[]       =   {   1   ,   3   ,   3   ,   11  ,   23  ,   47  ,   3   ,   39  ,   343 ,   71  ,   109 ,   4005    ,   7453    ,   8327    ,   9797    ,0 };
            const std::uint32_t dim2740Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   21  ,   31  ,   53  ,   33  ,   115 ,   287 ,   431 ,   2085    ,   5275    ,   5253    ,   18137   ,0 };
            const std::uint32_t dim2741Kuo2Init[]       =   {   1   ,   3   ,   1   ,   15  ,   21  ,   43  ,   95  ,   143 ,   103 ,   611 ,   583 ,   41  ,   483 ,   13973   ,   30231   ,0 };
            const std::uint32_t dim2742Kuo2Init[]       =   {   1   ,   1   ,   1   ,   9   ,   9   ,   33  ,   49  ,   35  ,   329 ,   887 ,   1593    ,   2301    ,   229 ,   10291   ,   21153   ,0 };
            const std::uint32_t dim2743Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   25  ,   55  ,   55  ,   207 ,   381 ,   747 ,   997 ,   3105    ,   377 ,   15327   ,   24367   ,0 };
            const std::uint32_t dim2744Kuo2Init[]       =   {   1   ,   3   ,   7   ,   15  ,   23  ,   25  ,   101 ,   225 ,   345 ,   579 ,   975 ,   2383    ,   7833    ,   12727   ,   15991   ,0 };
            const std::uint32_t dim2745Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   23  ,   13  ,   51  ,   45  ,   471 ,   271 ,   151 ,   1407    ,   2079    ,   3521    ,   6469    ,0 };
            const std::uint32_t dim2746Kuo2Init[]       =   {   1   ,   3   ,   1   ,   9   ,   3   ,   11  ,   117 ,   115 ,   89  ,   871 ,   1989    ,   1341    ,   2415    ,   12921   ,   3531    ,0 };
            const std::uint32_t dim2747Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   3   ,   49  ,   41  ,   215 ,   277 ,   155 ,   1185    ,   2837    ,   4361    ,   14495   ,   19877   ,0 };
            const std::uint32_t dim2748Kuo2Init[]       =   {   1   ,   1   ,   1   ,   9   ,   9   ,   19  ,   31  ,   211 ,   179 ,   367 ,   1597    ,   561 ,   5397    ,   7525    ,   2963    ,0 };
            const std::uint32_t dim2749Kuo2Init[]       =   {   1   ,   3   ,   7   ,   11  ,   25  ,   45  ,   29  ,   151 ,   107 ,   13  ,   1461    ,   235 ,   6939    ,   6223    ,   13111   ,0 };
            const std::uint32_t dim2750Kuo2Init[]       =   {   1   ,   3   ,   7   ,   15  ,   17  ,   11  ,   43  ,   113 ,   65  ,   321 ,   1393    ,   1131    ,   2481    ,   13139   ,   14647   ,0 };
            const std::uint32_t dim2751Kuo2Init[]       =   {   1   ,   3   ,   7   ,   3   ,   15  ,   23  ,   45  ,   229 ,   175 ,   857 ,   1303    ,   783 ,   3929    ,   855 ,   13581   ,0 };
            const std::uint32_t dim2752Kuo2Init[]       =   {   1   ,   3   ,   7   ,   3   ,   7   ,   55  ,   99  ,   85  ,   415 ,   667 ,   603 ,   593 ,   427 ,   10725   ,   6973    ,0 };
            const std::uint32_t dim2753Kuo2Init[]       =   {   1   ,   3   ,   7   ,   3   ,   1   ,   23  ,   93  ,   177 ,   59  ,   601 ,   1947    ,   3253    ,   639 ,   10007   ,   1441    ,0 };
            const std::uint32_t dim2754Kuo2Init[]       =   {   1   ,   3   ,   5   ,   11  ,   13  ,   37  ,   79  ,   19  ,   395 ,   161 ,   945 ,   969 ,   1579    ,   13537   ,   6347    ,0 };
            const std::uint32_t dim2755Kuo2Init[]       =   {   1   ,   3   ,   1   ,   15  ,   3   ,   61  ,   101 ,   3   ,   289 ,   707 ,   61  ,   1405    ,   811 ,   6727    ,   22339   ,0 };
            const std::uint32_t dim2756Kuo2Init[]       =   {   1   ,   3   ,   5   ,   11  ,   3   ,   45  ,   19  ,   125 ,   503 ,   153 ,   1439    ,   2105    ,   7483    ,   1835    ,   22841   ,0 };
            const std::uint32_t dim2757Kuo2Init[]       =   {   1   ,   1   ,   7   ,   3   ,   23  ,   49  ,   49  ,   227 ,   413 ,   57  ,   1829    ,   37  ,   407 ,   4203    ,   20575   ,0 };
            const std::uint32_t dim2758Kuo2Init[]       =   {   1   ,   3   ,   5   ,   11  ,   3   ,   43  ,   93  ,   85  ,   37  ,   471 ,   1971    ,   1559    ,   5151    ,   11641   ,   13011   ,0 };
            const std::uint32_t dim2759Kuo2Init[]       =   {   1   ,   1   ,   5   ,   15  ,   5   ,   13  ,   17  ,   209 ,   125 ,   581 ,   57  ,   43  ,   7089    ,   3367    ,   16073   ,0 };
            const std::uint32_t dim2760Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   29  ,   51  ,   93  ,   223 ,   73  ,   917 ,   1657    ,   2811    ,   1593    ,   8595    ,   23347   ,0 };
            const std::uint32_t dim2761Kuo2Init[]       =   {   1   ,   3   ,   1   ,   15  ,   25  ,   21  ,   111 ,   207 ,   61  ,   815 ,   805 ,   1439    ,   5745    ,   5065    ,   9877    ,0 };
            const std::uint32_t dim2762Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   7   ,   1   ,   113 ,   225 ,   467 ,   341 ,   1145    ,   3839    ,   1127    ,   5085    ,   885 ,0 };
            const std::uint32_t dim2763Kuo2Init[]       =   {   1   ,   1   ,   7   ,   3   ,   13  ,   27  ,   103 ,   17  ,   175 ,   351 ,   1321    ,   2093    ,   3407    ,   3387    ,   1663    ,0 };
            const std::uint32_t dim2764Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   5   ,   61  ,   31  ,   223 ,   249 ,   797 ,   1541    ,   3985    ,   2165    ,   8741    ,   561 ,0 };
            const std::uint32_t dim2765Kuo2Init[]       =   {   1   ,   1   ,   1   ,   7   ,   21  ,   51  ,   119 ,   9   ,   331 ,   305 ,   1279    ,   3331    ,   2769    ,   673 ,   26293   ,0 };
            const std::uint32_t dim2766Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   7   ,   61  ,   65  ,   157 ,   7   ,   259 ,   871 ,   557 ,   7917    ,   12839   ,   18521   ,0 };
            const std::uint32_t dim2767Kuo2Init[]       =   {   1   ,   3   ,   3   ,   5   ,   9   ,   63  ,   21  ,   109 ,   409 ,   843 ,   1811    ,   1869    ,   6833    ,   6041    ,   31557   ,0 };
            const std::uint32_t dim2768Kuo2Init[]       =   {   1   ,   1   ,   5   ,   15  ,   17  ,   17  ,   25  ,   79  ,   157 ,   657 ,   1049    ,   2071    ,   4381    ,   14123   ,   4609    ,0 };
            const std::uint32_t dim2769Kuo2Init[]       =   {   1   ,   1   ,   5   ,   3   ,   3   ,   7   ,   45  ,   69  ,   311 ,   197 ,   1729    ,   2803    ,   2621    ,   1165    ,   26455   ,0 };
            const std::uint32_t dim2770Kuo2Init[]       =   {   1   ,   3   ,   7   ,   7   ,   23  ,   21  ,   21  ,   227 ,   481 ,   825 ,   1871    ,   325 ,   3199    ,   5591    ,   22061   ,0 };
            const std::uint32_t dim2771Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   7   ,   53  ,   125 ,   163 ,   133 ,   1015    ,   727 ,   329 ,   403 ,   3347    ,   8957    ,0 };
            const std::uint32_t dim2772Kuo2Init[]       =   {   1   ,   1   ,   3   ,   1   ,   13  ,   19  ,   107 ,   31  ,   261 ,   771 ,   195 ,   2381    ,   2577    ,   5381    ,   7159    ,0 };
            const std::uint32_t dim2773Kuo2Init[]       =   {   1   ,   3   ,   7   ,   9   ,   7   ,   21  ,   61  ,   179 ,   405 ,   745 ,   689 ,   2527    ,   4189    ,   12869   ,   32101   ,0 };
            const std::uint32_t dim2774Kuo2Init[]       =   {   1   ,   3   ,   7   ,   1   ,   3   ,   25  ,   35  ,   103 ,   107 ,   433 ,   1039    ,   3557    ,   7207    ,   13945   ,   27751   ,0 };
            const std::uint32_t dim2775Kuo2Init[]       =   {   1   ,   3   ,   5   ,   5   ,   7   ,   9   ,   55  ,   93  ,   39  ,   965 ,   1391    ,   1069    ,   6003    ,   3785    ,   17337   ,0 };
            const std::uint32_t dim2776Kuo2Init[]       =   {   1   ,   1   ,   5   ,   5   ,   11  ,   33  ,   127 ,   247 ,   443 ,   697 ,   2007    ,   491 ,   3773    ,   4921    ,   21083   ,0 };
            const std::uint32_t dim2777Kuo2Init[]       =   {   1   ,   1   ,   5   ,   9   ,   1   ,   3   ,   33  ,   99  ,   31  ,   797 ,   295 ,   2855    ,   1911    ,   5741    ,   21255   ,0 };
            const std::uint32_t dim2778Kuo2Init[]       =   {   1   ,   1   ,   5   ,   9   ,   25  ,   27  ,   77  ,   111 ,   119 ,   1   ,   193 ,   2825    ,   3721    ,   2923    ,   1301    ,0 };
            const std::uint32_t dim2779Kuo2Init[]       =   {   1   ,   1   ,   1   ,   9   ,   11  ,   51  ,   51  ,   193 ,   331 ,   867 ,   1711    ,   969 ,   1245    ,   2815    ,   13165   ,0 };
            const std::uint32_t dim2780Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   23  ,   29  ,   23  ,   193 ,   357 ,   567 ,   983 ,   2861    ,   3973    ,   3613    ,   8049    ,0 };
            const std::uint32_t dim2781Kuo2Init[]       =   {   1   ,   1   ,   7   ,   3   ,   27  ,   1   ,   117 ,   255 ,   149 ,   427 ,   1211    ,   2945    ,   4057    ,   725 ,   11061   ,0 };
            const std::uint32_t dim2782Kuo2Init[]       =   {   1   ,   1   ,   7   ,   5   ,   13  ,   5   ,   101 ,   21  ,   167 ,   535 ,   825 ,   639 ,   6659    ,   9779    ,   11939   ,0 };
            const std::uint32_t dim2783Kuo2Init[]       =   {   1   ,   3   ,   7   ,   1   ,   23  ,   25  ,   5   ,   15  ,   491 ,   531 ,   1035    ,   1989    ,   2125    ,   2779    ,   3207    ,0 };
            const std::uint32_t dim2784Kuo2Init[]       =   {   1   ,   1   ,   3   ,   13  ,   13  ,   25  ,   43  ,   155 ,   251 ,   761 ,   123 ,   1373    ,   649 ,   11709   ,   22331   ,0 };
            const std::uint32_t dim2785Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   25  ,   37  ,   15  ,   247 ,   303 ,   95  ,   1837    ,   499 ,   2181    ,   11223   ,   1633    ,0 };
            const std::uint32_t dim2786Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   15  ,   53  ,   29  ,   193 ,   11  ,   625 ,   21  ,   3893    ,   957 ,   493 ,   32393   ,0 };
            const std::uint32_t dim2787Kuo2Init[]       =   {   1   ,   1   ,   5   ,   9   ,   31  ,   13  ,   3   ,   235 ,   65  ,   563 ,   1787    ,   387 ,   2573    ,   3435    ,   8669    ,0 };
            const std::uint32_t dim2788Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   29  ,   17  ,   73  ,   81  ,   207 ,   335 ,   1949    ,   3519    ,   6491    ,   9185    ,   2305    ,0 };
            const std::uint32_t dim2789Kuo2Init[]       =   {   1   ,   1   ,   3   ,   11  ,   5   ,   43  ,   15  ,   141 ,   347 ,   171 ,   1965    ,   2733    ,   7873    ,   7295    ,   10571   ,0 };
            const std::uint32_t dim2790Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   5   ,   3   ,   73  ,   89  ,   189 ,   77  ,   877 ,   1127    ,   3609    ,   11649   ,   31191   ,0 };
            const std::uint32_t dim2791Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   15  ,   25  ,   103 ,   73  ,   363 ,   261 ,   833 ,   2297    ,   4295    ,   13505   ,   8435    ,0 };
            const std::uint32_t dim2792Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   23  ,   57  ,   15  ,   87  ,   215 ,   789 ,   975 ,   2659    ,   6407    ,   9883    ,   3863    ,0 };
            const std::uint32_t dim2793Kuo2Init[]       =   {   1   ,   1   ,   1   ,   9   ,   19  ,   51  ,   127 ,   77  ,   259 ,   161 ,   1527    ,   1911    ,   6707    ,   15573   ,   12479   ,0 };
            const std::uint32_t dim2794Kuo2Init[]       =   {   1   ,   3   ,   1   ,   15  ,   11  ,   5   ,   35  ,   89  ,   235 ,   281 ,   269 ,   511 ,   783 ,   307 ,   19887   ,0 };
            const std::uint32_t dim2795Kuo2Init[]       =   {   1   ,   3   ,   7   ,   15  ,   1   ,   43  ,   85  ,   25  ,   133 ,   577 ,   1719    ,   3999    ,   4597    ,   125 ,   12945   ,0 };
            const std::uint32_t dim2796Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   3   ,   1   ,   3   ,   111 ,   145 ,   485 ,   1959    ,   1859    ,   3567    ,   4219    ,   7507    ,0 };
            const std::uint32_t dim2797Kuo2Init[]       =   {   1   ,   1   ,   3   ,   5   ,   27  ,   17  ,   45  ,   157 ,   87  ,   895 ,   497 ,   3   ,   1553    ,   2697    ,   24767   ,0 };
            const std::uint32_t dim2798Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   31  ,   23  ,   123 ,   67  ,   349 ,   717 ,   1699    ,   823 ,   851 ,   1283    ,   25641   ,0 };
            const std::uint32_t dim2799Kuo2Init[]       =   {   1   ,   1   ,   5   ,   15  ,   9   ,   61  ,   43  ,   171 ,   33  ,   367 ,   1887    ,   917 ,   1901    ,   10881   ,   5699    ,0 };
            const std::uint32_t dim2800Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   11  ,   33  ,   45  ,   19  ,   71  ,   913 ,   687 ,   265 ,   1579    ,   13857   ,   3833    ,0 };
            const std::uint32_t dim2801Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   7   ,   15  ,   11  ,   87  ,   277 ,   435 ,   1479    ,   3025    ,   4663    ,   12063   ,   25185   ,0 };
            const std::uint32_t dim2802Kuo2Init[]       =   {   1   ,   1   ,   1   ,   1   ,   15  ,   11  ,   91  ,   99  ,   195 ,   77  ,   967 ,   2741    ,   4291    ,   4441    ,   2763    ,0 };
            const std::uint32_t dim2803Kuo2Init[]       =   {   1   ,   3   ,   7   ,   9   ,   9   ,   47  ,   25  ,   225 ,   193 ,   569 ,   561 ,   2567    ,   2751    ,   9035    ,   21613   ,0 };
            const std::uint32_t dim2804Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   3   ,   25  ,   99  ,   95  ,   33  ,   811 ,   479 ,   99  ,   7893    ,   869 ,   6879    ,0 };
            const std::uint32_t dim2805Kuo2Init[]       =   {   1   ,   1   ,   5   ,   7   ,   11  ,   43  ,   111 ,   131 ,   107 ,   989 ,   147 ,   529 ,   6361    ,   769 ,   26651   ,0 };
            const std::uint32_t dim2806Kuo2Init[]       =   {   1   ,   1   ,   5   ,   9   ,   23  ,   47  ,   81  ,   97  ,   357 ,   613 ,   609 ,   357 ,   2001    ,   14795   ,   25093   ,0 };
            const std::uint32_t dim2807Kuo2Init[]       =   {   1   ,   1   ,   7   ,   3   ,   1   ,   13  ,   31  ,   171 ,   471 ,   981 ,   1923    ,   3053    ,   1577    ,   14433   ,   1795    ,0 };
            const std::uint32_t dim2808Kuo2Init[]       =   {   1   ,   1   ,   3   ,   11  ,   29  ,   15  ,   107 ,   5   ,   281 ,   773 ,   1323    ,   763 ,   6821    ,   15309   ,   21459   ,0 };
            const std::uint32_t dim2809Kuo2Init[]       =   {   1   ,   1   ,   5   ,   3   ,   17  ,   47  ,   49  ,   159 ,   17  ,   595 ,   1405    ,   1307    ,   3027    ,   3023    ,   17231   ,0 };
            const std::uint32_t dim2810Kuo2Init[]       =   {   1   ,   3   ,   3   ,   11  ,   5   ,   37  ,   39  ,   247 ,   391 ,   587 ,   1305    ,   969 ,   7183    ,   1079    ,   5723    ,0 };
            const std::uint32_t dim2811Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   11  ,   57  ,   49  ,   55  ,   505 ,   961 ,   115 ,   2445    ,   583 ,   9175    ,   11897   ,0 };
            const std::uint32_t dim2812Kuo2Init[]       =   {   1   ,   1   ,   7   ,   13  ,   23  ,   35  ,   9   ,   59  ,   147 ,   139 ,   361 ,   1497    ,   1691    ,   1149    ,   19777   ,0 };
            const std::uint32_t dim2813Kuo2Init[]       =   {   1   ,   3   ,   7   ,   1   ,   19  ,   41  ,   71  ,   63  ,   401 ,   193 ,   107 ,   1891    ,   5353    ,   4619    ,   18311   ,0 };
            const std::uint32_t dim2814Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   27  ,   7   ,   49  ,   69  ,   179 ,   461 ,   1625    ,   2431    ,   5149    ,   3221    ,   14221   ,0 };
            const std::uint32_t dim2815Kuo2Init[]       =   {   1   ,   3   ,   7   ,   13  ,   7   ,   11  ,   55  ,   93  ,   191 ,   1011    ,   139 ,   2323    ,   5103    ,   9655    ,   28605   ,0 };
            const std::uint32_t dim2816Kuo2Init[]       =   {   1   ,   1   ,   5   ,   7   ,   29  ,   53  ,   117 ,   253 ,   193 ,   29  ,   2003    ,   2051    ,   6113    ,   4941    ,   18407   ,0 };
            const std::uint32_t dim2817Kuo2Init[]       =   {   1   ,   1   ,   5   ,   5   ,   31  ,   7   ,   63  ,   179 ,   371 ,   1007    ,   107 ,   113 ,   6845    ,   8507    ,   9691    ,0 };
            const std::uint32_t dim2818Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   9   ,   31  ,   91  ,   225 ,   115 ,   905 ,   1593    ,   2791    ,   1507    ,   13323   ,   787 ,0 };
            const std::uint32_t dim2819Kuo2Init[]       =   {   1   ,   3   ,   1   ,   9   ,   31  ,   13  ,   81  ,   111 ,   255 ,   467 ,   2007    ,   3591    ,   3849    ,   3445    ,   6859    ,0 };
            const std::uint32_t dim2820Kuo2Init[]       =   {   1   ,   3   ,   7   ,   15  ,   19  ,   3   ,   89  ,   171 ,   445 ,   803 ,   1583    ,   1875    ,   5631    ,   10583   ,   32527   ,0 };
            const std::uint32_t dim2821Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   29  ,   29  ,   41  ,   199 ,   237 ,   507 ,   1715    ,   3887    ,   2951    ,   5803    ,   32749   ,0 };
            const std::uint32_t dim2822Kuo2Init[]       =   {   1   ,   1   ,   3   ,   5   ,   21  ,   51  ,   29  ,   131 ,   459 ,   611 ,   967 ,   99  ,   8057    ,   12685   ,   16021   ,0 };
            const std::uint32_t dim2823Kuo2Init[]       =   {   1   ,   3   ,   5   ,   5   ,   21  ,   19  ,   103 ,   131 ,   149 ,   477 ,   437 ,   4003    ,   7141    ,   2465    ,   32723   ,0 };
            const std::uint32_t dim2824Kuo2Init[]       =   {   1   ,   3   ,   7   ,   15  ,   9   ,   41  ,   115 ,   47  ,   261 ,   589 ,   1859    ,   631 ,   719 ,   4459    ,   26475   ,0 };
            const std::uint32_t dim2825Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   9   ,   43  ,   79  ,   51  ,   383 ,   355 ,   1977    ,   739 ,   7333    ,   3573    ,   16061   ,0 };
            const std::uint32_t dim2826Kuo2Init[]       =   {   1   ,   1   ,   3   ,   1   ,   11  ,   9   ,   79  ,   141 ,   135 ,   195 ,   755 ,   585 ,   7125    ,   4643    ,   31791   ,0 };
            const std::uint32_t dim2827Kuo2Init[]       =   {   1   ,   1   ,   1   ,   7   ,   21  ,   23  ,   5   ,   225 ,   57  ,   307 ,   455 ,   3713    ,   8167    ,   4759    ,   10337   ,0 };
            const std::uint32_t dim2828Kuo2Init[]       =   {   1   ,   3   ,   1   ,   15  ,   3   ,   45  ,   9   ,   225 ,   167 ,   847 ,   1205    ,   2105    ,   2547    ,   10925   ,   31181   ,0 };
            const std::uint32_t dim2829Kuo2Init[]       =   {   1   ,   1   ,   3   ,   5   ,   3   ,   25  ,   57  ,   21  ,   45  ,   685 ,   53  ,   2447    ,   3139    ,   10949   ,   14939   ,0 };
            const std::uint32_t dim2830Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   13  ,   55  ,   13  ,   185 ,   353 ,   613 ,   1655    ,   1171    ,   6261    ,   1703    ,   26859   ,0 };
            const std::uint32_t dim2831Kuo2Init[]       =   {   1   ,   1   ,   1   ,   15  ,   25  ,   29  ,   99  ,   81  ,   141 ,   387 ,   1369    ,   2177    ,   289 ,   14499   ,   23795   ,0 };
            const std::uint32_t dim2832Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   1   ,   37  ,   123 ,   99  ,   1   ,   707 ,   1415    ,   1275    ,   3979    ,   3359    ,   17807   ,0 };
            const std::uint32_t dim2833Kuo2Init[]       =   {   1   ,   1   ,   5   ,   15  ,   19  ,   7   ,   113 ,   51  ,   329 ,   109 ,   1705    ,   517 ,   1887    ,   393 ,   8283    ,0 };
            const std::uint32_t dim2834Kuo2Init[]       =   {   1   ,   3   ,   1   ,   13  ,   23  ,   63  ,   89  ,   117 ,   89  ,   515 ,   1221    ,   3267    ,   2371    ,   5065    ,   16391   ,0 };
            const std::uint32_t dim2835Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   1   ,   17  ,   39  ,   129 ,   453 ,   503 ,   841 ,   2997    ,   4279    ,   8639    ,   17623   ,0 };
            const std::uint32_t dim2836Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   27  ,   23  ,   127 ,   85  ,   301 ,   491 ,   959 ,   3241    ,   7525    ,   13723   ,   12317   ,0 };
            const std::uint32_t dim2837Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   31  ,   63  ,   45  ,   237 ,   173 ,   823 ,   223 ,   3129    ,   3285    ,   359 ,   3549    ,0 };
            const std::uint32_t dim2838Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   19  ,   29  ,   85  ,   191 ,   395 ,   717 ,   1305    ,   2529    ,   7939    ,   10905   ,   8941    ,0 };
            const std::uint32_t dim2839Kuo2Init[]       =   {   1   ,   1   ,   5   ,   13  ,   31  ,   3   ,   41  ,   61  ,   461 ,   341 ,   683 ,   1973    ,   7127    ,   2183    ,   2137    ,0 };
            const std::uint32_t dim2840Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   27  ,   33  ,   97  ,   97  ,   319 ,   329 ,   1075    ,   539 ,   3313    ,   6343    ,   11249   ,0 };
            const std::uint32_t dim2841Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   25  ,   31  ,   99  ,   59  ,   337 ,   169 ,   861 ,   1989    ,   5999    ,   5397    ,   20563   ,0 };
            const std::uint32_t dim2842Kuo2Init[]       =   {   1   ,   1   ,   5   ,   13  ,   17  ,   37  ,   83  ,   33  ,   75  ,   887 ,   379 ,   3499    ,   733 ,   4343    ,   31503   ,0 };
            const std::uint32_t dim2843Kuo2Init[]       =   {   1   ,   1   ,   3   ,   1   ,   3   ,   45  ,   3   ,   245 ,   37  ,   797 ,   43  ,   943 ,   5301    ,   6857    ,   6653    ,0 };
            const std::uint32_t dim2844Kuo2Init[]       =   {   1   ,   1   ,   1   ,   3   ,   9   ,   7   ,   39  ,   231 ,   349 ,   481 ,   1831    ,   2115    ,   6381    ,   13021   ,   18775   ,0 };
            const std::uint32_t dim2845Kuo2Init[]       =   {   1   ,   3   ,   1   ,   11  ,   31  ,   27  ,   33  ,   103 ,   469 ,   987 ,   663 ,   3533    ,   1441    ,   4703    ,   23383   ,0 };
            const std::uint32_t dim2846Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   27  ,   59  ,   31  ,   31  ,   463 ,   851 ,   1957    ,   2905    ,   4823    ,   12549   ,   849 ,0 };
            const std::uint32_t dim2847Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   17  ,   31  ,   125 ,   183 ,   189 ,   297 ,   417 ,   1387    ,   5811    ,   10517   ,   19367   ,0 };
            const std::uint32_t dim2848Kuo2Init[]       =   {   1   ,   3   ,   7   ,   7   ,   7   ,   9   ,   91  ,   9   ,   343 ,   267 ,   493 ,   431 ,   2345    ,   7173    ,   1769    ,0 };
            const std::uint32_t dim2849Kuo2Init[]       =   {   1   ,   1   ,   1   ,   13  ,   13  ,   43  ,   75  ,   83  ,   19  ,   115 ,   1609    ,   2449    ,   5647    ,   12201   ,   27053   ,0 };
            const std::uint32_t dim2850Kuo2Init[]       =   {   1   ,   3   ,   7   ,   7   ,   1   ,   7   ,   81  ,   89  ,   371 ,   283 ,   993 ,   3875    ,   6853    ,   16039   ,   12725   ,0 };
            const std::uint32_t dim2851Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   21  ,   61  ,   121 ,   135 ,   333 ,   339 ,   39  ,   2543    ,   3517    ,   9099    ,   27495   ,0 };
            const std::uint32_t dim2852Kuo2Init[]       =   {   1   ,   1   ,   7   ,   13  ,   19  ,   59  ,   65  ,   65  ,   407 ,   255 ,   915 ,   2679    ,   2841    ,   13981   ,   6351    ,0 };
            const std::uint32_t dim2853Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   9   ,   45  ,   73  ,   217 ,   93  ,   3   ,   493 ,   531 ,   6709    ,   6543    ,   26243   ,0 };
            const std::uint32_t dim2854Kuo2Init[]       =   {   1   ,   3   ,   3   ,   13  ,   9   ,   25  ,   77  ,   223 ,   495 ,   789 ,   1885    ,   383 ,   7767    ,   4309    ,   29863   ,0 };
            const std::uint32_t dim2855Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   21  ,   55  ,   11  ,   13  ,   19  ,   605 ,   1067    ,   667 ,   1163    ,   3847    ,   17997   ,0 };
            const std::uint32_t dim2856Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   15  ,   51  ,   69  ,   115 ,   19  ,   1003    ,   1307    ,   3245    ,   7087    ,   6935    ,   25439   ,0 };
            const std::uint32_t dim2857Kuo2Init[]       =   {   1   ,   1   ,   7   ,   5   ,   11  ,   7   ,   85  ,   171 ,   301 ,   953 ,   507 ,   3873    ,   1121    ,   1663    ,   6321    ,0 };
            const std::uint32_t dim2858Kuo2Init[]       =   {   1   ,   1   ,   1   ,   13  ,   11  ,   1   ,   105 ,   175 ,   163 ,   847 ,   983 ,   3869    ,   3571    ,   3405    ,   25475   ,0 };
            const std::uint32_t dim2859Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   7   ,   51  ,   89  ,   127 ,   347 ,   867 ,   429 ,   1483    ,   5203    ,   5215    ,   18521   ,0 };
            const std::uint32_t dim2860Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   21  ,   35  ,   91  ,   107 ,   111 ,   895 ,   1827    ,   3273    ,   3189    ,   4253    ,   12643   ,0 };
            const std::uint32_t dim2861Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   31  ,   33  ,   59  ,   27  ,   59  ,   297 ,   7   ,   1521    ,   1571    ,   10275   ,   32537   ,0 };
            const std::uint32_t dim2862Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   1   ,   27  ,   17  ,   115 ,   349 ,   593 ,   1819    ,   707 ,   4915    ,   2053    ,   13393   ,0 };
            const std::uint32_t dim2863Kuo2Init[]       =   {   1   ,   1   ,   1   ,   1   ,   25  ,   47  ,   73  ,   163 ,   191 ,   637 ,   1723    ,   2431    ,   4821    ,   4283    ,   14647   ,0 };
            const std::uint32_t dim2864Kuo2Init[]       =   {   1   ,   3   ,   7   ,   13  ,   1   ,   55  ,   67  ,   89  ,   113 ,   757 ,   1675    ,   255 ,   99  ,   9427    ,   953 ,0 };
            const std::uint32_t dim2865Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   1   ,   33  ,   7   ,   49  ,   299 ,   205 ,   1933    ,   2319    ,   6047    ,   6837    ,   6411    ,0 };
            const std::uint32_t dim2866Kuo2Init[]       =   {   1   ,   1   ,   7   ,   5   ,   11  ,   35  ,   61  ,   211 ,   487 ,   253 ,   1463    ,   2039    ,   3859    ,   4315    ,   29603   ,0 };
            const std::uint32_t dim2867Kuo2Init[]       =   {   1   ,   3   ,   1   ,   15  ,   23  ,   49  ,   99  ,   41  ,   263 ,   177 ,   193 ,   921 ,   1031    ,   13745   ,   14283   ,0 };
            const std::uint32_t dim2868Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   19  ,   35  ,   91  ,   19  ,   481 ,   305 ,   477 ,   2989    ,   7319    ,   2477    ,   2481    ,0 };
            const std::uint32_t dim2869Kuo2Init[]       =   {   1   ,   3   ,   7   ,   13  ,   1   ,   15  ,   25  ,   133 ,   175 ,   571 ,   15  ,   505 ,   7459    ,   13283   ,   10253   ,0 };
            const std::uint32_t dim2870Kuo2Init[]       =   {   1   ,   3   ,   7   ,   11  ,   13  ,   27  ,   95  ,   179 ,   149 ,   267 ,   481 ,   543 ,   3643    ,   4261    ,   1241    ,0 };
            const std::uint32_t dim2871Kuo2Init[]       =   {   1   ,   1   ,   3   ,   1   ,   5   ,   25  ,   115 ,   27  ,   503 ,   595 ,   43  ,   975 ,   6223    ,   14173   ,   12977   ,0 };
            const std::uint32_t dim2872Kuo2Init[]       =   {   1   ,   1   ,   1   ,   13  ,   17  ,   55  ,   3   ,   129 ,   125 ,   565 ,   785 ,   2787    ,   5963    ,   12565   ,   11061   ,0 };
            const std::uint32_t dim2873Kuo2Init[]       =   {   1   ,   1   ,   1   ,   1   ,   23  ,   25  ,   51  ,   89  ,   317 ,   887 ,   1007    ,   1619    ,   3221    ,   4015    ,   18183   ,0 };
            const std::uint32_t dim2874Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   27  ,   37  ,   33  ,   131 ,   379 ,   505 ,   1679    ,   2381    ,   629 ,   8593    ,   15553   ,0 };
            const std::uint32_t dim2875Kuo2Init[]       =   {   1   ,   3   ,   1   ,   9   ,   21  ,   53  ,   79  ,   85  ,   27  ,   541 ,   997 ,   1721    ,   2379    ,   9939    ,   32197   ,0 };
            const std::uint32_t dim2876Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   29  ,   3   ,   29  ,   7   ,   499 ,   195 ,   157 ,   1431    ,   1117    ,   14781   ,   14811   ,0 };
            const std::uint32_t dim2877Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   23  ,   19  ,   41  ,   59  ,   313 ,   391 ,   193 ,   3813    ,   2769    ,   7845    ,   4853    ,0 };
            const std::uint32_t dim2878Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   7   ,   61  ,   103 ,   45  ,   225 ,   753 ,   339 ,   963 ,   3991    ,   8699    ,   19805   ,0 };
            const std::uint32_t dim2879Kuo2Init[]       =   {   1   ,   1   ,   3   ,   5   ,   15  ,   61  ,   125 ,   121 ,   53  ,   105 ,   121 ,   1939    ,   4745    ,   1193    ,   1733    ,0 };
            const std::uint32_t dim2880Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   29  ,   29  ,   71  ,   137 ,   195 ,   757 ,   1251    ,   3483    ,   6977    ,   1189    ,   4929    ,0 };
            const std::uint32_t dim2881Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   1   ,   11  ,   21  ,   39  ,   199 ,   873 ,   1063    ,   3327    ,   2171    ,   14611   ,   15283   ,0 };
            const std::uint32_t dim2882Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   11  ,   19  ,   71  ,   185 ,   235 ,   211 ,   1435    ,   543 ,   3445    ,   2533    ,   25037   ,0 };
            const std::uint32_t dim2883Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   15  ,   17  ,   33  ,   139 ,   301 ,   853 ,   2027    ,   1665    ,   4931    ,   2083    ,   9775    ,0 };
            const std::uint32_t dim2884Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   31  ,   21  ,   91  ,   71  ,   273 ,   119 ,   801 ,   2071    ,   4537    ,   541 ,   743 ,0 };
            const std::uint32_t dim2885Kuo2Init[]       =   {   1   ,   1   ,   3   ,   5   ,   29  ,   23  ,   15  ,   225 ,   333 ,   979 ,   443 ,   1425    ,   3383    ,   5137    ,   27273   ,0 };
            const std::uint32_t dim2886Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   21  ,   27  ,   121 ,   169 ,   495 ,   883 ,   355 ,   3923    ,   1505    ,   13033   ,   6421    ,0 };
            const std::uint32_t dim2887Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   3   ,   17  ,   19  ,   169 ,   43  ,   659 ,   893 ,   1913    ,   885 ,   1239    ,   4055    ,0 };
            const std::uint32_t dim2888Kuo2Init[]       =   {   1   ,   1   ,   1   ,   13  ,   13  ,   39  ,   1   ,   123 ,   29  ,   573 ,   475 ,   535 ,   4685    ,   6377    ,   30009   ,0 };
            const std::uint32_t dim2889Kuo2Init[]       =   {   1   ,   3   ,   7   ,   7   ,   15  ,   53  ,   93  ,   183 ,   379 ,   125 ,   489 ,   4059    ,   5411    ,   7909    ,   25799   ,0 };
            const std::uint32_t dim2890Kuo2Init[]       =   {   1   ,   1   ,   1   ,   3   ,   23  ,   31  ,   75  ,   61  ,   75  ,   379 ,   1221    ,   3045    ,   7111    ,   10639   ,   3177    ,0 };
            const std::uint32_t dim2891Kuo2Init[]       =   {   1   ,   1   ,   1   ,   7   ,   27  ,   37  ,   77  ,   145 ,   35  ,   1005    ,   1105    ,   1301    ,   5217    ,   3011    ,   22631   ,0 };
            const std::uint32_t dim2892Kuo2Init[]       =   {   1   ,   1   ,   5   ,   5   ,   29  ,   7   ,   55  ,   139 ,   323 ,   413 ,   31  ,   1719    ,   2315    ,   5809    ,   9521    ,0 };
            const std::uint32_t dim2893Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   21  ,   61  ,   45  ,   143 ,   427 ,   511 ,   1007    ,   1009    ,   6775    ,   4243    ,   29573   ,0 };
            const std::uint32_t dim2894Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   11  ,   13  ,   29  ,   99  ,   179 ,   493 ,   1793    ,   375 ,   109 ,   8561    ,   14799   ,0 };
            const std::uint32_t dim2895Kuo2Init[]       =   {   1   ,   3   ,   1   ,   9   ,   5   ,   37  ,   83  ,   227 ,   241 ,   933 ,   869 ,   2125    ,   2733    ,   205 ,   14985   ,0 };
            const std::uint32_t dim2896Kuo2Init[]       =   {   1   ,   3   ,   7   ,   3   ,   11  ,   17  ,   39  ,   97  ,   229 ,   805 ,   491 ,   2881    ,   4147    ,   2159    ,   32461   ,0 };
            const std::uint32_t dim2897Kuo2Init[]       =   {   1   ,   3   ,   7   ,   15  ,   27  ,   17  ,   71  ,   227 ,   247 ,   731 ,   1287    ,   397 ,   7237    ,   10869   ,   7799    ,0 };
            const std::uint32_t dim2898Kuo2Init[]       =   {   1   ,   3   ,   7   ,   15  ,   7   ,   1   ,   63  ,   163 ,   249 ,   111 ,   1015    ,   2379    ,   7051    ,   11615   ,   20031   ,0 };
            const std::uint32_t dim2899Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   1   ,   41  ,   61  ,   99  ,   385 ,   725 ,   161 ,   2595    ,   1789    ,   6619    ,   13397   ,0 };
            const std::uint32_t dim2900Kuo2Init[]       =   {   1   ,   1   ,   7   ,   15  ,   5   ,   53  ,   59  ,   153 ,   427 ,   251 ,   1977    ,   1757    ,   821 ,   6391    ,   7825    ,0 };
            const std::uint32_t dim2901Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   17  ,   19  ,   83  ,   55  ,   199 ,   573 ,   337 ,   919 ,   649 ,   555 ,   27791   ,0 };
            const std::uint32_t dim2902Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   25  ,   11  ,   23  ,   167 ,   443 ,   325 ,   2037    ,   2533    ,   643 ,   1815    ,   24747   ,0 };
            const std::uint32_t dim2903Kuo2Init[]       =   {   1   ,   1   ,   1   ,   7   ,   3   ,   15  ,   21  ,   73  ,   165 ,   241 ,   1089    ,   337 ,   4465    ,   11867   ,   31075   ,0 };
            const std::uint32_t dim2904Kuo2Init[]       =   {   1   ,   3   ,   1   ,   9   ,   31  ,   33  ,   41  ,   217 ,   185 ,   973 ,   1971    ,   1537    ,   1251    ,   4307    ,   22729   ,0 };
            const std::uint32_t dim2905Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   7   ,   51  ,   17  ,   37  ,   113 ,   339 ,   211 ,   947 ,   4649    ,   8061    ,   1533    ,0 };
            const std::uint32_t dim2906Kuo2Init[]       =   {   1   ,   3   ,   3   ,   11  ,   7   ,   1   ,   29  ,   233 ,   145 ,   121 ,   83  ,   3311    ,   2007    ,   15325   ,   2507    ,0 };
            const std::uint32_t dim2907Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   25  ,   9   ,   117 ,   227 ,   359 ,   401 ,   695 ,   841 ,   5825    ,   14661   ,   14937   ,0 };
            const std::uint32_t dim2908Kuo2Init[]       =   {   1   ,   3   ,   3   ,   13  ,   27  ,   43  ,   61  ,   117 ,   297 ,   773 ,   1589    ,   347 ,   3227    ,   10893   ,   3331    ,0 };
            const std::uint32_t dim2909Kuo2Init[]       =   {   1   ,   1   ,   5   ,   13  ,   5   ,   15  ,   65  ,   97  ,   155 ,   905 ,   655 ,   1665    ,   2759    ,   14709   ,   14327   ,0 };
            const std::uint32_t dim2910Kuo2Init[]       =   {   1   ,   3   ,   3   ,   11  ,   31  ,   9   ,   63  ,   207 ,   287 ,   895 ,   817 ,   1753    ,   1961    ,   15363   ,   5269    ,0 };
            const std::uint32_t dim2911Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   3   ,   17  ,   21  ,   131 ,   295 ,   553 ,   1583    ,   1797    ,   6949    ,   7047    ,   30351   ,0 };
            const std::uint32_t dim2912Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   23  ,   9   ,   123 ,   155 ,   1   ,   525 ,   469 ,   165 ,   591 ,   6113    ,   17593   ,0 };
            const std::uint32_t dim2913Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   27  ,   21  ,   125 ,   175 ,   323 ,   113 ,   1805    ,   3775    ,   443 ,   15723   ,   187 ,0 };
            const std::uint32_t dim2914Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   29  ,   7   ,   89  ,   123 ,   349 ,   469 ,   635 ,   629 ,   1227    ,   11601   ,   10409   ,0 };
            const std::uint32_t dim2915Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   13  ,   7   ,   13  ,   209 ,   431 ,   59  ,   2001    ,   1347    ,   4619    ,   11581   ,   23281   ,0 };
            const std::uint32_t dim2916Kuo2Init[]       =   {   1   ,   3   ,   5   ,   3   ,   3   ,   9   ,   15  ,   169 ,   77  ,   293 ,   17  ,   3205    ,   5035    ,   14777   ,   2175    ,0 };
            const std::uint32_t dim2917Kuo2Init[]       =   {   1   ,   1   ,   1   ,   9   ,   27  ,   5   ,   39  ,   237 ,   275 ,   121 ,   217 ,   1283    ,   1619    ,   9115    ,   18019   ,0 };
            const std::uint32_t dim2918Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   31  ,   43  ,   111 ,   235 ,   439 ,   217 ,   769 ,   513 ,   5147    ,   4033    ,   27329   ,0 };
            const std::uint32_t dim2919Kuo2Init[]       =   {   1   ,   1   ,   5   ,   5   ,   31  ,   25  ,   35  ,   71  ,   441 ,   1013    ,   963 ,   2945    ,   4507    ,   16329   ,   5965    ,0 };
            const std::uint32_t dim2920Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   27  ,   25  ,   109 ,   43  ,   421 ,   963 ,   553 ,   3347    ,   3159    ,   11909   ,   29827   ,0 };
            const std::uint32_t dim2921Kuo2Init[]       =   {   1   ,   3   ,   3   ,   11  ,   5   ,   17  ,   1   ,   253 ,   497 ,   209 ,   423 ,   3837    ,   5233    ,   3919    ,   4593    ,0 };
            const std::uint32_t dim2922Kuo2Init[]       =   {   1   ,   3   ,   5   ,   11  ,   1   ,   61  ,   85  ,   61  ,   59  ,   637 ,   1017    ,   455 ,   5529    ,   7495    ,   16645   ,0 };
            const std::uint32_t dim2923Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   11  ,   11  ,   111 ,   151 ,   297 ,   289 ,   259 ,   1737    ,   4033    ,   5545    ,   22049   ,0 };
            const std::uint32_t dim2924Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   11  ,   33  ,   53  ,   43  ,   95  ,   859 ,   1113    ,   3201    ,   2705    ,   15009   ,   24945   ,0 };
            const std::uint32_t dim2925Kuo2Init[]       =   {   1   ,   1   ,   7   ,   3   ,   7   ,   1   ,   59  ,   201 ,   127 ,   1023    ,   879 ,   1359    ,   4323    ,   11829   ,   32591   ,0 };
            const std::uint32_t dim2926Kuo2Init[]       =   {   1   ,   1   ,   5   ,   13  ,   1   ,   15  ,   65  ,   3   ,   7   ,   373 ,   427 ,   3987    ,   3849    ,   16289   ,   3669    ,0 };
            const std::uint32_t dim2927Kuo2Init[]       =   {   1   ,   1   ,   1   ,   3   ,   23  ,   21  ,   49  ,   215 ,   159 ,   577 ,   963 ,   3257    ,   5919    ,   4397    ,   14811   ,0 };
            const std::uint32_t dim2928Kuo2Init[]       =   {   1   ,   3   ,   1   ,   9   ,   3   ,   43  ,   51  ,   49  ,   331 ,   717 ,   791 ,   279 ,   3305    ,   955 ,   14003   ,0 };
            const std::uint32_t dim2929Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   19  ,   45  ,   11  ,   249 ,   9   ,   221 ,   1525    ,   2413    ,   1807    ,   191 ,   3063    ,0 };
            const std::uint32_t dim2930Kuo2Init[]       =   {   1   ,   3   ,   7   ,   1   ,   17  ,   33  ,   45  ,   201 ,   471 ,   683 ,   13  ,   3851    ,   7337    ,   2249    ,   8287    ,0 };
            const std::uint32_t dim2931Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   11  ,   21  ,   85  ,   141 ,   445 ,   691 ,   577 ,   2781    ,   3677    ,   11799   ,   25555   ,0 };
            const std::uint32_t dim2932Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   3   ,   27  ,   71  ,   245 ,   341 ,   69  ,   1355    ,   1289    ,   8165    ,   1159    ,   6001    ,0 };
            const std::uint32_t dim2933Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   11  ,   31  ,   31  ,   117 ,   193 ,   847 ,   1755    ,   1629    ,   6707    ,   5447    ,   15961   ,0 };
            const std::uint32_t dim2934Kuo2Init[]       =   {   1   ,   1   ,   1   ,   1   ,   23  ,   13  ,   69  ,   107 ,   33  ,   731 ,   233 ,   2225    ,   201 ,   2667    ,   19935   ,0 };
            const std::uint32_t dim2935Kuo2Init[]       =   {   1   ,   1   ,   1   ,   9   ,   31  ,   9   ,   25  ,   225 ,   373 ,   99  ,   1725    ,   3029    ,   5019    ,   10927   ,   541 ,0 };
            const std::uint32_t dim2936Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   29  ,   29  ,   37  ,   235 ,   135 ,   99  ,   599 ,   581 ,   7663    ,   1607    ,   7957    ,0 };
            const std::uint32_t dim2937Kuo2Init[]       =   {   1   ,   3   ,   1   ,   11  ,   1   ,   31  ,   79  ,   33  ,   319 ,   341 ,   1701    ,   973 ,   5783    ,   3003    ,   15311   ,0 };
            const std::uint32_t dim2938Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   19  ,   11  ,   95  ,   51  ,   35  ,   887 ,   1505    ,   207 ,   7925    ,   1919    ,   30735   ,0 };
            const std::uint32_t dim2939Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   3   ,   27  ,   55  ,   41  ,   293 ,   519 ,   1885    ,   617 ,   321 ,   5911    ,   26813   ,0 };
            const std::uint32_t dim2940Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   7   ,   59  ,   9   ,   59  ,   291 ,   927 ,   1241    ,   1707    ,   3833    ,   13859   ,   3311    ,0 };
            const std::uint32_t dim2941Kuo2Init[]       =   {   1   ,   3   ,   3   ,   13  ,   17  ,   61  ,   1   ,   155 ,   355 ,   943 ,   159 ,   2519    ,   7835    ,   14097   ,   671 ,0 };
            const std::uint32_t dim2942Kuo2Init[]       =   {   1   ,   1   ,   3   ,   3   ,   29  ,   33  ,   59  ,   37  ,   363 ,   605 ,   365 ,   2431    ,   2529    ,   6449    ,   8847    ,0 };
            const std::uint32_t dim2943Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   1   ,   33  ,   87  ,   215 ,   465 ,   937 ,   2031    ,   421 ,   2535    ,   10017   ,   18395   ,0 };
            const std::uint32_t dim2944Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   27  ,   25  ,   7   ,   103 ,   501 ,   53  ,   1491    ,   99  ,   7433    ,   8251    ,   18849   ,0 };
            const std::uint32_t dim2945Kuo2Init[]       =   {   1   ,   3   ,   1   ,   1   ,   31  ,   15  ,   7   ,   89  ,   145 ,   457 ,   7   ,   2821    ,   6595    ,   5893    ,   29049   ,0 };
            const std::uint32_t dim2946Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   15  ,   55  ,   127 ,   39  ,   493 ,   39  ,   1753    ,   643 ,   4005    ,   12041   ,   21811   ,0 };
            const std::uint32_t dim2947Kuo2Init[]       =   {   1   ,   3   ,   3   ,   3   ,   17  ,   23  ,   79  ,   129 ,   181 ,   1017    ,   767 ,   1869    ,   4589    ,   4059    ,   15391   ,0 };
            const std::uint32_t dim2948Kuo2Init[]       =   {   1   ,   1   ,   1   ,   3   ,   13  ,   17  ,   109 ,   253 ,   441 ,   361 ,   1641    ,   1647    ,   2139    ,   11629   ,   21061   ,0 };
            const std::uint32_t dim2949Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   5   ,   15  ,   43  ,   113 ,   455 ,   17  ,   353 ,   3431    ,   4871    ,   14777   ,   3257    ,0 };
            const std::uint32_t dim2950Kuo2Init[]       =   {   1   ,   3   ,   1   ,   1   ,   7   ,   5   ,   49  ,   199 ,   295 ,   467 ,   1151    ,   2563    ,   1261    ,   1611    ,   8457    ,0 };
            const std::uint32_t dim2951Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   21  ,   1   ,   107 ,   71  ,   67  ,   271 ,   427 ,   673 ,   2093    ,   13255   ,   15941   ,0 };
            const std::uint32_t dim2952Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   19  ,   55  ,   127 ,   109 ,   101 ,   773 ,   1423    ,   2725    ,   2403    ,   1419    ,   2543    ,0 };
            const std::uint32_t dim2953Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   25  ,   49  ,   15  ,   77  ,   423 ,   723 ,   2033    ,   275 ,   1593    ,   3055    ,   12043   ,0 };
            const std::uint32_t dim2954Kuo2Init[]       =   {   1   ,   3   ,   1   ,   9   ,   29  ,   27  ,   115 ,   5   ,   407 ,   797 ,   2041    ,   155 ,   2389    ,   9749    ,   31653   ,0 };
            const std::uint32_t dim2955Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   5   ,   29  ,   123 ,   139 ,   467 ,   377 ,   1853    ,   2769    ,   6523    ,   14195   ,   31539   ,0 };
            const std::uint32_t dim2956Kuo2Init[]       =   {   1   ,   3   ,   3   ,   5   ,   25  ,   41  ,   103 ,   89  ,   469 ,   577 ,   1583    ,   1061    ,   7609    ,   4261    ,   17323   ,0 };
            const std::uint32_t dim2957Kuo2Init[]       =   {   1   ,   1   ,   5   ,   5   ,   29  ,   37  ,   79  ,   179 ,   189 ,   185 ,   535 ,   3433    ,   6091    ,   4935    ,   21853   ,0 };
            const std::uint32_t dim2958Kuo2Init[]       =   {   1   ,   1   ,   5   ,   13  ,   17  ,   63  ,   119 ,   191 ,   7   ,   353 ,   1591    ,   2881    ,   7857    ,   11355   ,   32427   ,0 };
            const std::uint32_t dim2959Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   13  ,   53  ,   21  ,   151 ,   499 ,   721 ,   1495    ,   2101    ,   7061    ,   12529   ,   16733   ,0 };
            const std::uint32_t dim2960Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   1   ,   1   ,   17  ,   141 ,   221 ,   875 ,   1569    ,   3165    ,   2583    ,   2803    ,   21001   ,0 };
            const std::uint32_t dim2961Kuo2Init[]       =   {   1   ,   3   ,   3   ,   13  ,   7   ,   7   ,   99  ,   129 ,   381 ,   237 ,   159 ,   2359    ,   2223    ,   7465    ,   25437   ,0 };
            const std::uint32_t dim2962Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   31  ,   19  ,   103 ,   17  ,   475 ,   649 ,   279 ,   1321    ,   1751    ,   6957    ,   26055   ,0 };
            const std::uint32_t dim2963Kuo2Init[]       =   {   1   ,   1   ,   1   ,   7   ,   5   ,   41  ,   3   ,   29  ,   23  ,   513 ,   1619    ,   291 ,   3949    ,   12117   ,   15175   ,0 };
            const std::uint32_t dim2964Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   13  ,   13  ,   73  ,   77  ,   373 ,   999 ,   1985    ,   161 ,   3223    ,   10873   ,   2967    ,0 };
            const std::uint32_t dim2965Kuo2Init[]       =   {   1   ,   1   ,   5   ,   7   ,   27  ,   1   ,   47  ,   79  ,   463 ,   499 ,   37  ,   113 ,   3207    ,   6753    ,   13207   ,0 };
            const std::uint32_t dim2966Kuo2Init[]       =   {   1   ,   1   ,   1   ,   9   ,   29  ,   33  ,   71  ,   225 ,   71  ,   943 ,   197 ,   3645    ,   7459    ,   5495    ,   22449   ,0 };
            const std::uint32_t dim2967Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   1   ,   21  ,   101 ,   31  ,   357 ,   689 ,   1081    ,   165 ,   621 ,   11277   ,   21773   ,0 };
            const std::uint32_t dim2968Kuo2Init[]       =   {   1   ,   1   ,   7   ,   3   ,   13  ,   13  ,   21  ,   11  ,   87  ,   741 ,   765 ,   3299    ,   2741    ,   12825   ,   13383   ,0 };
            const std::uint32_t dim2969Kuo2Init[]       =   {   1   ,   3   ,   3   ,   5   ,   5   ,   51  ,   49  ,   215 ,   427 ,   513 ,   621 ,   4067    ,   661 ,   12261   ,   6839    ,0 };
            const std::uint32_t dim2970Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   13  ,   9   ,   77  ,   17  ,   229 ,   139 ,   1053    ,   2061    ,   4915    ,   1047    ,   3621    ,0 };
            const std::uint32_t dim2971Kuo2Init[]       =   {   1   ,   1   ,   3   ,   1   ,   9   ,   7   ,   125 ,   165 ,   301 ,   721 ,   493 ,   543 ,   4885    ,   5011    ,   24545   ,0 };
            const std::uint32_t dim2972Kuo2Init[]       =   {   1   ,   3   ,   3   ,   11  ,   31  ,   11  ,   5   ,   61  ,   89  ,   35  ,   1551    ,   3031    ,   1175    ,   16223   ,   19433   ,0 };
            const std::uint32_t dim2973Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   27  ,   31  ,   115 ,   181 ,   487 ,   53  ,   795 ,   1789    ,   7343    ,   7821    ,   20469   ,0 };
            const std::uint32_t dim2974Kuo2Init[]       =   {   1   ,   1   ,   5   ,   3   ,   7   ,   25  ,   89  ,   145 ,   107 ,   361 ,   171 ,   2407    ,   1159    ,   9341    ,   23877   ,0 };
            const std::uint32_t dim2975Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   27  ,   47  ,   31  ,   53  ,   53  ,   479 ,   1479    ,   427 ,   461 ,   7287    ,   15947   ,0 };
            const std::uint32_t dim2976Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   3   ,   11  ,   79  ,   151 ,   463 ,   315 ,   919 ,   1531    ,   2367    ,   5189    ,   6971    ,0 };
            const std::uint32_t dim2977Kuo2Init[]       =   {   1   ,   1   ,   5   ,   9   ,   25  ,   17  ,   3   ,   111 ,   167 ,   365 ,   871 ,   355 ,   6763    ,   11889   ,   5531    ,0 };
            const std::uint32_t dim2978Kuo2Init[]       =   {   1   ,   1   ,   1   ,   13  ,   25  ,   31  ,   25  ,   185 ,   63  ,   335 ,   177 ,   3017    ,   941 ,   11849   ,   6879    ,0 };
            const std::uint32_t dim2979Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   29  ,   13  ,   81  ,   121 ,   119 ,   807 ,   1647    ,   569 ,   23  ,   9045    ,   15513   ,0 };
            const std::uint32_t dim2980Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   5   ,   61  ,   115 ,   79  ,   115 ,   401 ,   383 ,   3679    ,   8159    ,   15199   ,   1531    ,0 };
            const std::uint32_t dim2981Kuo2Init[]       =   {   1   ,   3   ,   3   ,   11  ,   17  ,   45  ,   17  ,   37  ,   175 ,   735 ,   849 ,   3597    ,   7253    ,   11863   ,   5215    ,0 };
            const std::uint32_t dim2982Kuo2Init[]       =   {   1   ,   1   ,   1   ,   13  ,   7   ,   59  ,   99  ,   67  ,   223 ,   635 ,   1645    ,   3169    ,   2655    ,   15925   ,   14969   ,0 };
            const std::uint32_t dim2983Kuo2Init[]       =   {   1   ,   3   ,   7   ,   15  ,   25  ,   17  ,   17  ,   25  ,   1   ,   799 ,   829 ,   2085    ,   7371    ,   6905    ,   11573   ,0 };
            const std::uint32_t dim2984Kuo2Init[]       =   {   1   ,   1   ,   5   ,   1   ,   19  ,   33  ,   127 ,   31  ,   305 ,   523 ,   1141    ,   1171    ,   3707    ,   14687   ,   27897   ,0 };
            const std::uint32_t dim2985Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   3   ,   7   ,   95  ,   243 ,   373 ,   481 ,   1663    ,   1449    ,   687 ,   5643    ,   3265    ,0 };
            const std::uint32_t dim2986Kuo2Init[]       =   {   1   ,   3   ,   7   ,   11  ,   17  ,   35  ,   45  ,   15  ,   201 ,   389 ,   1085    ,   1597    ,   5073    ,   5009    ,   6921    ,0 };
            const std::uint32_t dim2987Kuo2Init[]       =   {   1   ,   1   ,   5   ,   1   ,   25  ,   33  ,   99  ,   57  ,   429 ,   153 ,   1663    ,   1797    ,   785 ,   7323    ,   24763   ,0 };
            const std::uint32_t dim2988Kuo2Init[]       =   {   1   ,   1   ,   7   ,   15  ,   1   ,   63  ,   93  ,   225 ,   189 ,   297 ,   927 ,   2127    ,   7335    ,   5187    ,   12047   ,0 };
            const std::uint32_t dim2989Kuo2Init[]       =   {   1   ,   1   ,   5   ,   9   ,   23  ,   47  ,   27  ,   113 ,   469 ,   649 ,   1135    ,   1363    ,   6777    ,   2047    ,   5759    ,0 };
            const std::uint32_t dim2990Kuo2Init[]       =   {   1   ,   1   ,   3   ,   1   ,   9   ,   33  ,   21  ,   123 ,   309 ,   635 ,   1217    ,   1087    ,   4525    ,   10165   ,   18071   ,0 };
            const std::uint32_t dim2991Kuo2Init[]       =   {   1   ,   3   ,   3   ,   3   ,   19  ,   49  ,   13  ,   217 ,   155 ,   945 ,   1987    ,   2425    ,   3891    ,   13831   ,   21777   ,0 };
            const std::uint32_t dim2992Kuo2Init[]       =   {   1   ,   1   ,   3   ,   11  ,   25  ,   9   ,   75  ,   149 ,   241 ,   175 ,   799 ,   1285    ,   3265    ,   14103   ,   30147   ,0 };
            const std::uint32_t dim2993Kuo2Init[]       =   {   1   ,   1   ,   1   ,   3   ,   13  ,   41  ,   87  ,   127 ,   179 ,   723 ,   1345    ,   667 ,   4155    ,   8037    ,   29583   ,0 };
            const std::uint32_t dim2994Kuo2Init[]       =   {   1   ,   1   ,   1   ,   9   ,   15  ,   57  ,   67  ,   197 ,   131 ,   957 ,   1855    ,   2857    ,   2939    ,   6459    ,   5807    ,0 };
            const std::uint32_t dim2995Kuo2Init[]       =   {   1   ,   3   ,   5   ,   5   ,   23  ,   39  ,   19  ,   95  ,   103 ,   961 ,   239 ,   1151    ,   1069    ,   10261   ,   6065    ,0 };
            const std::uint32_t dim2996Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   23  ,   29  ,   51  ,   121 ,   45  ,   561 ,   1317    ,   1777    ,   1325    ,   5833    ,   5765    ,0 };
            const std::uint32_t dim2997Kuo2Init[]       =   {   1   ,   1   ,   5   ,   1   ,   31  ,   3   ,   67  ,   9   ,   453 ,   281 ,   525 ,   1751    ,   5771    ,   14257   ,   11869   ,0 };
            const std::uint32_t dim2998Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   13  ,   35  ,   33  ,   59  ,   117 ,   737 ,   929 ,   547 ,   4839    ,   7013    ,   28395   ,0 };
            const std::uint32_t dim2999Kuo2Init[]       =   {   1   ,   3   ,   7   ,   15  ,   21  ,   41  ,   19  ,   15  ,   73  ,   377 ,   665 ,   3867    ,   6445    ,   13137   ,   995 ,0 };
            const std::uint32_t dim3000Kuo2Init[]       =   {   1   ,   3   ,   7   ,   11  ,   13  ,   41  ,   53  ,   115 ,   435 ,   607 ,   871 ,   315 ,   6573    ,   6321    ,   10413   ,0 };
            const std::uint32_t dim3001Kuo2Init[]       =   {   1   ,   3   ,   3   ,   3   ,   27  ,   31  ,   23  ,   7   ,   151 ,   923 ,   1903    ,   789 ,   5031    ,   10631   ,   777 ,0 };
            const std::uint32_t dim3002Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   9   ,   25  ,   17  ,   241 ,   19  ,   569 ,   1269    ,   1211    ,   3947    ,   11351   ,   31211   ,0 };
            const std::uint32_t dim3003Kuo2Init[]       =   {   1   ,   1   ,   7   ,   13  ,   25  ,   31  ,   79  ,   111 ,   157 ,   483 ,   1787    ,   1201    ,   3491    ,   7943    ,   4879    ,0 };
            const std::uint32_t dim3004Kuo2Init[]       =   {   1   ,   3   ,   7   ,   13  ,   19  ,   9   ,   31  ,   133 ,   125 ,   347 ,   15  ,   1287    ,   4355    ,   15357   ,   21391   ,0 };
            const std::uint32_t dim3005Kuo2Init[]       =   {   1   ,   3   ,   3   ,   13  ,   1   ,   29  ,   63  ,   175 ,   279 ,   799 ,   1867    ,   2221    ,   6043    ,   307 ,   12475   ,0 };
            const std::uint32_t dim3006Kuo2Init[]       =   {   1   ,   1   ,   7   ,   5   ,   23  ,   51  ,   93  ,   65  ,   209 ,   45  ,   409 ,   3405    ,   2053    ,   1399    ,   4423    ,0 };
            const std::uint32_t dim3007Kuo2Init[]       =   {   1   ,   3   ,   7   ,   13  ,   23  ,   55  ,   21  ,   121 ,   281 ,   115 ,   85  ,   1941    ,   2609    ,   7041    ,   16267   ,0 };
            const std::uint32_t dim3008Kuo2Init[]       =   {   1   ,   1   ,   3   ,   5   ,   25  ,   3   ,   113 ,   107 ,   37  ,   393 ,   737 ,   2671    ,   7405    ,   12191   ,   27679   ,0 };
            const std::uint32_t dim3009Kuo2Init[]       =   {   1   ,   1   ,   3   ,   13  ,   15  ,   13  ,   33  ,   233 ,   25  ,   163 ,   1097    ,   2977    ,   6933    ,   14625   ,   29587   ,0 };
            const std::uint32_t dim3010Kuo2Init[]       =   {   1   ,   1   ,   1   ,   1   ,   31  ,   13  ,   11  ,   25  ,   47  ,   589 ,   2035    ,   3595    ,   1299    ,   10171   ,   12695   ,0 };
            const std::uint32_t dim3011Kuo2Init[]       =   {   1   ,   3   ,   5   ,   11  ,   31  ,   63  ,   97  ,   67  ,   381 ,   1021    ,   1029    ,   2869    ,   5779    ,   15451   ,   4291    ,0 };
            const std::uint32_t dim3012Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   9   ,   37  ,   9   ,   205 ,   169 ,   375 ,   1367    ,   1749    ,   8015    ,   1019    ,   12671   ,0 };
            const std::uint32_t dim3013Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   13  ,   29  ,   75  ,   53  ,   173 ,   535 ,   1795    ,   1705    ,   3601    ,   2487    ,   29851   ,0 };
            const std::uint32_t dim3014Kuo2Init[]       =   {   1   ,   3   ,   3   ,   5   ,   5   ,   17  ,   81  ,   209 ,   229 ,   913 ,   959 ,   3597    ,   1515    ,   13401   ,   1531    ,0 };
            const std::uint32_t dim3015Kuo2Init[]       =   {   1   ,   3   ,   3   ,   5   ,   29  ,   47  ,   5   ,   43  ,   117 ,   215 ,   1469    ,   3743    ,   6801    ,   10511   ,   11097   ,0 };
            const std::uint32_t dim3016Kuo2Init[]       =   {   1   ,   1   ,   1   ,   9   ,   11  ,   5   ,   79  ,   247 ,   43  ,   853 ,   663 ,   1967    ,   355 ,   12263   ,   15877   ,0 };
            const std::uint32_t dim3017Kuo2Init[]       =   {   1   ,   3   ,   3   ,   5   ,   25  ,   23  ,   105 ,   203 ,   255 ,   677 ,   1855    ,   527 ,   825 ,   433 ,   27701   ,0 };
            const std::uint32_t dim3018Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   13  ,   29  ,   119 ,   47  ,   331 ,   203 ,   1515    ,   1581    ,   1707    ,   10621   ,   19371   ,0 };
            const std::uint32_t dim3019Kuo2Init[]       =   {   1   ,   1   ,   1   ,   13  ,   27  ,   15  ,   5   ,   255 ,   201 ,   861 ,   1809    ,   703 ,   1707    ,   8209    ,   5175    ,0 };
            const std::uint32_t dim3020Kuo2Init[]       =   {   1   ,   3   ,   1   ,   13  ,   17  ,   61  ,   41  ,   143 ,   459 ,   291 ,   1747    ,   3605    ,   5545    ,   7441    ,   21493   ,0 };
            const std::uint32_t dim3021Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   21  ,   61  ,   77  ,   61  ,   79  ,   855 ,   57  ,   1543    ,   2755    ,   6249    ,   3387    ,0 };
            const std::uint32_t dim3022Kuo2Init[]       =   {   1   ,   1   ,   3   ,   1   ,   17  ,   5   ,   117 ,   243 ,   153 ,   397 ,   693 ,   701 ,   2201    ,   11375   ,   23753   ,0 };
            const std::uint32_t dim3023Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   17  ,   25  ,   123 ,   239 ,   411 ,   633 ,   395 ,   3809    ,   1483    ,   15125   ,   22221   ,0 };
            const std::uint32_t dim3024Kuo2Init[]       =   {   1   ,   3   ,   3   ,   3   ,   7   ,   45  ,   57  ,   51  ,   35  ,   463 ,   1287    ,   3101    ,   4213    ,   12931   ,   28639   ,0 };
            const std::uint32_t dim3025Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   13  ,   7   ,   103 ,   177 ,   277 ,   645 ,   833 ,   883 ,   3607    ,   13545   ,   6405    ,0 };
            const std::uint32_t dim3026Kuo2Init[]       =   {   1   ,   3   ,   7   ,   11  ,   17  ,   3   ,   41  ,   161 ,   511 ,   483 ,   773 ,   147 ,   8113    ,   2203    ,   29711   ,0 };
            const std::uint32_t dim3027Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   13  ,   29  ,   79  ,   189 ,   351 ,   65  ,   93  ,   1195    ,   5205    ,   7989    ,   14085   ,0 };
            const std::uint32_t dim3028Kuo2Init[]       =   {   1   ,   1   ,   3   ,   11  ,   13  ,   5   ,   13  ,   35  ,   231 ,   627 ,   1155    ,   1117    ,   3889    ,   3645    ,   25099   ,0 };
            const std::uint32_t dim3029Kuo2Init[]       =   {   1   ,   3   ,   5   ,   3   ,   13  ,   63  ,   73  ,   83  ,   249 ,   559 ,   303 ,   3303    ,   5387    ,   15773   ,   16249   ,0 };
            const std::uint32_t dim3030Kuo2Init[]       =   {   1   ,   1   ,   1   ,   9   ,   21  ,   23  ,   63  ,   153 ,   291 ,   951 ,   1409    ,   1333    ,   5385    ,   14621   ,   13763   ,0 };
            const std::uint32_t dim3031Kuo2Init[]       =   {   1   ,   3   ,   1   ,   9   ,   1   ,   45  ,   13  ,   139 ,   437 ,   495 ,   773 ,   1401    ,   1599    ,   2555    ,   21579   ,0 };
            const std::uint32_t dim3032Kuo2Init[]       =   {   1   ,   3   ,   1   ,   9   ,   11  ,   15  ,   51  ,   123 ,   393 ,   223 ,   1045    ,   1001    ,   6955    ,   12755   ,   5979    ,0 };
            const std::uint32_t dim3033Kuo2Init[]       =   {   1   ,   1   ,   1   ,   7   ,   31  ,   31  ,   57  ,   127 ,   339 ,   133 ,   1489    ,   3055    ,   3051    ,   14931   ,   7757    ,0 };
            const std::uint32_t dim3034Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   1   ,   23  ,   97  ,   79  ,   491 ,   641 ,   295 ,   2597    ,   3857    ,   1889    ,   16295   ,0 };
            const std::uint32_t dim3035Kuo2Init[]       =   {   1   ,   3   ,   7   ,   7   ,   21  ,   31  ,   111 ,   77  ,   199 ,   401 ,   1829    ,   925 ,   6023    ,   16161   ,   1783    ,0 };
            const std::uint32_t dim3036Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   5   ,   9   ,   53  ,   133 ,   347 ,   761 ,   841 ,   841 ,   3031    ,   10201   ,   27245   ,0 };
            const std::uint32_t dim3037Kuo2Init[]       =   {   1   ,   1   ,   3   ,   13  ,   31  ,   35  ,   21  ,   19  ,   95  ,   861 ,   1385    ,   3607    ,   335 ,   14643   ,   20435   ,0 };
            const std::uint32_t dim3038Kuo2Init[]       =   {   1   ,   3   ,   3   ,   13  ,   7   ,   61  ,   47  ,   225 ,   235 ,   333 ,   1923    ,   2961    ,   61  ,   14463   ,   12329   ,0 };
            const std::uint32_t dim3039Kuo2Init[]       =   {   1   ,   3   ,   5   ,   5   ,   23  ,   35  ,   43  ,   175 ,   25  ,   573 ,   1253    ,   233 ,   5377    ,   3153    ,   24543   ,0 };
            const std::uint32_t dim3040Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   27  ,   55  ,   49  ,   239 ,   479 ,   475 ,   223 ,   2947    ,   89  ,   5517    ,   2925    ,0 };
            const std::uint32_t dim3041Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   31  ,   45  ,   11  ,   255 ,   251 ,   647 ,   1161    ,   847 ,   1175    ,   1219    ,   19735   ,0 };
            const std::uint32_t dim3042Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   13  ,   19  ,   13  ,   31  ,   309 ,   165 ,   49  ,   2281    ,   5607    ,   11987   ,   19255   ,0 };
            const std::uint32_t dim3043Kuo2Init[]       =   {   1   ,   3   ,   7   ,   7   ,   15  ,   35  ,   51  ,   243 ,   119 ,   179 ,   1055    ,   3751    ,   4133    ,   14873   ,   12317   ,0 };
            const std::uint32_t dim3044Kuo2Init[]       =   {   1   ,   3   ,   7   ,   13  ,   13  ,   47  ,   87  ,   169 ,   203 ,   27  ,   449 ,   2755    ,   5407    ,   11857   ,   291 ,0 };
            const std::uint32_t dim3045Kuo2Init[]       =   {   1   ,   3   ,   3   ,   5   ,   29  ,   27  ,   1   ,   225 ,   493 ,   649 ,   1075    ,   2197    ,   2201    ,   14425   ,   18853   ,0 };
            const std::uint32_t dim3046Kuo2Init[]       =   {   1   ,   3   ,   7   ,   1   ,   23  ,   21  ,   87  ,   237 ,   377 ,   575 ,   445 ,   1845    ,   6689    ,   10945   ,   17517   ,0 };
            const std::uint32_t dim3047Kuo2Init[]       =   {   1   ,   1   ,   5   ,   5   ,   19  ,   43  ,   5   ,   177 ,   507 ,   395 ,   945 ,   2933    ,   1237    ,   10069   ,   15707   ,0 };
            const std::uint32_t dim3048Kuo2Init[]       =   {   1   ,   1   ,   1   ,   9   ,   31  ,   61  ,   85  ,   45  ,   325 ,   915 ,   863 ,   839 ,   2335    ,   14631   ,   32479   ,0 };
            const std::uint32_t dim3049Kuo2Init[]       =   {   1   ,   1   ,   3   ,   5   ,   11  ,   61  ,   47  ,   119 ,   439 ,   407 ,   203 ,   2841    ,   2205    ,   5335    ,   29721   ,0 };
            const std::uint32_t dim3050Kuo2Init[]       =   {   1   ,   3   ,   5   ,   11  ,   9   ,   9   ,   63  ,   179 ,   315 ,   257 ,   901 ,   5   ,   4523    ,   11085   ,   23639   ,0 };
            const std::uint32_t dim3051Kuo2Init[]       =   {   1   ,   1   ,   5   ,   1   ,   11  ,   9   ,   83  ,   109 ,   265 ,   601 ,   1457    ,   795 ,   509 ,   5605    ,   13235   ,0 };
            const std::uint32_t dim3052Kuo2Init[]       =   {   1   ,   3   ,   3   ,   13  ,   31  ,   25  ,   59  ,   37  ,   25  ,   811 ,   657 ,   467 ,   1317    ,   3783    ,   27645   ,0 };
            const std::uint32_t dim3053Kuo2Init[]       =   {   1   ,   1   ,   1   ,   9   ,   31  ,   51  ,   81  ,   255 ,   379 ,   575 ,   1401    ,   2341    ,   2411    ,   11893   ,   29599   ,0 };
            const std::uint32_t dim3054Kuo2Init[]       =   {   1   ,   1   ,   5   ,   13  ,   3   ,   47  ,   79  ,   183 ,   111 ,   409 ,   1223    ,   1305    ,   1073    ,   9251    ,   28331   ,0 };
            const std::uint32_t dim3055Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   31  ,   9   ,   39  ,   125 ,   269 ,   999 ,   1427    ,   1845    ,   4427    ,   3825    ,   29289   ,0 };
            const std::uint32_t dim3056Kuo2Init[]       =   {   1   ,   1   ,   3   ,   3   ,   17  ,   41  ,   3   ,   29  ,   9   ,   253 ,   925 ,   1279    ,   2263    ,   15521   ,   25455   ,0 };
            const std::uint32_t dim3057Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   31  ,   31  ,   53  ,   95  ,   225 ,   967 ,   893 ,   1315    ,   5683    ,   3311    ,   15259   ,0 };
            const std::uint32_t dim3058Kuo2Init[]       =   {   1   ,   1   ,   7   ,   3   ,   31  ,   21  ,   123 ,   145 ,   117 ,   137 ,   499 ,   2381    ,   6467    ,   15677   ,   2079    ,0 };
            const std::uint32_t dim3059Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   3   ,   15  ,   17  ,   235 ,   463 ,   493 ,   1465    ,   1717    ,   6511    ,   5331    ,   10265   ,0 };
            const std::uint32_t dim3060Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   25  ,   41  ,   31  ,   225 ,   115 ,   199 ,   1831    ,   29  ,   5563    ,   2697    ,   26689   ,0 };
            const std::uint32_t dim3061Kuo2Init[]       =   {   1   ,   3   ,   7   ,   15  ,   7   ,   23  ,   29  ,   79  ,   35  ,   493 ,   997 ,   2139    ,   3813    ,   9915    ,   16693   ,0 };
            const std::uint32_t dim3062Kuo2Init[]       =   {   1   ,   1   ,   7   ,   13  ,   13  ,   59  ,   71  ,   127 ,   41  ,   271 ,   1513    ,   2239    ,   6739    ,   6351    ,   11331   ,0 };
            const std::uint32_t dim3063Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   23  ,   63  ,   109 ,   225 ,   413 ,   277 ,   927 ,   1781    ,   843 ,   5959    ,   16655   ,0 };
            const std::uint32_t dim3064Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   9   ,   55  ,   91  ,   143 ,   401 ,   695 ,   1857    ,   205 ,   3617    ,   11847   ,   27339   ,0 };
            const std::uint32_t dim3065Kuo2Init[]       =   {   1   ,   1   ,   3   ,   1   ,   21  ,   41  ,   5   ,   1   ,   207 ,   247 ,   1269    ,   3071    ,   8045    ,   8711    ,   3595    ,0 };
            const std::uint32_t dim3066Kuo2Init[]       =   {   1   ,   3   ,   7   ,   15  ,   5   ,   23  ,   29  ,   119 ,   435 ,   961 ,   333 ,   2337    ,   3469    ,   6363    ,   29145   ,0 };
            const std::uint32_t dim3067Kuo2Init[]       =   {   1   ,   3   ,   5   ,   5   ,   21  ,   19  ,   65  ,   177 ,   309 ,   115 ,   707 ,   1659    ,   941 ,   6825    ,   3595    ,0 };
            const std::uint32_t dim3068Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   29  ,   5   ,   113 ,   15  ,   13  ,   897 ,   1535    ,   3453    ,   3539    ,   3937    ,   22647   ,0 };
            const std::uint32_t dim3069Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   13  ,   41  ,   45  ,   11  ,   259 ,   127 ,   1421    ,   195 ,   4555    ,   11643   ,   30239   ,0 };
            const std::uint32_t dim3070Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   5   ,   17  ,   115 ,   89  ,   183 ,   729 ,   1655    ,   3599    ,   1443    ,   11799   ,   29777   ,0 };
            const std::uint32_t dim3071Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   19  ,   57  ,   61  ,   3   ,   53  ,   221 ,   799 ,   3243    ,   5255    ,   3271    ,   8677    ,0 };
            const std::uint32_t dim3072Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   23  ,   45  ,   103 ,   173 ,   453 ,   111 ,   1145    ,   891 ,   4989    ,   3195    ,   20129   ,0 };
            const std::uint32_t dim3073Kuo2Init[]       =   {   1   ,   3   ,   1   ,   13  ,   13  ,   25  ,   71  ,   71  ,   125 ,   753 ,   397 ,   613 ,   1641    ,   2611    ,   1879    ,0 };
            const std::uint32_t dim3074Kuo2Init[]       =   {   1   ,   1   ,   1   ,   15  ,   23  ,   59  ,   25  ,   199 ,   285 ,   161 ,   225 ,   4039    ,   5427    ,   13711   ,   23643   ,0 };
            const std::uint32_t dim3075Kuo2Init[]       =   {   1   ,   1   ,   7   ,   13  ,   25  ,   9   ,   119 ,   121 ,   369 ,   811 ,   1857    ,   2227    ,   5711    ,   2761    ,   23033   ,0 };
            const std::uint32_t dim3076Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   27  ,   43  ,   75  ,   231 ,   221 ,   869 ,   603 ,   537 ,   3679    ,   15963   ,   27183   ,0 };
            const std::uint32_t dim3077Kuo2Init[]       =   {   1   ,   1   ,   5   ,   3   ,   9   ,   35  ,   33  ,   39  ,   383 ,   415 ,   1769    ,   3837    ,   1479    ,   3411    ,   20917   ,0 };
            const std::uint32_t dim3078Kuo2Init[]       =   {   1   ,   1   ,   5   ,   15  ,   7   ,   47  ,   119 ,   105 ,   31  ,   79  ,   229 ,   135 ,   1509    ,   1571    ,   24355   ,0 };
            const std::uint32_t dim3079Kuo2Init[]       =   {   1   ,   1   ,   5   ,   7   ,   7   ,   15  ,   99  ,   79  ,   65  ,   869 ,   1781    ,   2111    ,   2405    ,   1901    ,   8419    ,0 };
            const std::uint32_t dim3080Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   7   ,   59  ,   13  ,   211 ,   439 ,   543 ,   755 ,   2177    ,   971 ,   6045    ,   24943   ,0 };
            const std::uint32_t dim3081Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   13  ,   25  ,   89  ,   71  ,   453 ,   71  ,   1205    ,   1419    ,   971 ,   11139   ,   25075   ,0 };
            const std::uint32_t dim3082Kuo2Init[]       =   {   1   ,   3   ,   5   ,   3   ,   7   ,   63  ,   21  ,   17  ,   179 ,   749 ,   915 ,   3977    ,   5399    ,   11385   ,   13825   ,0 };
            const std::uint32_t dim3083Kuo2Init[]       =   {   1   ,   1   ,   5   ,   9   ,   19  ,   49  ,   77  ,   47  ,   351 ,   815 ,   1925    ,   559 ,   4503    ,   8095    ,   3115    ,0 };
            const std::uint32_t dim3084Kuo2Init[]       =   {   1   ,   3   ,   1   ,   9   ,   13  ,   61  ,   79  ,   245 ,   509 ,   691 ,   387 ,   2067    ,   1493    ,   10783   ,   31911   ,0 };
            const std::uint32_t dim3085Kuo2Init[]       =   {   1   ,   3   ,   1   ,   11  ,   31  ,   27  ,   117 ,   55  ,   93  ,   389 ,   1299    ,   573 ,   6883    ,   10449   ,   19779   ,0 };
            const std::uint32_t dim3086Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   15  ,   27  ,   5   ,   207 ,   215 ,   773 ,   1989    ,   2341    ,   2101    ,   10585   ,   6675    ,0 };
            const std::uint32_t dim3087Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   19  ,   37  ,   93  ,   127 ,   233 ,   49  ,   557 ,   1683    ,   7299    ,   5399    ,   21571   ,0 };
            const std::uint32_t dim3088Kuo2Init[]       =   {   1   ,   3   ,   1   ,   15  ,   15  ,   21  ,   95  ,   81  ,   167 ,   113 ,   245 ,   3607    ,   2007    ,   1847    ,   2317    ,0 };
            const std::uint32_t dim3089Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   21  ,   13  ,   1   ,   203 ,   361 ,   695 ,   539 ,   3927    ,   4149    ,   249 ,   8425    ,0 };
            const std::uint32_t dim3090Kuo2Init[]       =   {   1   ,   3   ,   3   ,   11  ,   1   ,   61  ,   25  ,   159 ,   215 ,   235 ,   1561    ,   99  ,   2965    ,   13035   ,   11673   ,0 };
            const std::uint32_t dim3091Kuo2Init[]       =   {   1   ,   3   ,   1   ,   1   ,   5   ,   27  ,   13  ,   83  ,   457 ,   57  ,   995 ,   2163    ,   257 ,   12671   ,   18391   ,0 };
            const std::uint32_t dim3092Kuo2Init[]       =   {   1   ,   1   ,   5   ,   13  ,   23  ,   25  ,   69  ,   15  ,   53  ,   253 ,   1789    ,   3415    ,   3667    ,   3255    ,   26871   ,0 };
            const std::uint32_t dim3093Kuo2Init[]       =   {   1   ,   1   ,   3   ,   3   ,   9   ,   13  ,   25  ,   81  ,   247 ,   483 ,   921 ,   649 ,   4759    ,   15037   ,   4923    ,0 };
            const std::uint32_t dim3094Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   5   ,   1   ,   111 ,   179 ,   329 ,   395 ,   1661    ,   2647    ,   6487    ,   11109   ,   15465   ,0 };
            const std::uint32_t dim3095Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   27  ,   27  ,   13  ,   123 ,   225 ,   181 ,   1205    ,   2703    ,   1753    ,   2513    ,   1671    ,0 };
            const std::uint32_t dim3096Kuo2Init[]       =   {   1   ,   3   ,   7   ,   9   ,   23  ,   51  ,   1   ,   9   ,   233 ,   709 ,   257 ,   999 ,   5761    ,   3281    ,   8083    ,0 };
            const std::uint32_t dim3097Kuo2Init[]       =   {   1   ,   1   ,   7   ,   11  ,   31  ,   33  ,   29  ,   83  ,   251 ,   1021    ,   1395    ,   447 ,   4071    ,   13257   ,   5821    ,0 };
            const std::uint32_t dim3098Kuo2Init[]       =   {   1   ,   1   ,   5   ,   1   ,   11  ,   19  ,   67  ,   35  ,   371 ,   425 ,   613 ,   1065    ,   269 ,   3895    ,   19507   ,0 };
            const std::uint32_t dim3099Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   1   ,   53  ,   79  ,   229 ,   489 ,   373 ,   1195    ,   3221    ,   7425    ,   2731    ,   16607   ,0 };
            const std::uint32_t dim3100Kuo2Init[]       =   {   1   ,   1   ,   3   ,   3   ,   3   ,   11  ,   49  ,   241 ,   269 ,   727 ,   549 ,   2463    ,   6983    ,   13067   ,   19829   ,0 };
            const std::uint32_t dim3101Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   13  ,   41  ,   53  ,   215 ,   131 ,   363 ,   595 ,   2777    ,   3929    ,   1305    ,   12725   ,0 };
            const std::uint32_t dim3102Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   5   ,   41  ,   87  ,   243 ,   485 ,   401 ,   1599    ,   397 ,   4207    ,   3707    ,   28949   ,0 };
            const std::uint32_t dim3103Kuo2Init[]       =   {   1   ,   1   ,   1   ,   3   ,   7   ,   5   ,   31  ,   59  ,   25  ,   391 ,   1419    ,   2355    ,   953 ,   1179    ,   22605   ,0 };
            const std::uint32_t dim3104Kuo2Init[]       =   {   1   ,   3   ,   3   ,   5   ,   13  ,   47  ,   3   ,   167 ,   25  ,   381 ,   341 ,   1999    ,   3423    ,   4465    ,   19517   ,0 };
            const std::uint32_t dim3105Kuo2Init[]       =   {   1   ,   1   ,   3   ,   3   ,   21  ,   55  ,   93  ,   93  ,   243 ,   67  ,   1743    ,   139 ,   5783    ,   2261    ,   22411   ,0 };
            const std::uint32_t dim3106Kuo2Init[]       =   {   1   ,   1   ,   1   ,   15  ,   25  ,   19  ,   1   ,   247 ,   325 ,   641 ,   347 ,   1095    ,   7301    ,   7079    ,   25403   ,0 };
            const std::uint32_t dim3107Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   29  ,   53  ,   23  ,   229 ,   425 ,   311 ,   1159    ,   2241    ,   105 ,   11165   ,   28737   ,0 };
            const std::uint32_t dim3108Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   31  ,   23  ,   3   ,   191 ,   119 ,   113 ,   543 ,   1119    ,   3375    ,   13605   ,   27753   ,0 };
            const std::uint32_t dim3109Kuo2Init[]       =   {   1   ,   1   ,   7   ,   15  ,   1   ,   49  ,   23  ,   193 ,   165 ,   869 ,   509 ,   1017    ,   1045    ,   13709   ,   16293   ,0 };
            const std::uint32_t dim3110Kuo2Init[]       =   {   1   ,   1   ,   1   ,   13  ,   3   ,   15  ,   25  ,   239 ,   423 ,   359 ,   409 ,   1075    ,   2629    ,   2291    ,   20293   ,0 };
            const std::uint32_t dim3111Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   27  ,   35  ,   67  ,   83  ,   11  ,   1   ,   1129    ,   1917    ,   1475    ,   14831   ,   13161   ,0 };
            const std::uint32_t dim3112Kuo2Init[]       =   {   1   ,   1   ,   7   ,   11  ,   27  ,   21  ,   117 ,   191 ,   321 ,   721 ,   929 ,   2293    ,   2257    ,   9259    ,   4849    ,0 };
            const std::uint32_t dim3113Kuo2Init[]       =   {   1   ,   1   ,   1   ,   1   ,   25  ,   61  ,   21  ,   211 ,   491 ,   127 ,   1423    ,   2291    ,   5121    ,   14065   ,   14835   ,0 };
            const std::uint32_t dim3114Kuo2Init[]       =   {   1   ,   1   ,   7   ,   15  ,   17  ,   15  ,   81  ,   221 ,   319 ,   1015    ,   1643    ,   665 ,   7429    ,   7829    ,   5369    ,0 };
            const std::uint32_t dim3115Kuo2Init[]       =   {   1   ,   3   ,   7   ,   13  ,   31  ,   45  ,   77  ,   103 ,   79  ,   891 ,   43  ,   1561    ,   295 ,   3977    ,   17699   ,0 };
            const std::uint32_t dim3116Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   11  ,   19  ,   105 ,   1   ,   179 ,   699 ,   655 ,   3125    ,   5851    ,   9577    ,   29513   ,0 };
            const std::uint32_t dim3117Kuo2Init[]       =   {   1   ,   3   ,   7   ,   13  ,   1   ,   15  ,   105 ,   239 ,   113 ,   917 ,   219 ,   1857    ,   801 ,   11703   ,   20955   ,0 };
            const std::uint32_t dim3118Kuo2Init[]       =   {   1   ,   1   ,   1   ,   9   ,   3   ,   35  ,   69  ,   43  ,   133 ,   455 ,   471 ,   1785    ,   4659    ,   6325    ,   3183    ,0 };
            const std::uint32_t dim3119Kuo2Init[]       =   {   1   ,   1   ,   5   ,   3   ,   7   ,   57  ,   127 ,   13  ,   151 ,   359 ,   135 ,   2445    ,   1795    ,   3257    ,   32305   ,0 };
            const std::uint32_t dim3120Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   11  ,   43  ,   51  ,   109 ,   323 ,   789 ,   1181    ,   1577    ,   4445    ,   1623    ,   28489   ,0 };
            const std::uint32_t dim3121Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   19  ,   55  ,   71  ,   65  ,   35  ,   605 ,   165 ,   1573    ,   1429    ,   7123    ,   1967    ,0 };
            const std::uint32_t dim3122Kuo2Init[]       =   {   1   ,   1   ,   1   ,   15  ,   15  ,   27  ,   87  ,   67  ,   503 ,   833 ,   1841    ,   2639    ,   5629    ,   5511    ,   12393   ,0 };
            const std::uint32_t dim3123Kuo2Init[]       =   {   1   ,   3   ,   1   ,   11  ,   9   ,   59  ,   85  ,   59  ,   289 ,   679 ,   1957    ,   399 ,   7949    ,   4735    ,   709 ,0 };
            const std::uint32_t dim3124Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   3   ,   37  ,   109 ,   3   ,   33  ,   971 ,   123 ,   1585    ,   3273    ,   8421    ,   20903   ,0 };
            const std::uint32_t dim3125Kuo2Init[]       =   {   1   ,   1   ,   1   ,   3   ,   17  ,   37  ,   99  ,   3   ,   405 ,   579 ,   755 ,   1337    ,   3649    ,   8217    ,   11011   ,0 };
            const std::uint32_t dim3126Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   25  ,   59  ,   87  ,   115 ,   237 ,   749 ,   355 ,   1781    ,   5199    ,   7019    ,   10615   ,0 };
            const std::uint32_t dim3127Kuo2Init[]       =   {   1   ,   1   ,   3   ,   11  ,   23  ,   5   ,   105 ,   129 ,   453 ,   813 ,   1423    ,   2703    ,   6241    ,   14969   ,   22943   ,0 };
            const std::uint32_t dim3128Kuo2Init[]       =   {   1   ,   1   ,   5   ,   7   ,   21  ,   41  ,   89  ,   129 ,   473 ,   139 ,   595 ,   925 ,   3915    ,   12059   ,   19675   ,0 };
            const std::uint32_t dim3129Kuo2Init[]       =   {   1   ,   1   ,   5   ,   3   ,   17  ,   19  ,   83  ,   19  ,   191 ,   757 ,   1185    ,   1849    ,   3403    ,   779 ,   24773   ,0 };
            const std::uint32_t dim3130Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   13  ,   31  ,   121 ,   211 ,   357 ,   487 ,   829 ,   1215    ,   1   ,   15103   ,   10835   ,0 };
            const std::uint32_t dim3131Kuo2Init[]       =   {   1   ,   1   ,   5   ,   15  ,   1   ,   15  ,   105 ,   137 ,   169 ,   295 ,   993 ,   261 ,   6787    ,   16339   ,   20307   ,0 };
            const std::uint32_t dim3132Kuo2Init[]       =   {   1   ,   1   ,   5   ,   15  ,   21  ,   11  ,   53  ,   149 ,   443 ,   285 ,   371 ,   2541    ,   7041    ,   5745    ,   12127   ,0 };
            const std::uint32_t dim3133Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   9   ,   23  ,   89  ,   77  ,   337 ,   623 ,   329 ,   1021    ,   2013    ,   11023   ,   27045   ,0 };
            const std::uint32_t dim3134Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   1   ,   11  ,   35  ,   67  ,   93  ,   121 ,   1155    ,   1063    ,   4997    ,   9567    ,   24023   ,0 };
            const std::uint32_t dim3135Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   3   ,   33  ,   119 ,   243 ,   423 ,   615 ,   721 ,   3057    ,   7873    ,   9329    ,   20783   ,0 };
            const std::uint32_t dim3136Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   3   ,   23  ,   41  ,   121 ,   111 ,   483 ,   1607    ,   181 ,   895 ,   12923   ,   21707   ,0 };
            const std::uint32_t dim3137Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   9   ,   63  ,   65  ,   87  ,   235 ,   915 ,   1569    ,   3421    ,   1373    ,   2159    ,   353 ,0 };
            const std::uint32_t dim3138Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   29  ,   3   ,   35  ,   193 ,   95  ,   977 ,   1405    ,   23  ,   1135    ,   5047    ,   16429   ,0 };
            const std::uint32_t dim3139Kuo2Init[]       =   {   1   ,   1   ,   7   ,   3   ,   7   ,   57  ,   123 ,   111 ,   33  ,   781 ,   613 ,   3423    ,   4701    ,   8727    ,   22665   ,0 };
            const std::uint32_t dim3140Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   13  ,   43  ,   101 ,   83  ,   447 ,   503 ,   1955    ,   2125    ,   4469    ,   14937   ,   24067   ,0 };
            const std::uint32_t dim3141Kuo2Init[]       =   {   1   ,   1   ,   5   ,   15  ,   7   ,   41  ,   115 ,   17  ,   335 ,   497 ,   1753    ,   1131    ,   4623    ,   11483   ,   5181    ,0 };
            const std::uint32_t dim3142Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   19  ,   37  ,   1   ,   89  ,   117 ,   211 ,   1203    ,   2469    ,   5989    ,   11429   ,   31597   ,0 };
            const std::uint32_t dim3143Kuo2Init[]       =   {   1   ,   3   ,   3   ,   11  ,   3   ,   7   ,   125 ,   97  ,   203 ,   935 ,   533 ,   2607    ,   6075    ,   12995   ,   9997    ,0 };
            const std::uint32_t dim3144Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   27  ,   25  ,   53  ,   99  ,   243 ,   729 ,   1521    ,   875 ,   2363    ,   3309    ,   22621   ,0 };
            const std::uint32_t dim3145Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   21  ,   7   ,   79  ,   105 ,   363 ,   227 ,   9   ,   2445    ,   3021    ,   15177   ,   19029   ,0 };
            const std::uint32_t dim3146Kuo2Init[]       =   {   1   ,   3   ,   7   ,   7   ,   13  ,   53  ,   55  ,   21  ,   137 ,   953 ,   1583    ,   3439    ,   2995    ,   4447    ,   19881   ,0 };
            const std::uint32_t dim3147Kuo2Init[]       =   {   1   ,   1   ,   7   ,   11  ,   29  ,   21  ,   83  ,   195 ,   387 ,   133 ,   1135    ,   1425    ,   4655    ,   9171    ,   19217   ,0 };
            const std::uint32_t dim3148Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   3   ,   19  ,   45  ,   249 ,   451 ,   797 ,   693 ,   3511    ,   7213    ,   12851   ,   31915   ,0 };
            const std::uint32_t dim3149Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   17  ,   35  ,   119 ,   153 ,   493 ,   815 ,   1621    ,   2305    ,   7963    ,   6405    ,   6253    ,0 };
            const std::uint32_t dim3150Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   19  ,   23  ,   111 ,   223 ,   469 ,   1015    ,   799 ,   1453    ,   7639    ,   2307    ,   20595   ,0 };
            const std::uint32_t dim3151Kuo2Init[]       =   {   1   ,   1   ,   5   ,   9   ,   9   ,   49  ,   33  ,   233 ,   3   ,   531 ,   1723    ,   845 ,   3585    ,   13993   ,   11955   ,0 };
            const std::uint32_t dim3152Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   1   ,   7   ,   3   ,   217 ,   191 ,   1   ,   2013    ,   3143    ,   5919    ,   3285    ,   10733   ,0 };
            const std::uint32_t dim3153Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   25  ,   9   ,   93  ,   127 ,   471 ,   51  ,   1227    ,   341 ,   3455    ,   11015   ,   21427   ,0 };
            const std::uint32_t dim3154Kuo2Init[]       =   {   1   ,   1   ,   5   ,   9   ,   23  ,   45  ,   9   ,   1   ,   445 ,   927 ,   661 ,   829 ,   411 ,   13531   ,   30903   ,0 };
            const std::uint32_t dim3155Kuo2Init[]       =   {   1   ,   3   ,   3   ,   5   ,   21  ,   25  ,   17  ,   225 ,   43  ,   209 ,   659 ,   3681    ,   3281    ,   10135   ,   6121    ,0 };
            const std::uint32_t dim3156Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   17  ,   33  ,   103 ,   209 ,   187 ,   759 ,   617 ,   2971    ,   3563    ,   12925   ,   23503   ,0 };
            const std::uint32_t dim3157Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   21  ,   13  ,   35  ,   65  ,   507 ,   95  ,   695 ,   961 ,   7589    ,   9633    ,   29065   ,0 };
            const std::uint32_t dim3158Kuo2Init[]       =   {   1   ,   3   ,   5   ,   5   ,   13  ,   17  ,   11  ,   145 ,   11  ,   115 ,   1449    ,   2361    ,   2959    ,   6713    ,   15345   ,0 };
            const std::uint32_t dim3159Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   21  ,   19  ,   15  ,   7   ,   303 ,   995 ,   1245    ,   349 ,   4117    ,   10993   ,   20627   ,0 };
            const std::uint32_t dim3160Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   1   ,   9   ,   21  ,   43  ,   259 ,   725 ,   1735    ,   1515    ,   3465    ,   10867   ,   14895   ,0 };
            const std::uint32_t dim3161Kuo2Init[]       =   {   1   ,   1   ,   1   ,   3   ,   7   ,   25  ,   57  ,   29  ,   435 ,   663 ,   383 ,   1197    ,   981 ,   4943    ,   24527   ,0 };
            const std::uint32_t dim3162Kuo2Init[]       =   {   1   ,   1   ,   3   ,   13  ,   3   ,   29  ,   43  ,   149 ,   351 ,   293 ,   1549    ,   3177    ,   6771    ,   7291    ,   23227   ,0 };
            const std::uint32_t dim3163Kuo2Init[]       =   {   1   ,   1   ,   1   ,   9   ,   29  ,   53  ,   9   ,   43  ,   369 ,   763 ,   1269    ,   595 ,   6559    ,   13799   ,   27751   ,0 };
            const std::uint32_t dim3164Kuo2Init[]       =   {   1   ,   1   ,   3   ,   3   ,   7   ,   53  ,   79  ,   167 ,   121 ,   761 ,   1015    ,   1299    ,   1523    ,   55  ,   4431    ,0 };
            const std::uint32_t dim3165Kuo2Init[]       =   {   1   ,   3   ,   1   ,   15  ,   19  ,   9   ,   103 ,   17  ,   121 ,   621 ,   765 ,   2225    ,   4123    ,   815 ,   4305    ,0 };
            const std::uint32_t dim3166Kuo2Init[]       =   {   1   ,   3   ,   7   ,   7   ,   29  ,   59  ,   43  ,   73  ,   505 ,   755 ,   617 ,   2113    ,   5605    ,   11887   ,   10211   ,0 };
            const std::uint32_t dim3167Kuo2Init[]       =   {   1   ,   1   ,   5   ,   15  ,   23  ,   47  ,   27  ,   241 ,   287 ,   649 ,   1601    ,   2461    ,   7851    ,   7901    ,   24305   ,0 };
            const std::uint32_t dim3168Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   9   ,   31  ,   43  ,   103 ,   227 ,   381 ,   813 ,   3871    ,   2293    ,   5317    ,   4907    ,0 };
            const std::uint32_t dim3169Kuo2Init[]       =   {   1   ,   3   ,   7   ,   1   ,   29  ,   41  ,   49  ,   75  ,   389 ,   799 ,   1283    ,   1823    ,   6907    ,   11715   ,   24101   ,0 };
            const std::uint32_t dim3170Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   1   ,   17  ,   53  ,   61  ,   133 ,   485 ,   317 ,   1779    ,   2437    ,   6195    ,   4745    ,0 };
            const std::uint32_t dim3171Kuo2Init[]       =   {   1   ,   3   ,   7   ,   11  ,   1   ,   55  ,   79  ,   147 ,   511 ,   29  ,   495 ,   1145    ,   677 ,   8581    ,   9491    ,0 };
            const std::uint32_t dim3172Kuo2Init[]       =   {   1   ,   1   ,   1   ,   7   ,   15  ,   23  ,   51  ,   243 ,   139 ,   605 ,   2035    ,   1039    ,   1135    ,   10747   ,   28225   ,0 };
            const std::uint32_t dim3173Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   15  ,   5   ,   121 ,   73  ,   403 ,   861 ,   1587    ,   2985    ,   2217    ,   1969    ,   10459   ,0 };
            const std::uint32_t dim3174Kuo2Init[]       =   {   1   ,   1   ,   3   ,   3   ,   15  ,   45  ,   123 ,   235 ,   85  ,   973 ,   915 ,   2217    ,   2405    ,   4473    ,   8119    ,0 };
            const std::uint32_t dim3175Kuo2Init[]       =   {   1   ,   1   ,   3   ,   3   ,   29  ,   29  ,   9   ,   47  ,   173 ,   121 ,   861 ,   1081    ,   917 ,   9757    ,   25923   ,0 };
            const std::uint32_t dim3176Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   25  ,   59  ,   57  ,   35  ,   291 ,   529 ,   1069    ,   4037    ,   4865    ,   5047    ,   1133    ,0 };
            const std::uint32_t dim3177Kuo2Init[]       =   {   1   ,   1   ,   5   ,   7   ,   5   ,   25  ,   49  ,   171 ,   363 ,   427 ,   1807    ,   1903    ,   6455    ,   12201   ,   12043   ,0 };
            const std::uint32_t dim3178Kuo2Init[]       =   {   1   ,   1   ,   3   ,   3   ,   23  ,   13  ,   77  ,   61  ,   415 ,   307 ,   1237    ,   2785    ,   1133    ,   14337   ,   25755   ,0 };
            const std::uint32_t dim3179Kuo2Init[]       =   {   1   ,   1   ,   1   ,   3   ,   3   ,   49  ,   95  ,   117 ,   409 ,   641 ,   393 ,   3205    ,   5047    ,   4795    ,   22773   ,0 };
            const std::uint32_t dim3180Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   15  ,   25  ,   39  ,   37  ,   15  ,   735 ,   1107    ,   2467    ,   8037    ,   6395    ,   26043   ,0 };
            const std::uint32_t dim3181Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   15  ,   51  ,   53  ,   211 ,   223 ,   165 ,   217 ,   3519    ,   6973    ,   823 ,   15733   ,0 };
            const std::uint32_t dim3182Kuo2Init[]       =   {   1   ,   1   ,   3   ,   11  ,   25  ,   15  ,   57  ,   9   ,   373 ,   445 ,   369 ,   2199    ,   2793    ,   12279   ,   7413    ,0 };
            const std::uint32_t dim3183Kuo2Init[]       =   {   1   ,   1   ,   3   ,   1   ,   29  ,   13  ,   37  ,   91  ,   429 ,   5   ,   467 ,   813 ,   2375    ,   10467   ,   10373   ,0 };
            const std::uint32_t dim3184Kuo2Init[]       =   {   1   ,   1   ,   7   ,   15  ,   1   ,   21  ,   65  ,   145 ,   341 ,   839 ,   467 ,   1029    ,   3127    ,   11519   ,   6711    ,0 };
            const std::uint32_t dim3185Kuo2Init[]       =   {   1   ,   1   ,   3   ,   11  ,   29  ,   55  ,   115 ,   65  ,   501 ,   375 ,   1669    ,   2227    ,   125 ,   8059    ,   15489   ,0 };
            const std::uint32_t dim3186Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   7   ,   9   ,   71  ,   179 ,   203 ,   1017    ,   107 ,   49  ,   1093    ,   4847    ,   14383   ,0 };
            const std::uint32_t dim3187Kuo2Init[]       =   {   1   ,   3   ,   7   ,   13  ,   9   ,   57  ,   75  ,   139 ,   67  ,   587 ,   1681    ,   1717    ,   459 ,   7835    ,   317 ,0 };
            const std::uint32_t dim3188Kuo2Init[]       =   {   1   ,   3   ,   1   ,   1   ,   13  ,   15  ,   37  ,   123 ,   233 ,   467 ,   1425    ,   2119    ,   2589    ,   10087   ,   31997   ,0 };
            const std::uint32_t dim3189Kuo2Init[]       =   {   1   ,   3   ,   7   ,   9   ,   29  ,   53  ,   119 ,   19  ,   387 ,   225 ,   1845    ,   2849    ,   181 ,   1991    ,   10323   ,0 };
            const std::uint32_t dim3190Kuo2Init[]       =   {   1   ,   3   ,   5   ,   11  ,   1   ,   61  ,   5   ,   221 ,   389 ,   595 ,   499 ,   2103    ,   5967    ,   4677    ,   17551   ,0 };
            const std::uint32_t dim3191Kuo2Init[]       =   {   1   ,   1   ,   7   ,   5   ,   31  ,   9   ,   63  ,   121 ,   505 ,   997 ,   939 ,   7   ,   7809    ,   11337   ,   11825   ,0 };
            const std::uint32_t dim3192Kuo2Init[]       =   {   1   ,   1   ,   1   ,   7   ,   27  ,   35  ,   99  ,   145 ,   401 ,   887 ,   657 ,   1023    ,   6215    ,   15775   ,   13477   ,0 };
            const std::uint32_t dim3193Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   7   ,   39  ,   35  ,   63  ,   395 ,   621 ,   1551    ,   2061    ,   7817    ,   6159    ,   13765   ,0 };
            const std::uint32_t dim3194Kuo2Init[]       =   {   1   ,   1   ,   7   ,   3   ,   13  ,   5   ,   17  ,   19  ,   469 ,   541 ,   707 ,   1697    ,   699 ,   5031    ,   4121    ,0 };
            const std::uint32_t dim3195Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   31  ,   7   ,   21  ,   15  ,   137 ,   151 ,   599 ,   857 ,   6267    ,   4725    ,   20317   ,0 };
            const std::uint32_t dim3196Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   23  ,   13  ,   59  ,   169 ,   73  ,   517 ,   1209    ,   2063    ,   1881    ,   849 ,   3263    ,0 };
            const std::uint32_t dim3197Kuo2Init[]       =   {   1   ,   1   ,   1   ,   9   ,   3   ,   61  ,   115 ,   75  ,   161 ,   395 ,   1889    ,   1229    ,   6153    ,   597 ,   5667    ,0 };
            const std::uint32_t dim3198Kuo2Init[]       =   {   1   ,   1   ,   3   ,   11  ,   5   ,   31  ,   37  ,   163 ,   469 ,   237 ,   91  ,   3531    ,   7197    ,   12673   ,   13741   ,0 };
            const std::uint32_t dim3199Kuo2Init[]       =   {   1   ,   1   ,   3   ,   1   ,   17  ,   61  ,   31  ,   29  ,   3   ,   855 ,   1703    ,   2091    ,   2791    ,   1963    ,   7385    ,0 };
            const std::uint32_t dim3200Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   13  ,   53  ,   105 ,   239 ,   143 ,   199 ,   2003    ,   4005    ,   1911    ,   4965    ,   31675   ,0 };
            const std::uint32_t dim3201Kuo2Init[]       =   {   1   ,   3   ,   7   ,   3   ,   7   ,   37  ,   73  ,   85  ,   219 ,   165 ,   887 ,   243 ,   117 ,   767 ,   5519    ,0 };
            const std::uint32_t dim3202Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   21  ,   3   ,   89  ,   13  ,   261 ,   835 ,   529 ,   3851    ,   4905    ,   2881    ,   3889    ,0 };
            const std::uint32_t dim3203Kuo2Init[]       =   {   1   ,   1   ,   7   ,   3   ,   15  ,   41  ,   21  ,   89  ,   137 ,   959 ,   839 ,   4087    ,   1689    ,   11347   ,   17701   ,0 };
            const std::uint32_t dim3204Kuo2Init[]       =   {   1   ,   3   ,   7   ,   3   ,   15  ,   17  ,   63  ,   31  ,   493 ,   509 ,   1079    ,   3223    ,   7649    ,   4377    ,   20291   ,0 };
            const std::uint32_t dim3205Kuo2Init[]       =   {   1   ,   3   ,   5   ,   5   ,   5   ,   63  ,   101 ,   83  ,   431 ,   201 ,   1965    ,   1227    ,   2161    ,   14661   ,   2027    ,0 };
            const std::uint32_t dim3206Kuo2Init[]       =   {   1   ,   1   ,   7   ,   3   ,   29  ,   19  ,   81  ,   245 ,   125 ,   795 ,   181 ,   4017    ,   4061    ,   12909   ,   30591   ,0 };
            const std::uint32_t dim3207Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   19  ,   63  ,   49  ,   205 ,   485 ,   789 ,   1123    ,   715 ,   6553    ,   5637    ,   7977    ,0 };
            const std::uint32_t dim3208Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   13  ,   63  ,   113 ,   63  ,   187 ,   515 ,   725 ,   3583    ,   1699    ,   5165    ,   21823   ,0 };
            const std::uint32_t dim3209Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   27  ,   17  ,   17  ,   241 ,   205 ,   593 ,   697 ,   4023    ,   7603    ,   15421   ,   9679    ,0 };
            const std::uint32_t dim3210Kuo2Init[]       =   {   1   ,   3   ,   1   ,   1   ,   3   ,   15  ,   39  ,   209 ,   53  ,   405 ,   601 ,   3315    ,   5487    ,   12163   ,   14741   ,0 };
            const std::uint32_t dim3211Kuo2Init[]       =   {   1   ,   1   ,   3   ,   13  ,   31  ,   9   ,   9   ,   159 ,   187 ,   307 ,   1115    ,   381 ,   7763    ,   4231    ,   2387    ,0 };
            const std::uint32_t dim3212Kuo2Init[]       =   {   1   ,   1   ,   7   ,   13  ,   1   ,   41  ,   17  ,   101 ,   321 ,   473 ,   515 ,   1959    ,   7589    ,   9323    ,   23947   ,0 };
            const std::uint32_t dim3213Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   21  ,   55  ,   55  ,   137 ,   115 ,   791 ,   1411    ,   3543    ,   8173    ,   14403   ,   28019   ,0 };
            const std::uint32_t dim3214Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   29  ,   35  ,   83  ,   119 ,   243 ,   561 ,   423 ,   2435    ,   7613    ,   1081    ,   29911   ,0 };
            const std::uint32_t dim3215Kuo2Init[]       =   {   1   ,   3   ,   1   ,   15  ,   13  ,   21  ,   9   ,   205 ,   3   ,   901 ,   1305    ,   4015    ,   4045    ,   11685   ,   489 ,0 };
            const std::uint32_t dim3216Kuo2Init[]       =   {   1   ,   1   ,   5   ,   13  ,   27  ,   57  ,   73  ,   173 ,   391 ,   259 ,   757 ,   3177    ,   3767    ,   5251    ,   12381   ,0 };
            const std::uint32_t dim3217Kuo2Init[]       =   {   1   ,   1   ,   3   ,   1   ,   3   ,   15  ,   121 ,   1   ,   85  ,   795 ,   1465    ,   1247    ,   5703    ,   3399    ,   28519   ,0 };
            const std::uint32_t dim3218Kuo2Init[]       =   {   1   ,   1   ,   1   ,   7   ,   27  ,   7   ,   41  ,   147 ,   277 ,   317 ,   1161    ,   2205    ,   1845    ,   12379   ,   9121    ,0 };
            const std::uint32_t dim3219Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   5   ,   59  ,   107 ,   115 ,   13  ,   469 ,   595 ,   3979    ,   7563    ,   521 ,   6407    ,0 };
            const std::uint32_t dim3220Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   31  ,   43  ,   107 ,   107 ,   49  ,   67  ,   475 ,   1371    ,   3205    ,   2035    ,   6349    ,0 };
            const std::uint32_t dim3221Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   19  ,   33  ,   73  ,   171 ,   493 ,   473 ,   1963    ,   2453    ,   2833    ,   6847    ,   9899    ,0 };
            const std::uint32_t dim3222Kuo2Init[]       =   {   1   ,   3   ,   1   ,   1   ,   31  ,   57  ,   33  ,   201 ,   431 ,   623 ,   327 ,   481 ,   2377    ,   6533    ,   30339   ,0 };
            const std::uint32_t dim3223Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   31  ,   11  ,   47  ,   183 ,   209 ,   661 ,   357 ,   3809    ,   4129    ,   5465    ,   29141   ,0 };
            const std::uint32_t dim3224Kuo2Init[]       =   {   1   ,   1   ,   3   ,   3   ,   19  ,   43  ,   99  ,   45  ,   471 ,   983 ,   627 ,   2397    ,   753 ,   6735    ,   24945   ,0 };
            const std::uint32_t dim3225Kuo2Init[]       =   {   1   ,   3   ,   5   ,   11  ,   3   ,   31  ,   127 ,   255 ,   175 ,   549 ,   1743    ,   3417    ,   3753    ,   11497   ,   5273    ,0 };
            const std::uint32_t dim3226Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   5   ,   17  ,   77  ,   99  ,   109 ,   973 ,   93  ,   1287    ,   1781    ,   6055    ,   6987    ,0 };
            const std::uint32_t dim3227Kuo2Init[]       =   {   1   ,   1   ,   7   ,   5   ,   17  ,   31  ,   23  ,   231 ,   63  ,   315 ,   1119    ,   2175    ,   5807    ,   6497    ,   12991   ,0 };
            const std::uint32_t dim3228Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   25  ,   17  ,   51  ,   81  ,   253 ,   725 ,   1351    ,   1941    ,   3893    ,   13059   ,   27373   ,0 };
            const std::uint32_t dim3229Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   17  ,   43  ,   35  ,   151 ,   127 ,   587 ,   229 ,   2253    ,   4299    ,   10269   ,   169 ,0 };
            const std::uint32_t dim3230Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   15  ,   11  ,   65  ,   31  ,   263 ,   897 ,   1345    ,   3011    ,   6767    ,   15851   ,   16801   ,0 };
            const std::uint32_t dim3231Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   15  ,   1   ,   119 ,   235 ,   57  ,   339 ,   503 ,   2633    ,   1307    ,   14387   ,   28759   ,0 };
            const std::uint32_t dim3232Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   5   ,   57  ,   111 ,   117 ,   273 ,   703 ,   1363    ,   1579    ,   97  ,   15323   ,   24897   ,0 };
            const std::uint32_t dim3233Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   23  ,   29  ,   43  ,   171 ,   347 ,   651 ,   869 ,   3623    ,   1643    ,   14647   ,   16271   ,0 };
            const std::uint32_t dim3234Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   11  ,   35  ,   41  ,   121 ,   117 ,   67  ,   1649    ,   1201    ,   213 ,   13013   ,   20403   ,0 };
            const std::uint32_t dim3235Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   3   ,   33  ,   61  ,   97  ,   439 ,   371 ,   117 ,   1341    ,   6513    ,   11043   ,   10055   ,0 };
            const std::uint32_t dim3236Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   25  ,   9   ,   25  ,   13  ,   121 ,   593 ,   1879    ,   2487    ,   385 ,   4341    ,   11515   ,0 };
            const std::uint32_t dim3237Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   11  ,   23  ,   65  ,   181 ,   205 ,   381 ,   1749    ,   3837    ,   5343    ,   12389   ,   27243   ,0 };
            const std::uint32_t dim3238Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   19  ,   9   ,   11  ,   185 ,   109 ,   49  ,   311 ,   1225    ,   7445    ,   14459   ,   12631   ,0 };
            const std::uint32_t dim3239Kuo2Init[]       =   {   1   ,   3   ,   7   ,   7   ,   27  ,   3   ,   87  ,   179 ,   467 ,   823 ,   1641    ,   189 ,   3489    ,   3203    ,   10447   ,0 };
            const std::uint32_t dim3240Kuo2Init[]       =   {   1   ,   3   ,   5   ,   3   ,   5   ,   15  ,   117 ,   139 ,   39  ,   497 ,   1137    ,   1193    ,   2281    ,   12945   ,   1329    ,0 };
            const std::uint32_t dim3241Kuo2Init[]       =   {   1   ,   3   ,   7   ,   15  ,   21  ,   9   ,   111 ,   115 ,   461 ,   987 ,   1091    ,   2363    ,   5453    ,   3929    ,   26887   ,0 };
            const std::uint32_t dim3242Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   19  ,   25  ,   113 ,   65  ,   301 ,   491 ,   1679    ,   4007    ,   4709    ,   4547    ,   25155   ,0 };
            const std::uint32_t dim3243Kuo2Init[]       =   {   1   ,   3   ,   1   ,   15  ,   29  ,   23  ,   87  ,   209 ,   471 ,   247 ,   633 ,   2533    ,   1077    ,   5079    ,   10311   ,0 };
            const std::uint32_t dim3244Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   27  ,   21  ,   27  ,   57  ,   69  ,   883 ,   145 ,   1559    ,   6751    ,   873 ,   28941   ,0 };
            const std::uint32_t dim3245Kuo2Init[]       =   {   1   ,   1   ,   7   ,   5   ,   23  ,   63  ,   113 ,   57  ,   243 ,   133 ,   1159    ,   3837    ,   4781    ,   6029    ,   391 ,0 };
            const std::uint32_t dim3246Kuo2Init[]       =   {   1   ,   1   ,   1   ,   7   ,   27  ,   47  ,   33  ,   211 ,   317 ,   891 ,   1955    ,   3201    ,   803 ,   1645    ,   26669   ,0 };
            const std::uint32_t dim3247Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   17  ,   5   ,   69  ,   233 ,   491 ,   489 ,   49  ,   1395    ,   1907    ,   10189   ,   17853   ,0 };
            const std::uint32_t dim3248Kuo2Init[]       =   {   1   ,   1   ,   7   ,   13  ,   9   ,   29  ,   25  ,   169 ,   469 ,   1015    ,   1729    ,   3095    ,   281 ,   15537   ,   32565   ,0 };
            const std::uint32_t dim3249Kuo2Init[]       =   {   1   ,   1   ,   1   ,   7   ,   23  ,   63  ,   55  ,   65  ,   1   ,   913 ,   343 ,   3749    ,   3085    ,   13557   ,   32121   ,0 };
            const std::uint32_t dim3250Kuo2Init[]       =   {   1   ,   3   ,   7   ,   13  ,   15  ,   29  ,   15  ,   141 ,   113 ,   315 ,   645 ,   821 ,   5083    ,   12141   ,   1603    ,0 };
            const std::uint32_t dim3251Kuo2Init[]       =   {   1   ,   3   ,   5   ,   11  ,   19  ,   7   ,   73  ,   245 ,   139 ,   923 ,   731 ,   211 ,   7223    ,   8179    ,   20811   ,0 };
            const std::uint32_t dim3252Kuo2Init[]       =   {   1   ,   3   ,   7   ,   11  ,   31  ,   21  ,   35  ,   253 ,   373 ,   889 ,   1671    ,   1069    ,   3475    ,   1947    ,   16129   ,0 };
            const std::uint32_t dim3253Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   17  ,   11  ,   3   ,   223 ,   169 ,   577 ,   2045    ,   2591    ,   2593    ,   10911   ,   20657   ,0 };
            const std::uint32_t dim3254Kuo2Init[]       =   {   1   ,   3   ,   3   ,   5   ,   21  ,   57  ,   121 ,   185 ,   329 ,   581 ,   471 ,   1799    ,   393 ,   1059    ,   19339   ,0 };
            const std::uint32_t dim3255Kuo2Init[]       =   {   1   ,   1   ,   3   ,   3   ,   17  ,   63  ,   39  ,   227 ,   447 ,   157 ,   1803    ,   239 ,   93  ,   5297    ,   801 ,0 };
            const std::uint32_t dim3256Kuo2Init[]       =   {   1   ,   3   ,   5   ,   5   ,   23  ,   47  ,   127 ,   211 ,   415 ,   943 ,   757 ,   213 ,   5071    ,   5811    ,   2135    ,0 };
            const std::uint32_t dim3257Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   7   ,   63  ,   95  ,   83  ,   307 ,   241 ,   511 ,   1417    ,   2141    ,   2599    ,   1665    ,0 };
            const std::uint32_t dim3258Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   17  ,   31  ,   113 ,   53  ,   27  ,   611 ,   45  ,   1909    ,   6519    ,   5687    ,   23335   ,0 };
            const std::uint32_t dim3259Kuo2Init[]       =   {   1   ,   1   ,   5   ,   9   ,   5   ,   43  ,   81  ,   99  ,   505 ,   739 ,   633 ,   1563    ,   6385    ,   14799   ,   24813   ,0 };
            const std::uint32_t dim3260Kuo2Init[]       =   {   1   ,   3   ,   7   ,   13  ,   19  ,   47  ,   11  ,   87  ,   403 ,   763 ,   483 ,   3793    ,   7445    ,   4865    ,   13187   ,0 };
            const std::uint32_t dim3261Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   17  ,   49  ,   25  ,   57  ,   417 ,   253 ,   1901    ,   115 ,   3933    ,   11743   ,   1925    ,0 };
            const std::uint32_t dim3262Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   15  ,   21  ,   13  ,   143 ,   399 ,   953 ,   1397    ,   3905    ,   7935    ,   11957   ,   4817    ,0 };
            const std::uint32_t dim3263Kuo2Init[]       =   {   1   ,   1   ,   5   ,   1   ,   7   ,   63  ,   49  ,   11  ,   321 ,   181 ,   545 ,   2035    ,   5339    ,   2727    ,   11623   ,0 };
            const std::uint32_t dim3264Kuo2Init[]       =   {   1   ,   3   ,   7   ,   1   ,   15  ,   13  ,   49  ,   101 ,   499 ,   831 ,   427 ,   531 ,   4165    ,   7087    ,   14077   ,0 };
            const std::uint32_t dim3265Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   13  ,   19  ,   119 ,   115 ,   283 ,   1015    ,   1189    ,   2507    ,   2491    ,   13467   ,   10437   ,0 };
            const std::uint32_t dim3266Kuo2Init[]       =   {   1   ,   1   ,   5   ,   3   ,   11  ,   31  ,   103 ,   3   ,   421 ,   717 ,   611 ,   2711    ,   2221    ,   13187   ,   19973   ,0 };
            const std::uint32_t dim3267Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   3   ,   53  ,   61  ,   3   ,   337 ,   55  ,   751 ,   3467    ,   7851    ,   3437    ,   31047   ,0 };
            const std::uint32_t dim3268Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   1   ,   57  ,   81  ,   127 ,   425 ,   965 ,   1633    ,   2193    ,   7061    ,   2239    ,   18383   ,0 };
            const std::uint32_t dim3269Kuo2Init[]       =   {   1   ,   1   ,   5   ,   15  ,   11  ,   55  ,   49  ,   31  ,   497 ,   715 ,   1725    ,   1359    ,   177 ,   13011   ,   11291   ,0 };
            const std::uint32_t dim3270Kuo2Init[]       =   {   1   ,   1   ,   5   ,   9   ,   3   ,   11  ,   121 ,   217 ,   77  ,   627 ,   1857    ,   41  ,   7613    ,   3471    ,   10591   ,0 };
            const std::uint32_t dim3271Kuo2Init[]       =   {   1   ,   1   ,   7   ,   11  ,   13  ,   23  ,   81  ,   253 ,   263 ,   663 ,   1581    ,   1839    ,   1327    ,   7735    ,   22843   ,0 };
            const std::uint32_t dim3272Kuo2Init[]       =   {   1   ,   1   ,   7   ,   3   ,   31  ,   29  ,   97  ,   243 ,   215 ,   893 ,   1179    ,   953 ,   915 ,   16003   ,   32685   ,0 };
            const std::uint32_t dim3273Kuo2Init[]       =   {   1   ,   1   ,   7   ,   3   ,   5   ,   61  ,   7   ,   35  ,   439 ,   1023    ,   1079    ,   3639    ,   3179    ,   8793    ,   8413    ,0 };
            const std::uint32_t dim3274Kuo2Init[]       =   {   1   ,   1   ,   5   ,   13  ,   31  ,   1   ,   99  ,   199 ,   181 ,   75  ,   283 ,   1581    ,   1137    ,   2725    ,   27179   ,0 };
            const std::uint32_t dim3275Kuo2Init[]       =   {   1   ,   3   ,   7   ,   1   ,   27  ,   35  ,   45  ,   49  ,   179 ,   403 ,   593 ,   2849    ,   2349    ,   5835    ,   32533   ,0 };
            const std::uint32_t dim3276Kuo2Init[]       =   {   1   ,   1   ,   1   ,   1   ,   5   ,   31  ,   21  ,   153 ,   169 ,   19  ,   813 ,   3077    ,   2569    ,   12355   ,   3805    ,0 };
            const std::uint32_t dim3277Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   1   ,   15  ,   77  ,   31  ,   17  ,   827 ,   2005    ,   799 ,   5663    ,   779 ,   28605   ,0 };
            const std::uint32_t dim3278Kuo2Init[]       =   {   1   ,   1   ,   5   ,   3   ,   29  ,   51  ,   3   ,   91  ,   505 ,   161 ,   2041    ,   2841    ,   269 ,   33  ,   21771   ,0 };
            const std::uint32_t dim3279Kuo2Init[]       =   {   1   ,   1   ,   3   ,   5   ,   17  ,   55  ,   105 ,   233 ,   9   ,   647 ,   987 ,   3801    ,   1421    ,   8589    ,   23389   ,0 };
            const std::uint32_t dim3280Kuo2Init[]       =   {   1   ,   1   ,   7   ,   15  ,   27  ,   63  ,   73  ,   87  ,   111 ,   233 ,   1231    ,   3631    ,   4355    ,   15843   ,   1227    ,0 };
            const std::uint32_t dim3281Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   17  ,   5   ,   63  ,   23  ,   55  ,   655 ,   1909    ,   891 ,   7873    ,   11163   ,   26269   ,0 };
            const std::uint32_t dim3282Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   19  ,   7   ,   47  ,   31  ,   41  ,   229 ,   1381    ,   773 ,   2183    ,   1687    ,   15761   ,0 };
            const std::uint32_t dim3283Kuo2Init[]       =   {   1   ,   1   ,   7   ,   3   ,   17  ,   57  ,   81  ,   115 ,   41  ,   907 ,   1353    ,   981 ,   2601    ,   10247   ,   13753   ,0 };
            const std::uint32_t dim3284Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   5   ,   13  ,   83  ,   19  ,   107 ,   935 ,   1519    ,   795 ,   2035    ,   5649    ,   21125   ,0 };
            const std::uint32_t dim3285Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   21  ,   7   ,   77  ,   229 ,   85  ,   837 ,   1085    ,   781 ,   6599    ,   5645    ,   15481   ,0 };
            const std::uint32_t dim3286Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   13  ,   23  ,   109 ,   21  ,   77  ,   223 ,   131 ,   4013    ,   7507    ,   10463   ,   25621   ,0 };
            const std::uint32_t dim3287Kuo2Init[]       =   {   1   ,   3   ,   5   ,   11  ,   21  ,   55  ,   99  ,   195 ,   447 ,   57  ,   1395    ,   1283    ,   377 ,   15019   ,   26951   ,0 };
            const std::uint32_t dim3288Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   13  ,   35  ,   119 ,   39  ,   161 ,   609 ,   247 ,   2541    ,   3133    ,   9625    ,   12129   ,0 };
            const std::uint32_t dim3289Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   7   ,   55  ,   69  ,   169 ,   459 ,   461 ,   1359    ,   255 ,   4567    ,   7915    ,   16883   ,0 };
            const std::uint32_t dim3290Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   25  ,   41  ,   93  ,   105 ,   147 ,   893 ,   515 ,   3161    ,   351 ,   12079   ,   3445    ,0 };
            const std::uint32_t dim3291Kuo2Init[]       =   {   1   ,   3   ,   3   ,   5   ,   15  ,   59  ,   93  ,   61  ,   235 ,   971 ,   1203    ,   2213    ,   3257    ,   16001   ,   20581   ,0 };
            const std::uint32_t dim3292Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   19  ,   5   ,   53  ,   49  ,   101 ,   653 ,   897 ,   3761    ,   8087    ,   14891   ,   30595   ,0 };
            const std::uint32_t dim3293Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   13  ,   27  ,   37  ,   29  ,   181 ,   875 ,   1429    ,   2483    ,   2987    ,   15951   ,   16217   ,0 };
            const std::uint32_t dim3294Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   11  ,   53  ,   69  ,   33  ,   309 ,   467 ,   1149    ,   3103    ,   3713    ,   9701    ,   16637   ,0 };
            const std::uint32_t dim3295Kuo2Init[]       =   {   1   ,   1   ,   5   ,   1   ,   31  ,   63  ,   5   ,   187 ,   371 ,   895 ,   1365    ,   2671    ,   5899    ,   15493   ,   9685    ,0 };
            const std::uint32_t dim3296Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   19  ,   3   ,   127 ,   251 ,   39  ,   335 ,   489 ,   3359    ,   4939    ,   413 ,   521 ,0 };
            const std::uint32_t dim3297Kuo2Init[]       =   {   1   ,   1   ,   7   ,   11  ,   11  ,   37  ,   51  ,   135 ,   191 ,   535 ,   1037    ,   2365    ,   381 ,   8253    ,   21177   ,0 };
            const std::uint32_t dim3298Kuo2Init[]       =   {   1   ,   1   ,   3   ,   13  ,   9   ,   23  ,   77  ,   147 ,   93  ,   793 ,   1223    ,   2655    ,   3873    ,   6049    ,   19201   ,0 };
            const std::uint32_t dim3299Kuo2Init[]       =   {   1   ,   3   ,   5   ,   5   ,   15  ,   41  ,   21  ,   217 ,   149 ,   965 ,   1173    ,   1779    ,   501 ,   4829    ,   17439   ,0 };
            const std::uint32_t dim3300Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   11  ,   37  ,   63  ,   233 ,   103 ,   453 ,   799 ,   571 ,   1991    ,   439 ,   26713   ,0 };
            const std::uint32_t dim3301Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   31  ,   1   ,   11  ,   155 ,   483 ,   875 ,   1943    ,   1355    ,   3125    ,   8771    ,   30531   ,0 };
            const std::uint32_t dim3302Kuo2Init[]       =   {   1   ,   3   ,   3   ,   13  ,   7   ,   31  ,   9   ,   139 ,   277 ,   203 ,   1937    ,   31  ,   4519    ,   2127    ,   22557   ,0 };
            const std::uint32_t dim3303Kuo2Init[]       =   {   1   ,   1   ,   1   ,   3   ,   19  ,   53  ,   117 ,   225 ,   391 ,   501 ,   607 ,   1493    ,   3119    ,   10817   ,   6307    ,0 };
            const std::uint32_t dim3304Kuo2Init[]       =   {   1   ,   1   ,   3   ,   11  ,   3   ,   19  ,   3   ,   51  ,   507 ,   245 ,   1563    ,   3987    ,   7461    ,   4851    ,   23697   ,0 };
            const std::uint32_t dim3305Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   1   ,   39  ,   49  ,   21  ,   39  ,   631 ,   1777    ,   1689    ,   665 ,   5657    ,   26469   ,0 };
            const std::uint32_t dim3306Kuo2Init[]       =   {   1   ,   3   ,   7   ,   3   ,   17  ,   41  ,   73  ,   13  ,   97  ,   649 ,   1737    ,   653 ,   5093    ,   629 ,   4389    ,0 };
            const std::uint32_t dim3307Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   13  ,   9   ,   99  ,   149 ,   389 ,   151 ,   313 ,   2517    ,   77  ,   2157    ,   4713    ,0 };
            const std::uint32_t dim3308Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   15  ,   25  ,   3   ,   129 ,   111 ,   847 ,   585 ,   3103    ,   6237    ,   8491    ,   24519   ,0 };
            const std::uint32_t dim3309Kuo2Init[]       =   {   1   ,   1   ,   3   ,   1   ,   11  ,   25  ,   71  ,   229 ,   325 ,   51  ,   537 ,   3393    ,   6561    ,   6871    ,   30609   ,0 };
            const std::uint32_t dim3310Kuo2Init[]       =   {   1   ,   3   ,   7   ,   15  ,   5   ,   3   ,   109 ,   237 ,   469 ,   235 ,   1703    ,   525 ,   2579    ,   9107    ,   13261   ,0 };
            const std::uint32_t dim3311Kuo2Init[]       =   {   1   ,   3   ,   7   ,   13  ,   7   ,   31  ,   65  ,   67  ,   165 ,   1003    ,   957 ,   371 ,   5857    ,   16307   ,   4069    ,0 };
            const std::uint32_t dim3312Kuo2Init[]       =   {   1   ,   1   ,   7   ,   15  ,   7   ,   63  ,   51  ,   199 ,   63  ,   259 ,   1383    ,   2747    ,   5945    ,   8061    ,   30961   ,0 };
            const std::uint32_t dim3313Kuo2Init[]       =   {   1   ,   1   ,   1   ,   7   ,   13  ,   43  ,   67  ,   143 ,   407 ,   369 ,   1803    ,   2405    ,   4737    ,   5741    ,   21311   ,0 };
            const std::uint32_t dim3314Kuo2Init[]       =   {   1   ,   3   ,   7   ,   11  ,   19  ,   25  ,   127 ,   251 ,   325 ,   327 ,   169 ,   3745    ,   2115    ,   4591    ,   12383   ,0 };
            const std::uint32_t dim3315Kuo2Init[]       =   {   1   ,   1   ,   3   ,   13  ,   31  ,   61  ,   35  ,   209 ,   161 ,   171 ,   1155    ,   531 ,   5493    ,   13607   ,   23809   ,0 };
            const std::uint32_t dim3316Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   21  ,   39  ,   93  ,   185 ,   421 ,   355 ,   2039    ,   259 ,   7309    ,   6747    ,   745 ,0 };
            const std::uint32_t dim3317Kuo2Init[]       =   {   1   ,   3   ,   5   ,   11  ,   1   ,   39  ,   43  ,   169 ,   137 ,   21  ,   1377    ,   3091    ,   4893    ,   1197    ,   1785    ,0 };
            const std::uint32_t dim3318Kuo2Init[]       =   {   1   ,   1   ,   5   ,   5   ,   29  ,   59  ,   89  ,   79  ,   457 ,   463 ,   193 ,   727 ,   2505    ,   10509   ,   5379    ,0 };
            const std::uint32_t dim3319Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   23  ,   23  ,   59  ,   35  ,   425 ,   47  ,   1787    ,   1705    ,   3469    ,   14583   ,   3439    ,0 };
            const std::uint32_t dim3320Kuo2Init[]       =   {   1   ,   1   ,   7   ,   5   ,   27  ,   5   ,   85  ,   51  ,   31  ,   277 ,   851 ,   2731    ,   5613    ,   11305   ,   23727   ,0 };
            const std::uint32_t dim3321Kuo2Init[]       =   {   1   ,   3   ,   1   ,   15  ,   15  ,   47  ,   109 ,   211 ,   385 ,   505 ,   791 ,   253 ,   4123    ,   13393   ,   31515   ,0 };
            const std::uint32_t dim3322Kuo2Init[]       =   {   1   ,   3   ,   5   ,   3   ,   25  ,   9   ,   73  ,   35  ,   203 ,   721 ,   1111    ,   1791    ,   5241    ,   15307   ,   4385    ,0 };
            const std::uint32_t dim3323Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   9   ,   43  ,   127 ,   127 ,   191 ,   21  ,   1967    ,   3523    ,   5959    ,   5775    ,   24635   ,0 };
            const std::uint32_t dim3324Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   7   ,   23  ,   75  ,   37  ,   307 ,   375 ,   1731    ,   2945    ,   763 ,   11723   ,   32033   ,0 };
            const std::uint32_t dim3325Kuo2Init[]       =   {   1   ,   3   ,   3   ,   13  ,   31  ,   19  ,   83  ,   185 ,   457 ,   109 ,   349 ,   1085    ,   7381    ,   8851    ,   27633   ,0 };
            const std::uint32_t dim3326Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   25  ,   17  ,   79  ,   73  ,   381 ,   655 ,   409 ,   2043    ,   6803    ,   9041    ,   25733   ,0 };
            const std::uint32_t dim3327Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   17  ,   9   ,   61  ,   47  ,   429 ,   507 ,   1933    ,   1653    ,   2057    ,   15791   ,   12035   ,0 };
            const std::uint32_t dim3328Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   5   ,   57  ,   31  ,   83  ,   223 ,   281 ,   1485    ,   2965    ,   4543    ,   9719    ,   22109   ,0 };
            const std::uint32_t dim3329Kuo2Init[]       =   {   1   ,   1   ,   3   ,   3   ,   5   ,   11  ,   69  ,   65  ,   229 ,   87  ,   1707    ,   2701    ,   985 ,   12261   ,   32209   ,0 };
            const std::uint32_t dim3330Kuo2Init[]       =   {   1   ,   3   ,   7   ,   15  ,   13  ,   29  ,   121 ,   1   ,   475 ,   905 ,   1843    ,   571 ,   5595    ,   1685    ,   8061    ,0 };
            const std::uint32_t dim3331Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   9   ,   37  ,   115 ,   35  ,   309 ,   117 ,   17  ,   3537    ,   4491    ,   13863   ,   12611   ,0 };
            const std::uint32_t dim3332Kuo2Init[]       =   {   1   ,   1   ,   7   ,   15  ,   9   ,   1   ,   79  ,   135 ,   95  ,   417 ,   633 ,   2109    ,   7911    ,   15009   ,   32399   ,0 };
            const std::uint32_t dim3333Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   9   ,   41  ,   23  ,   137 ,   135 ,   429 ,   267 ,   3787    ,   4643    ,   1221    ,   20257   ,0 };
            const std::uint32_t dim3334Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   11  ,   37  ,   97  ,   107 ,   43  ,   273 ,   213 ,   1779    ,   2317    ,   7325    ,   2495    ,0 };
            const std::uint32_t dim3335Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   13  ,   57  ,   29  ,   29  ,   5   ,   45  ,   633 ,   3437    ,   8147    ,   11819   ,   16397   ,0 };
            const std::uint32_t dim3336Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   19  ,   47  ,   67  ,   39  ,   281 ,   1003    ,   1489    ,   199 ,   3099    ,   3925    ,   17517   ,0 };
            const std::uint32_t dim3337Kuo2Init[]       =   {   1   ,   3   ,   3   ,   3   ,   21  ,   49  ,   91  ,   47  ,   435 ,   193 ,   683 ,   1845    ,   6237    ,   5573    ,   10647   ,0 };
            const std::uint32_t dim3338Kuo2Init[]       =   {   1   ,   3   ,   1   ,   11  ,   3   ,   59  ,   5   ,   197 ,   393 ,   389 ,   1735    ,   1417    ,   2061    ,   11827   ,   7587    ,0 };
            const std::uint32_t dim3339Kuo2Init[]       =   {   1   ,   1   ,   5   ,   15  ,   1   ,   35  ,   113 ,   81  ,   233 ,   435 ,   1481    ,   2007    ,   6043    ,   9005    ,   19277   ,0 };
            const std::uint32_t dim3340Kuo2Init[]       =   {   1   ,   3   ,   1   ,   11  ,   9   ,   53  ,   109 ,   193 ,   329 ,   187 ,   35  ,   3693    ,   951 ,   9735    ,   5587    ,0 };
            const std::uint32_t dim3341Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   19  ,   41  ,   25  ,   225 ,   269 ,   317 ,   201 ,   2817    ,   971 ,   2873    ,   22637   ,0 };
            const std::uint32_t dim3342Kuo2Init[]       =   {   1   ,   3   ,   7   ,   1   ,   9   ,   47  ,   105 ,   219 ,   69  ,   633 ,   1073    ,   1895    ,   1759    ,   12353   ,   9011    ,0 };
            const std::uint32_t dim3343Kuo2Init[]       =   {   1   ,   1   ,   7   ,   11  ,   11  ,   59  ,   3   ,   163 ,   361 ,   157 ,   1937    ,   3589    ,   1531    ,   9303    ,   3627    ,0 };
            const std::uint32_t dim3344Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   31  ,   15  ,   23  ,   5   ,   447 ,   59  ,   1907    ,   197 ,   2775    ,   11303   ,   32553   ,0 };
            const std::uint32_t dim3345Kuo2Init[]       =   {   1   ,   3   ,   1   ,   13  ,   11  ,   35  ,   83  ,   97  ,   225 ,   761 ,   907 ,   3107    ,   1827    ,   14745   ,   235 ,0 };
            const std::uint32_t dim3346Kuo2Init[]       =   {   1   ,   3   ,   1   ,   13  ,   13  ,   37  ,   127 ,   55  ,   511 ,   861 ,   1769    ,   3999    ,   8135    ,   445 ,   12537   ,0 };
            const std::uint32_t dim3347Kuo2Init[]       =   {   1   ,   1   ,   7   ,   11  ,   21  ,   61  ,   111 ,   107 ,   129 ,   43  ,   837 ,   3811    ,   3261    ,   15273   ,   24319   ,0 };
            const std::uint32_t dim3348Kuo2Init[]       =   {   1   ,   3   ,   7   ,   1   ,   17  ,   15  ,   23  ,   27  ,   227 ,   573 ,   1739    ,   2611    ,   3977    ,   493 ,   24091   ,0 };
            const std::uint32_t dim3349Kuo2Init[]       =   {   1   ,   3   ,   3   ,   5   ,   17  ,   59  ,   17  ,   61  ,   443 ,   215 ,   1171    ,   1587    ,   55  ,   14417   ,   30225   ,0 };
            const std::uint32_t dim3350Kuo2Init[]       =   {   1   ,   3   ,   3   ,   5   ,   5   ,   51  ,   5   ,   101 ,   147 ,   951 ,   445 ,   2203    ,   6731    ,   3993    ,   12935   ,0 };
            const std::uint32_t dim3351Kuo2Init[]       =   {   1   ,   1   ,   3   ,   13  ,   31  ,   15  ,   117 ,   125 ,   413 ,   927 ,   1837    ,   2781    ,   2569    ,   12177   ,   20551   ,0 };
            const std::uint32_t dim3352Kuo2Init[]       =   {   1   ,   1   ,   1   ,   9   ,   27  ,   13  ,   115 ,   243 ,   211 ,   123 ,   1631    ,   1277    ,   1217    ,   15271   ,   26377   ,0 };
            const std::uint32_t dim3353Kuo2Init[]       =   {   1   ,   3   ,   7   ,   3   ,   27  ,   55  ,   5   ,   91  ,   255 ,   367 ,   503 ,   659 ,   1527    ,   15907   ,   4485    ,0 };
            const std::uint32_t dim3354Kuo2Init[]       =   {   1   ,   3   ,   3   ,   13  ,   9   ,   11  ,   29  ,   175 ,   305 ,   593 ,   1209    ,   551 ,   7579    ,   1273    ,   22545   ,0 };
            const std::uint32_t dim3355Kuo2Init[]       =   {   1   ,   3   ,   3   ,   13  ,   17  ,   33  ,   101 ,   83  ,   93  ,   261 ,   1395    ,   573 ,   6665    ,   10073   ,   26139   ,0 };
            const std::uint32_t dim3356Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   25  ,   35  ,   93  ,   11  ,   29  ,   941 ,   525 ,   457 ,   1293    ,   15753   ,   19273   ,0 };
            const std::uint32_t dim3357Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   5   ,   31  ,   101 ,   211 ,   383 ,   759 ,   1287    ,   429 ,   291 ,   12347   ,   12683   ,0 };
            const std::uint32_t dim3358Kuo2Init[]       =   {   1   ,   1   ,   7   ,   3   ,   9   ,   53  ,   119 ,   81  ,   91  ,   113 ,   1525    ,   1037    ,   8021    ,   2913    ,   11205   ,0 };
            const std::uint32_t dim3359Kuo2Init[]       =   {   1   ,   1   ,   3   ,   1   ,   9   ,   47  ,   59  ,   23  ,   497 ,   273 ,   453 ,   1063    ,   2523    ,   8929    ,   43  ,0 };
            const std::uint32_t dim3360Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   1   ,   23  ,   65  ,   147 ,   327 ,   851 ,   177 ,   4047    ,   3881    ,   2885    ,   21021   ,0 };
            const std::uint32_t dim3361Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   19  ,   53  ,   13  ,   117 ,   267 ,   803 ,   21  ,   3825    ,   2387    ,   7273    ,   19753   ,0 };
            const std::uint32_t dim3362Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   9   ,   9   ,   107 ,   9   ,   261 ,   797 ,   1337    ,   1535    ,   663 ,   6635    ,   3383    ,0 };
            const std::uint32_t dim3363Kuo2Init[]       =   {   1   ,   1   ,   7   ,   13  ,   13  ,   27  ,   65  ,   75  ,   375 ,   805 ,   1079    ,   947 ,   993 ,   1793    ,   16235   ,0 };
            const std::uint32_t dim3364Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   11  ,   17  ,   119 ,   57  ,   501 ,   105 ,   1109    ,   3607    ,   1805    ,   8277    ,   24869   ,0 };
            const std::uint32_t dim3365Kuo2Init[]       =   {   1   ,   3   ,   7   ,   1   ,   1   ,   29  ,   125 ,   205 ,   453 ,   607 ,   1371    ,   2169    ,   2723    ,   7381    ,   23411   ,0 };
            const std::uint32_t dim3366Kuo2Init[]       =   {   1   ,   3   ,   7   ,   13  ,   13  ,   57  ,   83  ,   149 ,   197 ,   739 ,   823 ,   1551    ,   5329    ,   10781   ,   6055    ,0 };
            const std::uint32_t dim3367Kuo2Init[]       =   {   1   ,   3   ,   7   ,   1   ,   5   ,   33  ,   9   ,   237 ,   37  ,   733 ,   879 ,   1303    ,   365 ,   5595    ,   32425   ,0 };
            const std::uint32_t dim3368Kuo2Init[]       =   {   1   ,   1   ,   1   ,   1   ,   17  ,   13  ,   117 ,   189 ,   323 ,   377 ,   1645    ,   2143    ,   4469    ,   9497    ,   11573   ,0 };
            const std::uint32_t dim3369Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   13  ,   47  ,   19  ,   19  ,   155 ,   681 ,   1909    ,   913 ,   6985    ,   11449   ,   9981    ,0 };
            const std::uint32_t dim3370Kuo2Init[]       =   {   1   ,   3   ,   7   ,   11  ,   29  ,   55  ,   73  ,   113 ,   291 ,   865 ,   239 ,   209 ,   67  ,   10813   ,   19287   ,0 };
            const std::uint32_t dim3371Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   3   ,   7   ,   27  ,   119 ,   267 ,   649 ,   1125    ,   2953    ,   3393    ,   3281    ,   15539   ,0 };
            const std::uint32_t dim3372Kuo2Init[]       =   {   1   ,   3   ,   3   ,   13  ,   9   ,   41  ,   25  ,   145 ,   233 ,   475 ,   873 ,   631 ,   2429    ,   12071   ,   18123   ,0 };
            const std::uint32_t dim3373Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   17  ,   53  ,   85  ,   71  ,   193 ,   339 ,   493 ,   2495    ,   4369    ,   7239    ,   21395   ,0 };
            const std::uint32_t dim3374Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   25  ,   51  ,   87  ,   11  ,   291 ,   659 ,   455 ,   1217    ,   5737    ,   3263    ,   15213   ,0 };
            const std::uint32_t dim3375Kuo2Init[]       =   {   1   ,   3   ,   1   ,   11  ,   5   ,   37  ,   93  ,   51  ,   359 ,   113 ,   1847    ,   4007    ,   2497    ,   12287   ,   16961   ,0 };
            const std::uint32_t dim3376Kuo2Init[]       =   {   1   ,   3   ,   5   ,   11  ,   1   ,   27  ,   107 ,   189 ,   353 ,   499 ,   395 ,   1717    ,   6313    ,   315 ,   17027   ,0 };
            const std::uint32_t dim3377Kuo2Init[]       =   {   1   ,   1   ,   3   ,   3   ,   15  ,   57  ,   105 ,   107 ,   17  ,   769 ,   1207    ,   3243    ,   179 ,   305 ,   16425   ,0 };
            const std::uint32_t dim3378Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   19  ,   9   ,   87  ,   5   ,   303 ,   653 ,   481 ,   1673    ,   3101    ,   7751    ,   23301   ,0 };
            const std::uint32_t dim3379Kuo2Init[]       =   {   1   ,   1   ,   5   ,   9   ,   31  ,   39  ,   67  ,   225 ,   287 ,   285 ,   1937    ,   413 ,   2101    ,   10941   ,   32071   ,0 };
            const std::uint32_t dim3380Kuo2Init[]       =   {   1   ,   3   ,   5   ,   5   ,   1   ,   25  ,   49  ,   61  ,   309 ,   19  ,   641 ,   247 ,   7909    ,   13761   ,   14231   ,0 };
            const std::uint32_t dim3381Kuo2Init[]       =   {   1   ,   1   ,   5   ,   5   ,   13  ,   31  ,   55  ,   141 ,   223 ,   573 ,   895 ,   2853    ,   5663    ,   15519   ,   10871   ,0 };
            const std::uint32_t dim3382Kuo2Init[]       =   {   1   ,   3   ,   3   ,   11  ,   31  ,   27  ,   61  ,   239 ,   215 ,   897 ,   857 ,   2591    ,   6251    ,   14317   ,   10973   ,0 };
            const std::uint32_t dim3383Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   29  ,   23  ,   115 ,   5   ,   449 ,   455 ,   1597    ,   3329    ,   4463    ,   10653   ,   17079   ,0 };
            const std::uint32_t dim3384Kuo2Init[]       =   {   1   ,   1   ,   1   ,   1   ,   31  ,   27  ,   25  ,   43  ,   99  ,   817 ,   1863    ,   1563    ,   7021    ,   4981    ,   5049    ,0 };
            const std::uint32_t dim3385Kuo2Init[]       =   {   1   ,   1   ,   7   ,   5   ,   1   ,   13  ,   95  ,   241 ,   269 ,   145 ,   737 ,   1479    ,   7469    ,   10069   ,   21421   ,0 };
            const std::uint32_t dim3386Kuo2Init[]       =   {   1   ,   1   ,   5   ,   5   ,   21  ,   47  ,   111 ,   153 ,   411 ,   763 ,   2003    ,   1809    ,   5887    ,   4543    ,   7505    ,0 };
            const std::uint32_t dim3387Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   1   ,   31  ,   75  ,   131 ,   103 ,   873 ,   1893    ,   2025    ,   6525    ,   57  ,   19701   ,0 };
            const std::uint32_t dim3388Kuo2Init[]       =   {   1   ,   1   ,   1   ,   7   ,   13  ,   3   ,   41  ,   243 ,   19  ,   1007    ,   365 ,   601 ,   7015    ,   485 ,   6313    ,0 };
            const std::uint32_t dim3389Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   9   ,   49  ,   27  ,   47  ,   139 ,   837 ,   43  ,   2843    ,   83  ,   9987    ,   29817   ,0 };
            const std::uint32_t dim3390Kuo2Init[]       =   {   1   ,   3   ,   7   ,   15  ,   27  ,   51  ,   95  ,   133 ,   275 ,   625 ,   1489    ,   4077    ,   3049    ,   15213   ,   23817   ,0 };
            const std::uint32_t dim3391Kuo2Init[]       =   {   1   ,   1   ,   1   ,   7   ,   1   ,   33  ,   101 ,   109 ,   131 ,   997 ,   101 ,   881 ,   3051    ,   1215    ,   4783    ,0 };
            const std::uint32_t dim3392Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   9   ,   7   ,   3   ,   223 ,   343 ,   467 ,   697 ,   3441    ,   4723    ,   4265    ,   29517   ,0 };
            const std::uint32_t dim3393Kuo2Init[]       =   {   1   ,   1   ,   7   ,   3   ,   17  ,   25  ,   97  ,   191 ,   413 ,   211 ,   263 ,   2027    ,   2025    ,   6125    ,   9667    ,0 };
            const std::uint32_t dim3394Kuo2Init[]       =   {   1   ,   1   ,   7   ,   11  ,   15  ,   15  ,   57  ,   151 ,   351 ,   187 ,   103 ,   1231    ,   567 ,   7829    ,   17941   ,0 };
            const std::uint32_t dim3395Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   13  ,   43  ,   49  ,   235 ,   195 ,   271 ,   1945    ,   1459    ,   2335    ,   141 ,   27615   ,0 };
            const std::uint32_t dim3396Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   5   ,   49  ,   123 ,   231 ,   133 ,   781 ,   697 ,   157 ,   2889    ,   12929   ,   18099   ,0 };
            const std::uint32_t dim3397Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   19  ,   25  ,   127 ,   181 ,   169 ,   981 ,   1955    ,   3289    ,   2077    ,   10627   ,   30383   ,0 };
            const std::uint32_t dim3398Kuo2Init[]       =   {   1   ,   3   ,   7   ,   9   ,   1   ,   53  ,   99  ,   163 ,   291 ,   701 ,   1367    ,   3941    ,   3211    ,   6661    ,   29143   ,0 };
            const std::uint32_t dim3399Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   7   ,   49  ,   83  ,   77  ,   9   ,   549 ,   705 ,   527 ,   5609    ,   10933   ,   27715   ,0 };
            const std::uint32_t dim3400Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   27  ,   15  ,   31  ,   75  ,   39  ,   823 ,   497 ,   875 ,   435 ,   14427   ,   30859   ,0 };
            const std::uint32_t dim3401Kuo2Init[]       =   {   1   ,   1   ,   7   ,   5   ,   21  ,   49  ,   63  ,   245 ,   357 ,   653 ,   45  ,   2053    ,   169 ,   7459    ,   2441    ,0 };
            const std::uint32_t dim3402Kuo2Init[]       =   {   1   ,   3   ,   1   ,   13  ,   7   ,   53  ,   109 ,   167 ,   243 ,   585 ,   1173    ,   1925    ,   601 ,   13899   ,   29  ,0 };
            const std::uint32_t dim3403Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   21  ,   1   ,   119 ,   33  ,   129 ,   893 ,   1047    ,   1223    ,   3335    ,   5711    ,   28213   ,0 };
            const std::uint32_t dim3404Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   21  ,   47  ,   97  ,   9   ,   201 ,   647 ,   1595    ,   3091    ,   3635    ,   15487   ,   21375   ,0 };
            const std::uint32_t dim3405Kuo2Init[]       =   {   1   ,   3   ,   1   ,   11  ,   11  ,   17  ,   11  ,   133 ,   447 ,   925 ,   97  ,   2841    ,   4147    ,   15803   ,   6311    ,0 };
            const std::uint32_t dim3406Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   13  ,   27  ,   27  ,   201 ,   105 ,   37  ,   399 ,   1695    ,   4263    ,   6081    ,   21461   ,0 };
            const std::uint32_t dim3407Kuo2Init[]       =   {   1   ,   1   ,   7   ,   5   ,   7   ,   25  ,   45  ,   83  ,   327 ,   283 ,   1799    ,   691 ,   2795    ,   12961   ,   125 ,0 };
            const std::uint32_t dim3408Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   23  ,   23  ,   11  ,   221 ,   189 ,   353 ,   887 ,   3087    ,   4937    ,   11335   ,   29193   ,0 };
            const std::uint32_t dim3409Kuo2Init[]       =   {   1   ,   1   ,   1   ,   9   ,   1   ,   47  ,   49  ,   141 ,   391 ,   661 ,   1289    ,   3937    ,   5833    ,   10731   ,   26501   ,0 };
            const std::uint32_t dim3410Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   21  ,   57  ,   89  ,   123 ,   163 ,   137 ,   1575    ,   4073    ,   7663    ,   13611   ,   11511   ,0 };
            const std::uint32_t dim3411Kuo2Init[]       =   {   1   ,   1   ,   7   ,   15  ,   17  ,   27  ,   27  ,   149 ,   67  ,   147 ,   1069    ,   353 ,   3323    ,   7763    ,   11549   ,0 };
            const std::uint32_t dim3412Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   19  ,   61  ,   11  ,   19  ,   403 ,   451 ,   737 ,   3107    ,   847 ,   13403   ,   25943   ,0 };
            const std::uint32_t dim3413Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   11  ,   55  ,   93  ,   185 ,   241 ,   807 ,   1017    ,   1707    ,   2745    ,   1923    ,   20451   ,0 };
            const std::uint32_t dim3414Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   25  ,   51  ,   125 ,   87  ,   275 ,   43  ,   65  ,   3327    ,   3313    ,   211 ,   24217   ,0 };
            const std::uint32_t dim3415Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   23  ,   9   ,   3   ,   207 ,   367 ,   939 ,   423 ,   3741    ,   4051    ,   2673    ,   25363   ,0 };
            const std::uint32_t dim3416Kuo2Init[]       =   {   1   ,   1   ,   1   ,   9   ,   5   ,   41  ,   47  ,   255 ,   359 ,   179 ,   365 ,   3037    ,   6377    ,   14293   ,   21925   ,0 };
            const std::uint32_t dim3417Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   31  ,   31  ,   97  ,   77  ,   479 ,   375 ,   491 ,   1101    ,   6717    ,   5499    ,   12693   ,0 };
            const std::uint32_t dim3418Kuo2Init[]       =   {   1   ,   1   ,   3   ,   1   ,   29  ,   55  ,   75  ,   209 ,   231 ,   15  ,   49  ,   3233    ,   3627    ,   11307   ,   11413   ,0 };
            const std::uint32_t dim3419Kuo2Init[]       =   {   1   ,   1   ,   7   ,   5   ,   13  ,   25  ,   105 ,   165 ,   15  ,   863 ,   827 ,   3691    ,   3531    ,   1487    ,   14615   ,0 };
            const std::uint32_t dim3420Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   19  ,   17  ,   51  ,   37  ,   349 ,   71  ,   31  ,   2545    ,   1151    ,   6187    ,   26835   ,0 };
            const std::uint32_t dim3421Kuo2Init[]       =   {   1   ,   3   ,   3   ,   13  ,   21  ,   43  ,   19  ,   81  ,   307 ,   751 ,   61  ,   3319    ,   2129    ,   9275    ,   18825   ,0 };
            const std::uint32_t dim3422Kuo2Init[]       =   {   1   ,   3   ,   7   ,   11  ,   11  ,   57  ,   117 ,   29  ,   189 ,   267 ,   31  ,   579 ,   6103    ,   10553   ,   15037   ,0 };
            const std::uint32_t dim3423Kuo2Init[]       =   {   1   ,   3   ,   3   ,   5   ,   7   ,   41  ,   101 ,   149 ,   43  ,   693 ,   797 ,   2447    ,   2973    ,   11177   ,   5795    ,0 };
            const std::uint32_t dim3424Kuo2Init[]       =   {   1   ,   1   ,   1   ,   15  ,   25  ,   55  ,   117 ,   207 ,   187 ,   211 ,   109 ,   3719    ,   8161    ,   8091    ,   8301    ,0 };
            const std::uint32_t dim3425Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   3   ,   27  ,   17  ,   61  ,   71  ,   555 ,   847 ,   1733    ,   6171    ,   6467    ,   2289    ,0 };
            const std::uint32_t dim3426Kuo2Init[]       =   {   1   ,   3   ,   7   ,   15  ,   31  ,   57  ,   103 ,   173 ,   127 ,   513 ,   2003    ,   1483    ,   3495    ,   1951    ,   30371   ,0 };
            const std::uint32_t dim3427Kuo2Init[]       =   {   1   ,   3   ,   7   ,   1   ,   13  ,   3   ,   107 ,   63  ,   77  ,   647 ,   1645    ,   2935    ,   4019    ,   595 ,   21603   ,0 };
            const std::uint32_t dim3428Kuo2Init[]       =   {   1   ,   3   ,   7   ,   15  ,   23  ,   23  ,   121 ,   51  ,   163 ,   321 ,   2005    ,   3873    ,   41  ,   15907   ,   26881   ,0 };
            const std::uint32_t dim3429Kuo2Init[]       =   {   1   ,   3   ,   1   ,   11  ,   27  ,   63  ,   1   ,   173 ,   423 ,   1023    ,   1123    ,   1683    ,   5395    ,   15017   ,   31877   ,0 };
            const std::uint32_t dim3430Kuo2Init[]       =   {   1   ,   1   ,   3   ,   1   ,   19  ,   19  ,   67  ,   121 ,   277 ,   409 ,   809 ,   4061    ,   6041    ,   2161    ,   13845   ,0 };
            const std::uint32_t dim3431Kuo2Init[]       =   {   1   ,   3   ,   7   ,   9   ,   13  ,   1   ,   111 ,   241 ,   193 ,   463 ,   1585    ,   2787    ,   2651    ,   4439    ,   27315   ,0 };
            const std::uint32_t dim3432Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   5   ,   1   ,   83  ,   213 ,   425 ,   623 ,   1709    ,   3523    ,   4547    ,   5827    ,   14637   ,0 };
            const std::uint32_t dim3433Kuo2Init[]       =   {   1   ,   1   ,   5   ,   9   ,   11  ,   43  ,   87  ,   31  ,   455 ,   559 ,   1117    ,   2541    ,   6381    ,   6333    ,   16025   ,0 };
            const std::uint32_t dim3434Kuo2Init[]       =   {   1   ,   1   ,   3   ,   11  ,   5   ,   61  ,   69  ,   115 ,   253 ,   743 ,   719 ,   3745    ,   3739    ,   5511    ,   12207   ,0 };
            const std::uint32_t dim3435Kuo2Init[]       =   {   1   ,   3   ,   7   ,   1   ,   31  ,   63  ,   11  ,   239 ,   217 ,   569 ,   749 ,   2445    ,   7183    ,   11169   ,   15683   ,0 };
            const std::uint32_t dim3436Kuo2Init[]       =   {   1   ,   1   ,   1   ,   13  ,   21  ,   47  ,   11  ,   187 ,   65  ,   19  ,   217 ,   2205    ,   5435    ,   14333   ,   8095    ,0 };
            const std::uint32_t dim3437Kuo2Init[]       =   {   1   ,   1   ,   5   ,   1   ,   15  ,   63  ,   81  ,   3   ,   291 ,   289 ,   1575    ,   3499    ,   5583    ,   16189   ,   14587   ,0 };
            const std::uint32_t dim3438Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   29  ,   1   ,   105 ,   195 ,   37  ,   875 ,   203 ,   3937    ,   3661    ,   1103    ,   569 ,0 };
            const std::uint32_t dim3439Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   25  ,   55  ,   7   ,   75  ,   185 ,   995 ,   569 ,   1861    ,   1149    ,   14763   ,   7581    ,0 };
            const std::uint32_t dim3440Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   13  ,   3   ,   107 ,   223 ,   273 ,   607 ,   1877    ,   3595    ,   3985    ,   1675    ,   9387    ,0 };
            const std::uint32_t dim3441Kuo2Init[]       =   {   1   ,   3   ,   7   ,   15  ,   15  ,   35  ,   57  ,   95  ,   99  ,   5   ,   351 ,   3767    ,   7617    ,   7071    ,   1465    ,0 };
            const std::uint32_t dim3442Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   13  ,   11  ,   19  ,   169 ,   381 ,   245 ,   99  ,   1121    ,   7127    ,   6145    ,   625 ,0 };
            const std::uint32_t dim3443Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   29  ,   13  ,   89  ,   81  ,   31  ,   827 ,   989 ,   445 ,   6361    ,   7953    ,   5035    ,0 };
            const std::uint32_t dim3444Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   5   ,   9   ,   21  ,   27  ,   321 ,   739 ,   557 ,   3953    ,   3739    ,   15215   ,   5467    ,0 };
            const std::uint32_t dim3445Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   9   ,   41  ,   111 ,   195 ,   385 ,   647 ,   829 ,   2109    ,   3313    ,   2457    ,   10925   ,0 };
            const std::uint32_t dim3446Kuo2Init[]       =   {   1   ,   3   ,   7   ,   1   ,   9   ,   47  ,   107 ,   15  ,   367 ,   385 ,   969 ,   1947    ,   1069    ,   6929    ,   16135   ,0 };
            const std::uint32_t dim3447Kuo2Init[]       =   {   1   ,   1   ,   5   ,   7   ,   31  ,   27  ,   19  ,   133 ,   413 ,   79  ,   1051    ,   173 ,   1033    ,   9609    ,   17485   ,0 };
            const std::uint32_t dim3448Kuo2Init[]       =   {   1   ,   1   ,   5   ,   9   ,   23  ,   19  ,   71  ,   135 ,   203 ,   659 ,   385 ,   771 ,   2053    ,   6803    ,   27443   ,0 };
            const std::uint32_t dim3449Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   5   ,   11  ,   15  ,   117 ,   353 ,   949 ,   1873    ,   3925    ,   6831    ,   12609   ,   20761   ,0 };
            const std::uint32_t dim3450Kuo2Init[]       =   {   1   ,   1   ,   5   ,   9   ,   13  ,   51  ,   111 ,   105 ,   75  ,   147 ,   543 ,   2177    ,   2595    ,   4397    ,   20075   ,0 };
            const std::uint32_t dim3451Kuo2Init[]       =   {   1   ,   3   ,   7   ,   1   ,   31  ,   41  ,   17  ,   81  ,   477 ,   143 ,   1671    ,   131 ,   3861    ,   7937    ,   12421   ,0 };
            const std::uint32_t dim3452Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   29  ,   55  ,   59  ,   141 ,   407 ,   287 ,   1205    ,   2349    ,   5033    ,   15907   ,   19857   ,0 };
            const std::uint32_t dim3453Kuo2Init[]       =   {   1   ,   3   ,   7   ,   11  ,   5   ,   7   ,   123 ,   183 ,   333 ,   547 ,   849 ,   3447    ,   2419    ,   6873    ,   16951   ,0 };
            const std::uint32_t dim3454Kuo2Init[]       =   {   1   ,   3   ,   7   ,   9   ,   9   ,   31  ,   63  ,   249 ,   211 ,   63  ,   1577    ,   235 ,   621 ,   4907    ,   25537   ,0 };
            const std::uint32_t dim3455Kuo2Init[]       =   {   1   ,   1   ,   1   ,   1   ,   13  ,   41  ,   1   ,   37  ,   455 ,   111 ,   1959    ,   1529    ,   4029    ,   10687   ,   17283   ,0 };
            const std::uint32_t dim3456Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   9   ,   31  ,   105 ,   63  ,   39  ,   409 ,   1151    ,   2631    ,   1491    ,   2837    ,   2489    ,0 };
            const std::uint32_t dim3457Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   23  ,   63  ,   61  ,   31  ,   229 ,   685 ,   1869    ,   3101    ,   4285    ,   4485    ,   15371   ,0 };
            const std::uint32_t dim3458Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   17  ,   1   ,   9   ,   149 ,   239 ,   393 ,   1925    ,   2111    ,   1035    ,   16343   ,   10655   ,0 };
            const std::uint32_t dim3459Kuo2Init[]       =   {   1   ,   1   ,   5   ,   15  ,   5   ,   35  ,   107 ,   155 ,   381 ,   119 ,   1157    ,   3875    ,   2647    ,   3149    ,   141 ,0 };
            const std::uint32_t dim3460Kuo2Init[]       =   {   1   ,   1   ,   3   ,   1   ,   31  ,   1   ,   123 ,   163 ,   337 ,   653 ,   659 ,   2011    ,   2613    ,   15469   ,   16925   ,0 };
            const std::uint32_t dim3461Kuo2Init[]       =   {   1   ,   1   ,   7   ,   5   ,   19  ,   51  ,   3   ,   17  ,   151 ,   705 ,   349 ,   3015    ,   7791    ,   9899    ,   30235   ,0 };
            const std::uint32_t dim3462Kuo2Init[]       =   {   1   ,   1   ,   3   ,   11  ,   25  ,   55  ,   51  ,   201 ,   511 ,   67  ,   857 ,   1233    ,   2813    ,   10031   ,   17433   ,0 };
            const std::uint32_t dim3463Kuo2Init[]       =   {   1   ,   1   ,   5   ,   9   ,   17  ,   3   ,   27  ,   193 ,   81  ,   765 ,   711 ,   2551    ,   2569    ,   9081    ,   9997    ,0 };
            const std::uint32_t dim3464Kuo2Init[]       =   {   1   ,   3   ,   1   ,   9   ,   17  ,   19  ,   51  ,   41  ,   249 ,   157 ,   989 ,   597 ,   6059    ,   7699    ,   14761   ,0 };
            const std::uint32_t dim3465Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   7   ,   3   ,   87  ,   101 ,   171 ,   287 ,   1259    ,   1161    ,   2765    ,   9293    ,   1343    ,0 };
            const std::uint32_t dim3466Kuo2Init[]       =   {   1   ,   3   ,   1   ,   11  ,   1   ,   49  ,   91  ,   179 ,   287 ,   661 ,   573 ,   255 ,   2873    ,   12153   ,   16505   ,0 };
            const std::uint32_t dim3467Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   27  ,   9   ,   101 ,   15  ,   173 ,   327 ,   1523    ,   3727    ,   6089    ,   195 ,   29999   ,0 };
            const std::uint32_t dim3468Kuo2Init[]       =   {   1   ,   3   ,   3   ,   13  ,   5   ,   17  ,   31  ,   61  ,   395 ,   451 ,   743 ,   2337    ,   7295    ,   2411    ,   31039   ,0 };
            const std::uint32_t dim3469Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   17  ,   25  ,   59  ,   209 ,   255 ,   401 ,   321 ,   1881    ,   4539    ,   5371    ,   25829   ,0 };
            const std::uint32_t dim3470Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   21  ,   15  ,   57  ,   11  ,   233 ,   13  ,   1969    ,   1839    ,   7923    ,   11731   ,   32641   ,0 };
            const std::uint32_t dim3471Kuo2Init[]       =   {   1   ,   1   ,   1   ,   15  ,   15  ,   11  ,   69  ,   179 ,   167 ,   867 ,   1901    ,   1113    ,   5613    ,   1481    ,   18975   ,0 };
            const std::uint32_t dim3472Kuo2Init[]       =   {   1   ,   3   ,   3   ,   11  ,   15  ,   61  ,   1   ,   35  ,   111 ,   347 ,   141 ,   2749    ,   2987    ,   5587    ,   12385   ,0 };
            const std::uint32_t dim3473Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   3   ,   41  ,   53  ,   101 ,   417 ,   729 ,   403 ,   2043    ,   453 ,   2479    ,   21141   ,0 };
            const std::uint32_t dim3474Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   3   ,   55  ,   47  ,   227 ,   331 ,   425 ,   1361    ,   1657    ,   7231    ,   727 ,   4093    ,0 };
            const std::uint32_t dim3475Kuo2Init[]       =   {   1   ,   1   ,   1   ,   1   ,   9   ,   37  ,   91  ,   207 ,   493 ,   463 ,   161 ,   3887    ,   543 ,   8349    ,   17949   ,0 };
            const std::uint32_t dim3476Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   25  ,   9   ,   89  ,   221 ,   293 ,   997 ,   969 ,   3239    ,   5147    ,   7173    ,   11277   ,0 };
            const std::uint32_t dim3477Kuo2Init[]       =   {   1   ,   1   ,   7   ,   3   ,   21  ,   29  ,   87  ,   7   ,   331 ,   939 ,   1919    ,   5   ,   113 ,   2189    ,   21471   ,0 };
            const std::uint32_t dim3478Kuo2Init[]       =   {   1   ,   3   ,   3   ,   5   ,   11  ,   47  ,   67  ,   119 ,   5   ,   357 ,   981 ,   4055    ,   6327    ,   13281   ,   185 ,0 };
            const std::uint32_t dim3479Kuo2Init[]       =   {   1   ,   3   ,   7   ,   13  ,   27  ,   55  ,   39  ,   23  ,   209 ,   721 ,   2043    ,   417 ,   655 ,   15333   ,   5015    ,0 };
            const std::uint32_t dim3480Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   27  ,   7   ,   95  ,   125 ,   9   ,   1001    ,   557 ,   2947    ,   553 ,   4991    ,   11517   ,0 };
            const std::uint32_t dim3481Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   3   ,   25  ,   5   ,   99  ,   355 ,   63  ,   1241    ,   2559    ,   4717    ,   9935    ,   19245   ,0 };
            const std::uint32_t dim3482Kuo2Init[]       =   {   1   ,   3   ,   1   ,   13  ,   3   ,   27  ,   45  ,   141 ,   123 ,   859 ,   603 ,   2495    ,   3815    ,   4229    ,   17501   ,0 };
            const std::uint32_t dim3483Kuo2Init[]       =   {   1   ,   3   ,   5   ,   3   ,   13  ,   53  ,   5   ,   157 ,   33  ,   493 ,   1611    ,   105 ,   7855    ,   12173   ,   6877    ,0 };
            const std::uint32_t dim3484Kuo2Init[]       =   {   1   ,   3   ,   7   ,   7   ,   13  ,   29  ,   89  ,   19  ,   267 ,   563 ,   645 ,   2637    ,   6889    ,   8283    ,   25807   ,0 };
            const std::uint32_t dim3485Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   23  ,   55  ,   89  ,   69  ,   363 ,   333 ,   377 ,   3109    ,   5125    ,   1411    ,   22499   ,0 };
            const std::uint32_t dim3486Kuo2Init[]       =   {   1   ,   1   ,   5   ,   3   ,   29  ,   5   ,   11  ,   151 ,   455 ,   667 ,   1697    ,   1087    ,   1147    ,   12269   ,   14291   ,0 };
            const std::uint32_t dim3487Kuo2Init[]       =   {   1   ,   3   ,   7   ,   11  ,   1   ,   29  ,   21  ,   209 ,   173 ,   719 ,   1679    ,   1637    ,   6835    ,   8629    ,   27391   ,0 };
            const std::uint32_t dim3488Kuo2Init[]       =   {   1   ,   3   ,   7   ,   7   ,   23  ,   47  ,   125 ,   145 ,   93  ,   425 ,   2039    ,   2665    ,   3219    ,   12491   ,   12731   ,0 };
            const std::uint32_t dim3489Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   19  ,   55  ,   99  ,   253 ,   39  ,   189 ,   559 ,   1893    ,   2155    ,   7165    ,   7705    ,0 };
            const std::uint32_t dim3490Kuo2Init[]       =   {   1   ,   1   ,   7   ,   15  ,   1   ,   63  ,   85  ,   9   ,   281 ,   551 ,   1697    ,   1341    ,   6039    ,   3315    ,   26821   ,0 };
            const std::uint32_t dim3491Kuo2Init[]       =   {   1   ,   3   ,   1   ,   15  ,   19  ,   29  ,   63  ,   221 ,   201 ,   671 ,   529 ,   1221    ,   4455    ,   2769    ,   941 ,0 };
            const std::uint32_t dim3492Kuo2Init[]       =   {   1   ,   3   ,   5   ,   11  ,   23  ,   17  ,   113 ,   167 ,   173 ,   17  ,   1911    ,   1995    ,   6459    ,   1517    ,   19169   ,0 };
            const std::uint32_t dim3493Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   23  ,   7   ,   77  ,   231 ,   157 ,   237 ,   1855    ,   2771    ,   7871    ,   13523   ,   18143   ,0 };
            const std::uint32_t dim3494Kuo2Init[]       =   {   1   ,   3   ,   5   ,   5   ,   17  ,   49  ,   59  ,   175 ,   269 ,   765 ,   1863    ,   3661    ,   4979    ,   7029    ,   4071    ,0 };
            const std::uint32_t dim3495Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   31  ,   53  ,   9   ,   89  ,   353 ,   557 ,   1805    ,   3153    ,   4761    ,   14547   ,   20487   ,0 };
            const std::uint32_t dim3496Kuo2Init[]       =   {   1   ,   1   ,   1   ,   15  ,   23  ,   45  ,   31  ,   151 ,   299 ,   745 ,   1899    ,   3113    ,   4177    ,   107 ,   28863   ,0 };
            const std::uint32_t dim3497Kuo2Init[]       =   {   1   ,   3   ,   7   ,   3   ,   5   ,   39  ,   21  ,   145 ,   487 ,   35  ,   1891    ,   3985    ,   2501    ,   16217   ,   11963   ,0 };
            const std::uint32_t dim3498Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   29  ,   7   ,   15  ,   207 ,   235 ,   789 ,   1195    ,   253 ,   6443    ,   8921    ,   26009   ,0 };
            const std::uint32_t dim3499Kuo2Init[]       =   {   1   ,   3   ,   1   ,   15  ,   23  ,   53  ,   105 ,   233 ,   71  ,   595 ,   765 ,   2383    ,   7959    ,   3543    ,   5795    ,0 };
            const std::uint32_t dim3500Kuo2Init[]       =   {   1   ,   3   ,   1   ,   9   ,   1   ,   13  ,   95  ,   113 ,   311 ,   839 ,   1375    ,   4083    ,   7621    ,   4261    ,   6067    ,0 };
            const std::uint32_t dim3501Kuo2Init[]       =   {   1   ,   1   ,   3   ,   1   ,   25  ,   41  ,   111 ,   185 ,   15  ,   779 ,   375 ,   927 ,   3487    ,   8293    ,   11101   ,0 };
            const std::uint32_t dim3502Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   3   ,   15  ,   79  ,   233 ,   255 ,   279 ,   171 ,   1659    ,   2131    ,   3659    ,   2381    ,0 };
            const std::uint32_t dim3503Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   21  ,   47  ,   19  ,   163 ,   481 ,   135 ,   875 ,   1143    ,   5929    ,   1269    ,   30729   ,0 };
            const std::uint32_t dim3504Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   15  ,   33  ,   45  ,   83  ,   345 ,   751 ,   2045    ,   3221    ,   3101    ,   8727    ,   3785    ,0 };
            const std::uint32_t dim3505Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   29  ,   49  ,   95  ,   83  ,   31  ,   433 ,   693 ,   2459    ,   3563    ,   12973   ,   17627   ,0 };
            const std::uint32_t dim3506Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   31  ,   19  ,   97  ,   165 ,   353 ,   109 ,   1957    ,   1493    ,   3025    ,   15721   ,   21733   ,0 };
            const std::uint32_t dim3507Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   17  ,   55  ,   23  ,   47  ,   473 ,   803 ,   1921    ,   2523    ,   6493    ,   1881    ,   2277    ,0 };
            const std::uint32_t dim3508Kuo2Init[]       =   {   1   ,   3   ,   7   ,   1   ,   11  ,   11  ,   27  ,   137 ,   259 ,   825 ,   1093    ,   305 ,   1289    ,   9177    ,   22177   ,0 };
            const std::uint32_t dim3509Kuo2Init[]       =   {   1   ,   1   ,   3   ,   3   ,   5   ,   13  ,   85  ,   191 ,   319 ,   533 ,   1579    ,   351 ,   987 ,   13229   ,   8727    ,0 };
            const std::uint32_t dim3510Kuo2Init[]       =   {   1   ,   3   ,   5   ,   11  ,   21  ,   21  ,   21  ,   107 ,   201 ,   281 ,   809 ,   2331    ,   1513    ,   10721   ,   31379   ,0 };
            const std::uint32_t dim3511Kuo2Init[]       =   {   1   ,   3   ,   3   ,   3   ,   1   ,   21  ,   55  ,   157 ,   487 ,   303 ,   891 ,   2035    ,   7329    ,   16203   ,   11811   ,0 };
            const std::uint32_t dim3512Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   3   ,   35  ,   91  ,   157 ,   501 ,   169 ,   1437    ,   1765    ,   395 ,   4991    ,   19543   ,0 };
            const std::uint32_t dim3513Kuo2Init[]       =   {   1   ,   3   ,   7   ,   7   ,   1   ,   43  ,   3   ,   33  ,   13  ,   393 ,   805 ,   1453    ,   6409    ,   3153    ,   3609    ,0 };
            const std::uint32_t dim3514Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   25  ,   57  ,   13  ,   189 ,   333 ,   639 ,   1241    ,   277 ,   3665    ,   16025   ,   12687   ,0 };
            const std::uint32_t dim3515Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   5   ,   31  ,   45  ,   93  ,   193 ,   469 ,   1325    ,   3109    ,   2115    ,   15903   ,   2211    ,0 };
            const std::uint32_t dim3516Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   9   ,   37  ,   125 ,   163 ,   75  ,   505 ,   383 ,   705 ,   2155    ,   15999   ,   29139   ,0 };
            const std::uint32_t dim3517Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   13  ,   33  ,   37  ,   101 ,   459 ,   943 ,   821 ,   975 ,   5511    ,   3923    ,   12037   ,0 };
            const std::uint32_t dim3518Kuo2Init[]       =   {   1   ,   3   ,   7   ,   3   ,   11  ,   45  ,   77  ,   79  ,   35  ,   289 ,   499 ,   2285    ,   1179    ,   953 ,   19641   ,0 };
            const std::uint32_t dim3519Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   21  ,   25  ,   27  ,   13  ,   49  ,   365 ,   2047    ,   3015    ,   6483    ,   15287   ,   21813   ,0 };
            const std::uint32_t dim3520Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   21  ,   5   ,   113 ,   215 ,   247 ,   377 ,   625 ,   2481    ,   7681    ,   343 ,   29051   ,0 };
            const std::uint32_t dim3521Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   17  ,   33  ,   85  ,   143 ,   97  ,   443 ,   2029    ,   2343    ,   2539    ,   6033    ,   23371   ,0 };
            const std::uint32_t dim3522Kuo2Init[]       =   {   1   ,   1   ,   7   ,   13  ,   31  ,   31  ,   59  ,   135 ,   415 ,   1015    ,   1295    ,   2477    ,   1119    ,   15633   ,   23699   ,0 };
            const std::uint32_t dim3523Kuo2Init[]       =   {   1   ,   3   ,   5   ,   3   ,   3   ,   23  ,   61  ,   135 ,   273 ,   501 ,   1245    ,   427 ,   6981    ,   12135   ,   15081   ,0 };
            const std::uint32_t dim3524Kuo2Init[]       =   {   1   ,   3   ,   7   ,   1   ,   15  ,   35  ,   15  ,   127 ,   57  ,   813 ,   1769    ,   1919    ,   659 ,   7051    ,   30567   ,0 };
            const std::uint32_t dim3525Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   31  ,   11  ,   85  ,   131 ,   483 ,   33  ,   1311    ,   1101    ,   3939    ,   8531    ,   21019   ,0 };
            const std::uint32_t dim3526Kuo2Init[]       =   {   1   ,   1   ,   5   ,   15  ,   17  ,   17  ,   127 ,   33  ,   111 ,   805 ,   1139    ,   2631    ,   7015    ,   11253   ,   13141   ,0 };
            const std::uint32_t dim3527Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   5   ,   5   ,   55  ,   223 ,   237 ,   641 ,   1081    ,   1145    ,   3773    ,   15829   ,   2309    ,0 };
            const std::uint32_t dim3528Kuo2Init[]       =   {   1   ,   1   ,   7   ,   3   ,   29  ,   35  ,   97  ,   197 ,   259 ,   665 ,   1101    ,   2423    ,   1689    ,   12363   ,   16037   ,0 };
            const std::uint32_t dim3529Kuo2Init[]       =   {   1   ,   1   ,   7   ,   15  ,   7   ,   59  ,   59  ,   199 ,   187 ,   83  ,   803 ,   1391    ,   6701    ,   8105    ,   22967   ,0 };
            const std::uint32_t dim3530Kuo2Init[]       =   {   1   ,   1   ,   5   ,   9   ,   1   ,   59  ,   91  ,   253 ,   277 ,   1019    ,   87  ,   3727    ,   3367    ,   13351   ,   10217   ,0 };
            const std::uint32_t dim3531Kuo2Init[]       =   {   1   ,   3   ,   3   ,   11  ,   19  ,   39  ,   35  ,   29  ,   259 ,   525 ,   555 ,   1683    ,   1885    ,   8957    ,   17431   ,0 };
            const std::uint32_t dim3532Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   3   ,   5   ,   99  ,   49  ,   19  ,   211 ,   135 ,   1677    ,   37  ,   14611   ,   25219   ,0 };
            const std::uint32_t dim3533Kuo2Init[]       =   {   1   ,   3   ,   7   ,   3   ,   15  ,   31  ,   3   ,   201 ,   329 ,   755 ,   1013    ,   1917    ,   785 ,   14243   ,   28877   ,0 };
            const std::uint32_t dim3534Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   3   ,   13  ,   113 ,   41  ,   123 ,   157 ,   165 ,   125 ,   5147    ,   10085   ,   13903   ,0 };
            const std::uint32_t dim3535Kuo2Init[]       =   {   1   ,   3   ,   7   ,   11  ,   15  ,   29  ,   127 ,   249 ,   51  ,   543 ,   667 ,   2401    ,   2623    ,   2447    ,   9471    ,0 };
            const std::uint32_t dim3536Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   7   ,   55  ,   127 ,   165 ,   235 ,   271 ,   1721    ,   2301    ,   1705    ,   8209    ,   10837   ,0 };
            const std::uint32_t dim3537Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   31  ,   27  ,   49  ,   13  ,   33  ,   797 ,   1533    ,   3325    ,   7257    ,   21  ,   16787   ,0 };
            const std::uint32_t dim3538Kuo2Init[]       =   {   1   ,   1   ,   3   ,   13  ,   17  ,   29  ,   43  ,   79  ,   219 ,   133 ,   15  ,   2707    ,   5517    ,   15923   ,   18125   ,0 };
            const std::uint32_t dim3539Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   21  ,   1   ,   61  ,   233 ,   123 ,   599 ,   201 ,   1431    ,   3637    ,   7921    ,   14069   ,0 };
            const std::uint32_t dim3540Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   1   ,   1   ,   113 ,   187 ,   189 ,   1013    ,   1085    ,   3693    ,   337 ,   9807    ,   25367   ,0 };
            const std::uint32_t dim3541Kuo2Init[]       =   {   1   ,   3   ,   3   ,   13  ,   11  ,   13  ,   125 ,   243 ,   77  ,   671 ,   177 ,   647 ,   1985    ,   15007   ,   27919   ,0 };
            const std::uint32_t dim3542Kuo2Init[]       =   {   1   ,   3   ,   7   ,   13  ,   23  ,   3   ,   85  ,   13  ,   15  ,   443 ,   673 ,   1   ,   8119    ,   16227   ,   4497    ,0 };
            const std::uint32_t dim3543Kuo2Init[]       =   {   1   ,   1   ,   3   ,   3   ,   5   ,   25  ,   113 ,   125 ,   503 ,   141 ,   945 ,   631 ,   6413    ,   2997    ,   28309   ,0 };
            const std::uint32_t dim3544Kuo2Init[]       =   {   1   ,   3   ,   5   ,   5   ,   15  ,   37  ,   7   ,   169 ,   423 ,   917 ,   485 ,   3557    ,   1093    ,   11613   ,   11301   ,0 };
            const std::uint32_t dim3545Kuo2Init[]       =   {   1   ,   1   ,   7   ,   3   ,   5   ,   35  ,   45  ,   99  ,   215 ,   537 ,   1055    ,   3109    ,   7745    ,   15741   ,   30499   ,0 };
            const std::uint32_t dim3546Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   19  ,   21  ,   37  ,   127 ,   83  ,   489 ,   1809    ,   2479    ,   5875    ,   2559    ,   13593   ,0 };
            const std::uint32_t dim3547Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   11  ,   31  ,   19  ,   111 ,   245 ,   619 ,   793 ,   453 ,   2557    ,   16269   ,   2823    ,0 };
            const std::uint32_t dim3548Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   31  ,   1   ,   99  ,   255 ,   187 ,   277 ,   71  ,   1985    ,   3919    ,   8445    ,   10791   ,0 };
            const std::uint32_t dim3549Kuo2Init[]       =   {   1   ,   3   ,   1   ,   11  ,   25  ,   1   ,   63  ,   5   ,   219 ,   601 ,   1155    ,   2411    ,   7673    ,   8979    ,   23729   ,0 };
            const std::uint32_t dim3550Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   31  ,   59  ,   11  ,   37  ,   361 ,   145 ,   879 ,   2655    ,   3591    ,   13615   ,   25559   ,0 };
            const std::uint32_t dim3551Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   15  ,   5   ,   117 ,   175 ,   417 ,   825 ,   585 ,   1429    ,   5163    ,   335 ,   32281   ,0 };
            const std::uint32_t dim3552Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   27  ,   9   ,   107 ,   181 ,   493 ,   651 ,   1317    ,   2059    ,   4155    ,   15039   ,   27693   ,0 };
            const std::uint32_t dim3553Kuo2Init[]       =   {   1   ,   3   ,   7   ,   3   ,   1   ,   11  ,   13  ,   187 ,   173 ,   991 ,   1743    ,   2403    ,   5279    ,   11387   ,   11035   ,0 };
            const std::uint32_t dim3554Kuo2Init[]       =   {   1   ,   3   ,   1   ,   11  ,   31  ,   39  ,   87  ,   63  ,   177 ,   581 ,   609 ,   3315    ,   4859    ,   9597    ,   29901   ,0 };
            const std::uint32_t dim3555Kuo2Init[]       =   {   1   ,   3   ,   3   ,   11  ,   15  ,   47  ,   1   ,   53  ,   91  ,   39  ,   37  ,   1697    ,   6719    ,   383 ,   1793    ,0 };
            const std::uint32_t dim3556Kuo2Init[]       =   {   1   ,   3   ,   5   ,   5   ,   7   ,   19  ,   123 ,   167 ,   509 ,   585 ,   1153    ,   1803    ,   987 ,   2633    ,   14177   ,0 };
            const std::uint32_t dim3557Kuo2Init[]       =   {   1   ,   1   ,   5   ,   7   ,   9   ,   5   ,   59  ,   137 ,   209 ,   95  ,   519 ,   177 ,   5627    ,   7843    ,   23207   ,0 };
            const std::uint32_t dim3558Kuo2Init[]       =   {   1   ,   1   ,   1   ,   15  ,   7   ,   3   ,   89  ,   31  ,   125 ,   391 ,   545 ,   3781    ,   985 ,   7355    ,   27935   ,0 };
            const std::uint32_t dim3559Kuo2Init[]       =   {   1   ,   3   ,   7   ,   3   ,   31  ,   11  ,   7   ,   147 ,   155 ,   421 ,   195 ,   861 ,   3787    ,   10843   ,   2239    ,0 };
            const std::uint32_t dim3560Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   23  ,   29  ,   71  ,   79  ,   279 ,   157 ,   853 ,   421 ,   6499    ,   7695    ,   5527    ,0 };
            const std::uint32_t dim3561Kuo2Init[]       =   {   1   ,   3   ,   3   ,   11  ,   3   ,   63  ,   49  ,   199 ,   5   ,   457 ,   479 ,   3419    ,   6649    ,   14259   ,   17789   ,0 };
            const std::uint32_t dim3562Kuo2Init[]       =   {   1   ,   1   ,   3   ,   3   ,   23  ,   7   ,   85  ,   105 ,   281 ,   929 ,   1487    ,   3797    ,   3487    ,   15959   ,   25859   ,0 };
            const std::uint32_t dim3563Kuo2Init[]       =   {   1   ,   3   ,   5   ,   5   ,   23  ,   27  ,   33  ,   5   ,   283 ,   853 ,   1939    ,   3745    ,   2995    ,   14715   ,   32739   ,0 };
            const std::uint32_t dim3564Kuo2Init[]       =   {   1   ,   3   ,   3   ,   5   ,   9   ,   7   ,   111 ,   53  ,   299 ,   237 ,   1263    ,   2053    ,   6359    ,   15617   ,   29347   ,0 };
            const std::uint32_t dim3565Kuo2Init[]       =   {   1   ,   3   ,   3   ,   13  ,   29  ,   61  ,   55  ,   181 ,   49  ,   377 ,   729 ,   117 ,   8125    ,   15317   ,   32363   ,0 };
            const std::uint32_t dim3566Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   9   ,   31  ,   77  ,   107 ,   21  ,   375 ,   1719    ,   1701    ,   5439    ,   4187    ,   32397   ,0 };
            const std::uint32_t dim3567Kuo2Init[]       =   {   1   ,   1   ,   3   ,   11  ,   31  ,   41  ,   101 ,   1   ,   171 ,   401 ,   1711    ,   3027    ,   161 ,   441 ,   15589   ,0 };
            const std::uint32_t dim3568Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   25  ,   35  ,   7   ,   85  ,   45  ,   409 ,   1769    ,   767 ,   2615    ,   1313    ,   7031    ,0 };
            const std::uint32_t dim3569Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   29  ,   7   ,   73  ,   25  ,   397 ,   767 ,   315 ,   2105    ,   4677    ,   12081   ,   7763    ,0 };
            const std::uint32_t dim3570Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   31  ,   63  ,   87  ,   29  ,   81  ,   969 ,   1931    ,   3713    ,   7217    ,   15899   ,   20505   ,0 };
            const std::uint32_t dim3571Kuo2Init[]       =   {   1   ,   1   ,   5   ,   3   ,   15  ,   31  ,   121 ,   141 ,   209 ,   697 ,   941 ,   1565    ,   1363    ,   11919   ,   24479   ,0 };
            const std::uint32_t dim3572Kuo2Init[]       =   {   1   ,   1   ,   7   ,   15  ,   23  ,   9   ,   5   ,   179 ,   437 ,   259 ,   1223    ,   2159    ,   4825    ,   2977    ,   20851   ,0 };
            const std::uint32_t dim3573Kuo2Init[]       =   {   1   ,   1   ,   1   ,   13  ,   13  ,   25  ,   33  ,   169 ,   91  ,   1001    ,   1931    ,   1853    ,   6173    ,   5411    ,   21081   ,0 };
            const std::uint32_t dim3574Kuo2Init[]       =   {   1   ,   1   ,   1   ,   13  ,   1   ,   53  ,   109 ,   53  ,   345 ,   519 ,   771 ,   1673    ,   6721    ,   3585    ,   6289    ,0 };
            const std::uint32_t dim3575Kuo2Init[]       =   {   1   ,   3   ,   3   ,   3   ,   27  ,   37  ,   77  ,   243 ,   207 ,   791 ,   1585    ,   1965    ,   3327    ,   4719    ,   7121    ,0 };
            const std::uint32_t dim3576Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   3   ,   15  ,   115 ,   175 ,   303 ,   59  ,   835 ,   3347    ,   6055    ,   4959    ,   6963    ,0 };
            const std::uint32_t dim3577Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   11  ,   5   ,   99  ,   139 ,   351 ,   709 ,   281 ,   2635    ,   379 ,   2543    ,   29879   ,0 };
            const std::uint32_t dim3578Kuo2Init[]       =   {   1   ,   3   ,   1   ,   11  ,   7   ,   9   ,   117 ,   209 ,   221 ,   667 ,   491 ,   2833    ,   1113    ,   12289   ,   7947    ,0 };
            const std::uint32_t dim3579Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   17  ,   11  ,   11  ,   43  ,   475 ,   169 ,   1167    ,   2601    ,   2733    ,   243 ,   17279   ,0 };
            const std::uint32_t dim3580Kuo2Init[]       =   {   1   ,   1   ,   5   ,   15  ,   31  ,   43  ,   7   ,   107 ,   309 ,   993 ,   635 ,   3779    ,   1041    ,   9997    ,   23049   ,0 };
            const std::uint32_t dim3581Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   21  ,   15  ,   21  ,   41  ,   451 ,   1021    ,   131 ,   1539    ,   7147    ,   1639    ,   31157   ,0 };
            const std::uint32_t dim3582Kuo2Init[]       =   {   1   ,   1   ,   3   ,   1   ,   25  ,   37  ,   67  ,   91  ,   463 ,   63  ,   653 ,   4045    ,   1255    ,   3315    ,   10747   ,0 };
            const std::uint32_t dim3583Kuo2Init[]       =   {   1   ,   1   ,   3   ,   3   ,   29  ,   3   ,   95  ,   125 ,   477 ,   845 ,   563 ,   3095    ,   2985    ,   8935    ,   23247   ,0 };
            const std::uint32_t dim3584Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   11  ,   5   ,   21  ,   193 ,   121 ,   857 ,   997 ,   3487    ,   4613    ,   12231   ,   7819    ,0 };
            const std::uint32_t dim3585Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   27  ,   1   ,   65  ,   219 ,   241 ,   99  ,   1193    ,   3157    ,   7641    ,   10327   ,   25241   ,0 };
            const std::uint32_t dim3586Kuo2Init[]       =   {   1   ,   3   ,   7   ,   1   ,   3   ,   25  ,   61  ,   191 ,   501 ,   219 ,   1863    ,   4039    ,   5879    ,   11203   ,   10581   ,0 };
            const std::uint32_t dim3587Kuo2Init[]       =   {   1   ,   1   ,   5   ,   3   ,   23  ,   39  ,   81  ,   37  ,   477 ,   969 ,   1   ,   1161    ,   7171    ,   3595    ,   375 ,0 };
            const std::uint32_t dim3588Kuo2Init[]       =   {   1   ,   3   ,   3   ,   3   ,   21  ,   17  ,   99  ,   101 ,   165 ,   849 ,   607 ,   1863    ,   6675    ,   13557   ,   3349    ,0 };
            const std::uint32_t dim3589Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   9   ,   1   ,   125 ,   93  ,   211 ,   971 ,   1275    ,   545 ,   3625    ,   1503    ,   10735   ,0 };
            const std::uint32_t dim3590Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   19  ,   53  ,   1   ,   169 ,   453 ,   227 ,   425 ,   2831    ,   6751    ,   11693   ,   20483   ,0 };
            const std::uint32_t dim3591Kuo2Init[]       =   {   1   ,   1   ,   1   ,   3   ,   9   ,   19  ,   121 ,   203 ,   55  ,   485 ,   37  ,   3977    ,   2193    ,   9819    ,   4635    ,0 };
            const std::uint32_t dim3592Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   17  ,   35  ,   121 ,   207 ,   233 ,   149 ,   1607    ,   3599    ,   1013    ,   2295    ,   9113    ,0 };
            const std::uint32_t dim3593Kuo2Init[]       =   {   1   ,   3   ,   3   ,   13  ,   29  ,   17  ,   39  ,   85  ,   47  ,   477 ,   1967    ,   701 ,   1063    ,   3521    ,   23583   ,0 };
            const std::uint32_t dim3594Kuo2Init[]       =   {   1   ,   3   ,   3   ,   3   ,   23  ,   57  ,   69  ,   49  ,   55  ,   81  ,   1195    ,   347 ,   3869    ,   4843    ,   97  ,0 };
            const std::uint32_t dim3595Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   9   ,   19  ,   31  ,   199 ,   173 ,   5   ,   1557    ,   2669    ,   5471    ,   7203    ,   27289   ,0 };
            const std::uint32_t dim3596Kuo2Init[]       =   {   1   ,   3   ,   3   ,   3   ,   3   ,   1   ,   121 ,   195 ,   193 ,   359 ,   1269    ,   973 ,   3443    ,   1669    ,   31895   ,0 };
            const std::uint32_t dim3597Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   3   ,   43  ,   39  ,   77  ,   149 ,   111 ,   425 ,   1567    ,   1289    ,   13443   ,   30175   ,0 };
            const std::uint32_t dim3598Kuo2Init[]       =   {   1   ,   3   ,   3   ,   5   ,   15  ,   55  ,   67  ,   209 ,   167 ,   439 ,   825 ,   3165    ,   6537    ,   10291   ,   2561    ,0 };
            const std::uint32_t dim3599Kuo2Init[]       =   {   1   ,   1   ,   5   ,   7   ,   1   ,   27  ,   49  ,   67  ,   123 ,   905 ,   759 ,   1471    ,   4379    ,   8211    ,   1829    ,0 };
            const std::uint32_t dim3600Kuo2Init[]       =   {   1   ,   1   ,   7   ,   13  ,   23  ,   7   ,   99  ,   169 ,   349 ,   889 ,   1671    ,   3039    ,   6757    ,   7071    ,   20707   ,0 };
            const std::uint32_t dim3601Kuo2Init[]       =   {   1   ,   3   ,   3   ,   5   ,   21  ,   59  ,   103 ,   167 ,   69  ,   77  ,   155 ,   301 ,   6647    ,   13487   ,   19241   ,0 };
            const std::uint32_t dim3602Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   5   ,   53  ,   19  ,   17  ,   239 ,   691 ,   1079    ,   3485    ,   4941    ,   1769    ,   6953    ,0 };
            const std::uint32_t dim3603Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   15  ,   37  ,   87  ,   137 ,   205 ,   743 ,   965 ,   3911    ,   1421    ,   3003    ,   26639   ,0 };
            const std::uint32_t dim3604Kuo2Init[]       =   {   1   ,   1   ,   5   ,   7   ,   31  ,   17  ,   49  ,   151 ,   159 ,   323 ,   1393    ,   1677    ,   2335    ,   289 ,   30059   ,0 };
            const std::uint32_t dim3605Kuo2Init[]       =   {   1   ,   1   ,   7   ,   11  ,   25  ,   37  ,   93  ,   221 ,   441 ,   329 ,   421 ,   903 ,   2803    ,   11455   ,   20521   ,0 };
            const std::uint32_t dim3606Kuo2Init[]       =   {   1   ,   3   ,   5   ,   3   ,   11  ,   1   ,   127 ,   231 ,   451 ,   333 ,   1501    ,   1353    ,   1741    ,   7149    ,   17527   ,0 };
            const std::uint32_t dim3607Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   25  ,   33  ,   101 ,   255 ,   69  ,   693 ,   1579    ,   2307    ,   6071    ,   6711    ,   20071   ,0 };
            const std::uint32_t dim3608Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   29  ,   61  ,   39  ,   31  ,   193 ,   573 ,   1151    ,   2237    ,   125 ,   7851    ,   29569   ,0 };
            const std::uint32_t dim3609Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   25  ,   15  ,   93  ,   93  ,   309 ,   765 ,   23  ,   2111    ,   7001    ,   3885    ,   18391   ,0 };
            const std::uint32_t dim3610Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   29  ,   9   ,   119 ,   165 ,   127 ,   847 ,   753 ,   4089    ,   5739    ,   10385   ,   28691   ,0 };
            const std::uint32_t dim3611Kuo2Init[]       =   {   1   ,   1   ,   1   ,   7   ,   5   ,   23  ,   41  ,   39  ,   429 ,   851 ,   1221    ,   3817    ,   8049    ,   14547   ,   9277    ,0 };
            const std::uint32_t dim3612Kuo2Init[]       =   {   1   ,   3   ,   7   ,   1   ,   7   ,   23  ,   105 ,   231 ,   241 ,   49  ,   1083    ,   3903    ,   1469    ,   11055   ,   27949   ,0 };
            const std::uint32_t dim3613Kuo2Init[]       =   {   1   ,   1   ,   7   ,   15  ,   9   ,   11  ,   127 ,   83  ,   425 ,   671 ,   657 ,   2431    ,   1003    ,   2997    ,   5593    ,0 };
            const std::uint32_t dim3614Kuo2Init[]       =   {   1   ,   3   ,   1   ,   13  ,   15  ,   35  ,   73  ,   193 ,   155 ,   183 ,   2033    ,   2385    ,   7979    ,   8551    ,   2507    ,0 };
            const std::uint32_t dim3615Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   29  ,   43  ,   59  ,   17  ,   227 ,   159 ,   1839    ,   4047    ,   1667    ,   2541    ,   30517   ,0 };
            const std::uint32_t dim3616Kuo2Init[]       =   {   1   ,   3   ,   7   ,   9   ,   31  ,   45  ,   109 ,   243 ,   163 ,   871 ,   951 ,   2463    ,   5573    ,   8415    ,   16857   ,0 };
            const std::uint32_t dim3617Kuo2Init[]       =   {   1   ,   3   ,   7   ,   7   ,   11  ,   57  ,   93  ,   243 ,   227 ,   863 ,   483 ,   2371    ,   6781    ,   6811    ,   23423   ,0 };
            const std::uint32_t dim3618Kuo2Init[]       =   {   1   ,   3   ,   1   ,   1   ,   13  ,   9   ,   113 ,   3   ,   207 ,   735 ,   1021    ,   1933    ,   6635    ,   13609   ,   19651   ,0 };
            const std::uint32_t dim3619Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   5   ,   33  ,   33  ,   159 ,   273 ,   291 ,   159 ,   1693    ,   217 ,   12487   ,   21853   ,0 };
            const std::uint32_t dim3620Kuo2Init[]       =   {   1   ,   3   ,   1   ,   13  ,   27  ,   51  ,   65  ,   117 ,   485 ,   471 ,   29  ,   3929    ,   4509    ,   13577   ,   6745    ,0 };
            const std::uint32_t dim3621Kuo2Init[]       =   {   1   ,   3   ,   3   ,   13  ,   5   ,   29  ,   23  ,   81  ,   353 ,   727 ,   1437    ,   3239    ,   717 ,   13857   ,   18881   ,0 };
            const std::uint32_t dim3622Kuo2Init[]       =   {   1   ,   3   ,   1   ,   1   ,   11  ,   41  ,   97  ,   73  ,   271 ,   847 ,   471 ,   2857    ,   691 ,   10951   ,   31465   ,0 };
            const std::uint32_t dim3623Kuo2Init[]       =   {   1   ,   1   ,   1   ,   9   ,   11  ,   59  ,   3   ,   71  ,   235 ,   715 ,   1349    ,   199 ,   2853    ,   13641   ,   5025    ,0 };
            const std::uint32_t dim3624Kuo2Init[]       =   {   1   ,   3   ,   1   ,   9   ,   23  ,   7   ,   23  ,   49  ,   31  ,   145 ,   533 ,   2625    ,   207 ,   3661    ,   25215   ,0 };
            const std::uint32_t dim3625Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   17  ,   17  ,   53  ,   129 ,   105 ,   285 ,   1423    ,   3985    ,   8015    ,   3565    ,   24495   ,0 };
            const std::uint32_t dim3626Kuo2Init[]       =   {   1   ,   1   ,   1   ,   13  ,   7   ,   29  ,   93  ,   123 ,   167 ,   845 ,   69  ,   2297    ,   543 ,   9165    ,   4029    ,0 };
            const std::uint32_t dim3627Kuo2Init[]       =   {   1   ,   3   ,   7   ,   15  ,   19  ,   57  ,   71  ,   99  ,   95  ,   165 ,   1875    ,   4011    ,   4779    ,   4057    ,   16331   ,0 };
            const std::uint32_t dim3628Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   19  ,   43  ,   45  ,   83  ,   383 ,   111 ,   1859    ,   2767    ,   1469    ,   3687    ,   18343   ,0 };
            const std::uint32_t dim3629Kuo2Init[]       =   {   1   ,   1   ,   5   ,   1   ,   11  ,   7   ,   63  ,   51  ,   487 ,   609 ,   1619    ,   3399    ,   1   ,   7253    ,   24325   ,0 };
            const std::uint32_t dim3630Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   29  ,   27  ,   83  ,   61  ,   353 ,   913 ,   1359    ,   689 ,   7741    ,   3357    ,   7731    ,0 };
            const std::uint32_t dim3631Kuo2Init[]       =   {   1   ,   1   ,   1   ,   7   ,   31  ,   9   ,   5   ,   221 ,   177 ,   379 ,   1953    ,   3389    ,   3861    ,   10265   ,   1347    ,0 };
            const std::uint32_t dim3632Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   7   ,   13  ,   57  ,   9   ,   233 ,   601 ,   719 ,   1855    ,   6481    ,   9987    ,   16463   ,0 };
            const std::uint32_t dim3633Kuo2Init[]       =   {   1   ,   1   ,   3   ,   1   ,   15  ,   27  ,   67  ,   211 ,   289 ,   969 ,   1719    ,   2329    ,   3665    ,   7133    ,   24645   ,0 };
            const std::uint32_t dim3634Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   21  ,   37  ,   63  ,   11  ,   19  ,   797 ,   1591    ,   2037    ,   7731    ,   12533   ,   2799    ,0 };
            const std::uint32_t dim3635Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   15  ,   37  ,   1   ,   123 ,   209 ,   321 ,   737 ,   837 ,   561 ,   2631    ,   18547   ,0 };
            const std::uint32_t dim3636Kuo2Init[]       =   {   1   ,   3   ,   1   ,   1   ,   13  ,   33  ,   27  ,   119 ,   407 ,   675 ,   903 ,   2229    ,   1963    ,   3857    ,   5795    ,0 };
            const std::uint32_t dim3637Kuo2Init[]       =   {   1   ,   1   ,   5   ,   5   ,   9   ,   31  ,   25  ,   115 ,   471 ,   353 ,   113 ,   3297    ,   87  ,   9413    ,   25209   ,0 };
            const std::uint32_t dim3638Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   23  ,   27  ,   29  ,   95  ,   387 ,   747 ,   155 ,   3991    ,   3505    ,   975 ,   6371    ,0 };
            const std::uint32_t dim3639Kuo2Init[]       =   {   1   ,   1   ,   5   ,   13  ,   15  ,   45  ,   3   ,   213 ,   299 ,   775 ,   525 ,   2639    ,   491 ,   12039   ,   20295   ,0 };
            const std::uint32_t dim3640Kuo2Init[]       =   {   1   ,   1   ,   7   ,   15  ,   5   ,   47  ,   59  ,   131 ,   165 ,   93  ,   583 ,   3823    ,   7781    ,   16339   ,   16523   ,0 };
            const std::uint32_t dim3641Kuo2Init[]       =   {   1   ,   3   ,   5   ,   3   ,   25  ,   61  ,   23  ,   75  ,   343 ,   15  ,   347 ,   259 ,   4621    ,   8275    ,   10323   ,0 };
            const std::uint32_t dim3642Kuo2Init[]       =   {   1   ,   3   ,   3   ,   13  ,   7   ,   25  ,   1   ,   153 ,   199 ,   225 ,   1217    ,   161 ,   1185    ,   10775   ,   6709    ,0 };
            const std::uint32_t dim3643Kuo2Init[]       =   {   1   ,   1   ,   1   ,   1   ,   1   ,   49  ,   27  ,   67  ,   411 ,   425 ,   1385    ,   3921    ,   6373    ,   14581   ,   25159   ,0 };
            const std::uint32_t dim3644Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   5   ,   59  ,   125 ,   239 ,   391 ,   823 ,   969 ,   3287    ,   7257    ,   5405    ,   15  ,0 };
            const std::uint32_t dim3645Kuo2Init[]       =   {   1   ,   1   ,   5   ,   1   ,   1   ,   17  ,   109 ,   145 ,   289 ,   601 ,   1539    ,   807 ,   1123    ,   14541   ,   15885   ,0 };
            const std::uint32_t dim3646Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   23  ,   29  ,   119 ,   79  ,   253 ,   921 ,   1935    ,   4047    ,   7639    ,   10419   ,   26597   ,0 };
            const std::uint32_t dim3647Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   27  ,   53  ,   63  ,   123 ,   85  ,   121 ,   481 ,   3581    ,   4545    ,   7275    ,   981 ,0 };
            const std::uint32_t dim3648Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   27  ,   5   ,   43  ,   247 ,   299 ,   411 ,   299 ,   2545    ,   4403    ,   9903    ,   16161   ,0 };
            const std::uint32_t dim3649Kuo2Init[]       =   {   1   ,   3   ,   1   ,   11  ,   29  ,   21  ,   83  ,   37  ,   425 ,   741 ,   899 ,   3643    ,   6641    ,   5241    ,   3627    ,0 };
            const std::uint32_t dim3650Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   11  ,   23  ,   43  ,   191 ,   225 ,   101 ,   1423    ,   927 ,   1303    ,   15417   ,   25553   ,0 };
            const std::uint32_t dim3651Kuo2Init[]       =   {   1   ,   3   ,   1   ,   1   ,   23  ,   47  ,   103 ,   177 ,   437 ,   113 ,   295 ,   699 ,   1225    ,   8259    ,   19469   ,0 };
            const std::uint32_t dim3652Kuo2Init[]       =   {   1   ,   1   ,   7   ,   3   ,   13  ,   61  ,   119 ,   231 ,   33  ,   217 ,   1419    ,   989 ,   4413    ,   9171    ,   1199    ,0 };
            const std::uint32_t dim3653Kuo2Init[]       =   {   1   ,   1   ,   1   ,   1   ,   5   ,   13  ,   87  ,   185 ,   69  ,   471 ,   1665    ,   2201    ,   5889    ,   7931    ,   2913    ,0 };
            const std::uint32_t dim3654Kuo2Init[]       =   {   1   ,   1   ,   1   ,   15  ,   17  ,   7   ,   111 ,   27  ,   91  ,   127 ,   301 ,   3641    ,   561 ,   6697    ,   16767   ,0 };
            const std::uint32_t dim3655Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   11  ,   25  ,   127 ,   139 ,   355 ,   475 ,   821 ,   843 ,   493 ,   2713    ,   16877   ,0 };
            const std::uint32_t dim3656Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   27  ,   19  ,   51  ,   127 ,   211 ,   869 ,   339 ,   2469    ,   1515    ,   9007    ,   28807   ,0 };
            const std::uint32_t dim3657Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   15  ,   23  ,   79  ,   49  ,   185 ,   465 ,   1165    ,   1103    ,   5975    ,   13867   ,   30039   ,0 };
            const std::uint32_t dim3658Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   27  ,   41  ,   49  ,   195 ,   23  ,   441 ,   1225    ,   3861    ,   6661    ,   7261    ,   25415   ,0 };
            const std::uint32_t dim3659Kuo2Init[]       =   {   1   ,   1   ,   3   ,   3   ,   27  ,   41  ,   57  ,   139 ,   87  ,   403 ,   1351    ,   2063    ,   5445    ,   4559    ,   7181    ,0 };
            const std::uint32_t dim3660Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   7   ,   35  ,   43  ,   177 ,   63  ,   1021    ,   1157    ,   3831    ,   1515    ,   8117    ,   16567   ,0 };
            const std::uint32_t dim3661Kuo2Init[]       =   {   1   ,   3   ,   7   ,   9   ,   5   ,   47  ,   59  ,   221 ,   415 ,   541 ,   857 ,   257 ,   6961    ,   16349   ,   28975   ,0 };
            const std::uint32_t dim3662Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   13  ,   55  ,   55  ,   63  ,   7   ,   817 ,   693 ,   1183    ,   7417    ,   7087    ,   31173   ,0 };
            const std::uint32_t dim3663Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   1   ,   29  ,   17  ,   15  ,   417 ,   559 ,   155 ,   495 ,   6269    ,   11163   ,   15073   ,0 };
            const std::uint32_t dim3664Kuo2Init[]       =   {   1   ,   1   ,   5   ,   1   ,   29  ,   59  ,   49  ,   253 ,   489 ,   657 ,   1723    ,   1969    ,   471 ,   10821   ,   3527    ,0 };
            const std::uint32_t dim3665Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   29  ,   33  ,   121 ,   9   ,   73  ,   33  ,   89  ,   3419    ,   6491    ,   5361    ,   31587   ,0 };
            const std::uint32_t dim3666Kuo2Init[]       =   {   1   ,   3   ,   3   ,   5   ,   1   ,   49  ,   121 ,   25  ,   481 ,   813 ,   607 ,   757 ,   5493    ,   4353    ,   14355   ,0 };
            const std::uint32_t dim3667Kuo2Init[]       =   {   1   ,   1   ,   1   ,   1   ,   21  ,   45  ,   61  ,   101 ,   357 ,   875 ,   1381    ,   1731    ,   6505    ,   12891   ,   19595   ,   54305   ,0 };
            const std::uint32_t dim3668Kuo2Init[]       =   {   1   ,   3   ,   7   ,   7   ,   19  ,   55  ,   99  ,   131 ,   309 ,   303 ,   1575    ,   3241    ,   6799    ,   6543    ,   26973   ,   46843   ,0 };
            const std::uint32_t dim3669Kuo2Init[]       =   {   1   ,   1   ,   3   ,   3   ,   27  ,   11  ,   63  ,   237 ,   13  ,   949 ,   1359    ,   1563    ,   5501    ,   5293    ,   923 ,   3413    ,0 };
            const std::uint32_t dim3670Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   13  ,   55  ,   117 ,   143 ,   225 ,   161 ,   805 ,   3259    ,   4113    ,   8457    ,   461 ,   55507   ,0 };
            const std::uint32_t dim3671Kuo2Init[]       =   {   1   ,   1   ,   1   ,   15  ,   15  ,   57  ,   127 ,   249 ,   409 ,   885 ,   587 ,   285 ,   7087    ,   11613   ,   725 ,   61955   ,0 };
            const std::uint32_t dim3672Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   21  ,   5   ,   127 ,   179 ,   193 ,   683 ,   2045    ,   2555    ,   6707    ,   63  ,   815 ,   57953   ,0 };
            const std::uint32_t dim3673Kuo2Init[]       =   {   1   ,   3   ,   7   ,   7   ,   25  ,   45  ,   49  ,   37  ,   289 ,   431 ,   719 ,   3071    ,   7343    ,   1377    ,   18515   ,   33777   ,0 };
            const std::uint32_t dim3674Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   19  ,   5   ,   127 ,   29  ,   385 ,   895 ,   1951    ,   3817    ,   3277    ,   7677    ,   19781   ,   31181   ,0 };
            const std::uint32_t dim3675Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   19  ,   25  ,   105 ,   123 ,   445 ,   923 ,   801 ,   455 ,   955 ,   5529    ,   29133   ,   47531   ,0 };
            const std::uint32_t dim3676Kuo2Init[]       =   {   1   ,   1   ,   3   ,   11  ,   1   ,   15  ,   51  ,   5   ,   27  ,   335 ,   523 ,   2859    ,   5605    ,   15197   ,   14669   ,   29623   ,0 };
            const std::uint32_t dim3677Kuo2Init[]       =   {   1   ,   1   ,   3   ,   1   ,   11  ,   53  ,   97  ,   229 ,   477 ,   991 ,   749 ,   607 ,   6833    ,   6817    ,   2397    ,   31543   ,0 };
            const std::uint32_t dim3678Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   9   ,   45  ,   123 ,   201 ,   129 ,   587 ,   1373    ,   3733    ,   2331    ,   9741    ,   29441   ,   24711   ,0 };
            const std::uint32_t dim3679Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   1   ,   53  ,   29  ,   99  ,   475 ,   227 ,   1955    ,   351 ,   2583    ,   2335    ,   1821    ,   21105   ,0 };
            const std::uint32_t dim3680Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   13  ,   7   ,   121 ,   121 ,   163 ,   325 ,   13  ,   779 ,   4173    ,   7285    ,   26205   ,   19693   ,0 };
            const std::uint32_t dim3681Kuo2Init[]       =   {   1   ,   1   ,   3   ,   13  ,   17  ,   23  ,   23  ,   167 ,   131 ,   821 ,   933 ,   1919    ,   853 ,   7525    ,   8195    ,   7357    ,0 };
            const std::uint32_t dim3682Kuo2Init[]       =   {   1   ,   1   ,   5   ,   9   ,   21  ,   29  ,   97  ,   105 ,   85  ,   865 ,   459 ,   1405    ,   5767    ,   8379    ,   23397   ,   35269   ,0 };
            const std::uint32_t dim3683Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   7   ,   41  ,   125 ,   107 ,   507 ,   323 ,   149 ,   3475    ,   1149    ,   8811    ,   8295    ,   20543   ,0 };
            const std::uint32_t dim3684Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   13  ,   35  ,   41  ,   249 ,   195 ,   603 ,   873 ,   3825    ,   1679    ,   11727   ,   13839   ,   22241   ,0 };
            const std::uint32_t dim3685Kuo2Init[]       =   {   1   ,   3   ,   5   ,   3   ,   13  ,   15  ,   19  ,   113 ,   141 ,   7   ,   627 ,   1285    ,   6701    ,   15921   ,   4235    ,   30879   ,0 };
            const std::uint32_t dim3686Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   15  ,   57  ,   65  ,   239 ,   49  ,   657 ,   673 ,   4039    ,   5493    ,   2487    ,   1807    ,   14341   ,0 };
            const std::uint32_t dim3687Kuo2Init[]       =   {   1   ,   1   ,   1   ,   13  ,   25  ,   47  ,   19  ,   191 ,   177 ,   163 ,   1721    ,   3473    ,   6667    ,   10017   ,   19863   ,   43803   ,0 };
            const std::uint32_t dim3688Kuo2Init[]       =   {   1   ,   3   ,   5   ,   11  ,   15  ,   39  ,   33  ,   95  ,   353 ,   121 ,   503 ,   3025    ,   4773    ,   3853    ,   14263   ,   61149   ,0 };
            const std::uint32_t dim3689Kuo2Init[]       =   {   1   ,   1   ,   5   ,   3   ,   1   ,   57  ,   7   ,   105 ,   363 ,   797 ,   635 ,   23  ,   1795    ,   13501   ,   45  ,   22081   ,0 };
            const std::uint32_t dim3690Kuo2Init[]       =   {   1   ,   3   ,   7   ,   15  ,   19  ,   21  ,   9   ,   237 ,   249 ,   641 ,   1599    ,   3623    ,   2941    ,   12917   ,   5511    ,   18017   ,0 };
            const std::uint32_t dim3691Kuo2Init[]       =   {   1   ,   1   ,   5   ,   9   ,   17  ,   57  ,   81  ,   165 ,   315 ,   985 ,   1965    ,   3571    ,   2693    ,   11591   ,   13675   ,   36739   ,0 };
            const std::uint32_t dim3692Kuo2Init[]       =   {   1   ,   1   ,   7   ,   15  ,   5   ,   3   ,   11  ,   247 ,   79  ,   707 ,   1601    ,   2301    ,   7281    ,   4871    ,   26735   ,   14277   ,0 };
            const std::uint32_t dim3693Kuo2Init[]       =   {   1   ,   1   ,   5   ,   7   ,   17  ,   27  ,   101 ,   211 ,   507 ,   95  ,   1333    ,   2919    ,   1251    ,   3905    ,   1897    ,   12791   ,0 };
            const std::uint32_t dim3694Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   29  ,   15  ,   119 ,   3   ,   181 ,   621 ,   349 ,   2509    ,   295 ,   15719   ,   1593    ,   27333   ,0 };
            const std::uint32_t dim3695Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   9   ,   29  ,   75  ,   245 ,   353 ,   147 ,   1197    ,   2571    ,   7033    ,   15903   ,   28319   ,   7733    ,0 };
            const std::uint32_t dim3696Kuo2Init[]       =   {   1   ,   1   ,   7   ,   11  ,   19  ,   23  ,   53  ,   41  ,   377 ,   673 ,   1843    ,   1283    ,   1343    ,   2089    ,   12295   ,   33189   ,0 };
            const std::uint32_t dim3697Kuo2Init[]       =   {   1   ,   1   ,   1   ,   9   ,   17  ,   21  ,   17  ,   251 ,   399 ,   531 ,   2007    ,   3449    ,   265 ,   289 ,   15937   ,   19571   ,0 };
            const std::uint32_t dim3698Kuo2Init[]       =   {   1   ,   1   ,   5   ,   15  ,   15  ,   53  ,   21  ,   141 ,   387 ,   885 ,   1409    ,   2883    ,   2101    ,   4741    ,   597 ,   23435   ,0 };
            const std::uint32_t dim3699Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   27  ,   63  ,   33  ,   157 ,   331 ,   921 ,   1097    ,   3963    ,   3275    ,   14909   ,   2359    ,   12327   ,0 };
            const std::uint32_t dim3700Kuo2Init[]       =   {   1   ,   1   ,   3   ,   11  ,   15  ,   7   ,   121 ,   235 ,   219 ,   181 ,   1305    ,   3877    ,   2233    ,   4921    ,   31409   ,   28211   ,0 };
            const std::uint32_t dim3701Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   23  ,   25  ,   67  ,   147 ,   211 ,   757 ,   1903    ,   3077    ,   3931    ,   11885   ,   3053    ,   45709   ,0 };
            const std::uint32_t dim3702Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   29  ,   21  ,   121 ,   115 ,   231 ,   957 ,   203 ,   689 ,   5521    ,   2467    ,   21489   ,   10057   ,0 };
            const std::uint32_t dim3703Kuo2Init[]       =   {   1   ,   1   ,   5   ,   9   ,   15  ,   17  ,   11  ,   177 ,   319 ,   547 ,   801 ,   3899    ,   5919    ,   8785    ,   12019   ,   2535    ,0 };
            const std::uint32_t dim3704Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   21  ,   51  ,   83  ,   121 ,   317 ,   715 ,   467 ,   3587    ,   383 ,   3519    ,   26731   ,   64151   ,0 };
            const std::uint32_t dim3705Kuo2Init[]       =   {   1   ,   3   ,   3   ,   13  ,   31  ,   47  ,   41  ,   247 ,   211 ,   333 ,   691 ,   2679    ,   4599    ,   2479    ,   27687   ,   45793   ,0 };
            const std::uint32_t dim3706Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   31  ,   9   ,   41  ,   241 ,   439 ,   391 ,   949 ,   2957    ,   5105    ,   5073    ,   7607    ,   4809    ,0 };
            const std::uint32_t dim3707Kuo2Init[]       =   {   1   ,   1   ,   1   ,   9   ,   5   ,   57  ,   11  ,   167 ,   193 ,   1019    ,   533 ,   2559    ,   3899    ,   15199   ,   13723   ,   1909    ,0 };
            const std::uint32_t dim3708Kuo2Init[]       =   {   1   ,   3   ,   3   ,   3   ,   5   ,   17  ,   5   ,   21  ,   445 ,   857 ,   2017    ,   2759    ,   5011    ,   8415    ,   881 ,   15747   ,0 };
            const std::uint32_t dim3709Kuo2Init[]       =   {   1   ,   1   ,   1   ,   1   ,   1   ,   25  ,   31  ,   61  ,   407 ,   71  ,   263 ,   681 ,   5325    ,   13747   ,   10833   ,   12191   ,0 };
            const std::uint32_t dim3710Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   27  ,   3   ,   73  ,   145 ,   5   ,   851 ,   1519    ,   2809    ,   5857    ,   2327    ,   32659   ,   11145   ,0 };
            const std::uint32_t dim3711Kuo2Init[]       =   {   1   ,   3   ,   3   ,   5   ,   21  ,   3   ,   47  ,   11  ,   17  ,   1023    ,   621 ,   3527    ,   613 ,   5607    ,   19377   ,   49671   ,0 };
            const std::uint32_t dim3712Kuo2Init[]       =   {   1   ,   3   ,   1   ,   11  ,   5   ,   5   ,   57  ,   39  ,   221 ,   847 ,   735 ,   3951    ,   6661    ,   13959   ,   16735   ,   26471   ,0 };
            const std::uint32_t dim3713Kuo2Init[]       =   {   1   ,   3   ,   1   ,   11  ,   3   ,   31  ,   15  ,   121 ,   31  ,   689 ,   151 ,   849 ,   2859    ,   14903   ,   6065    ,   9203    ,0 };
            const std::uint32_t dim3714Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   5   ,   63  ,   27  ,   51  ,   379 ,   657 ,   1381    ,   67  ,   2733    ,   7673    ,   13217   ,   14265   ,0 };
            const std::uint32_t dim3715Kuo2Init[]       =   {   1   ,   1   ,   7   ,   15  ,   27  ,   63  ,   21  ,   25  ,   315 ,   101 ,   851 ,   2585    ,   4423    ,   7857    ,   30561   ,   60301   ,0 };
            const std::uint32_t dim3716Kuo2Init[]       =   {   1   ,   3   ,   3   ,   11  ,   21  ,   51  ,   9   ,   39  ,   123 ,   763 ,   1777    ,   3427    ,   5071    ,   7905    ,   1017    ,   15373   ,0 };
            const std::uint32_t dim3717Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   25  ,   59  ,   3   ,   223 ,   71  ,   33  ,   731 ,   2303    ,   7153    ,   12847   ,   9707    ,   50871   ,0 };
            const std::uint32_t dim3718Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   31  ,   61  ,   13  ,   155 ,   467 ,   501 ,   371 ,   1447    ,   7925    ,   13135   ,   27629   ,   45097   ,0 };
            const std::uint32_t dim3719Kuo2Init[]       =   {   1   ,   1   ,   1   ,   1   ,   13  ,   25  ,   35  ,   153 ,   333 ,   9   ,   1609    ,   539 ,   5029    ,   2059    ,   3547    ,   55407   ,0 };
            const std::uint32_t dim3720Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   21  ,   55  ,   101 ,   199 ,   279 ,   77  ,   1337    ,   3503    ,   2365    ,   4969    ,   2411    ,   16853   ,0 };
            const std::uint32_t dim3721Kuo2Init[]       =   {   1   ,   1   ,   7   ,   11  ,   29  ,   9   ,   111 ,   63  ,   435 ,   445 ,   1711    ,   3981    ,   6517    ,   14593   ,   29433   ,   31027   ,0 };
            const std::uint32_t dim3722Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   15  ,   57  ,   43  ,   137 ,   189 ,   83  ,   187 ,   417 ,   3425    ,   14653   ,   17805   ,   57685   ,0 };
            const std::uint32_t dim3723Kuo2Init[]       =   {   1   ,   1   ,   5   ,   3   ,   27  ,   23  ,   71  ,   65  ,   399 ,   605 ,   421 ,   463 ,   2019    ,   10707   ,   26201   ,   23573   ,0 };
            const std::uint32_t dim3724Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   17  ,   57  ,   119 ,   125 ,   365 ,   681 ,   1967    ,   241 ,   7647    ,   13317   ,   23661   ,   55683   ,0 };
            const std::uint32_t dim3725Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   7   ,   63  ,   91  ,   161 ,   45  ,   533 ,   1833    ,   2465    ,   5081    ,   6341    ,   16713   ,   34685   ,0 };
            const std::uint32_t dim3726Kuo2Init[]       =   {   1   ,   3   ,   1   ,   9   ,   23  ,   9   ,   43  ,   157 ,   307 ,   521 ,   1611    ,   3851    ,   6943    ,   14939   ,   13833   ,   20099   ,0 };
            const std::uint32_t dim3727Kuo2Init[]       =   {   1   ,   1   ,   5   ,   3   ,   27  ,   13  ,   35  ,   131 ,   129 ,   257 ,   1015    ,   1849    ,   6645    ,   11567   ,   13385   ,   30943   ,0 };
            const std::uint32_t dim3728Kuo2Init[]       =   {   1   ,   1   ,   5   ,   1   ,   21  ,   49  ,   101 ,   77  ,   301 ,   541 ,   481 ,   2903    ,   8121    ,   2689    ,   21541   ,   25337   ,0 };
            const std::uint32_t dim3729Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   1   ,   13  ,   125 ,   209 ,   327 ,   245 ,   1055    ,   1097    ,   4931    ,   15721   ,   8193    ,   19923   ,0 };
            const std::uint32_t dim3730Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   17  ,   31  ,   85  ,   159 ,   405 ,   287 ,   1083    ,   1679    ,   6227    ,   305 ,   9549    ,   27303   ,0 };
            const std::uint32_t dim3731Kuo2Init[]       =   {   1   ,   1   ,   1   ,   13  ,   7   ,   45  ,   125 ,   181 ,   219 ,   811 ,   1471    ,   999 ,   93  ,   12845   ,   4597    ,   60641   ,0 };
            const std::uint32_t dim3732Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   29  ,   23  ,   109 ,   37  ,   367 ,   185 ,   1467    ,   1871    ,   6349    ,   8563    ,   8743    ,   30277   ,0 };
            const std::uint32_t dim3733Kuo2Init[]       =   {   1   ,   1   ,   1   ,   15  ,   19  ,   23  ,   75  ,   93  ,   191 ,   993 ,   1111    ,   1531    ,   2105    ,   8869    ,   27217   ,   16609   ,0 };
            const std::uint32_t dim3734Kuo2Init[]       =   {   1   ,   3   ,   1   ,   15  ,   31  ,   29  ,   23  ,   145 ,   467 ,   465 ,   637 ,   3169    ,   889 ,   9225    ,   17917   ,   8379    ,0 };
            const std::uint32_t dim3735Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   1   ,   33  ,   7   ,   209 ,   99  ,   753 ,   113 ,   2945    ,   345 ,   14091   ,   13169   ,   4799    ,0 };
            const std::uint32_t dim3736Kuo2Init[]       =   {   1   ,   3   ,   3   ,   11  ,   21  ,   5   ,   9   ,   97  ,   347 ,   537 ,   1287    ,   1401    ,   815 ,   9289    ,   17259   ,   11755   ,0 };
            const std::uint32_t dim3737Kuo2Init[]       =   {   1   ,   1   ,   5   ,   1   ,   7   ,   9   ,   21  ,   87  ,   495 ,   685 ,   1675    ,   1909    ,   4215    ,   1589    ,   18229   ,   2253    ,0 };
            const std::uint32_t dim3738Kuo2Init[]       =   {   1   ,   1   ,   1   ,   3   ,   7   ,   29  ,   121 ,   67  ,   383 ,   351 ,   1555    ,   3091    ,   3677    ,   3489    ,   30241   ,   55309   ,0 };
            const std::uint32_t dim3739Kuo2Init[]       =   {   1   ,   1   ,   7   ,   11  ,   21  ,   39  ,   33  ,   201 ,   195 ,   601 ,   1235    ,   3499    ,   1657    ,   4495    ,   26501   ,   49783   ,0 };
            const std::uint32_t dim3740Kuo2Init[]       =   {   1   ,   1   ,   5   ,   1   ,   15  ,   37  ,   91  ,   169 ,   65  ,   471 ,   1409    ,   3017    ,   1071    ,   15331   ,   27085   ,   22837   ,0 };
            const std::uint32_t dim3741Kuo2Init[]       =   {   1   ,   1   ,   5   ,   13  ,   23  ,   45  ,   115 ,   153 ,   27  ,   773 ,   637 ,   2673    ,   79  ,   4275    ,   21133   ,   38509   ,0 };
            const std::uint32_t dim3742Kuo2Init[]       =   {   1   ,   3   ,   1   ,   13  ,   17  ,   53  ,   49  ,   55  ,   439 ,   255 ,   383 ,   1057    ,   4995    ,   3853    ,   29839   ,   2529    ,0 };
            const std::uint32_t dim3743Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   17  ,   29  ,   73  ,   205 ,   1   ,   685 ,   991 ,   3563    ,   4281    ,   2341    ,   27111   ,   36609   ,0 };
            const std::uint32_t dim3744Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   19  ,   25  ,   65  ,   167 ,   425 ,   289 ,   963 ,   1653    ,   131 ,   4599    ,   4615    ,   57653   ,0 };
            const std::uint32_t dim3745Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   19  ,   57  ,   93  ,   239 ,   375 ,   739 ,   1101    ,   881 ,   7391    ,   921 ,   11493   ,   50417   ,0 };
            const std::uint32_t dim3746Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   7   ,   33  ,   5   ,   59  ,   381 ,   123 ,   33  ,   1903    ,   2639    ,   12073   ,   511 ,   659 ,0 };
            const std::uint32_t dim3747Kuo2Init[]       =   {   1   ,   1   ,   3   ,   1   ,   23  ,   1   ,   77  ,   55  ,   455 ,   687 ,   1825    ,   1355    ,   2997    ,   615 ,   123 ,   17611   ,0 };
            const std::uint32_t dim3748Kuo2Init[]       =   {   1   ,   1   ,   7   ,   13  ,   25  ,   61  ,   119 ,   101 ,   397 ,   645 ,   485 ,   3361    ,   899 ,   5103    ,   3307    ,   9765    ,0 };
            const std::uint32_t dim3749Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   25  ,   59  ,   27  ,   245 ,   3   ,   915 ,   1001    ,   977 ,   7913    ,   4667    ,   24845   ,   37183   ,0 };
            const std::uint32_t dim3750Kuo2Init[]       =   {   1   ,   1   ,   7   ,   15  ,   19  ,   21  ,   1   ,   233 ,   175 ,   347 ,   1335    ,   2757    ,   1615    ,   8381    ,   10611   ,   32409   ,0 };
            const std::uint32_t dim3751Kuo2Init[]       =   {   1   ,   1   ,   7   ,   15  ,   23  ,   33  ,   7   ,   51  ,   235 ,   735 ,   615 ,   3305    ,   4555    ,   15079   ,   21309   ,   55397   ,0 };
            const std::uint32_t dim3752Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   19  ,   49  ,   59  ,   213 ,   155 ,   23  ,   239 ,   753 ,   1473    ,   6869    ,   19993   ,   14383   ,0 };
            const std::uint32_t dim3753Kuo2Init[]       =   {   1   ,   1   ,   5   ,   9   ,   17  ,   37  ,   23  ,   163 ,   45  ,   409 ,   1103    ,   289 ,   4707    ,   12657   ,   26033   ,   27547   ,0 };
            const std::uint32_t dim3754Kuo2Init[]       =   {   1   ,   3   ,   7   ,   9   ,   23  ,   49  ,   83  ,   63  ,   79  ,   643 ,   107 ,   3041    ,   1921    ,   10343   ,   19179   ,   4961    ,0 };
            const std::uint32_t dim3755Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   31  ,   7   ,   81  ,   145 ,   281 ,   751 ,   867 ,   535 ,   6593    ,   7255    ,   13785   ,   62137   ,0 };
            const std::uint32_t dim3756Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   13  ,   55  ,   59  ,   203 ,   329 ,   421 ,   483 ,   2931    ,   521 ,   3013    ,   1077    ,   3405    ,0 };
            const std::uint32_t dim3757Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   15  ,   13  ,   21  ,   205 ,   187 ,   491 ,   887 ,   893 ,   3917    ,   6989    ,   23569   ,   48729   ,0 };
            const std::uint32_t dim3758Kuo2Init[]       =   {   1   ,   1   ,   3   ,   11  ,   15  ,   35  ,   63  ,   109 ,   157 ,   643 ,   961 ,   3713    ,   1459    ,   8585    ,   6113    ,   7339    ,0 };
            const std::uint32_t dim3759Kuo2Init[]       =   {   1   ,   3   ,   7   ,   9   ,   7   ,   53  ,   57  ,   251 ,   203 ,   701 ,   2041    ,   73  ,   7637    ,   12745   ,   8003    ,   45849   ,0 };
            const std::uint32_t dim3760Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   23  ,   27  ,   109 ,   211 ,   273 ,   1013    ,   19  ,   2499    ,   377 ,   5185    ,   25261   ,   8997    ,0 };
            const std::uint32_t dim3761Kuo2Init[]       =   {   1   ,   3   ,   7   ,   15  ,   3   ,   35  ,   41  ,   85  ,   391 ,   409 ,   1945    ,   25  ,   6069    ,   3499    ,   10879   ,   38239   ,0 };
            const std::uint32_t dim3762Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   3   ,   37  ,   65  ,   229 ,   441 ,   675 ,   909 ,   3887    ,   7347    ,   3221    ,   1935    ,   65147   ,0 };
            const std::uint32_t dim3763Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   13  ,   29  ,   119 ,   29  ,   277 ,   303 ,   685 ,   1921    ,   4863    ,   12483   ,   9303    ,   59355   ,0 };
            const std::uint32_t dim3764Kuo2Init[]       =   {   1   ,   1   ,   1   ,   9   ,   21  ,   43  ,   115 ,   253 ,   349 ,   655 ,   779 ,   1965    ,   4831    ,   6491    ,   16051   ,   6975    ,0 };
            const std::uint32_t dim3765Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   1   ,   9   ,   55  ,   253 ,   21  ,   655 ,   133 ,   3777    ,   4239    ,   14447   ,   7221    ,   59819   ,0 };
            const std::uint32_t dim3766Kuo2Init[]       =   {   1   ,   1   ,   7   ,   3   ,   19  ,   49  ,   11  ,   93  ,   39  ,   149 ,   683 ,   3295    ,   6519    ,   12187   ,   2231    ,   39829   ,0 };
            const std::uint32_t dim3767Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   23  ,   9   ,   101 ,   197 ,   3   ,   873 ,   1459    ,   747 ,   6939    ,   5629    ,   27305   ,   32235   ,0 };
            const std::uint32_t dim3768Kuo2Init[]       =   {   1   ,   1   ,   5   ,   7   ,   13  ,   9   ,   31  ,   251 ,   481 ,   877 ,   773 ,   993 ,   4431    ,   12081   ,   15987   ,   27081   ,0 };
            const std::uint32_t dim3769Kuo2Init[]       =   {   1   ,   1   ,   1   ,   1   ,   9   ,   49  ,   13  ,   89  ,   39  ,   797 ,   815 ,   319 ,   5917    ,   621 ,   25867   ,   46433   ,0 };
            const std::uint32_t dim3770Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   23  ,   27  ,   83  ,   123 ,   83  ,   177 ,   1001    ,   995 ,   2765    ,   6401    ,   15593   ,   20205   ,0 };
            const std::uint32_t dim3771Kuo2Init[]       =   {   1   ,   1   ,   5   ,   13  ,   25  ,   9   ,   59  ,   123 ,   141 ,   737 ,   1111    ,   1883    ,   2647    ,   733 ,   3551    ,   44453   ,0 };
            const std::uint32_t dim3772Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   7   ,   49  ,   25  ,   177 ,   297 ,   87  ,   1039    ,   1917    ,   3167    ,   11025   ,   22959   ,   63929   ,0 };
            const std::uint32_t dim3773Kuo2Init[]       =   {   1   ,   1   ,   1   ,   3   ,   17  ,   57  ,   103 ,   99  ,   127 ,   579 ,   903 ,   2835    ,   607 ,   9723    ,   22397   ,   36621   ,0 };
            const std::uint32_t dim3774Kuo2Init[]       =   {   1   ,   1   ,   3   ,   15  ,   13  ,   47  ,   77  ,   213 ,   383 ,   371 ,   887 ,   281 ,   6171    ,   10383   ,   12157   ,   57899   ,0 };
            const std::uint32_t dim3775Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   5   ,   15  ,   65  ,   119 ,   303 ,   265 ,   783 ,   3075    ,   7893    ,   441 ,   22065   ,   52157   ,0 };
            const std::uint32_t dim3776Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   7   ,   49  ,   105 ,   145 ,   301 ,   57  ,   1949    ,   3073    ,   435 ,   1171    ,   27691   ,   34821   ,0 };
            const std::uint32_t dim3777Kuo2Init[]       =   {   1   ,   3   ,   1   ,   11  ,   5   ,   31  ,   33  ,   159 ,   319 ,   437 ,   453 ,   1005    ,   3335    ,   5895    ,   15407   ,   159 ,0 };
            const std::uint32_t dim3778Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   31  ,   15  ,   69  ,   129 ,   221 ,   991 ,   1879    ,   1251    ,   5303    ,   6677    ,   15823   ,   46319   ,0 };
            const std::uint32_t dim3779Kuo2Init[]       =   {   1   ,   3   ,   7   ,   11  ,   1   ,   47  ,   49  ,   13  ,   401 ,   755 ,   1703    ,   2021    ,   5195    ,   9489    ,   9191    ,   30427   ,0 };
            const std::uint32_t dim3780Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   7   ,   11  ,   25  ,   147 ,   471 ,   31  ,   489 ,   3477    ,   3025    ,   4011    ,   7733    ,   22091   ,0 };
            const std::uint32_t dim3781Kuo2Init[]       =   {   1   ,   1   ,   5   ,   9   ,   7   ,   7   ,   99  ,   23  ,   397 ,   67  ,   2027    ,   3885    ,   3269    ,   15385   ,   24367   ,   1715    ,0 };
            const std::uint32_t dim3782Kuo2Init[]       =   {   1   ,   1   ,   5   ,   1   ,   7   ,   45  ,   83  ,   159 ,   501 ,   561 ,   993 ,   1495    ,   4415    ,   2559    ,   27  ,   60825   ,0 };
            const std::uint32_t dim3783Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   7   ,   43  ,   99  ,   159 ,   117 ,   453 ,   1841    ,   1807    ,   1881    ,   12513   ,   16413   ,   37993   ,0 };
            const std::uint32_t dim3784Kuo2Init[]       =   {   1   ,   3   ,   1   ,   13  ,   15  ,   37  ,   53  ,   173 ,   279 ,   415 ,   535 ,   2553    ,   3995    ,   8245    ,   4507    ,   19575   ,0 };
            const std::uint32_t dim3785Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   25  ,   7   ,   79  ,   25  ,   105 ,   525 ,   1179    ,   1793    ,   4899    ,   10253   ,   22655   ,   1419    ,0 };
            const std::uint32_t dim3786Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   11  ,   35  ,   77  ,   139 ,   449 ,   879 ,   619 ,   1645    ,   3309    ,   37  ,   10607   ,   43757   ,0 };
            const std::uint32_t dim3787Kuo2Init[]       =   {   1   ,   1   ,   1   ,   13  ,   17  ,   17  ,   7   ,   69  ,   389 ,   733 ,   775 ,   791 ,   5451    ,   15737   ,   9043    ,   16573   ,0 };
            const std::uint32_t dim3788Kuo2Init[]       =   {   1   ,   1   ,   7   ,   5   ,   15  ,   57  ,   81  ,   19  ,   307 ,   207 ,   241 ,   449 ,   7745    ,   521 ,   16975   ,   11907   ,0 };
            const std::uint32_t dim3789Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   25  ,   1   ,   55  ,   229 ,   123 ,   809 ,   1673    ,   3461    ,   7729    ,   8615    ,   8755    ,   35929   ,0 };
            const std::uint32_t dim3790Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   23  ,   7   ,   19  ,   235 ,   375 ,   79  ,   899 ,   21  ,   7681    ,   7169    ,   13057   ,   1379    ,0 };
            const std::uint32_t dim3791Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   29  ,   49  ,   93  ,   217 ,   409 ,   263 ,   225 ,   2333    ,   1621    ,   14741   ,   4933    ,   58263   ,0 };
            const std::uint32_t dim3792Kuo2Init[]       =   {   1   ,   3   ,   1   ,   13  ,   11  ,   35  ,   19  ,   55  ,   71  ,   937 ,   551 ,   1693    ,   3843    ,   7411    ,   29501   ,   31525   ,0 };
            const std::uint32_t dim3793Kuo2Init[]       =   {   1   ,   1   ,   5   ,   13  ,   17  ,   17  ,   105 ,   31  ,   181 ,   915 ,   321 ,   3161    ,   5247    ,   13317   ,   23595   ,   21783   ,0 };
            const std::uint32_t dim3794Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   31  ,   19  ,   85  ,   71  ,   55  ,   933 ,   1425    ,   2419    ,   2891    ,   15813   ,   18209   ,   30347   ,0 };
            const std::uint32_t dim3795Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   1   ,   45  ,   31  ,   1   ,   193 ,   445 ,   1293    ,   2563    ,   5837    ,   6113    ,   5741    ,   12245   ,0 };
            const std::uint32_t dim3796Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   25  ,   25  ,   7   ,   155 ,   267 ,   65  ,   2015    ,   2021    ,   6331    ,   6973    ,   1303    ,   14833   ,0 };
            const std::uint32_t dim3797Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   21  ,   31  ,   87  ,   21  ,   509 ,   555 ,   429 ,   1405    ,   4417    ,   1891    ,   15679   ,   3819    ,0 };
            const std::uint32_t dim3798Kuo2Init[]       =   {   1   ,   3   ,   7   ,   3   ,   19  ,   49  ,   53  ,   251 ,   423 ,   949 ,   971 ,   425 ,   1589    ,   5257    ,   19021   ,   16817   ,0 };
            const std::uint32_t dim3799Kuo2Init[]       =   {   1   ,   1   ,   5   ,   7   ,   1   ,   27  ,   71  ,   185 ,   357 ,   1009    ,   897 ,   491 ,   6433    ,   6717    ,   23445   ,   29097   ,0 };
            const std::uint32_t dim3800Kuo2Init[]       =   {   1   ,   3   ,   7   ,   15  ,   9   ,   39  ,   87  ,   25  ,   149 ,   291 ,   1249    ,   3987    ,   7441    ,   11225   ,   18051   ,   17747   ,0 };
            const std::uint32_t dim3801Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   13  ,   61  ,   13  ,   141 ,   39  ,   317 ,   579 ,   2181    ,   6735    ,   14749   ,   25997   ,   16025   ,0 };
            const std::uint32_t dim3802Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   27  ,   19  ,   127 ,   231 ,   13  ,   7   ,   1707    ,   87  ,   7379    ,   8171    ,   27435   ,   47911   ,0 };
            const std::uint32_t dim3803Kuo2Init[]       =   {   1   ,   1   ,   1   ,   15  ,   21  ,   33  ,   33  ,   85  ,   205 ,   321 ,   785 ,   4051    ,   2503    ,   15589   ,   10881   ,   63103   ,0 };
            const std::uint32_t dim3804Kuo2Init[]       =   {   1   ,   1   ,   1   ,   3   ,   15  ,   11  ,   31  ,   105 ,   185 ,   113 ,   293 ,   3279    ,   4867    ,   9249    ,   14403   ,   24951   ,0 };
            const std::uint32_t dim3805Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   7   ,   47  ,   105 ,   253 ,   117 ,   577 ,   2019    ,   2089    ,   1357    ,   5299    ,   27961   ,   36675   ,0 };
            const std::uint32_t dim3806Kuo2Init[]       =   {   1   ,   1   ,   1   ,   7   ,   31  ,   33  ,   117 ,   51  ,   283 ,   453 ,   1657    ,   1343    ,   6491    ,   649 ,   1029    ,   44809   ,0 };
            const std::uint32_t dim3807Kuo2Init[]       =   {   1   ,   1   ,   1   ,   3   ,   3   ,   45  ,   121 ,   155 ,   191 ,   607 ,   1087    ,   3291    ,   8171    ,   3757    ,   14247   ,   49647   ,0 };
            const std::uint32_t dim3808Kuo2Init[]       =   {   1   ,   3   ,   1   ,   3   ,   7   ,   17  ,   109 ,   163 ,   87  ,   63  ,   573 ,   3127    ,   3361    ,   6733    ,   26729   ,   44427   ,0 };
            const std::uint32_t dim3809Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   13  ,   23  ,   29  ,   173 ,   487 ,   345 ,   351 ,   3401    ,   4611    ,   5591    ,   6209    ,   58537   ,0 };
            const std::uint32_t dim3810Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   23  ,   49  ,   31  ,   51  ,   157 ,   623 ,   1103    ,   681 ,   6645    ,   2147    ,   1715    ,   42253   ,0 };
            const std::uint32_t dim3811Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   7   ,   61  ,   85  ,   129 ,   309 ,   701 ,   1139    ,   3211    ,   4943    ,   8365    ,   20727   ,   51025   ,0 };
            const std::uint32_t dim3812Kuo2Init[]       =   {   1   ,   1   ,   3   ,   11  ,   29  ,   47  ,   119 ,   181 ,   109 ,   403 ,   1459    ,   39  ,   609 ,   7405    ,   25651   ,   61395   ,0 };
            const std::uint32_t dim3813Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   5   ,   55  ,   65  ,   155 ,   273 ,   177 ,   1879    ,   3901    ,   3219    ,   8699    ,   10445   ,   40141   ,0 };
            const std::uint32_t dim3814Kuo2Init[]       =   {   1   ,   3   ,   7   ,   15  ,   3   ,   11  ,   45  ,   85  ,   473 ,   1013    ,   1725    ,   155 ,   3369    ,   7345    ,   1475    ,   28781   ,0 };
            const std::uint32_t dim3815Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   13  ,   61  ,   31  ,   217 ,   111 ,   719 ,   161 ,   1053    ,   1451    ,   10437   ,   28909   ,   1173    ,0 };
            const std::uint32_t dim3816Kuo2Init[]       =   {   1   ,   1   ,   3   ,   11  ,   9   ,   21  ,   119 ,   119 ,   355 ,   563 ,   855 ,   853 ,   4243    ,   5201    ,   2521    ,   41389   ,0 };
            const std::uint32_t dim3817Kuo2Init[]       =   {   1   ,   1   ,   5   ,   15  ,   9   ,   5   ,   15  ,   79  ,   489 ,   499 ,   1065    ,   2073    ,   7567    ,   5385    ,   9329    ,   17643   ,0 };
            const std::uint32_t dim3818Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   15  ,   53  ,   61  ,   225 ,   381 ,   217 ,   163 ,   4005    ,   7269    ,   4481    ,   23697   ,   46055   ,0 };
            const std::uint32_t dim3819Kuo2Init[]       =   {   1   ,   3   ,   3   ,   13  ,   1   ,   55  ,   77  ,   95  ,   345 ,   113 ,   1359    ,   539 ,   6979    ,   5459    ,   9551    ,   45035   ,0 };
            const std::uint32_t dim3820Kuo2Init[]       =   {   1   ,   1   ,   5   ,   3   ,   5   ,   45  ,   93  ,   147 ,   387 ,   165 ,   1529    ,   1243    ,   7639    ,   5531    ,   22381   ,   63517   ,0 };
            const std::uint32_t dim3821Kuo2Init[]       =   {   1   ,   1   ,   3   ,   1   ,   9   ,   27  ,   109 ,   161 ,   71  ,   547 ,   259 ,   1399    ,   5815    ,   1569    ,   26627   ,   63133   ,0 };
            const std::uint32_t dim3822Kuo2Init[]       =   {   1   ,   1   ,   3   ,   3   ,   29  ,   37  ,   21  ,   205 ,   49  ,   863 ,   707 ,   307 ,   573 ,   3167    ,   17595   ,   63485   ,0 };
            const std::uint32_t dim3823Kuo2Init[]       =   {   1   ,   1   ,   5   ,   1   ,   17  ,   15  ,   95  ,   21  ,   111 ,   991 ,   657 ,   3865    ,   8091    ,   7589    ,   30487   ,   63229   ,0 };
            const std::uint32_t dim3824Kuo2Init[]       =   {   1   ,   1   ,   1   ,   7   ,   29  ,   11  ,   65  ,   201 ,   357 ,   269 ,   281 ,   1329    ,   6359    ,   7875    ,   23561   ,   44489   ,0 };
            const std::uint32_t dim3825Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   27  ,   29  ,   1   ,   15  ,   475 ,   393 ,   1917    ,   3605    ,   4463    ,   7809    ,   16529   ,   64599   ,0 };
            const std::uint32_t dim3826Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   29  ,   15  ,   11  ,   255 ,   315 ,   209 ,   895 ,   2813    ,   2263    ,   7095    ,   1447    ,   55307   ,0 };
            const std::uint32_t dim3827Kuo2Init[]       =   {   1   ,   3   ,   1   ,   15  ,   17  ,   11  ,   73  ,   57  ,   13  ,   529 ,   35  ,   1065    ,   81  ,   13801   ,   19531   ,   27249   ,0 };
            const std::uint32_t dim3828Kuo2Init[]       =   {   1   ,   3   ,   1   ,   11  ,   19  ,   15  ,   117 ,   235 ,   219 ,   109 ,   1885    ,   4005    ,   3565    ,   2591    ,   29233   ,   47111   ,0 };
            const std::uint32_t dim3829Kuo2Init[]       =   {   1   ,   3   ,   3   ,   11  ,   21  ,   35  ,   27  ,   227 ,   393 ,   57  ,   1637    ,   537 ,   2463    ,   4483    ,   32153   ,   22035   ,0 };
            const std::uint32_t dim3830Kuo2Init[]       =   {   1   ,   1   ,   7   ,   5   ,   13  ,   9   ,   79  ,   147 ,   341 ,   1007    ,   1093    ,   3837    ,   5581    ,   3363    ,   10637   ,   60109   ,0 };
            const std::uint32_t dim3831Kuo2Init[]       =   {   1   ,   3   ,   5   ,   13  ,   31  ,   49  ,   121 ,   231 ,   485 ,   947 ,   127 ,   1817    ,   3005    ,   11085   ,   14157   ,   21145   ,0 };
            const std::uint32_t dim3832Kuo2Init[]       =   {   1   ,   1   ,   3   ,   1   ,   1   ,   23  ,   17  ,   195 ,   351 ,   527 ,   1787    ,   3885    ,   2281    ,   729 ,   25083   ,   63523   ,0 };
            const std::uint32_t dim3833Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   19  ,   31  ,   51  ,   5   ,   55  ,   551 ,   33  ,   1735    ,   427 ,   2859    ,   3941    ,   48639   ,0 };
            const std::uint32_t dim3834Kuo2Init[]       =   {   1   ,   3   ,   7   ,   7   ,   11  ,   59  ,   101 ,   125 ,   167 ,   311 ,   1487    ,   969 ,   5023    ,   3893    ,   22065   ,   48803   ,0 };
            const std::uint32_t dim3835Kuo2Init[]       =   {   1   ,   3   ,   3   ,   11  ,   27  ,   11  ,   77  ,   43  ,   295 ,   31  ,   1061    ,   2999    ,   4451    ,   10339   ,   9213    ,   63705   ,0 };
            const std::uint32_t dim3836Kuo2Init[]       =   {   1   ,   3   ,   1   ,   11  ,   1   ,   63  ,   83  ,   179 ,   413 ,   317 ,   1921    ,   2917    ,   6697    ,   6637    ,   5291    ,   48791   ,0 };
            const std::uint32_t dim3837Kuo2Init[]       =   {   1   ,   1   ,   3   ,   3   ,   19  ,   57  ,   55  ,   159 ,   137 ,   291 ,   1353    ,   81  ,   2495    ,   12315   ,   31031   ,   41081   ,0 };
            const std::uint32_t dim3838Kuo2Init[]       =   {   1   ,   1   ,   3   ,   3   ,   25  ,   49  ,   49  ,   239 ,   53  ,   999 ,   303 ,   3083    ,   2455    ,   3977    ,   13945   ,   22667   ,0 };
            const std::uint32_t dim3839Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   7   ,   15  ,   85  ,   215 ,   463 ,   301 ,   1061    ,   3993    ,   5927    ,   703 ,   23083   ,   44633   ,0 };
            const std::uint32_t dim3840Kuo2Init[]       =   {   1   ,   3   ,   3   ,   1   ,   9   ,   53  ,   21  ,   165 ,   129 ,   697 ,   1867    ,   2427    ,   5383    ,   13223   ,   12127   ,   60477   ,0 };
            const std::uint32_t dim3841Kuo2Init[]       =   {   1   ,   3   ,   5   ,   5   ,   17  ,   13  ,   37  ,   151 ,   337 ,   425 ,   829 ,   2415    ,   1705    ,   10389   ,   26299   ,   45655   ,0 };
            const std::uint32_t dim3842Kuo2Init[]       =   {   1   ,   3   ,   1   ,   9   ,   13  ,   3   ,   99  ,   111 ,   371 ,   589 ,   605 ,   3137    ,   4515    ,   5303    ,   6151    ,   14225   ,0 };
            const std::uint32_t dim3843Kuo2Init[]       =   {   1   ,   1   ,   3   ,   11  ,   15  ,   59  ,   31  ,   95  ,   305 ,   133 ,   751 ,   13  ,   7691    ,   2603    ,   21761   ,   18577   ,0 };
            const std::uint32_t dim3844Kuo2Init[]       =   {   1   ,   1   ,   1   ,   13  ,   25  ,   47  ,   93  ,   251 ,   341 ,   465 ,   1043    ,   3391    ,   271 ,   3431    ,   16465   ,   53283   ,0 };
            const std::uint32_t dim3845Kuo2Init[]       =   {   1   ,   1   ,   5   ,   9   ,   31  ,   1   ,   31  ,   77  ,   383 ,   151 ,   1243    ,   3165    ,   2363    ,   13751   ,   10251   ,   55111   ,0 };
            const std::uint32_t dim3846Kuo2Init[]       =   {   1   ,   1   ,   5   ,   13  ,   23  ,   35  ,   123 ,   229 ,   193 ,   29  ,   201 ,   2661    ,   7539    ,   10407   ,   30831   ,   56091   ,0 };
            const std::uint32_t dim3847Kuo2Init[]       =   {   1   ,   1   ,   5   ,   15  ,   19  ,   17  ,   83  ,   157 ,   265 ,   649 ,   815 ,   531 ,   3905    ,   10691   ,   4137    ,   29875   ,0 };
            const std::uint32_t dim3848Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   29  ,   41  ,   29  ,   153 ,   509 ,   617 ,   151 ,   2409    ,   4631    ,   6525    ,   8539    ,   20855   ,0 };
            const std::uint32_t dim3849Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   27  ,   37  ,   55  ,   215 ,   135 ,   463 ,   163 ,   1415    ,   1457    ,   2675    ,   9461    ,   6585    ,0 };
            const std::uint32_t dim3850Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   23  ,   17  ,   29  ,   183 ,   33  ,   593 ,   717 ,   1487    ,   4777    ,   6281    ,   3299    ,   37531   ,0 };
            const std::uint32_t dim3851Kuo2Init[]       =   {   1   ,   1   ,   5   ,   15  ,   15  ,   17  ,   91  ,   243 ,   259 ,   655 ,   1347    ,   3229    ,   1449    ,   10069   ,   2671    ,   11391   ,0 };
            const std::uint32_t dim3852Kuo2Init[]       =   {   1   ,   1   ,   7   ,   15  ,   17  ,   35  ,   35  ,   105 ,   285 ,   761 ,   1989    ,   3427    ,   3649    ,   223 ,   21887   ,   6153    ,0 };
            const std::uint32_t dim3853Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   17  ,   55  ,   47  ,   235 ,   7   ,   829 ,   1437    ,   1669    ,   2837    ,   6573    ,   3847    ,   32347   ,0 };
            const std::uint32_t dim3854Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   5   ,   19  ,   41  ,   151 ,   59  ,   427 ,   1917    ,   3339    ,   4139    ,   13781   ,   15171   ,   50597   ,0 };
            const std::uint32_t dim3855Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   3   ,   47  ,   77  ,   175 ,   239 ,   729 ,   1957    ,   2941    ,   4749    ,   15157   ,   30351   ,   57657   ,0 };
            const std::uint32_t dim3856Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   23  ,   39  ,   51  ,   239 ,   455 ,   347 ,   1673    ,   1355    ,   1707    ,   10125   ,   18923   ,   53953   ,0 };
            const std::uint32_t dim3857Kuo2Init[]       =   {   1   ,   3   ,   3   ,   11  ,   5   ,   21  ,   113 ,   161 ,   325 ,   663 ,   9   ,   641 ,   4089    ,   7043    ,   9771    ,   16719   ,0 };
            const std::uint32_t dim3858Kuo2Init[]       =   {   1   ,   3   ,   7   ,   7   ,   1   ,   63  ,   3   ,   77  ,   67  ,   575 ,   313 ,   1249    ,   1203    ,   8121    ,   13647   ,   563 ,0 };
            const std::uint32_t dim3859Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   17  ,   61  ,   95  ,   75  ,   421 ,   671 ,   835 ,   4015    ,   6591    ,   7589    ,   8039    ,   10055   ,0 };
            const std::uint32_t dim3860Kuo2Init[]       =   {   1   ,   1   ,   3   ,   3   ,   27  ,   43  ,   75  ,   121 ,   143 ,   235 ,   1243    ,   2063    ,   7711    ,   7925    ,   2943    ,   23419   ,0 };
            const std::uint32_t dim3861Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   1   ,   21  ,   41  ,   225 ,   427 ,   843 ,   1417    ,   3481    ,   5239    ,   16373   ,   11599   ,   37267   ,0 };
            const std::uint32_t dim3862Kuo2Init[]       =   {   1   ,   1   ,   7   ,   15  ,   17  ,   23  ,   95  ,   185 ,   193 ,   471 ,   1475    ,   861 ,   5115    ,   4573    ,   12909   ,   12337   ,0 };
            const std::uint32_t dim3863Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   19  ,   25  ,   107 ,   171 ,   355 ,   57  ,   1301    ,   2343    ,   6425    ,   5537    ,   29391   ,   27187   ,0 };
            const std::uint32_t dim3864Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   19  ,   35  ,   67  ,   157 ,   183 ,   477 ,   961 ,   1087    ,   7329    ,   15787   ,   9547    ,   59001   ,0 };
            const std::uint32_t dim3865Kuo2Init[]       =   {   1   ,   1   ,   3   ,   5   ,   29  ,   57  ,   29  ,   119 ,   315 ,   533 ,   717 ,   1099    ,   713 ,   1473    ,   19511   ,   59777   ,0 };
            const std::uint32_t dim3866Kuo2Init[]       =   {   1   ,   3   ,   7   ,   7   ,   17  ,   63  ,   71  ,   181 ,   103 ,   943 ,   305 ,   1657    ,   6117    ,   11921   ,   6119    ,   26437   ,0 };
            const std::uint32_t dim3867Kuo2Init[]       =   {   1   ,   3   ,   7   ,   9   ,   3   ,   61  ,   91  ,   65  ,   389 ,   331 ,   549 ,   2355    ,   4591    ,   3385    ,   19913   ,   62541   ,0 };
            const std::uint32_t dim3868Kuo2Init[]       =   {   1   ,   1   ,   5   ,   1   ,   17  ,   1   ,   127 ,   127 ,   471 ,   139 ,   1147    ,   1463    ,   5403    ,   10877   ,   11469   ,   65283   ,0 };
            const std::uint32_t dim3869Kuo2Init[]       =   {   1   ,   3   ,   1   ,   13  ,   27  ,   29  ,   31  ,   57  ,   433 ,   941 ,   1559    ,   2495    ,   83  ,   14701   ,   20787   ,   10761   ,0 };
            const std::uint32_t dim3870Kuo2Init[]       =   {   1   ,   3   ,   3   ,   9   ,   23  ,   59  ,   23  ,   175 ,   25  ,   865 ,   751 ,   3395    ,   4111    ,   10287   ,   28191   ,   38487   ,0 };
            const std::uint32_t dim3871Kuo2Init[]       =   {   1   ,   1   ,   3   ,   7   ,   21  ,   3   ,   107 ,   205 ,   349 ,   473 ,   1115    ,   1647    ,   2379    ,   4709    ,   21697   ,   47899   ,0 };
            const std::uint32_t dim3872Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   27  ,   49  ,   113 ,   73  ,   487 ,   487 ,   1531    ,   357 ,   8073    ,   10275   ,   7713    ,   9169    ,0 };
            const std::uint32_t dim3873Kuo2Init[]       =   {   1   ,   3   ,   3   ,   13  ,   1   ,   55  ,   97  ,   19  ,   5   ,   997 ,   1   ,   437 ,   343 ,   4867    ,   4897    ,   20291   ,0 };
            const std::uint32_t dim3874Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   19  ,   51  ,   25  ,   3   ,   143 ,   783 ,   1415    ,   2231    ,   1809    ,   2011    ,   32607   ,   33817   ,0 };
            const std::uint32_t dim3875Kuo2Init[]       =   {   1   ,   1   ,   5   ,   1   ,   3   ,   59  ,   49  ,   183 ,   447 ,   55  ,   17  ,   1455    ,   3753    ,   13531   ,   17193   ,   22375   ,0 };
            const std::uint32_t dim3876Kuo2Init[]       =   {   1   ,   3   ,   7   ,   5   ,   21  ,   55  ,   25  ,   79  ,   161 ,   763 ,   815 ,   2161    ,   1639    ,   7165    ,   15681   ,   53681   ,0 };
            const std::uint32_t dim3877Kuo2Init[]       =   {   1   ,   3   ,   7   ,   3   ,   15  ,   53  ,   75  ,   243 ,   49  ,   701 ,   519 ,   1781    ,   8073    ,   16349   ,   487 ,   35051   ,0 };
            const std::uint32_t dim3878Kuo2Init[]       =   {   1   ,   3   ,   3   ,   15  ,   11  ,   33  ,   65  ,   93  ,   157 ,   499 ,   1487    ,   627 ,   4483    ,   9001    ,   26869   ,   11713   ,0 };
            const std::uint32_t dim3879Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   15  ,   43  ,   29  ,   159 ,   125 ,   329 ,   1619    ,   41  ,   2565    ,   6043    ,   23983   ,   33397   ,0 };
            const std::uint32_t dim3880Kuo2Init[]       =   {   1   ,   1   ,   1   ,   9   ,   31  ,   25  ,   71  ,   53  ,   109 ,   415 ,   1895    ,   309 ,   5121    ,   3659    ,   24591   ,   5207    ,0 };
            const std::uint32_t dim3881Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   23  ,   33  ,   35  ,   95  ,   171 ,   395 ,   171 ,   1085    ,   6629    ,   757 ,   29347   ,   22703   ,0 };
            const std::uint32_t dim3882Kuo2Init[]       =   {   1   ,   1   ,   7   ,   5   ,   17  ,   59  ,   35  ,   9   ,   141 ,   311 ,   1075    ,   2499    ,   321 ,   14733   ,   4069    ,   46015   ,0 };
            const std::uint32_t dim3883Kuo2Init[]       =   {   1   ,   1   ,   1   ,   13  ,   5   ,   27  ,   93  ,   105 ,   205 ,   875 ,   1867    ,   2423    ,   3015    ,   2939    ,   27529   ,   24221   ,0 };
            const std::uint32_t dim3884Kuo2Init[]       =   {   1   ,   1   ,   1   ,   15  ,   21  ,   51  ,   55  ,   239 ,   95  ,   517 ,   1449    ,   537 ,   8083    ,   11519   ,   30293   ,   56663   ,0 };
            const std::uint32_t dim3885Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   3   ,   1   ,   31  ,   77  ,   75  ,   343 ,   423 ,   3781    ,   1171    ,   5331    ,   8885    ,   1917    ,0 };
            const std::uint32_t dim3886Kuo2Init[]       =   {   1   ,   3   ,   1   ,   13  ,   1   ,   45  ,   127 ,   123 ,   153 ,   769 ,   1549    ,   3049    ,   4023    ,   10475   ,   3185    ,   7973    ,0 };
            const std::uint32_t dim3887Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   17  ,   17  ,   63  ,   197 ,   483 ,   253 ,   1655    ,   4053    ,   3753    ,   4159    ,   23551   ,   34501   ,0 };
            const std::uint32_t dim3888Kuo2Init[]       =   {   1   ,   3   ,   7   ,   7   ,   27  ,   35  ,   91  ,   241 ,   377 ,   299 ,   1741    ,   2009    ,   4051    ,   3753    ,   18631   ,   56383   ,0 };
            const std::uint32_t dim3889Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   11  ,   45  ,   101 ,   221 ,   167 ,   845 ,   249 ,   2297    ,   967 ,   5203    ,   29305   ,   8875    ,0 };
            const std::uint32_t dim3890Kuo2Init[]       =   {   1   ,   3   ,   5   ,   9   ,   31  ,   41  ,   21  ,   251 ,   421 ,   47  ,   421 ,   3037    ,   867 ,   12623   ,   23289   ,   39289   ,0 };
            const std::uint32_t dim3891Kuo2Init[]       =   {   1   ,   1   ,   7   ,   9   ,   31  ,   13  ,   99  ,   207 ,   181 ,   683 ,   1881    ,   2047    ,   2299    ,   15795   ,   24597   ,   46881   ,0 };
            const std::uint32_t dim3892Kuo2Init[]       =   {   1   ,   1   ,   1   ,   15  ,   1   ,   45  ,   57  ,   171 ,   149 ,   909 ,   1493    ,   181 ,   4539    ,   9625    ,   20357   ,   9291    ,0 };
            const std::uint32_t dim3893Kuo2Init[]       =   {   1   ,   3   ,   5   ,   15  ,   5   ,   19  ,   101 ,   167 ,   245 ,   213 ,   1453    ,   1447    ,   19  ,   2091    ,   27345   ,   45839   ,0 };
            const std::uint32_t dim3894Kuo2Init[]       =   {   1   ,   1   ,   5   ,   5   ,   5   ,   61  ,   59  ,   159 ,   343 ,   51  ,   2009    ,   3651    ,   5263    ,   1425    ,   4399    ,   34357   ,0 };
            const std::uint32_t dim3895Kuo2Init[]       =   {   1   ,   3   ,   1   ,   15  ,   15  ,   61  ,   49  ,   15  ,   415 ,   365 ,   551 ,   797 ,   7147    ,   12771   ,   17557   ,   30663   ,0 };
            const std::uint32_t dim3896Kuo2Init[]       =   {   1   ,   3   ,   1   ,   7   ,   17  ,   15  ,   125 ,   195 ,   455 ,   553 ,   1259    ,   1851    ,   5149    ,   6843    ,   29195   ,   15015   ,0 };
            const std::uint32_t dim3897Kuo2Init[]       =   {   1   ,   3   ,   7   ,   3   ,   23  ,   21  ,   5   ,   195 ,   77  ,   881 ,   941 ,   2839    ,   2837    ,   10405   ,   22289   ,   6211    ,0 };
            const std::uint32_t dim3898Kuo2Init[]       =   {   1   ,   1   ,   1   ,   7   ,   11  ,   61  ,   99  ,   247 ,   251 ,   183 ,   1263    ,   157 ,   511 ,   8627    ,   19503   ,   43933   ,0 };
            const std::uint32_t dim3899Kuo2Init[]       =   {   1   ,   3   ,   1   ,   9   ,   15  ,   15  ,   113 ,   255 ,   225 ,   173 ,   1427    ,   3837    ,   6607    ,   3777    ,   4913    ,   11173   ,0 };
            const std::uint32_t dim3900Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   17  ,   51  ,   65  ,   249 ,   361 ,   377 ,   1597    ,   3065    ,   5949    ,   9363    ,   25597   ,   40657   ,0 };
            const std::uint32_t dim3901Kuo2Init[]       =   {   1   ,   1   ,   3   ,   13  ,   15  ,   41  ,   51  ,   75  ,   277 ,   611 ,   517 ,   3751    ,   721 ,   6673    ,   32715   ,   29053   ,0 };
            const std::uint32_t dim3902Kuo2Init[]       =   {   1   ,   3   ,   3   ,   11  ,   31  ,   61  ,   97  ,   163 ,   79  ,   267 ,   1601    ,   3155    ,   1623    ,   6301    ,   12897   ,   1555    ,0 };
            const std::uint32_t dim3903Kuo2Init[]       =   {   1   ,   1   ,   5   ,   1   ,   31  ,   33  ,   29  ,   239 ,   15  ,   235 ,   1675    ,   1453    ,   1005    ,   4811    ,   21601   ,   34343   ,0 };
            const std::uint32_t dim3904Kuo2Init[]       =   {   1   ,   3   ,   7   ,   9   ,   13  ,   23  ,   43  ,   119 ,   313 ,   249 ,   643 ,   3797    ,   5299    ,   5127    ,   5639    ,   8509    ,0 };
            const std::uint32_t dim3905Kuo2Init[]       =   {   1   ,   1   ,   7   ,   5   ,   11  ,   51  ,   85  ,   181 ,   231 ,   641 ,   1285    ,   1417    ,   4535    ,   10417   ,   21261   ,   4965    ,0 };
            const std::uint32_t dim3906Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   15  ,   47  ,   109 ,   197 ,   93  ,   115 ,   47  ,   2315    ,   863 ,   2787    ,   25487   ,   4069    ,0 };
            const std::uint32_t dim3907Kuo2Init[]       =   {   1   ,   1   ,   7   ,   11  ,   13  ,   43  ,   117 ,   203 ,   189 ,   151 ,   549 ,   1045    ,   7953    ,   11003   ,   17637   ,   3627    ,0 };
            const std::uint32_t dim3908Kuo2Init[]       =   {   1   ,   3   ,   5   ,   7   ,   7   ,   29  ,   5   ,   55  ,   281 ,   767 ,   1809    ,   2489    ,   6417    ,   10927   ,   30935   ,   10769   ,0 };
            const std::uint32_t dim3909Kuo2Init[]       =   {   1   ,   3   ,   7   ,   1   ,   5   ,   21  ,   75  ,   247 ,   127 ,   223 ,   103 ,   1737    ,   6577    ,   389 ,   26319   ,   20005   ,0 };
            const std::uint32_t dim3910Kuo2Init[]       =   {   1   ,   1   ,   1   ,   5   ,   15  ,   55  ,   33  ,   171 ,   115 ,   535 ,   1523    ,   383 ,   2029    ,   16339   ,   12799   ,   46209   ,0 };
            const std::uint32_t dim3911Kuo2Init[]       =   {   1   ,   1   ,   5   ,   5   ,   21  ,   39  ,   9   ,   239 ,   221 ,   497 ,   913 ,   2465    ,   561 ,   15701   ,   18851   ,   11207   ,0 };
            const std::uint32_t dim3912Kuo2Init[]       =   {   1   ,   3   ,   7   ,   3   ,   5   ,   33  ,   97  ,   227 ,   91  ,   283 ,   1971    ,   3791    ,   2313    ,   9519    ,   11039   ,   46973   ,0 };
            const std::uint32_t dim3913Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   1   ,   35  ,   1   ,   23  ,   391 ,   365 ,   1099    ,   429 ,   5159    ,   409 ,   17641   ,   55545   ,0 };
            const std::uint32_t dim3914Kuo2Init[]       =   {   1   ,   3   ,   7   ,   9   ,   29  ,   11  ,   5   ,   63  ,   1   ,   401 ,   265 ,   753 ,   6933    ,   899 ,   10407   ,   21391   ,0 };
            const std::uint32_t dim3915Kuo2Init[]       =   {   1   ,   1   ,   3   ,   5   ,   25  ,   7   ,   95  ,   251 ,   241 ,   625 ,   661 ,   829 ,   1077    ,   2157    ,   27767   ,   32355   ,0 };
            const std::uint32_t dim3916Kuo2Init[]       =   {   1   ,   3   ,   7   ,   3   ,   21  ,   17  ,   63  ,   85  ,   83  ,   507 ,   265 ,   1183    ,   6095    ,   343 ,   11011   ,   39071   ,0 };
            const std::uint32_t dim3917Kuo2Init[]       =   {   1   ,   3   ,   7   ,   11  ,   7   ,   23  ,   17  ,   67  ,   83  ,   875 ,   1487    ,   2565    ,   6619    ,   8651    ,   31249   ,   28487   ,0 };
            const std::uint32_t dim3918Kuo2Init[]       =   {   1   ,   3   ,   3   ,   7   ,   9   ,   27  ,   63  ,   23  ,   107 ,   103 ,   1059    ,   2029    ,   1417    ,   8883    ,   7003    ,   4729    ,0 };
            const std::uint32_t dim3919Kuo2Init[]       =   {   1   ,   1   ,   1   ,   11  ,   5   ,   53  ,   67  ,   41  ,   227 ,   643 ,   1767    ,   615 ,   2165    ,   14475   ,   21143   ,   22079   ,0 };
            const std::uint32_t dim3920Kuo2Init[]       =   {   1   ,   1   ,   7   ,   7   ,   1   ,   19  ,   77  ,   211 ,   379 ,   173 ,   1097    ,   3865    ,   3735    ,   10719   ,   9223    ,   209 ,0 };
            const std::uint32_t dim3921Kuo2Init[]       =   {   1   ,   1   ,   5   ,   7   ,   31  ,   53  ,   77  ,   73  ,   329 ,   587 ,   1121    ,   2139    ,   7433    ,   9569    ,   20289   ,   47867   ,0 };
            const std::uint32_t dim3922Kuo2Init[]       =   {   1   ,   1   ,   3   ,   3   ,   7   ,   21  ,   19  ,   181 ,   209 ,   603 ,   885 ,   2251    ,   1563    ,   6435    ,   9455    ,   1753    ,0 };
            const std::uint32_t dim3923Kuo2Init[]       =   {   1   ,   1   ,   5   ,   11  ,   5   ,   7   ,   67  ,   111 ,   355 ,   457 ,   193 ,   1311    ,   5987    ,   5223    ,   13489   ,   49679   ,0 };
            const std::uint32_t dim3924Kuo2Init[]       =   {   1   ,   1   ,   3   ,   9   ,   23  ,   11  ,   21  ,   217 ,   361 ,   803 ,   325 ,   2767    ,   3363    ,   9753    ,   26523   ,   20517   ,0 };
            const std::uint32_t dim3925Kuo2Init[]       =   {   1   ,   3   ,   5   ,   11  ,   27  ,   13  ,   71  ,   127 ,   249 ,   49  ,   153 ,   4017    ,   289 ,   10705   ,   19671   ,   21929   ,0 };
            const std::uint32_t dim3926Kuo2Init[]       =   {   1   ,   1   ,   5   ,   5   ,   13  ,   51  ,   113 ,   109 ,   135 ,   507 ,   719 ,   2011    ,   3803    ,   12049   ,   13629   ,   50781   ,0 };
            const std::uint32_t dim3927Kuo2Init[]       =   {   1   ,   3   ,   1   ,   9   ,   5   ,   33  ,   125 ,   223 ,   309 ,   909 ,   1209    ,   3099    ,   3431    ,   853 ,   2553    ,   1845    ,0 };
            const std::uint32_t dim3928Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   21  ,   61  ,   63  ,   21  ,   485 ,   101 ,   1307    ,   3777    ,   6331    ,   3549    ,   20867   ,   41487   ,0 };
            const std::uint32_t dim3929Kuo2Init[]       =   {   1   ,   3   ,   7   ,   1   ,   1   ,   33  ,   115 ,   97  ,   445 ,   521 ,   1801    ,   2869    ,   7893    ,   10229   ,   27265   ,   7749    ,0 };
            const std::uint32_t dim3930Kuo2Init[]       =   {   1   ,   1   ,   1   ,   15  ,   7   ,   25  ,   23  ,   87  ,   277 ,   699 ,   783 ,   2891    ,   5033    ,   14031   ,   22947   ,   15921   ,0 };
            const std::uint32_t dim3931Kuo2Init[]       =   {   1   ,   3   ,   5   ,   11  ,   17  ,   1   ,   53  ,   195 ,   125 ,   937 ,   739 ,   999 ,   1729    ,   14809   ,   16855   ,   16407   ,0 };
            const std::uint32_t dim3932Kuo2Init[]       =   {   1   ,   1   ,   7   ,   15  ,   11  ,   21  ,   13  ,   205 ,   367 ,   167 ,   1967    ,   4003    ,   1145    ,   5679    ,   26437   ,   27597   ,0 };
            const std::uint32_t dim3933Kuo2Init[]       =   {   1   ,   1   ,   1   ,   15  ,   15  ,   45  ,   51  ,   23  ,   51  ,   279 ,   1463    ,   1585    ,   5863    ,   6625    ,   32427   ,   33877   ,0 };
            const std::uint32_t dim3934Kuo2Init[]       =   {   1   ,   1   ,   1   ,   9   ,   9   ,   47  ,   83  ,   61  ,   493 ,   399 ,   1055    ,   231 ,   671 ,   11643   ,   9151    ,   48169   ,0 };
            const std::uint32_t dim3935Kuo2Init[]       =   {   1   ,   3   ,   1   ,   13  ,   9   ,   43  ,   3   ,   119 ,   439 ,   335 ,   1167    ,   249 ,   193 ,   4305    ,   8821    ,   49611   ,0 };
            const std::uint32_t dim3936Kuo2Init[]       =   {   1   ,   3   ,   5   ,   1   ,   19  ,   55  ,   43  ,   251 ,   17  ,   865 ,   147 ,   507 ,   1315    ,   12029   ,   5077    ,   6003    ,0 };
            const std::uint32_t dim3937Kuo2Init[]       =   {   1   ,   3   ,   7   ,   7   ,   3   ,   23  ,   83  ,   7   ,   241 ,   197 ,   139 ,   1325    ,   7777    ,   8425    ,   27451   ,   47015   ,0 };
            const std::uint32_t dim3938Kuo2Init[]       =   {   1   ,   1   ,   3   ,   3   ,   27  ,   29  ,   37  ,   31  ,   325 ,   937 ,   59  ,   2615    ,   7331    ,   15635   ,   29159   ,   49697   ,0 };
            const std::uint32_t dim3939Kuo2Init[]       =   {   1   ,   3   ,   3   ,   5   ,   27  ,   47  ,   125 ,   165 ,   363 ,   573 ,   189 ,   3249    ,   1471    ,   7869    ,   6169    ,   43525   ,0 };
            const std::uint32_t dim3940Kuo2Init[]       =   {   1   ,   1   ,   3   ,   13  ,   19  ,   33  ,   15  ,   123 ,   245 ,   939 ,   209 ,   853 ,   6485    ,   5059    ,   21891   ,   7115    ,0 };
            const std::uint32_t dim3941Kuo2Init[]       =   {   1   ,   3   ,   7   ,   1   ,   23  ,   59  ,   91  ,   197 ,   79  ,   381 ,   151 ,   3533    ,   7553    ,   511 ,   3381    ,   29339   ,0 };
            const std::uint32_t dim3942Kuo2Init[]       =   {   1   ,   3   ,   5   ,   3   ,   21  ,   61  ,   73  ,   57  ,   317 ,   77  ,   2027    ,   1055    ,   3599    ,   15157   ,   17017   ,   23563   ,0 };
            const std::uint32_t dim3943Kuo2Init[]       =   {   1   ,   1   ,   7   ,   1   ,   15  ,   43  ,   97  ,   205 ,   421 ,   901 ,   1589    ,   2051    ,   5737    ,   13231   ,   15325   ,   54725   ,0 };
            const std::uint32_t dim3944Kuo2Init[]       =   {   1   ,   1   ,   5   ,   5   ,   31  ,   33  ,   93  ,   129 ,   385 ,   961 ,   733 ,   277 ,   3555    ,   5619    ,   16499   ,   57747   ,0 };
            const std::uint32_t dim3945Kuo2Init[]       =   {   1   ,   3   ,   1   ,   5   ,   17  ,   3   ,   65  ,   167 ,   237 ,   785 ,   771 ,   4033    ,   6053    ,   343 ,   9499    ,   55861   ,0 };
            const std::uint32_t dim3946Kuo2Init[]       =   {   1   ,   3   ,   3   ,   3   ,   19  ,   57  ,   23  ,   119 ,   75  ,   435 ,   1023    ,   2357    ,   4671    ,   14581   ,   15343   ,   2383    ,0 };

            const std::uint32_t * const Kuo2initializers[3946]
            =
            {
                dim1Kuo2Init,
                dim2Kuo2Init,
                dim3Kuo2Init,
                dim4Kuo2Init,
                dim5Kuo2Init,
                dim6Kuo2Init,
                dim7Kuo2Init,
                dim8Kuo2Init,
                dim9Kuo2Init,
                dim10Kuo2Init,
                dim11Kuo2Init,
                dim12Kuo2Init,
                dim13Kuo2Init,
                dim14Kuo2Init,
                dim15Kuo2Init,
                dim16Kuo2Init,
                dim17Kuo2Init,
                dim18Kuo2Init,
                dim19Kuo2Init,
                dim20Kuo2Init,
                dim21Kuo2Init,
                dim22Kuo2Init,
                dim23Kuo2Init,
                dim24Kuo2Init,
                dim25Kuo2Init,
                dim26Kuo2Init,
                dim27Kuo2Init,
                dim28Kuo2Init,
                dim29Kuo2Init,
                dim30Kuo2Init,
                dim31Kuo2Init,
                dim32Kuo2Init,
                dim33Kuo2Init,
                dim34Kuo2Init,
                dim35Kuo2Init,
                dim36Kuo2Init,
                dim37Kuo2Init,
                dim38Kuo2Init,
                dim39Kuo2Init,
                dim40Kuo2Init,
                dim41Kuo2Init,
                dim42Kuo2Init,
                dim43Kuo2Init,
                dim44Kuo2Init,
                dim45Kuo2Init,
                dim46Kuo2Init,
                dim47Kuo2Init,
                dim48Kuo2Init,
                dim49Kuo2Init,
                dim50Kuo2Init,
                dim51Kuo2Init,
                dim52Kuo2Init,
                dim53Kuo2Init,
                dim54Kuo2Init,
                dim55Kuo2Init,
                dim56Kuo2Init,
                dim57Kuo2Init,
                dim58Kuo2Init,
                dim59Kuo2Init,
                dim60Kuo2Init,
                dim61Kuo2Init,
                dim62Kuo2Init,
                dim63Kuo2Init,
                dim64Kuo2Init,
                dim65Kuo2Init,
                dim66Kuo2Init,
                dim67Kuo2Init,
                dim68Kuo2Init,
                dim69Kuo2Init,
                dim70Kuo2Init,
                dim71Kuo2Init,
                dim72Kuo2Init,
                dim73Kuo2Init,
                dim74Kuo2Init,
                dim75Kuo2Init,
                dim76Kuo2Init,
                dim77Kuo2Init,
                dim78Kuo2Init,
                dim79Kuo2Init,
                dim80Kuo2Init,
                dim81Kuo2Init,
                dim82Kuo2Init,
                dim83Kuo2Init,
                dim84Kuo2Init,
                dim85Kuo2Init,
                dim86Kuo2Init,
                dim87Kuo2Init,
                dim88Kuo2Init,
                dim89Kuo2Init,
                dim90Kuo2Init,
                dim91Kuo2Init,
                dim92Kuo2Init,
                dim93Kuo2Init,
                dim94Kuo2Init,
                dim95Kuo2Init,
                dim96Kuo2Init,
                dim97Kuo2Init,
                dim98Kuo2Init,
                dim99Kuo2Init,
                dim100Kuo2Init,
                dim101Kuo2Init,
                dim102Kuo2Init,
                dim103Kuo2Init,
                dim104Kuo2Init,
                dim105Kuo2Init,
                dim106Kuo2Init,
                dim107Kuo2Init,
                dim108Kuo2Init,
                dim109Kuo2Init,
                dim110Kuo2Init,
                dim111Kuo2Init,
                dim112Kuo2Init,
                dim113Kuo2Init,
                dim114Kuo2Init,
                dim115Kuo2Init,
                dim116Kuo2Init,
                dim117Kuo2Init,
                dim118Kuo2Init,
                dim119Kuo2Init,
                dim120Kuo2Init,
                dim121Kuo2Init,
                dim122Kuo2Init,
                dim123Kuo2Init,
                dim124Kuo2Init,
                dim125Kuo2Init,
                dim126Kuo2Init,
                dim127Kuo2Init,
                dim128Kuo2Init,
                dim129Kuo2Init,
                dim130Kuo2Init,
                dim131Kuo2Init,
                dim132Kuo2Init,
                dim133Kuo2Init,
                dim134Kuo2Init,
                dim135Kuo2Init,
                dim136Kuo2Init,
                dim137Kuo2Init,
                dim138Kuo2Init,
                dim139Kuo2Init,
                dim140Kuo2Init,
                dim141Kuo2Init,
                dim142Kuo2Init,
                dim143Kuo2Init,
                dim144Kuo2Init,
                dim145Kuo2Init,
                dim146Kuo2Init,
                dim147Kuo2Init,
                dim148Kuo2Init,
                dim149Kuo2Init,
                dim150Kuo2Init,
                dim151Kuo2Init,
                dim152Kuo2Init,
                dim153Kuo2Init,
                dim154Kuo2Init,
                dim155Kuo2Init,
                dim156Kuo2Init,
                dim157Kuo2Init,
                dim158Kuo2Init,
                dim159Kuo2Init,
                dim160Kuo2Init,
                dim161Kuo2Init,
                dim162Kuo2Init,
                dim163Kuo2Init,
                dim164Kuo2Init,
                dim165Kuo2Init,
                dim166Kuo2Init,
                dim167Kuo2Init,
                dim168Kuo2Init,
                dim169Kuo2Init,
                dim170Kuo2Init,
                dim171Kuo2Init,
                dim172Kuo2Init,
                dim173Kuo2Init,
                dim174Kuo2Init,
                dim175Kuo2Init,
                dim176Kuo2Init,
                dim177Kuo2Init,
                dim178Kuo2Init,
                dim179Kuo2Init,
                dim180Kuo2Init,
                dim181Kuo2Init,
                dim182Kuo2Init,
                dim183Kuo2Init,
                dim184Kuo2Init,
                dim185Kuo2Init,
                dim186Kuo2Init,
                dim187Kuo2Init,
                dim188Kuo2Init,
                dim189Kuo2Init,
                dim190Kuo2Init,
                dim191Kuo2Init,
                dim192Kuo2Init,
                dim193Kuo2Init,
                dim194Kuo2Init,
                dim195Kuo2Init,
                dim196Kuo2Init,
                dim197Kuo2Init,
                dim198Kuo2Init,
                dim199Kuo2Init,
                dim200Kuo2Init,
                dim201Kuo2Init,
                dim202Kuo2Init,
                dim203Kuo2Init,
                dim204Kuo2Init,
                dim205Kuo2Init,
                dim206Kuo2Init,
                dim207Kuo2Init,
                dim208Kuo2Init,
                dim209Kuo2Init,
                dim210Kuo2Init,
                dim211Kuo2Init,
                dim212Kuo2Init,
                dim213Kuo2Init,
                dim214Kuo2Init,
                dim215Kuo2Init,
                dim216Kuo2Init,
                dim217Kuo2Init,
                dim218Kuo2Init,
                dim219Kuo2Init,
                dim220Kuo2Init,
                dim221Kuo2Init,
                dim222Kuo2Init,
                dim223Kuo2Init,
                dim224Kuo2Init,
                dim225Kuo2Init,
                dim226Kuo2Init,
                dim227Kuo2Init,
                dim228Kuo2Init,
                dim229Kuo2Init,
                dim230Kuo2Init,
                dim231Kuo2Init,
                dim232Kuo2Init,
                dim233Kuo2Init,
                dim234Kuo2Init,
                dim235Kuo2Init,
                dim236Kuo2Init,
                dim237Kuo2Init,
                dim238Kuo2Init,
                dim239Kuo2Init,
                dim240Kuo2Init,
                dim241Kuo2Init,
                dim242Kuo2Init,
                dim243Kuo2Init,
                dim244Kuo2Init,
                dim245Kuo2Init,
                dim246Kuo2Init,
                dim247Kuo2Init,
                dim248Kuo2Init,
                dim249Kuo2Init,
                dim250Kuo2Init,
                dim251Kuo2Init,
                dim252Kuo2Init,
                dim253Kuo2Init,
                dim254Kuo2Init,
                dim255Kuo2Init,
                dim256Kuo2Init,
                dim257Kuo2Init,
                dim258Kuo2Init,
                dim259Kuo2Init,
                dim260Kuo2Init,
                dim261Kuo2Init,
                dim262Kuo2Init,
                dim263Kuo2Init,
                dim264Kuo2Init,
                dim265Kuo2Init,
                dim266Kuo2Init,
                dim267Kuo2Init,
                dim268Kuo2Init,
                dim269Kuo2Init,
                dim270Kuo2Init,
                dim271Kuo2Init,
                dim272Kuo2Init,
                dim273Kuo2Init,
                dim274Kuo2Init,
                dim275Kuo2Init,
                dim276Kuo2Init,
                dim277Kuo2Init,
                dim278Kuo2Init,
                dim279Kuo2Init,
                dim280Kuo2Init,
                dim281Kuo2Init,
                dim282Kuo2Init,
                dim283Kuo2Init,
                dim284Kuo2Init,
                dim285Kuo2Init,
                dim286Kuo2Init,
                dim287Kuo2Init,
                dim288Kuo2Init,
                dim289Kuo2Init,
                dim290Kuo2Init,
                dim291Kuo2Init,
                dim292Kuo2Init,
                dim293Kuo2Init,
                dim294Kuo2Init,
                dim295Kuo2Init,
                dim296Kuo2Init,
                dim297Kuo2Init,
                dim298Kuo2Init,
                dim299Kuo2Init,
                dim300Kuo2Init,
                dim301Kuo2Init,
                dim302Kuo2Init,
                dim303Kuo2Init,
                dim304Kuo2Init,
                dim305Kuo2Init,
                dim306Kuo2Init,
                dim307Kuo2Init,
                dim308Kuo2Init,
                dim309Kuo2Init,
                dim310Kuo2Init,
                dim311Kuo2Init,
                dim312Kuo2Init,
                dim313Kuo2Init,
                dim314Kuo2Init,
                dim315Kuo2Init,
                dim316Kuo2Init,
                dim317Kuo2Init,
                dim318Kuo2Init,
                dim319Kuo2Init,
                dim320Kuo2Init,
                dim321Kuo2Init,
                dim322Kuo2Init,
                dim323Kuo2Init,
                dim324Kuo2Init,
                dim325Kuo2Init,
                dim326Kuo2Init,
                dim327Kuo2Init,
                dim328Kuo2Init,
                dim329Kuo2Init,
                dim330Kuo2Init,
                dim331Kuo2Init,
                dim332Kuo2Init,
                dim333Kuo2Init,
                dim334Kuo2Init,
                dim335Kuo2Init,
                dim336Kuo2Init,
                dim337Kuo2Init,
                dim338Kuo2Init,
                dim339Kuo2Init,
                dim340Kuo2Init,
                dim341Kuo2Init,
                dim342Kuo2Init,
                dim343Kuo2Init,
                dim344Kuo2Init,
                dim345Kuo2Init,
                dim346Kuo2Init,
                dim347Kuo2Init,
                dim348Kuo2Init,
                dim349Kuo2Init,
                dim350Kuo2Init,
                dim351Kuo2Init,
                dim352Kuo2Init,
                dim353Kuo2Init,
                dim354Kuo2Init,
                dim355Kuo2Init,
                dim356Kuo2Init,
                dim357Kuo2Init,
                dim358Kuo2Init,
                dim359Kuo2Init,
                dim360Kuo2Init,
                dim361Kuo2Init,
                dim362Kuo2Init,
                dim363Kuo2Init,
                dim364Kuo2Init,
                dim365Kuo2Init,
                dim366Kuo2Init,
                dim367Kuo2Init,
                dim368Kuo2Init,
                dim369Kuo2Init,
                dim370Kuo2Init,
                dim371Kuo2Init,
                dim372Kuo2Init,
                dim373Kuo2Init,
                dim374Kuo2Init,
                dim375Kuo2Init,
                dim376Kuo2Init,
                dim377Kuo2Init,
                dim378Kuo2Init,
                dim379Kuo2Init,
                dim380Kuo2Init,
                dim381Kuo2Init,
                dim382Kuo2Init,
                dim383Kuo2Init,
                dim384Kuo2Init,
                dim385Kuo2Init,
                dim386Kuo2Init,
                dim387Kuo2Init,
                dim388Kuo2Init,
                dim389Kuo2Init,
                dim390Kuo2Init,
                dim391Kuo2Init,
                dim392Kuo2Init,
                dim393Kuo2Init,
                dim394Kuo2Init,
                dim395Kuo2Init,
                dim396Kuo2Init,
                dim397Kuo2Init,
                dim398Kuo2Init,
                dim399Kuo2Init,
                dim400Kuo2Init,
                dim401Kuo2Init,
                dim402Kuo2Init,
                dim403Kuo2Init,
                dim404Kuo2Init,
                dim405Kuo2Init,
                dim406Kuo2Init,
                dim407Kuo2Init,
                dim408Kuo2Init,
                dim409Kuo2Init,
                dim410Kuo2Init,
                dim411Kuo2Init,
                dim412Kuo2Init,
                dim413Kuo2Init,
                dim414Kuo2Init,
                dim415Kuo2Init,
                dim416Kuo2Init,
                dim417Kuo2Init,
                dim418Kuo2Init,
                dim419Kuo2Init,
                dim420Kuo2Init,
                dim421Kuo2Init,
                dim422Kuo2Init,
                dim423Kuo2Init,
                dim424Kuo2Init,
                dim425Kuo2Init,
                dim426Kuo2Init,
                dim427Kuo2Init,
                dim428Kuo2Init,
                dim429Kuo2Init,
                dim430Kuo2Init,
                dim431Kuo2Init,
                dim432Kuo2Init,
                dim433Kuo2Init,
                dim434Kuo2Init,
                dim435Kuo2Init,
                dim436Kuo2Init,
                dim437Kuo2Init,
                dim438Kuo2Init,
                dim439Kuo2Init,
                dim440Kuo2Init,
                dim441Kuo2Init,
                dim442Kuo2Init,
                dim443Kuo2Init,
                dim444Kuo2Init,
                dim445Kuo2Init,
                dim446Kuo2Init,
                dim447Kuo2Init,
                dim448Kuo2Init,
                dim449Kuo2Init,
                dim450Kuo2Init,
                dim451Kuo2Init,
                dim452Kuo2Init,
                dim453Kuo2Init,
                dim454Kuo2Init,
                dim455Kuo2Init,
                dim456Kuo2Init,
                dim457Kuo2Init,
                dim458Kuo2Init,
                dim459Kuo2Init,
                dim460Kuo2Init,
                dim461Kuo2Init,
                dim462Kuo2Init,
                dim463Kuo2Init,
                dim464Kuo2Init,
                dim465Kuo2Init,
                dim466Kuo2Init,
                dim467Kuo2Init,
                dim468Kuo2Init,
                dim469Kuo2Init,
                dim470Kuo2Init,
                dim471Kuo2Init,
                dim472Kuo2Init,
                dim473Kuo2Init,
                dim474Kuo2Init,
                dim475Kuo2Init,
                dim476Kuo2Init,
                dim477Kuo2Init,
                dim478Kuo2Init,
                dim479Kuo2Init,
                dim480Kuo2Init,
                dim481Kuo2Init,
                dim482Kuo2Init,
                dim483Kuo2Init,
                dim484Kuo2Init,
                dim485Kuo2Init,
                dim486Kuo2Init,
                dim487Kuo2Init,
                dim488Kuo2Init,
                dim489Kuo2Init,
                dim490Kuo2Init,
                dim491Kuo2Init,
                dim492Kuo2Init,
                dim493Kuo2Init,
                dim494Kuo2Init,
                dim495Kuo2Init,
                dim496Kuo2Init,
                dim497Kuo2Init,
                dim498Kuo2Init,
                dim499Kuo2Init,
                dim500Kuo2Init,
                dim501Kuo2Init,
                dim502Kuo2Init,
                dim503Kuo2Init,
                dim504Kuo2Init,
                dim505Kuo2Init,
                dim506Kuo2Init,
                dim507Kuo2Init,
                dim508Kuo2Init,
                dim509Kuo2Init,
                dim510Kuo2Init,
                dim511Kuo2Init,
                dim512Kuo2Init,
                dim513Kuo2Init,
                dim514Kuo2Init,
                dim515Kuo2Init,
                dim516Kuo2Init,
                dim517Kuo2Init,
                dim518Kuo2Init,
                dim519Kuo2Init,
                dim520Kuo2Init,
                dim521Kuo2Init,
                dim522Kuo2Init,
                dim523Kuo2Init,
                dim524Kuo2Init,
                dim525Kuo2Init,
                dim526Kuo2Init,
                dim527Kuo2Init,
                dim528Kuo2Init,
                dim529Kuo2Init,
                dim530Kuo2Init,
                dim531Kuo2Init,
                dim532Kuo2Init,
                dim533Kuo2Init,
                dim534Kuo2Init,
                dim535Kuo2Init,
                dim536Kuo2Init,
                dim537Kuo2Init,
                dim538Kuo2Init,
                dim539Kuo2Init,
                dim540Kuo2Init,
                dim541Kuo2Init,
                dim542Kuo2Init,
                dim543Kuo2Init,
                dim544Kuo2Init,
                dim545Kuo2Init,
                dim546Kuo2Init,
                dim547Kuo2Init,
                dim548Kuo2Init,
                dim549Kuo2Init,
                dim550Kuo2Init,
                dim551Kuo2Init,
                dim552Kuo2Init,
                dim553Kuo2Init,
                dim554Kuo2Init,
                dim555Kuo2Init,
                dim556Kuo2Init,
                dim557Kuo2Init,
                dim558Kuo2Init,
                dim559Kuo2Init,
                dim560Kuo2Init,
                dim561Kuo2Init,
                dim562Kuo2Init,
                dim563Kuo2Init,
                dim564Kuo2Init,
                dim565Kuo2Init,
                dim566Kuo2Init,
                dim567Kuo2Init,
                dim568Kuo2Init,
                dim569Kuo2Init,
                dim570Kuo2Init,
                dim571Kuo2Init,
                dim572Kuo2Init,
                dim573Kuo2Init,
                dim574Kuo2Init,
                dim575Kuo2Init,
                dim576Kuo2Init,
                dim577Kuo2Init,
                dim578Kuo2Init,
                dim579Kuo2Init,
                dim580Kuo2Init,
                dim581Kuo2Init,
                dim582Kuo2Init,
                dim583Kuo2Init,
                dim584Kuo2Init,
                dim585Kuo2Init,
                dim586Kuo2Init,
                dim587Kuo2Init,
                dim588Kuo2Init,
                dim589Kuo2Init,
                dim590Kuo2Init,
                dim591Kuo2Init,
                dim592Kuo2Init,
                dim593Kuo2Init,
                dim594Kuo2Init,
                dim595Kuo2Init,
                dim596Kuo2Init,
                dim597Kuo2Init,
                dim598Kuo2Init,
                dim599Kuo2Init,
                dim600Kuo2Init,
                dim601Kuo2Init,
                dim602Kuo2Init,
                dim603Kuo2Init,
                dim604Kuo2Init,
                dim605Kuo2Init,
                dim606Kuo2Init,
                dim607Kuo2Init,
                dim608Kuo2Init,
                dim609Kuo2Init,
                dim610Kuo2Init,
                dim611Kuo2Init,
                dim612Kuo2Init,
                dim613Kuo2Init,
                dim614Kuo2Init,
                dim615Kuo2Init,
                dim616Kuo2Init,
                dim617Kuo2Init,
                dim618Kuo2Init,
                dim619Kuo2Init,
                dim620Kuo2Init,
                dim621Kuo2Init,
                dim622Kuo2Init,
                dim623Kuo2Init,
                dim624Kuo2Init,
                dim625Kuo2Init,
                dim626Kuo2Init,
                dim627Kuo2Init,
                dim628Kuo2Init,
                dim629Kuo2Init,
                dim630Kuo2Init,
                dim631Kuo2Init,
                dim632Kuo2Init,
                dim633Kuo2Init,
                dim634Kuo2Init,
                dim635Kuo2Init,
                dim636Kuo2Init,
                dim637Kuo2Init,
                dim638Kuo2Init,
                dim639Kuo2Init,
                dim640Kuo2Init,
                dim641Kuo2Init,
                dim642Kuo2Init,
                dim643Kuo2Init,
                dim644Kuo2Init,
                dim645Kuo2Init,
                dim646Kuo2Init,
                dim647Kuo2Init,
                dim648Kuo2Init,
                dim649Kuo2Init,
                dim650Kuo2Init,
                dim651Kuo2Init,
                dim652Kuo2Init,
                dim653Kuo2Init,
                dim654Kuo2Init,
                dim655Kuo2Init,
                dim656Kuo2Init,
                dim657Kuo2Init,
                dim658Kuo2Init,
                dim659Kuo2Init,
                dim660Kuo2Init,
                dim661Kuo2Init,
                dim662Kuo2Init,
                dim663Kuo2Init,
                dim664Kuo2Init,
                dim665Kuo2Init,
                dim666Kuo2Init,
                dim667Kuo2Init,
                dim668Kuo2Init,
                dim669Kuo2Init,
                dim670Kuo2Init,
                dim671Kuo2Init,
                dim672Kuo2Init,
                dim673Kuo2Init,
                dim674Kuo2Init,
                dim675Kuo2Init,
                dim676Kuo2Init,
                dim677Kuo2Init,
                dim678Kuo2Init,
                dim679Kuo2Init,
                dim680Kuo2Init,
                dim681Kuo2Init,
                dim682Kuo2Init,
                dim683Kuo2Init,
                dim684Kuo2Init,
                dim685Kuo2Init,
                dim686Kuo2Init,
                dim687Kuo2Init,
                dim688Kuo2Init,
                dim689Kuo2Init,
                dim690Kuo2Init,
                dim691Kuo2Init,
                dim692Kuo2Init,
                dim693Kuo2Init,
                dim694Kuo2Init,
                dim695Kuo2Init,
                dim696Kuo2Init,
                dim697Kuo2Init,
                dim698Kuo2Init,
                dim699Kuo2Init,
                dim700Kuo2Init,
                dim701Kuo2Init,
                dim702Kuo2Init,
                dim703Kuo2Init,
                dim704Kuo2Init,
                dim705Kuo2Init,
                dim706Kuo2Init,
                dim707Kuo2Init,
                dim708Kuo2Init,
                dim709Kuo2Init,
                dim710Kuo2Init,
                dim711Kuo2Init,
                dim712Kuo2Init,
                dim713Kuo2Init,
                dim714Kuo2Init,
                dim715Kuo2Init,
                dim716Kuo2Init,
                dim717Kuo2Init,
                dim718Kuo2Init,
                dim719Kuo2Init,
                dim720Kuo2Init,
                dim721Kuo2Init,
                dim722Kuo2Init,
                dim723Kuo2Init,
                dim724Kuo2Init,
                dim725Kuo2Init,
                dim726Kuo2Init,
                dim727Kuo2Init,
                dim728Kuo2Init,
                dim729Kuo2Init,
                dim730Kuo2Init,
                dim731Kuo2Init,
                dim732Kuo2Init,
                dim733Kuo2Init,
                dim734Kuo2Init,
                dim735Kuo2Init,
                dim736Kuo2Init,
                dim737Kuo2Init,
                dim738Kuo2Init,
                dim739Kuo2Init,
                dim740Kuo2Init,
                dim741Kuo2Init,
                dim742Kuo2Init,
                dim743Kuo2Init,
                dim744Kuo2Init,
                dim745Kuo2Init,
                dim746Kuo2Init,
                dim747Kuo2Init,
                dim748Kuo2Init,
                dim749Kuo2Init,
                dim750Kuo2Init,
                dim751Kuo2Init,
                dim752Kuo2Init,
                dim753Kuo2Init,
                dim754Kuo2Init,
                dim755Kuo2Init,
                dim756Kuo2Init,
                dim757Kuo2Init,
                dim758Kuo2Init,
                dim759Kuo2Init,
                dim760Kuo2Init,
                dim761Kuo2Init,
                dim762Kuo2Init,
                dim763Kuo2Init,
                dim764Kuo2Init,
                dim765Kuo2Init,
                dim766Kuo2Init,
                dim767Kuo2Init,
                dim768Kuo2Init,
                dim769Kuo2Init,
                dim770Kuo2Init,
                dim771Kuo2Init,
                dim772Kuo2Init,
                dim773Kuo2Init,
                dim774Kuo2Init,
                dim775Kuo2Init,
                dim776Kuo2Init,
                dim777Kuo2Init,
                dim778Kuo2Init,
                dim779Kuo2Init,
                dim780Kuo2Init,
                dim781Kuo2Init,
                dim782Kuo2Init,
                dim783Kuo2Init,
                dim784Kuo2Init,
                dim785Kuo2Init,
                dim786Kuo2Init,
                dim787Kuo2Init,
                dim788Kuo2Init,
                dim789Kuo2Init,
                dim790Kuo2Init,
                dim791Kuo2Init,
                dim792Kuo2Init,
                dim793Kuo2Init,
                dim794Kuo2Init,
                dim795Kuo2Init,
                dim796Kuo2Init,
                dim797Kuo2Init,
                dim798Kuo2Init,
                dim799Kuo2Init,
                dim800Kuo2Init,
                dim801Kuo2Init,
                dim802Kuo2Init,
                dim803Kuo2Init,
                dim804Kuo2Init,
                dim805Kuo2Init,
                dim806Kuo2Init,
                dim807Kuo2Init,
                dim808Kuo2Init,
                dim809Kuo2Init,
                dim810Kuo2Init,
                dim811Kuo2Init,
                dim812Kuo2Init,
                dim813Kuo2Init,
                dim814Kuo2Init,
                dim815Kuo2Init,
                dim816Kuo2Init,
                dim817Kuo2Init,
                dim818Kuo2Init,
                dim819Kuo2Init,
                dim820Kuo2Init,
                dim821Kuo2Init,
                dim822Kuo2Init,
                dim823Kuo2Init,
                dim824Kuo2Init,
                dim825Kuo2Init,
                dim826Kuo2Init,
                dim827Kuo2Init,
                dim828Kuo2Init,
                dim829Kuo2Init,
                dim830Kuo2Init,
                dim831Kuo2Init,
                dim832Kuo2Init,
                dim833Kuo2Init,
                dim834Kuo2Init,
                dim835Kuo2Init,
                dim836Kuo2Init,
                dim837Kuo2Init,
                dim838Kuo2Init,
                dim839Kuo2Init,
                dim840Kuo2Init,
                dim841Kuo2Init,
                dim842Kuo2Init,
                dim843Kuo2Init,
                dim844Kuo2Init,
                dim845Kuo2Init,
                dim846Kuo2Init,
                dim847Kuo2Init,
                dim848Kuo2Init,
                dim849Kuo2Init,
                dim850Kuo2Init,
                dim851Kuo2Init,
                dim852Kuo2Init,
                dim853Kuo2Init,
                dim854Kuo2Init,
                dim855Kuo2Init,
                dim856Kuo2Init,
                dim857Kuo2Init,
                dim858Kuo2Init,
                dim859Kuo2Init,
                dim860Kuo2Init,
                dim861Kuo2Init,
                dim862Kuo2Init,
                dim863Kuo2Init,
                dim864Kuo2Init,
                dim865Kuo2Init,
                dim866Kuo2Init,
                dim867Kuo2Init,
                dim868Kuo2Init,
                dim869Kuo2Init,
                dim870Kuo2Init,
                dim871Kuo2Init,
                dim872Kuo2Init,
                dim873Kuo2Init,
                dim874Kuo2Init,
                dim875Kuo2Init,
                dim876Kuo2Init,
                dim877Kuo2Init,
                dim878Kuo2Init,
                dim879Kuo2Init,
                dim880Kuo2Init,
                dim881Kuo2Init,
                dim882Kuo2Init,
                dim883Kuo2Init,
                dim884Kuo2Init,
                dim885Kuo2Init,
                dim886Kuo2Init,
                dim887Kuo2Init,
                dim888Kuo2Init,
                dim889Kuo2Init,
                dim890Kuo2Init,
                dim891Kuo2Init,
                dim892Kuo2Init,
                dim893Kuo2Init,
                dim894Kuo2Init,
                dim895Kuo2Init,
                dim896Kuo2Init,
                dim897Kuo2Init,
                dim898Kuo2Init,
                dim899Kuo2Init,
                dim900Kuo2Init,
                dim901Kuo2Init,
                dim902Kuo2Init,
                dim903Kuo2Init,
                dim904Kuo2Init,
                dim905Kuo2Init,
                dim906Kuo2Init,
                dim907Kuo2Init,
                dim908Kuo2Init,
                dim909Kuo2Init,
                dim910Kuo2Init,
                dim911Kuo2Init,
                dim912Kuo2Init,
                dim913Kuo2Init,
                dim914Kuo2Init,
                dim915Kuo2Init,
                dim916Kuo2Init,
                dim917Kuo2Init,
                dim918Kuo2Init,
                dim919Kuo2Init,
                dim920Kuo2Init,
                dim921Kuo2Init,
                dim922Kuo2Init,
                dim923Kuo2Init,
                dim924Kuo2Init,
                dim925Kuo2Init,
                dim926Kuo2Init,
                dim927Kuo2Init,
                dim928Kuo2Init,
                dim929Kuo2Init,
                dim930Kuo2Init,
                dim931Kuo2Init,
                dim932Kuo2Init,
                dim933Kuo2Init,
                dim934Kuo2Init,
                dim935Kuo2Init,
                dim936Kuo2Init,
                dim937Kuo2Init,
                dim938Kuo2Init,
                dim939Kuo2Init,
                dim940Kuo2Init,
                dim941Kuo2Init,
                dim942Kuo2Init,
                dim943Kuo2Init,
                dim944Kuo2Init,
                dim945Kuo2Init,
                dim946Kuo2Init,
                dim947Kuo2Init,
                dim948Kuo2Init,
                dim949Kuo2Init,
                dim950Kuo2Init,
                dim951Kuo2Init,
                dim952Kuo2Init,
                dim953Kuo2Init,
                dim954Kuo2Init,
                dim955Kuo2Init,
                dim956Kuo2Init,
                dim957Kuo2Init,
                dim958Kuo2Init,
                dim959Kuo2Init,
                dim960Kuo2Init,
                dim961Kuo2Init,
                dim962Kuo2Init,
                dim963Kuo2Init,
                dim964Kuo2Init,
                dim965Kuo2Init,
                dim966Kuo2Init,
                dim967Kuo2Init,
                dim968Kuo2Init,
                dim969Kuo2Init,
                dim970Kuo2Init,
                dim971Kuo2Init,
                dim972Kuo2Init,
                dim973Kuo2Init,
                dim974Kuo2Init,
                dim975Kuo2Init,
                dim976Kuo2Init,
                dim977Kuo2Init,
                dim978Kuo2Init,
                dim979Kuo2Init,
                dim980Kuo2Init,
                dim981Kuo2Init,
                dim982Kuo2Init,
                dim983Kuo2Init,
                dim984Kuo2Init,
                dim985Kuo2Init,
                dim986Kuo2Init,
                dim987Kuo2Init,
                dim988Kuo2Init,
                dim989Kuo2Init,
                dim990Kuo2Init,
                dim991Kuo2Init,
                dim992Kuo2Init,
                dim993Kuo2Init,
                dim994Kuo2Init,
                dim995Kuo2Init,
                dim996Kuo2Init,
                dim997Kuo2Init,
                dim998Kuo2Init,
                dim999Kuo2Init,
                dim1000Kuo2Init,
                dim1001Kuo2Init,
                dim1002Kuo2Init,
                dim1003Kuo2Init,
                dim1004Kuo2Init,
                dim1005Kuo2Init,
                dim1006Kuo2Init,
                dim1007Kuo2Init,
                dim1008Kuo2Init,
                dim1009Kuo2Init,
                dim1010Kuo2Init,
                dim1011Kuo2Init,
                dim1012Kuo2Init,
                dim1013Kuo2Init,
                dim1014Kuo2Init,
                dim1015Kuo2Init,
                dim1016Kuo2Init,
                dim1017Kuo2Init,
                dim1018Kuo2Init,
                dim1019Kuo2Init,
                dim1020Kuo2Init,
                dim1021Kuo2Init,
                dim1022Kuo2Init,
                dim1023Kuo2Init,
                dim1024Kuo2Init,
                dim1025Kuo2Init,
                dim1026Kuo2Init,
                dim1027Kuo2Init,
                dim1028Kuo2Init,
                dim1029Kuo2Init,
                dim1030Kuo2Init,
                dim1031Kuo2Init,
                dim1032Kuo2Init,
                dim1033Kuo2Init,
                dim1034Kuo2Init,
                dim1035Kuo2Init,
                dim1036Kuo2Init,
                dim1037Kuo2Init,
                dim1038Kuo2Init,
                dim1039Kuo2Init,
                dim1040Kuo2Init,
                dim1041Kuo2Init,
                dim1042Kuo2Init,
                dim1043Kuo2Init,
                dim1044Kuo2Init,
                dim1045Kuo2Init,
                dim1046Kuo2Init,
                dim1047Kuo2Init,
                dim1048Kuo2Init,
                dim1049Kuo2Init,
                dim1050Kuo2Init,
                dim1051Kuo2Init,
                dim1052Kuo2Init,
                dim1053Kuo2Init,
                dim1054Kuo2Init,
                dim1055Kuo2Init,
                dim1056Kuo2Init,
                dim1057Kuo2Init,
                dim1058Kuo2Init,
                dim1059Kuo2Init,
                dim1060Kuo2Init,
                dim1061Kuo2Init,
                dim1062Kuo2Init,
                dim1063Kuo2Init,
                dim1064Kuo2Init,
                dim1065Kuo2Init,
                dim1066Kuo2Init,
                dim1067Kuo2Init,
                dim1068Kuo2Init,
                dim1069Kuo2Init,
                dim1070Kuo2Init,
                dim1071Kuo2Init,
                dim1072Kuo2Init,
                dim1073Kuo2Init,
                dim1074Kuo2Init,
                dim1075Kuo2Init,
                dim1076Kuo2Init,
                dim1077Kuo2Init,
                dim1078Kuo2Init,
                dim1079Kuo2Init,
                dim1080Kuo2Init,
                dim1081Kuo2Init,
                dim1082Kuo2Init,
                dim1083Kuo2Init,
                dim1084Kuo2Init,
                dim1085Kuo2Init,
                dim1086Kuo2Init,
                dim1087Kuo2Init,
                dim1088Kuo2Init,
                dim1089Kuo2Init,
                dim1090Kuo2Init,
                dim1091Kuo2Init,
                dim1092Kuo2Init,
                dim1093Kuo2Init,
                dim1094Kuo2Init,
                dim1095Kuo2Init,
                dim1096Kuo2Init,
                dim1097Kuo2Init,
                dim1098Kuo2Init,
                dim1099Kuo2Init,
                dim1100Kuo2Init,
                dim1101Kuo2Init,
                dim1102Kuo2Init,
                dim1103Kuo2Init,
                dim1104Kuo2Init,
                dim1105Kuo2Init,
                dim1106Kuo2Init,
                dim1107Kuo2Init,
                dim1108Kuo2Init,
                dim1109Kuo2Init,
                dim1110Kuo2Init,
                dim1111Kuo2Init,
                dim1112Kuo2Init,
                dim1113Kuo2Init,
                dim1114Kuo2Init,
                dim1115Kuo2Init,
                dim1116Kuo2Init,
                dim1117Kuo2Init,
                dim1118Kuo2Init,
                dim1119Kuo2Init,
                dim1120Kuo2Init,
                dim1121Kuo2Init,
                dim1122Kuo2Init,
                dim1123Kuo2Init,
                dim1124Kuo2Init,
                dim1125Kuo2Init,
                dim1126Kuo2Init,
                dim1127Kuo2Init,
                dim1128Kuo2Init,
                dim1129Kuo2Init,
                dim1130Kuo2Init,
                dim1131Kuo2Init,
                dim1132Kuo2Init,
                dim1133Kuo2Init,
                dim1134Kuo2Init,
                dim1135Kuo2Init,
                dim1136Kuo2Init,
                dim1137Kuo2Init,
                dim1138Kuo2Init,
                dim1139Kuo2Init,
                dim1140Kuo2Init,
                dim1141Kuo2Init,
                dim1142Kuo2Init,
                dim1143Kuo2Init,
                dim1144Kuo2Init,
                dim1145Kuo2Init,
                dim1146Kuo2Init,
                dim1147Kuo2Init,
                dim1148Kuo2Init,
                dim1149Kuo2Init,
                dim1150Kuo2Init,
                dim1151Kuo2Init,
                dim1152Kuo2Init,
                dim1153Kuo2Init,
                dim1154Kuo2Init,
                dim1155Kuo2Init,
                dim1156Kuo2Init,
                dim1157Kuo2Init,
                dim1158Kuo2Init,
                dim1159Kuo2Init,
                dim1160Kuo2Init,
                dim1161Kuo2Init,
                dim1162Kuo2Init,
                dim1163Kuo2Init,
                dim1164Kuo2Init,
                dim1165Kuo2Init,
                dim1166Kuo2Init,
                dim1167Kuo2Init,
                dim1168Kuo2Init,
                dim1169Kuo2Init,
                dim1170Kuo2Init,
                dim1171Kuo2Init,
                dim1172Kuo2Init,
                dim1173Kuo2Init,
                dim1174Kuo2Init,
                dim1175Kuo2Init,
                dim1176Kuo2Init,
                dim1177Kuo2Init,
                dim1178Kuo2Init,
                dim1179Kuo2Init,
                dim1180Kuo2Init,
                dim1181Kuo2Init,
                dim1182Kuo2Init,
                dim1183Kuo2Init,
                dim1184Kuo2Init,
                dim1185Kuo2Init,
                dim1186Kuo2Init,
                dim1187Kuo2Init,
                dim1188Kuo2Init,
                dim1189Kuo2Init,
                dim1190Kuo2Init,
                dim1191Kuo2Init,
                dim1192Kuo2Init,
                dim1193Kuo2Init,
                dim1194Kuo2Init,
                dim1195Kuo2Init,
                dim1196Kuo2Init,
                dim1197Kuo2Init,
                dim1198Kuo2Init,
                dim1199Kuo2Init,
                dim1200Kuo2Init,
                dim1201Kuo2Init,
                dim1202Kuo2Init,
                dim1203Kuo2Init,
                dim1204Kuo2Init,
                dim1205Kuo2Init,
                dim1206Kuo2Init,
                dim1207Kuo2Init,
                dim1208Kuo2Init,
                dim1209Kuo2Init,
                dim1210Kuo2Init,
                dim1211Kuo2Init,
                dim1212Kuo2Init,
                dim1213Kuo2Init,
                dim1214Kuo2Init,
                dim1215Kuo2Init,
                dim1216Kuo2Init,
                dim1217Kuo2Init,
                dim1218Kuo2Init,
                dim1219Kuo2Init,
                dim1220Kuo2Init,
                dim1221Kuo2Init,
                dim1222Kuo2Init,
                dim1223Kuo2Init,
                dim1224Kuo2Init,
                dim1225Kuo2Init,
                dim1226Kuo2Init,
                dim1227Kuo2Init,
                dim1228Kuo2Init,
                dim1229Kuo2Init,
                dim1230Kuo2Init,
                dim1231Kuo2Init,
                dim1232Kuo2Init,
                dim1233Kuo2Init,
                dim1234Kuo2Init,
                dim1235Kuo2Init,
                dim1236Kuo2Init,
                dim1237Kuo2Init,
                dim1238Kuo2Init,
                dim1239Kuo2Init,
                dim1240Kuo2Init,
                dim1241Kuo2Init,
                dim1242Kuo2Init,
                dim1243Kuo2Init,
                dim1244Kuo2Init,
                dim1245Kuo2Init,
                dim1246Kuo2Init,
                dim1247Kuo2Init,
                dim1248Kuo2Init,
                dim1249Kuo2Init,
                dim1250Kuo2Init,
                dim1251Kuo2Init,
                dim1252Kuo2Init,
                dim1253Kuo2Init,
                dim1254Kuo2Init,
                dim1255Kuo2Init,
                dim1256Kuo2Init,
                dim1257Kuo2Init,
                dim1258Kuo2Init,
                dim1259Kuo2Init,
                dim1260Kuo2Init,
                dim1261Kuo2Init,
                dim1262Kuo2Init,
                dim1263Kuo2Init,
                dim1264Kuo2Init,
                dim1265Kuo2Init,
                dim1266Kuo2Init,
                dim1267Kuo2Init,
                dim1268Kuo2Init,
                dim1269Kuo2Init,
                dim1270Kuo2Init,
                dim1271Kuo2Init,
                dim1272Kuo2Init,
                dim1273Kuo2Init,
                dim1274Kuo2Init,
                dim1275Kuo2Init,
                dim1276Kuo2Init,
                dim1277Kuo2Init,
                dim1278Kuo2Init,
                dim1279Kuo2Init,
                dim1280Kuo2Init,
                dim1281Kuo2Init,
                dim1282Kuo2Init,
                dim1283Kuo2Init,
                dim1284Kuo2Init,
                dim1285Kuo2Init,
                dim1286Kuo2Init,
                dim1287Kuo2Init,
                dim1288Kuo2Init,
                dim1289Kuo2Init,
                dim1290Kuo2Init,
                dim1291Kuo2Init,
                dim1292Kuo2Init,
                dim1293Kuo2Init,
                dim1294Kuo2Init,
                dim1295Kuo2Init,
                dim1296Kuo2Init,
                dim1297Kuo2Init,
                dim1298Kuo2Init,
                dim1299Kuo2Init,
                dim1300Kuo2Init,
                dim1301Kuo2Init,
                dim1302Kuo2Init,
                dim1303Kuo2Init,
                dim1304Kuo2Init,
                dim1305Kuo2Init,
                dim1306Kuo2Init,
                dim1307Kuo2Init,
                dim1308Kuo2Init,
                dim1309Kuo2Init,
                dim1310Kuo2Init,
                dim1311Kuo2Init,
                dim1312Kuo2Init,
                dim1313Kuo2Init,
                dim1314Kuo2Init,
                dim1315Kuo2Init,
                dim1316Kuo2Init,
                dim1317Kuo2Init,
                dim1318Kuo2Init,
                dim1319Kuo2Init,
                dim1320Kuo2Init,
                dim1321Kuo2Init,
                dim1322Kuo2Init,
                dim1323Kuo2Init,
                dim1324Kuo2Init,
                dim1325Kuo2Init,
                dim1326Kuo2Init,
                dim1327Kuo2Init,
                dim1328Kuo2Init,
                dim1329Kuo2Init,
                dim1330Kuo2Init,
                dim1331Kuo2Init,
                dim1332Kuo2Init,
                dim1333Kuo2Init,
                dim1334Kuo2Init,
                dim1335Kuo2Init,
                dim1336Kuo2Init,
                dim1337Kuo2Init,
                dim1338Kuo2Init,
                dim1339Kuo2Init,
                dim1340Kuo2Init,
                dim1341Kuo2Init,
                dim1342Kuo2Init,
                dim1343Kuo2Init,
                dim1344Kuo2Init,
                dim1345Kuo2Init,
                dim1346Kuo2Init,
                dim1347Kuo2Init,
                dim1348Kuo2Init,
                dim1349Kuo2Init,
                dim1350Kuo2Init,
                dim1351Kuo2Init,
                dim1352Kuo2Init,
                dim1353Kuo2Init,
                dim1354Kuo2Init,
                dim1355Kuo2Init,
                dim1356Kuo2Init,
                dim1357Kuo2Init,
                dim1358Kuo2Init,
                dim1359Kuo2Init,
                dim1360Kuo2Init,
                dim1361Kuo2Init,
                dim1362Kuo2Init,
                dim1363Kuo2Init,
                dim1364Kuo2Init,
                dim1365Kuo2Init,
                dim1366Kuo2Init,
                dim1367Kuo2Init,
                dim1368Kuo2Init,
                dim1369Kuo2Init,
                dim1370Kuo2Init,
                dim1371Kuo2Init,
                dim1372Kuo2Init,
                dim1373Kuo2Init,
                dim1374Kuo2Init,
                dim1375Kuo2Init,
                dim1376Kuo2Init,
                dim1377Kuo2Init,
                dim1378Kuo2Init,
                dim1379Kuo2Init,
                dim1380Kuo2Init,
                dim1381Kuo2Init,
                dim1382Kuo2Init,
                dim1383Kuo2Init,
                dim1384Kuo2Init,
                dim1385Kuo2Init,
                dim1386Kuo2Init,
                dim1387Kuo2Init,
                dim1388Kuo2Init,
                dim1389Kuo2Init,
                dim1390Kuo2Init,
                dim1391Kuo2Init,
                dim1392Kuo2Init,
                dim1393Kuo2Init,
                dim1394Kuo2Init,
                dim1395Kuo2Init,
                dim1396Kuo2Init,
                dim1397Kuo2Init,
                dim1398Kuo2Init,
                dim1399Kuo2Init,
                dim1400Kuo2Init,
                dim1401Kuo2Init,
                dim1402Kuo2Init,
                dim1403Kuo2Init,
                dim1404Kuo2Init,
                dim1405Kuo2Init,
                dim1406Kuo2Init,
                dim1407Kuo2Init,
                dim1408Kuo2Init,
                dim1409Kuo2Init,
                dim1410Kuo2Init,
                dim1411Kuo2Init,
                dim1412Kuo2Init,
                dim1413Kuo2Init,
                dim1414Kuo2Init,
                dim1415Kuo2Init,
                dim1416Kuo2Init,
                dim1417Kuo2Init,
                dim1418Kuo2Init,
                dim1419Kuo2Init,
                dim1420Kuo2Init,
                dim1421Kuo2Init,
                dim1422Kuo2Init,
                dim1423Kuo2Init,
                dim1424Kuo2Init,
                dim1425Kuo2Init,
                dim1426Kuo2Init,
                dim1427Kuo2Init,
                dim1428Kuo2Init,
                dim1429Kuo2Init,
                dim1430Kuo2Init,
                dim1431Kuo2Init,
                dim1432Kuo2Init,
                dim1433Kuo2Init,
                dim1434Kuo2Init,
                dim1435Kuo2Init,
                dim1436Kuo2Init,
                dim1437Kuo2Init,
                dim1438Kuo2Init,
                dim1439Kuo2Init,
                dim1440Kuo2Init,
                dim1441Kuo2Init,
                dim1442Kuo2Init,
                dim1443Kuo2Init,
                dim1444Kuo2Init,
                dim1445Kuo2Init,
                dim1446Kuo2Init,
                dim1447Kuo2Init,
                dim1448Kuo2Init,
                dim1449Kuo2Init,
                dim1450Kuo2Init,
                dim1451Kuo2Init,
                dim1452Kuo2Init,
                dim1453Kuo2Init,
                dim1454Kuo2Init,
                dim1455Kuo2Init,
                dim1456Kuo2Init,
                dim1457Kuo2Init,
                dim1458Kuo2Init,
                dim1459Kuo2Init,
                dim1460Kuo2Init,
                dim1461Kuo2Init,
                dim1462Kuo2Init,
                dim1463Kuo2Init,
                dim1464Kuo2Init,
                dim1465Kuo2Init,
                dim1466Kuo2Init,
                dim1467Kuo2Init,
                dim1468Kuo2Init,
                dim1469Kuo2Init,
                dim1470Kuo2Init,
                dim1471Kuo2Init,
                dim1472Kuo2Init,
                dim1473Kuo2Init,
                dim1474Kuo2Init,
                dim1475Kuo2Init,
                dim1476Kuo2Init,
                dim1477Kuo2Init,
                dim1478Kuo2Init,
                dim1479Kuo2Init,
                dim1480Kuo2Init,
                dim1481Kuo2Init,
                dim1482Kuo2Init,
                dim1483Kuo2Init,
                dim1484Kuo2Init,
                dim1485Kuo2Init,
                dim1486Kuo2Init,
                dim1487Kuo2Init,
                dim1488Kuo2Init,
                dim1489Kuo2Init,
                dim1490Kuo2Init,
                dim1491Kuo2Init,
                dim1492Kuo2Init,
                dim1493Kuo2Init,
                dim1494Kuo2Init,
                dim1495Kuo2Init,
                dim1496Kuo2Init,
                dim1497Kuo2Init,
                dim1498Kuo2Init,
                dim1499Kuo2Init,
                dim1500Kuo2Init,
                dim1501Kuo2Init,
                dim1502Kuo2Init,
                dim1503Kuo2Init,
                dim1504Kuo2Init,
                dim1505Kuo2Init,
                dim1506Kuo2Init,
                dim1507Kuo2Init,
                dim1508Kuo2Init,
                dim1509Kuo2Init,
                dim1510Kuo2Init,
                dim1511Kuo2Init,
                dim1512Kuo2Init,
                dim1513Kuo2Init,
                dim1514Kuo2Init,
                dim1515Kuo2Init,
                dim1516Kuo2Init,
                dim1517Kuo2Init,
                dim1518Kuo2Init,
                dim1519Kuo2Init,
                dim1520Kuo2Init,
                dim1521Kuo2Init,
                dim1522Kuo2Init,
                dim1523Kuo2Init,
                dim1524Kuo2Init,
                dim1525Kuo2Init,
                dim1526Kuo2Init,
                dim1527Kuo2Init,
                dim1528Kuo2Init,
                dim1529Kuo2Init,
                dim1530Kuo2Init,
                dim1531Kuo2Init,
                dim1532Kuo2Init,
                dim1533Kuo2Init,
                dim1534Kuo2Init,
                dim1535Kuo2Init,
                dim1536Kuo2Init,
                dim1537Kuo2Init,
                dim1538Kuo2Init,
                dim1539Kuo2Init,
                dim1540Kuo2Init,
                dim1541Kuo2Init,
                dim1542Kuo2Init,
                dim1543Kuo2Init,
                dim1544Kuo2Init,
                dim1545Kuo2Init,
                dim1546Kuo2Init,
                dim1547Kuo2Init,
                dim1548Kuo2Init,
                dim1549Kuo2Init,
                dim1550Kuo2Init,
                dim1551Kuo2Init,
                dim1552Kuo2Init,
                dim1553Kuo2Init,
                dim1554Kuo2Init,
                dim1555Kuo2Init,
                dim1556Kuo2Init,
                dim1557Kuo2Init,
                dim1558Kuo2Init,
                dim1559Kuo2Init,
                dim1560Kuo2Init,
                dim1561Kuo2Init,
                dim1562Kuo2Init,
                dim1563Kuo2Init,
                dim1564Kuo2Init,
                dim1565Kuo2Init,
                dim1566Kuo2Init,
                dim1567Kuo2Init,
                dim1568Kuo2Init,
                dim1569Kuo2Init,
                dim1570Kuo2Init,
                dim1571Kuo2Init,
                dim1572Kuo2Init,
                dim1573Kuo2Init,
                dim1574Kuo2Init,
                dim1575Kuo2Init,
                dim1576Kuo2Init,
                dim1577Kuo2Init,
                dim1578Kuo2Init,
                dim1579Kuo2Init,
                dim1580Kuo2Init,
                dim1581Kuo2Init,
                dim1582Kuo2Init,
                dim1583Kuo2Init,
                dim1584Kuo2Init,
                dim1585Kuo2Init,
                dim1586Kuo2Init,
                dim1587Kuo2Init,
                dim1588Kuo2Init,
                dim1589Kuo2Init,
                dim1590Kuo2Init,
                dim1591Kuo2Init,
                dim1592Kuo2Init,
                dim1593Kuo2Init,
                dim1594Kuo2Init,
                dim1595Kuo2Init,
                dim1596Kuo2Init,
                dim1597Kuo2Init,
                dim1598Kuo2Init,
                dim1599Kuo2Init,
                dim1600Kuo2Init,
                dim1601Kuo2Init,
                dim1602Kuo2Init,
                dim1603Kuo2Init,
                dim1604Kuo2Init,
                dim1605Kuo2Init,
                dim1606Kuo2Init,
                dim1607Kuo2Init,
                dim1608Kuo2Init,
                dim1609Kuo2Init,
                dim1610Kuo2Init,
                dim1611Kuo2Init,
                dim1612Kuo2Init,
                dim1613Kuo2Init,
                dim1614Kuo2Init,
                dim1615Kuo2Init,
                dim1616Kuo2Init,
                dim1617Kuo2Init,
                dim1618Kuo2Init,
                dim1619Kuo2Init,
                dim1620Kuo2Init,
                dim1621Kuo2Init,
                dim1622Kuo2Init,
                dim1623Kuo2Init,
                dim1624Kuo2Init,
                dim1625Kuo2Init,
                dim1626Kuo2Init,
                dim1627Kuo2Init,
                dim1628Kuo2Init,
                dim1629Kuo2Init,
                dim1630Kuo2Init,
                dim1631Kuo2Init,
                dim1632Kuo2Init,
                dim1633Kuo2Init,
                dim1634Kuo2Init,
                dim1635Kuo2Init,
                dim1636Kuo2Init,
                dim1637Kuo2Init,
                dim1638Kuo2Init,
                dim1639Kuo2Init,
                dim1640Kuo2Init,
                dim1641Kuo2Init,
                dim1642Kuo2Init,
                dim1643Kuo2Init,
                dim1644Kuo2Init,
                dim1645Kuo2Init,
                dim1646Kuo2Init,
                dim1647Kuo2Init,
                dim1648Kuo2Init,
                dim1649Kuo2Init,
                dim1650Kuo2Init,
                dim1651Kuo2Init,
                dim1652Kuo2Init,
                dim1653Kuo2Init,
                dim1654Kuo2Init,
                dim1655Kuo2Init,
                dim1656Kuo2Init,
                dim1657Kuo2Init,
                dim1658Kuo2Init,
                dim1659Kuo2Init,
                dim1660Kuo2Init,
                dim1661Kuo2Init,
                dim1662Kuo2Init,
                dim1663Kuo2Init,
                dim1664Kuo2Init,
                dim1665Kuo2Init,
                dim1666Kuo2Init,
                dim1667Kuo2Init,
                dim1668Kuo2Init,
                dim1669Kuo2Init,
                dim1670Kuo2Init,
                dim1671Kuo2Init,
                dim1672Kuo2Init,
                dim1673Kuo2Init,
                dim1674Kuo2Init,
                dim1675Kuo2Init,
                dim1676Kuo2Init,
                dim1677Kuo2Init,
                dim1678Kuo2Init,
                dim1679Kuo2Init,
                dim1680Kuo2Init,
                dim1681Kuo2Init,
                dim1682Kuo2Init,
                dim1683Kuo2Init,
                dim1684Kuo2Init,
                dim1685Kuo2Init,
                dim1686Kuo2Init,
                dim1687Kuo2Init,
                dim1688Kuo2Init,
                dim1689Kuo2Init,
                dim1690Kuo2Init,
                dim1691Kuo2Init,
                dim1692Kuo2Init,
                dim1693Kuo2Init,
                dim1694Kuo2Init,
                dim1695Kuo2Init,
                dim1696Kuo2Init,
                dim1697Kuo2Init,
                dim1698Kuo2Init,
                dim1699Kuo2Init,
                dim1700Kuo2Init,
                dim1701Kuo2Init,
                dim1702Kuo2Init,
                dim1703Kuo2Init,
                dim1704Kuo2Init,
                dim1705Kuo2Init,
                dim1706Kuo2Init,
                dim1707Kuo2Init,
                dim1708Kuo2Init,
                dim1709Kuo2Init,
                dim1710Kuo2Init,
                dim1711Kuo2Init,
                dim1712Kuo2Init,
                dim1713Kuo2Init,
                dim1714Kuo2Init,
                dim1715Kuo2Init,
                dim1716Kuo2Init,
                dim1717Kuo2Init,
                dim1718Kuo2Init,
                dim1719Kuo2Init,
                dim1720Kuo2Init,
                dim1721Kuo2Init,
                dim1722Kuo2Init,
                dim1723Kuo2Init,
                dim1724Kuo2Init,
                dim1725Kuo2Init,
                dim1726Kuo2Init,
                dim1727Kuo2Init,
                dim1728Kuo2Init,
                dim1729Kuo2Init,
                dim1730Kuo2Init,
                dim1731Kuo2Init,
                dim1732Kuo2Init,
                dim1733Kuo2Init,
                dim1734Kuo2Init,
                dim1735Kuo2Init,
                dim1736Kuo2Init,
                dim1737Kuo2Init,
                dim1738Kuo2Init,
                dim1739Kuo2Init,
                dim1740Kuo2Init,
                dim1741Kuo2Init,
                dim1742Kuo2Init,
                dim1743Kuo2Init,
                dim1744Kuo2Init,
                dim1745Kuo2Init,
                dim1746Kuo2Init,
                dim1747Kuo2Init,
                dim1748Kuo2Init,
                dim1749Kuo2Init,
                dim1750Kuo2Init,
                dim1751Kuo2Init,
                dim1752Kuo2Init,
                dim1753Kuo2Init,
                dim1754Kuo2Init,
                dim1755Kuo2Init,
                dim1756Kuo2Init,
                dim1757Kuo2Init,
                dim1758Kuo2Init,
                dim1759Kuo2Init,
                dim1760Kuo2Init,
                dim1761Kuo2Init,
                dim1762Kuo2Init,
                dim1763Kuo2Init,
                dim1764Kuo2Init,
                dim1765Kuo2Init,
                dim1766Kuo2Init,
                dim1767Kuo2Init,
                dim1768Kuo2Init,
                dim1769Kuo2Init,
                dim1770Kuo2Init,
                dim1771Kuo2Init,
                dim1772Kuo2Init,
                dim1773Kuo2Init,
                dim1774Kuo2Init,
                dim1775Kuo2Init,
                dim1776Kuo2Init,
                dim1777Kuo2Init,
                dim1778Kuo2Init,
                dim1779Kuo2Init,
                dim1780Kuo2Init,
                dim1781Kuo2Init,
                dim1782Kuo2Init,
                dim1783Kuo2Init,
                dim1784Kuo2Init,
                dim1785Kuo2Init,
                dim1786Kuo2Init,
                dim1787Kuo2Init,
                dim1788Kuo2Init,
                dim1789Kuo2Init,
                dim1790Kuo2Init,
                dim1791Kuo2Init,
                dim1792Kuo2Init,
                dim1793Kuo2Init,
                dim1794Kuo2Init,
                dim1795Kuo2Init,
                dim1796Kuo2Init,
                dim1797Kuo2Init,
                dim1798Kuo2Init,
                dim1799Kuo2Init,
                dim1800Kuo2Init,
                dim1801Kuo2Init,
                dim1802Kuo2Init,
                dim1803Kuo2Init,
                dim1804Kuo2Init,
                dim1805Kuo2Init,
                dim1806Kuo2Init,
                dim1807Kuo2Init,
                dim1808Kuo2Init,
                dim1809Kuo2Init,
                dim1810Kuo2Init,
                dim1811Kuo2Init,
                dim1812Kuo2Init,
                dim1813Kuo2Init,
                dim1814Kuo2Init,
                dim1815Kuo2Init,
                dim1816Kuo2Init,
                dim1817Kuo2Init,
                dim1818Kuo2Init,
                dim1819Kuo2Init,
                dim1820Kuo2Init,
                dim1821Kuo2Init,
                dim1822Kuo2Init,
                dim1823Kuo2Init,
                dim1824Kuo2Init,
                dim1825Kuo2Init,
                dim1826Kuo2Init,
                dim1827Kuo2Init,
                dim1828Kuo2Init,
                dim1829Kuo2Init,
                dim1830Kuo2Init,
                dim1831Kuo2Init,
                dim1832Kuo2Init,
                dim1833Kuo2Init,
                dim1834Kuo2Init,
                dim1835Kuo2Init,
                dim1836Kuo2Init,
                dim1837Kuo2Init,
                dim1838Kuo2Init,
                dim1839Kuo2Init,
                dim1840Kuo2Init,
                dim1841Kuo2Init,
                dim1842Kuo2Init,
                dim1843Kuo2Init,
                dim1844Kuo2Init,
                dim1845Kuo2Init,
                dim1846Kuo2Init,
                dim1847Kuo2Init,
                dim1848Kuo2Init,
                dim1849Kuo2Init,
                dim1850Kuo2Init,
                dim1851Kuo2Init,
                dim1852Kuo2Init,
                dim1853Kuo2Init,
                dim1854Kuo2Init,
                dim1855Kuo2Init,
                dim1856Kuo2Init,
                dim1857Kuo2Init,
                dim1858Kuo2Init,
                dim1859Kuo2Init,
                dim1860Kuo2Init,
                dim1861Kuo2Init,
                dim1862Kuo2Init,
                dim1863Kuo2Init,
                dim1864Kuo2Init,
                dim1865Kuo2Init,
                dim1866Kuo2Init,
                dim1867Kuo2Init,
                dim1868Kuo2Init,
                dim1869Kuo2Init,
                dim1870Kuo2Init,
                dim1871Kuo2Init,
                dim1872Kuo2Init,
                dim1873Kuo2Init,
                dim1874Kuo2Init,
                dim1875Kuo2Init,
                dim1876Kuo2Init,
                dim1877Kuo2Init,
                dim1878Kuo2Init,
                dim1879Kuo2Init,
                dim1880Kuo2Init,
                dim1881Kuo2Init,
                dim1882Kuo2Init,
                dim1883Kuo2Init,
                dim1884Kuo2Init,
                dim1885Kuo2Init,
                dim1886Kuo2Init,
                dim1887Kuo2Init,
                dim1888Kuo2Init,
                dim1889Kuo2Init,
                dim1890Kuo2Init,
                dim1891Kuo2Init,
                dim1892Kuo2Init,
                dim1893Kuo2Init,
                dim1894Kuo2Init,
                dim1895Kuo2Init,
                dim1896Kuo2Init,
                dim1897Kuo2Init,
                dim1898Kuo2Init,
                dim1899Kuo2Init,
                dim1900Kuo2Init,
                dim1901Kuo2Init,
                dim1902Kuo2Init,
                dim1903Kuo2Init,
                dim1904Kuo2Init,
                dim1905Kuo2Init,
                dim1906Kuo2Init,
                dim1907Kuo2Init,
                dim1908Kuo2Init,
                dim1909Kuo2Init,
                dim1910Kuo2Init,
                dim1911Kuo2Init,
                dim1912Kuo2Init,
                dim1913Kuo2Init,
                dim1914Kuo2Init,
                dim1915Kuo2Init,
                dim1916Kuo2Init,
                dim1917Kuo2Init,
                dim1918Kuo2Init,
                dim1919Kuo2Init,
                dim1920Kuo2Init,
                dim1921Kuo2Init,
                dim1922Kuo2Init,
                dim1923Kuo2Init,
                dim1924Kuo2Init,
                dim1925Kuo2Init,
                dim1926Kuo2Init,
                dim1927Kuo2Init,
                dim1928Kuo2Init,
                dim1929Kuo2Init,
                dim1930Kuo2Init,
                dim1931Kuo2Init,
                dim1932Kuo2Init,
                dim1933Kuo2Init,
                dim1934Kuo2Init,
                dim1935Kuo2Init,
                dim1936Kuo2Init,
                dim1937Kuo2Init,
                dim1938Kuo2Init,
                dim1939Kuo2Init,
                dim1940Kuo2Init,
                dim1941Kuo2Init,
                dim1942Kuo2Init,
                dim1943Kuo2Init,
                dim1944Kuo2Init,
                dim1945Kuo2Init,
                dim1946Kuo2Init,
                dim1947Kuo2Init,
                dim1948Kuo2Init,
                dim1949Kuo2Init,
                dim1950Kuo2Init,
                dim1951Kuo2Init,
                dim1952Kuo2Init,
                dim1953Kuo2Init,
                dim1954Kuo2Init,
                dim1955Kuo2Init,
                dim1956Kuo2Init,
                dim1957Kuo2Init,
                dim1958Kuo2Init,
                dim1959Kuo2Init,
                dim1960Kuo2Init,
                dim1961Kuo2Init,
                dim1962Kuo2Init,
                dim1963Kuo2Init,
                dim1964Kuo2Init,
                dim1965Kuo2Init,
                dim1966Kuo2Init,
                dim1967Kuo2Init,
                dim1968Kuo2Init,
                dim1969Kuo2Init,
                dim1970Kuo2Init,
                dim1971Kuo2Init,
                dim1972Kuo2Init,
                dim1973Kuo2Init,
                dim1974Kuo2Init,
                dim1975Kuo2Init,
                dim1976Kuo2Init,
                dim1977Kuo2Init,
                dim1978Kuo2Init,
                dim1979Kuo2Init,
                dim1980Kuo2Init,
                dim1981Kuo2Init,
                dim1982Kuo2Init,
                dim1983Kuo2Init,
                dim1984Kuo2Init,
                dim1985Kuo2Init,
                dim1986Kuo2Init,
                dim1987Kuo2Init,
                dim1988Kuo2Init,
                dim1989Kuo2Init,
                dim1990Kuo2Init,
                dim1991Kuo2Init,
                dim1992Kuo2Init,
                dim1993Kuo2Init,
                dim1994Kuo2Init,
                dim1995Kuo2Init,
                dim1996Kuo2Init,
                dim1997Kuo2Init,
                dim1998Kuo2Init,
                dim1999Kuo2Init,
                dim2000Kuo2Init,
                dim2001Kuo2Init,
                dim2002Kuo2Init,
                dim2003Kuo2Init,
                dim2004Kuo2Init,
                dim2005Kuo2Init,
                dim2006Kuo2Init,
                dim2007Kuo2Init,
                dim2008Kuo2Init,
                dim2009Kuo2Init,
                dim2010Kuo2Init,
                dim2011Kuo2Init,
                dim2012Kuo2Init,
                dim2013Kuo2Init,
                dim2014Kuo2Init,
                dim2015Kuo2Init,
                dim2016Kuo2Init,
                dim2017Kuo2Init,
                dim2018Kuo2Init,
                dim2019Kuo2Init,
                dim2020Kuo2Init,
                dim2021Kuo2Init,
                dim2022Kuo2Init,
                dim2023Kuo2Init,
                dim2024Kuo2Init,
                dim2025Kuo2Init,
                dim2026Kuo2Init,
                dim2027Kuo2Init,
                dim2028Kuo2Init,
                dim2029Kuo2Init,
                dim2030Kuo2Init,
                dim2031Kuo2Init,
                dim2032Kuo2Init,
                dim2033Kuo2Init,
                dim2034Kuo2Init,
                dim2035Kuo2Init,
                dim2036Kuo2Init,
                dim2037Kuo2Init,
                dim2038Kuo2Init,
                dim2039Kuo2Init,
                dim2040Kuo2Init,
                dim2041Kuo2Init,
                dim2042Kuo2Init,
                dim2043Kuo2Init,
                dim2044Kuo2Init,
                dim2045Kuo2Init,
                dim2046Kuo2Init,
                dim2047Kuo2Init,
                dim2048Kuo2Init,
                dim2049Kuo2Init,
                dim2050Kuo2Init,
                dim2051Kuo2Init,
                dim2052Kuo2Init,
                dim2053Kuo2Init,
                dim2054Kuo2Init,
                dim2055Kuo2Init,
                dim2056Kuo2Init,
                dim2057Kuo2Init,
                dim2058Kuo2Init,
                dim2059Kuo2Init,
                dim2060Kuo2Init,
                dim2061Kuo2Init,
                dim2062Kuo2Init,
                dim2063Kuo2Init,
                dim2064Kuo2Init,
                dim2065Kuo2Init,
                dim2066Kuo2Init,
                dim2067Kuo2Init,
                dim2068Kuo2Init,
                dim2069Kuo2Init,
                dim2070Kuo2Init,
                dim2071Kuo2Init,
                dim2072Kuo2Init,
                dim2073Kuo2Init,
                dim2074Kuo2Init,
                dim2075Kuo2Init,
                dim2076Kuo2Init,
                dim2077Kuo2Init,
                dim2078Kuo2Init,
                dim2079Kuo2Init,
                dim2080Kuo2Init,
                dim2081Kuo2Init,
                dim2082Kuo2Init,
                dim2083Kuo2Init,
                dim2084Kuo2Init,
                dim2085Kuo2Init,
                dim2086Kuo2Init,
                dim2087Kuo2Init,
                dim2088Kuo2Init,
                dim2089Kuo2Init,
                dim2090Kuo2Init,
                dim2091Kuo2Init,
                dim2092Kuo2Init,
                dim2093Kuo2Init,
                dim2094Kuo2Init,
                dim2095Kuo2Init,
                dim2096Kuo2Init,
                dim2097Kuo2Init,
                dim2098Kuo2Init,
                dim2099Kuo2Init,
                dim2100Kuo2Init,
                dim2101Kuo2Init,
                dim2102Kuo2Init,
                dim2103Kuo2Init,
                dim2104Kuo2Init,
                dim2105Kuo2Init,
                dim2106Kuo2Init,
                dim2107Kuo2Init,
                dim2108Kuo2Init,
                dim2109Kuo2Init,
                dim2110Kuo2Init,
                dim2111Kuo2Init,
                dim2112Kuo2Init,
                dim2113Kuo2Init,
                dim2114Kuo2Init,
                dim2115Kuo2Init,
                dim2116Kuo2Init,
                dim2117Kuo2Init,
                dim2118Kuo2Init,
                dim2119Kuo2Init,
                dim2120Kuo2Init,
                dim2121Kuo2Init,
                dim2122Kuo2Init,
                dim2123Kuo2Init,
                dim2124Kuo2Init,
                dim2125Kuo2Init,
                dim2126Kuo2Init,
                dim2127Kuo2Init,
                dim2128Kuo2Init,
                dim2129Kuo2Init,
                dim2130Kuo2Init,
                dim2131Kuo2Init,
                dim2132Kuo2Init,
                dim2133Kuo2Init,
                dim2134Kuo2Init,
                dim2135Kuo2Init,
                dim2136Kuo2Init,
                dim2137Kuo2Init,
                dim2138Kuo2Init,
                dim2139Kuo2Init,
                dim2140Kuo2Init,
                dim2141Kuo2Init,
                dim2142Kuo2Init,
                dim2143Kuo2Init,
                dim2144Kuo2Init,
                dim2145Kuo2Init,
                dim2146Kuo2Init,
                dim2147Kuo2Init,
                dim2148Kuo2Init,
                dim2149Kuo2Init,
                dim2150Kuo2Init,
                dim2151Kuo2Init,
                dim2152Kuo2Init,
                dim2153Kuo2Init,
                dim2154Kuo2Init,
                dim2155Kuo2Init,
                dim2156Kuo2Init,
                dim2157Kuo2Init,
                dim2158Kuo2Init,
                dim2159Kuo2Init,
                dim2160Kuo2Init,
                dim2161Kuo2Init,
                dim2162Kuo2Init,
                dim2163Kuo2Init,
                dim2164Kuo2Init,
                dim2165Kuo2Init,
                dim2166Kuo2Init,
                dim2167Kuo2Init,
                dim2168Kuo2Init,
                dim2169Kuo2Init,
                dim2170Kuo2Init,
                dim2171Kuo2Init,
                dim2172Kuo2Init,
                dim2173Kuo2Init,
                dim2174Kuo2Init,
                dim2175Kuo2Init,
                dim2176Kuo2Init,
                dim2177Kuo2Init,
                dim2178Kuo2Init,
                dim2179Kuo2Init,
                dim2180Kuo2Init,
                dim2181Kuo2Init,
                dim2182Kuo2Init,
                dim2183Kuo2Init,
                dim2184Kuo2Init,
                dim2185Kuo2Init,
                dim2186Kuo2Init,
                dim2187Kuo2Init,
                dim2188Kuo2Init,
                dim2189Kuo2Init,
                dim2190Kuo2Init,
                dim2191Kuo2Init,
                dim2192Kuo2Init,
                dim2193Kuo2Init,
                dim2194Kuo2Init,
                dim2195Kuo2Init,
                dim2196Kuo2Init,
                dim2197Kuo2Init,
                dim2198Kuo2Init,
                dim2199Kuo2Init,
                dim2200Kuo2Init,
                dim2201Kuo2Init,
                dim2202Kuo2Init,
                dim2203Kuo2Init,
                dim2204Kuo2Init,
                dim2205Kuo2Init,
                dim2206Kuo2Init,
                dim2207Kuo2Init,
                dim2208Kuo2Init,
                dim2209Kuo2Init,
                dim2210Kuo2Init,
                dim2211Kuo2Init,
                dim2212Kuo2Init,
                dim2213Kuo2Init,
                dim2214Kuo2Init,
                dim2215Kuo2Init,
                dim2216Kuo2Init,
                dim2217Kuo2Init,
                dim2218Kuo2Init,
                dim2219Kuo2Init,
                dim2220Kuo2Init,
                dim2221Kuo2Init,
                dim2222Kuo2Init,
                dim2223Kuo2Init,
                dim2224Kuo2Init,
                dim2225Kuo2Init,
                dim2226Kuo2Init,
                dim2227Kuo2Init,
                dim2228Kuo2Init,
                dim2229Kuo2Init,
                dim2230Kuo2Init,
                dim2231Kuo2Init,
                dim2232Kuo2Init,
                dim2233Kuo2Init,
                dim2234Kuo2Init,
                dim2235Kuo2Init,
                dim2236Kuo2Init,
                dim2237Kuo2Init,
                dim2238Kuo2Init,
                dim2239Kuo2Init,
                dim2240Kuo2Init,
                dim2241Kuo2Init,
                dim2242Kuo2Init,
                dim2243Kuo2Init,
                dim2244Kuo2Init,
                dim2245Kuo2Init,
                dim2246Kuo2Init,
                dim2247Kuo2Init,
                dim2248Kuo2Init,
                dim2249Kuo2Init,
                dim2250Kuo2Init,
                dim2251Kuo2Init,
                dim2252Kuo2Init,
                dim2253Kuo2Init,
                dim2254Kuo2Init,
                dim2255Kuo2Init,
                dim2256Kuo2Init,
                dim2257Kuo2Init,
                dim2258Kuo2Init,
                dim2259Kuo2Init,
                dim2260Kuo2Init,
                dim2261Kuo2Init,
                dim2262Kuo2Init,
                dim2263Kuo2Init,
                dim2264Kuo2Init,
                dim2265Kuo2Init,
                dim2266Kuo2Init,
                dim2267Kuo2Init,
                dim2268Kuo2Init,
                dim2269Kuo2Init,
                dim2270Kuo2Init,
                dim2271Kuo2Init,
                dim2272Kuo2Init,
                dim2273Kuo2Init,
                dim2274Kuo2Init,
                dim2275Kuo2Init,
                dim2276Kuo2Init,
                dim2277Kuo2Init,
                dim2278Kuo2Init,
                dim2279Kuo2Init,
                dim2280Kuo2Init,
                dim2281Kuo2Init,
                dim2282Kuo2Init,
                dim2283Kuo2Init,
                dim2284Kuo2Init,
                dim2285Kuo2Init,
                dim2286Kuo2Init,
                dim2287Kuo2Init,
                dim2288Kuo2Init,
                dim2289Kuo2Init,
                dim2290Kuo2Init,
                dim2291Kuo2Init,
                dim2292Kuo2Init,
                dim2293Kuo2Init,
                dim2294Kuo2Init,
                dim2295Kuo2Init,
                dim2296Kuo2Init,
                dim2297Kuo2Init,
                dim2298Kuo2Init,
                dim2299Kuo2Init,
                dim2300Kuo2Init,
                dim2301Kuo2Init,
                dim2302Kuo2Init,
                dim2303Kuo2Init,
                dim2304Kuo2Init,
                dim2305Kuo2Init,
                dim2306Kuo2Init,
                dim2307Kuo2Init,
                dim2308Kuo2Init,
                dim2309Kuo2Init,
                dim2310Kuo2Init,
                dim2311Kuo2Init,
                dim2312Kuo2Init,
                dim2313Kuo2Init,
                dim2314Kuo2Init,
                dim2315Kuo2Init,
                dim2316Kuo2Init,
                dim2317Kuo2Init,
                dim2318Kuo2Init,
                dim2319Kuo2Init,
                dim2320Kuo2Init,
                dim2321Kuo2Init,
                dim2322Kuo2Init,
                dim2323Kuo2Init,
                dim2324Kuo2Init,
                dim2325Kuo2Init,
                dim2326Kuo2Init,
                dim2327Kuo2Init,
                dim2328Kuo2Init,
                dim2329Kuo2Init,
                dim2330Kuo2Init,
                dim2331Kuo2Init,
                dim2332Kuo2Init,
                dim2333Kuo2Init,
                dim2334Kuo2Init,
                dim2335Kuo2Init,
                dim2336Kuo2Init,
                dim2337Kuo2Init,
                dim2338Kuo2Init,
                dim2339Kuo2Init,
                dim2340Kuo2Init,
                dim2341Kuo2Init,
                dim2342Kuo2Init,
                dim2343Kuo2Init,
                dim2344Kuo2Init,
                dim2345Kuo2Init,
                dim2346Kuo2Init,
                dim2347Kuo2Init,
                dim2348Kuo2Init,
                dim2349Kuo2Init,
                dim2350Kuo2Init,
                dim2351Kuo2Init,
                dim2352Kuo2Init,
                dim2353Kuo2Init,
                dim2354Kuo2Init,
                dim2355Kuo2Init,
                dim2356Kuo2Init,
                dim2357Kuo2Init,
                dim2358Kuo2Init,
                dim2359Kuo2Init,
                dim2360Kuo2Init,
                dim2361Kuo2Init,
                dim2362Kuo2Init,
                dim2363Kuo2Init,
                dim2364Kuo2Init,
                dim2365Kuo2Init,
                dim2366Kuo2Init,
                dim2367Kuo2Init,
                dim2368Kuo2Init,
                dim2369Kuo2Init,
                dim2370Kuo2Init,
                dim2371Kuo2Init,
                dim2372Kuo2Init,
                dim2373Kuo2Init,
                dim2374Kuo2Init,
                dim2375Kuo2Init,
                dim2376Kuo2Init,
                dim2377Kuo2Init,
                dim2378Kuo2Init,
                dim2379Kuo2Init,
                dim2380Kuo2Init,
                dim2381Kuo2Init,
                dim2382Kuo2Init,
                dim2383Kuo2Init,
                dim2384Kuo2Init,
                dim2385Kuo2Init,
                dim2386Kuo2Init,
                dim2387Kuo2Init,
                dim2388Kuo2Init,
                dim2389Kuo2Init,
                dim2390Kuo2Init,
                dim2391Kuo2Init,
                dim2392Kuo2Init,
                dim2393Kuo2Init,
                dim2394Kuo2Init,
                dim2395Kuo2Init,
                dim2396Kuo2Init,
                dim2397Kuo2Init,
                dim2398Kuo2Init,
                dim2399Kuo2Init,
                dim2400Kuo2Init,
                dim2401Kuo2Init,
                dim2402Kuo2Init,
                dim2403Kuo2Init,
                dim2404Kuo2Init,
                dim2405Kuo2Init,
                dim2406Kuo2Init,
                dim2407Kuo2Init,
                dim2408Kuo2Init,
                dim2409Kuo2Init,
                dim2410Kuo2Init,
                dim2411Kuo2Init,
                dim2412Kuo2Init,
                dim2413Kuo2Init,
                dim2414Kuo2Init,
                dim2415Kuo2Init,
                dim2416Kuo2Init,
                dim2417Kuo2Init,
                dim2418Kuo2Init,
                dim2419Kuo2Init,
                dim2420Kuo2Init,
                dim2421Kuo2Init,
                dim2422Kuo2Init,
                dim2423Kuo2Init,
                dim2424Kuo2Init,
                dim2425Kuo2Init,
                dim2426Kuo2Init,
                dim2427Kuo2Init,
                dim2428Kuo2Init,
                dim2429Kuo2Init,
                dim2430Kuo2Init,
                dim2431Kuo2Init,
                dim2432Kuo2Init,
                dim2433Kuo2Init,
                dim2434Kuo2Init,
                dim2435Kuo2Init,
                dim2436Kuo2Init,
                dim2437Kuo2Init,
                dim2438Kuo2Init,
                dim2439Kuo2Init,
                dim2440Kuo2Init,
                dim2441Kuo2Init,
                dim2442Kuo2Init,
                dim2443Kuo2Init,
                dim2444Kuo2Init,
                dim2445Kuo2Init,
                dim2446Kuo2Init,
                dim2447Kuo2Init,
                dim2448Kuo2Init,
                dim2449Kuo2Init,
                dim2450Kuo2Init,
                dim2451Kuo2Init,
                dim2452Kuo2Init,
                dim2453Kuo2Init,
                dim2454Kuo2Init,
                dim2455Kuo2Init,
                dim2456Kuo2Init,
                dim2457Kuo2Init,
                dim2458Kuo2Init,
                dim2459Kuo2Init,
                dim2460Kuo2Init,
                dim2461Kuo2Init,
                dim2462Kuo2Init,
                dim2463Kuo2Init,
                dim2464Kuo2Init,
                dim2465Kuo2Init,
                dim2466Kuo2Init,
                dim2467Kuo2Init,
                dim2468Kuo2Init,
                dim2469Kuo2Init,
                dim2470Kuo2Init,
                dim2471Kuo2Init,
                dim2472Kuo2Init,
                dim2473Kuo2Init,
                dim2474Kuo2Init,
                dim2475Kuo2Init,
                dim2476Kuo2Init,
                dim2477Kuo2Init,
                dim2478Kuo2Init,
                dim2479Kuo2Init,
                dim2480Kuo2Init,
                dim2481Kuo2Init,
                dim2482Kuo2Init,
                dim2483Kuo2Init,
                dim2484Kuo2Init,
                dim2485Kuo2Init,
                dim2486Kuo2Init,
                dim2487Kuo2Init,
                dim2488Kuo2Init,
                dim2489Kuo2Init,
                dim2490Kuo2Init,
                dim2491Kuo2Init,
                dim2492Kuo2Init,
                dim2493Kuo2Init,
                dim2494Kuo2Init,
                dim2495Kuo2Init,
                dim2496Kuo2Init,
                dim2497Kuo2Init,
                dim2498Kuo2Init,
                dim2499Kuo2Init,
                dim2500Kuo2Init,
                dim2501Kuo2Init,
                dim2502Kuo2Init,
                dim2503Kuo2Init,
                dim2504Kuo2Init,
                dim2505Kuo2Init,
                dim2506Kuo2Init,
                dim2507Kuo2Init,
                dim2508Kuo2Init,
                dim2509Kuo2Init,
                dim2510Kuo2Init,
                dim2511Kuo2Init,
                dim2512Kuo2Init,
                dim2513Kuo2Init,
                dim2514Kuo2Init,
                dim2515Kuo2Init,
                dim2516Kuo2Init,
                dim2517Kuo2Init,
                dim2518Kuo2Init,
                dim2519Kuo2Init,
                dim2520Kuo2Init,
                dim2521Kuo2Init,
                dim2522Kuo2Init,
                dim2523Kuo2Init,
                dim2524Kuo2Init,
                dim2525Kuo2Init,
                dim2526Kuo2Init,
                dim2527Kuo2Init,
                dim2528Kuo2Init,
                dim2529Kuo2Init,
                dim2530Kuo2Init,
                dim2531Kuo2Init,
                dim2532Kuo2Init,
                dim2533Kuo2Init,
                dim2534Kuo2Init,
                dim2535Kuo2Init,
                dim2536Kuo2Init,
                dim2537Kuo2Init,
                dim2538Kuo2Init,
                dim2539Kuo2Init,
                dim2540Kuo2Init,
                dim2541Kuo2Init,
                dim2542Kuo2Init,
                dim2543Kuo2Init,
                dim2544Kuo2Init,
                dim2545Kuo2Init,
                dim2546Kuo2Init,
                dim2547Kuo2Init,
                dim2548Kuo2Init,
                dim2549Kuo2Init,
                dim2550Kuo2Init,
                dim2551Kuo2Init,
                dim2552Kuo2Init,
                dim2553Kuo2Init,
                dim2554Kuo2Init,
                dim2555Kuo2Init,
                dim2556Kuo2Init,
                dim2557Kuo2Init,
                dim2558Kuo2Init,
                dim2559Kuo2Init,
                dim2560Kuo2Init,
                dim2561Kuo2Init,
                dim2562Kuo2Init,
                dim2563Kuo2Init,
                dim2564Kuo2Init,
                dim2565Kuo2Init,
                dim2566Kuo2Init,
                dim2567Kuo2Init,
                dim2568Kuo2Init,
                dim2569Kuo2Init,
                dim2570Kuo2Init,
                dim2571Kuo2Init,
                dim2572Kuo2Init,
                dim2573Kuo2Init,
                dim2574Kuo2Init,
                dim2575Kuo2Init,
                dim2576Kuo2Init,
                dim2577Kuo2Init,
                dim2578Kuo2Init,
                dim2579Kuo2Init,
                dim2580Kuo2Init,
                dim2581Kuo2Init,
                dim2582Kuo2Init,
                dim2583Kuo2Init,
                dim2584Kuo2Init,
                dim2585Kuo2Init,
                dim2586Kuo2Init,
                dim2587Kuo2Init,
                dim2588Kuo2Init,
                dim2589Kuo2Init,
                dim2590Kuo2Init,
                dim2591Kuo2Init,
                dim2592Kuo2Init,
                dim2593Kuo2Init,
                dim2594Kuo2Init,
                dim2595Kuo2Init,
                dim2596Kuo2Init,
                dim2597Kuo2Init,
                dim2598Kuo2Init,
                dim2599Kuo2Init,
                dim2600Kuo2Init,
                dim2601Kuo2Init,
                dim2602Kuo2Init,
                dim2603Kuo2Init,
                dim2604Kuo2Init,
                dim2605Kuo2Init,
                dim2606Kuo2Init,
                dim2607Kuo2Init,
                dim2608Kuo2Init,
                dim2609Kuo2Init,
                dim2610Kuo2Init,
                dim2611Kuo2Init,
                dim2612Kuo2Init,
                dim2613Kuo2Init,
                dim2614Kuo2Init,
                dim2615Kuo2Init,
                dim2616Kuo2Init,
                dim2617Kuo2Init,
                dim2618Kuo2Init,
                dim2619Kuo2Init,
                dim2620Kuo2Init,
                dim2621Kuo2Init,
                dim2622Kuo2Init,
                dim2623Kuo2Init,
                dim2624Kuo2Init,
                dim2625Kuo2Init,
                dim2626Kuo2Init,
                dim2627Kuo2Init,
                dim2628Kuo2Init,
                dim2629Kuo2Init,
                dim2630Kuo2Init,
                dim2631Kuo2Init,
                dim2632Kuo2Init,
                dim2633Kuo2Init,
                dim2634Kuo2Init,
                dim2635Kuo2Init,
                dim2636Kuo2Init,
                dim2637Kuo2Init,
                dim2638Kuo2Init,
                dim2639Kuo2Init,
                dim2640Kuo2Init,
                dim2641Kuo2Init,
                dim2642Kuo2Init,
                dim2643Kuo2Init,
                dim2644Kuo2Init,
                dim2645Kuo2Init,
                dim2646Kuo2Init,
                dim2647Kuo2Init,
                dim2648Kuo2Init,
                dim2649Kuo2Init,
                dim2650Kuo2Init,
                dim2651Kuo2Init,
                dim2652Kuo2Init,
                dim2653Kuo2Init,
                dim2654Kuo2Init,
                dim2655Kuo2Init,
                dim2656Kuo2Init,
                dim2657Kuo2Init,
                dim2658Kuo2Init,
                dim2659Kuo2Init,
                dim2660Kuo2Init,
                dim2661Kuo2Init,
                dim2662Kuo2Init,
                dim2663Kuo2Init,
                dim2664Kuo2Init,
                dim2665Kuo2Init,
                dim2666Kuo2Init,
                dim2667Kuo2Init,
                dim2668Kuo2Init,
                dim2669Kuo2Init,
                dim2670Kuo2Init,
                dim2671Kuo2Init,
                dim2672Kuo2Init,
                dim2673Kuo2Init,
                dim2674Kuo2Init,
                dim2675Kuo2Init,
                dim2676Kuo2Init,
                dim2677Kuo2Init,
                dim2678Kuo2Init,
                dim2679Kuo2Init,
                dim2680Kuo2Init,
                dim2681Kuo2Init,
                dim2682Kuo2Init,
                dim2683Kuo2Init,
                dim2684Kuo2Init,
                dim2685Kuo2Init,
                dim2686Kuo2Init,
                dim2687Kuo2Init,
                dim2688Kuo2Init,
                dim2689Kuo2Init,
                dim2690Kuo2Init,
                dim2691Kuo2Init,
                dim2692Kuo2Init,
                dim2693Kuo2Init,
                dim2694Kuo2Init,
                dim2695Kuo2Init,
                dim2696Kuo2Init,
                dim2697Kuo2Init,
                dim2698Kuo2Init,
                dim2699Kuo2Init,
                dim2700Kuo2Init,
                dim2701Kuo2Init,
                dim2702Kuo2Init,
                dim2703Kuo2Init,
                dim2704Kuo2Init,
                dim2705Kuo2Init,
                dim2706Kuo2Init,
                dim2707Kuo2Init,
                dim2708Kuo2Init,
                dim2709Kuo2Init,
                dim2710Kuo2Init,
                dim2711Kuo2Init,
                dim2712Kuo2Init,
                dim2713Kuo2Init,
                dim2714Kuo2Init,
                dim2715Kuo2Init,
                dim2716Kuo2Init,
                dim2717Kuo2Init,
                dim2718Kuo2Init,
                dim2719Kuo2Init,
                dim2720Kuo2Init,
                dim2721Kuo2Init,
                dim2722Kuo2Init,
                dim2723Kuo2Init,
                dim2724Kuo2Init,
                dim2725Kuo2Init,
                dim2726Kuo2Init,
                dim2727Kuo2Init,
                dim2728Kuo2Init,
                dim2729Kuo2Init,
                dim2730Kuo2Init,
                dim2731Kuo2Init,
                dim2732Kuo2Init,
                dim2733Kuo2Init,
                dim2734Kuo2Init,
                dim2735Kuo2Init,
                dim2736Kuo2Init,
                dim2737Kuo2Init,
                dim2738Kuo2Init,
                dim2739Kuo2Init,
                dim2740Kuo2Init,
                dim2741Kuo2Init,
                dim2742Kuo2Init,
                dim2743Kuo2Init,
                dim2744Kuo2Init,
                dim2745Kuo2Init,
                dim2746Kuo2Init,
                dim2747Kuo2Init,
                dim2748Kuo2Init,
                dim2749Kuo2Init,
                dim2750Kuo2Init,
                dim2751Kuo2Init,
                dim2752Kuo2Init,
                dim2753Kuo2Init,
                dim2754Kuo2Init,
                dim2755Kuo2Init,
                dim2756Kuo2Init,
                dim2757Kuo2Init,
                dim2758Kuo2Init,
                dim2759Kuo2Init,
                dim2760Kuo2Init,
                dim2761Kuo2Init,
                dim2762Kuo2Init,
                dim2763Kuo2Init,
                dim2764Kuo2Init,
                dim2765Kuo2Init,
                dim2766Kuo2Init,
                dim2767Kuo2Init,
                dim2768Kuo2Init,
                dim2769Kuo2Init,
                dim2770Kuo2Init,
                dim2771Kuo2Init,
                dim2772Kuo2Init,
                dim2773Kuo2Init,
                dim2774Kuo2Init,
                dim2775Kuo2Init,
                dim2776Kuo2Init,
                dim2777Kuo2Init,
                dim2778Kuo2Init,
                dim2779Kuo2Init,
                dim2780Kuo2Init,
                dim2781Kuo2Init,
                dim2782Kuo2Init,
                dim2783Kuo2Init,
                dim2784Kuo2Init,
                dim2785Kuo2Init,
                dim2786Kuo2Init,
                dim2787Kuo2Init,
                dim2788Kuo2Init,
                dim2789Kuo2Init,
                dim2790Kuo2Init,
                dim2791Kuo2Init,
                dim2792Kuo2Init,
                dim2793Kuo2Init,
                dim2794Kuo2Init,
                dim2795Kuo2Init,
                dim2796Kuo2Init,
                dim2797Kuo2Init,
                dim2798Kuo2Init,
                dim2799Kuo2Init,
                dim2800Kuo2Init,
                dim2801Kuo2Init,
                dim2802Kuo2Init,
                dim2803Kuo2Init,
                dim2804Kuo2Init,
                dim2805Kuo2Init,
                dim2806Kuo2Init,
                dim2807Kuo2Init,
                dim2808Kuo2Init,
                dim2809Kuo2Init,
                dim2810Kuo2Init,
                dim2811Kuo2Init,
                dim2812Kuo2Init,
                dim2813Kuo2Init,
                dim2814Kuo2Init,
                dim2815Kuo2Init,
                dim2816Kuo2Init,
                dim2817Kuo2Init,
                dim2818Kuo2Init,
                dim2819Kuo2Init,
                dim2820Kuo2Init,
                dim2821Kuo2Init,
                dim2822Kuo2Init,
                dim2823Kuo2Init,
                dim2824Kuo2Init,
                dim2825Kuo2Init,
                dim2826Kuo2Init,
                dim2827Kuo2Init,
                dim2828Kuo2Init,
                dim2829Kuo2Init,
                dim2830Kuo2Init,
                dim2831Kuo2Init,
                dim2832Kuo2Init,
                dim2833Kuo2Init,
                dim2834Kuo2Init,
                dim2835Kuo2Init,
                dim2836Kuo2Init,
                dim2837Kuo2Init,
                dim2838Kuo2Init,
                dim2839Kuo2Init,
                dim2840Kuo2Init,
                dim2841Kuo2Init,
                dim2842Kuo2Init,
                dim2843Kuo2Init,
                dim2844Kuo2Init,
                dim2845Kuo2Init,
                dim2846Kuo2Init,
                dim2847Kuo2Init,
                dim2848Kuo2Init,
                dim2849Kuo2Init,
                dim2850Kuo2Init,
                dim2851Kuo2Init,
                dim2852Kuo2Init,
                dim2853Kuo2Init,
                dim2854Kuo2Init,
                dim2855Kuo2Init,
                dim2856Kuo2Init,
                dim2857Kuo2Init,
                dim2858Kuo2Init,
                dim2859Kuo2Init,
                dim2860Kuo2Init,
                dim2861Kuo2Init,
                dim2862Kuo2Init,
                dim2863Kuo2Init,
                dim2864Kuo2Init,
                dim2865Kuo2Init,
                dim2866Kuo2Init,
                dim2867Kuo2Init,
                dim2868Kuo2Init,
                dim2869Kuo2Init,
                dim2870Kuo2Init,
                dim2871Kuo2Init,
                dim2872Kuo2Init,
                dim2873Kuo2Init,
                dim2874Kuo2Init,
                dim2875Kuo2Init,
                dim2876Kuo2Init,
                dim2877Kuo2Init,
                dim2878Kuo2Init,
                dim2879Kuo2Init,
                dim2880Kuo2Init,
                dim2881Kuo2Init,
                dim2882Kuo2Init,
                dim2883Kuo2Init,
                dim2884Kuo2Init,
                dim2885Kuo2Init,
                dim2886Kuo2Init,
                dim2887Kuo2Init,
                dim2888Kuo2Init,
                dim2889Kuo2Init,
                dim2890Kuo2Init,
                dim2891Kuo2Init,
                dim2892Kuo2Init,
                dim2893Kuo2Init,
                dim2894Kuo2Init,
                dim2895Kuo2Init,
                dim2896Kuo2Init,
                dim2897Kuo2Init,
                dim2898Kuo2Init,
                dim2899Kuo2Init,
                dim2900Kuo2Init,
                dim2901Kuo2Init,
                dim2902Kuo2Init,
                dim2903Kuo2Init,
                dim2904Kuo2Init,
                dim2905Kuo2Init,
                dim2906Kuo2Init,
                dim2907Kuo2Init,
                dim2908Kuo2Init,
                dim2909Kuo2Init,
                dim2910Kuo2Init,
                dim2911Kuo2Init,
                dim2912Kuo2Init,
                dim2913Kuo2Init,
                dim2914Kuo2Init,
                dim2915Kuo2Init,
                dim2916Kuo2Init,
                dim2917Kuo2Init,
                dim2918Kuo2Init,
                dim2919Kuo2Init,
                dim2920Kuo2Init,
                dim2921Kuo2Init,
                dim2922Kuo2Init,
                dim2923Kuo2Init,
                dim2924Kuo2Init,
                dim2925Kuo2Init,
                dim2926Kuo2Init,
                dim2927Kuo2Init,
                dim2928Kuo2Init,
                dim2929Kuo2Init,
                dim2930Kuo2Init,
                dim2931Kuo2Init,
                dim2932Kuo2Init,
                dim2933Kuo2Init,
                dim2934Kuo2Init,
                dim2935Kuo2Init,
                dim2936Kuo2Init,
                dim2937Kuo2Init,
                dim2938Kuo2Init,
                dim2939Kuo2Init,
                dim2940Kuo2Init,
                dim2941Kuo2Init,
                dim2942Kuo2Init,
                dim2943Kuo2Init,
                dim2944Kuo2Init,
                dim2945Kuo2Init,
                dim2946Kuo2Init,
                dim2947Kuo2Init,
                dim2948Kuo2Init,
                dim2949Kuo2Init,
                dim2950Kuo2Init,
                dim2951Kuo2Init,
                dim2952Kuo2Init,
                dim2953Kuo2Init,
                dim2954Kuo2Init,
                dim2955Kuo2Init,
                dim2956Kuo2Init,
                dim2957Kuo2Init,
                dim2958Kuo2Init,
                dim2959Kuo2Init,
                dim2960Kuo2Init,
                dim2961Kuo2Init,
                dim2962Kuo2Init,
                dim2963Kuo2Init,
                dim2964Kuo2Init,
                dim2965Kuo2Init,
                dim2966Kuo2Init,
                dim2967Kuo2Init,
                dim2968Kuo2Init,
                dim2969Kuo2Init,
                dim2970Kuo2Init,
                dim2971Kuo2Init,
                dim2972Kuo2Init,
                dim2973Kuo2Init,
                dim2974Kuo2Init,
                dim2975Kuo2Init,
                dim2976Kuo2Init,
                dim2977Kuo2Init,
                dim2978Kuo2Init,
                dim2979Kuo2Init,
                dim2980Kuo2Init,
                dim2981Kuo2Init,
                dim2982Kuo2Init,
                dim2983Kuo2Init,
                dim2984Kuo2Init,
                dim2985Kuo2Init,
                dim2986Kuo2Init,
                dim2987Kuo2Init,
                dim2988Kuo2Init,
                dim2989Kuo2Init,
                dim2990Kuo2Init,
                dim2991Kuo2Init,
                dim2992Kuo2Init,
                dim2993Kuo2Init,
                dim2994Kuo2Init,
                dim2995Kuo2Init,
                dim2996Kuo2Init,
                dim2997Kuo2Init,
                dim2998Kuo2Init,
                dim2999Kuo2Init,
                dim3000Kuo2Init,
                dim3001Kuo2Init,
                dim3002Kuo2Init,
                dim3003Kuo2Init,
                dim3004Kuo2Init,
                dim3005Kuo2Init,
                dim3006Kuo2Init,
                dim3007Kuo2Init,
                dim3008Kuo2Init,
                dim3009Kuo2Init,
                dim3010Kuo2Init,
                dim3011Kuo2Init,
                dim3012Kuo2Init,
                dim3013Kuo2Init,
                dim3014Kuo2Init,
                dim3015Kuo2Init,
                dim3016Kuo2Init,
                dim3017Kuo2Init,
                dim3018Kuo2Init,
                dim3019Kuo2Init,
                dim3020Kuo2Init,
                dim3021Kuo2Init,
                dim3022Kuo2Init,
                dim3023Kuo2Init,
                dim3024Kuo2Init,
                dim3025Kuo2Init,
                dim3026Kuo2Init,
                dim3027Kuo2Init,
                dim3028Kuo2Init,
                dim3029Kuo2Init,
                dim3030Kuo2Init,
                dim3031Kuo2Init,
                dim3032Kuo2Init,
                dim3033Kuo2Init,
                dim3034Kuo2Init,
                dim3035Kuo2Init,
                dim3036Kuo2Init,
                dim3037Kuo2Init,
                dim3038Kuo2Init,
                dim3039Kuo2Init,
                dim3040Kuo2Init,
                dim3041Kuo2Init,
                dim3042Kuo2Init,
                dim3043Kuo2Init,
                dim3044Kuo2Init,
                dim3045Kuo2Init,
                dim3046Kuo2Init,
                dim3047Kuo2Init,
                dim3048Kuo2Init,
                dim3049Kuo2Init,
                dim3050Kuo2Init,
                dim3051Kuo2Init,
                dim3052Kuo2Init,
                dim3053Kuo2Init,
                dim3054Kuo2Init,
                dim3055Kuo2Init,
                dim3056Kuo2Init,
                dim3057Kuo2Init,
                dim3058Kuo2Init,
                dim3059Kuo2Init,
                dim3060Kuo2Init,
                dim3061Kuo2Init,
                dim3062Kuo2Init,
                dim3063Kuo2Init,
                dim3064Kuo2Init,
                dim3065Kuo2Init,
                dim3066Kuo2Init,
                dim3067Kuo2Init,
                dim3068Kuo2Init,
                dim3069Kuo2Init,
                dim3070Kuo2Init,
                dim3071Kuo2Init,
                dim3072Kuo2Init,
                dim3073Kuo2Init,
                dim3074Kuo2Init,
                dim3075Kuo2Init,
                dim3076Kuo2Init,
                dim3077Kuo2Init,
                dim3078Kuo2Init,
                dim3079Kuo2Init,
                dim3080Kuo2Init,
                dim3081Kuo2Init,
                dim3082Kuo2Init,
                dim3083Kuo2Init,
                dim3084Kuo2Init,
                dim3085Kuo2Init,
                dim3086Kuo2Init,
                dim3087Kuo2Init,
                dim3088Kuo2Init,
                dim3089Kuo2Init,
                dim3090Kuo2Init,
                dim3091Kuo2Init,
                dim3092Kuo2Init,
                dim3093Kuo2Init,
                dim3094Kuo2Init,
                dim3095Kuo2Init,
                dim3096Kuo2Init,
                dim3097Kuo2Init,
                dim3098Kuo2Init,
                dim3099Kuo2Init,
                dim3100Kuo2Init,
                dim3101Kuo2Init,
                dim3102Kuo2Init,
                dim3103Kuo2Init,
                dim3104Kuo2Init,
                dim3105Kuo2Init,
                dim3106Kuo2Init,
                dim3107Kuo2Init,
                dim3108Kuo2Init,
                dim3109Kuo2Init,
                dim3110Kuo2Init,
                dim3111Kuo2Init,
                dim3112Kuo2Init,
                dim3113Kuo2Init,
                dim3114Kuo2Init,
                dim3115Kuo2Init,
                dim3116Kuo2Init,
                dim3117Kuo2Init,
                dim3118Kuo2Init,
                dim3119Kuo2Init,
                dim3120Kuo2Init,
                dim3121Kuo2Init,
                dim3122Kuo2Init,
                dim3123Kuo2Init,
                dim3124Kuo2Init,
                dim3125Kuo2Init,
                dim3126Kuo2Init,
                dim3127Kuo2Init,
                dim3128Kuo2Init,
                dim3129Kuo2Init,
                dim3130Kuo2Init,
                dim3131Kuo2Init,
                dim3132Kuo2Init,
                dim3133Kuo2Init,
                dim3134Kuo2Init,
                dim3135Kuo2Init,
                dim3136Kuo2Init,
                dim3137Kuo2Init,
                dim3138Kuo2Init,
                dim3139Kuo2Init,
                dim3140Kuo2Init,
                dim3141Kuo2Init,
                dim3142Kuo2Init,
                dim3143Kuo2Init,
                dim3144Kuo2Init,
                dim3145Kuo2Init,
                dim3146Kuo2Init,
                dim3147Kuo2Init,
                dim3148Kuo2Init,
                dim3149Kuo2Init,
                dim3150Kuo2Init,
                dim3151Kuo2Init,
                dim3152Kuo2Init,
                dim3153Kuo2Init,
                dim3154Kuo2Init,
                dim3155Kuo2Init,
                dim3156Kuo2Init,
                dim3157Kuo2Init,
                dim3158Kuo2Init,
                dim3159Kuo2Init,
                dim3160Kuo2Init,
                dim3161Kuo2Init,
                dim3162Kuo2Init,
                dim3163Kuo2Init,
                dim3164Kuo2Init,
                dim3165Kuo2Init,
                dim3166Kuo2Init,
                dim3167Kuo2Init,
                dim3168Kuo2Init,
                dim3169Kuo2Init,
                dim3170Kuo2Init,
                dim3171Kuo2Init,
                dim3172Kuo2Init,
                dim3173Kuo2Init,
                dim3174Kuo2Init,
                dim3175Kuo2Init,
                dim3176Kuo2Init,
                dim3177Kuo2Init,
                dim3178Kuo2Init,
                dim3179Kuo2Init,
                dim3180Kuo2Init,
                dim3181Kuo2Init,
                dim3182Kuo2Init,
                dim3183Kuo2Init,
                dim3184Kuo2Init,
                dim3185Kuo2Init,
                dim3186Kuo2Init,
                dim3187Kuo2Init,
                dim3188Kuo2Init,
                dim3189Kuo2Init,
                dim3190Kuo2Init,
                dim3191Kuo2Init,
                dim3192Kuo2Init,
                dim3193Kuo2Init,
                dim3194Kuo2Init,
                dim3195Kuo2Init,
                dim3196Kuo2Init,
                dim3197Kuo2Init,
                dim3198Kuo2Init,
                dim3199Kuo2Init,
                dim3200Kuo2Init,
                dim3201Kuo2Init,
                dim3202Kuo2Init,
                dim3203Kuo2Init,
                dim3204Kuo2Init,
                dim3205Kuo2Init,
                dim3206Kuo2Init,
                dim3207Kuo2Init,
                dim3208Kuo2Init,
                dim3209Kuo2Init,
                dim3210Kuo2Init,
                dim3211Kuo2Init,
                dim3212Kuo2Init,
                dim3213Kuo2Init,
                dim3214Kuo2Init,
                dim3215Kuo2Init,
                dim3216Kuo2Init,
                dim3217Kuo2Init,
                dim3218Kuo2Init,
                dim3219Kuo2Init,
                dim3220Kuo2Init,
                dim3221Kuo2Init,
                dim3222Kuo2Init,
                dim3223Kuo2Init,
                dim3224Kuo2Init,
                dim3225Kuo2Init,
                dim3226Kuo2Init,
                dim3227Kuo2Init,
                dim3228Kuo2Init,
                dim3229Kuo2Init,
                dim3230Kuo2Init,
                dim3231Kuo2Init,
                dim3232Kuo2Init,
                dim3233Kuo2Init,
                dim3234Kuo2Init,
                dim3235Kuo2Init,
                dim3236Kuo2Init,
                dim3237Kuo2Init,
                dim3238Kuo2Init,
                dim3239Kuo2Init,
                dim3240Kuo2Init,
                dim3241Kuo2Init,
                dim3242Kuo2Init,
                dim3243Kuo2Init,
                dim3244Kuo2Init,
                dim3245Kuo2Init,
                dim3246Kuo2Init,
                dim3247Kuo2Init,
                dim3248Kuo2Init,
                dim3249Kuo2Init,
                dim3250Kuo2Init,
                dim3251Kuo2Init,
                dim3252Kuo2Init,
                dim3253Kuo2Init,
                dim3254Kuo2Init,
                dim3255Kuo2Init,
                dim3256Kuo2Init,
                dim3257Kuo2Init,
                dim3258Kuo2Init,
                dim3259Kuo2Init,
                dim3260Kuo2Init,
                dim3261Kuo2Init,
                dim3262Kuo2Init,
                dim3263Kuo2Init,
                dim3264Kuo2Init,
                dim3265Kuo2Init,
                dim3266Kuo2Init,
                dim3267Kuo2Init,
                dim3268Kuo2Init,
                dim3269Kuo2Init,
                dim3270Kuo2Init,
                dim3271Kuo2Init,
                dim3272Kuo2Init,
                dim3273Kuo2Init,
                dim3274Kuo2Init,
                dim3275Kuo2Init,
                dim3276Kuo2Init,
                dim3277Kuo2Init,
                dim3278Kuo2Init,
                dim3279Kuo2Init,
                dim3280Kuo2Init,
                dim3281Kuo2Init,
                dim3282Kuo2Init,
                dim3283Kuo2Init,
                dim3284Kuo2Init,
                dim3285Kuo2Init,
                dim3286Kuo2Init,
                dim3287Kuo2Init,
                dim3288Kuo2Init,
                dim3289Kuo2Init,
                dim3290Kuo2Init,
                dim3291Kuo2Init,
                dim3292Kuo2Init,
                dim3293Kuo2Init,
                dim3294Kuo2Init,
                dim3295Kuo2Init,
                dim3296Kuo2Init,
                dim3297Kuo2Init,
                dim3298Kuo2Init,
                dim3299Kuo2Init,
                dim3300Kuo2Init,
                dim3301Kuo2Init,
                dim3302Kuo2Init,
                dim3303Kuo2Init,
                dim3304Kuo2Init,
                dim3305Kuo2Init,
                dim3306Kuo2Init,
                dim3307Kuo2Init,
                dim3308Kuo2Init,
                dim3309Kuo2Init,
                dim3310Kuo2Init,
                dim3311Kuo2Init,
                dim3312Kuo2Init,
                dim3313Kuo2Init,
                dim3314Kuo2Init,
                dim3315Kuo2Init,
                dim3316Kuo2Init,
                dim3317Kuo2Init,
                dim3318Kuo2Init,
                dim3319Kuo2Init,
                dim3320Kuo2Init,
                dim3321Kuo2Init,
                dim3322Kuo2Init,
                dim3323Kuo2Init,
                dim3324Kuo2Init,
                dim3325Kuo2Init,
                dim3326Kuo2Init,
                dim3327Kuo2Init,
                dim3328Kuo2Init,
                dim3329Kuo2Init,
                dim3330Kuo2Init,
                dim3331Kuo2Init,
                dim3332Kuo2Init,
                dim3333Kuo2Init,
                dim3334Kuo2Init,
                dim3335Kuo2Init,
                dim3336Kuo2Init,
                dim3337Kuo2Init,
                dim3338Kuo2Init,
                dim3339Kuo2Init,
                dim3340Kuo2Init,
                dim3341Kuo2Init,
                dim3342Kuo2Init,
                dim3343Kuo2Init,
                dim3344Kuo2Init,
                dim3345Kuo2Init,
                dim3346Kuo2Init,
                dim3347Kuo2Init,
                dim3348Kuo2Init,
                dim3349Kuo2Init,
                dim3350Kuo2Init,
                dim3351Kuo2Init,
                dim3352Kuo2Init,
                dim3353Kuo2Init,
                dim3354Kuo2Init,
                dim3355Kuo2Init,
                dim3356Kuo2Init,
                dim3357Kuo2Init,
                dim3358Kuo2Init,
                dim3359Kuo2Init,
                dim3360Kuo2Init,
                dim3361Kuo2Init,
                dim3362Kuo2Init,
                dim3363Kuo2Init,
                dim3364Kuo2Init,
                dim3365Kuo2Init,
                dim3366Kuo2Init,
                dim3367Kuo2Init,
                dim3368Kuo2Init,
                dim3369Kuo2Init,
                dim3370Kuo2Init,
                dim3371Kuo2Init,
                dim3372Kuo2Init,
                dim3373Kuo2Init,
                dim3374Kuo2Init,
                dim3375Kuo2Init,
                dim3376Kuo2Init,
                dim3377Kuo2Init,
                dim3378Kuo2Init,
                dim3379Kuo2Init,
                dim3380Kuo2Init,
                dim3381Kuo2Init,
                dim3382Kuo2Init,
                dim3383Kuo2Init,
                dim3384Kuo2Init,
                dim3385Kuo2Init,
                dim3386Kuo2Init,
                dim3387Kuo2Init,
                dim3388Kuo2Init,
                dim3389Kuo2Init,
                dim3390Kuo2Init,
                dim3391Kuo2Init,
                dim3392Kuo2Init,
                dim3393Kuo2Init,
                dim3394Kuo2Init,
                dim3395Kuo2Init,
                dim3396Kuo2Init,
                dim3397Kuo2Init,
                dim3398Kuo2Init,
                dim3399Kuo2Init,
                dim3400Kuo2Init,
                dim3401Kuo2Init,
                dim3402Kuo2Init,
                dim3403Kuo2Init,
                dim3404Kuo2Init,
                dim3405Kuo2Init,
                dim3406Kuo2Init,
                dim3407Kuo2Init,
                dim3408Kuo2Init,
                dim3409Kuo2Init,
                dim3410Kuo2Init,
                dim3411Kuo2Init,
                dim3412Kuo2Init,
                dim3413Kuo2Init,
                dim3414Kuo2Init,
                dim3415Kuo2Init,
                dim3416Kuo2Init,
                dim3417Kuo2Init,
                dim3418Kuo2Init,
                dim3419Kuo2Init,
                dim3420Kuo2Init,
                dim3421Kuo2Init,
                dim3422Kuo2Init,
                dim3423Kuo2Init,
                dim3424Kuo2Init,
                dim3425Kuo2Init,
                dim3426Kuo2Init,
                dim3427Kuo2Init,
                dim3428Kuo2Init,
                dim3429Kuo2Init,
                dim3430Kuo2Init,
                dim3431Kuo2Init,
                dim3432Kuo2Init,
                dim3433Kuo2Init,
                dim3434Kuo2Init,
                dim3435Kuo2Init,
                dim3436Kuo2Init,
                dim3437Kuo2Init,
                dim3438Kuo2Init,
                dim3439Kuo2Init,
                dim3440Kuo2Init,
                dim3441Kuo2Init,
                dim3442Kuo2Init,
                dim3443Kuo2Init,
                dim3444Kuo2Init,
                dim3445Kuo2Init,
                dim3446Kuo2Init,
                dim3447Kuo2Init,
                dim3448Kuo2Init,
                dim3449Kuo2Init,
                dim3450Kuo2Init,
                dim3451Kuo2Init,
                dim3452Kuo2Init,
                dim3453Kuo2Init,
                dim3454Kuo2Init,
                dim3455Kuo2Init,
                dim3456Kuo2Init,
                dim3457Kuo2Init,
                dim3458Kuo2Init,
                dim3459Kuo2Init,
                dim3460Kuo2Init,
                dim3461Kuo2Init,
                dim3462Kuo2Init,
                dim3463Kuo2Init,
                dim3464Kuo2Init,
                dim3465Kuo2Init,
                dim3466Kuo2Init,
                dim3467Kuo2Init,
                dim3468Kuo2Init,
                dim3469Kuo2Init,
                dim3470Kuo2Init,
                dim3471Kuo2Init,
                dim3472Kuo2Init,
                dim3473Kuo2Init,
                dim3474Kuo2Init,
                dim3475Kuo2Init,
                dim3476Kuo2Init,
                dim3477Kuo2Init,
                dim3478Kuo2Init,
                dim3479Kuo2Init,
                dim3480Kuo2Init,
                dim3481Kuo2Init,
                dim3482Kuo2Init,
                dim3483Kuo2Init,
                dim3484Kuo2Init,
                dim3485Kuo2Init,
                dim3486Kuo2Init,
                dim3487Kuo2Init,
                dim3488Kuo2Init,
                dim3489Kuo2Init,
                dim3490Kuo2Init,
                dim3491Kuo2Init,
                dim3492Kuo2Init,
                dim3493Kuo2Init,
                dim3494Kuo2Init,
                dim3495Kuo2Init,
                dim3496Kuo2Init,
                dim3497Kuo2Init,
                dim3498Kuo2Init,
                dim3499Kuo2Init,
                dim3500Kuo2Init,
                dim3501Kuo2Init,
                dim3502Kuo2Init,
                dim3503Kuo2Init,
                dim3504Kuo2Init,
                dim3505Kuo2Init,
                dim3506Kuo2Init,
                dim3507Kuo2Init,
                dim3508Kuo2Init,
                dim3509Kuo2Init,
                dim3510Kuo2Init,
                dim3511Kuo2Init,
                dim3512Kuo2Init,
                dim3513Kuo2Init,
                dim3514Kuo2Init,
                dim3515Kuo2Init,
                dim3516Kuo2Init,
                dim3517Kuo2Init,
                dim3518Kuo2Init,
                dim3519Kuo2Init,
                dim3520Kuo2Init,
                dim3521Kuo2Init,
                dim3522Kuo2Init,
                dim3523Kuo2Init,
                dim3524Kuo2Init,
                dim3525Kuo2Init,
                dim3526Kuo2Init,
                dim3527Kuo2Init,
                dim3528Kuo2Init,
                dim3529Kuo2Init,
                dim3530Kuo2Init,
                dim3531Kuo2Init,
                dim3532Kuo2Init,
                dim3533Kuo2Init,
                dim3534Kuo2Init,
                dim3535Kuo2Init,
                dim3536Kuo2Init,
                dim3537Kuo2Init,
                dim3538Kuo2Init,
                dim3539Kuo2Init,
                dim3540Kuo2Init,
                dim3541Kuo2Init,
                dim3542Kuo2Init,
                dim3543Kuo2Init,
                dim3544Kuo2Init,
                dim3545Kuo2Init,
                dim3546Kuo2Init,
                dim3547Kuo2Init,
                dim3548Kuo2Init,
                dim3549Kuo2Init,
                dim3550Kuo2Init,
                dim3551Kuo2Init,
                dim3552Kuo2Init,
                dim3553Kuo2Init,
                dim3554Kuo2Init,
                dim3555Kuo2Init,
                dim3556Kuo2Init,
                dim3557Kuo2Init,
                dim3558Kuo2Init,
                dim3559Kuo2Init,
                dim3560Kuo2Init,
                dim3561Kuo2Init,
                dim3562Kuo2Init,
                dim3563Kuo2Init,
                dim3564Kuo2Init,
                dim3565Kuo2Init,
                dim3566Kuo2Init,
                dim3567Kuo2Init,
                dim3568Kuo2Init,
                dim3569Kuo2Init,
                dim3570Kuo2Init,
                dim3571Kuo2Init,
                dim3572Kuo2Init,
                dim3573Kuo2Init,
                dim3574Kuo2Init,
                dim3575Kuo2Init,
                dim3576Kuo2Init,
                dim3577Kuo2Init,
                dim3578Kuo2Init,
                dim3579Kuo2Init,
                dim3580Kuo2Init,
                dim3581Kuo2Init,
                dim3582Kuo2Init,
                dim3583Kuo2Init,
                dim3584Kuo2Init,
                dim3585Kuo2Init,
                dim3586Kuo2Init,
                dim3587Kuo2Init,
                dim3588Kuo2Init,
                dim3589Kuo2Init,
                dim3590Kuo2Init,
                dim3591Kuo2Init,
                dim3592Kuo2Init,
                dim3593Kuo2Init,
                dim3594Kuo2Init,
                dim3595Kuo2Init,
                dim3596Kuo2Init,
                dim3597Kuo2Init,
                dim3598Kuo2Init,
                dim3599Kuo2Init,
                dim3600Kuo2Init,
                dim3601Kuo2Init,
                dim3602Kuo2Init,
                dim3603Kuo2Init,
                dim3604Kuo2Init,
                dim3605Kuo2Init,
                dim3606Kuo2Init,
                dim3607Kuo2Init,
                dim3608Kuo2Init,
                dim3609Kuo2Init,
                dim3610Kuo2Init,
                dim3611Kuo2Init,
                dim3612Kuo2Init,
                dim3613Kuo2Init,
                dim3614Kuo2Init,
                dim3615Kuo2Init,
                dim3616Kuo2Init,
                dim3617Kuo2Init,
                dim3618Kuo2Init,
                dim3619Kuo2Init,
                dim3620Kuo2Init,
                dim3621Kuo2Init,
                dim3622Kuo2Init,
                dim3623Kuo2Init,
                dim3624Kuo2Init,
                dim3625Kuo2Init,
                dim3626Kuo2Init,
                dim3627Kuo2Init,
                dim3628Kuo2Init,
                dim3629Kuo2Init,
                dim3630Kuo2Init,
                dim3631Kuo2Init,
                dim3632Kuo2Init,
                dim3633Kuo2Init,
                dim3634Kuo2Init,
                dim3635Kuo2Init,
                dim3636Kuo2Init,
                dim3637Kuo2Init,
                dim3638Kuo2Init,
                dim3639Kuo2Init,
                dim3640Kuo2Init,
                dim3641Kuo2Init,
                dim3642Kuo2Init,
                dim3643Kuo2Init,
                dim3644Kuo2Init,
                dim3645Kuo2Init,
                dim3646Kuo2Init,
                dim3647Kuo2Init,
                dim3648Kuo2Init,
                dim3649Kuo2Init,
                dim3650Kuo2Init,
                dim3651Kuo2Init,
                dim3652Kuo2Init,
                dim3653Kuo2Init,
                dim3654Kuo2Init,
                dim3655Kuo2Init,
                dim3656Kuo2Init,
                dim3657Kuo2Init,
                dim3658Kuo2Init,
                dim3659Kuo2Init,
                dim3660Kuo2Init,
                dim3661Kuo2Init,
                dim3662Kuo2Init,
                dim3663Kuo2Init,
                dim3664Kuo2Init,
                dim3665Kuo2Init,
                dim3666Kuo2Init,
                dim3667Kuo2Init,
                dim3668Kuo2Init,
                dim3669Kuo2Init,
                dim3670Kuo2Init,
                dim3671Kuo2Init,
                dim3672Kuo2Init,
                dim3673Kuo2Init,
                dim3674Kuo2Init,
                dim3675Kuo2Init,
                dim3676Kuo2Init,
                dim3677Kuo2Init,
                dim3678Kuo2Init,
                dim3679Kuo2Init,
                dim3680Kuo2Init,
                dim3681Kuo2Init,
                dim3682Kuo2Init,
                dim3683Kuo2Init,
                dim3684Kuo2Init,
                dim3685Kuo2Init,
                dim3686Kuo2Init,
                dim3687Kuo2Init,
                dim3688Kuo2Init,
                dim3689Kuo2Init,
                dim3690Kuo2Init,
                dim3691Kuo2Init,
                dim3692Kuo2Init,
                dim3693Kuo2Init,
                dim3694Kuo2Init,
                dim3695Kuo2Init,
                dim3696Kuo2Init,
                dim3697Kuo2Init,
                dim3698Kuo2Init,
                dim3699Kuo2Init,
                dim3700Kuo2Init,
                dim3701Kuo2Init,
                dim3702Kuo2Init,
                dim3703Kuo2Init,
                dim3704Kuo2Init,
                dim3705Kuo2Init,
                dim3706Kuo2Init,
                dim3707Kuo2Init,
                dim3708Kuo2Init,
                dim3709Kuo2Init,
                dim3710Kuo2Init,
                dim3711Kuo2Init,
                dim3712Kuo2Init,
                dim3713Kuo2Init,
                dim3714Kuo2Init,
                dim3715Kuo2Init,
                dim3716Kuo2Init,
                dim3717Kuo2Init,
                dim3718Kuo2Init,
                dim3719Kuo2Init,
                dim3720Kuo2Init,
                dim3721Kuo2Init,
                dim3722Kuo2Init,
                dim3723Kuo2Init,
                dim3724Kuo2Init,
                dim3725Kuo2Init,
                dim3726Kuo2Init,
                dim3727Kuo2Init,
                dim3728Kuo2Init,
                dim3729Kuo2Init,
                dim3730Kuo2Init,
                dim3731Kuo2Init,
                dim3732Kuo2Init,
                dim3733Kuo2Init,
                dim3734Kuo2Init,
                dim3735Kuo2Init,
                dim3736Kuo2Init,
                dim3737Kuo2Init,
                dim3738Kuo2Init,
                dim3739Kuo2Init,
                dim3740Kuo2Init,
                dim3741Kuo2Init,
                dim3742Kuo2Init,
                dim3743Kuo2Init,
                dim3744Kuo2Init,
                dim3745Kuo2Init,
                dim3746Kuo2Init,
                dim3747Kuo2Init,
                dim3748Kuo2Init,
                dim3749Kuo2Init,
                dim3750Kuo2Init,
                dim3751Kuo2Init,
                dim3752Kuo2Init,
                dim3753Kuo2Init,
                dim3754Kuo2Init,
                dim3755Kuo2Init,
                dim3756Kuo2Init,
                dim3757Kuo2Init,
                dim3758Kuo2Init,
                dim3759Kuo2Init,
                dim3760Kuo2Init,
                dim3761Kuo2Init,
                dim3762Kuo2Init,
                dim3763Kuo2Init,
                dim3764Kuo2Init,
                dim3765Kuo2Init,
                dim3766Kuo2Init,
                dim3767Kuo2Init,
                dim3768Kuo2Init,
                dim3769Kuo2Init,
                dim3770Kuo2Init,
                dim3771Kuo2Init,
                dim3772Kuo2Init,
                dim3773Kuo2Init,
                dim3774Kuo2Init,
                dim3775Kuo2Init,
                dim3776Kuo2Init,
                dim3777Kuo2Init,
                dim3778Kuo2Init,
                dim3779Kuo2Init,
                dim3780Kuo2Init,
                dim3781Kuo2Init,
                dim3782Kuo2Init,
                dim3783Kuo2Init,
                dim3784Kuo2Init,
                dim3785Kuo2Init,
                dim3786Kuo2Init,
                dim3787Kuo2Init,
                dim3788Kuo2Init,
                dim3789Kuo2Init,
                dim3790Kuo2Init,
                dim3791Kuo2Init,
                dim3792Kuo2Init,
                dim3793Kuo2Init,
                dim3794Kuo2Init,
                dim3795Kuo2Init,
                dim3796Kuo2Init,
                dim3797Kuo2Init,
                dim3798Kuo2Init,
                dim3799Kuo2Init,
                dim3800Kuo2Init,
                dim3801Kuo2Init,
                dim3802Kuo2Init,
                dim3803Kuo2Init,
                dim3804Kuo2Init,
                dim3805Kuo2Init,
                dim3806Kuo2Init,
                dim3807Kuo2Init,
                dim3808Kuo2Init,
                dim3809Kuo2Init,
                dim3810Kuo2Init,
                dim3811Kuo2Init,
                dim3812Kuo2Init,
                dim3813Kuo2Init,
                dim3814Kuo2Init,
                dim3815Kuo2Init,
                dim3816Kuo2Init,
                dim3817Kuo2Init,
                dim3818Kuo2Init,
                dim3819Kuo2Init,
                dim3820Kuo2Init,
                dim3821Kuo2Init,
                dim3822Kuo2Init,
                dim3823Kuo2Init,
                dim3824Kuo2Init,
                dim3825Kuo2Init,
                dim3826Kuo2Init,
                dim3827Kuo2Init,
                dim3828Kuo2Init,
                dim3829Kuo2Init,
                dim3830Kuo2Init,
                dim3831Kuo2Init,
                dim3832Kuo2Init,
                dim3833Kuo2Init,
                dim3834Kuo2Init,
                dim3835Kuo2Init,
                dim3836Kuo2Init,
                dim3837Kuo2Init,
                dim3838Kuo2Init,
                dim3839Kuo2Init,
                dim3840Kuo2Init,
                dim3841Kuo2Init,
                dim3842Kuo2Init,
                dim3843Kuo2Init,
                dim3844Kuo2Init,
                dim3845Kuo2Init,
                dim3846Kuo2Init,
                dim3847Kuo2Init,
                dim3848Kuo2Init,
                dim3849Kuo2Init,
                dim3850Kuo2Init,
                dim3851Kuo2Init,
                dim3852Kuo2Init,
                dim3853Kuo2Init,
                dim3854Kuo2Init,
                dim3855Kuo2Init,
                dim3856Kuo2Init,
                dim3857Kuo2Init,
                dim3858Kuo2Init,
                dim3859Kuo2Init,
                dim3860Kuo2Init,
                dim3861Kuo2Init,
                dim3862Kuo2Init,
                dim3863Kuo2Init,
                dim3864Kuo2Init,
                dim3865Kuo2Init,
                dim3866Kuo2Init,
                dim3867Kuo2Init,
                dim3868Kuo2Init,
                dim3869Kuo2Init,
                dim3870Kuo2Init,
                dim3871Kuo2Init,
                dim3872Kuo2Init,
                dim3873Kuo2Init,
                dim3874Kuo2Init,
                dim3875Kuo2Init,
                dim3876Kuo2Init,
                dim3877Kuo2Init,
                dim3878Kuo2Init,
                dim3879Kuo2Init,
                dim3880Kuo2Init,
                dim3881Kuo2Init,
                dim3882Kuo2Init,
                dim3883Kuo2Init,
                dim3884Kuo2Init,
                dim3885Kuo2Init,
                dim3886Kuo2Init,
                dim3887Kuo2Init,
                dim3888Kuo2Init,
                dim3889Kuo2Init,
                dim3890Kuo2Init,
                dim3891Kuo2Init,
                dim3892Kuo2Init,
                dim3893Kuo2Init,
                dim3894Kuo2Init,
                dim3895Kuo2Init,
                dim3896Kuo2Init,
                dim3897Kuo2Init,
                dim3898Kuo2Init,
                dim3899Kuo2Init,
                dim3900Kuo2Init,
                dim3901Kuo2Init,
                dim3902Kuo2Init,
                dim3903Kuo2Init,
                dim3904Kuo2Init,
                dim3905Kuo2Init,
                dim3906Kuo2Init,
                dim3907Kuo2Init,
                dim3908Kuo2Init,
                dim3909Kuo2Init,
                dim3910Kuo2Init,
                dim3911Kuo2Init,
                dim3912Kuo2Init,
                dim3913Kuo2Init,
                dim3914Kuo2Init,
                dim3915Kuo2Init,
                dim3916Kuo2Init,
                dim3917Kuo2Init,
                dim3918Kuo2Init,
                dim3919Kuo2Init,
                dim3920Kuo2Init,
                dim3921Kuo2Init,
                dim3922Kuo2Init,
                dim3923Kuo2Init,
                dim3924Kuo2Init,
                dim3925Kuo2Init,
                dim3926Kuo2Init,
                dim3927Kuo2Init,
                dim3928Kuo2Init,
                dim3929Kuo2Init,
                dim3930Kuo2Init,
                dim3931Kuo2Init,
                dim3932Kuo2Init,
                dim3933Kuo2Init,
                dim3934Kuo2Init,
                dim3935Kuo2Init,
                dim3936Kuo2Init,
                dim3937Kuo2Init,
                dim3938Kuo2Init,
                dim3939Kuo2Init,
                dim3940Kuo2Init,
                dim3941Kuo2Init,
                dim3942Kuo2Init,
                dim3943Kuo2Init,
                dim3944Kuo2Init,
                dim3945Kuo2Init,
                dim3946Kuo2Init,
            };

            const std::uint32_t dim1Kuo3Init[]  =   {   1   ,0 };
            const std::uint32_t dim2Kuo3Init[]  =   {   1   ,   1   ,0 };
            const std::uint32_t dim3Kuo3Init[]  =   {   1   ,   1   ,   1   ,0 };
            const std::uint32_t dim4Kuo3Init[]  =   {   1   ,   3   ,   1   ,0 };
            const std::uint32_t dim5Kuo3Init[]  =   {   1   ,   3   ,   7   ,   1   ,0 };
            const std::uint32_t dim6Kuo3Init[]  =   {   1   ,   1   ,   3   ,   7   ,0 };
            const std::uint32_t dim7Kuo3Init[]  =   {   1   ,   3   ,   1   ,   7   ,   23  ,0 };
            const std::uint32_t dim8Kuo3Init[]  =   {   1   ,   3   ,   1   ,   1   ,   13  ,0 };
            const std::uint32_t dim9Kuo3Init[]  =   {   1   ,   1   ,   7   ,   7   ,   9   ,0 };
            const std::uint32_t dim10Kuo3Init[] =   {   1   ,   1   ,   5   ,   15  ,   21  ,0 };
            const std::uint32_t dim11Kuo3Init[] =   {   1   ,   3   ,   5   ,   3   ,   23  ,0 };
            const std::uint32_t dim12Kuo3Init[] =   {   1   ,   1   ,   1   ,   15  ,   27  ,0 };
            const std::uint32_t dim13Kuo3Init[] =   {   1   ,   3   ,   7   ,   9   ,   1   ,   9   ,0 };
            const std::uint32_t dim14Kuo3Init[] =   {   1   ,   1   ,   7   ,   15  ,   31  ,   37  ,0 };
            const std::uint32_t dim15Kuo3Init[] =   {   1   ,   1   ,   5   ,   5   ,   31  ,   9   ,0 };
            const std::uint32_t dim16Kuo3Init[] =   {   1   ,   3   ,   1   ,   13  ,   3   ,   49  ,0 };
            const std::uint32_t dim17Kuo3Init[] =   {   1   ,   1   ,   7   ,   15  ,   1   ,   13  ,0 };
            const std::uint32_t dim18Kuo3Init[] =   {   1   ,   3   ,   3   ,   13  ,   29  ,   37  ,0 };
            const std::uint32_t dim19Kuo3Init[] =   {   1   ,   1   ,   1   ,   5   ,   13  ,   51  ,   45  ,0 };
            const std::uint32_t dim20Kuo3Init[] =   {   1   ,   3   ,   1   ,   7   ,   19  ,   23  ,   51  ,0 };
            const std::uint32_t dim21Kuo3Init[] =   {   1   ,   3   ,   7   ,   1   ,   27  ,   45  ,   61  ,0 };
            const std::uint32_t dim22Kuo3Init[] =   {   1   ,   3   ,   7   ,   3   ,   9   ,   51  ,   1   ,0 };
            const std::uint32_t dim23Kuo3Init[] =   {   1   ,   3   ,   1   ,   11  ,   27  ,   3   ,   23  ,0 };
            const std::uint32_t dim24Kuo3Init[] =   {   1   ,   3   ,   7   ,   9   ,   5   ,   35  ,   105 ,0 };
            const std::uint32_t dim25Kuo3Init[] =   {   1   ,   1   ,   1   ,   1   ,   19  ,   21  ,   69  ,0 };
            const std::uint32_t dim26Kuo3Init[] =   {   1   ,   3   ,   3   ,   5   ,   11  ,   61  ,   41  ,0 };
            const std::uint32_t dim27Kuo3Init[] =   {   1   ,   1   ,   3   ,   13  ,   15  ,   17  ,   25  ,0 };
            const std::uint32_t dim28Kuo3Init[] =   {   1   ,   1   ,   1   ,   13  ,   19  ,   47  ,   19  ,0 };
            const std::uint32_t dim29Kuo3Init[] =   {   1   ,   1   ,   7   ,   1   ,   31  ,   23  ,   127 ,0 };
            const std::uint32_t dim30Kuo3Init[] =   {   1   ,   1   ,   7   ,   1   ,   31  ,   59  ,   123 ,0 };
            const std::uint32_t dim31Kuo3Init[] =   {   1   ,   1   ,   5   ,   5   ,   13  ,   39  ,   109 ,0 };
            const std::uint32_t dim32Kuo3Init[] =   {   1   ,   3   ,   7   ,   15  ,   23  ,   19  ,   127 ,0 };
            const std::uint32_t dim33Kuo3Init[] =   {   1   ,   1   ,   5   ,   3   ,   1   ,   47  ,   15  ,0 };
            const std::uint32_t dim34Kuo3Init[] =   {   1   ,   1   ,   3   ,   13  ,   23  ,   1   ,   61  ,0 };
            const std::uint32_t dim35Kuo3Init[] =   {   1   ,   3   ,   3   ,   3   ,   3   ,   35  ,   83  ,0 };
            const std::uint32_t dim36Kuo3Init[] =   {   1   ,   1   ,   5   ,   5   ,   13  ,   5   ,   19  ,0 };
            const std::uint32_t dim37Kuo3Init[] =   {   1   ,   1   ,   5   ,   9   ,   13  ,   51  ,   25  ,   117 ,0 };
            const std::uint32_t dim38Kuo3Init[] =   {   1   ,   1   ,   5   ,   11  ,   19  ,   33  ,   111 ,   71  ,0 };
            const std::uint32_t dim39Kuo3Init[] =   {   1   ,   3   ,   1   ,   9   ,   5   ,   63  ,   33  ,   27  ,0 };
            const std::uint32_t dim40Kuo3Init[] =   {   1   ,   3   ,   1   ,   5   ,   19  ,   57  ,   15  ,   181 ,0 };
            const std::uint32_t dim41Kuo3Init[] =   {   1   ,   3   ,   7   ,   5   ,   5   ,   41  ,   115 ,   15  ,0 };
            const std::uint32_t dim42Kuo3Init[] =   {   1   ,   3   ,   1   ,   9   ,   9   ,   23  ,   45  ,   43  ,0 };
            const std::uint32_t dim43Kuo3Init[] =   {   1   ,   1   ,   1   ,   1   ,   13  ,   1   ,   109 ,   29  ,0 };
            const std::uint32_t dim44Kuo3Init[] =   {   1   ,   1   ,   5   ,   13  ,   31  ,   29  ,   95  ,   111 ,0 };
            const std::uint32_t dim45Kuo3Init[] =   {   1   ,   1   ,   1   ,   3   ,   9   ,   39  ,   109 ,   17  ,0 };
            const std::uint32_t dim46Kuo3Init[] =   {   1   ,   1   ,   1   ,   5   ,   17  ,   17  ,   47  ,   153 ,0 };
            const std::uint32_t dim47Kuo3Init[] =   {   1   ,   1   ,   1   ,   3   ,   31  ,   57  ,   43  ,   17  ,0 };
            const std::uint32_t dim48Kuo3Init[] =   {   1   ,   3   ,   7   ,   3   ,   29  ,   17  ,   91  ,   153 ,0 };
            const std::uint32_t dim49Kuo3Init[] =   {   1   ,   3   ,   3   ,   5   ,   21  ,   7   ,   73  ,   91  ,0 };
            const std::uint32_t dim50Kuo3Init[] =   {   1   ,   1   ,   7   ,   11  ,   13  ,   9   ,   83  ,   213 ,0 };
            const std::uint32_t dim51Kuo3Init[] =   {   1   ,   1   ,   7   ,   3   ,   17  ,   55  ,   37  ,   189 ,0 };
            const std::uint32_t dim52Kuo3Init[] =   {   1   ,   3   ,   7   ,   5   ,   7   ,   15  ,   39  ,   247 ,0 };
            const std::uint32_t dim53Kuo3Init[] =   {   1   ,   3   ,   1   ,   9   ,   27  ,   41  ,   83  ,   63  ,   89  ,0 };
            const std::uint32_t dim54Kuo3Init[] =   {   1   ,   3   ,   7   ,   11  ,   9   ,   51  ,   59  ,   89  ,   11  ,0 };
            const std::uint32_t dim55Kuo3Init[] =   {   1   ,   3   ,   5   ,   13  ,   29  ,   21  ,   55  ,   65  ,   45  ,0 };
            const std::uint32_t dim56Kuo3Init[] =   {   1   ,   3   ,   7   ,   5   ,   29  ,   33  ,   83  ,   229 ,   287 ,0 };
            const std::uint32_t dim57Kuo3Init[] =   {   1   ,   3   ,   5   ,   15  ,   13  ,   7   ,   89  ,   151 ,   391 ,0 };
            const std::uint32_t dim58Kuo3Init[] =   {   1   ,   3   ,   3   ,   9   ,   29  ,   3   ,   111 ,   177 ,   475 ,0 };
            const std::uint32_t dim59Kuo3Init[] =   {   1   ,   3   ,   1   ,   1   ,   5   ,   11  ,   23  ,   33  ,   337 ,0 };
            const std::uint32_t dim60Kuo3Init[] =   {   1   ,   1   ,   1   ,   15  ,   1   ,   23  ,   111 ,   175 ,   125 ,0 };
            const std::uint32_t dim61Kuo3Init[] =   {   1   ,   3   ,   7   ,   15  ,   27  ,   47  ,   31  ,   103 ,   245 ,0 };
            const std::uint32_t dim62Kuo3Init[] =   {   1   ,   3   ,   5   ,   7   ,   7   ,   3   ,   127 ,   187 ,   245 ,0 };
            const std::uint32_t dim63Kuo3Init[] =   {   1   ,   1   ,   1   ,   13  ,   13  ,   33  ,   33  ,   249 ,   381 ,0 };
            const std::uint32_t dim64Kuo3Init[] =   {   1   ,   1   ,   3   ,   11  ,   27  ,   45  ,   95  ,   31  ,   419 ,0 };
            const std::uint32_t dim65Kuo3Init[] =   {   1   ,   1   ,   1   ,   13  ,   17  ,   53  ,   35  ,   197 ,   455 ,0 };
            const std::uint32_t dim66Kuo3Init[] =   {   1   ,   1   ,   5   ,   7   ,   21  ,   43  ,   93  ,   237 ,   467 ,0 };
            const std::uint32_t dim67Kuo3Init[] =   {   1   ,   3   ,   5   ,   15  ,   1   ,   19  ,   43  ,   245 ,   193 ,0 };
            const std::uint32_t dim68Kuo3Init[] =   {   1   ,   1   ,   7   ,   11  ,   21  ,   21  ,   23  ,   147 ,   429 ,0 };
            const std::uint32_t dim69Kuo3Init[] =   {   1   ,   3   ,   3   ,   7   ,   27  ,   33  ,   99  ,   127 ,   97  ,0 };
            const std::uint32_t dim70Kuo3Init[] =   {   1   ,   1   ,   5   ,   11  ,   13  ,   21  ,   101 ,   73  ,   17  ,0 };
            const std::uint32_t dim71Kuo3Init[] =   {   1   ,   3   ,   1   ,   13  ,   3   ,   41  ,   7   ,   237 ,   311 ,0 };
            const std::uint32_t dim72Kuo3Init[] =   {   1   ,   3   ,   7   ,   1   ,   1   ,   43  ,   115 ,   215 ,   499 ,0 };
            const std::uint32_t dim73Kuo3Init[] =   {   1   ,   3   ,   1   ,   13  ,   1   ,   9   ,   113 ,   121 ,   473 ,0 };
            const std::uint32_t dim74Kuo3Init[] =   {   1   ,   1   ,   5   ,   5   ,   21  ,   7   ,   5   ,   171 ,   41  ,0 };
            const std::uint32_t dim75Kuo3Init[] =   {   1   ,   3   ,   7   ,   15  ,   31  ,   11  ,   87  ,   89  ,   495 ,0 };
            const std::uint32_t dim76Kuo3Init[] =   {   1   ,   1   ,   5   ,   1   ,   9   ,   9   ,   19  ,   161 ,   325 ,0 };
            const std::uint32_t dim77Kuo3Init[] =   {   1   ,   3   ,   3   ,   11  ,   15  ,   35  ,   75  ,   99  ,   331 ,0 };
            const std::uint32_t dim78Kuo3Init[] =   {   1   ,   3   ,   1   ,   1   ,   9   ,   27  ,   103 ,   93  ,   187 ,0 };
            const std::uint32_t dim79Kuo3Init[] =   {   1   ,   1   ,   3   ,   11  ,   19  ,   43  ,   123 ,   169 ,   325 ,0 };
            const std::uint32_t dim80Kuo3Init[] =   {   1   ,   1   ,   7   ,   9   ,   17  ,   59  ,   65  ,   139 ,   89  ,0 };
            const std::uint32_t dim81Kuo3Init[] =   {   1   ,   1   ,   5   ,   15  ,   19  ,   57  ,   29  ,   151 ,   131 ,0 };
            const std::uint32_t dim82Kuo3Init[] =   {   1   ,   1   ,   1   ,   1   ,   23  ,   49  ,   75  ,   85  ,   365 ,0 };
            const std::uint32_t dim83Kuo3Init[] =   {   1   ,   1   ,   5   ,   13  ,   11  ,   45  ,   31  ,   245 ,   311 ,0 };
            const std::uint32_t dim84Kuo3Init[] =   {   1   ,   3   ,   7   ,   5   ,   5   ,   13  ,   23  ,   1   ,   461 ,0 };
            const std::uint32_t dim85Kuo3Init[] =   {   1   ,   3   ,   1   ,   11  ,   17  ,   23  ,   19  ,   43  ,   393 ,0 };
            const std::uint32_t dim86Kuo3Init[] =   {   1   ,   1   ,   3   ,   5   ,   27  ,   9   ,   37  ,   105 ,   491 ,0 };
            const std::uint32_t dim87Kuo3Init[] =   {   1   ,   3   ,   3   ,   1   ,   15  ,   51  ,   107 ,   231 ,   39  ,0 };
            const std::uint32_t dim88Kuo3Init[] =   {   1   ,   1   ,   1   ,   5   ,   21  ,   57  ,   59  ,   143 ,   47  ,0 };
            const std::uint32_t dim89Kuo3Init[] =   {   1   ,   1   ,   7   ,   7   ,   23  ,   45  ,   29  ,   33  ,   403 ,0 };
            const std::uint32_t dim90Kuo3Init[] =   {   1   ,   3   ,   7   ,   5   ,   31  ,   7   ,   91  ,   5   ,   355 ,0 };
            const std::uint32_t dim91Kuo3Init[] =   {   1   ,   3   ,   5   ,   1   ,   25  ,   7   ,   15  ,   191 ,   45  ,0 };
            const std::uint32_t dim92Kuo3Init[] =   {   1   ,   1   ,   7   ,   5   ,   9   ,   33  ,   63  ,   75  ,   45  ,0 };
            const std::uint32_t dim93Kuo3Init[] =   {   1   ,   3   ,   5   ,   7   ,   27  ,   39  ,   83  ,   121 ,   495 ,0 };
            const std::uint32_t dim94Kuo3Init[] =   {   1   ,   1   ,   7   ,   5   ,   1   ,   25  ,   71  ,   31  ,   33  ,0 };
            const std::uint32_t dim95Kuo3Init[] =   {   1   ,   1   ,   7   ,   13  ,   13  ,   63  ,   85  ,   203 ,   491 ,0 };
            const std::uint32_t dim96Kuo3Init[] =   {   1   ,   3   ,   3   ,   11  ,   21  ,   39  ,   25  ,   213 ,   423 ,0 };
            const std::uint32_t dim97Kuo3Init[] =   {   1   ,   3   ,   5   ,   11  ,   3   ,   7   ,   115 ,   3   ,   191 ,0 };
            const std::uint32_t dim98Kuo3Init[] =   {   1   ,   1   ,   1   ,   9   ,   19  ,   1   ,   51  ,   247 ,   301 ,0 };
            const std::uint32_t dim99Kuo3Init[] =   {   1   ,   1   ,   1   ,   7   ,   13  ,   15  ,   45  ,   243 ,   453 ,0 };
            const std::uint32_t dim100Kuo3Init[]    =   {   1   ,   1   ,   1   ,   7   ,   25  ,   1   ,   113 ,   153 ,   105 ,0 };
            const std::uint32_t dim101Kuo3Init[]    =   {   1   ,   3   ,   5   ,   11  ,   19  ,   15  ,   3   ,   245 ,   443 ,   651 ,0 };
            const std::uint32_t dim102Kuo3Init[]    =   {   1   ,   3   ,   7   ,   15  ,   13  ,   35  ,   5   ,   167 ,   233 ,   9   ,0 };
            const std::uint32_t dim103Kuo3Init[]    =   {   1   ,   3   ,   5   ,   11  ,   21  ,   63  ,   95  ,   45  ,   411 ,   189 ,0 };
            const std::uint32_t dim104Kuo3Init[]    =   {   1   ,   1   ,   7   ,   7   ,   31  ,   11  ,   81  ,   87  ,   15  ,   677 ,0 };
            const std::uint32_t dim105Kuo3Init[]    =   {   1   ,   3   ,   3   ,   9   ,   13  ,   21  ,   27  ,   215 ,   459 ,   923 ,0 };
            const std::uint32_t dim106Kuo3Init[]    =   {   1   ,   1   ,   1   ,   9   ,   13  ,   49  ,   23  ,   7   ,   441 ,   31  ,0 };
            const std::uint32_t dim107Kuo3Init[]    =   {   1   ,   3   ,   1   ,   7   ,   27  ,   19  ,   5   ,   71  ,   391 ,   159 ,0 };
            const std::uint32_t dim108Kuo3Init[]    =   {   1   ,   3   ,   7   ,   9   ,   9   ,   55  ,   77  ,   95  ,   353 ,   519 ,0 };
            const std::uint32_t dim109Kuo3Init[]    =   {   1   ,   3   ,   1   ,   1   ,   23  ,   51  ,   51  ,   113 ,   33  ,   725 ,0 };
            const std::uint32_t dim110Kuo3Init[]    =   {   1   ,   3   ,   3   ,   1   ,   21  ,   3   ,   107 ,   223 ,   261 ,   913 ,0 };
            const std::uint32_t dim111Kuo3Init[]    =   {   1   ,   1   ,   1   ,   7   ,   9   ,   31  ,   83  ,   219 ,   285 ,   695 ,0 };
            const std::uint32_t dim112Kuo3Init[]    =   {   1   ,   1   ,   3   ,   15  ,   1   ,   1   ,   23  ,   49  ,   39  ,   485 ,0 };
            const std::uint32_t dim113Kuo3Init[]    =   {   1   ,   1   ,   1   ,   9   ,   5   ,   61  ,   71  ,   121 ,   427 ,   83  ,0 };
            const std::uint32_t dim114Kuo3Init[]    =   {   1   ,   1   ,   3   ,   3   ,   5   ,   45  ,   111 ,   227 ,   261 ,   957 ,0 };
            const std::uint32_t dim115Kuo3Init[]    =   {   1   ,   3   ,   7   ,   7   ,   17  ,   51  ,   61  ,   85  ,   183 ,   831 ,0 };
            const std::uint32_t dim116Kuo3Init[]    =   {   1   ,   3   ,   3   ,   5   ,   13  ,   35  ,   27  ,   135 ,   189 ,   743 ,0 };
            const std::uint32_t dim117Kuo3Init[]    =   {   1   ,   3   ,   1   ,   5   ,   7   ,   5   ,   7   ,   149 ,   333 ,   287 ,0 };
            const std::uint32_t dim118Kuo3Init[]    =   {   1   ,   3   ,   1   ,   13  ,   19  ,   57  ,   127 ,   201 ,   365 ,   359 ,0 };
            const std::uint32_t dim119Kuo3Init[]    =   {   1   ,   1   ,   5   ,   9   ,   27  ,   23  ,   79  ,   173 ,   227 ,   299 ,0 };
            const std::uint32_t dim120Kuo3Init[]    =   {   1   ,   1   ,   7   ,   7   ,   9   ,   35  ,   123 ,   1   ,   289 ,   43  ,0 };
            const std::uint32_t dim121Kuo3Init[]    =   {   1   ,   1   ,   5   ,   15  ,   15  ,   17  ,   57  ,   175 ,   97  ,   585 ,0 };
            const std::uint32_t dim122Kuo3Init[]    =   {   1   ,   1   ,   3   ,   13  ,   9   ,   23  ,   123 ,   45  ,   463 ,   137 ,0 };
            const std::uint32_t dim123Kuo3Init[]    =   {   1   ,   3   ,   1   ,   9   ,   19  ,   3   ,   81  ,   35  ,   221 ,   75  ,0 };
            const std::uint32_t dim124Kuo3Init[]    =   {   1   ,   3   ,   7   ,   13  ,   31  ,   41  ,   53  ,   207 ,   253 ,   957 ,0 };
            const std::uint32_t dim125Kuo3Init[]    =   {   1   ,   1   ,   1   ,   5   ,   1   ,   35  ,   51  ,   67  ,   289 ,   417 ,0 };
            const std::uint32_t dim126Kuo3Init[]    =   {   1   ,   1   ,   1   ,   11  ,   27  ,   21  ,   121 ,   235 ,   49  ,   3   ,0 };
            const std::uint32_t dim127Kuo3Init[]    =   {   1   ,   3   ,   7   ,   5   ,   15  ,   59  ,   25  ,   43  ,   141 ,   965 ,0 };
            const std::uint32_t dim128Kuo3Init[]    =   {   1   ,   1   ,   5   ,   3   ,   7   ,   23  ,   121 ,   161 ,   223 ,   245 ,0 };
            const std::uint32_t dim129Kuo3Init[]    =   {   1   ,   3   ,   7   ,   15  ,   5   ,   5   ,   49  ,   235 ,   329 ,   777 ,0 };
            const std::uint32_t dim130Kuo3Init[]    =   {   1   ,   3   ,   1   ,   11  ,   7   ,   49  ,   41  ,   187 ,   221 ,   639 ,0 };
            const std::uint32_t dim131Kuo3Init[]    =   {   1   ,   1   ,   5   ,   9   ,   1   ,   11  ,   41  ,   39  ,   319 ,   203 ,0 };
            const std::uint32_t dim132Kuo3Init[]    =   {   1   ,   3   ,   3   ,   3   ,   21  ,   61  ,   23  ,   233 ,   397 ,   251 ,0 };
            const std::uint32_t dim133Kuo3Init[]    =   {   1   ,   1   ,   1   ,   1   ,   27  ,   49  ,   87  ,   251 ,   371 ,   973 ,0 };
            const std::uint32_t dim134Kuo3Init[]    =   {   1   ,   1   ,   5   ,   11  ,   11  ,   43  ,   57  ,   59  ,   153 ,   695 ,0 };
            const std::uint32_t dim135Kuo3Init[]    =   {   1   ,   1   ,   3   ,   7   ,   29  ,   57  ,   87  ,   17  ,   129 ,   511 ,0 };
            const std::uint32_t dim136Kuo3Init[]    =   {   1   ,   3   ,   7   ,   7   ,   5   ,   39  ,   71  ,   27  ,   59  ,   49  ,0 };
            const std::uint32_t dim137Kuo3Init[]    =   {   1   ,   3   ,   3   ,   5   ,   1   ,   49  ,   65  ,   87  ,   453 ,   515 ,0 };
            const std::uint32_t dim138Kuo3Init[]    =   {   1   ,   3   ,   3   ,   9   ,   19  ,   3   ,   3   ,   167 ,   85  ,   653 ,0 };
            const std::uint32_t dim139Kuo3Init[]    =   {   1   ,   1   ,   7   ,   15  ,   7   ,   51  ,   67  ,   37  ,   245 ,   943 ,0 };
            const std::uint32_t dim140Kuo3Init[]    =   {   1   ,   1   ,   5   ,   7   ,   1   ,   7   ,   21  ,   5   ,   135 ,   999 ,0 };
            const std::uint32_t dim141Kuo3Init[]    =   {   1   ,   3   ,   3   ,   5   ,   19  ,   1   ,   7   ,   179 ,   405 ,   589 ,0 };
            const std::uint32_t dim142Kuo3Init[]    =   {   1   ,   1   ,   3   ,   15  ,   3   ,   3   ,   43  ,   79  ,   501 ,   287 ,0 };
            const std::uint32_t dim143Kuo3Init[]    =   {   1   ,   1   ,   3   ,   9   ,   21  ,   39  ,   59  ,   181 ,   99  ,   737 ,0 };
            const std::uint32_t dim144Kuo3Init[]    =   {   1   ,   3   ,   7   ,   1   ,   3   ,   11  ,   91  ,   33  ,   273 ,   651 ,0 };
            const std::uint32_t dim145Kuo3Init[]    =   {   1   ,   1   ,   5   ,   11  ,   23  ,   47  ,   97  ,   253 ,   465 ,   741 ,0 };
            const std::uint32_t dim146Kuo3Init[]    =   {   1   ,   1   ,   5   ,   1   ,   7   ,   45  ,   33  ,   203 ,   297 ,   193 ,0 };
            const std::uint32_t dim147Kuo3Init[]    =   {   1   ,   1   ,   5   ,   3   ,   31  ,   55  ,   63  ,   41  ,   243 ,   953 ,0 };
            const std::uint32_t dim148Kuo3Init[]    =   {   1   ,   3   ,   5   ,   9   ,   9   ,   53  ,   51  ,   71  ,   281 ,   447 ,0 };
            const std::uint32_t dim149Kuo3Init[]    =   {   1   ,   3   ,   3   ,   9   ,   5   ,   63  ,   77  ,   89  ,   213 ,   527 ,0 };
            const std::uint32_t dim150Kuo3Init[]    =   {   1   ,   1   ,   3   ,   11  ,   31  ,   15  ,   3   ,   91  ,   321 ,   997 ,0 };
            const std::uint32_t dim151Kuo3Init[]    =   {   1   ,   3   ,   5   ,   7   ,   31  ,   27  ,   117 ,   179 ,   389 ,   645 ,0 };
            const std::uint32_t dim152Kuo3Init[]    =   {   1   ,   3   ,   3   ,   9   ,   21  ,   37  ,   41  ,   49  ,   143 ,   401 ,0 };
            const std::uint32_t dim153Kuo3Init[]    =   {   1   ,   3   ,   1   ,   3   ,   31  ,   57  ,   77  ,   129 ,   49  ,   245 ,0 };
            const std::uint32_t dim154Kuo3Init[]    =   {   1   ,   3   ,   1   ,   15  ,   27  ,   7   ,   23  ,   69  ,   177 ,   1009    ,0 };
            const std::uint32_t dim155Kuo3Init[]    =   {   1   ,   3   ,   3   ,   3   ,   11  ,   9   ,   101 ,   141 ,   313 ,   739 ,0 };
            const std::uint32_t dim156Kuo3Init[]    =   {   1   ,   1   ,   3   ,   13  ,   27  ,   31  ,   27  ,   129 ,   139 ,   645 ,0 };
            const std::uint32_t dim157Kuo3Init[]    =   {   1   ,   3   ,   7   ,   5   ,   7   ,   11  ,   99  ,   145 ,   313 ,   641 ,0 };
            const std::uint32_t dim158Kuo3Init[]    =   {   1   ,   3   ,   1   ,   13  ,   15  ,   3   ,   55  ,   183 ,   153 ,   743 ,0 };
            const std::uint32_t dim159Kuo3Init[]    =   {   1   ,   3   ,   5   ,   1   ,   23  ,   63  ,   53  ,   237 ,   267 ,   333 ,0 };
            const std::uint32_t dim160Kuo3Init[]    =   {   1   ,   3   ,   1   ,   9   ,   5   ,   27  ,   45  ,   49  ,   9   ,   911 ,0 };
            const std::uint32_t dim161Kuo3Init[]    =   {   1   ,   1   ,   3   ,   9   ,   11  ,   51  ,   97  ,   231 ,   295 ,   877 ,   353 ,0 };
            const std::uint32_t dim162Kuo3Init[]    =   {   1   ,   3   ,   7   ,   3   ,   15  ,   55  ,   125 ,   241 ,   149 ,   417 ,   449 ,0 };
            const std::uint32_t dim163Kuo3Init[]    =   {   1   ,   1   ,   7   ,   1   ,   7   ,   31  ,   89  ,   91  ,   259 ,   819 ,   849 ,0 };
            const std::uint32_t dim164Kuo3Init[]    =   {   1   ,   3   ,   1   ,   11  ,   3   ,   9   ,   79  ,   77  ,   195 ,   39  ,   937 ,0 };
            const std::uint32_t dim165Kuo3Init[]    =   {   1   ,   1   ,   3   ,   15  ,   27  ,   37  ,   123 ,   233 ,   221 ,   661 ,   323 ,0 };
            const std::uint32_t dim166Kuo3Init[]    =   {   1   ,   3   ,   7   ,   7   ,   31  ,   59  ,   121 ,   71  ,   19  ,   723 ,   1713    ,0 };
            const std::uint32_t dim167Kuo3Init[]    =   {   1   ,   1   ,   5   ,   5   ,   23  ,   43  ,   75  ,   201 ,   7   ,   565 ,   293 ,0 };
            const std::uint32_t dim168Kuo3Init[]    =   {   1   ,   1   ,   1   ,   3   ,   13  ,   39  ,   115 ,   209 ,   239 ,   439 ,   1623    ,0 };
            const std::uint32_t dim169Kuo3Init[]    =   {   1   ,   3   ,   7   ,   5   ,   29  ,   39  ,   69  ,   241 ,   71  ,   465 ,   77  ,0 };
            const std::uint32_t dim170Kuo3Init[]    =   {   1   ,   1   ,   1   ,   13  ,   17  ,   1   ,   91  ,   67  ,   491 ,   969 ,   1709    ,0 };
            const std::uint32_t dim171Kuo3Init[]    =   {   1   ,   3   ,   1   ,   3   ,   7   ,   37  ,   17  ,   185 ,   365 ,   571 ,   757 ,0 };
            const std::uint32_t dim172Kuo3Init[]    =   {   1   ,   1   ,   5   ,   1   ,   29  ,   47  ,   87  ,   65  ,   171 ,   893 ,   1659    ,0 };
            const std::uint32_t dim173Kuo3Init[]    =   {   1   ,   3   ,   5   ,   5   ,   13  ,   5   ,   21  ,   151 ,   91  ,   801 ,   1415    ,0 };
            const std::uint32_t dim174Kuo3Init[]    =   {   1   ,   3   ,   3   ,   13  ,   27  ,   35  ,   81  ,   49  ,   417 ,   315 ,   1039    ,0 };
            const std::uint32_t dim175Kuo3Init[]    =   {   1   ,   3   ,   3   ,   7   ,   13  ,   11  ,   63  ,   19  ,   35  ,   659 ,   83  ,0 };
            const std::uint32_t dim176Kuo3Init[]    =   {   1   ,   1   ,   1   ,   15  ,   11  ,   55  ,   43  ,   181 ,   45  ,   657 ,   681 ,0 };
            const std::uint32_t dim177Kuo3Init[]    =   {   1   ,   3   ,   7   ,   1   ,   23  ,   9   ,   73  ,   55  ,   143 ,   731 ,   401 ,0 };
            const std::uint32_t dim178Kuo3Init[]    =   {   1   ,   1   ,   3   ,   1   ,   5   ,   49  ,   125 ,   1   ,   113 ,   41  ,   1733    ,0 };
            const std::uint32_t dim179Kuo3Init[]    =   {   1   ,   1   ,   3   ,   5   ,   21  ,   63  ,   45  ,   119 ,   67  ,   499 ,   141 ,0 };
            const std::uint32_t dim180Kuo3Init[]    =   {   1   ,   3   ,   5   ,   11  ,   29  ,   39  ,   45  ,   93  ,   415 ,   515 ,   413 ,0 };
            const std::uint32_t dim181Kuo3Init[]    =   {   1   ,   1   ,   7   ,   15  ,   5   ,   3   ,   79  ,   201 ,   5   ,   473 ,   55  ,0 };
            const std::uint32_t dim182Kuo3Init[]    =   {   1   ,   1   ,   3   ,   7   ,   25  ,   31  ,   55  ,   61  ,   175 ,   919 ,   2047    ,0 };
            const std::uint32_t dim183Kuo3Init[]    =   {   1   ,   1   ,   7   ,   3   ,   31  ,   61  ,   15  ,   147 ,   409 ,   249 ,   1677    ,0 };
            const std::uint32_t dim184Kuo3Init[]    =   {   1   ,   3   ,   3   ,   9   ,   11  ,   37  ,   9   ,   65  ,   383 ,   689 ,   111 ,0 };
            const std::uint32_t dim185Kuo3Init[]    =   {   1   ,   1   ,   5   ,   1   ,   31  ,   23  ,   93  ,   15  ,   327 ,   973 ,   765 ,0 };
            const std::uint32_t dim186Kuo3Init[]    =   {   1   ,   3   ,   7   ,   15  ,   25  ,   17  ,   115 ,   245 ,   205 ,   169 ,   13  ,0 };
            const std::uint32_t dim187Kuo3Init[]    =   {   1   ,   1   ,   5   ,   15  ,   15  ,   27  ,   109 ,   39  ,   289 ,   135 ,   693 ,0 };
            const std::uint32_t dim188Kuo3Init[]    =   {   1   ,   1   ,   7   ,   3   ,   23  ,   1   ,   119 ,   199 ,   1   ,   661 ,   1741    ,0 };
            const std::uint32_t dim189Kuo3Init[]    =   {   1   ,   3   ,   5   ,   13  ,   7   ,   29  ,   3   ,   55  ,   369 ,   903 ,   715 ,0 };
            const std::uint32_t dim190Kuo3Init[]    =   {   1   ,   1   ,   5   ,   1   ,   29  ,   19  ,   31  ,   7   ,   165 ,   1019    ,   467 ,0 };
            const std::uint32_t dim191Kuo3Init[]    =   {   1   ,   1   ,   7   ,   11  ,   27  ,   33  ,   105 ,   27  ,   271 ,   55  ,   475 ,0 };
            const std::uint32_t dim192Kuo3Init[]    =   {   1   ,   1   ,   5   ,   1   ,   27  ,   9   ,   63  ,   157 ,   507 ,   491 ,   1525    ,0 };
            const std::uint32_t dim193Kuo3Init[]    =   {   1   ,   3   ,   3   ,   9   ,   1   ,   41  ,   71  ,   239 ,   471 ,   147 ,   505 ,0 };
            const std::uint32_t dim194Kuo3Init[]    =   {   1   ,   3   ,   3   ,   1   ,   25  ,   11  ,   1   ,   35  ,   127 ,   583 ,   2043    ,0 };
            const std::uint32_t dim195Kuo3Init[]    =   {   1   ,   3   ,   7   ,   15  ,   1   ,   13  ,   119 ,   183 ,   89  ,   555 ,   1739    ,0 };
            const std::uint32_t dim196Kuo3Init[]    =   {   1   ,   1   ,   1   ,   3   ,   3   ,   45  ,   61  ,   163 ,   357 ,   679 ,   641 ,0 };
            const std::uint32_t dim197Kuo3Init[]    =   {   1   ,   3   ,   5   ,   13  ,   23  ,   27  ,   57  ,   125 ,   393 ,   917 ,   939 ,0 };
            const std::uint32_t dim198Kuo3Init[]    =   {   1   ,   1   ,   3   ,   9   ,   9   ,   21  ,   85  ,   105 ,   111 ,   537 ,   733 ,0 };
            const std::uint32_t dim199Kuo3Init[]    =   {   1   ,   1   ,   3   ,   15  ,   9   ,   61  ,   43  ,   103 ,   65  ,   227 ,   315 ,0 };
            const std::uint32_t dim200Kuo3Init[]    =   {   1   ,   1   ,   7   ,   9   ,   9   ,   7   ,   31  ,   219 ,   293 ,   441 ,   559 ,0 };
            const std::uint32_t dim201Kuo3Init[]    =   {   1   ,   1   ,   3   ,   1   ,   23  ,   21  ,   25  ,   229 ,   303 ,   537 ,   1655    ,0 };
            const std::uint32_t dim202Kuo3Init[]    =   {   1   ,   3   ,   7   ,   7   ,   31  ,   5   ,   21  ,   177 ,   435 ,   899 ,   1939    ,0 };
            const std::uint32_t dim203Kuo3Init[]    =   {   1   ,   3   ,   3   ,   3   ,   11  ,   43  ,   77  ,   131 ,   353 ,   11  ,   157 ,0 };
            const std::uint32_t dim204Kuo3Init[]    =   {   1   ,   3   ,   3   ,   3   ,   5   ,   45  ,   13  ,   39  ,   459 ,   261 ,   237 ,0 };
            const std::uint32_t dim205Kuo3Init[]    =   {   1   ,   3   ,   5   ,   7   ,   23  ,   1   ,   55  ,   63  ,   9   ,   755 ,   589 ,0 };
            const std::uint32_t dim206Kuo3Init[]    =   {   1   ,   1   ,   7   ,   5   ,   3   ,   11  ,   59  ,   167 ,   145 ,   459 ,   617 ,0 };
            const std::uint32_t dim207Kuo3Init[]    =   {   1   ,   3   ,   1   ,   13  ,   31  ,   49  ,   53  ,   235 ,   1   ,   37  ,   1373    ,0 };
            const std::uint32_t dim208Kuo3Init[]    =   {   1   ,   1   ,   7   ,   11  ,   27  ,   63  ,   21  ,   59  ,   183 ,   297 ,   15  ,0 };
            const std::uint32_t dim209Kuo3Init[]    =   {   1   ,   3   ,   7   ,   15  ,   3   ,   61  ,   57  ,   205 ,   359 ,   799 ,   1591    ,0 };
            const std::uint32_t dim210Kuo3Init[]    =   {   1   ,   1   ,   1   ,   3   ,   29  ,   29  ,   121 ,   193 ,   405 ,   161 ,   909 ,0 };
            const std::uint32_t dim211Kuo3Init[]    =   {   1   ,   1   ,   5   ,   5   ,   15  ,   43  ,   19  ,   87  ,   337 ,   595 ,   551 ,0 };
            const std::uint32_t dim212Kuo3Init[]    =   {   1   ,   3   ,   3   ,   7   ,   27  ,   23  ,   109 ,   127 ,   107 ,   793 ,   787 ,0 };
            const std::uint32_t dim213Kuo3Init[]    =   {   1   ,   1   ,   3   ,   5   ,   9   ,   11  ,   63  ,   21  ,   363 ,   403 ,   981 ,0 };
            const std::uint32_t dim214Kuo3Init[]    =   {   1   ,   1   ,   3   ,   5   ,   1   ,   39  ,   43  ,   71  ,   5   ,   151 ,   1535    ,0 };
            const std::uint32_t dim215Kuo3Init[]    =   {   1   ,   1   ,   7   ,   3   ,   1   ,   33  ,   65  ,   249 ,   81  ,   889 ,   1591    ,0 };
            const std::uint32_t dim216Kuo3Init[]    =   {   1   ,   3   ,   5   ,   11  ,   15  ,   53  ,   117 ,   47  ,   13  ,   215 ,   1953    ,0 };
            const std::uint32_t dim217Kuo3Init[]    =   {   1   ,   1   ,   3   ,   13  ,   15  ,   13  ,   49  ,   209 ,   137 ,   403 ,   1373    ,0 };
            const std::uint32_t dim218Kuo3Init[]    =   {   1   ,   1   ,   3   ,   15  ,   25  ,   13  ,   123 ,   193 ,   275 ,   235 ,   1975    ,0 };
            const std::uint32_t dim219Kuo3Init[]    =   {   1   ,   3   ,   1   ,   3   ,   21  ,   55  ,   109 ,   115 ,   411 ,   413 ,   2023    ,0 };
            const std::uint32_t dim220Kuo3Init[]    =   {   1   ,   3   ,   3   ,   1   ,   5   ,   7   ,   53  ,   161 ,   221 ,   529 ,   489 ,0 };
            const std::uint32_t dim221Kuo3Init[]    =   {   1   ,   1   ,   3   ,   5   ,   25  ,   27  ,   103 ,   31  ,   7   ,   103 ,   343 ,0 };
            const std::uint32_t dim222Kuo3Init[]    =   {   1   ,   1   ,   7   ,   11  ,   19  ,   47  ,   45  ,   201 ,   499 ,   255 ,   1501    ,0 };
            const std::uint32_t dim223Kuo3Init[]    =   {   1   ,   3   ,   1   ,   1   ,   5   ,   7   ,   79  ,   113 ,   445 ,   515 ,   287 ,0 };
            const std::uint32_t dim224Kuo3Init[]    =   {   1   ,   1   ,   7   ,   11  ,   7   ,   35  ,   87  ,   145 ,   115 ,   773 ,   1415    ,0 };
            const std::uint32_t dim225Kuo3Init[]    =   {   1   ,   1   ,   1   ,   13  ,   15  ,   25  ,   83  ,   143 ,   347 ,   473 ,   415 ,0 };
            const std::uint32_t dim226Kuo3Init[]    =   {   1   ,   3   ,   1   ,   11  ,   23  ,   45  ,   79  ,   245 ,   81  ,   835 ,   589 ,0 };
            const std::uint32_t dim227Kuo3Init[]    =   {   1   ,   1   ,   1   ,   13  ,   25  ,   49  ,   17  ,   15  ,   255 ,   421 ,   1195    ,0 };
            const std::uint32_t dim228Kuo3Init[]    =   {   1   ,   1   ,   3   ,   1   ,   13  ,   31  ,   103 ,   189 ,   43  ,   389 ,   1497    ,0 };
            const std::uint32_t dim229Kuo3Init[]    =   {   1   ,   3   ,   5   ,   7   ,   3   ,   63  ,   21  ,   151 ,   339 ,   525 ,   455 ,0 };
            const std::uint32_t dim230Kuo3Init[]    =   {   1   ,   3   ,   3   ,   13  ,   23  ,   29  ,   101 ,   25  ,   461 ,   631 ,   2017    ,0 };
            const std::uint32_t dim231Kuo3Init[]    =   {   1   ,   1   ,   5   ,   13  ,   7   ,   57  ,   11  ,   181 ,   215 ,   911 ,   463 ,0 };
            const std::uint32_t dim232Kuo3Init[]    =   {   1   ,   3   ,   7   ,   1   ,   1   ,   45  ,   41  ,   101 ,   263 ,   835 ,   1985    ,0 };
            const std::uint32_t dim233Kuo3Init[]    =   {   1   ,   3   ,   3   ,   3   ,   25  ,   13  ,   127 ,   245 ,   137 ,   709 ,   993 ,0 };
            const std::uint32_t dim234Kuo3Init[]    =   {   1   ,   3   ,   7   ,   3   ,   5   ,   19  ,   23  ,   55  ,   51  ,   367 ,   1513    ,0 };
            const std::uint32_t dim235Kuo3Init[]    =   {   1   ,   1   ,   5   ,   3   ,   13  ,   39  ,   101 ,   119 ,   119 ,   835 ,   875 ,0 };
            const std::uint32_t dim236Kuo3Init[]    =   {   1   ,   1   ,   7   ,   13  ,   17  ,   27  ,   103 ,   31  ,   223 ,   461 ,   1267    ,0 };
            const std::uint32_t dim237Kuo3Init[]    =   {   1   ,   3   ,   5   ,   13  ,   29  ,   29  ,   29  ,   189 ,   13  ,   647 ,   1931    ,0 };
            const std::uint32_t dim238Kuo3Init[]    =   {   1   ,   3   ,   5   ,   15  ,   9   ,   27  ,   127 ,   43  ,   341 ,   939 ,   1981    ,0 };
            const std::uint32_t dim239Kuo3Init[]    =   {   1   ,   1   ,   7   ,   11  ,   27  ,   27  ,   25  ,   163 ,   83  ,   709 ,   141 ,0 };
            const std::uint32_t dim240Kuo3Init[]    =   {   1   ,   3   ,   7   ,   15  ,   31  ,   45  ,   119 ,   141 ,   181 ,   231 ,   411 ,0 };
            const std::uint32_t dim241Kuo3Init[]    =   {   1   ,   1   ,   5   ,   9   ,   31  ,   25  ,   113 ,   243 ,   435 ,   55  ,   765 ,0 };
            const std::uint32_t dim242Kuo3Init[]    =   {   1   ,   1   ,   7   ,   9   ,   27  ,   5   ,   63  ,   23  ,   133 ,   767 ,   1963    ,0 };
            const std::uint32_t dim243Kuo3Init[]    =   {   1   ,   3   ,   7   ,   9   ,   9   ,   55  ,   97  ,   159 ,   371 ,   1013    ,   2013    ,0 };
            const std::uint32_t dim244Kuo3Init[]    =   {   1   ,   1   ,   3   ,   7   ,   3   ,   17  ,   13  ,   215 ,   15  ,   281 ,   291 ,0 };
            const std::uint32_t dim245Kuo3Init[]    =   {   1   ,   3   ,   5   ,   9   ,   29  ,   7   ,   71  ,   9   ,   181 ,   763 ,   1111    ,0 };
            const std::uint32_t dim246Kuo3Init[]    =   {   1   ,   3   ,   7   ,   13  ,   23  ,   55  ,   79  ,   99  ,   165 ,   447 ,   1947    ,0 };
            const std::uint32_t dim247Kuo3Init[]    =   {   1   ,   3   ,   7   ,   7   ,   29  ,   59  ,   25  ,   41  ,   313 ,   665 ,   1245    ,0 };
            const std::uint32_t dim248Kuo3Init[]    =   {   1   ,   1   ,   3   ,   3   ,   5   ,   29  ,   71  ,   71  ,   475 ,   781 ,   567 ,0 };
            const std::uint32_t dim249Kuo3Init[]    =   {   1   ,   1   ,   1   ,   3   ,   19  ,   53  ,   61  ,   215 ,   475 ,   885 ,   459 ,0 };
            const std::uint32_t dim250Kuo3Init[]    =   {   1   ,   3   ,   3   ,   13  ,   5   ,   31  ,   95  ,   137 ,   119 ,   249 ,   975 ,0 };
            const std::uint32_t dim251Kuo3Init[]    =   {   1   ,   1   ,   1   ,   15  ,   21  ,   51  ,   71  ,   21  ,   193 ,   709 ,   1167    ,0 };
            const std::uint32_t dim252Kuo3Init[]    =   {   1   ,   3   ,   7   ,   9   ,   29  ,   61  ,   45  ,   153 ,   351 ,   867 ,   995 ,0 };
            const std::uint32_t dim253Kuo3Init[]    =   {   1   ,   1   ,   1   ,   15  ,   7   ,   37  ,   65  ,   51  ,   45  ,   497 ,   1825    ,0 };
            const std::uint32_t dim254Kuo3Init[]    =   {   1   ,   3   ,   3   ,   1   ,   23  ,   59  ,   11  ,   127 ,   501 ,   351 ,   1525    ,0 };
            const std::uint32_t dim255Kuo3Init[]    =   {   1   ,   1   ,   3   ,   15  ,   31  ,   29  ,   47  ,   105 ,   179 ,   159 ,   991 ,0 };
            const std::uint32_t dim256Kuo3Init[]    =   {   1   ,   3   ,   3   ,   15  ,   27  ,   23  ,   93  ,   163 ,   169 ,   1003    ,   1369    ,0 };
            const std::uint32_t dim257Kuo3Init[]    =   {   1   ,   3   ,   1   ,   5   ,   31  ,   51  ,   85  ,   221 ,   87  ,   941 ,   317 ,0 };
            const std::uint32_t dim258Kuo3Init[]    =   {   1   ,   3   ,   7   ,   15  ,   21  ,   19  ,   71  ,   205 ,   385 ,   371 ,   1401    ,0 };
            const std::uint32_t dim259Kuo3Init[]    =   {   1   ,   1   ,   5   ,   11  ,   1   ,   51  ,   31  ,   185 ,   407 ,   233 ,   1171    ,0 };
            const std::uint32_t dim260Kuo3Init[]    =   {   1   ,   3   ,   3   ,   9   ,   19  ,   11  ,   93  ,   253 ,   373 ,   679 ,   69  ,0 };
            const std::uint32_t dim261Kuo3Init[]    =   {   1   ,   1   ,   7   ,   15  ,   23  ,   45  ,   87  ,   61  ,   113 ,   541 ,   1701    ,0 };
            const std::uint32_t dim262Kuo3Init[]    =   {   1   ,   1   ,   5   ,   7   ,   7   ,   61  ,   55  ,   167 ,   345 ,   633 ,   1699    ,0 };
            const std::uint32_t dim263Kuo3Init[]    =   {   1   ,   3   ,   7   ,   7   ,   1   ,   23  ,   121 ,   33  ,   507 ,   361 ,   1945    ,0 };
            const std::uint32_t dim264Kuo3Init[]    =   {   1   ,   3   ,   7   ,   1   ,   19  ,   47  ,   43  ,   101 ,   67  ,   57  ,   1685    ,0 };
            const std::uint32_t dim265Kuo3Init[]    =   {   1   ,   3   ,   3   ,   3   ,   25  ,   63  ,   53  ,   149 ,   483 ,   551 ,   1519    ,0 };
            const std::uint32_t dim266Kuo3Init[]    =   {   1   ,   3   ,   1   ,   3   ,   27  ,   1   ,   41  ,   213 ,   57  ,   897 ,   121 ,0 };
            const std::uint32_t dim267Kuo3Init[]    =   {   1   ,   3   ,   1   ,   5   ,   19  ,   13  ,   49  ,   81  ,   239 ,   455 ,   957 ,0 };
            const std::uint32_t dim268Kuo3Init[]    =   {   1   ,   1   ,   3   ,   7   ,   15  ,   23  ,   89  ,   171 ,   319 ,   117 ,   2041    ,0 };
            const std::uint32_t dim269Kuo3Init[]    =   {   1   ,   1   ,   3   ,   13  ,   3   ,   13  ,   41  ,   15  ,   145 ,   659 ,   973 ,0 };
            const std::uint32_t dim270Kuo3Init[]    =   {   1   ,   3   ,   7   ,   1   ,   15  ,   17  ,   69  ,   53  ,   245 ,   179 ,   159 ,0 };
            const std::uint32_t dim271Kuo3Init[]    =   {   1   ,   3   ,   3   ,   5   ,   5   ,   3   ,   113 ,   183 ,   219 ,   469 ,   1169    ,0 };
            const std::uint32_t dim272Kuo3Init[]    =   {   1   ,   1   ,   5   ,   15  ,   13  ,   45  ,   89  ,   87  ,   371 ,   267 ,   1643    ,0 };
            const std::uint32_t dim273Kuo3Init[]    =   {   1   ,   3   ,   5   ,   5   ,   1   ,   25  ,   3   ,   247 ,   309 ,   401 ,   2027    ,0 };
            const std::uint32_t dim274Kuo3Init[]    =   {   1   ,   3   ,   1   ,   11  ,   13  ,   7   ,   79  ,   17  ,   297 ,   679 ,   1699    ,0 };
            const std::uint32_t dim275Kuo3Init[]    =   {   1   ,   3   ,   1   ,   5   ,   13  ,   19  ,   123 ,   255 ,   343 ,   393 ,   1635    ,0 };
            const std::uint32_t dim276Kuo3Init[]    =   {   1   ,   3   ,   3   ,   15  ,   13  ,   13  ,   37  ,   229 ,   483 ,   283 ,   1423    ,0 };
            const std::uint32_t dim277Kuo3Init[]    =   {   1   ,   3   ,   1   ,   1   ,   7   ,   37  ,   65  ,   67  ,   77  ,   247 ,   1539    ,0 };
            const std::uint32_t dim278Kuo3Init[]    =   {   1   ,   1   ,   3   ,   5   ,   25  ,   39  ,   37  ,   19  ,   231 ,   835 ,   797 ,0 };
            const std::uint32_t dim279Kuo3Init[]    =   {   1   ,   1   ,   1   ,   11  ,   27  ,   53  ,   1   ,   217 ,   211 ,   7   ,   801 ,0 };
            const std::uint32_t dim280Kuo3Init[]    =   {   1   ,   3   ,   7   ,   1   ,   15  ,   55  ,   69  ,   77  ,   491 ,   61  ,   55  ,0 };
            const std::uint32_t dim281Kuo3Init[]    =   {   1   ,   1   ,   1   ,   1   ,   29  ,   21  ,   47  ,   167 ,   281 ,   105 ,   1363    ,0 };
            const std::uint32_t dim282Kuo3Init[]    =   {   1   ,   3   ,   1   ,   15  ,   15  ,   55  ,   57  ,   207 ,   479 ,   709 ,   867 ,0 };
            const std::uint32_t dim283Kuo3Init[]    =   {   1   ,   1   ,   1   ,   9   ,   7   ,   13  ,   115 ,   237 ,   47  ,   127 ,   1849    ,0 };
            const std::uint32_t dim284Kuo3Init[]    =   {   1   ,   1   ,   7   ,   9   ,   7   ,   35  ,   83  ,   63  ,   155 ,   441 ,   1105    ,0 };
            const std::uint32_t dim285Kuo3Init[]    =   {   1   ,   3   ,   3   ,   9   ,   17  ,   39  ,   19  ,   231 ,   491 ,   593 ,   1997    ,0 };
            const std::uint32_t dim286Kuo3Init[]    =   {   1   ,   3   ,   3   ,   13  ,   17  ,   19  ,   65  ,   21  ,   389 ,   391 ,   483 ,0 };
            const std::uint32_t dim287Kuo3Init[]    =   {   1   ,   1   ,   5   ,   7   ,   17  ,   7   ,   97  ,   173 ,   413 ,   917 ,   1691    ,0 };
            const std::uint32_t dim288Kuo3Init[]    =   {   1   ,   1   ,   3   ,   3   ,   29  ,   49  ,   3   ,   127 ,   337 ,   713 ,   1057    ,0 };
            const std::uint32_t dim289Kuo3Init[]    =   {   1   ,   3   ,   7   ,   5   ,   31  ,   23  ,   31  ,   119 ,   161 ,   51  ,   537 ,0 };
            const std::uint32_t dim290Kuo3Init[]    =   {   1   ,   1   ,   5   ,   1   ,   29  ,   25  ,   15  ,   187 ,   143 ,   927 ,   715 ,0 };
            const std::uint32_t dim291Kuo3Init[]    =   {   1   ,   1   ,   7   ,   11  ,   15  ,   47  ,   55  ,   103 ,   109 ,   465 ,   1439    ,0 };
            const std::uint32_t dim292Kuo3Init[]    =   {   1   ,   1   ,   3   ,   13  ,   31  ,   47  ,   115 ,   177 ,   355 ,   163 ,   833 ,0 };
            const std::uint32_t dim293Kuo3Init[]    =   {   1   ,   3   ,   5   ,   5   ,   31  ,   13  ,   15  ,   163 ,   57  ,   937 ,   1553    ,0 };
            const std::uint32_t dim294Kuo3Init[]    =   {   1   ,   3   ,   5   ,   15  ,   7   ,   29  ,   47  ,   139 ,   231 ,   507 ,   595 ,0 };
            const std::uint32_t dim295Kuo3Init[]    =   {   1   ,   3   ,   1   ,   15  ,   31  ,   13  ,   49  ,   253 ,   29  ,   109 ,   727 ,0 };
            const std::uint32_t dim296Kuo3Init[]    =   {   1   ,   1   ,   5   ,   15  ,   21  ,   1   ,   107 ,   89  ,   367 ,   825 ,   1297    ,0 };
            const std::uint32_t dim297Kuo3Init[]    =   {   1   ,   3   ,   3   ,   9   ,   31  ,   21  ,   31  ,   247 ,   375 ,   767 ,   1761    ,0 };
            const std::uint32_t dim298Kuo3Init[]    =   {   1   ,   1   ,   7   ,   3   ,   31  ,   33  ,   119 ,   119 ,   409 ,   955 ,   1411    ,0 };
            const std::uint32_t dim299Kuo3Init[]    =   {   1   ,   1   ,   7   ,   1   ,   17  ,   57  ,   101 ,   37  ,   147 ,   367 ,   265 ,0 };
            const std::uint32_t dim300Kuo3Init[]    =   {   1   ,   3   ,   3   ,   3   ,   25  ,   53  ,   91  ,   43  ,   351 ,   1021    ,   1243    ,0 };
            const std::uint32_t dim301Kuo3Init[]    =   {   1   ,   3   ,   3   ,   5   ,   11  ,   47  ,   107 ,   209 ,   251 ,   765 ,   1089    ,0 };
            const std::uint32_t dim302Kuo3Init[]    =   {   1   ,   1   ,   7   ,   5   ,   9   ,   13  ,   23  ,   153 ,   367 ,   585 ,   315 ,0 };
            const std::uint32_t dim303Kuo3Init[]    =   {   1   ,   3   ,   3   ,   15  ,   23  ,   57  ,   83  ,   173 ,   413 ,   555 ,   159 ,0 };
            const std::uint32_t dim304Kuo3Init[]    =   {   1   ,   3   ,   7   ,   15  ,   7   ,   59  ,   31  ,   233 ,   67  ,   767 ,   75  ,0 };
            const std::uint32_t dim305Kuo3Init[]    =   {   1   ,   3   ,   5   ,   3   ,   17  ,   1   ,   35  ,   37  ,   445 ,   847 ,   1853    ,0 };
            const std::uint32_t dim306Kuo3Init[]    =   {   1   ,   3   ,   5   ,   13  ,   3   ,   1   ,   75  ,   113 ,   83  ,   467 ,   1057    ,0 };
            const std::uint32_t dim307Kuo3Init[]    =   {   1   ,   1   ,   7   ,   1   ,   7   ,   15  ,   125 ,   31  ,   341 ,   133 ,   285 ,0 };
            const std::uint32_t dim308Kuo3Init[]    =   {   1   ,   1   ,   5   ,   5   ,   15  ,   11  ,   97  ,   3   ,   59  ,   777 ,   1125    ,0 };
            const std::uint32_t dim309Kuo3Init[]    =   {   1   ,   3   ,   7   ,   9   ,   17  ,   55  ,   117 ,   255 ,   429 ,   239 ,   1071    ,0 };
            const std::uint32_t dim310Kuo3Init[]    =   {   1   ,   1   ,   7   ,   3   ,   27  ,   37  ,   31  ,   221 ,   385 ,   877 ,   1767    ,0 };
            const std::uint32_t dim311Kuo3Init[]    =   {   1   ,   1   ,   5   ,   1   ,   5   ,   31  ,   43  ,   23  ,   77  ,   497 ,   1605    ,0 };
            const std::uint32_t dim312Kuo3Init[]    =   {   1   ,   3   ,   5   ,   15  ,   15  ,   37  ,   103 ,   227 ,   33  ,   185 ,   481 ,0 };
            const std::uint32_t dim313Kuo3Init[]    =   {   1   ,   3   ,   3   ,   11  ,   29  ,   61  ,   67  ,   53  ,   257 ,   609 ,   1581    ,0 };
            const std::uint32_t dim314Kuo3Init[]    =   {   1   ,   1   ,   3   ,   15  ,   31  ,   25  ,   123 ,   59  ,   395 ,   107 ,   587 ,0 };
            const std::uint32_t dim315Kuo3Init[]    =   {   1   ,   3   ,   1   ,   7   ,   29  ,   19  ,   51  ,   135 ,   503 ,   71  ,   33  ,0 };
            const std::uint32_t dim316Kuo3Init[]    =   {   1   ,   3   ,   1   ,   15  ,   21  ,   31  ,   23  ,   85  ,   17  ,   227 ,   657 ,0 };
            const std::uint32_t dim317Kuo3Init[]    =   {   1   ,   1   ,   1   ,   3   ,   9   ,   63  ,   61  ,   205 ,   61  ,   699 ,   599 ,0 };
            const std::uint32_t dim318Kuo3Init[]    =   {   1   ,   3   ,   1   ,   15  ,   1   ,   39  ,   45  ,   133 ,   1   ,   391 ,   255 ,0 };
            const std::uint32_t dim319Kuo3Init[]    =   {   1   ,   3   ,   5   ,   13  ,   17  ,   13  ,   107 ,   245 ,   55  ,   619 ,   1085    ,0 };
            const std::uint32_t dim320Kuo3Init[]    =   {   1   ,   3   ,   3   ,   9   ,   5   ,   25  ,   5   ,   49  ,   509 ,   661 ,   1225    ,0 };
            const std::uint32_t dim321Kuo3Init[]    =   {   1   ,   3   ,   7   ,   9   ,   29  ,   61  ,   13  ,   247 ,   341 ,   257 ,   1551    ,0 };
            const std::uint32_t dim322Kuo3Init[]    =   {   1   ,   3   ,   7   ,   9   ,   5   ,   39  ,   123 ,   221 ,   391 ,   501 ,   527 ,0 };
            const std::uint32_t dim323Kuo3Init[]    =   {   1   ,   3   ,   1   ,   7   ,   21  ,   23  ,   65  ,   233 ,   181 ,   405 ,   1297    ,0 };
            const std::uint32_t dim324Kuo3Init[]    =   {   1   ,   1   ,   1   ,   3   ,   23  ,   23  ,   15  ,   253 ,   37  ,   679 ,   1455    ,0 };
            const std::uint32_t dim325Kuo3Init[]    =   {   1   ,   3   ,   3   ,   3   ,   3   ,   31  ,   89  ,   105 ,   11  ,   1015    ,   1837    ,0 };
            const std::uint32_t dim326Kuo3Init[]    =   {   1   ,   3   ,   1   ,   7   ,   15  ,   59  ,   105 ,   179 ,   477 ,   923 ,   1189    ,0 };
            const std::uint32_t dim327Kuo3Init[]    =   {   1   ,   3   ,   5   ,   9   ,   1   ,   9   ,   21  ,   71  ,   145 ,   409 ,   1235    ,0 };
            const std::uint32_t dim328Kuo3Init[]    =   {   1   ,   1   ,   7   ,   13  ,   9   ,   43  ,   85  ,   241 ,   497 ,   683 ,   1169    ,0 };
            const std::uint32_t dim329Kuo3Init[]    =   {   1   ,   3   ,   3   ,   13  ,   29  ,   41  ,   23  ,   51  ,   1   ,   563 ,   905 ,0 };
            const std::uint32_t dim330Kuo3Init[]    =   {   1   ,   3   ,   5   ,   9   ,   25  ,   51  ,   1   ,   71  ,   25  ,   195 ,   363 ,0 };
            const std::uint32_t dim331Kuo3Init[]    =   {   1   ,   3   ,   7   ,   7   ,   31  ,   49  ,   13  ,   255 ,   471 ,   653 ,   1127    ,0 };
            const std::uint32_t dim332Kuo3Init[]    =   {   1   ,   3   ,   3   ,   7   ,   7   ,   61  ,   63  ,   21  ,   413 ,   817 ,   1369    ,0 };
            const std::uint32_t dim333Kuo3Init[]    =   {   1   ,   3   ,   5   ,   1   ,   7   ,   53  ,   43  ,   167 ,   173 ,   261 ,   633 ,0 };
            const std::uint32_t dim334Kuo3Init[]    =   {   1   ,   1   ,   1   ,   13  ,   21  ,   59  ,   49  ,   135 ,   351 ,   187 ,   447 ,0 };
            const std::uint32_t dim335Kuo3Init[]    =   {   1   ,   1   ,   3   ,   7   ,   5   ,   35  ,   103 ,   5   ,   247 ,   555 ,   1439    ,0 };
            const std::uint32_t dim336Kuo3Init[]    =   {   1   ,   1   ,   3   ,   1   ,   3   ,   11  ,   5   ,   153 ,   507 ,   21  ,   1331    ,0 };
            const std::uint32_t dim337Kuo3Init[]    =   {   1   ,   3   ,   7   ,   15  ,   25  ,   11  ,   29  ,   51  ,   353 ,   447 ,   337 ,   3621    ,0 };
            const std::uint32_t dim338Kuo3Init[]    =   {   1   ,   3   ,   5   ,   13  ,   31  ,   51  ,   103 ,   69  ,   311 ,   645 ,   1373    ,   1155    ,0 };
            const std::uint32_t dim339Kuo3Init[]    =   {   1   ,   1   ,   7   ,   7   ,   1   ,   55  ,   101 ,   203 ,   503 ,   711 ,   131 ,   937 ,0 };
            const std::uint32_t dim340Kuo3Init[]    =   {   1   ,   3   ,   3   ,   11  ,   7   ,   5   ,   75  ,   63  ,   217 ,   643 ,   871 ,   3511    ,0 };
            const std::uint32_t dim341Kuo3Init[]    =   {   1   ,   1   ,   3   ,   15  ,   21  ,   23  ,   75  ,   3   ,   113 ,   203 ,   13  ,   2727    ,0 };
            const std::uint32_t dim342Kuo3Init[]    =   {   1   ,   3   ,   5   ,   11  ,   7   ,   1   ,   27  ,   39  ,   411 ,   195 ,   607 ,   1705    ,0 };
            const std::uint32_t dim343Kuo3Init[]    =   {   1   ,   1   ,   7   ,   11  ,   23  ,   21  ,   11  ,   113 ,   437 ,   947 ,   1897    ,   1249    ,0 };
            const std::uint32_t dim344Kuo3Init[]    =   {   1   ,   1   ,   7   ,   5   ,   23  ,   45  ,   41  ,   169 ,   33  ,   981 ,   1331    ,   2013    ,0 };
            const std::uint32_t dim345Kuo3Init[]    =   {   1   ,   3   ,   1   ,   7   ,   11  ,   5   ,   11  ,   121 ,   239 ,   269 ,   1759    ,   829 ,0 };
            const std::uint32_t dim346Kuo3Init[]    =   {   1   ,   1   ,   1   ,   9   ,   31  ,   51  ,   77  ,   61  ,   19  ,   121 ,   969 ,   3627    ,0 };
            const std::uint32_t dim347Kuo3Init[]    =   {   1   ,   3   ,   1   ,   13  ,   23  ,   45  ,   39  ,   183 ,   21  ,   787 ,   967 ,   1911    ,0 };
            const std::uint32_t dim348Kuo3Init[]    =   {   1   ,   1   ,   1   ,   15  ,   21  ,   19  ,   91  ,   231 ,   325 ,   531 ,   473 ,   2543    ,0 };
            const std::uint32_t dim349Kuo3Init[]    =   {   1   ,   3   ,   5   ,   3   ,   7   ,   25  ,   91  ,   193 ,   387 ,   181 ,   493 ,   1225    ,0 };
            const std::uint32_t dim350Kuo3Init[]    =   {   1   ,   1   ,   7   ,   7   ,   23  ,   21  ,   55  ,   221 ,   283 ,   995 ,   793 ,   485 ,0 };
            const std::uint32_t dim351Kuo3Init[]    =   {   1   ,   1   ,   1   ,   15  ,   29  ,   61  ,   1   ,   33  ,   59  ,   725 ,   1053    ,   55  ,0 };
            const std::uint32_t dim352Kuo3Init[]    =   {   1   ,   3   ,   3   ,   5   ,   15  ,   43  ,   85  ,   87  ,   425 ,   39  ,   1559    ,   1403    ,0 };
            const std::uint32_t dim353Kuo3Init[]    =   {   1   ,   1   ,   5   ,   9   ,   3   ,   7   ,   65  ,   3   ,   177 ,   491 ,   121 ,   2755    ,0 };
            const std::uint32_t dim354Kuo3Init[]    =   {   1   ,   1   ,   3   ,   3   ,   15  ,   37  ,   67  ,   145 ,   295 ,   421 ,   1849    ,   2151    ,0 };
            const std::uint32_t dim355Kuo3Init[]    =   {   1   ,   1   ,   3   ,   15  ,   17  ,   41  ,   109 ,   125 ,   509 ,   407 ,   1927    ,   2401    ,0 };
            const std::uint32_t dim356Kuo3Init[]    =   {   1   ,   1   ,   7   ,   5   ,   9   ,   39  ,   69  ,   1   ,   259 ,   821 ,   1837    ,   947 ,0 };
            const std::uint32_t dim357Kuo3Init[]    =   {   1   ,   1   ,   7   ,   9   ,   25  ,   55  ,   127 ,   185 ,   143 ,   211 ,   1615    ,   1949    ,0 };
            const std::uint32_t dim358Kuo3Init[]    =   {   1   ,   3   ,   3   ,   13  ,   15  ,   25  ,   25  ,   231 ,   197 ,   329 ,   1319    ,   853 ,0 };
            const std::uint32_t dim359Kuo3Init[]    =   {   1   ,   3   ,   7   ,   11  ,   29  ,   1   ,   23  ,   131 ,   473 ,   497 ,   1147    ,   3779    ,0 };
            const std::uint32_t dim360Kuo3Init[]    =   {   1   ,   3   ,   1   ,   15  ,   21  ,   23  ,   67  ,   243 ,   191 ,   353 ,   1091    ,   2121    ,0 };
            const std::uint32_t dim361Kuo3Init[]    =   {   1   ,   1   ,   7   ,   11  ,   27  ,   15  ,   41  ,   183 ,   235 ,   219 ,   303 ,   795 ,0 };
            const std::uint32_t dim362Kuo3Init[]    =   {   1   ,   3   ,   7   ,   15  ,   3   ,   21  ,   19  ,   187 ,   365 ,   453 ,   1069    ,   1983    ,0 };
            const std::uint32_t dim363Kuo3Init[]    =   {   1   ,   1   ,   7   ,   1   ,   27  ,   11  ,   95  ,   117 ,   433 ,   453 ,   1839    ,   3863    ,0 };
            const std::uint32_t dim364Kuo3Init[]    =   {   1   ,   3   ,   3   ,   5   ,   29  ,   63  ,   17  ,   243 ,   247 ,   609 ,   1999    ,   785 ,0 };
            const std::uint32_t dim365Kuo3Init[]    =   {   1   ,   1   ,   1   ,   7   ,   21  ,   17  ,   57  ,   99  ,   227 ,   217 ,   585 ,   397 ,0 };
            const std::uint32_t dim366Kuo3Init[]    =   {   1   ,   1   ,   1   ,   13  ,   13  ,   41  ,   75  ,   153 ,   355 ,   175 ,   313 ,   2237    ,0 };
            const std::uint32_t dim367Kuo3Init[]    =   {   1   ,   3   ,   7   ,   9   ,   27  ,   63  ,   1   ,   33  ,   383 ,   507 ,   1315    ,   1691    ,0 };
            const std::uint32_t dim368Kuo3Init[]    =   {   1   ,   1   ,   3   ,   3   ,   17  ,   33  ,   65  ,   235 ,   395 ,   317 ,   1769    ,   2937    ,0 };
            const std::uint32_t dim369Kuo3Init[]    =   {   1   ,   3   ,   1   ,   5   ,   31  ,   19  ,   25  ,   15  ,   373 ,   823 ,   2003    ,   1309    ,0 };
            const std::uint32_t dim370Kuo3Init[]    =   {   1   ,   3   ,   3   ,   5   ,   3   ,   33  ,   43  ,   225 ,   445 ,   181 ,   325 ,   797 ,0 };
            const std::uint32_t dim371Kuo3Init[]    =   {   1   ,   1   ,   3   ,   1   ,   11  ,   19  ,   49  ,   129 ,   73  ,   983 ,   621 ,   2381    ,0 };
            const std::uint32_t dim372Kuo3Init[]    =   {   1   ,   3   ,   3   ,   15  ,   1   ,   33  ,   109 ,   33  ,   363 ,   925 ,   589 ,   3955    ,0 };
            const std::uint32_t dim373Kuo3Init[]    =   {   1   ,   1   ,   3   ,   3   ,   11  ,   21  ,   23  ,   99  ,   159 ,   949 ,   977 ,   3103    ,0 };
            const std::uint32_t dim374Kuo3Init[]    =   {   1   ,   1   ,   5   ,   3   ,   3   ,   15  ,   41  ,   45  ,   325 ,   703 ,   907 ,   2467    ,0 };
            const std::uint32_t dim375Kuo3Init[]    =   {   1   ,   1   ,   7   ,   15  ,   31  ,   11  ,   71  ,   225 ,   199 ,   521 ,   933 ,   2777    ,0 };
            const std::uint32_t dim376Kuo3Init[]    =   {   1   ,   3   ,   5   ,   9   ,   13  ,   55  ,   23  ,   199 ,   293 ,   297 ,   2031    ,   3815    ,0 };
            const std::uint32_t dim377Kuo3Init[]    =   {   1   ,   1   ,   3   ,   13  ,   25  ,   5   ,   25  ,   229 ,   301 ,   301 ,   1165    ,   2229    ,0 };
            const std::uint32_t dim378Kuo3Init[]    =   {   1   ,   1   ,   1   ,   11  ,   1   ,   39  ,   25  ,   211 ,   233 ,   233 ,   355 ,   3131    ,0 };
            const std::uint32_t dim379Kuo3Init[]    =   {   1   ,   3   ,   3   ,   9   ,   31  ,   37  ,   113 ,   17  ,   163 ,   547 ,   877 ,   333 ,0 };
            const std::uint32_t dim380Kuo3Init[]    =   {   1   ,   1   ,   7   ,   1   ,   31  ,   7   ,   117 ,   175 ,   191 ,   191 ,   1185    ,   2637    ,0 };
            const std::uint32_t dim381Kuo3Init[]    =   {   1   ,   1   ,   3   ,   11  ,   27  ,   59  ,   33  ,   79  ,   293 ,   657 ,   1899    ,   1547    ,0 };
            const std::uint32_t dim382Kuo3Init[]    =   {   1   ,   3   ,   1   ,   7   ,   29  ,   43  ,   89  ,   227 ,   315 ,   971 ,   1175    ,   693 ,0 };
            const std::uint32_t dim383Kuo3Init[]    =   {   1   ,   1   ,   1   ,   5   ,   9   ,   43  ,   17  ,   37  ,   321 ,   907 ,   441 ,   21  ,0 };
            const std::uint32_t dim384Kuo3Init[]    =   {   1   ,   3   ,   1   ,   15  ,   25  ,   47  ,   21  ,   11  ,   385 ,   353 ,   1103    ,   3445    ,0 };
            const std::uint32_t dim385Kuo3Init[]    =   {   1   ,   1   ,   7   ,   9   ,   21  ,   63  ,   9   ,   147 ,   79  ,   627 ,   471 ,   1683    ,0 };
            const std::uint32_t dim386Kuo3Init[]    =   {   1   ,   3   ,   7   ,   7   ,   1   ,   13  ,   29  ,   127 ,   3   ,   629 ,   1213    ,   2981    ,0 };
            const std::uint32_t dim387Kuo3Init[]    =   {   1   ,   1   ,   5   ,   9   ,   7   ,   41  ,   41  ,   235 ,   131 ,   379 ,   23  ,   1251    ,0 };
            const std::uint32_t dim388Kuo3Init[]    =   {   1   ,   3   ,   5   ,   3   ,   17  ,   31  ,   101 ,   193 ,   271 ,   189 ,   1923    ,   1849    ,0 };
            const std::uint32_t dim389Kuo3Init[]    =   {   1   ,   1   ,   1   ,   5   ,   21  ,   43  ,   35  ,   209 ,   359 ,   185 ,   1921    ,   2773    ,0 };
            const std::uint32_t dim390Kuo3Init[]    =   {   1   ,   1   ,   7   ,   5   ,   31  ,   5   ,   41  ,   127 ,   415 ,   151 ,   1027    ,   2171    ,0 };
            const std::uint32_t dim391Kuo3Init[]    =   {   1   ,   1   ,   1   ,   3   ,   31  ,   53  ,   127 ,   37  ,   273 ,   415 ,   1657    ,   467 ,0 };
            const std::uint32_t dim392Kuo3Init[]    =   {   1   ,   3   ,   7   ,   3   ,   29  ,   43  ,   77  ,   35  ,   347 ,   37  ,   1265    ,   1211    ,0 };
            const std::uint32_t dim393Kuo3Init[]    =   {   1   ,   1   ,   1   ,   1   ,   3   ,   31  ,   89  ,   57  ,   405 ,   491 ,   1685    ,   2727    ,0 };
            const std::uint32_t dim394Kuo3Init[]    =   {   1   ,   3   ,   5   ,   15  ,   29  ,   9   ,   23  ,   79  ,   253 ,   161 ,   273 ,   4001    ,0 };
            const std::uint32_t dim395Kuo3Init[]    =   {   1   ,   3   ,   3   ,   13  ,   29  ,   49  ,   73  ,   145 ,   203 ,   215 ,   423 ,   3293    ,0 };
            const std::uint32_t dim396Kuo3Init[]    =   {   1   ,   1   ,   5   ,   15  ,   29  ,   43  ,   49  ,   99  ,   335 ,   1017    ,   315 ,   2761    ,0 };
            const std::uint32_t dim397Kuo3Init[]    =   {   1   ,   3   ,   1   ,   9   ,   15  ,   39  ,   87  ,   243 ,   331 ,   1015    ,   1771    ,   1303    ,0 };
            const std::uint32_t dim398Kuo3Init[]    =   {   1   ,   1   ,   1   ,   5   ,   5   ,   1   ,   15  ,   19  ,   277 ,   699 ,   1957    ,   373 ,0 };
            const std::uint32_t dim399Kuo3Init[]    =   {   1   ,   1   ,   7   ,   1   ,   7   ,   13  ,   41  ,   211 ,   167 ,   705 ,   1011    ,   2097    ,0 };
            const std::uint32_t dim400Kuo3Init[]    =   {   1   ,   1   ,   7   ,   9   ,   3   ,   25  ,   127 ,   75  ,   271 ,   817 ,   629 ,   2027    ,0 };
            const std::uint32_t dim401Kuo3Init[]    =   {   1   ,   3   ,   1   ,   5   ,   31  ,   49  ,   17  ,   113 ,   71  ,   233 ,   443 ,   3005    ,0 };
            const std::uint32_t dim402Kuo3Init[]    =   {   1   ,   1   ,   1   ,   1   ,   1   ,   23  ,   87  ,   29  ,   121 ,   485 ,   227 ,   2981    ,0 };
            const std::uint32_t dim403Kuo3Init[]    =   {   1   ,   1   ,   1   ,   1   ,   19  ,   3   ,   127 ,   31  ,   57  ,   567 ,   375 ,   1121    ,0 };
            const std::uint32_t dim404Kuo3Init[]    =   {   1   ,   1   ,   1   ,   9   ,   15  ,   49  ,   67  ,   49  ,   473 ,   957 ,   1955    ,   29  ,0 };
            const std::uint32_t dim405Kuo3Init[]    =   {   1   ,   1   ,   1   ,   1   ,   15  ,   49  ,   71  ,   241 ,   43  ,   611 ,   953 ,   4013    ,0 };
            const std::uint32_t dim406Kuo3Init[]    =   {   1   ,   3   ,   3   ,   3   ,   13  ,   57  ,   45  ,   65  ,   5   ,   101 ,   511 ,   3317    ,0 };
            const std::uint32_t dim407Kuo3Init[]    =   {   1   ,   3   ,   3   ,   7   ,   25  ,   9   ,   97  ,   35  ,   495 ,   791 ,   223 ,   1555    ,0 };
            const std::uint32_t dim408Kuo3Init[]    =   {   1   ,   1   ,   3   ,   1   ,   25  ,   37  ,   73  ,   61  ,   31  ,   525 ,   855 ,   695 ,0 };
            const std::uint32_t dim409Kuo3Init[]    =   {   1   ,   3   ,   5   ,   11  ,   15  ,   45  ,   11  ,   53  ,   393 ,   557 ,   349 ,   2507    ,0 };
            const std::uint32_t dim410Kuo3Init[]    =   {   1   ,   1   ,   5   ,   11  ,   1   ,   43  ,   77  ,   215 ,   149 ,   81  ,   1663    ,   987 ,0 };
            const std::uint32_t dim411Kuo3Init[]    =   {   1   ,   3   ,   5   ,   5   ,   13  ,   55  ,   45  ,   79  ,   305 ,   65  ,   1721    ,   605 ,0 };
            const std::uint32_t dim412Kuo3Init[]    =   {   1   ,   1   ,   1   ,   3   ,   15  ,   19  ,   103 ,   249 ,   253 ,   935 ,   1933    ,   3809    ,0 };
            const std::uint32_t dim413Kuo3Init[]    =   {   1   ,   1   ,   1   ,   11  ,   1   ,   43  ,   119 ,   233 ,   79  ,   539 ,   1397    ,   1669    ,0 };
            const std::uint32_t dim414Kuo3Init[]    =   {   1   ,   1   ,   7   ,   15  ,   9   ,   27  ,   29  ,   125 ,   335 ,   573 ,   1721    ,   551 ,0 };
            const std::uint32_t dim415Kuo3Init[]    =   {   1   ,   1   ,   5   ,   11  ,   29  ,   33  ,   121 ,   47  ,   351 ,   857 ,   1155    ,   2939    ,0 };
            const std::uint32_t dim416Kuo3Init[]    =   {   1   ,   1   ,   1   ,   13  ,   21  ,   13  ,   107 ,   179 ,   135 ,   597 ,   39  ,   2129    ,0 };
            const std::uint32_t dim417Kuo3Init[]    =   {   1   ,   3   ,   5   ,   15  ,   11  ,   5   ,   101 ,   227 ,   457 ,   773 ,   1369    ,   2229    ,0 };
            const std::uint32_t dim418Kuo3Init[]    =   {   1   ,   1   ,   7   ,   3   ,   9   ,   47  ,   53  ,   47  ,   315 ,   221 ,   369 ,   2991    ,0 };
            const std::uint32_t dim419Kuo3Init[]    =   {   1   ,   3   ,   7   ,   9   ,   7   ,   1   ,   117 ,   229 ,   193 ,   105 ,   1591    ,   875 ,0 };
            const std::uint32_t dim420Kuo3Init[]    =   {   1   ,   3   ,   1   ,   13  ,   5   ,   49  ,   47  ,   95  ,   431 ,   37  ,   2037    ,   3793    ,0 };
            const std::uint32_t dim421Kuo3Init[]    =   {   1   ,   1   ,   3   ,   11  ,   17  ,   39  ,   91  ,   225 ,   109 ,   375 ,   1431    ,   3689    ,0 };
            const std::uint32_t dim422Kuo3Init[]    =   {   1   ,   3   ,   5   ,   7   ,   27  ,   39  ,   23  ,   215 ,   55  ,   573 ,   965 ,   321 ,0 };
            const std::uint32_t dim423Kuo3Init[]    =   {   1   ,   1   ,   3   ,   13  ,   1   ,   51  ,   23  ,   181 ,   399 ,   471 ,   429 ,   2409    ,0 };
            const std::uint32_t dim424Kuo3Init[]    =   {   1   ,   1   ,   7   ,   9   ,   17  ,   21  ,   43  ,   177 ,   327 ,   789 ,   1581    ,   3505    ,0 };
            const std::uint32_t dim425Kuo3Init[]    =   {   1   ,   1   ,   7   ,   7   ,   9   ,   39  ,   59  ,   187 ,   203 ,   655 ,   545 ,   2107    ,0 };
            const std::uint32_t dim426Kuo3Init[]    =   {   1   ,   1   ,   7   ,   3   ,   15  ,   13  ,   83  ,   189 ,   213 ,   575 ,   255 ,   1475    ,0 };
            const std::uint32_t dim427Kuo3Init[]    =   {   1   ,   1   ,   1   ,   3   ,   23  ,   27  ,   101 ,   67  ,   299 ,   1003    ,   1351    ,   1799    ,0 };
            const std::uint32_t dim428Kuo3Init[]    =   {   1   ,   3   ,   3   ,   9   ,   13  ,   29  ,   83  ,   251 ,   151 ,   607 ,   2047    ,   447 ,0 };
            const std::uint32_t dim429Kuo3Init[]    =   {   1   ,   3   ,   1   ,   5   ,   5   ,   7   ,   23  ,   145 ,   241 ,   437 ,   1215    ,   489 ,0 };
            const std::uint32_t dim430Kuo3Init[]    =   {   1   ,   3   ,   1   ,   11  ,   3   ,   63  ,   55  ,   53  ,   187 ,   179 ,   1137    ,   3923    ,0 };
            const std::uint32_t dim431Kuo3Init[]    =   {   1   ,   3   ,   7   ,   11  ,   31  ,   29  ,   127 ,   37  ,   509 ,   835 ,   1693    ,   965 ,0 };
            const std::uint32_t dim432Kuo3Init[]    =   {   1   ,   1   ,   1   ,   9   ,   29  ,   1   ,   11  ,   61  ,   459 ,   415 ,   317 ,   2981    ,0 };
            const std::uint32_t dim433Kuo3Init[]    =   {   1   ,   3   ,   7   ,   3   ,   1   ,   61  ,   31  ,   77  ,   55  ,   301 ,   1333    ,   2803    ,0 };
            const std::uint32_t dim434Kuo3Init[]    =   {   1   ,   1   ,   7   ,   13  ,   3   ,   1   ,   117 ,   185 ,   385 ,   771 ,   409 ,   3667    ,0 };
            const std::uint32_t dim435Kuo3Init[]    =   {   1   ,   1   ,   5   ,   13  ,   19  ,   3   ,   43  ,   53  ,   41  ,   111 ,   1617    ,   95  ,0 };
            const std::uint32_t dim436Kuo3Init[]    =   {   1   ,   3   ,   7   ,   13  ,   25  ,   25  ,   125 ,   91  ,   85  ,   99  ,   461 ,   3999    ,0 };
            const std::uint32_t dim437Kuo3Init[]    =   {   1   ,   3   ,   5   ,   7   ,   7   ,   29  ,   15  ,   155 ,   237 ,   443 ,   1187    ,   623 ,0 };
            const std::uint32_t dim438Kuo3Init[]    =   {   1   ,   3   ,   3   ,   1   ,   11  ,   3   ,   35  ,   169 ,   449 ,   917 ,   141 ,   1525    ,0 };
            const std::uint32_t dim439Kuo3Init[]    =   {   1   ,   1   ,   5   ,   7   ,   17  ,   11  ,   85  ,   31  ,   165 ,   35  ,   1069    ,   3395    ,0 };
            const std::uint32_t dim440Kuo3Init[]    =   {   1   ,   3   ,   7   ,   15  ,   11  ,   21  ,   89  ,   61  ,   459 ,   211 ,   959 ,   2411    ,0 };
            const std::uint32_t dim441Kuo3Init[]    =   {   1   ,   1   ,   5   ,   11  ,   25  ,   35  ,   1   ,   137 ,   491 ,   955 ,   1287    ,   3955    ,0 };
            const std::uint32_t dim442Kuo3Init[]    =   {   1   ,   3   ,   3   ,   11  ,   13  ,   47  ,   105 ,   69  ,   119 ,   455 ,   769 ,   1665    ,0 };
            const std::uint32_t dim443Kuo3Init[]    =   {   1   ,   3   ,   3   ,   13  ,   17  ,   9   ,   27  ,   25  ,   445 ,   611 ,   855 ,   1273    ,0 };
            const std::uint32_t dim444Kuo3Init[]    =   {   1   ,   1   ,   3   ,   9   ,   3   ,   5   ,   107 ,   89  ,   443 ,   991 ,   727 ,   871 ,0 };
            const std::uint32_t dim445Kuo3Init[]    =   {   1   ,   1   ,   5   ,   3   ,   19  ,   43  ,   93  ,   163 ,   193 ,   395 ,   99  ,   1717    ,0 };
            const std::uint32_t dim446Kuo3Init[]    =   {   1   ,   1   ,   1   ,   7   ,   23  ,   43  ,   121 ,   205 ,   249 ,   255 ,   1763    ,   1867    ,0 };
            const std::uint32_t dim447Kuo3Init[]    =   {   1   ,   1   ,   3   ,   3   ,   1   ,   45  ,   33  ,   191 ,   475 ,   503 ,   761 ,   1845    ,0 };
            const std::uint32_t dim448Kuo3Init[]    =   {   1   ,   1   ,   3   ,   3   ,   31  ,   39  ,   11  ,   203 ,   9   ,   183 ,   407 ,   3787    ,0 };
            const std::uint32_t dim449Kuo3Init[]    =   {   1   ,   1   ,   5   ,   11  ,   11  ,   3   ,   65  ,   175 ,   131 ,   757 ,   1717    ,   1003    ,0 };
            const std::uint32_t dim450Kuo3Init[]    =   {   1   ,   1   ,   1   ,   15  ,   13  ,   61  ,   29  ,   123 ,   269 ,   531 ,   257 ,   1399    ,0 };
            const std::uint32_t dim451Kuo3Init[]    =   {   1   ,   3   ,   5   ,   5   ,   13  ,   23  ,   23  ,   1   ,   293 ,   921 ,   79  ,   479 ,0 };
            const std::uint32_t dim452Kuo3Init[]    =   {   1   ,   1   ,   3   ,   13  ,   9   ,   55  ,   21  ,   15  ,   47  ,   685 ,   829 ,   2679    ,0 };
            const std::uint32_t dim453Kuo3Init[]    =   {   1   ,   3   ,   5   ,   11  ,   1   ,   39  ,   97  ,   59  ,   37  ,   787 ,   991 ,   263 ,0 };
            const std::uint32_t dim454Kuo3Init[]    =   {   1   ,   3   ,   5   ,   15  ,   31  ,   3   ,   45  ,   159 ,   219 ,   161 ,   1025    ,   665 ,0 };
            const std::uint32_t dim455Kuo3Init[]    =   {   1   ,   3   ,   7   ,   15  ,   11  ,   51  ,   51  ,   19  ,   181 ,   125 ,   1677    ,   2125    ,0 };
            const std::uint32_t dim456Kuo3Init[]    =   {   1   ,   1   ,   3   ,   5   ,   27  ,   23  ,   79  ,   161 ,   97  ,   581 ,   405 ,   2239    ,0 };
            const std::uint32_t dim457Kuo3Init[]    =   {   1   ,   3   ,   1   ,   11  ,   17  ,   1   ,   97  ,   33  ,   31  ,   771 ,   707 ,   1053    ,0 };
            const std::uint32_t dim458Kuo3Init[]    =   {   1   ,   1   ,   1   ,   11  ,   11  ,   51  ,   113 ,   47  ,   51  ,   827 ,   385 ,   3211    ,0 };
            const std::uint32_t dim459Kuo3Init[]    =   {   1   ,   3   ,   3   ,   7   ,   17  ,   3   ,   99  ,   57  ,   59  ,   199 ,   1359    ,   2459    ,0 };
            const std::uint32_t dim460Kuo3Init[]    =   {   1   ,   1   ,   5   ,   11  ,   1   ,   7   ,   19  ,   37  ,   53  ,   435 ,   1095    ,   495 ,0 };
            const std::uint32_t dim461Kuo3Init[]    =   {   1   ,   1   ,   5   ,   13  ,   19  ,   5   ,   95  ,   109 ,   245 ,   737 ,   1163    ,   33  ,0 };
            const std::uint32_t dim462Kuo3Init[]    =   {   1   ,   3   ,   5   ,   3   ,   1   ,   17  ,   79  ,   195 ,   153 ,   857 ,   603 ,   2905    ,0 };
            const std::uint32_t dim463Kuo3Init[]    =   {   1   ,   3   ,   5   ,   5   ,   31  ,   51  ,   71  ,   103 ,   121 ,   5   ,   931 ,   217 ,0 };
            const std::uint32_t dim464Kuo3Init[]    =   {   1   ,   1   ,   5   ,   7   ,   31  ,   39  ,   11  ,   9   ,   223 ,   365 ,   1317    ,   449 ,0 };
            const std::uint32_t dim465Kuo3Init[]    =   {   1   ,   3   ,   5   ,   3   ,   17  ,   19  ,   85  ,   121 ,   161 ,   75  ,   527 ,   3941    ,0 };
            const std::uint32_t dim466Kuo3Init[]    =   {   1   ,   3   ,   5   ,   9   ,   17  ,   53  ,   41  ,   255 ,   207 ,   251 ,   925 ,   2395    ,0 };
            const std::uint32_t dim467Kuo3Init[]    =   {   1   ,   3   ,   3   ,   3   ,   13  ,   5   ,   109 ,   125 ,   293 ,   165 ,   1715    ,   1017    ,0 };
            const std::uint32_t dim468Kuo3Init[]    =   {   1   ,   3   ,   7   ,   1   ,   23  ,   27  ,   45  ,   141 ,   267 ,   187 ,   611 ,   59  ,0 };
            const std::uint32_t dim469Kuo3Init[]    =   {   1   ,   3   ,   1   ,   9   ,   11  ,   9   ,   81  ,   239 ,   469 ,   905 ,   525 ,   1549    ,0 };
            const std::uint32_t dim470Kuo3Init[]    =   {   1   ,   1   ,   1   ,   15  ,   13  ,   21  ,   71  ,   87  ,   199 ,   389 ,   139 ,   3499    ,0 };
            const std::uint32_t dim471Kuo3Init[]    =   {   1   ,   3   ,   7   ,   5   ,   21  ,   41  ,   107 ,   195 ,   369 ,   391 ,   271 ,   3351    ,0 };
            const std::uint32_t dim472Kuo3Init[]    =   {   1   ,   3   ,   3   ,   1   ,   17  ,   19  ,   75  ,   219 ,   415 ,   241 ,   1441    ,   967 ,0 };
            const std::uint32_t dim473Kuo3Init[]    =   {   1   ,   1   ,   1   ,   15  ,   7   ,   7   ,   79  ,   213 ,   391 ,   831 ,   1649    ,   3741    ,0 };
            const std::uint32_t dim474Kuo3Init[]    =   {   1   ,   3   ,   5   ,   3   ,   29  ,   57  ,   99  ,   207 ,   243 ,   915 ,   1969    ,   2499    ,0 };
            const std::uint32_t dim475Kuo3Init[]    =   {   1   ,   1   ,   3   ,   13  ,   1   ,   3   ,   27  ,   211 ,   271 ,   657 ,   1251    ,   3333    ,0 };
            const std::uint32_t dim476Kuo3Init[]    =   {   1   ,   3   ,   3   ,   1   ,   3   ,   31  ,   49  ,   53  ,   273 ,   837 ,   1771    ,   1405    ,0 };
            const std::uint32_t dim477Kuo3Init[]    =   {   1   ,   3   ,   7   ,   7   ,   1   ,   33  ,   125 ,   221 ,   179 ,   601 ,   565 ,   2709    ,0 };
            const std::uint32_t dim478Kuo3Init[]    =   {   1   ,   1   ,   1   ,   7   ,   31  ,   19  ,   81  ,   173 ,   413 ,   849 ,   579 ,   2487    ,0 };
            const std::uint32_t dim479Kuo3Init[]    =   {   1   ,   1   ,   7   ,   11  ,   17  ,   23  ,   97  ,   145 ,   383 ,   1015    ,   547 ,   483 ,0 };
            const std::uint32_t dim480Kuo3Init[]    =   {   1   ,   3   ,   1   ,   3   ,   11  ,   63  ,   41  ,   175 ,   43  ,   283 ,   1441    ,   2695    ,0 };
            const std::uint32_t dim481Kuo3Init[]    =   {   1   ,   1   ,   7   ,   9   ,   5   ,   23  ,   61  ,   161 ,   149 ,   49  ,   1851    ,   1281    ,   4615    ,0 };
            const std::uint32_t dim482Kuo3Init[]    =   {   1   ,   1   ,   5   ,   7   ,   23  ,   47  ,   111 ,   213 ,   317 ,   107 ,   849 ,   1563    ,   6863    ,0 };
            const std::uint32_t dim483Kuo3Init[]    =   {   1   ,   1   ,   7   ,   9   ,   31  ,   53  ,   115 ,   233 ,   497 ,   23  ,   1395    ,   327 ,   551 ,0 };
            const std::uint32_t dim484Kuo3Init[]    =   {   1   ,   1   ,   7   ,   13  ,   21  ,   51  ,   17  ,   109 ,   29  ,   1003    ,   1221    ,   2175    ,   4645    ,0 };
            const std::uint32_t dim485Kuo3Init[]    =   {   1   ,   3   ,   3   ,   15  ,   7   ,   57  ,   103 ,   131 ,   63  ,   217 ,   607 ,   2311    ,   1237    ,0 };
            const std::uint32_t dim486Kuo3Init[]    =   {   1   ,   3   ,   5   ,   3   ,   19  ,   27  ,   107 ,   223 ,   15  ,   149 ,   1777    ,   2211    ,   2241    ,0 };
            const std::uint32_t dim487Kuo3Init[]    =   {   1   ,   1   ,   1   ,   1   ,   5   ,   37  ,   87  ,   59  ,   435 ,   37  ,   1771    ,   1675    ,   6241    ,0 };
            const std::uint32_t dim488Kuo3Init[]    =   {   1   ,   3   ,   1   ,   7   ,   29  ,   51  ,   83  ,   41  ,   11  ,   545 ,   995 ,   1625    ,   4883    ,0 };
            const std::uint32_t dim489Kuo3Init[]    =   {   1   ,   1   ,   1   ,   5   ,   15  ,   43  ,   57  ,   111 ,   55  ,   921 ,   567 ,   1767    ,   1849    ,0 };
            const std::uint32_t dim490Kuo3Init[]    =   {   1   ,   1   ,   5   ,   15  ,   5   ,   49  ,   3   ,   23  ,   307 ,   691 ,   1727    ,   2297    ,   6705    ,0 };
            const std::uint32_t dim491Kuo3Init[]    =   {   1   ,   3   ,   7   ,   5   ,   31  ,   1   ,   111 ,   53  ,   499 ,   1017    ,   1889    ,   1955    ,   1327    ,0 };
            const std::uint32_t dim492Kuo3Init[]    =   {   1   ,   3   ,   7   ,   11  ,   17  ,   35  ,   71  ,   223 ,   149 ,   743 ,   319 ,   3157    ,   5961    ,0 };
            const std::uint32_t dim493Kuo3Init[]    =   {   1   ,   1   ,   1   ,   3   ,   21  ,   31  ,   27  ,   79  ,   353 ,   753 ,   341 ,   2121    ,   5455    ,0 };
            const std::uint32_t dim494Kuo3Init[]    =   {   1   ,   1   ,   5   ,   3   ,   21  ,   29  ,   27  ,   91  ,   111 ,   359 ,   27  ,   2383    ,   7149    ,0 };
            const std::uint32_t dim495Kuo3Init[]    =   {   1   ,   3   ,   7   ,   9   ,   5   ,   51  ,   115 ,   65  ,   275 ,   211 ,   1519    ,   2247    ,   2065    ,0 };
            const std::uint32_t dim496Kuo3Init[]    =   {   1   ,   1   ,   1   ,   15  ,   27  ,   7   ,   21  ,   173 ,   79  ,   357 ,   693 ,   873 ,   879 ,0 };
            const std::uint32_t dim497Kuo3Init[]    =   {   1   ,   3   ,   1   ,   7   ,   25  ,   47  ,   53  ,   123 ,   491 ,   707 ,   1723    ,   1139    ,   3757    ,0 };
            const std::uint32_t dim498Kuo3Init[]    =   {   1   ,   1   ,   7   ,   5   ,   15  ,   55  ,   103 ,   17  ,   17  ,   345 ,   1477    ,   3423    ,   7527    ,0 };
            const std::uint32_t dim499Kuo3Init[]    =   {   1   ,   3   ,   1   ,   13  ,   1   ,   3   ,   55  ,   85  ,   251 ,   389 ,   631 ,   117 ,   4879    ,0 };
            const std::uint32_t dim500Kuo3Init[]    =   {   1   ,   1   ,   7   ,   1   ,   29  ,   33  ,   17  ,   3   ,   303 ,   299 ,   465 ,   1709    ,   1111    ,0 };
            const std::uint32_t dim501Kuo3Init[]    =   {   1   ,   1   ,   7   ,   5   ,   3   ,   29  ,   111 ,   249 ,   383 ,   611 ,   859 ,   1555    ,   7387    ,0 };
            const std::uint32_t dim502Kuo3Init[]    =   {   1   ,   3   ,   5   ,   5   ,   29  ,   41  ,   33  ,   63  ,   395 ,   53  ,   351 ,   247 ,   5317    ,0 };
            const std::uint32_t dim503Kuo3Init[]    =   {   1   ,   1   ,   5   ,   7   ,   11  ,   63  ,   121 ,   131 ,   249 ,   451 ,   619 ,   2395    ,   4575    ,0 };
            const std::uint32_t dim504Kuo3Init[]    =   {   1   ,   3   ,   7   ,   3   ,   3   ,   43  ,   37  ,   211 ,   385 ,   289 ,   791 ,   735 ,   4683    ,0 };
            const std::uint32_t dim505Kuo3Init[]    =   {   1   ,   1   ,   3   ,   11  ,   7   ,   13  ,   53  ,   7   ,   497 ,   771 ,   903 ,   119 ,   6601    ,0 };
            const std::uint32_t dim506Kuo3Init[]    =   {   1   ,   3   ,   7   ,   1   ,   3   ,   61  ,   117 ,   237 ,   427 ,   335 ,   1749    ,   3105    ,   6493    ,0 };
            const std::uint32_t dim507Kuo3Init[]    =   {   1   ,   3   ,   5   ,   7   ,   11  ,   55  ,   121 ,   93  ,   3   ,   953 ,   433 ,   2663    ,   1633    ,0 };
            const std::uint32_t dim508Kuo3Init[]    =   {   1   ,   1   ,   7   ,   1   ,   7   ,   51  ,   43  ,   31  ,   31  ,   819 ,   791 ,   1071    ,   569 ,0 };
            const std::uint32_t dim509Kuo3Init[]    =   {   1   ,   3   ,   5   ,   11  ,   17  ,   37  ,   71  ,   97  ,   69  ,   681 ,   1133    ,   2425    ,   3217    ,0 };
            const std::uint32_t dim510Kuo3Init[]    =   {   1   ,   1   ,   1   ,   15  ,   9   ,   15  ,   31  ,   131 ,   113 ,   567 ,   593 ,   1781    ,   6715    ,0 };
            const std::uint32_t dim511Kuo3Init[]    =   {   1   ,   1   ,   7   ,   9   ,   29  ,   25  ,   39  ,   159 ,   495 ,   507 ,   1253    ,   409 ,   6723    ,0 };
            const std::uint32_t dim512Kuo3Init[]    =   {   1   ,   1   ,   1   ,   5   ,   13  ,   29  ,   25  ,   197 ,   489 ,   853 ,   87  ,   3173    ,   6389    ,0 };
            const std::uint32_t dim513Kuo3Init[]    =   {   1   ,   1   ,   7   ,   11  ,   11  ,   7   ,   27  ,   227 ,   347 ,   777 ,   893 ,   1007    ,   1953    ,0 };
            const std::uint32_t dim514Kuo3Init[]    =   {   1   ,   1   ,   3   ,   7   ,   31  ,   9   ,   61  ,   39  ,   251 ,   1   ,   1297    ,   2861    ,   2593    ,0 };
            const std::uint32_t dim515Kuo3Init[]    =   {   1   ,   1   ,   5   ,   1   ,   15  ,   45  ,   3   ,   147 ,   143 ,   279 ,   2045    ,   649 ,   5579    ,0 };
            const std::uint32_t dim516Kuo3Init[]    =   {   1   ,   1   ,   5   ,   5   ,   9   ,   51  ,   3   ,   249 ,   253 ,   533 ,   1305    ,   1749    ,   1287    ,0 };
            const std::uint32_t dim517Kuo3Init[]    =   {   1   ,   3   ,   7   ,   9   ,   13  ,   15  ,   85  ,   165 ,   183 ,   943 ,   41  ,   4061    ,   5845    ,0 };
            const std::uint32_t dim518Kuo3Init[]    =   {   1   ,   3   ,   3   ,   1   ,   23  ,   31  ,   49  ,   247 ,   287 ,   83  ,   1833    ,   1249    ,   2789    ,0 };
            const std::uint32_t dim519Kuo3Init[]    =   {   1   ,   3   ,   3   ,   7   ,   7   ,   53  ,   125 ,   211 ,   145 ,   837 ,   515 ,   1971    ,   6201    ,0 };
            const std::uint32_t dim520Kuo3Init[]    =   {   1   ,   3   ,   3   ,   11  ,   13  ,   11  ,   87  ,   11  ,   33  ,   355 ,   1049    ,   3053    ,   4801    ,0 };
            const std::uint32_t dim521Kuo3Init[]    =   {   1   ,   3   ,   5   ,   13  ,   23  ,   25  ,   63  ,   221 ,   385 ,   217 ,   687 ,   455 ,   4083    ,0 };
            const std::uint32_t dim522Kuo3Init[]    =   {   1   ,   1   ,   5   ,   1   ,   3   ,   21  ,   119 ,   79  ,   207 ,   693 ,   925 ,   1519    ,   3981    ,0 };
            const std::uint32_t dim523Kuo3Init[]    =   {   1   ,   1   ,   3   ,   11  ,   21  ,   35  ,   21  ,   21  ,   297 ,   461 ,   793 ,   1679    ,   1285    ,0 };
            const std::uint32_t dim524Kuo3Init[]    =   {   1   ,   3   ,   5   ,   13  ,   31  ,   23  ,   11  ,   129 ,   189 ,   933 ,   283 ,   3435    ,   4593    ,0 };
            const std::uint32_t dim525Kuo3Init[]    =   {   1   ,   3   ,   1   ,   1   ,   13  ,   11  ,   113 ,   35  ,   199 ,   149 ,   181 ,   3183    ,   6205    ,0 };
            const std::uint32_t dim526Kuo3Init[]    =   {   1   ,   3   ,   1   ,   9   ,   7   ,   59  ,   105 ,   161 ,   63  ,   821 ,   13  ,   2561    ,   755 ,0 };
            const std::uint32_t dim527Kuo3Init[]    =   {   1   ,   1   ,   1   ,   7   ,   27  ,   3   ,   87  ,   243 ,   279 ,   13  ,   1341    ,   2383    ,   6005    ,0 };
            const std::uint32_t dim528Kuo3Init[]    =   {   1   ,   3   ,   3   ,   13  ,   27  ,   25  ,   91  ,   205 ,   275 ,   663 ,   1875    ,   2399    ,   4179    ,0 };
            const std::uint32_t dim529Kuo3Init[]    =   {   1   ,   1   ,   7   ,   15  ,   27  ,   25  ,   51  ,   235 ,   391 ,   951 ,   759 ,   285 ,   3443    ,0 };
            const std::uint32_t dim530Kuo3Init[]    =   {   1   ,   3   ,   3   ,   5   ,   1   ,   33  ,   57  ,   107 ,   137 ,   851 ,   1937    ,   1003    ,   2427    ,0 };
            const std::uint32_t dim531Kuo3Init[]    =   {   1   ,   1   ,   5   ,   11  ,   27  ,   3   ,   27  ,   81  ,   303 ,   151 ,   433 ,   1893    ,   587 ,0 };
            const std::uint32_t dim532Kuo3Init[]    =   {   1   ,   1   ,   1   ,   9   ,   25  ,   45  ,   113 ,   173 ,   471 ,   191 ,   1031    ,   2119    ,   4853    ,0 };
            const std::uint32_t dim533Kuo3Init[]    =   {   1   ,   1   ,   7   ,   11  ,   27  ,   23  ,   107 ,   229 ,   485 ,   197 ,   1925    ,   1809    ,   7775    ,0 };
            const std::uint32_t dim534Kuo3Init[]    =   {   1   ,   1   ,   1   ,   3   ,   31  ,   61  ,   91  ,   47  ,   3   ,   643 ,   1487    ,   2563    ,   3893    ,0 };
            const std::uint32_t dim535Kuo3Init[]    =   {   1   ,   1   ,   7   ,   15  ,   19  ,   27  ,   97  ,   109 ,   283 ,   67  ,   335 ,   3707    ,   1909    ,0 };
            const std::uint32_t dim536Kuo3Init[]    =   {   1   ,   1   ,   1   ,   11  ,   23  ,   59  ,   101 ,   249 ,   121 ,   919 ,   1385    ,   2119    ,   7389    ,0 };
            const std::uint32_t dim537Kuo3Init[]    =   {   1   ,   1   ,   7   ,   11  ,   7   ,   29  ,   33  ,   111 ,   243 ,   617 ,   125 ,   3887    ,   727 ,0 };
            const std::uint32_t dim538Kuo3Init[]    =   {   1   ,   1   ,   3   ,   1   ,   7   ,   41  ,   91  ,   177 ,   315 ,   555 ,   1653    ,   1725    ,   8069    ,0 };
            const std::uint32_t dim539Kuo3Init[]    =   {   1   ,   1   ,   5   ,   15  ,   3   ,   63  ,   53  ,   31  ,   177 ,   451 ,   141 ,   3727    ,   1695    ,0 };
            const std::uint32_t dim540Kuo3Init[]    =   {   1   ,   1   ,   3   ,   15  ,   25  ,   37  ,   17  ,   229 ,   75  ,   705 ,   327 ,   1367    ,   807 ,0 };
            const std::uint32_t dim541Kuo3Init[]    =   {   1   ,   3   ,   5   ,   5   ,   27  ,   1   ,   35  ,   97  ,   171 ,   167 ,   1077    ,   25  ,   5497    ,0 };
            const std::uint32_t dim542Kuo3Init[]    =   {   1   ,   1   ,   7   ,   7   ,   11  ,   17  ,   105 ,   41  ,   53  ,   389 ,   941 ,   3273    ,   967 ,0 };
            const std::uint32_t dim543Kuo3Init[]    =   {   1   ,   3   ,   3   ,   15  ,   11  ,   61  ,   125 ,   155 ,   361 ,   229 ,   1981    ,   1647    ,   5077    ,0 };
            const std::uint32_t dim544Kuo3Init[]    =   {   1   ,   3   ,   1   ,   15  ,   5   ,   11  ,   35  ,   203 ,   425 ,   509 ,   993 ,   1861    ,   1977    ,0 };
            const std::uint32_t dim545Kuo3Init[]    =   {   1   ,   3   ,   5   ,   15  ,   25  ,   7   ,   55  ,   89  ,   101 ,   939 ,   7   ,   3535    ,   7543    ,0 };
            const std::uint32_t dim546Kuo3Init[]    =   {   1   ,   1   ,   3   ,   1   ,   19  ,   45  ,   117 ,   249 ,   261 ,   529 ,   1299    ,   597 ,   7207    ,0 };
            const std::uint32_t dim547Kuo3Init[]    =   {   1   ,   3   ,   5   ,   13  ,   17  ,   47  ,   73  ,   231 ,   353 ,   941 ,   325 ,   115 ,   4005    ,0 };
            const std::uint32_t dim548Kuo3Init[]    =   {   1   ,   3   ,   1   ,   9   ,   5   ,   29  ,   11  ,   161 ,   461 ,   793 ,   813 ,   3755    ,   7017    ,0 };
            const std::uint32_t dim549Kuo3Init[]    =   {   1   ,   3   ,   3   ,   15  ,   23  ,   21  ,   83  ,   47  ,   143 ,   279 ,   1009    ,   3315    ,   3801    ,0 };
            const std::uint32_t dim550Kuo3Init[]    =   {   1   ,   1   ,   7   ,   9   ,   21  ,   55  ,   31  ,   129 ,   325 ,   59  ,   701 ,   2227    ,   1491    ,0 };
            const std::uint32_t dim551Kuo3Init[]    =   {   1   ,   1   ,   7   ,   1   ,   21  ,   41  ,   87  ,   151 ,   269 ,   885 ,   795 ,   4087    ,   2919    ,0 };
            const std::uint32_t dim552Kuo3Init[]    =   {   1   ,   1   ,   3   ,   11  ,   7   ,   19  ,   103 ,   45  ,   461 ,   109 ,   1921    ,   2497    ,   4969    ,0 };
            const std::uint32_t dim553Kuo3Init[]    =   {   1   ,   1   ,   3   ,   7   ,   7   ,   49  ,   9   ,   185 ,   95  ,   277 ,   1325    ,   2393    ,   7585    ,0 };
            const std::uint32_t dim554Kuo3Init[]    =   {   1   ,   3   ,   3   ,   13  ,   13  ,   1   ,   71  ,   77  ,   245 ,   865 ,   1693    ,   2187    ,   2589    ,0 };
            const std::uint32_t dim555Kuo3Init[]    =   {   1   ,   3   ,   1   ,   15  ,   19  ,   59  ,   17  ,   189 ,   101 ,   511 ,   23  ,   677 ,   4091    ,0 };
            const std::uint32_t dim556Kuo3Init[]    =   {   1   ,   3   ,   5   ,   7   ,   9   ,   45  ,   45  ,   233 ,   47  ,   973 ,   795 ,   2339    ,   595 ,0 };
            const std::uint32_t dim557Kuo3Init[]    =   {   1   ,   3   ,   1   ,   7   ,   15  ,   35  ,   79  ,   53  ,   429 ,   299 ,   389 ,   237 ,   2261    ,0 };
            const std::uint32_t dim558Kuo3Init[]    =   {   1   ,   3   ,   1   ,   1   ,   9   ,   35  ,   27  ,   169 ,   85  ,   755 ,   145 ,   91  ,   257 ,0 };
            const std::uint32_t dim559Kuo3Init[]    =   {   1   ,   3   ,   7   ,   11  ,   25  ,   33  ,   41  ,   151 ,   11  ,   401 ,   1335    ,   2111    ,   3309    ,0 };
            const std::uint32_t dim560Kuo3Init[]    =   {   1   ,   1   ,   7   ,   3   ,   17  ,   1   ,   61  ,   253 ,   289 ,   917 ,   1157    ,   1513    ,   4783    ,0 };
            const std::uint32_t dim561Kuo3Init[]    =   {   1   ,   1   ,   5   ,   7   ,   23  ,   51  ,   59  ,   171 ,   161 ,   815 ,   969 ,   1199    ,   4137    ,0 };
            const std::uint32_t dim562Kuo3Init[]    =   {   1   ,   3   ,   3   ,   7   ,   7   ,   27  ,   81  ,   175 ,   89  ,   145 ,   19  ,   1469    ,   3775    ,0 };
            const std::uint32_t dim563Kuo3Init[]    =   {   1   ,   3   ,   1   ,   7   ,   7   ,   33  ,   95  ,   179 ,   177 ,   375 ,   1077    ,   3711    ,   2903    ,0 };
            const std::uint32_t dim564Kuo3Init[]    =   {   1   ,   3   ,   1   ,   15  ,   15  ,   27  ,   127 ,   245 ,   307 ,   949 ,   1037    ,   3753    ,   4993    ,0 };
            const std::uint32_t dim565Kuo3Init[]    =   {   1   ,   3   ,   3   ,   7   ,   29  ,   15  ,   59  ,   39  ,   9   ,   331 ,   1877    ,   3565    ,   6483    ,0 };
            const std::uint32_t dim566Kuo3Init[]    =   {   1   ,   1   ,   5   ,   3   ,   1   ,   41  ,   29  ,   185 ,   351 ,   837 ,   747 ,   3263    ,   749 ,0 };
            const std::uint32_t dim567Kuo3Init[]    =   {   1   ,   1   ,   7   ,   1   ,   19  ,   47  ,   1   ,   239 ,   489 ,   79  ,   767 ,   1123    ,   8145    ,0 };
            const std::uint32_t dim568Kuo3Init[]    =   {   1   ,   3   ,   7   ,   15  ,   7   ,   39  ,   23  ,   239 ,   465 ,   981 ,   185 ,   837 ,   7837    ,0 };
            const std::uint32_t dim569Kuo3Init[]    =   {   1   ,   3   ,   5   ,   5   ,   23  ,   15  ,   21  ,   221 ,   259 ,   663 ,   185 ,   1203    ,   2857    ,0 };
            const std::uint32_t dim570Kuo3Init[]    =   {   1   ,   1   ,   3   ,   5   ,   31  ,   43  ,   107 ,   199 ,   117 ,   161 ,   403 ,   2227    ,   7969    ,0 };
            const std::uint32_t dim571Kuo3Init[]    =   {   1   ,   1   ,   3   ,   5   ,   5   ,   5   ,   105 ,   153 ,   349 ,   601 ,   815 ,   939 ,   3547    ,0 };
            const std::uint32_t dim572Kuo3Init[]    =   {   1   ,   1   ,   7   ,   15  ,   23  ,   33  ,   85  ,   51  ,   309 ,   63  ,   1799    ,   1599    ,   1711    ,0 };
            const std::uint32_t dim573Kuo3Init[]    =   {   1   ,   1   ,   7   ,   3   ,   15  ,   41  ,   71  ,   169 ,   87  ,   381 ,   1695    ,   3189    ,   3343    ,0 };
            const std::uint32_t dim574Kuo3Init[]    =   {   1   ,   1   ,   7   ,   11  ,   15  ,   57  ,   81  ,   107 ,   57  ,   773 ,   111 ,   2741    ,   6399    ,0 };
            const std::uint32_t dim575Kuo3Init[]    =   {   1   ,   1   ,   5   ,   15  ,   5   ,   55  ,   65  ,   35  ,   387 ,   797 ,   1093    ,   4039    ,   3041    ,0 };
            const std::uint32_t dim576Kuo3Init[]    =   {   1   ,   1   ,   5   ,   3   ,   29  ,   5   ,   87  ,   235 ,   503 ,   539 ,   483 ,   2785    ,   4211    ,0 };
            const std::uint32_t dim577Kuo3Init[]    =   {   1   ,   1   ,   3   ,   5   ,   11  ,   53  ,   101 ,   83  ,   61  ,   97  ,   411 ,   2063    ,   2951    ,0 };
            const std::uint32_t dim578Kuo3Init[]    =   {   1   ,   1   ,   1   ,   5   ,   25  ,   33  ,   45  ,   253 ,   183 ,   251 ,   1323    ,   1891    ,   5143    ,0 };
            const std::uint32_t dim579Kuo3Init[]    =   {   1   ,   1   ,   5   ,   11  ,   7   ,   61  ,   67  ,   201 ,   465 ,   851 ,   1   ,   1533    ,   2839    ,0 };
            const std::uint32_t dim580Kuo3Init[]    =   {   1   ,   3   ,   3   ,   7   ,   15  ,   3   ,   51  ,   9   ,   425 ,   671 ,   223 ,   2203    ,   481 ,0 };
            const std::uint32_t dim581Kuo3Init[]    =   {   1   ,   1   ,   1   ,   7   ,   25  ,   5   ,   45  ,   153 ,   479 ,   437 ,   221 ,   1085    ,   455 ,0 };
            const std::uint32_t dim582Kuo3Init[]    =   {   1   ,   3   ,   7   ,   1   ,   7   ,   53  ,   65  ,   35  ,   153 ,   423 ,   989 ,   2779    ,   4787    ,0 };
            const std::uint32_t dim583Kuo3Init[]    =   {   1   ,   3   ,   1   ,   3   ,   29  ,   43  ,   7   ,   219 ,   47  ,   431 ,   627 ,   3735    ,   383 ,0 };
            const std::uint32_t dim584Kuo3Init[]    =   {   1   ,   1   ,   5   ,   13  ,   31  ,   49  ,   121 ,   29  ,   235 ,   325 ,   1247    ,   1765    ,   7173    ,0 };
            const std::uint32_t dim585Kuo3Init[]    =   {   1   ,   1   ,   1   ,   9   ,   25  ,   15  ,   73  ,   167 ,   191 ,   215 ,   259 ,   111 ,   2289    ,0 };
            const std::uint32_t dim586Kuo3Init[]    =   {   1   ,   3   ,   7   ,   9   ,   23  ,   1   ,   119 ,   15  ,   155 ,   153 ,   1419    ,   667 ,   6309    ,0 };
            const std::uint32_t dim587Kuo3Init[]    =   {   1   ,   1   ,   5   ,   13  ,   7   ,   53  ,   91  ,   161 ,   445 ,   283 ,   571 ,   3623    ,   5737    ,0 };
            const std::uint32_t dim588Kuo3Init[]    =   {   1   ,   3   ,   3   ,   5   ,   3   ,   39  ,   29  ,   47  ,   393 ,   871 ,   345 ,   805 ,   8167    ,0 };
            const std::uint32_t dim589Kuo3Init[]    =   {   1   ,   3   ,   1   ,   5   ,   21  ,   9   ,   1   ,   169 ,   471 ,   693 ,   53  ,   967 ,   4145    ,0 };
            const std::uint32_t dim590Kuo3Init[]    =   {   1   ,   3   ,   7   ,   11  ,   17  ,   19  ,   123 ,   133 ,   511 ,   15  ,   675 ,   3935    ,   5465    ,0 };
            const std::uint32_t dim591Kuo3Init[]    =   {   1   ,   3   ,   5   ,   13  ,   25  ,   51  ,   63  ,   87  ,   503 ,   61  ,   907 ,   105 ,   7599    ,0 };
            const std::uint32_t dim592Kuo3Init[]    =   {   1   ,   3   ,   5   ,   13  ,   27  ,   3   ,   67  ,   189 ,   193 ,   131 ,   1227    ,   227 ,   1975    ,0 };
            const std::uint32_t dim593Kuo3Init[]    =   {   1   ,   3   ,   5   ,   5   ,   31  ,   17  ,   89  ,   187 ,   391 ,   575 ,   1715    ,   2551    ,   5371    ,0 };
            const std::uint32_t dim594Kuo3Init[]    =   {   1   ,   3   ,   1   ,   9   ,   11  ,   63  ,   9   ,   251 ,   399 ,   703 ,   1557    ,   107 ,   675 ,0 };
            const std::uint32_t dim595Kuo3Init[]    =   {   1   ,   3   ,   5   ,   15  ,   29  ,   55  ,   15  ,   65  ,   51  ,   811 ,   1387    ,   3815    ,   7973    ,0 };
            const std::uint32_t dim596Kuo3Init[]    =   {   1   ,   3   ,   1   ,   13  ,   19  ,   33  ,   87  ,   7   ,   183 ,   97  ,   2011    ,   3849    ,   3015    ,0 };
            const std::uint32_t dim597Kuo3Init[]    =   {   1   ,   1   ,   3   ,   11  ,   29  ,   57  ,   27  ,   185 ,   457 ,   181 ,   1341    ,   2033    ,   2181    ,0 };
            const std::uint32_t dim598Kuo3Init[]    =   {   1   ,   3   ,   7   ,   5   ,   25  ,   19  ,   19  ,   147 ,   101 ,   73  ,   499 ,   897 ,   3053    ,0 };
            const std::uint32_t dim599Kuo3Init[]    =   {   1   ,   3   ,   5   ,   5   ,   29  ,   29  ,   109 ,   5   ,   197 ,   581 ,   1829    ,   3679    ,   283 ,0 };
            const std::uint32_t dim600Kuo3Init[]    =   {   1   ,   3   ,   5   ,   1   ,   27  ,   63  ,   71  ,   131 ,   309 ,   193 ,   1663    ,   3009    ,   1041    ,0 };
            const std::uint32_t dim601Kuo3Init[]    =   {   1   ,   3   ,   3   ,   5   ,   19  ,   29  ,   95  ,   173 ,   195 ,   205 ,   207 ,   3597    ,   2223    ,0 };
            const std::uint32_t dim602Kuo3Init[]    =   {   1   ,   1   ,   5   ,   1   ,   3   ,   45  ,   127 ,   251 ,   175 ,   663 ,   415 ,   1789    ,   6577    ,0 };
            const std::uint32_t dim603Kuo3Init[]    =   {   1   ,   3   ,   1   ,   9   ,   1   ,   51  ,   73  ,   165 ,   377 ,   525 ,   381 ,   2829    ,   4619    ,0 };
            const std::uint32_t dim604Kuo3Init[]    =   {   1   ,   3   ,   1   ,   15  ,   23  ,   19  ,   79  ,   115 ,   297 ,   75  ,   1505    ,   1407    ,   5865    ,0 };
            const std::uint32_t dim605Kuo3Init[]    =   {   1   ,   1   ,   1   ,   5   ,   27  ,   33  ,   93  ,   123 ,   449 ,   747 ,   2027    ,   51  ,   4507    ,0 };
            const std::uint32_t dim606Kuo3Init[]    =   {   1   ,   3   ,   1   ,   7   ,   13  ,   39  ,   49  ,   111 ,   101 ,   247 ,   1375    ,   3577    ,   6769    ,0 };
            const std::uint32_t dim607Kuo3Init[]    =   {   1   ,   1   ,   7   ,   9   ,   19  ,   49  ,   35  ,   139 ,   57  ,   527 ,   1943    ,   1781    ,   1839    ,0 };
            const std::uint32_t dim608Kuo3Init[]    =   {   1   ,   3   ,   7   ,   7   ,   3   ,   7   ,   67  ,   163 ,   289 ,   139 ,   1415    ,   2149    ,   7501    ,0 };
            const std::uint32_t dim609Kuo3Init[]    =   {   1   ,   3   ,   5   ,   5   ,   13  ,   47  ,   21  ,   47  ,   3   ,   105 ,   473 ,   2013    ,   2443    ,0 };
            const std::uint32_t dim610Kuo3Init[]    =   {   1   ,   1   ,   3   ,   13  ,   31  ,   25  ,   21  ,   75  ,   505 ,   795 ,   1311    ,   2467    ,   5541    ,0 };
            const std::uint32_t dim611Kuo3Init[]    =   {   1   ,   1   ,   5   ,   1   ,   25  ,   15  ,   21  ,   113 ,   427 ,   249 ,   293 ,   1089    ,   1589    ,0 };
            const std::uint32_t dim612Kuo3Init[]    =   {   1   ,   1   ,   7   ,   5   ,   17  ,   11  ,   3   ,   211 ,   219 ,   37  ,   781 ,   1299    ,   3669    ,0 };
            const std::uint32_t dim613Kuo3Init[]    =   {   1   ,   3   ,   1   ,   15  ,   23  ,   3   ,   55  ,   59  ,   273 ,   947 ,   1647    ,   3111    ,   2615    ,0 };
            const std::uint32_t dim614Kuo3Init[]    =   {   1   ,   1   ,   3   ,   7   ,   21  ,   33  ,   81  ,   253 ,   267 ,   499 ,   299 ,   4015    ,   1669    ,0 };
            const std::uint32_t dim615Kuo3Init[]    =   {   1   ,   3   ,   7   ,   5   ,   5   ,   17  ,   75  ,   205 ,   53  ,   237 ,   1791    ,   3671    ,   4205    ,0 };
            const std::uint32_t dim616Kuo3Init[]    =   {   1   ,   3   ,   1   ,   5   ,   3   ,   59  ,   77  ,   39  ,   295 ,   649 ,   1219    ,   3971    ,   7675    ,0 };
            const std::uint32_t dim617Kuo3Init[]    =   {   1   ,   3   ,   5   ,   15  ,   1   ,   1   ,   13  ,   207 ,   445 ,   91  ,   571 ,   869 ,   359 ,0 };
            const std::uint32_t dim618Kuo3Init[]    =   {   1   ,   3   ,   5   ,   5   ,   15  ,   35  ,   79  ,   175 ,   313 ,   745 ,   1689    ,   1499    ,   5899    ,0 };
            const std::uint32_t dim619Kuo3Init[]    =   {   1   ,   3   ,   7   ,   7   ,   19  ,   51  ,   57  ,   131 ,   491 ,   301 ,   1405    ,   3789    ,   6081    ,0 };
            const std::uint32_t dim620Kuo3Init[]    =   {   1   ,   1   ,   3   ,   9   ,   27  ,   53  ,   55  ,   193 ,   413 ,   535 ,   715 ,   2823    ,   2063    ,0 };
            const std::uint32_t dim621Kuo3Init[]    =   {   1   ,   1   ,   7   ,   13  ,   31  ,   47  ,   47  ,   99  ,   441 ,   125 ,   999 ,   3575    ,   8007    ,0 };
            const std::uint32_t dim622Kuo3Init[]    =   {   1   ,   1   ,   1   ,   11  ,   17  ,   45  ,   67  ,   27  ,   329 ,   267 ,   773 ,   565 ,   5559    ,0 };
            const std::uint32_t dim623Kuo3Init[]    =   {   1   ,   1   ,   7   ,   11  ,   31  ,   23  ,   125 ,   117 ,   373 ,   523 ,   571 ,   1385    ,   3841    ,0 };
            const std::uint32_t dim624Kuo3Init[]    =   {   1   ,   3   ,   7   ,   15  ,   3   ,   15  ,   63  ,   91  ,   23  ,   97  ,   311 ,   3045    ,   2025    ,0 };
            const std::uint32_t dim625Kuo3Init[]    =   {   1   ,   3   ,   7   ,   5   ,   29  ,   37  ,   105 ,   63  ,   511 ,   35  ,   537 ,   4047    ,   7449    ,0 };
            const std::uint32_t dim626Kuo3Init[]    =   {   1   ,   3   ,   1   ,   13  ,   5   ,   9   ,   29  ,   51  ,   269 ,   395 ,   1737    ,   2097    ,   199 ,0 };
            const std::uint32_t dim627Kuo3Init[]    =   {   1   ,   3   ,   7   ,   15  ,   23  ,   33  ,   71  ,   111 ,   497 ,   369 ,   1265    ,   2937    ,   1883    ,0 };
            const std::uint32_t dim628Kuo3Init[]    =   {   1   ,   1   ,   3   ,   3   ,   3   ,   49  ,   117 ,   243 ,   57  ,   83  ,   3   ,   3319    ,   5711    ,0 };
            const std::uint32_t dim629Kuo3Init[]    =   {   1   ,   1   ,   5   ,   11  ,   25  ,   41  ,   29  ,   123 ,   405 ,   623 ,   1537    ,   3467    ,   699 ,0 };
            const std::uint32_t dim630Kuo3Init[]    =   {   1   ,   3   ,   7   ,   13  ,   17  ,   5   ,   87  ,   103 ,   501 ,   581 ,   713 ,   1535    ,   4637    ,0 };
            const std::uint32_t dim631Kuo3Init[]    =   {   1   ,   3   ,   3   ,   3   ,   25  ,   59  ,   91  ,   241 ,   163 ,   537 ,   1249    ,   3427    ,   6647    ,0 };
            const std::uint32_t dim632Kuo3Init[]    =   {   1   ,   3   ,   7   ,   1   ,   27  ,   7   ,   49  ,   219 ,   51  ,   989 ,   599 ,   2593    ,   6051    ,0 };
            const std::uint32_t dim633Kuo3Init[]    =   {   1   ,   1   ,   7   ,   9   ,   17  ,   19  ,   31  ,   23  ,   199 ,   729 ,   819 ,   287 ,   4689    ,0 };
            const std::uint32_t dim634Kuo3Init[]    =   {   1   ,   1   ,   1   ,   11  ,   13  ,   49  ,   97  ,   229 ,   411 ,   29  ,   1815    ,   3761    ,   3849    ,0 };
            const std::uint32_t dim635Kuo3Init[]    =   {   1   ,   3   ,   1   ,   1   ,   23  ,   35  ,   15  ,   33  ,   3   ,   865 ,   995 ,   1263    ,   3779    ,0 };
            const std::uint32_t dim636Kuo3Init[]    =   {   1   ,   1   ,   7   ,   7   ,   17  ,   1   ,   103 ,   117 ,   455 ,   93  ,   599 ,   1075    ,   4389    ,0 };
            const std::uint32_t dim637Kuo3Init[]    =   {   1   ,   3   ,   7   ,   5   ,   27  ,   3   ,   67  ,   117 ,   101 ,   443 ,   1773    ,   3731    ,   629 ,0 };
            const std::uint32_t dim638Kuo3Init[]    =   {   1   ,   3   ,   1   ,   11  ,   9   ,   51  ,   63  ,   217 ,   273 ,   425 ,   1889    ,   1113    ,   3799    ,0 };
            const std::uint32_t dim639Kuo3Init[]    =   {   1   ,   1   ,   3   ,   3   ,   25  ,   13  ,   37  ,   89  ,   429 ,   493 ,   637 ,   3287    ,   6733    ,0 };
            const std::uint32_t dim640Kuo3Init[]    =   {   1   ,   1   ,   1   ,   9   ,   17  ,   29  ,   45  ,   89  ,   141 ,   633 ,   243 ,   4035    ,   1835    ,0 };
            const std::uint32_t dim641Kuo3Init[]    =   {   1   ,   1   ,   1   ,   9   ,   15  ,   41  ,   61  ,   239 ,   349 ,   3   ,   1669    ,   1767    ,   6257    ,0 };
            const std::uint32_t dim642Kuo3Init[]    =   {   1   ,   3   ,   5   ,   11  ,   21  ,   41  ,   17  ,   65  ,   495 ,   879 ,   1891    ,   667 ,   3807    ,0 };
            const std::uint32_t dim643Kuo3Init[]    =   {   1   ,   1   ,   5   ,   11  ,   7   ,   25  ,   101 ,   231 ,   159 ,   287 ,   1125    ,   3859    ,   4331    ,0 };
            const std::uint32_t dim644Kuo3Init[]    =   {   1   ,   1   ,   1   ,   9   ,   13  ,   59  ,   23  ,   85  ,   393 ,   611 ,   1213    ,   7   ,   5707    ,0 };
            const std::uint32_t dim645Kuo3Init[]    =   {   1   ,   3   ,   5   ,   15  ,   13  ,   33  ,   61  ,   255 ,   163 ,   465 ,   641 ,   703 ,   6391    ,0 };
            const std::uint32_t dim646Kuo3Init[]    =   {   1   ,   1   ,   3   ,   3   ,   29  ,   41  ,   25  ,   19  ,   247 ,   973 ,   1815    ,   235 ,   7215    ,0 };
            const std::uint32_t dim647Kuo3Init[]    =   {   1   ,   1   ,   3   ,   11  ,   17  ,   43  ,   83  ,   105 ,   493 ,   663 ,   1395    ,   1079    ,   745 ,0 };
            const std::uint32_t dim648Kuo3Init[]    =   {   1   ,   1   ,   3   ,   13  ,   17  ,   53  ,   5   ,   55  ,   31  ,   459 ,   673 ,   1253    ,   5601    ,0 };
            const std::uint32_t dim649Kuo3Init[]    =   {   1   ,   3   ,   7   ,   7   ,   1   ,   49  ,   85  ,   73  ,   265 ,   555 ,   43  ,   2235    ,   6787    ,0 };
            const std::uint32_t dim650Kuo3Init[]    =   {   1   ,   1   ,   7   ,   5   ,   15  ,   3   ,   43  ,   201 ,   289 ,   755 ,   1605    ,   1927    ,   6179    ,0 };
            const std::uint32_t dim651Kuo3Init[]    =   {   1   ,   1   ,   7   ,   9   ,   15  ,   5   ,   101 ,   19  ,   17  ,   879 ,   1155    ,   3845    ,   3225    ,0 };
            const std::uint32_t dim652Kuo3Init[]    =   {   1   ,   3   ,   5   ,   15  ,   15  ,   63  ,   103 ,   133 ,   209 ,   121 ,   1865    ,   4039    ,   3335    ,0 };
            const std::uint32_t dim653Kuo3Init[]    =   {   1   ,   3   ,   7   ,   11  ,   15  ,   51  ,   87  ,   241 ,   455 ,   431 ,   1111    ,   1319    ,   1959    ,0 };
            const std::uint32_t dim654Kuo3Init[]    =   {   1   ,   3   ,   7   ,   5   ,   21  ,   47  ,   67  ,   251 ,   91  ,   575 ,   481 ,   3269    ,   1473    ,0 };
            const std::uint32_t dim655Kuo3Init[]    =   {   1   ,   3   ,   1   ,   1   ,   23  ,   5   ,   37  ,   169 ,   105 ,   803 ,   1765    ,   1823    ,   5081    ,0 };
            const std::uint32_t dim656Kuo3Init[]    =   {   1   ,   1   ,   7   ,   9   ,   1   ,   37  ,   55  ,   175 ,   431 ,   77  ,   171 ,   3759    ,   1227    ,0 };
            const std::uint32_t dim657Kuo3Init[]    =   {   1   ,   3   ,   7   ,   9   ,   3   ,   61  ,   111 ,   139 ,   87  ,   649 ,   243 ,   1109    ,   1303    ,0 };
            const std::uint32_t dim658Kuo3Init[]    =   {   1   ,   3   ,   1   ,   11  ,   17  ,   25  ,   9   ,   117 ,   227 ,   821 ,   1219    ,   2567    ,   5851    ,0 };
            const std::uint32_t dim659Kuo3Init[]    =   {   1   ,   1   ,   7   ,   1   ,   19  ,   53  ,   89  ,   57  ,   29  ,   885 ,   275 ,   2289    ,   4341    ,0 };
            const std::uint32_t dim660Kuo3Init[]    =   {   1   ,   3   ,   1   ,   5   ,   5   ,   1   ,   43  ,   237 ,   235 ,   667 ,   1433    ,   2497    ,   5535    ,0 };
            const std::uint32_t dim661Kuo3Init[]    =   {   1   ,   1   ,   1   ,   11  ,   21  ,   9   ,   29  ,   165 ,   153 ,   157 ,   1209    ,   817 ,   7819    ,0 };
            const std::uint32_t dim662Kuo3Init[]    =   {   1   ,   3   ,   1   ,   5   ,   1   ,   37  ,   33  ,   9   ,   493 ,   497 ,   1469    ,   357 ,   5929    ,0 };
            const std::uint32_t dim663Kuo3Init[]    =   {   1   ,   3   ,   3   ,   9   ,   25  ,   55  ,   5   ,   157 ,   397 ,   461 ,   537 ,   1085    ,   6737    ,0 };
            const std::uint32_t dim664Kuo3Init[]    =   {   1   ,   3   ,   3   ,   13  ,   3   ,   61  ,   83  ,   5   ,   5   ,   243 ,   1745    ,   845 ,   1965    ,0 };
            const std::uint32_t dim665Kuo3Init[]    =   {   1   ,   3   ,   1   ,   3   ,   31  ,   63  ,   3   ,   75  ,   355 ,   799 ,   417 ,   791 ,   2763    ,0 };
            const std::uint32_t dim666Kuo3Init[]    =   {   1   ,   3   ,   3   ,   11  ,   5   ,   31  ,   99  ,   163 ,   69  ,   699 ,   809 ,   1651    ,   7249    ,0 };
            const std::uint32_t dim667Kuo3Init[]    =   {   1   ,   1   ,   7   ,   3   ,   29  ,   53  ,   51  ,   185 ,   379 ,   743 ,   611 ,   963 ,   5631    ,0 };
            const std::uint32_t dim668Kuo3Init[]    =   {   1   ,   1   ,   5   ,   11  ,   21  ,   15  ,   59  ,   75  ,   121 ,   247 ,   307 ,   2483    ,   2861    ,0 };
            const std::uint32_t dim669Kuo3Init[]    =   {   1   ,   1   ,   1   ,   5   ,   21  ,   5   ,   33  ,   43  ,   225 ,   675 ,   213 ,   3081    ,   5047    ,0 };
            const std::uint32_t dim670Kuo3Init[]    =   {   1   ,   3   ,   3   ,   15  ,   29  ,   45  ,   19  ,   19  ,   15  ,   605 ,   1531    ,   1305    ,   7725    ,0 };
            const std::uint32_t dim671Kuo3Init[]    =   {   1   ,   3   ,   1   ,   5   ,   19  ,   21  ,   73  ,   131 ,   37  ,   667 ,   1953    ,   1211    ,   7499    ,0 };
            const std::uint32_t dim672Kuo3Init[]    =   {   1   ,   3   ,   1   ,   5   ,   13  ,   3   ,   105 ,   151 ,   131 ,   965 ,   1953    ,   335 ,   4991    ,0 };
            const std::uint32_t dim673Kuo3Init[]    =   {   1   ,   3   ,   1   ,   13  ,   23  ,   37  ,   81  ,   147 ,   353 ,   125 ,   141 ,   4017    ,   7543    ,0 };
            const std::uint32_t dim674Kuo3Init[]    =   {   1   ,   1   ,   1   ,   7   ,   15  ,   13  ,   25  ,   107 ,   431 ,   327 ,   1069    ,   155 ,   1729    ,0 };
            const std::uint32_t dim675Kuo3Init[]    =   {   1   ,   1   ,   5   ,   1   ,   19  ,   3   ,   51  ,   113 ,   349 ,   845 ,   1157    ,   1771    ,   4923    ,0 };
            const std::uint32_t dim676Kuo3Init[]    =   {   1   ,   1   ,   3   ,   7   ,   17  ,   19  ,   47  ,   249 ,   215 ,   959 ,   659 ,   3989    ,   3719    ,0 };
            const std::uint32_t dim677Kuo3Init[]    =   {   1   ,   3   ,   5   ,   5   ,   27  ,   57  ,   41  ,   29  ,   153 ,   1007    ,   1209    ,   1373    ,   2847    ,0 };
            const std::uint32_t dim678Kuo3Init[]    =   {   1   ,   3   ,   5   ,   7   ,   5   ,   21  ,   23  ,   67  ,   127 ,   755 ,   211 ,   2517    ,   8161    ,0 };
            const std::uint32_t dim679Kuo3Init[]    =   {   1   ,   1   ,   7   ,   15  ,   1   ,   5   ,   65  ,   197 ,   435 ,   275 ,   473 ,   1333    ,   3669    ,0 };
            const std::uint32_t dim680Kuo3Init[]    =   {   1   ,   3   ,   7   ,   1   ,   17  ,   19  ,   61  ,   11  ,   425 ,   717 ,   351 ,   2323    ,   6575    ,0 };
            const std::uint32_t dim681Kuo3Init[]    =   {   1   ,   1   ,   7   ,   3   ,   29  ,   13  ,   115 ,   19  ,   235 ,   371 ,   81  ,   3107    ,   3103    ,0 };
            const std::uint32_t dim682Kuo3Init[]    =   {   1   ,   1   ,   3   ,   1   ,   23  ,   19  ,   57  ,   179 ,   7   ,   405 ,   217 ,   3159    ,   6675    ,0 };
            const std::uint32_t dim683Kuo3Init[]    =   {   1   ,   3   ,   3   ,   3   ,   19  ,   39  ,   121 ,   195 ,   205 ,   489 ,   1959    ,   3617    ,   799 ,0 };
            const std::uint32_t dim684Kuo3Init[]    =   {   1   ,   3   ,   5   ,   9   ,   19  ,   35  ,   115 ,   3   ,   17  ,   201 ,   671 ,   1847    ,   597 ,0 };
            const std::uint32_t dim685Kuo3Init[]    =   {   1   ,   3   ,   1   ,   3   ,   7   ,   1   ,   121 ,   77  ,   163 ,   769 ,   977 ,   1223    ,   4215    ,0 };
            const std::uint32_t dim686Kuo3Init[]    =   {   1   ,   1   ,   1   ,   15  ,   9   ,   13  ,   33  ,   57  ,   271 ,   733 ,   1699    ,   3083    ,   813 ,0 };
            const std::uint32_t dim687Kuo3Init[]    =   {   1   ,   1   ,   7   ,   7   ,   15  ,   49  ,   101 ,   183 ,   339 ,   129 ,   1865    ,   2697    ,   3131    ,0 };
            const std::uint32_t dim688Kuo3Init[]    =   {   1   ,   3   ,   1   ,   3   ,   9   ,   39  ,   33  ,   141 ,   459 ,   971 ,   1621    ,   3893    ,   4393    ,0 };
            const std::uint32_t dim689Kuo3Init[]    =   {   1   ,   1   ,   3   ,   3   ,   27  ,   61  ,   53  ,   79  ,   375 ,   613 ,   663 ,   2325    ,   4707    ,0 };
            const std::uint32_t dim690Kuo3Init[]    =   {   1   ,   1   ,   7   ,   1   ,   27  ,   59  ,   59  ,   179 ,   173 ,   333 ,   649 ,   1053    ,   555 ,0 };
            const std::uint32_t dim691Kuo3Init[]    =   {   1   ,   3   ,   3   ,   13  ,   15  ,   55  ,   25  ,   91  ,   45  ,   739 ,   1769    ,   1341    ,   2007    ,0 };
            const std::uint32_t dim692Kuo3Init[]    =   {   1   ,   1   ,   3   ,   15  ,   9   ,   59  ,   27  ,   45  ,   133 ,   941 ,   1037    ,   1559    ,   7145    ,0 };
            const std::uint32_t dim693Kuo3Init[]    =   {   1   ,   3   ,   5   ,   1   ,   13  ,   5   ,   3   ,   167 ,   235 ,   609 ,   1023    ,   1967    ,   771 ,0 };
            const std::uint32_t dim694Kuo3Init[]    =   {   1   ,   1   ,   1   ,   15  ,   19  ,   15  ,   45  ,   143 ,   309 ,   697 ,   337 ,   3399    ,   3599    ,0 };
            const std::uint32_t dim695Kuo3Init[]    =   {   1   ,   1   ,   5   ,   3   ,   9   ,   1   ,   19  ,   41  ,   39  ,   1003    ,   997 ,   1357    ,   5849    ,0 };
            const std::uint32_t dim696Kuo3Init[]    =   {   1   ,   3   ,   3   ,   7   ,   29  ,   37  ,   9   ,   165 ,   9   ,   855 ,   337 ,   2363    ,   2633    ,0 };
            const std::uint32_t dim697Kuo3Init[]    =   {   1   ,   3   ,   5   ,   1   ,   23  ,   19  ,   97  ,   55  ,   411 ,   623 ,   287 ,   3365    ,   7675    ,0 };
            const std::uint32_t dim698Kuo3Init[]    =   {   1   ,   3   ,   3   ,   3   ,   11  ,   1   ,   47  ,   81  ,   377 ,   85  ,   859 ,   3717    ,   1979    ,0 };
            const std::uint32_t dim699Kuo3Init[]    =   {   1   ,   1   ,   3   ,   1   ,   11  ,   3   ,   125 ,   43  ,   471 ,   127 ,   341 ,   2943    ,   231 ,0 };
            const std::uint32_t dim700Kuo3Init[]    =   {   1   ,   1   ,   5   ,   15  ,   29  ,   21  ,   101 ,   193 ,   389 ,   727 ,   1397    ,   2799    ,   4387    ,0 };
            const std::uint32_t dim701Kuo3Init[]    =   {   1   ,   3   ,   5   ,   15  ,   27  ,   19  ,   13  ,   195 ,   105 ,   5   ,   985 ,   767 ,   4573    ,0 };
            const std::uint32_t dim702Kuo3Init[]    =   {   1   ,   1   ,   5   ,   3   ,   13  ,   29  ,   33  ,   123 ,   107 ,   353 ,   723 ,   3821    ,   5425    ,0 };
            const std::uint32_t dim703Kuo3Init[]    =   {   1   ,   3   ,   5   ,   11  ,   23  ,   11  ,   69  ,   219 ,   15  ,   735 ,   1015    ,   431 ,   6511    ,0 };
            const std::uint32_t dim704Kuo3Init[]    =   {   1   ,   3   ,   1   ,   1   ,   27  ,   49  ,   79  ,   91  ,   201 ,   365 ,   255 ,   1309    ,   7165    ,0 };
            const std::uint32_t dim705Kuo3Init[]    =   {   1   ,   3   ,   1   ,   13  ,   21  ,   61  ,   39  ,   111 ,   71  ,   137 ,   551 ,   3237    ,   6681    ,0 };
            const std::uint32_t dim706Kuo3Init[]    =   {   1   ,   3   ,   5   ,   13  ,   19  ,   21  ,   121 ,   227 ,   381 ,   677 ,   421 ,   449 ,   5375    ,0 };
            const std::uint32_t dim707Kuo3Init[]    =   {   1   ,   1   ,   7   ,   5   ,   1   ,   23  ,   95  ,   199 ,   509 ,   197 ,   829 ,   941 ,   2269    ,0 };
            const std::uint32_t dim708Kuo3Init[]    =   {   1   ,   3   ,   7   ,   5   ,   21  ,   61  ,   119 ,   59  ,   97  ,   841 ,   453 ,   2439    ,   7345    ,0 };
            const std::uint32_t dim709Kuo3Init[]    =   {   1   ,   1   ,   1   ,   3   ,   23  ,   21  ,   19  ,   245 ,   281 ,   841 ,   273 ,   1967    ,   2129    ,0 };
            const std::uint32_t dim710Kuo3Init[]    =   {   1   ,   3   ,   3   ,   5   ,   7   ,   43  ,   19  ,   253 ,   239 ,   421 ,   461 ,   4023    ,   6981    ,0 };
            const std::uint32_t dim711Kuo3Init[]    =   {   1   ,   3   ,   1   ,   11  ,   25  ,   3   ,   109 ,   107 ,   55  ,   781 ,   1109    ,   101 ,   889 ,0 };
            const std::uint32_t dim712Kuo3Init[]    =   {   1   ,   3   ,   7   ,   13  ,   1   ,   21  ,   27  ,   3   ,   303 ,   557 ,   1381    ,   407 ,   1849    ,0 };
            const std::uint32_t dim713Kuo3Init[]    =   {   1   ,   1   ,   3   ,   13  ,   3   ,   61  ,   121 ,   119 ,   453 ,   137 ,   2039    ,   3333    ,   333 ,0 };
            const std::uint32_t dim714Kuo3Init[]    =   {   1   ,   3   ,   5   ,   1   ,   21  ,   9   ,   113 ,   9   ,   413 ,   301 ,   1795    ,   2827    ,   1837    ,0 };
            const std::uint32_t dim715Kuo3Init[]    =   {   1   ,   3   ,   5   ,   15  ,   13  ,   31  ,   119 ,   107 ,   445 ,   277 ,   1555    ,   2121    ,   2173    ,0 };
            const std::uint32_t dim716Kuo3Init[]    =   {   1   ,   1   ,   1   ,   5   ,   9   ,   5   ,   5   ,   97  ,   191 ,   949 ,   1603    ,   2181    ,   6879    ,0 };
            const std::uint32_t dim717Kuo3Init[]    =   {   1   ,   3   ,   3   ,   9   ,   5   ,   47  ,   77  ,   43  ,   483 ,   137 ,   61  ,   1811    ,   5309    ,0 };
            const std::uint32_t dim718Kuo3Init[]    =   {   1   ,   3   ,   7   ,   11  ,   25  ,   63  ,   107 ,   207 ,   23  ,   231 ,   1685    ,   4009    ,   391 ,0 };
            const std::uint32_t dim719Kuo3Init[]    =   {   1   ,   3   ,   7   ,   9   ,   3   ,   35  ,   119 ,   83  ,   193 ,   269 ,   289 ,   3051    ,   8137    ,0 };
            const std::uint32_t dim720Kuo3Init[]    =   {   1   ,   3   ,   3   ,   11  ,   25  ,   25  ,   17  ,   243 ,   195 ,   503 ,   1797    ,   1913    ,   749 ,0 };
            const std::uint32_t dim721Kuo3Init[]    =   {   1   ,   3   ,   1   ,   13  ,   5   ,   35  ,   101 ,   57  ,   185 ,   881 ,   2005    ,   3493    ,   2715    ,0 };
            const std::uint32_t dim722Kuo3Init[]    =   {   1   ,   3   ,   1   ,   11  ,   25  ,   51  ,   113 ,   177 ,   175 ,   855 ,   1727    ,   1901    ,   8181    ,0 };
            const std::uint32_t dim723Kuo3Init[]    =   {   1   ,   1   ,   3   ,   9   ,   9   ,   63  ,   109 ,   233 ,   205 ,   357 ,   499 ,   3367    ,   1189    ,0 };
            const std::uint32_t dim724Kuo3Init[]    =   {   1   ,   3   ,   1   ,   15  ,   17  ,   11  ,   35  ,   135 ,   501 ,   319 ,   1465    ,   2095    ,   5269    ,0 };
            const std::uint32_t dim725Kuo3Init[]    =   {   1   ,   1   ,   3   ,   9   ,   1   ,   27  ,   99  ,   201 ,   67  ,   269 ,   135 ,   3891    ,   4067    ,0 };
            const std::uint32_t dim726Kuo3Init[]    =   {   1   ,   1   ,   1   ,   9   ,   15  ,   37  ,   83  ,   135 ,   3   ,   645 ,   499 ,   2597    ,   2705    ,0 };
            const std::uint32_t dim727Kuo3Init[]    =   {   1   ,   3   ,   1   ,   7   ,   17  ,   33  ,   89  ,   51  ,   295 ,   809 ,   743 ,   27  ,   2599    ,0 };
            const std::uint32_t dim728Kuo3Init[]    =   {   1   ,   1   ,   7   ,   1   ,   5   ,   55  ,   11  ,   97  ,   177 ,   515 ,   1651    ,   1183    ,   5803    ,0 };
            const std::uint32_t dim729Kuo3Init[]    =   {   1   ,   1   ,   3   ,   11  ,   21  ,   3   ,   39  ,   249 ,   55  ,   891 ,   1681    ,   709 ,   7833    ,0 };
            const std::uint32_t dim730Kuo3Init[]    =   {   1   ,   3   ,   5   ,   13  ,   11  ,   21  ,   81  ,   21  ,   99  ,   223 ,   355 ,   2015    ,   7195    ,0 };
            const std::uint32_t dim731Kuo3Init[]    =   {   1   ,   3   ,   7   ,   11  ,   25  ,   23  ,   9   ,   131 ,   417 ,   583 ,   1927    ,   277 ,   2923    ,0 };
            const std::uint32_t dim732Kuo3Init[]    =   {   1   ,   1   ,   5   ,   5   ,   1   ,   43  ,   35  ,   87  ,   471 ,   499 ,   1411    ,   2867    ,   2477    ,0 };
            const std::uint32_t dim733Kuo3Init[]    =   {   1   ,   1   ,   5   ,   9   ,   25  ,   43  ,   83  ,   103 ,   183 ,   527 ,   483 ,   935 ,   7097    ,0 };
            const std::uint32_t dim734Kuo3Init[]    =   {   1   ,   1   ,   5   ,   7   ,   31  ,   13  ,   49  ,   169 ,   135 ,   885 ,   1367    ,   2627    ,   5917    ,0 };
            const std::uint32_t dim735Kuo3Init[]    =   {   1   ,   3   ,   7   ,   5   ,   1   ,   39  ,   97  ,   167 ,   95  ,   745 ,   1067    ,   805 ,   2885    ,0 };
            const std::uint32_t dim736Kuo3Init[]    =   {   1   ,   3   ,   7   ,   15  ,   31  ,   41  ,   1   ,   147 ,   15  ,   795 ,   323 ,   309 ,   5075    ,0 };
            const std::uint32_t dim737Kuo3Init[]    =   {   1   ,   3   ,   7   ,   5   ,   23  ,   3   ,   65  ,   143 ,   183 ,   671 ,   993 ,   547 ,   5971    ,0 };
            const std::uint32_t dim738Kuo3Init[]    =   {   1   ,   3   ,   7   ,   1   ,   21  ,   59  ,   29  ,   45  ,   367 ,   363 ,   1707    ,   541 ,   7045    ,0 };
            const std::uint32_t dim739Kuo3Init[]    =   {   1   ,   1   ,   7   ,   15  ,   11  ,   25  ,   77  ,   33  ,   409 ,   495 ,   1713    ,   1479    ,   2857    ,0 };
            const std::uint32_t dim740Kuo3Init[]    =   {   1   ,   1   ,   3   ,   1   ,   11  ,   59  ,   113 ,   217 ,   313 ,   79  ,   379 ,   627 ,   3917    ,0 };
            const std::uint32_t dim741Kuo3Init[]    =   {   1   ,   1   ,   1   ,   15  ,   31  ,   61  ,   73  ,   211 ,   419 ,   965 ,   1817    ,   3965    ,   1425    ,0 };
            const std::uint32_t dim742Kuo3Init[]    =   {   1   ,   1   ,   7   ,   13  ,   9   ,   9   ,   61  ,   119 ,   223 ,   387 ,   595 ,   191 ,   1723    ,0 };
            const std::uint32_t dim743Kuo3Init[]    =   {   1   ,   3   ,   5   ,   3   ,   25  ,   49  ,   83  ,   175 ,   329 ,   1003    ,   729 ,   1399    ,   6553    ,0 };
            const std::uint32_t dim744Kuo3Init[]    =   {   1   ,   1   ,   5   ,   9   ,   5   ,   37  ,   31  ,   43  ,   365 ,   403 ,   1485    ,   1621    ,   3753    ,0 };
            const std::uint32_t dim745Kuo3Init[]    =   {   1   ,   3   ,   5   ,   7   ,   17  ,   5   ,   125 ,   219 ,   311 ,   1   ,   639 ,   1939    ,   4367    ,0 };
            const std::uint32_t dim746Kuo3Init[]    =   {   1   ,   3   ,   5   ,   3   ,   21  ,   63  ,   119 ,   31  ,   151 ,   325 ,   1063    ,   2477    ,   1223    ,0 };
            const std::uint32_t dim747Kuo3Init[]    =   {   1   ,   1   ,   5   ,   13  ,   15  ,   23  ,   1   ,   141 ,   105 ,   21  ,   747 ,   161 ,   3555    ,0 };
            const std::uint32_t dim748Kuo3Init[]    =   {   1   ,   3   ,   7   ,   1   ,   31  ,   21  ,   11  ,   27  ,   267 ,   205 ,   1569    ,   765 ,   1357    ,0 };
            const std::uint32_t dim749Kuo3Init[]    =   {   1   ,   1   ,   3   ,   9   ,   23  ,   59  ,   93  ,   51  ,   81  ,   367 ,   1545    ,   1161    ,   3481    ,0 };
            const std::uint32_t dim750Kuo3Init[]    =   {   1   ,   3   ,   7   ,   11  ,   15  ,   51  ,   43  ,   205 ,   237 ,   617 ,   1075    ,   1051    ,   5285    ,0 };
            const std::uint32_t dim751Kuo3Init[]    =   {   1   ,   3   ,   7   ,   3   ,   11  ,   5   ,   95  ,   203 ,   495 ,   661 ,   1119    ,   1095    ,   3391    ,0 };
            const std::uint32_t dim752Kuo3Init[]    =   {   1   ,   3   ,   3   ,   1   ,   25  ,   39  ,   59  ,   159 ,   273 ,   101 ,   1887    ,   417 ,   3423    ,0 };
            const std::uint32_t dim753Kuo3Init[]    =   {   1   ,   3   ,   5   ,   13  ,   23  ,   45  ,   13  ,   87  ,   139 ,   313 ,   1527    ,   3739    ,   7009    ,0 };
            const std::uint32_t dim754Kuo3Init[]    =   {   1   ,   1   ,   5   ,   1   ,   23  ,   43  ,   127 ,   149 ,   63  ,   823 ,   1075    ,   3123    ,   3079    ,0 };
            const std::uint32_t dim755Kuo3Init[]    =   {   1   ,   1   ,   7   ,   3   ,   11  ,   1   ,   29  ,   127 ,   313 ,   971 ,   1363    ,   1765    ,   6439    ,0 };
            const std::uint32_t dim756Kuo3Init[]    =   {   1   ,   1   ,   3   ,   13  ,   1   ,   19  ,   61  ,   125 ,   345 ,   51  ,   273 ,   2783    ,   5255    ,0 };
            const std::uint32_t dim757Kuo3Init[]    =   {   1   ,   1   ,   1   ,   7   ,   29  ,   33  ,   21  ,   239 ,   351 ,   481 ,   795 ,   2865    ,   2235    ,0 };
            const std::uint32_t dim758Kuo3Init[]    =   {   1   ,   3   ,   3   ,   3   ,   19  ,   31  ,   41  ,   125 ,   327 ,   169 ,   837 ,   753 ,   191 ,0 };
            const std::uint32_t dim759Kuo3Init[]    =   {   1   ,   3   ,   7   ,   15  ,   5   ,   15  ,   5   ,   109 ,   333 ,   127 ,   2021    ,   441 ,   6307    ,0 };
            const std::uint32_t dim760Kuo3Init[]    =   {   1   ,   3   ,   7   ,   9   ,   23  ,   39  ,   79  ,   235 ,   27  ,   573 ,   1989    ,   1401    ,   7597    ,0 };
            const std::uint32_t dim761Kuo3Init[]    =   {   1   ,   1   ,   7   ,   3   ,   23  ,   29  ,   119 ,   53  ,   105 ,   609 ,   1139    ,   321 ,   1111    ,0 };
            const std::uint32_t dim762Kuo3Init[]    =   {   1   ,   1   ,   7   ,   13  ,   13  ,   43  ,   3   ,   211 ,   389 ,   563 ,   1047    ,   1373    ,   4669    ,0 };
            const std::uint32_t dim763Kuo3Init[]    =   {   1   ,   3   ,   3   ,   1   ,   9   ,   7   ,   1   ,   135 ,   455 ,   539 ,   1681    ,   1851    ,   4585    ,0 };
            const std::uint32_t dim764Kuo3Init[]    =   {   1   ,   3   ,   1   ,   13  ,   19  ,   45  ,   65  ,   109 ,   391 ,   563 ,   753 ,   2405    ,   2623    ,0 };
            const std::uint32_t dim765Kuo3Init[]    =   {   1   ,   3   ,   1   ,   13  ,   31  ,   41  ,   29  ,   153 ,   507 ,   559 ,   877 ,   125 ,   4827    ,0 };
            const std::uint32_t dim766Kuo3Init[]    =   {   1   ,   1   ,   7   ,   3   ,   15  ,   53  ,   39  ,   1   ,   143 ,   351 ,   505 ,   1213    ,   4829    ,0 };
            const std::uint32_t dim767Kuo3Init[]    =   {   1   ,   1   ,   5   ,   5   ,   27  ,   49  ,   39  ,   101 ,   501 ,   239 ,   1233    ,   1695    ,   6929    ,0 };
            const std::uint32_t dim768Kuo3Init[]    =   {   1   ,   1   ,   5   ,   9   ,   13  ,   29  ,   103 ,   185 ,   343 ,   943 ,   1709    ,   801 ,   1227    ,0 };
            const std::uint32_t dim769Kuo3Init[]    =   {   1   ,   1   ,   1   ,   3   ,   3   ,   1   ,   63  ,   23  ,   199 ,   53  ,   1629    ,   325 ,   7609    ,0 };
            const std::uint32_t dim770Kuo3Init[]    =   {   1   ,   3   ,   7   ,   1   ,   11  ,   47  ,   61  ,   171 ,   71  ,   493 ,   2035    ,   869 ,   5925    ,0 };
            const std::uint32_t dim771Kuo3Init[]    =   {   1   ,   1   ,   7   ,   7   ,   5   ,   3   ,   95  ,   163 ,   89  ,   395 ,   1033    ,   2051    ,   5589    ,0 };
            const std::uint32_t dim772Kuo3Init[]    =   {   1   ,   3   ,   5   ,   9   ,   3   ,   21  ,   29  ,   143 ,   333 ,   805 ,   267 ,   4077    ,   383 ,0 };
            const std::uint32_t dim773Kuo3Init[]    =   {   1   ,   1   ,   3   ,   13  ,   9   ,   17  ,   87  ,   163 ,   107 ,   1011    ,   1099    ,   3395    ,   987 ,0 };
            const std::uint32_t dim774Kuo3Init[]    =   {   1   ,   3   ,   1   ,   1   ,   5   ,   51  ,   71  ,   249 ,   441 ,   513 ,   791 ,   1831    ,   2757    ,0 };
            const std::uint32_t dim775Kuo3Init[]    =   {   1   ,   1   ,   3   ,   13  ,   23  ,   7   ,   101 ,   211 ,   289 ,   1001    ,   1623    ,   3239    ,   1685    ,0 };
            const std::uint32_t dim776Kuo3Init[]    =   {   1   ,   1   ,   5   ,   15  ,   31  ,   53  ,   91  ,   245 ,   143 ,   237 ,   557 ,   3099    ,   3737    ,0 };
            const std::uint32_t dim777Kuo3Init[]    =   {   1   ,   3   ,   1   ,   1   ,   5   ,   27  ,   51  ,   173 ,   321 ,   85  ,   1385    ,   9   ,   1887    ,0 };
            const std::uint32_t dim778Kuo3Init[]    =   {   1   ,   3   ,   1   ,   15  ,   11  ,   17  ,   49  ,   97  ,   121 ,   189 ,   2031    ,   565 ,   7513    ,0 };
            const std::uint32_t dim779Kuo3Init[]    =   {   1   ,   1   ,   5   ,   5   ,   1   ,   3   ,   55  ,   157 ,   27  ,   783 ,   1543    ,   2645    ,   1079    ,0 };
            const std::uint32_t dim780Kuo3Init[]    =   {   1   ,   1   ,   5   ,   11  ,   27  ,   9   ,   83  ,   155 ,   17  ,   147 ,   1561    ,   3213    ,   4483    ,0 };
            const std::uint32_t dim781Kuo3Init[]    =   {   1   ,   3   ,   5   ,   15  ,   23  ,   63  ,   127 ,   97  ,   459 ,   869 ,   671 ,   3287    ,   995 ,0 };
            const std::uint32_t dim782Kuo3Init[]    =   {   1   ,   3   ,   3   ,   1   ,   5   ,   1   ,   89  ,   229 ,   269 ,   493 ,   709 ,   2719    ,   4803    ,0 };
            const std::uint32_t dim783Kuo3Init[]    =   {   1   ,   1   ,   3   ,   3   ,   27  ,   5   ,   85  ,   55  ,   491 ,   781 ,   711 ,   3193    ,   2051    ,0 };
            const std::uint32_t dim784Kuo3Init[]    =   {   1   ,   1   ,   5   ,   13  ,   21  ,   9   ,   31  ,   107 ,   381 ,   613 ,   991 ,   2289    ,   325 ,0 };
            const std::uint32_t dim785Kuo3Init[]    =   {   1   ,   3   ,   7   ,   11  ,   11  ,   47  ,   115 ,   103 ,   101 ,   945 ,   1993    ,   1345    ,   2031    ,0 };
            const std::uint32_t dim786Kuo3Init[]    =   {   1   ,   3   ,   7   ,   11  ,   27  ,   59  ,   123 ,   73  ,   85  ,   975 ,   397 ,   2619    ,   2095    ,0 };
            const std::uint32_t dim787Kuo3Init[]    =   {   1   ,   1   ,   1   ,   13  ,   19  ,   31  ,   87  ,   45  ,   39  ,   43  ,   1041    ,   2015    ,   5859    ,0 };
            const std::uint32_t dim788Kuo3Init[]    =   {   1   ,   1   ,   3   ,   15  ,   5   ,   19  ,   47  ,   193 ,   293 ,   961 ,   113 ,   3013    ,   889 ,0 };
            const std::uint32_t dim789Kuo3Init[]    =   {   1   ,   1   ,   1   ,   3   ,   31  ,   61  ,   61  ,   209 ,   493 ,   785 ,   1825    ,   3779    ,   8095    ,0 };
            const std::uint32_t dim790Kuo3Init[]    =   {   1   ,   1   ,   3   ,   9   ,   17  ,   51  ,   103 ,   255 ,   133 ,   165 ,   281 ,   3945    ,   2779    ,0 };
            const std::uint32_t dim791Kuo3Init[]    =   {   1   ,   1   ,   7   ,   3   ,   9   ,   33  ,   105 ,   29  ,   449 ,   231 ,   1393    ,   1071    ,   5043    ,0 };
            const std::uint32_t dim792Kuo3Init[]    =   {   1   ,   1   ,   7   ,   5   ,   29  ,   35  ,   115 ,   1   ,   467 ,   969 ,   343 ,   2291    ,   5099    ,0 };
            const std::uint32_t dim793Kuo3Init[]    =   {   1   ,   1   ,   3   ,   5   ,   13  ,   21  ,   99  ,   151 ,   13  ,   861 ,   189 ,   1709    ,   4943    ,0 };
            const std::uint32_t dim794Kuo3Init[]    =   {   1   ,   1   ,   7   ,   15  ,   5   ,   41  ,   53  ,   89  ,   235 ,   515 ,   1819    ,   3907    ,   4861    ,0 };
            const std::uint32_t dim795Kuo3Init[]    =   {   1   ,   3   ,   5   ,   1   ,   7   ,   15  ,   75  ,   65  ,   247 ,   581 ,   853 ,   445 ,   7623    ,0 };
            const std::uint32_t dim796Kuo3Init[]    =   {   1   ,   1   ,   3   ,   5   ,   25  ,   29  ,   27  ,   73  ,   359 ,   729 ,   1991    ,   1075    ,   8107    ,0 };
            const std::uint32_t dim797Kuo3Init[]    =   {   1   ,   1   ,   3   ,   1   ,   5   ,   35  ,   83  ,   119 ,   385 ,   657 ,   1085    ,   2707    ,   4403    ,0 };
            const std::uint32_t dim798Kuo3Init[]    =   {   1   ,   3   ,   5   ,   5   ,   25  ,   55  ,   51  ,   205 ,   257 ,   887 ,   827 ,   2795    ,   925 ,0 };
            const std::uint32_t dim799Kuo3Init[]    =   {   1   ,   1   ,   3   ,   1   ,   5   ,   29  ,   113 ,   195 ,   439 ,   241 ,   127 ,   2783    ,   2577    ,0 };
            const std::uint32_t dim800Kuo3Init[]    =   {   1   ,   3   ,   1   ,   11  ,   15  ,   47  ,   7   ,   149 ,   81  ,   897 ,   235 ,   3935    ,   6981    ,0 };
            const std::uint32_t dim801Kuo3Init[]    =   {   1   ,   3   ,   3   ,   1   ,   27  ,   5   ,   69  ,   125 ,   377 ,   829 ,   1549    ,   3025    ,   2319    ,0 };
            const std::uint32_t dim802Kuo3Init[]    =   {   1   ,   1   ,   7   ,   15  ,   15  ,   19  ,   3   ,   205 ,   291 ,   209 ,   1817    ,   2439    ,   1001    ,0 };
            const std::uint32_t dim803Kuo3Init[]    =   {   1   ,   1   ,   7   ,   9   ,   21  ,   7   ,   101 ,   17  ,   13  ,   615 ,   137 ,   1821    ,   1387    ,0 };
            const std::uint32_t dim804Kuo3Init[]    =   {   1   ,   3   ,   3   ,   11  ,   21  ,   27  ,   61  ,   133 ,   183 ,   699 ,   245 ,   527 ,   471 ,0 };
            const std::uint32_t dim805Kuo3Init[]    =   {   1   ,   3   ,   3   ,   13  ,   5   ,   25  ,   111 ,   69  ,   417 ,   271 ,   1545    ,   2729    ,   475 ,0 };
            const std::uint32_t dim806Kuo3Init[]    =   {   1   ,   3   ,   5   ,   15  ,   11  ,   47  ,   93  ,   93  ,   311 ,   775 ,   789 ,   1163    ,   1563    ,0 };
            const std::uint32_t dim807Kuo3Init[]    =   {   1   ,   3   ,   5   ,   1   ,   13  ,   63  ,   27  ,   113 ,   449 ,   971 ,   1021    ,   73  ,   1229    ,0 };
            const std::uint32_t dim808Kuo3Init[]    =   {   1   ,   3   ,   3   ,   15  ,   17  ,   37  ,   103 ,   13  ,   91  ,   823 ,   1767    ,   1295    ,   6941    ,0 };
            const std::uint32_t dim809Kuo3Init[]    =   {   1   ,   1   ,   3   ,   9   ,   15  ,   59  ,   125 ,   91  ,   195 ,   409 ,   65  ,   2873    ,   1921    ,0 };
            const std::uint32_t dim810Kuo3Init[]    =   {   1   ,   3   ,   1   ,   7   ,   17  ,   31  ,   21  ,   251 ,   145 ,   385 ,   1385    ,   1505    ,   5735    ,0 };
            const std::uint32_t dim811Kuo3Init[]    =   {   1   ,   3   ,   7   ,   11  ,   17  ,   19  ,   85  ,   85  ,   81  ,   583 ,   889 ,   669 ,   5187    ,0 };
            const std::uint32_t dim812Kuo3Init[]    =   {   1   ,   1   ,   5   ,   9   ,   23  ,   53  ,   97  ,   217 ,   129 ,   517 ,   271 ,   2967    ,   3937    ,0 };
            const std::uint32_t dim813Kuo3Init[]    =   {   1   ,   1   ,   1   ,   13  ,   3   ,   45  ,   49  ,   193 ,   35  ,   671 ,   1039    ,   2841    ,   4547    ,0 };
            const std::uint32_t dim814Kuo3Init[]    =   {   1   ,   3   ,   1   ,   15  ,   21  ,   29  ,   5   ,   91  ,   23  ,   247 ,   1701    ,   1585    ,   1493    ,0 };
            const std::uint32_t dim815Kuo3Init[]    =   {   1   ,   3   ,   3   ,   11  ,   15  ,   31  ,   21  ,   165 ,   153 ,   607 ,   221 ,   2781    ,   6159    ,0 };
            const std::uint32_t dim816Kuo3Init[]    =   {   1   ,   3   ,   7   ,   15  ,   15  ,   27  ,   107 ,   25  ,   457 ,   995 ,   849 ,   877 ,   407 ,0 };
            const std::uint32_t dim817Kuo3Init[]    =   {   1   ,   3   ,   1   ,   15  ,   7   ,   17  ,   37  ,   31  ,   203 ,   585 ,   369 ,   609 ,   2509    ,0 };
            const std::uint32_t dim818Kuo3Init[]    =   {   1   ,   3   ,   1   ,   11  ,   17  ,   5   ,   17  ,   71  ,   453 ,   171 ,   1317    ,   1985    ,   5817    ,0 };
            const std::uint32_t dim819Kuo3Init[]    =   {   1   ,   1   ,   5   ,   5   ,   23  ,   39  ,   123 ,   179 ,   49  ,   19  ,   1337    ,   1051    ,   5289    ,0 };
            const std::uint32_t dim820Kuo3Init[]    =   {   1   ,   3   ,   1   ,   13  ,   17  ,   43  ,   47  ,   139 ,   21  ,   851 ,   1253    ,   1939    ,   299 ,0 };
            const std::uint32_t dim821Kuo3Init[]    =   {   1   ,   1   ,   7   ,   1   ,   3   ,   35  ,   57  ,   115 ,   481 ,   653 ,   1975    ,   1319    ,   5225    ,0 };
            const std::uint32_t dim822Kuo3Init[]    =   {   1   ,   3   ,   7   ,   15  ,   5   ,   13  ,   3   ,   249 ,   21  ,   791 ,   1349    ,   1961    ,   6975    ,0 };
            const std::uint32_t dim823Kuo3Init[]    =   {   1   ,   1   ,   5   ,   11  ,   17  ,   3   ,   97  ,   103 ,   201 ,   313 ,   939 ,   693 ,   5397    ,0 };
            const std::uint32_t dim824Kuo3Init[]    =   {   1   ,   1   ,   7   ,   9   ,   29  ,   59  ,   35  ,   91  ,   135 ,   19  ,   1505    ,   1715    ,   3335    ,0 };
            const std::uint32_t dim825Kuo3Init[]    =   {   1   ,   3   ,   5   ,   1   ,   17  ,   53  ,   59  ,   217 ,   1   ,   305 ,   1257    ,   3773    ,   3509    ,0 };
            const std::uint32_t dim826Kuo3Init[]    =   {   1   ,   3   ,   7   ,   7   ,   5   ,   29  ,   47  ,   245 ,   487 ,   525 ,   1409    ,   245 ,   6427    ,0 };
            const std::uint32_t dim827Kuo3Init[]    =   {   1   ,   3   ,   5   ,   15  ,   25  ,   39  ,   49  ,   153 ,   461 ,   1003    ,   1527    ,   2883    ,   3499    ,0 };
            const std::uint32_t dim828Kuo3Init[]    =   {   1   ,   1   ,   7   ,   13  ,   23  ,   11  ,   15  ,   163 ,   9   ,   77  ,   1853    ,   1679    ,   1023    ,0 };
            const std::uint32_t dim829Kuo3Init[]    =   {   1   ,   3   ,   7   ,   13  ,   3   ,   55  ,   101 ,   229 ,   327 ,   537 ,   79  ,   3947    ,   6259    ,0 };
            const std::uint32_t dim830Kuo3Init[]    =   {   1   ,   3   ,   7   ,   5   ,   9   ,   39  ,   3   ,   151 ,   439 ,   181 ,   1473    ,   3613    ,   7425    ,0 };
            const std::uint32_t dim831Kuo3Init[]    =   {   1   ,   3   ,   7   ,   11  ,   21  ,   5   ,   53  ,   11  ,   39  ,   455 ,   1131    ,   393 ,   1525    ,0 };
            const std::uint32_t dim832Kuo3Init[]    =   {   1   ,   1   ,   1   ,   7   ,   5   ,   45  ,   49  ,   229 ,   173 ,   567 ,   1285    ,   2317    ,   2207    ,0 };
            const std::uint32_t dim833Kuo3Init[]    =   {   1   ,   1   ,   1   ,   7   ,   5   ,   33  ,   53  ,   241 ,   477 ,   161 ,   1607    ,   1253    ,   4497    ,0 };
            const std::uint32_t dim834Kuo3Init[]    =   {   1   ,   1   ,   7   ,   15  ,   11  ,   3   ,   107 ,   187 ,   249 ,   529 ,   905 ,   2883    ,   7777    ,0 };
            const std::uint32_t dim835Kuo3Init[]    =   {   1   ,   1   ,   5   ,   7   ,   17  ,   13  ,   123 ,   7   ,   449 ,   627 ,   1679    ,   569 ,   4145    ,0 };
            const std::uint32_t dim836Kuo3Init[]    =   {   1   ,   1   ,   1   ,   1   ,   3   ,   29  ,   57  ,   219 ,   209 ,   51  ,   1475    ,   2989    ,   7373    ,0 };
            const std::uint32_t dim837Kuo3Init[]    =   {   1   ,   3   ,   3   ,   5   ,   19  ,   33  ,   95  ,   241 ,   257 ,   465 ,   1305    ,   189 ,   269 ,0 };
            const std::uint32_t dim838Kuo3Init[]    =   {   1   ,   1   ,   3   ,   1   ,   13  ,   11  ,   67  ,   53  ,   157 ,   693 ,   1583    ,   739 ,   3827    ,0 };
            const std::uint32_t dim839Kuo3Init[]    =   {   1   ,   1   ,   3   ,   9   ,   17  ,   9   ,   5   ,   7   ,   421 ,   425 ,   1851    ,   3847    ,   5147    ,0 };
            const std::uint32_t dim840Kuo3Init[]    =   {   1   ,   1   ,   3   ,   3   ,   23  ,   47  ,   123 ,   215 ,   11  ,   643 ,   1543    ,   1859    ,   4073    ,0 };
            const std::uint32_t dim841Kuo3Init[]    =   {   1   ,   1   ,   1   ,   11  ,   5   ,   35  ,   79  ,   55  ,   225 ,   773 ,   1717    ,   2891    ,   563 ,0 };
            const std::uint32_t dim842Kuo3Init[]    =   {   1   ,   1   ,   1   ,   15  ,   5   ,   17  ,   115 ,   3   ,   107 ,   33  ,   1897    ,   3677    ,   4313    ,0 };
            const std::uint32_t dim843Kuo3Init[]    =   {   1   ,   1   ,   5   ,   7   ,   5   ,   57  ,   75  ,   65  ,   177 ,   269 ,   733 ,   3837    ,   1211    ,0 };
            const std::uint32_t dim844Kuo3Init[]    =   {   1   ,   1   ,   5   ,   15  ,   25  ,   45  ,   125 ,   159 ,   501 ,   17  ,   693 ,   1083    ,   1801    ,0 };
            const std::uint32_t dim845Kuo3Init[]    =   {   1   ,   3   ,   5   ,   3   ,   15  ,   17  ,   17  ,   159 ,   421 ,   449 ,   83  ,   1367    ,   7719    ,0 };
            const std::uint32_t dim846Kuo3Init[]    =   {   1   ,   3   ,   7   ,   3   ,   7   ,   31  ,   121 ,   43  ,   491 ,   501 ,   335 ,   2731    ,   1959    ,0 };
            const std::uint32_t dim847Kuo3Init[]    =   {   1   ,   1   ,   1   ,   11  ,   7   ,   1   ,   43  ,   187 ,   437 ,   113 ,   1205    ,   1255    ,   1319    ,0 };
            const std::uint32_t dim848Kuo3Init[]    =   {   1   ,   1   ,   5   ,   15  ,   15  ,   49  ,   103 ,   139 ,   187 ,   697 ,   907 ,   1229    ,   3205    ,0 };
            const std::uint32_t dim849Kuo3Init[]    =   {   1   ,   1   ,   5   ,   13  ,   9   ,   19  ,   25  ,   89  ,   345 ,   229 ,   1325    ,   859 ,   527 ,0 };
            const std::uint32_t dim850Kuo3Init[]    =   {   1   ,   1   ,   1   ,   3   ,   3   ,   63  ,   105 ,   11  ,   407 ,   131 ,   679 ,   3069    ,   4153    ,0 };
            const std::uint32_t dim851Kuo3Init[]    =   {   1   ,   1   ,   3   ,   11  ,   21  ,   27  ,   113 ,   59  ,   409 ,   845 ,   309 ,   2639    ,   129 ,0 };
            const std::uint32_t dim852Kuo3Init[]    =   {   1   ,   1   ,   5   ,   15  ,   21  ,   47  ,   55  ,   237 ,   201 ,   103 ,   331 ,   3531    ,   4965    ,0 };
            const std::uint32_t dim853Kuo3Init[]    =   {   1   ,   1   ,   5   ,   11  ,   9   ,   11  ,   85  ,   49  ,   209 ,   333 ,   1993    ,   511 ,   7347    ,0 };
            const std::uint32_t dim854Kuo3Init[]    =   {   1   ,   1   ,   5   ,   13  ,   25  ,   49  ,   109 ,   241 ,   297 ,   677 ,   313 ,   657 ,   4503    ,0 };
            const std::uint32_t dim855Kuo3Init[]    =   {   1   ,   1   ,   1   ,   15  ,   23  ,   57  ,   61  ,   117 ,   461 ,   559 ,   837 ,   2781    ,   709 ,0 };
            const std::uint32_t dim856Kuo3Init[]    =   {   1   ,   1   ,   3   ,   3   ,   31  ,   13  ,   109 ,   167 ,   389 ,   1021    ,   1437    ,   31  ,   811 ,0 };
            const std::uint32_t dim857Kuo3Init[]    =   {   1   ,   1   ,   1   ,   9   ,   21  ,   17  ,   19  ,   61  ,   241 ,   445 ,   1935    ,   3161    ,   4061    ,0 };
            const std::uint32_t dim858Kuo3Init[]    =   {   1   ,   3   ,   5   ,   5   ,   17  ,   5   ,   59  ,   117 ,   241 ,   913 ,   1315    ,   1597    ,   713 ,0 };
            const std::uint32_t dim859Kuo3Init[]    =   {   1   ,   3   ,   1   ,   15  ,   5   ,   41  ,   91  ,   191 ,   43  ,   49  ,   1491    ,   4051    ,   2317    ,0 };
            const std::uint32_t dim860Kuo3Init[]    =   {   1   ,   1   ,   1   ,   3   ,   13  ,   33  ,   53  ,   39  ,   341 ,   341 ,   617 ,   2627    ,   421 ,0 };
            const std::uint32_t dim861Kuo3Init[]    =   {   1   ,   3   ,   3   ,   15  ,   23  ,   25  ,   47  ,   251 ,   405 ,   659 ,   721 ,   229 ,   2269    ,0 };
            const std::uint32_t dim862Kuo3Init[]    =   {   1   ,   1   ,   3   ,   3   ,   25  ,   19  ,   123 ,   53  ,   59  ,   805 ,   2033    ,   1693    ,   6223    ,0 };
            const std::uint32_t dim863Kuo3Init[]    =   {   1   ,   1   ,   1   ,   3   ,   13  ,   45  ,   67  ,   67  ,   199 ,   925 ,   145 ,   775 ,   7923    ,0 };
            const std::uint32_t dim864Kuo3Init[]    =   {   1   ,   1   ,   5   ,   7   ,   17  ,   23  ,   49  ,   37  ,   185 ,   253 ,   1743    ,   2771    ,   6899    ,0 };
            const std::uint32_t dim865Kuo3Init[]    =   {   1   ,   3   ,   5   ,   5   ,   15  ,   53  ,   75  ,   185 ,   17  ,   379 ,   1091    ,   4029    ,   5399    ,0 };
            const std::uint32_t dim866Kuo3Init[]    =   {   1   ,   1   ,   1   ,   9   ,   13  ,   37  ,   101 ,   33  ,   499 ,   723 ,   57  ,   467 ,   7227    ,0 };
            const std::uint32_t dim867Kuo3Init[]    =   {   1   ,   1   ,   7   ,   1   ,   21  ,   49  ,   17  ,   49  ,   417 ,   895 ,   1099    ,   3199    ,   7059    ,0 };
            const std::uint32_t dim868Kuo3Init[]    =   {   1   ,   1   ,   5   ,   13  ,   27  ,   35  ,   49  ,   35  ,   213 ,   799 ,   197 ,   3599    ,   4135    ,0 };
            const std::uint32_t dim869Kuo3Init[]    =   {   1   ,   3   ,   5   ,   3   ,   31  ,   33  ,   61  ,   127 ,   87  ,   343 ,   845 ,   1699    ,   3897    ,0 };
            const std::uint32_t dim870Kuo3Init[]    =   {   1   ,   3   ,   1   ,   11  ,   7   ,   59  ,   19  ,   161 ,   119 ,   377 ,   1637    ,   2025    ,   849 ,0 };
            const std::uint32_t dim871Kuo3Init[]    =   {   1   ,   1   ,   3   ,   3   ,   3   ,   51  ,   3   ,   67  ,   77  ,   357 ,   295 ,   2383    ,   7423    ,0 };
            const std::uint32_t dim872Kuo3Init[]    =   {   1   ,   3   ,   1   ,   3   ,   23  ,   25  ,   67  ,   29  ,   433 ,   49  ,   901 ,   1641    ,   3021    ,0 };
            const std::uint32_t dim873Kuo3Init[]    =   {   1   ,   3   ,   7   ,   3   ,   25  ,   59  ,   15  ,   181 ,   193 ,   809 ,   1089    ,   423 ,   1629    ,0 };
            const std::uint32_t dim874Kuo3Init[]    =   {   1   ,   3   ,   5   ,   1   ,   3   ,   19  ,   53  ,   45  ,   277 ,   411 ,   455 ,   9   ,   3651    ,0 };
            const std::uint32_t dim875Kuo3Init[]    =   {   1   ,   3   ,   7   ,   15  ,   13  ,   33  ,   37  ,   15  ,   489 ,   275 ,   1113    ,   3371    ,   3915    ,0 };
            const std::uint32_t dim876Kuo3Init[]    =   {   1   ,   1   ,   5   ,   11  ,   3   ,   3   ,   97  ,   47  ,   471 ,   713 ,   1975    ,   1679    ,   7901    ,0 };
            const std::uint32_t dim877Kuo3Init[]    =   {   1   ,   1   ,   3   ,   15  ,   31  ,   47  ,   13  ,   33  ,   111 ,   607 ,   85  ,   4049    ,   2937    ,0 };
            const std::uint32_t dim878Kuo3Init[]    =   {   1   ,   1   ,   5   ,   1   ,   7   ,   61  ,   17  ,   179 ,   301 ,   245 ,   67  ,   2823    ,   4121    ,0 };
            const std::uint32_t dim879Kuo3Init[]    =   {   1   ,   3   ,   7   ,   15  ,   7   ,   25  ,   97  ,   73  ,   19  ,   899 ,   1357    ,   2041    ,   6493    ,0 };
            const std::uint32_t dim880Kuo3Init[]    =   {   1   ,   1   ,   1   ,   3   ,   3   ,   63  ,   117 ,   231 ,   125 ,   527 ,   1795    ,   1807    ,   7331    ,0 };
            const std::uint32_t dim881Kuo3Init[]    =   {   1   ,   1   ,   5   ,   11  ,   17  ,   35  ,   61  ,   161 ,   415 ,   687 ,   1015    ,   1239    ,   6925    ,0 };
            const std::uint32_t dim882Kuo3Init[]    =   {   1   ,   3   ,   3   ,   5   ,   15  ,   19  ,   1   ,   5   ,   209 ,   545 ,   1341    ,   4019    ,   6177    ,0 };
            const std::uint32_t dim883Kuo3Init[]    =   {   1   ,   3   ,   5   ,   15  ,   13  ,   3   ,   7   ,   39  ,   63  ,   727 ,   1033    ,   2551    ,   449 ,0 };
            const std::uint32_t dim884Kuo3Init[]    =   {   1   ,   1   ,   1   ,   5   ,   11  ,   35  ,   39  ,   143 ,   361 ,   659 ,   1407    ,   2399    ,   6421    ,0 };
            const std::uint32_t dim885Kuo3Init[]    =   {   1   ,   1   ,   7   ,   13  ,   3   ,   23  ,   21  ,   161 ,   153 ,   595 ,   1847    ,   1339    ,   1887    ,0 };
            const std::uint32_t dim886Kuo3Init[]    =   {   1   ,   3   ,   3   ,   9   ,   3   ,   43  ,   75  ,   45  ,   433 ,   811 ,   1045    ,   2773    ,   2415    ,0 };
            const std::uint32_t dim887Kuo3Init[]    =   {   1   ,   1   ,   3   ,   5   ,   23  ,   29  ,   73  ,   167 ,   211 ,   403 ,   539 ,   13  ,   4433    ,0 };
            const std::uint32_t dim888Kuo3Init[]    =   {   1   ,   3   ,   3   ,   13  ,   19  ,   25  ,   113 ,   181 ,   343 ,   349 ,   931 ,   115 ,   5687    ,0 };
            const std::uint32_t dim889Kuo3Init[]    =   {   1   ,   3   ,   1   ,   11  ,   25  ,   39  ,   23  ,   91  ,   359 ,   221 ,   37  ,   575 ,   3035    ,0 };
            const std::uint32_t dim890Kuo3Init[]    =   {   1   ,   1   ,   7   ,   1   ,   19  ,   61  ,   99  ,   81  ,   167 ,   53  ,   1493    ,   2623    ,   5797    ,0 };
            const std::uint32_t dim891Kuo3Init[]    =   {   1   ,   1   ,   3   ,   5   ,   13  ,   13  ,   105 ,   53  ,   449 ,   1003    ,   1405    ,   1403    ,   2557    ,0 };
            const std::uint32_t dim892Kuo3Init[]    =   {   1   ,   1   ,   3   ,   15  ,   1   ,   37  ,   51  ,   69  ,   13  ,   5   ,   1865    ,   3585    ,   3409    ,0 };
            const std::uint32_t dim893Kuo3Init[]    =   {   1   ,   1   ,   7   ,   13  ,   15  ,   31  ,   61  ,   53  ,   439 ,   665 ,   57  ,   445 ,   435 ,0 };
            const std::uint32_t dim894Kuo3Init[]    =   {   1   ,   3   ,   1   ,   3   ,   1   ,   27  ,   1   ,   155 ,   65  ,   191 ,   449 ,   2185    ,   1787    ,0 };
            const std::uint32_t dim895Kuo3Init[]    =   {   1   ,   1   ,   3   ,   11  ,   13  ,   59  ,   15  ,   43  ,   435 ,   477 ,   823 ,   717 ,   299 ,0 };
            const std::uint32_t dim896Kuo3Init[]    =   {   1   ,   1   ,   3   ,   1   ,   23  ,   9   ,   85  ,   155 ,   127 ,   543 ,   1081    ,   221 ,   7357    ,0 };
            const std::uint32_t dim897Kuo3Init[]    =   {   1   ,   3   ,   3   ,   1   ,   7   ,   35  ,   77  ,   9   ,   79  ,   283 ,   449 ,   2729    ,   4193    ,0 };
            const std::uint32_t dim898Kuo3Init[]    =   {   1   ,   1   ,   7   ,   1   ,   9   ,   15  ,   97  ,   99  ,   363 ,   513 ,   1063    ,   3051    ,   1529    ,0 };
            const std::uint32_t dim899Kuo3Init[]    =   {   1   ,   1   ,   5   ,   3   ,   1   ,   17  ,   101 ,   19  ,   425 ,   377 ,   1369    ,   3071    ,   6877    ,0 };
            const std::uint32_t dim900Kuo3Init[]    =   {   1   ,   1   ,   5   ,   1   ,   23  ,   63  ,   11  ,   7   ,   29  ,   717 ,   963 ,   2205    ,   7487    ,0 };
            const std::uint32_t dim901Kuo3Init[]    =   {   1   ,   3   ,   1   ,   13  ,   1   ,   15  ,   43  ,   151 ,   59  ,   315 ,   691 ,   2765    ,   7723    ,0 };
            const std::uint32_t dim902Kuo3Init[]    =   {   1   ,   3   ,   1   ,   5   ,   5   ,   31  ,   17  ,   81  ,   235 ,   419 ,   123 ,   2983    ,   1797    ,0 };
            const std::uint32_t dim903Kuo3Init[]    =   {   1   ,   1   ,   1   ,   11  ,   29  ,   17  ,   123 ,   115 ,   91  ,   531 ,   1393    ,   3537    ,   6387    ,0 };
            const std::uint32_t dim904Kuo3Init[]    =   {   1   ,   3   ,   5   ,   11  ,   31  ,   5   ,   107 ,   61  ,   463 ,   507 ,   1937    ,   4075    ,   4727    ,0 };
            const std::uint32_t dim905Kuo3Init[]    =   {   1   ,   3   ,   7   ,   1   ,   9   ,   27  ,   23  ,   97  ,   125 ,   511 ,   239 ,   1031    ,   153 ,0 };
            const std::uint32_t dim906Kuo3Init[]    =   {   1   ,   3   ,   5   ,   9   ,   13  ,   55  ,   53  ,   195 ,   265 ,   217 ,   357 ,   567 ,   1613    ,0 };
            const std::uint32_t dim907Kuo3Init[]    =   {   1   ,   1   ,   5   ,   15  ,   5   ,   51  ,   51  ,   235 ,   63  ,   393 ,   1915    ,   2495    ,   7067    ,0 };
            const std::uint32_t dim908Kuo3Init[]    =   {   1   ,   1   ,   7   ,   1   ,   15  ,   35  ,   97  ,   65  ,   115 ,   819 ,   1419    ,   2313    ,   6029    ,0 };
            const std::uint32_t dim909Kuo3Init[]    =   {   1   ,   1   ,   5   ,   13  ,   11  ,   35  ,   45  ,   149 ,   45  ,   617 ,   2001    ,   1629    ,   5611    ,0 };
            const std::uint32_t dim910Kuo3Init[]    =   {   1   ,   3   ,   5   ,   11  ,   15  ,   17  ,   39  ,   155 ,   143 ,   473 ,   1269    ,   2537    ,   2571    ,0 };
            const std::uint32_t dim911Kuo3Init[]    =   {   1   ,   1   ,   3   ,   3   ,   1   ,   7   ,   57  ,   227 ,   151 ,   731 ,   1871    ,   245 ,   7605    ,0 };
            const std::uint32_t dim912Kuo3Init[]    =   {   1   ,   1   ,   1   ,   13  ,   21  ,   1   ,   19  ,   189 ,   299 ,   483 ,   513 ,   2235    ,   3079    ,0 };
            const std::uint32_t dim913Kuo3Init[]    =   {   1   ,   1   ,   5   ,   15  ,   13  ,   53  ,   91  ,   55  ,   339 ,   161 ,   273 ,   2759    ,   7251    ,0 };
            const std::uint32_t dim914Kuo3Init[]    =   {   1   ,   3   ,   1   ,   1   ,   17  ,   47  ,   29  ,   107 ,   371 ,   437 ,   715 ,   739 ,   2195    ,0 };
            const std::uint32_t dim915Kuo3Init[]    =   {   1   ,   3   ,   5   ,   11  ,   27  ,   1   ,   35  ,   105 ,   443 ,   623 ,   1401    ,   2683    ,   4327    ,0 };
            const std::uint32_t dim916Kuo3Init[]    =   {   1   ,   1   ,   5   ,   7   ,   13  ,   23  ,   101 ,   235 ,   369 ,   951 ,   1983    ,   1021    ,   7835    ,0 };
            const std::uint32_t dim917Kuo3Init[]    =   {   1   ,   1   ,   1   ,   5   ,   21  ,   57  ,   45  ,   67  ,   89  ,   209 ,   1105    ,   2161    ,   2245    ,0 };
            const std::uint32_t dim918Kuo3Init[]    =   {   1   ,   1   ,   7   ,   15  ,   7   ,   33  ,   69  ,   129 ,   181 ,   231 ,   961 ,   1621    ,   7763    ,0 };
            const std::uint32_t dim919Kuo3Init[]    =   {   1   ,   3   ,   1   ,   5   ,   1   ,   31  ,   105 ,   123 ,   413 ,   989 ,   1311    ,   199 ,   5175    ,0 };
            const std::uint32_t dim920Kuo3Init[]    =   {   1   ,   3   ,   5   ,   13  ,   15  ,   9   ,   123 ,   215 ,   463 ,   197 ,   537 ,   531 ,   2331    ,0 };
            const std::uint32_t dim921Kuo3Init[]    =   {   1   ,   1   ,   3   ,   13  ,   13  ,   45  ,   61  ,   189 ,   91  ,   445 ,   1719    ,   3335    ,   5269    ,0 };
            const std::uint32_t dim922Kuo3Init[]    =   {   1   ,   3   ,   1   ,   11  ,   19  ,   41  ,   65  ,   143 ,   199 ,   177 ,   1695    ,   3647    ,   7169    ,0 };
            const std::uint32_t dim923Kuo3Init[]    =   {   1   ,   1   ,   3   ,   13  ,   13  ,   25  ,   37  ,   89  ,   175 ,   551 ,   1535    ,   1401    ,   1823    ,0 };
            const std::uint32_t dim924Kuo3Init[]    =   {   1   ,   3   ,   3   ,   1   ,   21  ,   15  ,   31  ,   101 ,   329 ,   907 ,   731 ,   1493    ,   451 ,0 };
            const std::uint32_t dim925Kuo3Init[]    =   {   1   ,   1   ,   3   ,   9   ,   5   ,   61  ,   85  ,   247 ,   289 ,   547 ,   1031    ,   3567    ,   1769    ,0 };
            const std::uint32_t dim926Kuo3Init[]    =   {   1   ,   3   ,   1   ,   7   ,   25  ,   35  ,   99  ,   43  ,   25  ,   855 ,   1451    ,   617 ,   2615    ,0 };
            const std::uint32_t dim927Kuo3Init[]    =   {   1   ,   1   ,   1   ,   7   ,   25  ,   9   ,   77  ,   39  ,   127 ,   327 ,   1501    ,   57  ,   1485    ,0 };
            const std::uint32_t dim928Kuo3Init[]    =   {   1   ,   3   ,   5   ,   5   ,   9   ,   13  ,   13  ,   239 ,   125 ,   473 ,   785 ,   2853    ,   5165    ,0 };
            const std::uint32_t dim929Kuo3Init[]    =   {   1   ,   1   ,   1   ,   3   ,   27  ,   43  ,   117 ,   63  ,   175 ,   487 ,   1505    ,   157 ,   6043    ,0 };
            const std::uint32_t dim930Kuo3Init[]    =   {   1   ,   1   ,   5   ,   5   ,   25  ,   43  ,   97  ,   231 ,   389 ,   191 ,   1795    ,   2659    ,   7409    ,0 };
            const std::uint32_t dim931Kuo3Init[]    =   {   1   ,   1   ,   7   ,   7   ,   11  ,   25  ,   47  ,   131 ,   363 ,   311 ,   523 ,   2773    ,   8015    ,0 };
            const std::uint32_t dim932Kuo3Init[]    =   {   1   ,   1   ,   5   ,   11  ,   25  ,   61  ,   123 ,   83  ,   265 ,   995 ,   613 ,   1893    ,   6341    ,0 };
            const std::uint32_t dim933Kuo3Init[]    =   {   1   ,   1   ,   3   ,   3   ,   27  ,   45  ,   41  ,   143 ,   173 ,   1009    ,   1963    ,   4009    ,   3675    ,0 };
            const std::uint32_t dim934Kuo3Init[]    =   {   1   ,   3   ,   3   ,   9   ,   5   ,   11  ,   95  ,   253 ,   415 ,   307 ,   501 ,   3117    ,   4621    ,0 };
            const std::uint32_t dim935Kuo3Init[]    =   {   1   ,   3   ,   5   ,   1   ,   31  ,   41  ,   95  ,   39  ,   473 ,   565 ,   1389    ,   4049    ,   5673    ,0 };
            const std::uint32_t dim936Kuo3Init[]    =   {   1   ,   1   ,   3   ,   11  ,   3   ,   13  ,   87  ,   101 ,   413 ,   769 ,   1223    ,   549 ,   4967    ,0 };
            const std::uint32_t dim937Kuo3Init[]    =   {   1   ,   3   ,   1   ,   3   ,   13  ,   41  ,   29  ,   187 ,   491 ,   197 ,   1685    ,   3859    ,   3799    ,0 };
            const std::uint32_t dim938Kuo3Init[]    =   {   1   ,   3   ,   1   ,   3   ,   17  ,   55  ,   91  ,   131 ,   429 ,   899 ,   29  ,   1193    ,   7323    ,0 };
            const std::uint32_t dim939Kuo3Init[]    =   {   1   ,   1   ,   3   ,   1   ,   11  ,   17  ,   107 ,   113 ,   71  ,   185 ,   1057    ,   897 ,   249 ,0 };
            const std::uint32_t dim940Kuo3Init[]    =   {   1   ,   1   ,   3   ,   5   ,   29  ,   27  ,   87  ,   33  ,   273 ,   405 ,   547 ,   763 ,   2195    ,0 };
            const std::uint32_t dim941Kuo3Init[]    =   {   1   ,   3   ,   1   ,   11  ,   7   ,   43  ,   39  ,   103 ,   475 ,   515 ,   1105    ,   767 ,   3881    ,0 };
            const std::uint32_t dim942Kuo3Init[]    =   {   1   ,   3   ,   3   ,   1   ,   13  ,   21  ,   93  ,   141 ,   407 ,   1001    ,   1939    ,   2747    ,   6479    ,0 };
            const std::uint32_t dim943Kuo3Init[]    =   {   1   ,   3   ,   1   ,   15  ,   1   ,   31  ,   15  ,   69  ,   313 ,   547 ,   987 ,   3569    ,   2795    ,0 };
            const std::uint32_t dim944Kuo3Init[]    =   {   1   ,   3   ,   5   ,   7   ,   1   ,   17  ,   105 ,   113 ,   253 ,   453 ,   1219    ,   2769    ,   197 ,0 };
            const std::uint32_t dim945Kuo3Init[]    =   {   1   ,   3   ,   7   ,   7   ,   29  ,   55  ,   77  ,   169 ,   227 ,   471 ,   1385    ,   2689    ,   7995    ,0 };
            const std::uint32_t dim946Kuo3Init[]    =   {   1   ,   3   ,   7   ,   15  ,   7   ,   15  ,   113 ,   133 ,   205 ,   271 ,   263 ,   3141    ,   5007    ,0 };
            const std::uint32_t dim947Kuo3Init[]    =   {   1   ,   1   ,   5   ,   7   ,   7   ,   57  ,   121 ,   209 ,   319 ,   733 ,   1689    ,   2817    ,   6621    ,0 };
            const std::uint32_t dim948Kuo3Init[]    =   {   1   ,   3   ,   7   ,   9   ,   23  ,   37  ,   101 ,   229 ,   269 ,   429 ,   157 ,   515 ,   6975    ,0 };
            const std::uint32_t dim949Kuo3Init[]    =   {   1   ,   1   ,   7   ,   7   ,   23  ,   31  ,   83  ,   237 ,   299 ,   333 ,   959 ,   1467    ,   419 ,0 };
            const std::uint32_t dim950Kuo3Init[]    =   {   1   ,   3   ,   7   ,   3   ,   23  ,   45  ,   17  ,   33  ,   293 ,   679 ,   625 ,   3651    ,   4205    ,0 };
            const std::uint32_t dim951Kuo3Init[]    =   {   1   ,   3   ,   1   ,   13  ,   17  ,   19  ,   87  ,   237 ,   219 ,   119 ,   841 ,   1923    ,   8141    ,0 };
            const std::uint32_t dim952Kuo3Init[]    =   {   1   ,   1   ,   1   ,   15  ,   15  ,   49  ,   21  ,   189 ,   287 ,   759 ,   695 ,   913 ,   5167    ,0 };
            const std::uint32_t dim953Kuo3Init[]    =   {   1   ,   1   ,   3   ,   15  ,   1   ,   9   ,   125 ,   5   ,   67  ,   603 ,   1691    ,   2863    ,   1299    ,0 };
            const std::uint32_t dim954Kuo3Init[]    =   {   1   ,   3   ,   7   ,   3   ,   5   ,   35  ,   105 ,   27  ,   51  ,   889 ,   1469    ,   3203    ,   6997    ,0 };
            const std::uint32_t dim955Kuo3Init[]    =   {   1   ,   3   ,   5   ,   7   ,   1   ,   53  ,   77  ,   1   ,   313 ,   475 ,   1515    ,   2233    ,   399 ,0 };
            const std::uint32_t dim956Kuo3Init[]    =   {   1   ,   3   ,   5   ,   7   ,   3   ,   31  ,   43  ,   17  ,   425 ,   673 ,   1817    ,   1939    ,   8027    ,0 };
            const std::uint32_t dim957Kuo3Init[]    =   {   1   ,   1   ,   5   ,   5   ,   31  ,   31  ,   119 ,   179 ,   157 ,   635 ,   1   ,   315 ,   1179    ,0 };
            const std::uint32_t dim958Kuo3Init[]    =   {   1   ,   1   ,   5   ,   5   ,   1   ,   7   ,   25  ,   15  ,   311 ,   489 ,   829 ,   1929    ,   623 ,0 };
            const std::uint32_t dim959Kuo3Init[]    =   {   1   ,   1   ,   5   ,   11  ,   1   ,   17  ,   43  ,   205 ,   347 ,   713 ,   2029    ,   977 ,   4345    ,0 };
            const std::uint32_t dim960Kuo3Init[]    =   {   1   ,   1   ,   3   ,   9   ,   17  ,   3   ,   109 ,   253 ,   427 ,   333 ,   203 ,   1609    ,   1851    ,0 };
            const std::uint32_t dim961Kuo3Init[]    =   {   1   ,   3   ,   1   ,   9   ,   21  ,   55  ,   107 ,   203 ,   483 ,   869 ,   1417    ,   587 ,   3965    ,0 };
            const std::uint32_t dim962Kuo3Init[]    =   {   1   ,   3   ,   3   ,   13  ,   27  ,   21  ,   103 ,   109 ,   313 ,   797 ,   723 ,   683 ,   349 ,0 };
            const std::uint32_t dim963Kuo3Init[]    =   {   1   ,   3   ,   5   ,   3   ,   1   ,   35  ,   43  ,   19  ,   367 ,   487 ,   703 ,   2211    ,   1199    ,0 };
            const std::uint32_t dim964Kuo3Init[]    =   {   1   ,   3   ,   1   ,   3   ,   19  ,   33  ,   13  ,   135 ,   329 ,   621 ,   843 ,   407 ,   6523    ,0 };
            const std::uint32_t dim965Kuo3Init[]    =   {   1   ,   1   ,   7   ,   5   ,   13  ,   1   ,   45  ,   133 ,   27  ,   267 ,   1975    ,   2761    ,   5061    ,0 };
            const std::uint32_t dim966Kuo3Init[]    =   {   1   ,   1   ,   3   ,   3   ,   19  ,   59  ,   13  ,   35  ,   489 ,   391 ,   1595    ,   2983    ,   3203    ,0 };
            const std::uint32_t dim967Kuo3Init[]    =   {   1   ,   3   ,   3   ,   7   ,   19  ,   27  ,   125 ,   55  ,   121 ,   733 ,   1437    ,   51  ,   4029    ,0 };
            const std::uint32_t dim968Kuo3Init[]    =   {   1   ,   3   ,   1   ,   15  ,   11  ,   7   ,   73  ,   187 ,   209 ,   127 ,   1259    ,   1733    ,   1897    ,0 };
            const std::uint32_t dim969Kuo3Init[]    =   {   1   ,   3   ,   7   ,   1   ,   27  ,   19  ,   87  ,   189 ,   91  ,   113 ,   237 ,   2073    ,   419 ,0 };
            const std::uint32_t dim970Kuo3Init[]    =   {   1   ,   3   ,   5   ,   3   ,   15  ,   27  ,   107 ,   77  ,   467 ,   953 ,   1317    ,   877 ,   6911    ,0 };
            const std::uint32_t dim971Kuo3Init[]    =   {   1   ,   3   ,   7   ,   13  ,   7   ,   17  ,   107 ,   157 ,   439 ,   871 ,   651 ,   797 ,   2095    ,0 };
            const std::uint32_t dim972Kuo3Init[]    =   {   1   ,   1   ,   3   ,   9   ,   13  ,   19  ,   19  ,   75  ,   13  ,   267 ,   435 ,   1067    ,   6603    ,0 };
            const std::uint32_t dim973Kuo3Init[]    =   {   1   ,   1   ,   7   ,   13  ,   25  ,   7   ,   81  ,   207 ,   149 ,   587 ,   1561    ,   2025    ,   2355    ,0 };
            const std::uint32_t dim974Kuo3Init[]    =   {   1   ,   3   ,   3   ,   5   ,   25  ,   25  ,   79  ,   249 ,   371 ,   305 ,   305 ,   53  ,   1051    ,0 };
            const std::uint32_t dim975Kuo3Init[]    =   {   1   ,   1   ,   3   ,   9   ,   19  ,   63  ,   57  ,   237 ,   39  ,   349 ,   1163    ,   2443    ,   1739    ,0 };
            const std::uint32_t dim976Kuo3Init[]    =   {   1   ,   1   ,   5   ,   5   ,   23  ,   57  ,   61  ,   21  ,   115 ,   107 ,   303 ,   1451    ,   2955    ,0 };
            const std::uint32_t dim977Kuo3Init[]    =   {   1   ,   3   ,   1   ,   3   ,   17  ,   19  ,   121 ,   123 ,   25  ,   367 ,   963 ,   545 ,   2885    ,0 };
            const std::uint32_t dim978Kuo3Init[]    =   {   1   ,   3   ,   3   ,   5   ,   15  ,   57  ,   123 ,   1   ,   193 ,   861 ,   1001    ,   1457    ,   4977    ,0 };
            const std::uint32_t dim979Kuo3Init[]    =   {   1   ,   3   ,   5   ,   9   ,   21  ,   31  ,   37  ,   83  ,   361 ,   491 ,   1933    ,   407 ,   1923    ,0 };
            const std::uint32_t dim980Kuo3Init[]    =   {   1   ,   3   ,   7   ,   5   ,   9   ,   47  ,   33  ,   43  ,   239 ,   837 ,   799 ,   3731    ,   5883    ,0 };
            const std::uint32_t dim981Kuo3Init[]    =   {   1   ,   3   ,   5   ,   5   ,   7   ,   39  ,   49  ,   201 ,   339 ,   783 ,   1937    ,   1473    ,   391 ,0 };
            const std::uint32_t dim982Kuo3Init[]    =   {   1   ,   3   ,   5   ,   13  ,   3   ,   63  ,   39  ,   91  ,   63  ,   645 ,   929 ,   1543    ,   577 ,0 };
            const std::uint32_t dim983Kuo3Init[]    =   {   1   ,   3   ,   3   ,   3   ,   9   ,   59  ,   107 ,   129 ,   455 ,   259 ,   1523    ,   107 ,   285 ,0 };
            const std::uint32_t dim984Kuo3Init[]    =   {   1   ,   1   ,   3   ,   9   ,   23  ,   21  ,   89  ,   13  ,   413 ,   87  ,   1703    ,   1611    ,   5667    ,0 };
            const std::uint32_t dim985Kuo3Init[]    =   {   1   ,   1   ,   3   ,   9   ,   21  ,   9   ,   83  ,   187 ,   159 ,   757 ,   1111    ,   3619    ,   3907    ,0 };
            const std::uint32_t dim986Kuo3Init[]    =   {   1   ,   3   ,   3   ,   9   ,   21  ,   35  ,   27  ,   57  ,   357 ,   659 ,   1243    ,   2725    ,   5769    ,0 };
            const std::uint32_t dim987Kuo3Init[]    =   {   1   ,   1   ,   7   ,   1   ,   3   ,   7   ,   75  ,   145 ,   119 ,   1019    ,   1169    ,   953 ,   2343    ,0 };
            const std::uint32_t dim988Kuo3Init[]    =   {   1   ,   3   ,   3   ,   11  ,   19  ,   15  ,   121 ,   135 ,   187 ,   569 ,   671 ,   131 ,   479 ,0 };
            const std::uint32_t dim989Kuo3Init[]    =   {   1   ,   3   ,   5   ,   1   ,   21  ,   27  ,   63  ,   187 ,   367 ,   181 ,   1885    ,   2513    ,   4499    ,0 };
            const std::uint32_t dim990Kuo3Init[]    =   {   1   ,   3   ,   3   ,   5   ,   27  ,   13  ,   107 ,   183 ,   345 ,   855 ,   123 ,   1491    ,   867 ,0 };
            const std::uint32_t dim991Kuo3Init[]    =   {   1   ,   3   ,   7   ,   9   ,   5   ,   41  ,   43  ,   47  ,   277 ,   657 ,   1227    ,   2265    ,   1777    ,0 };
            const std::uint32_t dim992Kuo3Init[]    =   {   1   ,   1   ,   5   ,   5   ,   31  ,   37  ,   119 ,   5   ,   395 ,   399 ,   787 ,   2869    ,   829 ,0 };
            const std::uint32_t dim993Kuo3Init[]    =   {   1   ,   1   ,   1   ,   5   ,   3   ,   55  ,   43  ,   117 ,   191 ,   577 ,   1185    ,   3407    ,   4673    ,0 };
            const std::uint32_t dim994Kuo3Init[]    =   {   1   ,   3   ,   5   ,   11  ,   15  ,   63  ,   103 ,   127 ,   505 ,   53  ,   297 ,   3411    ,   3919    ,0 };
            const std::uint32_t dim995Kuo3Init[]    =   {   1   ,   3   ,   7   ,   13  ,   15  ,   57  ,   45  ,   17  ,   253 ,   261 ,   767 ,   1951    ,   6599    ,0 };
            const std::uint32_t dim996Kuo3Init[]    =   {   1   ,   3   ,   1   ,   13  ,   3   ,   55  ,   11  ,   113 ,   223 ,   403 ,   249 ,   633 ,   3265    ,0 };
            const std::uint32_t dim997Kuo3Init[]    =   {   1   ,   1   ,   1   ,   5   ,   7   ,   49  ,   47  ,   47  ,   467 ,   633 ,   1991    ,   361 ,   8099    ,0 };
            const std::uint32_t dim998Kuo3Init[]    =   {   1   ,   1   ,   3   ,   5   ,   31  ,   45  ,   87  ,   117 ,   483 ,   331 ,   687 ,   3393    ,   7377    ,0 };
            const std::uint32_t dim999Kuo3Init[]    =   {   1   ,   1   ,   7   ,   9   ,   29  ,   3   ,   11  ,   147 ,   147 ,   631 ,   1131    ,   2651    ,   3141    ,0 };
            const std::uint32_t dim1000Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   27  ,   49  ,   41  ,   207 ,   305 ,   403 ,   889 ,   2947    ,   5775    ,0 };
            const std::uint32_t dim1001Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   1   ,   63  ,   25  ,   127 ,   401 ,   375 ,   727 ,   2375    ,   2945    ,0 };
            const std::uint32_t dim1002Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   7   ,   19  ,   65  ,   29  ,   383 ,   809 ,   279 ,   2081    ,   1993    ,0 };
            const std::uint32_t dim1003Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   29  ,   9   ,   39  ,   159 ,   457 ,   435 ,   947 ,   2309    ,   2219    ,0 };
            const std::uint32_t dim1004Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   15  ,   31  ,   51  ,   147 ,   167 ,   113 ,   145 ,   125 ,   6997    ,0 };
            const std::uint32_t dim1005Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   27  ,   21  ,   123 ,   249 ,   21  ,   487 ,   331 ,   35  ,   3101    ,0 };
            const std::uint32_t dim1006Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   5   ,   7   ,   127 ,   173 ,   115 ,   607 ,   1061    ,   2923    ,   6869    ,0 };
            const std::uint32_t dim1007Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   17  ,   55  ,   13  ,   15  ,   95  ,   365 ,   1419    ,   1111    ,   7561    ,0 };
            const std::uint32_t dim1008Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   23  ,   45  ,   115 ,   123 ,   477 ,   335 ,   85  ,   431 ,   6893    ,0 };
            const std::uint32_t dim1009Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   5   ,   49  ,   95  ,   19  ,   429 ,   549 ,   713 ,   661 ,   167 ,0 };
            const std::uint32_t dim1010Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   3   ,   13  ,   127 ,   189 ,   385 ,   649 ,   67  ,   499 ,   5355    ,0 };
            const std::uint32_t dim1011Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   9   ,   31  ,   17  ,   21  ,   419 ,   655 ,   287 ,   1173    ,   1023    ,0 };
            const std::uint32_t dim1012Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   17  ,   11  ,   19  ,   17  ,   195 ,   1015    ,   1621    ,   1197    ,   3497    ,0 };
            const std::uint32_t dim1013Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   29  ,   55  ,   85  ,   43  ,   381 ,   59  ,   149 ,   391 ,   2109    ,0 };
            const std::uint32_t dim1014Kuo3Init[]   =   {   1   ,   1   ,   7   ,   9   ,   11  ,   43  ,   115 ,   57  ,   211 ,   463 ,   787 ,   3665    ,   5619    ,0 };
            const std::uint32_t dim1015Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   23  ,   5   ,   55  ,   93  ,   117 ,   925 ,   941 ,   91  ,   6221    ,0 };
            const std::uint32_t dim1016Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   29  ,   35  ,   89  ,   7   ,   75  ,   759 ,   735 ,   3011    ,   1279    ,0 };
            const std::uint32_t dim1017Kuo3Init[]   =   {   1   ,   1   ,   1   ,   15  ,   13  ,   17  ,   13  ,   175 ,   167 ,   965 ,   1069    ,   2215    ,   6065    ,0 };
            const std::uint32_t dim1018Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   1   ,   11  ,   109 ,   205 ,   501 ,   419 ,   1071    ,   543 ,   5377    ,0 };
            const std::uint32_t dim1019Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   11  ,   1   ,   123 ,   147 ,   87  ,   289 ,   325 ,   3693    ,   4939    ,0 };
            const std::uint32_t dim1020Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   9   ,   21  ,   29  ,   215 ,   365 ,   995 ,   1727    ,   2515    ,   5741    ,0 };
            const std::uint32_t dim1021Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   3   ,   7   ,   5   ,   147 ,   413 ,   505 ,   661 ,   3071    ,   2521    ,0 };
            const std::uint32_t dim1022Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   5   ,   41  ,   117 ,   145 ,   455 ,   379 ,   601 ,   455 ,   5377    ,0 };
            const std::uint32_t dim1023Kuo3Init[]   =   {   1   ,   1   ,   7   ,   15  ,   11  ,   45  ,   27  ,   37  ,   457 ,   935 ,   595 ,   3883    ,   1491    ,0 };
            const std::uint32_t dim1024Kuo3Init[]   =   {   1   ,   3   ,   5   ,   9   ,   15  ,   7   ,   49  ,   95  ,   225 ,   837 ,   805 ,   2553    ,   4891    ,0 };
            const std::uint32_t dim1025Kuo3Init[]   =   {   1   ,   3   ,   3   ,   5   ,   1   ,   29  ,   109 ,   99  ,   349 ,   221 ,   749 ,   3499    ,   4201    ,0 };
            const std::uint32_t dim1026Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   27  ,   35  ,   47  ,   253 ,   151 ,   129 ,   927 ,   4039    ,   6133    ,0 };
            const std::uint32_t dim1027Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   17  ,   59  ,   1   ,   63  ,   61  ,   927 ,   933 ,   3645    ,   3707    ,0 };
            const std::uint32_t dim1028Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   29  ,   33  ,   45  ,   59  ,   183 ,   459 ,   903 ,   747 ,   1895    ,0 };
            const std::uint32_t dim1029Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   19  ,   53  ,   71  ,   199 ,   91  ,   807 ,   507 ,   3821    ,   1815    ,0 };
            const std::uint32_t dim1030Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   23  ,   43  ,   39  ,   17  ,   139 ,   751 ,   467 ,   617 ,   5237    ,0 };
            const std::uint32_t dim1031Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   5   ,   53  ,   43  ,   181 ,   337 ,   731 ,   497 ,   3189    ,   4063    ,0 };
            const std::uint32_t dim1032Kuo3Init[]   =   {   1   ,   1   ,   7   ,   9   ,   1   ,   45  ,   103 ,   151 ,   265 ,   897 ,   1821    ,   2957    ,   5591    ,0 };
            const std::uint32_t dim1033Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   13  ,   43  ,   65  ,   49  ,   233 ,   1   ,   1709    ,   2641    ,   5633    ,0 };
            const std::uint32_t dim1034Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   15  ,   15  ,   95  ,   223 ,   447 ,   967 ,   1533    ,   1969    ,   6497    ,0 };
            const std::uint32_t dim1035Kuo3Init[]   =   {   1   ,   1   ,   7   ,   9   ,   29  ,   5   ,   55  ,   57  ,   377 ,   487 ,   443 ,   2589    ,   4735    ,0 };
            const std::uint32_t dim1036Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   23  ,   49  ,   5   ,   47  ,   203 ,   727 ,   1955    ,   3465    ,   6691    ,0 };
            const std::uint32_t dim1037Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   25  ,   13  ,   31  ,   153 ,   411 ,   79  ,   121 ,   3815    ,   2123    ,0 };
            const std::uint32_t dim1038Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   3   ,   57  ,   11  ,   141 ,   465 ,   713 ,   659 ,   2849    ,   487 ,0 };
            const std::uint32_t dim1039Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   29  ,   49  ,   91  ,   249 ,   353 ,   247 ,   1793    ,   1617    ,   3321    ,0 };
            const std::uint32_t dim1040Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   31  ,   3   ,   59  ,   213 ,   265 ,   3   ,   543 ,   2237    ,   6617    ,0 };
            const std::uint32_t dim1041Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   9   ,   23  ,   57  ,   89  ,   365 ,   11  ,   871 ,   1343    ,   7375    ,0 };
            const std::uint32_t dim1042Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   7   ,   19  ,   15  ,   101 ,   239 ,   341 ,   1259    ,   3607    ,   3879    ,0 };
            const std::uint32_t dim1043Kuo3Init[]   =   {   1   ,   1   ,   5   ,   7   ,   29  ,   25  ,   117 ,   183 ,   131 ,   705 ,   1497    ,   3537    ,   1007    ,0 };
            const std::uint32_t dim1044Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   11  ,   41  ,   113 ,   127 ,   95  ,   417 ,   1177    ,   1939    ,   1317    ,0 };
            const std::uint32_t dim1045Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   1   ,   37  ,   1   ,   141 ,   417 ,   157 ,   993 ,   671 ,   4993    ,0 };
            const std::uint32_t dim1046Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   23  ,   15  ,   41  ,   171 ,   389 ,   261 ,   1967    ,   3009    ,   2237    ,0 };
            const std::uint32_t dim1047Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   31  ,   41  ,   49  ,   39  ,   73  ,   201 ,   495 ,   3121    ,   4247    ,0 };
            const std::uint32_t dim1048Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   17  ,   21  ,   95  ,   219 ,   343 ,   103 ,   93  ,   2907    ,   1279    ,0 };
            const std::uint32_t dim1049Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   7   ,   31  ,   79  ,   139 ,   347 ,   437 ,   1261    ,   3425    ,   6981    ,0 };
            const std::uint32_t dim1050Kuo3Init[]   =   {   1   ,   1   ,   5   ,   7   ,   9   ,   19  ,   55  ,   185 ,   425 ,   145 ,   1627    ,   3045    ,   8113    ,0 };
            const std::uint32_t dim1051Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   15  ,   33  ,   99  ,   185 ,   485 ,   859 ,   481 ,   3063    ,   3209    ,0 };
            const std::uint32_t dim1052Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   23  ,   7   ,   7   ,   81  ,   405 ,   705 ,   1933    ,   315 ,   5819    ,0 };
            const std::uint32_t dim1053Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   9   ,   55  ,   95  ,   101 ,   391 ,   299 ,   185 ,   3687    ,   2833    ,0 };
            const std::uint32_t dim1054Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   15  ,   5   ,   119 ,   29  ,   29  ,   893 ,   207 ,   1789    ,   3395    ,0 };
            const std::uint32_t dim1055Kuo3Init[]   =   {   1   ,   3   ,   3   ,   5   ,   1   ,   59  ,   49  ,   81  ,   391 ,   95  ,   289 ,   3167    ,   5417    ,0 };
            const std::uint32_t dim1056Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   31  ,   21  ,   5   ,   189 ,   63  ,   567 ,   1515    ,   297 ,   5415    ,0 };
            const std::uint32_t dim1057Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   3   ,   23  ,   105 ,   113 ,   403 ,   799 ,   591 ,   1977    ,   1117    ,0 };
            const std::uint32_t dim1058Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   23  ,   55  ,   59  ,   229 ,   319 ,   357 ,   1703    ,   585 ,   3785    ,0 };
            const std::uint32_t dim1059Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   7   ,   1   ,   97  ,   247 ,   451 ,   897 ,   137 ,   3289    ,   3621    ,0 };
            const std::uint32_t dim1060Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   13  ,   43  ,   89  ,   75  ,   243 ,   489 ,   1999    ,   1179    ,   13  ,0 };
            const std::uint32_t dim1061Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   11  ,   21  ,   51  ,   199 ,   15  ,   859 ,   83  ,   613 ,   5027    ,0 };
            const std::uint32_t dim1062Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   15  ,   15  ,   81  ,   87  ,   311 ,   681 ,   1391    ,   2123    ,   6747    ,0 };
            const std::uint32_t dim1063Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   5   ,   45  ,   5   ,   123 ,   19  ,   831 ,   1345    ,   3313    ,   7945    ,0 };
            const std::uint32_t dim1064Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   5   ,   9   ,   93  ,   39  ,   221 ,   601 ,   315 ,   2179    ,   6573    ,0 };
            const std::uint32_t dim1065Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   17  ,   17  ,   117 ,   145 ,   471 ,   893 ,   305 ,   3065    ,   7519    ,0 };
            const std::uint32_t dim1066Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   1   ,   55  ,   119 ,   235 ,   417 ,   167 ,   467 ,   2947    ,   3235    ,0 };
            const std::uint32_t dim1067Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   25  ,   51  ,   71  ,   101 ,   255 ,   671 ,   1929    ,   2911    ,   2837    ,0 };
            const std::uint32_t dim1068Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   17  ,   1   ,   79  ,   241 ,   25  ,   635 ,   379 ,   1701    ,   7139    ,0 };
            const std::uint32_t dim1069Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   1   ,   1   ,   119 ,   121 ,   469 ,   51  ,   939 ,   2161    ,   4247    ,0 };
            const std::uint32_t dim1070Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   3   ,   35  ,   95  ,   107 ,   143 ,   701 ,   1843    ,   301 ,   6345    ,0 };
            const std::uint32_t dim1071Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   27  ,   13  ,   117 ,   143 ,   49  ,   875 ,   1705    ,   3005    ,   3671    ,0 };
            const std::uint32_t dim1072Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   5   ,   49  ,   111 ,   33  ,   169 ,   189 ,   1109    ,   805 ,   2753    ,0 };
            const std::uint32_t dim1073Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   19  ,   49  ,   59  ,   3   ,   71  ,   859 ,   435 ,   3417    ,   1883    ,0 };
            const std::uint32_t dim1074Kuo3Init[]   =   {   1   ,   3   ,   5   ,   9   ,   9   ,   51  ,   35  ,   79  ,   385 ,   83  ,   1121    ,   1421    ,   7317    ,0 };
            const std::uint32_t dim1075Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   13  ,   29  ,   49  ,   41  ,   219 ,   23  ,   1025    ,   849 ,   499 ,0 };
            const std::uint32_t dim1076Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   3   ,   15  ,   13  ,   167 ,   441 ,   753 ,   1731    ,   527 ,   8099    ,0 };
            const std::uint32_t dim1077Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   1   ,   57  ,   17  ,   193 ,   29  ,   849 ,   15  ,   539 ,   1713    ,0 };
            const std::uint32_t dim1078Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   27  ,   47  ,   59  ,   249 ,   363 ,   175 ,   3   ,   2485    ,   3551    ,0 };
            const std::uint32_t dim1079Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   25  ,   45  ,   79  ,   45  ,   141 ,   13  ,   1007    ,   1235    ,   5359    ,0 };
            const std::uint32_t dim1080Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   29  ,   31  ,   111 ,   173 ,   281 ,   287 ,   173 ,   2627    ,   4125    ,0 };
            const std::uint32_t dim1081Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   3   ,   13  ,   37  ,   157 ,   509 ,   323 ,   1695    ,   765 ,   6533    ,0 };
            const std::uint32_t dim1082Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   7   ,   33  ,   77  ,   237 ,   377 ,   351 ,   205 ,   183 ,   5273    ,0 };
            const std::uint32_t dim1083Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   11  ,   1   ,   123 ,   251 ,   3   ,   207 ,   1319    ,   553 ,   8143    ,0 };
            const std::uint32_t dim1084Kuo3Init[]   =   {   1   ,   1   ,   7   ,   15  ,   23  ,   25  ,   105 ,   43  ,   271 ,   633 ,   1331    ,   2197    ,   7229    ,0 };
            const std::uint32_t dim1085Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   13  ,   37  ,   119 ,   195 ,   21  ,   751 ,   1809    ,   4025    ,   3037    ,0 };
            const std::uint32_t dim1086Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   19  ,   1   ,   3   ,   33  ,   79  ,   477 ,   1203    ,   3657    ,   5573    ,0 };
            const std::uint32_t dim1087Kuo3Init[]   =   {   1   ,   1   ,   1   ,   1   ,   21  ,   21  ,   121 ,   183 ,   355 ,   259 ,   1033    ,   1621    ,   2843    ,0 };
            const std::uint32_t dim1088Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   19  ,   37  ,   121 ,   233 ,   397 ,   27  ,   279 ,   2891    ,   4191    ,0 };
            const std::uint32_t dim1089Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   13  ,   5   ,   31  ,   237 ,   453 ,   913 ,   1073    ,   3573    ,   7883    ,0 };
            const std::uint32_t dim1090Kuo3Init[]   =   {   1   ,   1   ,   1   ,   1   ,   1   ,   11  ,   57  ,   103 ,   453 ,   605 ,   1041    ,   2975    ,   4735    ,0 };
            const std::uint32_t dim1091Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   29  ,   33  ,   119 ,   241 ,   27  ,   491 ,   341 ,   1945    ,   6599    ,0 };
            const std::uint32_t dim1092Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   25  ,   41  ,   83  ,   191 ,   481 ,   995 ,   1819    ,   1577    ,   3837    ,0 };
            const std::uint32_t dim1093Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   15  ,   21  ,   81  ,   111 ,   143 ,   281 ,   509 ,   2905    ,   177 ,0 };
            const std::uint32_t dim1094Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   19  ,   19  ,   31  ,   107 ,   451 ,   1007    ,   2027    ,   3947    ,   3903    ,0 };
            const std::uint32_t dim1095Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   27  ,   41  ,   23  ,   147 ,   299 ,   315 ,   895 ,   407 ,   4761    ,0 };
            const std::uint32_t dim1096Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   27  ,   1   ,   105 ,   103 ,   507 ,   897 ,   1309    ,   3979    ,   5123    ,0 };
            const std::uint32_t dim1097Kuo3Init[]   =   {   1   ,   3   ,   1   ,   11  ,   7   ,   41  ,   99  ,   67  ,   183 ,   495 ,   1509    ,   2733    ,   6995    ,0 };
            const std::uint32_t dim1098Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   13  ,   5   ,   69  ,   239 ,   95  ,   211 ,   691 ,   323 ,   7485    ,0 };
            const std::uint32_t dim1099Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   23  ,   57  ,   5   ,   113 ,   417 ,   893 ,   1229    ,   2109    ,   7657    ,0 };
            const std::uint32_t dim1100Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   19  ,   59  ,   111 ,   181 ,   61  ,   743 ,   227 ,   831 ,   3035    ,0 };
            const std::uint32_t dim1101Kuo3Init[]   =   {   1   ,   1   ,   5   ,   7   ,   19  ,   13  ,   107 ,   63  ,   127 ,   17  ,   1753    ,   337 ,   3403    ,0 };
            const std::uint32_t dim1102Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   7   ,   21  ,   85  ,   219 ,   77  ,   311 ,   685 ,   145 ,   3451    ,0 };
            const std::uint32_t dim1103Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   3   ,   55  ,   123 ,   187 ,   407 ,   539 ,   1167    ,   2741    ,   6885    ,0 };
            const std::uint32_t dim1104Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   23  ,   57  ,   109 ,   93  ,   93  ,   483 ,   857 ,   1895    ,   7145    ,0 };
            const std::uint32_t dim1105Kuo3Init[]   =   {   1   ,   1   ,   1   ,   15  ,   19  ,   43  ,   37  ,   129 ,   487 ,   523 ,   1959    ,   2053    ,   6281    ,0 };
            const std::uint32_t dim1106Kuo3Init[]   =   {   1   ,   3   ,   1   ,   11  ,   9   ,   1   ,   105 ,   123 ,   483 ,   511 ,   1661    ,   1065    ,   7539    ,0 };
            const std::uint32_t dim1107Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   27  ,   33  ,   87  ,   191 ,   89  ,   697 ,   1195    ,   1699    ,   2699    ,0 };
            const std::uint32_t dim1108Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   21  ,   57  ,   5   ,   109 ,   343 ,   721 ,   1355    ,   1155    ,   4515    ,0 };
            const std::uint32_t dim1109Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   27  ,   43  ,   47  ,   167 ,   457 ,   93  ,   221 ,   3693    ,   383 ,0 };
            const std::uint32_t dim1110Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   13  ,   13  ,   55  ,   75  ,   113 ,   577 ,   397 ,   2491    ,   6871    ,0 };
            const std::uint32_t dim1111Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   31  ,   31  ,   71  ,   189 ,   39  ,   397 ,   977 ,   2645    ,   1683    ,   5081    ,0 };
            const std::uint32_t dim1112Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   27  ,   41  ,   125 ,   69  ,   269 ,   157 ,   1827    ,   41  ,   3105    ,   10615   ,0 };
            const std::uint32_t dim1113Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   5   ,   45  ,   33  ,   169 ,   317 ,   371 ,   389 ,   595 ,   1071    ,   5323    ,0 };
            const std::uint32_t dim1114Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   25  ,   25  ,   69  ,   45  ,   313 ,   105 ,   795 ,   3987    ,   5181    ,   155 ,0 };
            const std::uint32_t dim1115Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   19  ,   17  ,   13  ,   119 ,   213 ,   289 ,   269 ,   1561    ,   6069    ,   15631   ,0 };
            const std::uint32_t dim1116Kuo3Init[]   =   {   1   ,   3   ,   7   ,   1   ,   15  ,   7   ,   17  ,   173 ,   491 ,   907 ,   315 ,   101 ,   6205    ,   4631    ,0 };
            const std::uint32_t dim1117Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   17  ,   13  ,   9   ,   67  ,   267 ,   719 ,   1565    ,   2157    ,   5773    ,   5167    ,0 };
            const std::uint32_t dim1118Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   11  ,   45  ,   65  ,   207 ,   403 ,   231 ,   1019    ,   3345    ,   2779    ,   3621    ,0 };
            const std::uint32_t dim1119Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   13  ,   59  ,   65  ,   225 ,   307 ,   581 ,   1159    ,   2041    ,   3535    ,   16381   ,0 };
            const std::uint32_t dim1120Kuo3Init[]   =   {   1   ,   3   ,   1   ,   15  ,   9   ,   45  ,   17  ,   99  ,   285 ,   797 ,   477 ,   3041    ,   3123    ,   397 ,0 };
            const std::uint32_t dim1121Kuo3Init[]   =   {   1   ,   3   ,   1   ,   15  ,   3   ,   57  ,   99  ,   115 ,   105 ,   877 ,   9   ,   1185    ,   3147    ,   6285    ,0 };
            const std::uint32_t dim1122Kuo3Init[]   =   {   1   ,   1   ,   1   ,   1   ,   25  ,   31  ,   37  ,   13  ,   119 ,   935 ,   1339    ,   2147    ,   2371    ,   16107   ,0 };
            const std::uint32_t dim1123Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   17  ,   31  ,   123 ,   131 ,   135 ,   977 ,   1943    ,   3643    ,   4457    ,   15405   ,0 };
            const std::uint32_t dim1124Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   3   ,   57  ,   29  ,   33  ,   1   ,   519 ,   535 ,   681 ,   6255    ,   16263   ,0 };
            const std::uint32_t dim1125Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   9   ,   45  ,   39  ,   215 ,   329 ,   457 ,   1341    ,   3037    ,   1631    ,   15335   ,0 };
            const std::uint32_t dim1126Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   3   ,   27  ,   23  ,   73  ,   465 ,   771 ,   1453    ,   3821    ,   3099    ,   10075   ,0 };
            const std::uint32_t dim1127Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   21  ,   45  ,   119 ,   233 ,   507 ,   959 ,   1743    ,   2711    ,   2465    ,   4257    ,0 };
            const std::uint32_t dim1128Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   31  ,   37  ,   113 ,   207 ,   239 ,   305 ,   1085    ,   2447    ,   743 ,   15747   ,0 };
            const std::uint32_t dim1129Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   27  ,   25  ,   83  ,   255 ,   93  ,   149 ,   627 ,   1887    ,   6913    ,   5793    ,0 };
            const std::uint32_t dim1130Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   17  ,   61  ,   91  ,   75  ,   469 ,   503 ,   1405    ,   3609    ,   421 ,   10819   ,0 };
            const std::uint32_t dim1131Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   13  ,   47  ,   53  ,   221 ,   351 ,   621 ,   1025    ,   3729    ,   367 ,   16091   ,0 };
            const std::uint32_t dim1132Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   7   ,   41  ,   3   ,   177 ,   127 ,   71  ,   753 ,   1581    ,   2227    ,   257 ,0 };
            const std::uint32_t dim1133Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   3   ,   17  ,   69  ,   31  ,   143 ,   825 ,   291 ,   257 ,   2147    ,   4199    ,0 };
            const std::uint32_t dim1134Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   29  ,   21  ,   49  ,   1   ,   35  ,   321 ,   383 ,   1495    ,   4201    ,   7143    ,0 };
            const std::uint32_t dim1135Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   5   ,   27  ,   31  ,   143 ,   117 ,   487 ,   585 ,   809 ,   2425    ,   15681   ,0 };
            const std::uint32_t dim1136Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   23  ,   3   ,   33  ,   213 ,   209 ,   185 ,   603 ,   431 ,   5519    ,   5017    ,0 };
            const std::uint32_t dim1137Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   21  ,   61  ,   3   ,   53  ,   303 ,   793 ,   759 ,   3869    ,   391 ,   8395    ,0 };
            const std::uint32_t dim1138Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   25  ,   13  ,   119 ,   37  ,   419 ,   399 ,   825 ,   709 ,   5351    ,   1299    ,0 };
            const std::uint32_t dim1139Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   17  ,   11  ,   93  ,   205 ,   33  ,   493 ,   1353    ,   3777    ,   2521    ,   13405   ,0 };
            const std::uint32_t dim1140Kuo3Init[]   =   {   1   ,   3   ,   3   ,   5   ,   5   ,   3   ,   25  ,   215 ,   209 ,   559 ,   465 ,   1809    ,   6621    ,   8733    ,0 };
            const std::uint32_t dim1141Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   23  ,   17  ,   75  ,   11  ,   299 ,   613 ,   565 ,   3487    ,   5017    ,   6187    ,0 };
            const std::uint32_t dim1142Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   15  ,   41  ,   121 ,   225 ,   259 ,   283 ,   1119    ,   3509    ,   6663    ,   241 ,0 };
            const std::uint32_t dim1143Kuo3Init[]   =   {   1   ,   3   ,   3   ,   5   ,   17  ,   49  ,   5   ,   227 ,   493 ,   677 ,   1365    ,   3681    ,   1651    ,   5079    ,0 };
            const std::uint32_t dim1144Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   3   ,   13  ,   43  ,   219 ,   247 ,   223 ,   1451    ,   1449    ,   605 ,   5877    ,0 };
            const std::uint32_t dim1145Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   21  ,   47  ,   7   ,   197 ,   387 ,   59  ,   7   ,   3209    ,   5623    ,   1221    ,0 };
            const std::uint32_t dim1146Kuo3Init[]   =   {   1   ,   3   ,   3   ,   5   ,   25  ,   5   ,   97  ,   1   ,   105 ,   801 ,   815 ,   1635    ,   3567    ,   5231    ,0 };
            const std::uint32_t dim1147Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   17  ,   21  ,   101 ,   167 ,   265 ,   407 ,   1859    ,   3359    ,   1245    ,   4153    ,0 };
            const std::uint32_t dim1148Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   31  ,   61  ,   21  ,   101 ,   77  ,   325 ,   645 ,   2059    ,   3201    ,   527 ,0 };
            const std::uint32_t dim1149Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   29  ,   55  ,   107 ,   135 ,   55  ,   433 ,   1519    ,   1049    ,   6119    ,   15877   ,0 };
            const std::uint32_t dim1150Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   19  ,   29  ,   1   ,   167 ,   13  ,   67  ,   1703    ,   1159    ,   7145    ,   4243    ,0 };
            const std::uint32_t dim1151Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   1   ,   33  ,   7   ,   21  ,   407 ,   695 ,   345 ,   425 ,   7399    ,   3847    ,0 };
            const std::uint32_t dim1152Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   15  ,   59  ,   121 ,   175 ,   21  ,   859 ,   1311    ,   1365    ,   3823    ,   3983    ,0 };
            const std::uint32_t dim1153Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   29  ,   21  ,   111 ,   221 ,   429 ,   739 ,   985 ,   1989    ,   4947    ,   8311    ,0 };
            const std::uint32_t dim1154Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   29  ,   17  ,   103 ,   39  ,   475 ,   193 ,   253 ,   1903    ,   4073    ,   15039   ,0 };
            const std::uint32_t dim1155Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   1   ,   57  ,   35  ,   197 ,   89  ,   475 ,   283 ,   2291    ,   7129    ,   14357   ,0 };
            const std::uint32_t dim1156Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   15  ,   63  ,   29  ,   157 ,   211 ,   517 ,   1643    ,   199 ,   285 ,   8621    ,0 };
            const std::uint32_t dim1157Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   9   ,   47  ,   43  ,   215 ,   407 ,   979 ,   51  ,   635 ,   467 ,   6365    ,0 };
            const std::uint32_t dim1158Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   23  ,   27  ,   97  ,   111 ,   51  ,   407 ,   1037    ,   1337    ,   1475    ,   1151    ,0 };
            const std::uint32_t dim1159Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   13  ,   45  ,   67  ,   51  ,   331 ,   691 ,   1137    ,   1967    ,   5715    ,   3125    ,0 };
            const std::uint32_t dim1160Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   31  ,   19  ,   85  ,   221 ,   449 ,   689 ,   1817    ,   1575    ,   7429    ,   12125   ,0 };
            const std::uint32_t dim1161Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   21  ,   61  ,   77  ,   55  ,   65  ,   591 ,   9   ,   2477    ,   4081    ,   4631    ,0 };
            const std::uint32_t dim1162Kuo3Init[]   =   {   1   ,   3   ,   5   ,   9   ,   27  ,   45  ,   29  ,   159 ,   21  ,   931 ,   1939    ,   1297    ,   5589    ,   12635   ,0 };
            const std::uint32_t dim1163Kuo3Init[]   =   {   1   ,   1   ,   7   ,   9   ,   21  ,   41  ,   7   ,   171 ,   461 ,   373 ,   1655    ,   3475    ,   4073    ,   4859    ,0 };
            const std::uint32_t dim1164Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   17  ,   35  ,   3   ,   41  ,   45  ,   37  ,   1409    ,   3939    ,   5497    ,   3501    ,0 };
            const std::uint32_t dim1165Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   11  ,   57  ,   121 ,   177 ,   177 ,   515 ,   675 ,   1943    ,   2645    ,   2469    ,0 };
            const std::uint32_t dim1166Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   23  ,   63  ,   29  ,   157 ,   157 ,   397 ,   1131    ,   1479    ,   4683    ,   10011   ,0 };
            const std::uint32_t dim1167Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   15  ,   35  ,   75  ,   99  ,   195 ,   589 ,   19  ,   3427    ,   1623    ,   12843   ,0 };
            const std::uint32_t dim1168Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   21  ,   19  ,   101 ,   135 ,   351 ,   549 ,   223 ,   517 ,   4023    ,   1863    ,0 };
            const std::uint32_t dim1169Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   7   ,   23  ,   67  ,   15  ,   217 ,   915 ,   1617    ,   1527    ,   877 ,   15061   ,0 };
            const std::uint32_t dim1170Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   11  ,   35  ,   95  ,   5   ,   399 ,   669 ,   1185    ,   167 ,   7405    ,   11169   ,0 };
            const std::uint32_t dim1171Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   1   ,   49  ,   91  ,   125 ,   185 ,   73  ,   263 ,   1139    ,   3171    ,   5427    ,0 };
            const std::uint32_t dim1172Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   27  ,   51  ,   89  ,   81  ,   179 ,   593 ,   67  ,   1495    ,   3669    ,   15981   ,0 };
            const std::uint32_t dim1173Kuo3Init[]   =   {   1   ,   3   ,   1   ,   11  ,   29  ,   63  ,   47  ,   105 ,   327 ,   747 ,   953 ,   2399    ,   6711    ,   16313   ,0 };
            const std::uint32_t dim1174Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   21  ,   21  ,   117 ,   179 ,   427 ,   981 ,   2029    ,   1   ,   495 ,   4005    ,0 };
            const std::uint32_t dim1175Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   23  ,   21  ,   59  ,   99  ,   459 ,   217 ,   1131    ,   1853    ,   3049    ,   2247    ,0 };
            const std::uint32_t dim1176Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   29  ,   9   ,   71  ,   167 ,   55  ,   775 ,   627 ,   3967    ,   45  ,   11199   ,0 };
            const std::uint32_t dim1177Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   29  ,   25  ,   1   ,   69  ,   317 ,   649 ,   1567    ,   2587    ,   2277    ,   15675   ,0 };
            const std::uint32_t dim1178Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   21  ,   3   ,   39  ,   147 ,   279 ,   953 ,   1207    ,   333 ,   2747    ,   1717    ,0 };
            const std::uint32_t dim1179Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   31  ,   63  ,   113 ,   149 ,   431 ,   699 ,   335 ,   2475    ,   6375    ,   13061   ,0 };
            const std::uint32_t dim1180Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   11  ,   19  ,   51  ,   175 ,   377 ,   971 ,   35  ,   2749    ,   6309    ,   4755    ,0 };
            const std::uint32_t dim1181Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   27  ,   53  ,   105 ,   221 ,   15  ,   495 ,   799 ,   1717    ,   6997    ,   15949   ,0 };
            const std::uint32_t dim1182Kuo3Init[]   =   {   1   ,   1   ,   1   ,   15  ,   31  ,   29  ,   69  ,   137 ,   421 ,   231 ,   2021    ,   1869    ,   4533    ,   1121    ,0 };
            const std::uint32_t dim1183Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   15  ,   49  ,   17  ,   121 ,   285 ,   303 ,   1085    ,   2463    ,   357 ,   2519    ,0 };
            const std::uint32_t dim1184Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   29  ,   47  ,   109 ,   95  ,   339 ,   15  ,   1195    ,   2171    ,   4649    ,   6517    ,0 };
            const std::uint32_t dim1185Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   29  ,   19  ,   45  ,   93  ,   47  ,   827 ,   1113    ,   4055    ,   601 ,   10807   ,0 };
            const std::uint32_t dim1186Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   15  ,   47  ,   11  ,   79  ,   137 ,   267 ,   1443    ,   1003    ,   2475    ,   147 ,0 };
            const std::uint32_t dim1187Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   11  ,   39  ,   95  ,   191 ,   205 ,   967 ,   333 ,   3371    ,   4913    ,   15231   ,0 };
            const std::uint32_t dim1188Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   25  ,   9   ,   47  ,   75  ,   77  ,   539 ,   487 ,   361 ,   2293    ,   7285    ,0 };
            const std::uint32_t dim1189Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   27  ,   11  ,   93  ,   181 ,   455 ,   277 ,   1001    ,   3313    ,   7335    ,   4593    ,0 };
            const std::uint32_t dim1190Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   15  ,   35  ,   107 ,   51  ,   223 ,   447 ,   371 ,   1739    ,   1937    ,   3589    ,0 };
            const std::uint32_t dim1191Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   15  ,   51  ,   23  ,   129 ,   285 ,   895 ,   2015    ,   1389    ,   2043    ,   1989    ,0 };
            const std::uint32_t dim1192Kuo3Init[]   =   {   1   ,   1   ,   5   ,   7   ,   21  ,   57  ,   107 ,   149 ,   285 ,   825 ,   959 ,   827 ,   2931    ,   3207    ,0 };
            const std::uint32_t dim1193Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   23  ,   19  ,   91  ,   15  ,   261 ,   785 ,   1031    ,   2245    ,   505 ,   14891   ,0 };
            const std::uint32_t dim1194Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   23  ,   21  ,   33  ,   153 ,   71  ,   757 ,   1131    ,   3251    ,   877 ,   4533    ,0 };
            const std::uint32_t dim1195Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   25  ,   39  ,   33  ,   231 ,   451 ,   587 ,   781 ,   1145    ,   4743    ,   467 ,0 };
            const std::uint32_t dim1196Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   23  ,   7   ,   35  ,   45  ,   397 ,   41  ,   1443    ,   2087    ,   587 ,   14139   ,0 };
            const std::uint32_t dim1197Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   19  ,   57  ,   61  ,   225 ,   197 ,   263 ,   1447    ,   1929    ,   2833    ,   5325    ,0 };
            const std::uint32_t dim1198Kuo3Init[]   =   {   1   ,   1   ,   5   ,   7   ,   25  ,   51  ,   45  ,   221 ,   403 ,   843 ,   727 ,   3099    ,   3883    ,   9151    ,0 };
            const std::uint32_t dim1199Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   9   ,   23  ,   33  ,   119 ,   81  ,   525 ,   1527    ,   567 ,   2867    ,   12907   ,0 };
            const std::uint32_t dim1200Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   11  ,   19  ,   125 ,   135 ,   427 ,   949 ,   643 ,   3403    ,   6531    ,   12607   ,0 };
            const std::uint32_t dim1201Kuo3Init[]   =   {   1   ,   3   ,   3   ,   7   ,   27  ,   23  ,   89  ,   83  ,   381 ,   333 ,   361 ,   2773    ,   4247    ,   10233   ,0 };
            const std::uint32_t dim1202Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   25  ,   61  ,   105 ,   141 ,   473 ,   993 ,   379 ,   2949    ,   5757    ,   4003    ,0 };
            const std::uint32_t dim1203Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   27  ,   29  ,   75  ,   175 ,   391 ,   567 ,   1017    ,   1575    ,   5287    ,   16289   ,0 };
            const std::uint32_t dim1204Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   7   ,   33  ,   23  ,   137 ,   299 ,   19  ,   599 ,   2649    ,   6141    ,   3321    ,0 };
            const std::uint32_t dim1205Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   3   ,   19  ,   101 ,   95  ,   499 ,   261 ,   51  ,   43  ,   5457    ,   313 ,0 };
            const std::uint32_t dim1206Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   27  ,   5   ,   7   ,   85  ,   419 ,   983 ,   1965    ,   1639    ,   6397    ,   15823   ,0 };
            const std::uint32_t dim1207Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   13  ,   55  ,   121 ,   13  ,   289 ,   791 ,   437 ,   3279    ,   7125    ,   10473   ,0 };
            const std::uint32_t dim1208Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   13  ,   15  ,   25  ,   9   ,   21  ,   205 ,   61  ,   749 ,   8005    ,   9453    ,0 };
            const std::uint32_t dim1209Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   19  ,   47  ,   55  ,   113 ,   325 ,   165 ,   771 ,   3655    ,   6265    ,   11157   ,0 };
            const std::uint32_t dim1210Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   19  ,   45  ,   107 ,   37  ,   205 ,   677 ,   1273    ,   3817    ,   559 ,   11321   ,0 };
            const std::uint32_t dim1211Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   31  ,   57  ,   87  ,   31  ,   431 ,   383 ,   327 ,   2703    ,   4197    ,   7861    ,0 };
            const std::uint32_t dim1212Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   3   ,   33  ,   39  ,   253 ,   215 ,   903 ,   447 ,   2175    ,   5249    ,   3203    ,0 };
            const std::uint32_t dim1213Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   15  ,   5   ,   27  ,   145 ,   391 ,   869 ,   1641    ,   2497    ,   4683    ,   3111    ,0 };
            const std::uint32_t dim1214Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   3   ,   33  ,   39  ,   223 ,   379 ,   803 ,   1833    ,   1799    ,   2617    ,   2113    ,0 };
            const std::uint32_t dim1215Kuo3Init[]   =   {   1   ,   3   ,   1   ,   15  ,   29  ,   37  ,   57  ,   227 ,   425 ,   943 ,   311 ,   2883    ,   2973    ,   1831    ,0 };
            const std::uint32_t dim1216Kuo3Init[]   =   {   1   ,   3   ,   3   ,   5   ,   17  ,   63  ,   113 ,   139 ,   453 ,   871 ,   1029    ,   2705    ,   3379    ,   4503    ,0 };
            const std::uint32_t dim1217Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   19  ,   35  ,   43  ,   151 ,   511 ,   657 ,   1885    ,   1425    ,   387 ,   2165    ,0 };
            const std::uint32_t dim1218Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   9   ,   61  ,   123 ,   241 ,   485 ,   485 ,   955 ,   1215    ,   87  ,   3195    ,0 };
            const std::uint32_t dim1219Kuo3Init[]   =   {   1   ,   3   ,   5   ,   9   ,   23  ,   45  ,   51  ,   15  ,   23  ,   49  ,   2025    ,   853 ,   6609    ,   12099   ,0 };
            const std::uint32_t dim1220Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   23  ,   35  ,   95  ,   67  ,   131 ,   281 ,   1821    ,   1951    ,   1363    ,   7477    ,0 };
            const std::uint32_t dim1221Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   9   ,   53  ,   79  ,   255 ,   453 ,   77  ,   629 ,   1207    ,   4171    ,   4415    ,0 };
            const std::uint32_t dim1222Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   23  ,   5   ,   11  ,   153 ,   57  ,   217 ,   1177    ,   2297    ,   3515    ,   15121   ,0 };
            const std::uint32_t dim1223Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   31  ,   57  ,   93  ,   35  ,   177 ,   449 ,   1505    ,   2715    ,   1315    ,   8953    ,0 };
            const std::uint32_t dim1224Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   7   ,   7   ,   109 ,   255 ,   317 ,   325 ,   267 ,   2573    ,   1511    ,   3371    ,0 };
            const std::uint32_t dim1225Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   13  ,   51  ,   29  ,   203 ,   13  ,   889 ,   679 ,   1981    ,   5553    ,   671 ,0 };
            const std::uint32_t dim1226Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   29  ,   11  ,   29  ,   249 ,   289 ,   817 ,   1983    ,   1865    ,   6705    ,   9667    ,0 };
            const std::uint32_t dim1227Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   15  ,   19  ,   23  ,   59  ,   143 ,   815 ,   643 ,   763 ,   1437    ,   2909    ,0 };
            const std::uint32_t dim1228Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   15  ,   61  ,   121 ,   73  ,   367 ,   13  ,   1455    ,   561 ,   7475    ,   8479    ,0 };
            const std::uint32_t dim1229Kuo3Init[]   =   {   1   ,   3   ,   1   ,   15  ,   17  ,   19  ,   105 ,   223 ,   481 ,   49  ,   217 ,   2935    ,   2731    ,   9857    ,0 };
            const std::uint32_t dim1230Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   3   ,   41  ,   3   ,   195 ,   245 ,   969 ,   139 ,   2727    ,   6957    ,   2049    ,0 };
            const std::uint32_t dim1231Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   13  ,   39  ,   55  ,   247 ,   279 ,   991 ,   875 ,   1393    ,   2649    ,   14477   ,0 };
            const std::uint32_t dim1232Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   19  ,   1   ,   83  ,   87  ,   277 ,   939 ,   105 ,   681 ,   5377    ,   16067   ,0 };
            const std::uint32_t dim1233Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   29  ,   9   ,   63  ,   67  ,   97  ,   457 ,   179 ,   1137    ,   5067    ,   14541   ,0 };
            const std::uint32_t dim1234Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   25  ,   23  ,   17  ,   175 ,   33  ,   523 ,   2023    ,   649 ,   6889    ,   3481    ,0 };
            const std::uint32_t dim1235Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   13  ,   7   ,   7   ,   145 ,   81  ,   69  ,   1029    ,   1351    ,   285 ,   13007   ,0 };
            const std::uint32_t dim1236Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   3   ,   23  ,   107 ,   67  ,   327 ,   463 ,   1123    ,   1981    ,   1189    ,   6921    ,0 };
            const std::uint32_t dim1237Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   15  ,   31  ,   15  ,   51  ,   421 ,   191 ,   1663    ,   2257    ,   2633    ,   4685    ,0 };
            const std::uint32_t dim1238Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   9   ,   41  ,   101 ,   43  ,   23  ,   453 ,   1399    ,   2349    ,   8013    ,   15791   ,0 };
            const std::uint32_t dim1239Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   27  ,   47  ,   15  ,   193 ,   99  ,   355 ,   1873    ,   1541    ,   5957    ,   13079   ,0 };
            const std::uint32_t dim1240Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   11  ,   45  ,   43  ,   171 ,   355 ,   17  ,   955 ,   1153    ,   1437    ,   5477    ,0 };
            const std::uint32_t dim1241Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   29  ,   25  ,   11  ,   231 ,   79  ,   951 ,   1619    ,   69  ,   2279    ,   7249    ,0 };
            const std::uint32_t dim1242Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   5   ,   41  ,   47  ,   229 ,   353 ,   261 ,   443 ,   1181    ,   1813    ,   7929    ,0 };
            const std::uint32_t dim1243Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   19  ,   45  ,   69  ,   11  ,   209 ,   477 ,   1623    ,   429 ,   1853    ,   13571   ,0 };
            const std::uint32_t dim1244Kuo3Init[]   =   {   1   ,   3   ,   3   ,   5   ,   19  ,   55  ,   49  ,   243 ,   357 ,   675 ,   129 ,   2801    ,   2511    ,   12965   ,0 };
            const std::uint32_t dim1245Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   11  ,   47  ,   11  ,   11  ,   291 ,   943 ,   573 ,   2257    ,   1767    ,   2547    ,0 };
            const std::uint32_t dim1246Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   1   ,   11  ,   103 ,   65  ,   395 ,   623 ,   697 ,   3375    ,   7977    ,   13449   ,0 };
            const std::uint32_t dim1247Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   3   ,   35  ,   69  ,   59  ,   85  ,   379 ,   835 ,   557 ,   873 ,   16281   ,0 };
            const std::uint32_t dim1248Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   31  ,   41  ,   59  ,   137 ,   297 ,   43  ,   1111    ,   2119    ,   3109    ,   1551    ,0 };
            const std::uint32_t dim1249Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   11  ,   11  ,   87  ,   199 ,   283 ,   461 ,   951 ,   2429    ,   6739    ,   11499   ,0 };
            const std::uint32_t dim1250Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   31  ,   13  ,   89  ,   75  ,   117 ,   755 ,   1761    ,   581 ,   7233    ,   8395    ,0 };
            const std::uint32_t dim1251Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   1   ,   29  ,   117 ,   213 ,   81  ,   901 ,   357 ,   27  ,   127 ,   10541   ,0 };
            const std::uint32_t dim1252Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   31  ,   1   ,   11  ,   243 ,   321 ,   973 ,   1753    ,   2363    ,   6717    ,   14861   ,0 };
            const std::uint32_t dim1253Kuo3Init[]   =   {   1   ,   1   ,   1   ,   1   ,   17  ,   25  ,   35  ,   211 ,   197 ,   697 ,   1389    ,   1371    ,   3687    ,   11941   ,0 };
            const std::uint32_t dim1254Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   15  ,   35  ,   27  ,   179 ,   367 ,   891 ,   483 ,   3581    ,   4343    ,   9581    ,0 };
            const std::uint32_t dim1255Kuo3Init[]   =   {   1   ,   3   ,   5   ,   1   ,   13  ,   41  ,   67  ,   75  ,   309 ,   601 ,   247 ,   1609    ,   4365    ,   3003    ,0 };
            const std::uint32_t dim1256Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   1   ,   59  ,   55  ,   213 ,   415 ,   445 ,   1763    ,   3615    ,   6847    ,   11931   ,0 };
            const std::uint32_t dim1257Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   25  ,   53  ,   9   ,   63  ,   501 ,   95  ,   1745    ,   3273    ,   3551    ,   12733   ,0 };
            const std::uint32_t dim1258Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   13  ,   23  ,   117 ,   75  ,   169 ,   11  ,   1401    ,   125 ,   2127    ,   15609   ,0 };
            const std::uint32_t dim1259Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   21  ,   53  ,   113 ,   247 ,   495 ,   39  ,   1491    ,   985 ,   4943    ,   3683    ,0 };
            const std::uint32_t dim1260Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   5   ,   49  ,   23  ,   207 ,   43  ,   863 ,   749 ,   3363    ,   1191    ,   1305    ,0 };
            const std::uint32_t dim1261Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   3   ,   13  ,   19  ,   123 ,   377 ,   803 ,   319 ,   2617    ,   7781    ,   5113    ,0 };
            const std::uint32_t dim1262Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   23  ,   53  ,   19  ,   223 ,   63  ,   729 ,   599 ,   2437    ,   1023    ,   13659   ,0 };
            const std::uint32_t dim1263Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   7   ,   31  ,   101 ,   227 ,   53  ,   933 ,   405 ,   1077    ,   1341    ,   12049   ,0 };
            const std::uint32_t dim1264Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   21  ,   31  ,   65  ,   191 ,   175 ,   735 ,   593 ,   805 ,   4405    ,   7893    ,0 };
            const std::uint32_t dim1265Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   11  ,   23  ,   57  ,   71  ,   367 ,   275 ,   715 ,   81  ,   6455    ,   9509    ,0 };
            const std::uint32_t dim1266Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   7   ,   5   ,   99  ,   19  ,   193 ,   501 ,   243 ,   1971    ,   4685    ,   455 ,0 };
            const std::uint32_t dim1267Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   11  ,   59  ,   45  ,   241 ,   257 ,   107 ,   605 ,   3885    ,   813 ,   15667   ,0 };
            const std::uint32_t dim1268Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   17  ,   63  ,   93  ,   129 ,   191 ,   839 ,   535 ,   271 ,   1087    ,   10393   ,0 };
            const std::uint32_t dim1269Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   19  ,   15  ,   11  ,   85  ,   377 ,   653 ,   891 ,   1909    ,   5561    ,   1289    ,0 };
            const std::uint32_t dim1270Kuo3Init[]   =   {   1   ,   3   ,   1   ,   15  ,   7   ,   25  ,   25  ,   67  ,   55  ,   749 ,   1541    ,   1183    ,   1563    ,   5377    ,0 };
            const std::uint32_t dim1271Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   11  ,   57  ,   121 ,   173 ,   317 ,   777 ,   749 ,   4037    ,   123 ,   10707   ,0 };
            const std::uint32_t dim1272Kuo3Init[]   =   {   1   ,   3   ,   3   ,   5   ,   29  ,   45  ,   99  ,   215 ,   103 ,   447 ,   1743    ,   991 ,   7649    ,   11773   ,0 };
            const std::uint32_t dim1273Kuo3Init[]   =   {   1   ,   1   ,   5   ,   7   ,   3   ,   33  ,   39  ,   169 ,   255 ,   383 ,   559 ,   3635    ,   5669    ,   4267    ,0 };
            const std::uint32_t dim1274Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   15  ,   41  ,   51  ,   69  ,   373 ,   815 ,   293 ,   2125    ,   4903    ,   12429   ,0 };
            const std::uint32_t dim1275Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   17  ,   53  ,   101 ,   153 ,   271 ,   491 ,   801 ,   2811    ,   619 ,   2021    ,0 };
            const std::uint32_t dim1276Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   25  ,   37  ,   33  ,   139 ,   385 ,   323 ,   601 ,   1077    ,   753 ,   3925    ,0 };
            const std::uint32_t dim1277Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   25  ,   21  ,   127 ,   67  ,   463 ,   121 ,   1765    ,   1561    ,   5   ,   5161    ,0 };
            const std::uint32_t dim1278Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   25  ,   27  ,   37  ,   159 ,   453 ,   847 ,   353 ,   3051    ,   4269    ,   13981   ,0 };
            const std::uint32_t dim1279Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   13  ,   1   ,   11  ,   123 ,   459 ,   989 ,   1459    ,   3793    ,   5915    ,   8411    ,0 };
            const std::uint32_t dim1280Kuo3Init[]   =   {   1   ,   3   ,   1   ,   15  ,   5   ,   21  ,   37  ,   41  ,   399 ,   471 ,   1147    ,   143 ,   2737    ,   9447    ,0 };
            const std::uint32_t dim1281Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   27  ,   5   ,   121 ,   77  ,   183 ,   209 ,   49  ,   3737    ,   4317    ,   11225   ,0 };
            const std::uint32_t dim1282Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   5   ,   9   ,   65  ,   25  ,   237 ,   21  ,   139 ,   1729    ,   965 ,   15419   ,0 };
            const std::uint32_t dim1283Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   5   ,   47  ,   115 ,   211 ,   495 ,   97  ,   1439    ,   127 ,   4823    ,   11643   ,0 };
            const std::uint32_t dim1284Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   11  ,   37  ,   19  ,   129 ,   35  ,   1017    ,   1057    ,   3501    ,   4293    ,   15271   ,0 };
            const std::uint32_t dim1285Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   3   ,   31  ,   45  ,   25  ,   441 ,   729 ,   909 ,   3519    ,   5579    ,   10341   ,0 };
            const std::uint32_t dim1286Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   23  ,   55  ,   13  ,   47  ,   25  ,   319 ,   697 ,   2839    ,   209 ,   5007    ,0 };
            const std::uint32_t dim1287Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   31  ,   7   ,   81  ,   239 ,   305 ,   667 ,   233 ,   3555    ,   7385    ,   10113   ,0 };
            const std::uint32_t dim1288Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   23  ,   7   ,   101 ,   193 ,   343 ,   435 ,   1065    ,   3399    ,   1855    ,   15231   ,0 };
            const std::uint32_t dim1289Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   3   ,   31  ,   13  ,   51  ,   141 ,   523 ,   1545    ,   31  ,   3827    ,   13871   ,0 };
            const std::uint32_t dim1290Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   29  ,   37  ,   117 ,   187 ,   337 ,   799 ,   923 ,   3919    ,   5861    ,   3167    ,0 };
            const std::uint32_t dim1291Kuo3Init[]   =   {   1   ,   3   ,   7   ,   1   ,   21  ,   17  ,   59  ,   73  ,   223 ,   455 ,   2025    ,   2701    ,   673 ,   8333    ,0 };
            const std::uint32_t dim1292Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   9   ,   53  ,   99  ,   87  ,   35  ,   637 ,   1553    ,   1417    ,   1233    ,   855 ,0 };
            const std::uint32_t dim1293Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   25  ,   21  ,   3   ,   227 ,   345 ,   711 ,   1347    ,   437 ,   7513    ,   7731    ,0 };
            const std::uint32_t dim1294Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   5   ,   51  ,   125 ,   133 ,   241 ,   327 ,   589 ,   1895    ,   1627    ,   6945    ,0 };
            const std::uint32_t dim1295Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   21  ,   19  ,   101 ,   95  ,   143 ,   353 ,   1783    ,   2815    ,   3691    ,   11209   ,0 };
            const std::uint32_t dim1296Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   31  ,   29  ,   95  ,   121 ,   253 ,   925 ,   277 ,   2857    ,   963 ,   7701    ,0 };
            const std::uint32_t dim1297Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   3   ,   23  ,   31  ,   63  ,   467 ,   91  ,   1235    ,   1927    ,   4347    ,   9281    ,0 };
            const std::uint32_t dim1298Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   21  ,   23  ,   113 ,   219 ,   69  ,   13  ,   1165    ,   1043    ,   6335    ,   3499    ,0 };
            const std::uint32_t dim1299Kuo3Init[]   =   {   1   ,   1   ,   7   ,   15  ,   25  ,   35  ,   67  ,   67  ,   273 ,   421 ,   521 ,   1169    ,   1557    ,   1523    ,0 };
            const std::uint32_t dim1300Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   25  ,   5   ,   19  ,   157 ,   385 ,   35  ,   1701    ,   1697    ,   1425    ,   12549   ,0 };
            const std::uint32_t dim1301Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   15  ,   13  ,   31  ,   219 ,   159 ,   831 ,   909 ,   1907    ,   4251    ,   4231    ,0 };
            const std::uint32_t dim1302Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   27  ,   51  ,   19  ,   205 ,   177 ,   769 ,   1881    ,   3961    ,   7715    ,   13351   ,0 };
            const std::uint32_t dim1303Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   13  ,   19  ,   1   ,   91  ,   257 ,   201 ,   459 ,   525 ,   5093    ,   7259    ,0 };
            const std::uint32_t dim1304Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   3   ,   37  ,   87  ,   117 ,   209 ,   9   ,   1019    ,   195 ,   1531    ,   14445   ,0 };
            const std::uint32_t dim1305Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   23  ,   35  ,   21  ,   27  ,   455 ,   665 ,   455 ,   1009    ,   2315    ,   11465   ,0 };
            const std::uint32_t dim1306Kuo3Init[]   =   {   1   ,   3   ,   7   ,   1   ,   17  ,   55  ,   3   ,   71  ,   239 ,   183 ,   889 ,   2091    ,   2853    ,   12541   ,0 };
            const std::uint32_t dim1307Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   5   ,   7   ,   67  ,   127 ,   411 ,   719 ,   835 ,   2299    ,   1339    ,   12149   ,0 };
            const std::uint32_t dim1308Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   7   ,   21  ,   113 ,   199 ,   17  ,   161 ,   1945    ,   1141    ,   4879    ,   1579    ,0 };
            const std::uint32_t dim1309Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   5   ,   9   ,   35  ,   169 ,   317 ,   355 ,   193 ,   599 ,   7653    ,   7689    ,0 };
            const std::uint32_t dim1310Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   29  ,   35  ,   59  ,   85  ,   139 ,   199 ,   1075    ,   2799    ,   6263    ,   11133   ,0 };
            const std::uint32_t dim1311Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   19  ,   63  ,   13  ,   41  ,   289 ,   845 ,   1455    ,   633 ,   4995    ,   2037    ,0 };
            const std::uint32_t dim1312Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   19  ,   25  ,   65  ,   213 ,   27  ,   257 ,   1151    ,   4063    ,   5587    ,   2205    ,0 };
            const std::uint32_t dim1313Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   9   ,   53  ,   103 ,   49  ,   187 ,   579 ,   801 ,   263 ,   2975    ,   12013   ,0 };
            const std::uint32_t dim1314Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   7   ,   13  ,   85  ,   11  ,   365 ,   63  ,   595 ,   747 ,   1565    ,   1817    ,0 };
            const std::uint32_t dim1315Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   11  ,   1   ,   45  ,   3   ,   181 ,   357 ,   447 ,   821 ,   6471    ,   10121   ,0 };
            const std::uint32_t dim1316Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   7   ,   25  ,   75  ,   139 ,   463 ,   679 ,   1327    ,   2863    ,   2373    ,   10681   ,0 };
            const std::uint32_t dim1317Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   17  ,   7   ,   103 ,   157 ,   241 ,   781 ,   399 ,   3951    ,   6587    ,   35  ,0 };
            const std::uint32_t dim1318Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   17  ,   29  ,   71  ,   115 ,   415 ,   91  ,   729 ,   3055    ,   5219    ,   15271   ,0 };
            const std::uint32_t dim1319Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   7   ,   5   ,   123 ,   235 ,   33  ,   103 ,   257 ,   1151    ,   3931    ,   16257   ,0 };
            const std::uint32_t dim1320Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   27  ,   29  ,   29  ,   31  ,   463 ,   187 ,   103 ,   209 ,   747 ,   14311   ,0 };
            const std::uint32_t dim1321Kuo3Init[]   =   {   1   ,   3   ,   5   ,   1   ,   11  ,   61  ,   79  ,   103 ,   233 ,   733 ,   779 ,   705 ,   2377    ,   12689   ,0 };
            const std::uint32_t dim1322Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   31  ,   11  ,   123 ,   239 ,   227 ,   81  ,   525 ,   2099    ,   8149    ,   5851    ,0 };
            const std::uint32_t dim1323Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   1   ,   37  ,   9   ,   199 ,   313 ,   875 ,   975 ,   777 ,   5449    ,   3075    ,0 };
            const std::uint32_t dim1324Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   7   ,   29  ,   5   ,   133 ,   419 ,   691 ,   859 ,   1089    ,   4331    ,   11079   ,0 };
            const std::uint32_t dim1325Kuo3Init[]   =   {   1   ,   1   ,   1   ,   1   ,   5   ,   57  ,   113 ,   17  ,   481 ,   989 ,   233 ,   1523    ,   3291    ,   1665    ,0 };
            const std::uint32_t dim1326Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   27  ,   31  ,   43  ,   247 ,   403 ,   395 ,   69  ,   2561    ,   7281    ,   7291    ,0 };
            const std::uint32_t dim1327Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   31  ,   43  ,   105 ,   237 ,   21  ,   719 ,   861 ,   199 ,   1045    ,   7689    ,0 };
            const std::uint32_t dim1328Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   1   ,   15  ,   3   ,   35  ,   219 ,   993 ,   891 ,   3649    ,   3795    ,   11599   ,0 };
            const std::uint32_t dim1329Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   7   ,   15  ,   125 ,   243 ,   449 ,   173 ,   1041    ,   1433    ,   6559    ,   14285   ,0 };
            const std::uint32_t dim1330Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   1   ,   5   ,   75  ,   189 ,   439 ,   745 ,   1361    ,   3525    ,   2913    ,   10513   ,0 };
            const std::uint32_t dim1331Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   31  ,   7   ,   49  ,   41  ,   413 ,   347 ,   881 ,   2953    ,   2173    ,   8667    ,0 };
            const std::uint32_t dim1332Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   27  ,   33  ,   75  ,   99  ,   451 ,   207 ,   1847    ,   1285    ,   3217    ,   7899    ,0 };
            const std::uint32_t dim1333Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   21  ,   63  ,   87  ,   11  ,   429 ,   591 ,   1471    ,   3221    ,   2441    ,   2889    ,0 };
            const std::uint32_t dim1334Kuo3Init[]   =   {   1   ,   3   ,   1   ,   15  ,   3   ,   47  ,   103 ,   219 ,   317 ,   605 ,   1709    ,   2473    ,   3511    ,   10035   ,0 };
            const std::uint32_t dim1335Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   13  ,   21  ,   117 ,   113 ,   443 ,   863 ,   201 ,   1293    ,   1291    ,   5537    ,0 };
            const std::uint32_t dim1336Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   3   ,   15  ,   59  ,   45  ,   135 ,   465 ,   1033    ,   605 ,   2783    ,   1001    ,0 };
            const std::uint32_t dim1337Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   25  ,   49  ,   125 ,   171 ,   231 ,   691 ,   1759    ,   3493    ,   1703    ,   4405    ,0 };
            const std::uint32_t dim1338Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   3   ,   31  ,   73  ,   31  ,   189 ,   533 ,   1191    ,   487 ,   6233    ,   5607    ,0 };
            const std::uint32_t dim1339Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   11  ,   23  ,   91  ,   207 ,   337 ,   225 ,   339 ,   2085    ,   6223    ,   16299   ,0 };
            const std::uint32_t dim1340Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   21  ,   35  ,   47  ,   81  ,   229 ,   815 ,   767 ,   1939    ,   1335    ,   1865    ,0 };
            const std::uint32_t dim1341Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   3   ,   11  ,   19  ,   253 ,   499 ,   13  ,   1771    ,   1461    ,   2339    ,   1217    ,0 };
            const std::uint32_t dim1342Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   15  ,   51  ,   91  ,   213 ,   435 ,   137 ,   551 ,   3483    ,   1485    ,   4061    ,0 };
            const std::uint32_t dim1343Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   23  ,   25  ,   57  ,   1   ,   147 ,   705 ,   399 ,   3061    ,   5921    ,   4201    ,0 };
            const std::uint32_t dim1344Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   9   ,   15  ,   53  ,   105 ,   175 ,   147 ,   1077    ,   2323    ,   6041    ,   9591    ,0 };
            const std::uint32_t dim1345Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   5   ,   17  ,   125 ,   243 ,   5   ,   329 ,   161 ,   795 ,   8105    ,   8385    ,0 };
            const std::uint32_t dim1346Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   9   ,   7   ,   83  ,   49  ,   83  ,   109 ,   759 ,   2197    ,   2587    ,   10715   ,0 };
            const std::uint32_t dim1347Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   17  ,   11  ,   33  ,   173 ,   133 ,   853 ,   1005    ,   3027    ,   2137    ,   14471   ,0 };
            const std::uint32_t dim1348Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   23  ,   19  ,   29  ,   169 ,   73  ,   405 ,   1175    ,   3179    ,   2449    ,   13447   ,0 };
            const std::uint32_t dim1349Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   21  ,   43  ,   1   ,   85  ,   387 ,   979 ,   571 ,   1849    ,   3287    ,   1201    ,0 };
            const std::uint32_t dim1350Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   15  ,   43  ,   125 ,   49  ,   365 ,   689 ,   1569    ,   719 ,   3925    ,   3781    ,0 };
            const std::uint32_t dim1351Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   11  ,   5   ,   39  ,   181 ,   39  ,   729 ,   641 ,   1983    ,   7321    ,   14747   ,0 };
            const std::uint32_t dim1352Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   11  ,   9   ,   115 ,   125 ,   305 ,   371 ,   1647    ,   463 ,   2473    ,   9029    ,0 };
            const std::uint32_t dim1353Kuo3Init[]   =   {   1   ,   1   ,   7   ,   15  ,   5   ,   11  ,   69  ,   177 ,   249 ,   235 ,   1843    ,   695 ,   7931    ,   10891   ,0 };
            const std::uint32_t dim1354Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   17  ,   57  ,   127 ,   135 ,   357 ,   315 ,   55  ,   2867    ,   4187    ,   15803   ,0 };
            const std::uint32_t dim1355Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   29  ,   23  ,   69  ,   179 ,   151 ,   813 ,   1317    ,   1943    ,   3995    ,   13023   ,0 };
            const std::uint32_t dim1356Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   9   ,   55  ,   39  ,   65  ,   3   ,   127 ,   1781    ,   117 ,   2651    ,   16111   ,0 };
            const std::uint32_t dim1357Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   31  ,   19  ,   89  ,   185 ,   351 ,   623 ,   1301    ,   3123    ,   5905    ,   7231    ,0 };
            const std::uint32_t dim1358Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   31  ,   25  ,   31  ,   163 ,   81  ,   927 ,   1171    ,   2667    ,   5699    ,   7555    ,0 };
            const std::uint32_t dim1359Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   17  ,   55  ,   83  ,   217 ,   97  ,   795 ,   1745    ,   875 ,   483 ,   3271    ,0 };
            const std::uint32_t dim1360Kuo3Init[]   =   {   1   ,   1   ,   1   ,   1   ,   9   ,   13  ,   19  ,   207 ,   325 ,   277 ,   1393    ,   2619    ,   3055    ,   8499    ,0 };
            const std::uint32_t dim1361Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   1   ,   11  ,   113 ,   181 ,   411 ,   55  ,   505 ,   3125    ,   619 ,   1749    ,0 };
            const std::uint32_t dim1362Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   11  ,   47  ,   25  ,   123 ,   143 ,   51  ,   1075    ,   715 ,   4647    ,   13995   ,0 };
            const std::uint32_t dim1363Kuo3Init[]   =   {   1   ,   1   ,   1   ,   1   ,   21  ,   23  ,   121 ,   217 ,   325 ,   589 ,   2017    ,   3027    ,   6175    ,   1293    ,0 };
            const std::uint32_t dim1364Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   3   ,   47  ,   35  ,   233 ,   381 ,   905 ,   1031    ,   2229    ,   2575    ,   6891    ,0 };
            const std::uint32_t dim1365Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   3   ,   33  ,   17  ,   39  ,   377 ,   635 ,   1281    ,   2673    ,   2101    ,   2921    ,0 };
            const std::uint32_t dim1366Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   13  ,   21  ,   43  ,   55  ,   353 ,   643 ,   533 ,   57  ,   5583    ,   2189    ,0 };
            const std::uint32_t dim1367Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   27  ,   15  ,   79  ,   47  ,   463 ,   327 ,   1231    ,   171 ,   4931    ,   7549    ,0 };
            const std::uint32_t dim1368Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   11  ,   27  ,   109 ,   15  ,   57  ,   35  ,   1347    ,   3061    ,   8179    ,   5461    ,0 };
            const std::uint32_t dim1369Kuo3Init[]   =   {   1   ,   3   ,   3   ,   7   ,   29  ,   57  ,   103 ,   221 ,   409 ,   437 ,   1541    ,   2591    ,   4757    ,   13735   ,0 };
            const std::uint32_t dim1370Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   3   ,   23  ,   115 ,   35  ,   165 ,   389 ,   1399    ,   2081    ,   3169    ,   1493    ,0 };
            const std::uint32_t dim1371Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   25  ,   27  ,   93  ,   253 ,   83  ,   557 ,   957 ,   2017    ,   2005    ,   10005   ,0 };
            const std::uint32_t dim1372Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   1   ,   33  ,   55  ,   227 ,   427 ,   595 ,   1235    ,   3815    ,   5397    ,   4827    ,0 };
            const std::uint32_t dim1373Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   31  ,   23  ,   53  ,   155 ,   177 ,   851 ,   531 ,   2441    ,   2049    ,   12209   ,0 };
            const std::uint32_t dim1374Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   21  ,   27  ,   13  ,   67  ,   467 ,   607 ,   611 ,   2565    ,   5907    ,   8441    ,0 };
            const std::uint32_t dim1375Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   31  ,   59  ,   99  ,   65  ,   403 ,   439 ,   1407    ,   2587    ,   3111    ,   8715    ,0 };
            const std::uint32_t dim1376Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   7   ,   3   ,   35  ,   69  ,   177 ,   591 ,   449 ,   369 ,   5047    ,   3435    ,0 };
            const std::uint32_t dim1377Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   17  ,   27  ,   9   ,   49  ,   161 ,   925 ,   603 ,   2555    ,   3349    ,   4913    ,0 };
            const std::uint32_t dim1378Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   11  ,   43  ,   89  ,   139 ,   163 ,   851 ,   1991    ,   3439    ,   227 ,   5875    ,0 };
            const std::uint32_t dim1379Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   15  ,   7   ,   63  ,   133 ,   437 ,   447 ,   1227    ,   3945    ,   3467    ,   14919   ,0 };
            const std::uint32_t dim1380Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   13  ,   49  ,   113 ,   39  ,   77  ,   773 ,   127 ,   3361    ,   2325    ,   987 ,0 };
            const std::uint32_t dim1381Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   31  ,   23  ,   69  ,   203 ,   189 ,   35  ,   647 ,   3507    ,   6679    ,   2097    ,0 };
            const std::uint32_t dim1382Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   23  ,   9   ,   99  ,   253 ,   203 ,   167 ,   1073    ,   435 ,   1745    ,   2155    ,0 };
            const std::uint32_t dim1383Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   11  ,   27  ,   15  ,   125 ,   291 ,   261 ,   1953    ,   3695    ,   6345    ,   8519    ,0 };
            const std::uint32_t dim1384Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   3   ,   39  ,   23  ,   143 ,   401 ,   587 ,   1729    ,   3083    ,   4255    ,   7427    ,0 };
            const std::uint32_t dim1385Kuo3Init[]   =   {   1   ,   1   ,   7   ,   9   ,   27  ,   7   ,   63  ,   153 ,   349 ,   1003    ,   1315    ,   841 ,   5991    ,   15647   ,0 };
            const std::uint32_t dim1386Kuo3Init[]   =   {   1   ,   3   ,   5   ,   1   ,   27  ,   45  ,   91  ,   245 ,   297 ,   485 ,   647 ,   91  ,   231 ,   5231    ,0 };
            const std::uint32_t dim1387Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   29  ,   43  ,   53  ,   79  ,   387 ,   977 ,   247 ,   371 ,   5823    ,   8335    ,0 };
            const std::uint32_t dim1388Kuo3Init[]   =   {   1   ,   3   ,   3   ,   5   ,   5   ,   17  ,   29  ,   71  ,   417 ,   201 ,   1495    ,   277 ,   2087    ,   15421   ,0 };
            const std::uint32_t dim1389Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   7   ,   47  ,   37  ,   171 ,   167 ,   355 ,   1845    ,   1747    ,   839 ,   7213    ,0 };
            const std::uint32_t dim1390Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   15  ,   29  ,   107 ,   35  ,   183 ,   735 ,   183 ,   2993    ,   6495    ,   981 ,0 };
            const std::uint32_t dim1391Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   3   ,   25  ,   25  ,   195 ,   461 ,   739 ,   861 ,   3027    ,   2007    ,   7771    ,0 };
            const std::uint32_t dim1392Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   29  ,   55  ,   115 ,   57  ,   67  ,   913 ,   1603    ,   2397    ,   949 ,   14671   ,0 };
            const std::uint32_t dim1393Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   27  ,   15  ,   51  ,   201 ,   127 ,   459 ,   1545    ,   3415    ,   1823    ,   1673    ,0 };
            const std::uint32_t dim1394Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   21  ,   43  ,   75  ,   59  ,   379 ,   1007    ,   1697    ,   763 ,   741 ,   3801    ,0 };
            const std::uint32_t dim1395Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   13  ,   41  ,   105 ,   235 ,   381 ,   465 ,   665 ,   877 ,   1025    ,   9041    ,0 };
            const std::uint32_t dim1396Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   3   ,   63  ,   65  ,   151 ,   167 ,   683 ,   327 ,   3545    ,   2531    ,   13479   ,0 };
            const std::uint32_t dim1397Kuo3Init[]   =   {   1   ,   3   ,   5   ,   1   ,   7   ,   25  ,   61  ,   137 ,   155 ,   5   ,   623 ,   649 ,   7235    ,   13495   ,0 };
            const std::uint32_t dim1398Kuo3Init[]   =   {   1   ,   3   ,   5   ,   1   ,   23  ,   33  ,   3   ,   45  ,   235 ,   909 ,   1619    ,   2843    ,   5307    ,   14345   ,0 };
            const std::uint32_t dim1399Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   29  ,   1   ,   67  ,   161 ,   237 ,   229 ,   1403    ,   3289    ,   399 ,   237 ,0 };
            const std::uint32_t dim1400Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   5   ,   27  ,   83  ,   133 ,   189 ,   277 ,   1975    ,   1399    ,   65  ,   13645   ,0 };
            const std::uint32_t dim1401Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   1   ,   41  ,   11  ,   121 ,   413 ,   413 ,   1817    ,   1533    ,   5299    ,   9089    ,0 };
            const std::uint32_t dim1402Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   15  ,   59  ,   75  ,   255 ,   419 ,   441 ,   1993    ,   573 ,   6025    ,   16375   ,0 };
            const std::uint32_t dim1403Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   3   ,   35  ,   117 ,   69  ,   473 ,   53  ,   1007    ,   2229    ,   1749    ,   14795   ,0 };
            const std::uint32_t dim1404Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   23  ,   27  ,   117 ,   183 ,   69  ,   689 ,   1903    ,   1851    ,   1143    ,   11959   ,0 };
            const std::uint32_t dim1405Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   3   ,   9   ,   125 ,   173 ,   365 ,   393 ,   1313    ,   3937    ,   1699    ,   15667   ,0 };
            const std::uint32_t dim1406Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   19  ,   3   ,   45  ,   181 ,   439 ,   61  ,   1139    ,   149 ,   1929    ,   15617   ,0 };
            const std::uint32_t dim1407Kuo3Init[]   =   {   1   ,   3   ,   7   ,   1   ,   13  ,   41  ,   43  ,   131 ,   79  ,   947 ,   1579    ,   2055    ,   451 ,   10875   ,0 };
            const std::uint32_t dim1408Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   27  ,   11  ,   105 ,   109 ,   503 ,   361 ,   27  ,   133 ,   801 ,   853 ,0 };
            const std::uint32_t dim1409Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   11  ,   43  ,   3   ,   233 ,   449 ,   557 ,   2003    ,   467 ,   5617    ,   7431    ,0 };
            const std::uint32_t dim1410Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   5   ,   31  ,   121 ,   13  ,   301 ,   433 ,   1719    ,   821 ,   8107    ,   13313   ,0 };
            const std::uint32_t dim1411Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   25  ,   17  ,   117 ,   81  ,   239 ,   219 ,   195 ,   2653    ,   1287    ,   11595   ,0 };
            const std::uint32_t dim1412Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   31  ,   37  ,   123 ,   35  ,   507 ,   91  ,   1345    ,   279 ,   2369    ,   1613    ,0 };
            const std::uint32_t dim1413Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   23  ,   9   ,   83  ,   91  ,   257 ,   977 ,   697 ,   3813    ,   6839    ,   2755    ,0 };
            const std::uint32_t dim1414Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   21  ,   23  ,   65  ,   63  ,   407 ,   515 ,   1817    ,   2893    ,   7539    ,   11803   ,0 };
            const std::uint32_t dim1415Kuo3Init[]   =   {   1   ,   3   ,   1   ,   15  ,   5   ,   1   ,   7   ,   195 ,   15  ,   319 ,   1177    ,   3191    ,   3489    ,   6213    ,0 };
            const std::uint32_t dim1416Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   29  ,   11  ,   97  ,   125 ,   89  ,   1005    ,   455 ,   3397    ,   7345    ,   14481   ,0 };
            const std::uint32_t dim1417Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   31  ,   37  ,   15  ,   35  ,   405 ,   181 ,   601 ,   543 ,   6639    ,   16103   ,0 };
            const std::uint32_t dim1418Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   1   ,   33  ,   127 ,   177 ,   277 ,   681 ,   2039    ,   3109    ,   4657    ,   1303    ,0 };
            const std::uint32_t dim1419Kuo3Init[]   =   {   1   ,   1   ,   5   ,   7   ,   3   ,   61  ,   107 ,   215 ,   175 ,   973 ,   899 ,   3655    ,   823 ,   7125    ,0 };
            const std::uint32_t dim1420Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   3   ,   47  ,   87  ,   179 ,   387 ,   987 ,   1171    ,   2767    ,   6329    ,   609 ,0 };
            const std::uint32_t dim1421Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   7   ,   25  ,   33  ,   109 ,   485 ,   789 ,   979 ,   659 ,   2555    ,   10175   ,0 };
            const std::uint32_t dim1422Kuo3Init[]   =   {   1   ,   1   ,   5   ,   7   ,   15  ,   41  ,   77  ,   69  ,   487 ,   601 ,   753 ,   2785    ,   1075    ,   35  ,0 };
            const std::uint32_t dim1423Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   23  ,   3   ,   125 ,   143 ,   463 ,   981 ,   499 ,   1249    ,   5461    ,   43  ,0 };
            const std::uint32_t dim1424Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   9   ,   1   ,   55  ,   147 ,   85  ,   857 ,   1995    ,   3471    ,   6115    ,   5511    ,0 };
            const std::uint32_t dim1425Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   11  ,   25  ,   27  ,   201 ,   497 ,   533 ,   643 ,   2015    ,   205 ,   13535   ,0 };
            const std::uint32_t dim1426Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   23  ,   53  ,   77  ,   143 ,   231 ,   335 ,   471 ,   1821    ,   739 ,   4727    ,0 };
            const std::uint32_t dim1427Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   13  ,   25  ,   53  ,   61  ,   155 ,   1013    ,   1439    ,   1745    ,   6393    ,   13329   ,0 };
            const std::uint32_t dim1428Kuo3Init[]   =   {   1   ,   3   ,   7   ,   1   ,   5   ,   11  ,   111 ,   21  ,   357 ,   599 ,   1213    ,   3581    ,   1221    ,   75  ,0 };
            const std::uint32_t dim1429Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   23  ,   45  ,   79  ,   83  ,   97  ,   191 ,   53  ,   2157    ,   7737    ,   1533    ,0 };
            const std::uint32_t dim1430Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   25  ,   17  ,   123 ,   179 ,   151 ,   77  ,   1903    ,   1457    ,   1403    ,   13557   ,0 };
            const std::uint32_t dim1431Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   23  ,   59  ,   65  ,   47  ,   119 ,   113 ,   133 ,   3601    ,   7543    ,   16289   ,0 };
            const std::uint32_t dim1432Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   17  ,   51  ,   33  ,   39  ,   257 ,   409 ,   659 ,   3907    ,   7301    ,   8893    ,0 };
            const std::uint32_t dim1433Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   31  ,   25  ,   79  ,   245 ,   465 ,   809 ,   1317    ,   1109    ,   5983    ,   4359    ,0 };
            const std::uint32_t dim1434Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   5   ,   25  ,   83  ,   239 ,   199 ,   497 ,   521 ,   1527    ,   4509    ,   12627   ,0 };
            const std::uint32_t dim1435Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   25  ,   33  ,   97  ,   171 ,   443 ,   75  ,   1681    ,   407 ,   7669    ,   14893   ,0 };
            const std::uint32_t dim1436Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   17  ,   31  ,   53  ,   113 ,   97  ,   653 ,   917 ,   11  ,   5697    ,   8083    ,0 };
            const std::uint32_t dim1437Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   19  ,   27  ,   1   ,   155 ,   89  ,   579 ,   951 ,   1779    ,   343 ,   12053   ,0 };
            const std::uint32_t dim1438Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   23  ,   29  ,   33  ,   143 ,   181 ,   25  ,   109 ,   3407    ,   3255    ,   15363   ,0 };
            const std::uint32_t dim1439Kuo3Init[]   =   {   1   ,   3   ,   3   ,   7   ,   5   ,   47  ,   119 ,   111 ,   315 ,   225 ,   1655    ,   3019    ,   4835    ,   11641   ,0 };
            const std::uint32_t dim1440Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   19  ,   51  ,   103 ,   219 ,   233 ,   633 ,   1923    ,   1523    ,   467 ,   15363   ,0 };
            const std::uint32_t dim1441Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   11  ,   5   ,   125 ,   143 ,   277 ,   5   ,   1597    ,   2445    ,   4261    ,   12449   ,0 };
            const std::uint32_t dim1442Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   7   ,   1   ,   103 ,   63  ,   23  ,   65  ,   1449    ,   3097    ,   601 ,   12563   ,0 };
            const std::uint32_t dim1443Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   31  ,   51  ,   23  ,   251 ,   193 ,   227 ,   1569    ,   439 ,   1037    ,   8013    ,0 };
            const std::uint32_t dim1444Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   17  ,   9   ,   45  ,   241 ,   197 ,   787 ,   555 ,   1951    ,   2697    ,   725 ,0 };
            const std::uint32_t dim1445Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   9   ,   43  ,   1   ,   211 ,   51  ,   645 ,   1977    ,   3085    ,   4003    ,   10331   ,0 };
            const std::uint32_t dim1446Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   7   ,   31  ,   89  ,   209 ,   505 ,   753 ,   641 ,   3177    ,   2791    ,   10727   ,0 };
            const std::uint32_t dim1447Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   31  ,   13  ,   53  ,   223 ,   435 ,   51  ,   571 ,   2033    ,   1689    ,   67  ,0 };
            const std::uint32_t dim1448Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   21  ,   55  ,   19  ,   31  ,   273 ,   175 ,   1657    ,   3399    ,   3031    ,   10271   ,0 };
            const std::uint32_t dim1449Kuo3Init[]   =   {   1   ,   1   ,   7   ,   9   ,   27  ,   51  ,   87  ,   157 ,   395 ,   57  ,   1501    ,   2547    ,   5061    ,   11325   ,0 };
            const std::uint32_t dim1450Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   19  ,   43  ,   55  ,   147 ,   193 ,   531 ,   511 ,   4019    ,   2317    ,   3727    ,0 };
            const std::uint32_t dim1451Kuo3Init[]   =   {   1   ,   1   ,   1   ,   15  ,   1   ,   15  ,   5   ,   157 ,   335 ,   183 ,   619 ,   2483    ,   5817    ,   3247    ,0 };
            const std::uint32_t dim1452Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   29  ,   59  ,   27  ,   27  ,   355 ,   315 ,   193 ,   707 ,   5897    ,   4623    ,0 };
            const std::uint32_t dim1453Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   23  ,   29  ,   33  ,   123 ,   413 ,   317 ,   1099    ,   1633    ,   1619    ,   9141    ,0 };
            const std::uint32_t dim1454Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   11  ,   49  ,   85  ,   95  ,   73  ,   829 ,   929 ,   2013    ,   4653    ,   3045    ,0 };
            const std::uint32_t dim1455Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   5   ,   63  ,   81  ,   177 ,   23  ,   455 ,   1527    ,   2271    ,   2523    ,   3711    ,0 };
            const std::uint32_t dim1456Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   9   ,   13  ,   1   ,   241 ,   225 ,   191 ,   933 ,   657 ,   4557    ,   6903    ,0 };
            const std::uint32_t dim1457Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   19  ,   29  ,   121 ,   3   ,   235 ,   729 ,   1705    ,   4035    ,   5429    ,   15339   ,0 };
            const std::uint32_t dim1458Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   3   ,   63  ,   79  ,   89  ,   363 ,   407 ,   325 ,   3045    ,   7761    ,   8855    ,0 };
            const std::uint32_t dim1459Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   13  ,   39  ,   69  ,   119 ,   45  ,   259 ,   577 ,   269 ,   2977    ,   2093    ,0 };
            const std::uint32_t dim1460Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   5   ,   9   ,   115 ,   161 ,   319 ,   799 ,   777 ,   459 ,   1823    ,   10971   ,0 };
            const std::uint32_t dim1461Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   1   ,   45  ,   31  ,   223 ,   421 ,   389 ,   1535    ,   1701    ,   3739    ,   9301    ,0 };
            const std::uint32_t dim1462Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   5   ,   49  ,   53  ,   189 ,   101 ,   475 ,   453 ,   1921    ,   7161    ,   4529    ,0 };
            const std::uint32_t dim1463Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   29  ,   37  ,   53  ,   213 ,   371 ,   985 ,   647 ,   765 ,   6303    ,   10947   ,0 };
            const std::uint32_t dim1464Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   5   ,   23  ,   51  ,   199 ,   463 ,   11  ,   709 ,   2083    ,   6337    ,   1115    ,0 };
            const std::uint32_t dim1465Kuo3Init[]   =   {   1   ,   1   ,   1   ,   1   ,   17  ,   57  ,   1   ,   91  ,   159 ,   1013    ,   1229    ,   2147    ,   571 ,   335 ,0 };
            const std::uint32_t dim1466Kuo3Init[]   =   {   1   ,   3   ,   1   ,   11  ,   21  ,   53  ,   119 ,   221 ,   203 ,   467 ,   845 ,   645 ,   7939    ,   7257    ,0 };
            const std::uint32_t dim1467Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   9   ,   45  ,   87  ,   213 ,   483 ,   247 ,   1423    ,   1855    ,   583 ,   13339   ,0 };
            const std::uint32_t dim1468Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   13  ,   39  ,   89  ,   87  ,   467 ,   107 ,   185 ,   1507    ,   755 ,   12069   ,0 };
            const std::uint32_t dim1469Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   5   ,   49  ,   17  ,   61  ,   483 ,   877 ,   1887    ,   2973    ,   6733    ,   3241    ,0 };
            const std::uint32_t dim1470Kuo3Init[]   =   {   1   ,   1   ,   7   ,   15  ,   31  ,   25  ,   105 ,   215 ,   449 ,   723 ,   973 ,   4011    ,   1079    ,   9713    ,0 };
            const std::uint32_t dim1471Kuo3Init[]   =   {   1   ,   3   ,   3   ,   5   ,   23  ,   61  ,   9   ,   85  ,   323 ,   675 ,   101 ,   2451    ,   5441    ,   14371   ,0 };
            const std::uint32_t dim1472Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   1   ,   47  ,   109 ,   177 ,   279 ,   675 ,   867 ,   2053    ,   6975    ,   4829    ,0 };
            const std::uint32_t dim1473Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   23  ,   15  ,   17  ,   49  ,   273 ,   839 ,   779 ,   3899    ,   3775    ,   4289    ,0 };
            const std::uint32_t dim1474Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   3   ,   5   ,   9   ,   83  ,   291 ,   727 ,   2041    ,   2221    ,   979 ,   761 ,0 };
            const std::uint32_t dim1475Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   7   ,   5   ,   23  ,   187 ,   293 ,   159 ,   847 ,   697 ,   7227    ,   9549    ,0 };
            const std::uint32_t dim1476Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   19  ,   7   ,   77  ,   57  ,   225 ,   443 ,   539 ,   1531    ,   857 ,   12997   ,0 };
            const std::uint32_t dim1477Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   9   ,   33  ,   79  ,   137 ,   15  ,   927 ,   1621    ,   1241    ,   5741    ,   13507   ,0 };
            const std::uint32_t dim1478Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   11  ,   37  ,   87  ,   255 ,   293 ,   649 ,   393 ,   2549    ,   8083    ,   13417   ,0 };
            const std::uint32_t dim1479Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   19  ,   31  ,   47  ,   243 ,   423 ,   663 ,   359 ,   3293    ,   7915    ,   16351   ,0 };
            const std::uint32_t dim1480Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   19  ,   63  ,   87  ,   245 ,   445 ,   975 ,   1047    ,   935 ,   4221    ,   851 ,0 };
            const std::uint32_t dim1481Kuo3Init[]   =   {   1   ,   3   ,   5   ,   1   ,   19  ,   43  ,   11  ,   85  ,   257 ,   875 ,   369 ,   1075    ,   1343    ,   8487    ,0 };
            const std::uint32_t dim1482Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   29  ,   35  ,   37  ,   201 ,   473 ,   853 ,   185 ,   3157    ,   6135    ,   7631    ,0 };
            const std::uint32_t dim1483Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   13  ,   53  ,   43  ,   55  ,   65  ,   999 ,   729 ,   857 ,   3645    ,   9793    ,0 };
            const std::uint32_t dim1484Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   21  ,   47  ,   85  ,   19  ,   1   ,   333 ,   989 ,   327 ,   4693    ,   3521    ,0 };
            const std::uint32_t dim1485Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   11  ,   39  ,   101 ,   209 ,   51  ,   53  ,   631 ,   1439    ,   5909    ,   9599    ,0 };
            const std::uint32_t dim1486Kuo3Init[]   =   {   1   ,   1   ,   7   ,   15  ,   29  ,   57  ,   21  ,   181 ,   293 ,   807 ,   1299    ,   1001    ,   4265    ,   1811    ,0 };
            const std::uint32_t dim1487Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   15  ,   1   ,   17  ,   63  ,   213 ,   85  ,   1025    ,   3955    ,   2371    ,   9065    ,0 };
            const std::uint32_t dim1488Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   13  ,   57  ,   23  ,   169 ,   93  ,   501 ,   7   ,   2481    ,   123 ,   8985    ,0 };
            const std::uint32_t dim1489Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   11  ,   61  ,   19  ,   133 ,   175 ,   833 ,   1753    ,   3871    ,   8169    ,   2771    ,0 };
            const std::uint32_t dim1490Kuo3Init[]   =   {   1   ,   3   ,   5   ,   1   ,   11  ,   13  ,   57  ,   55  ,   385 ,   463 ,   785 ,   2339    ,   7117    ,   12519   ,0 };
            const std::uint32_t dim1491Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   15  ,   35  ,   27  ,   179 ,   375 ,   477 ,   1157    ,   2067    ,   6971    ,   8269    ,0 };
            const std::uint32_t dim1492Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   27  ,   21  ,   57  ,   125 ,   219 ,   433 ,   67  ,   307 ,   7327    ,   2915    ,0 };
            const std::uint32_t dim1493Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   21  ,   7   ,   111 ,   21  ,   85  ,   295 ,   1751    ,   821 ,   1175    ,   3109    ,0 };
            const std::uint32_t dim1494Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   7   ,   51  ,   43  ,   119 ,   89  ,   751 ,   835 ,   3969    ,   861 ,   5775    ,0 };
            const std::uint32_t dim1495Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   5   ,   37  ,   93  ,   185 ,   435 ,   283 ,   1221    ,   2965    ,   2845    ,   6025    ,0 };
            const std::uint32_t dim1496Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   31  ,   27  ,   99  ,   143 ,   507 ,   461 ,   1999    ,   3743    ,   4277    ,   13729   ,0 };
            const std::uint32_t dim1497Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   15  ,   43  ,   99  ,   121 ,   245 ,   73  ,   829 ,   3887    ,   3093    ,   16183   ,0 };
            const std::uint32_t dim1498Kuo3Init[]   =   {   1   ,   3   ,   3   ,   7   ,   15  ,   35  ,   29  ,   79  ,   457 ,   695 ,   1469    ,   1505    ,   3891    ,   14677   ,0 };
            const std::uint32_t dim1499Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   5   ,   59  ,   71  ,   179 ,   305 ,   9   ,   2043    ,   245 ,   1291    ,   14409   ,0 };
            const std::uint32_t dim1500Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   13  ,   7   ,   17  ,   43  ,   367 ,   163 ,   1649    ,   3671    ,   2663    ,   2277    ,0 };
            const std::uint32_t dim1501Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   9   ,   57  ,   115 ,   177 ,   271 ,   735 ,   263 ,   1137    ,   2127    ,   15367   ,0 };
            const std::uint32_t dim1502Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   17  ,   11  ,   37  ,   197 ,   459 ,   647 ,   307 ,   3617    ,   3201    ,   10293   ,0 };
            const std::uint32_t dim1503Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   31  ,   37  ,   61  ,   59  ,   331 ,   483 ,   1849    ,   1737    ,   2617    ,   5053    ,0 };
            const std::uint32_t dim1504Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   31  ,   43  ,   31  ,   185 ,   261 ,   249 ,   1137    ,   1285    ,   2885    ,   4289    ,0 };
            const std::uint32_t dim1505Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   21  ,   53  ,   113 ,   163 ,   209 ,   25  ,   329 ,   2963    ,   7849    ,   10933   ,0 };
            const std::uint32_t dim1506Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   31  ,   23  ,   101 ,   151 ,   173 ,   193 ,   1267    ,   487 ,   4701    ,   8543    ,0 };
            const std::uint32_t dim1507Kuo3Init[]   =   {   1   ,   1   ,   1   ,   1   ,   25  ,   33  ,   85  ,   31  ,   433 ,   537 ,   613 ,   1675    ,   6997    ,   11975   ,0 };
            const std::uint32_t dim1508Kuo3Init[]   =   {   1   ,   3   ,   7   ,   1   ,   7   ,   59  ,   57  ,   249 ,   511 ,   371 ,   121 ,   3435    ,   8029    ,   11785   ,0 };
            const std::uint32_t dim1509Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   19  ,   61  ,   105 ,   27  ,   217 ,   47  ,   861 ,   2571    ,   6203    ,   805 ,0 };
            const std::uint32_t dim1510Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   27  ,   33  ,   41  ,   217 ,   39  ,   917 ,   355 ,   3083    ,   2803    ,   747 ,0 };
            const std::uint32_t dim1511Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   23  ,   33  ,   43  ,   27  ,   151 ,   399 ,   1307    ,   3269    ,   7941    ,   195 ,0 };
            const std::uint32_t dim1512Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   3   ,   37  ,   71  ,   111 ,   389 ,   13  ,   1147    ,   3649    ,   1497    ,   10459   ,0 };
            const std::uint32_t dim1513Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   25  ,   23  ,   19  ,   251 ,   87  ,   347 ,   711 ,   3379    ,   4677    ,   5651    ,0 };
            const std::uint32_t dim1514Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   9   ,   21  ,   51  ,   85  ,   491 ,   67  ,   485 ,   2099    ,   3081    ,   11751   ,0 };
            const std::uint32_t dim1515Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   27  ,   37  ,   75  ,   71  ,   41  ,   823 ,   1035    ,   133 ,   7537    ,   129 ,0 };
            const std::uint32_t dim1516Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   31  ,   35  ,   75  ,   223 ,   379 ,   395 ,   2011    ,   1403    ,   4923    ,   391 ,0 };
            const std::uint32_t dim1517Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   19  ,   37  ,   87  ,   109 ,   291 ,   73  ,   355 ,   1427    ,   741 ,   7393    ,0 };
            const std::uint32_t dim1518Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   23  ,   1   ,   109 ,   81  ,   319 ,   1001    ,   1173    ,   2529    ,   5859    ,   3167    ,0 };
            const std::uint32_t dim1519Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   17  ,   23  ,   121 ,   223 ,   49  ,   203 ,   1653    ,   1567    ,   7795    ,   1631    ,0 };
            const std::uint32_t dim1520Kuo3Init[]   =   {   1   ,   3   ,   1   ,   15  ,   15  ,   61  ,   123 ,   141 ,   127 ,   871 ,   897 ,   533 ,   231 ,   13767   ,0 };
            const std::uint32_t dim1521Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   5   ,   17  ,   31  ,   5   ,   505 ,   65  ,   587 ,   3721    ,   5755    ,   3865    ,0 };
            const std::uint32_t dim1522Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   27  ,   59  ,   17  ,   17  ,   33  ,   399 ,   1963    ,   3135    ,   5807    ,   2427    ,0 };
            const std::uint32_t dim1523Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   29  ,   19  ,   77  ,   55  ,   511 ,   569 ,   729 ,   2893    ,   373 ,   643 ,0 };
            const std::uint32_t dim1524Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   17  ,   17  ,   101 ,   107 ,   449 ,   581 ,   905 ,   3281    ,   4487    ,   9397    ,0 };
            const std::uint32_t dim1525Kuo3Init[]   =   {   1   ,   1   ,   7   ,   9   ,   23  ,   3   ,   103 ,   29  ,   291 ,   437 ,   1417    ,   2289    ,   3705    ,   14439   ,0 };
            const std::uint32_t dim1526Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   11  ,   61  ,   7   ,   87  ,   471 ,   707 ,   1823    ,   3971    ,   7255    ,   14395   ,0 };
            const std::uint32_t dim1527Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   21  ,   25  ,   125 ,   19  ,   221 ,   885 ,   1787    ,   3825    ,   7661    ,   8839    ,0 };
            const std::uint32_t dim1528Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   29  ,   39  ,   21  ,   47  ,   475 ,   447 ,   405 ,   3365    ,   5545    ,   11759   ,0 };
            const std::uint32_t dim1529Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   13  ,   11  ,   113 ,   123 ,   411 ,   385 ,   533 ,   4091    ,   6451    ,   6021    ,0 };
            const std::uint32_t dim1530Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   7   ,   7   ,   25  ,   65  ,   105 ,   409 ,   1837    ,   2609    ,   6417    ,   16111   ,0 };
            const std::uint32_t dim1531Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   25  ,   11  ,   101 ,   151 ,   91  ,   305 ,   865 ,   2653    ,   3031    ,   2295    ,0 };
            const std::uint32_t dim1532Kuo3Init[]   =   {   1   ,   1   ,   1   ,   15  ,   11  ,   53  ,   87  ,   203 ,   275 ,   915 ,   281 ,   687 ,   5857    ,   393 ,0 };
            const std::uint32_t dim1533Kuo3Init[]   =   {   1   ,   3   ,   3   ,   5   ,   15  ,   11  ,   97  ,   169 ,   175 ,   325 ,   285 ,   2287    ,   7095    ,   5245    ,0 };
            const std::uint32_t dim1534Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   25  ,   3   ,   31  ,   79  ,   49  ,   637 ,   1927    ,   2361    ,   2233    ,   7935    ,0 };
            const std::uint32_t dim1535Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   17  ,   41  ,   69  ,   9   ,   441 ,   719 ,   765 ,   689 ,   475 ,   8613    ,0 };
            const std::uint32_t dim1536Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   9   ,   11  ,   51  ,   175 ,   231 ,   975 ,   1983    ,   1389    ,   205 ,   5051    ,0 };
            const std::uint32_t dim1537Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   17  ,   37  ,   9   ,   193 ,   243 ,   331 ,   1545    ,   3905    ,   4601    ,   7731    ,0 };
            const std::uint32_t dim1538Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   9   ,   41  ,   27  ,   29  ,   231 ,   775 ,   1753    ,   1915    ,   7247    ,   6821    ,0 };
            const std::uint32_t dim1539Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   21  ,   9   ,   51  ,   165 ,   313 ,   951 ,   1897    ,   2123    ,   2999    ,   3171    ,0 };
            const std::uint32_t dim1540Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   25  ,   43  ,   81  ,   249 ,   309 ,   523 ,   373 ,   3293    ,   6607    ,   9495    ,0 };
            const std::uint32_t dim1541Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   15  ,   63  ,   11  ,   139 ,   319 ,   665 ,   1703    ,   1669    ,   4817    ,   3645    ,0 };
            const std::uint32_t dim1542Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   11  ,   47  ,   117 ,   245 ,   251 ,   341 ,   415 ,   815 ,   7335    ,   14297   ,0 };
            const std::uint32_t dim1543Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   19  ,   33  ,   109 ,   191 ,   253 ,   867 ,   1505    ,   2629    ,   6619    ,   7913    ,0 };
            const std::uint32_t dim1544Kuo3Init[]   =   {   1   ,   3   ,   5   ,   1   ,   7   ,   49  ,   53  ,   51  ,   285 ,   25  ,   1783    ,   2201    ,   7603    ,   11365   ,0 };
            const std::uint32_t dim1545Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   1   ,   49  ,   9   ,   89  ,   365 ,   909 ,   1563    ,   2719    ,   6859    ,   14135   ,0 };
            const std::uint32_t dim1546Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   17  ,   57  ,   21  ,   165 ,   419 ,   443 ,   1207    ,   3821    ,   1151    ,   14037   ,0 };
            const std::uint32_t dim1547Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   1   ,   31  ,   97  ,   133 ,   423 ,   993 ,   745 ,   3559    ,   7725    ,   2069    ,0 };
            const std::uint32_t dim1548Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   31  ,   1   ,   65  ,   3   ,   63  ,   255 ,   313 ,   515 ,   455 ,   4957    ,0 };
            const std::uint32_t dim1549Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   5   ,   31  ,   37  ,   121 ,   201 ,   493 ,   55  ,   3735    ,   5019    ,   5665    ,0 };
            const std::uint32_t dim1550Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   9   ,   57  ,   55  ,   155 ,   171 ,   687 ,   1415    ,   2017    ,   7021    ,   7409    ,0 };
            const std::uint32_t dim1551Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   15  ,   23  ,   83  ,   79  ,   367 ,   485 ,   1933    ,   315 ,   2591    ,   7609    ,0 };
            const std::uint32_t dim1552Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   25  ,   49  ,   79  ,   15  ,   435 ,   809 ,   265 ,   2215    ,   7207    ,   563 ,0 };
            const std::uint32_t dim1553Kuo3Init[]   =   {   1   ,   3   ,   7   ,   1   ,   19  ,   61  ,   103 ,   101 ,   51  ,   637 ,   639 ,   55  ,   4323    ,   179 ,0 };
            const std::uint32_t dim1554Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   23  ,   27  ,   33  ,   79  ,   215 ,   849 ,   331 ,   2881    ,   2109    ,   10309   ,0 };
            const std::uint32_t dim1555Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   21  ,   63  ,   113 ,   237 ,   63  ,   769 ,   63  ,   391 ,   1433    ,   6913    ,0 };
            const std::uint32_t dim1556Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   3   ,   53  ,   25  ,   187 ,   313 ,   93  ,   1499    ,   3281    ,   557 ,   12441   ,0 };
            const std::uint32_t dim1557Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   7   ,   27  ,   97  ,   211 ,   5   ,   31  ,   497 ,   1659    ,   7061    ,   807 ,0 };
            const std::uint32_t dim1558Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   23  ,   3   ,   39  ,   55  ,   369 ,   197 ,   299 ,   2529    ,   2703    ,   247 ,0 };
            const std::uint32_t dim1559Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   15  ,   49  ,   119 ,   241 ,   45  ,   303 ,   1741    ,   1077    ,   6735    ,   8079    ,0 };
            const std::uint32_t dim1560Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   21  ,   55  ,   91  ,   17  ,   341 ,   123 ,   1389    ,   2557    ,   3667    ,   4891    ,0 };
            const std::uint32_t dim1561Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   27  ,   21  ,   107 ,   111 ,   85  ,   39  ,   863 ,   1965    ,   5173    ,   49  ,0 };
            const std::uint32_t dim1562Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   11  ,   5   ,   15  ,   185 ,   269 ,   711 ,   557 ,   2021    ,   7481    ,   4977    ,0 };
            const std::uint32_t dim1563Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   5   ,   1   ,   93  ,   139 ,   323 ,   915 ,   549 ,   1345    ,   6031    ,   3979    ,0 };
            const std::uint32_t dim1564Kuo3Init[]   =   {   1   ,   3   ,   3   ,   7   ,   19  ,   9   ,   57  ,   177 ,   135 ,   65  ,   27  ,   795 ,   4637    ,   11977   ,0 };
            const std::uint32_t dim1565Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   7   ,   17  ,   117 ,   35  ,   257 ,   671 ,   1741    ,   1993    ,   1887    ,   8149    ,0 };
            const std::uint32_t dim1566Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   3   ,   45  ,   5   ,   199 ,   29  ,   227 ,   1613    ,   835 ,   2451    ,   13079   ,0 };
            const std::uint32_t dim1567Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   23  ,   45  ,   87  ,   15  ,   349 ,   843 ,   159 ,   3283    ,   1017    ,   15813   ,0 };
            const std::uint32_t dim1568Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   21  ,   21  ,   31  ,   51  ,   481 ,   49  ,   1561    ,   2171    ,   6025    ,   9955    ,0 };
            const std::uint32_t dim1569Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   7   ,   51  ,   97  ,   195 ,   5   ,   251 ,   1509    ,   1479    ,   1165    ,   16375   ,0 };
            const std::uint32_t dim1570Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   7   ,   17  ,   43  ,   101 ,   281 ,   807 ,   2003    ,   2821    ,   6877    ,   2457    ,0 };
            const std::uint32_t dim1571Kuo3Init[]   =   {   1   ,   1   ,   1   ,   1   ,   15  ,   23  ,   59  ,   91  ,   19  ,   933 ,   145 ,   673 ,   4729    ,   10369   ,0 };
            const std::uint32_t dim1572Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   31  ,   37  ,   9   ,   219 ,   343 ,   907 ,   1401    ,   213 ,   5149    ,   14171   ,0 };
            const std::uint32_t dim1573Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   17  ,   17  ,   61  ,   181 ,   281 ,   707 ,   113 ,   3595    ,   67  ,   15423   ,0 };
            const std::uint32_t dim1574Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   3   ,   51  ,   69  ,   93  ,   375 ,   451 ,   1181    ,   1353    ,   939 ,   629 ,0 };
            const std::uint32_t dim1575Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   13  ,   33  ,   113 ,   85  ,   397 ,   823 ,   1513    ,   283 ,   7167    ,   4627    ,0 };
            const std::uint32_t dim1576Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   25  ,   31  ,   5   ,   17  ,   377 ,   429 ,   1841    ,   3915    ,   6023    ,   11791   ,0 };
            const std::uint32_t dim1577Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   15  ,   35  ,   45  ,   31  ,   427 ,   509 ,   1827    ,   1171    ,   7001    ,   6419    ,0 };
            const std::uint32_t dim1578Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   7   ,   37  ,   41  ,   35  ,   349 ,   73  ,   171 ,   35  ,   2333    ,   659 ,0 };
            const std::uint32_t dim1579Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   13  ,   61  ,   53  ,   87  ,   463 ,   143 ,   257 ,   3151    ,   6149    ,   10155   ,0 };
            const std::uint32_t dim1580Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   3   ,   17  ,   29  ,   151 ,   259 ,   881 ,   2003    ,   1057    ,   1867    ,   7773    ,0 };
            const std::uint32_t dim1581Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   5   ,   55  ,   97  ,   49  ,   473 ,   795 ,   1545    ,   1169    ,   187 ,   10475   ,0 };
            const std::uint32_t dim1582Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   9   ,   11  ,   61  ,   205 ,   71  ,   183 ,   1551    ,   621 ,   5715    ,   3401    ,0 };
            const std::uint32_t dim1583Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   25  ,   41  ,   109 ,   211 ,   189 ,   859 ,   1681    ,   3281    ,   8153    ,   13303   ,0 };
            const std::uint32_t dim1584Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   13  ,   17  ,   81  ,   151 ,   189 ,   419 ,   1707    ,   235 ,   355 ,   8295    ,0 };
            const std::uint32_t dim1585Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   19  ,   33  ,   49  ,   249 ,   347 ,   617 ,   2037    ,   537 ,   755 ,   5131    ,0 };
            const std::uint32_t dim1586Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   23  ,   17  ,   93  ,   35  ,   357 ,   523 ,   355 ,   1159    ,   1329    ,   7663    ,0 };
            const std::uint32_t dim1587Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   15  ,   17  ,   81  ,   197 ,   479 ,   405 ,   55  ,   4095    ,   4931    ,   7663    ,0 };
            const std::uint32_t dim1588Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   1   ,   1   ,   17  ,   173 ,   259 ,   191 ,   1929    ,   2063    ,   6623    ,   5065    ,0 };
            const std::uint32_t dim1589Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   31  ,   21  ,   25  ,   33  ,   233 ,   663 ,   1687    ,   495 ,   5223    ,   439 ,0 };
            const std::uint32_t dim1590Kuo3Init[]   =   {   1   ,   3   ,   3   ,   5   ,   31  ,   47  ,   43  ,   119 ,   491 ,   893 ,   1513    ,   2453    ,   6131    ,   8675    ,0 };
            const std::uint32_t dim1591Kuo3Init[]   =   {   1   ,   3   ,   5   ,   1   ,   21  ,   51  ,   21  ,   27  ,   35  ,   613 ,   849 ,   3679    ,   4089    ,   9671    ,0 };
            const std::uint32_t dim1592Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   29  ,   53  ,   125 ,   223 ,   415 ,   315 ,   811 ,   513 ,   4833    ,   10667   ,0 };
            const std::uint32_t dim1593Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   5   ,   49  ,   87  ,   47  ,   85  ,   115 ,   757 ,   567 ,   3655    ,   4009    ,0 };
            const std::uint32_t dim1594Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   9   ,   1   ,   65  ,   179 ,   55  ,   545 ,   467 ,   1615    ,   4349    ,   14745   ,0 };
            const std::uint32_t dim1595Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   7   ,   49  ,   91  ,   133 ,   151 ,   113 ,   1373    ,   203 ,   2711    ,   8045    ,0 };
            const std::uint32_t dim1596Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   13  ,   5   ,   53  ,   181 ,   397 ,   309 ,   1653    ,   2987    ,   175 ,   13419   ,0 };
            const std::uint32_t dim1597Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   19  ,   35  ,   17  ,   177 ,   77  ,   1011    ,   1667    ,   3083    ,   7977    ,   14925   ,0 };
            const std::uint32_t dim1598Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   25  ,   33  ,   59  ,   21  ,   345 ,   395 ,   1575    ,   2173    ,   159 ,   11799   ,0 };
            const std::uint32_t dim1599Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   3   ,   19  ,   87  ,   135 ,   227 ,   995 ,   1965    ,   3469    ,   3801    ,   1979    ,0 };
            const std::uint32_t dim1600Kuo3Init[]   =   {   1   ,   1   ,   1   ,   15  ,   11  ,   1   ,   51  ,   235 ,   37  ,   695 ,   1761    ,   275 ,   5793    ,   4897    ,0 };
            const std::uint32_t dim1601Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   13  ,   37  ,   123 ,   23  ,   363 ,   377 ,   2009    ,   2897    ,   207 ,   15103   ,0 };
            const std::uint32_t dim1602Kuo3Init[]   =   {   1   ,   1   ,   1   ,   15  ,   3   ,   43  ,   49  ,   23  ,   351 ,   429 ,   1181    ,   2003    ,   1397    ,   9489    ,0 };
            const std::uint32_t dim1603Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   23  ,   61  ,   105 ,   149 ,   183 ,   83  ,   69  ,   121 ,   6719    ,   4729    ,0 };
            const std::uint32_t dim1604Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   27  ,   9   ,   119 ,   59  ,   115 ,   207 ,   1865    ,   3953    ,   45  ,   9739    ,0 };
            const std::uint32_t dim1605Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   7   ,   29  ,   81  ,   75  ,   361 ,   589 ,   1689    ,   49  ,   7125    ,   10563   ,0 };
            const std::uint32_t dim1606Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   11  ,   21  ,   43  ,   31  ,   43  ,   991 ,   357 ,   3707    ,   7679    ,   4305    ,0 };
            const std::uint32_t dim1607Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   23  ,   41  ,   33  ,   167 ,   207 ,   1015    ,   517 ,   1039    ,   4831    ,   753 ,0 };
            const std::uint32_t dim1608Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   1   ,   29  ,   25  ,   227 ,   5   ,   935 ,   1201    ,   2781    ,   6947    ,   1597    ,0 };
            const std::uint32_t dim1609Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   13  ,   27  ,   79  ,   175 ,   25  ,   681 ,   1805    ,   1435    ,   7325    ,   10439   ,0 };
            const std::uint32_t dim1610Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   25  ,   21  ,   105 ,   175 ,   501 ,   43  ,   19  ,   965 ,   255 ,   4177    ,0 };
            const std::uint32_t dim1611Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   1   ,   27  ,   115 ,   105 ,   43  ,   181 ,   181 ,   3747    ,   3827    ,   13451   ,0 };
            const std::uint32_t dim1612Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   15  ,   27  ,   49  ,   57  ,   361 ,   911 ,   1735    ,   3815    ,   5935    ,   11793   ,0 };
            const std::uint32_t dim1613Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   23  ,   7   ,   103 ,   83  ,   343 ,   59  ,   1383    ,   945 ,   4839    ,   1475    ,0 };
            const std::uint32_t dim1614Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   13  ,   17  ,   15  ,   129 ,   449 ,   645 ,   719 ,   283 ,   7911    ,   14961   ,0 };
            const std::uint32_t dim1615Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   1   ,   35  ,   27  ,   15  ,   177 ,   983 ,   1537    ,   2439    ,   7459    ,   7107    ,0 };
            const std::uint32_t dim1616Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   25  ,   45  ,   3   ,   163 ,   149 ,   285 ,   917 ,   2233    ,   7463    ,   15869   ,0 };
            const std::uint32_t dim1617Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   3   ,   3   ,   45  ,   175 ,   367 ,   261 ,   723 ,   3273    ,   5611    ,   3323    ,0 };
            const std::uint32_t dim1618Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   25  ,   25  ,   9   ,   189 ,   437 ,   807 ,   801 ,   3655    ,   5759    ,   9099    ,0 };
            const std::uint32_t dim1619Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   27  ,   37  ,   37  ,   177 ,   313 ,   179 ,   1897    ,   1299    ,   8041    ,   10523   ,0 };
            const std::uint32_t dim1620Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   7   ,   61  ,   105 ,   125 ,   343 ,   201 ,   1089    ,   43  ,   5645    ,   7547    ,0 };
            const std::uint32_t dim1621Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   17  ,   9   ,   69  ,   199 ,   333 ,   791 ,   1611    ,   1273    ,   7193    ,   6575    ,0 };
            const std::uint32_t dim1622Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   7   ,   63  ,   79  ,   225 ,   89  ,   391 ,   503 ,   3199    ,   1409    ,   4669    ,0 };
            const std::uint32_t dim1623Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   29  ,   7   ,   3   ,   119 ,   361 ,   269 ,   205 ,   1253    ,   113 ,   9665    ,0 };
            const std::uint32_t dim1624Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   13  ,   59  ,   53  ,   75  ,   467 ,   317 ,   815 ,   3401    ,   7223    ,   8237    ,0 };
            const std::uint32_t dim1625Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   7   ,   15  ,   49  ,   191 ,   333 ,   1017    ,   399 ,   55  ,   931 ,   14979   ,0 };
            const std::uint32_t dim1626Kuo3Init[]   =   {   1   ,   3   ,   1   ,   11  ,   23  ,   5   ,   113 ,   47  ,   105 ,   341 ,   615 ,   81  ,   7393    ,   1037    ,0 };
            const std::uint32_t dim1627Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   3   ,   29  ,   95  ,   3   ,   275 ,   257 ,   613 ,   1627    ,   695 ,   5929    ,0 };
            const std::uint32_t dim1628Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   11  ,   31  ,   57  ,   83  ,   77  ,   573 ,   969 ,   1237    ,   7449    ,   13959   ,0 };
            const std::uint32_t dim1629Kuo3Init[]   =   {   1   ,   3   ,   3   ,   5   ,   31  ,   47  ,   51  ,   37  ,   123 ,   817 ,   1293    ,   771 ,   4241    ,   3007    ,0 };
            const std::uint32_t dim1630Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   9   ,   13  ,   23  ,   111 ,   311 ,   213 ,   1217    ,   2187    ,   5709    ,   6891    ,0 };
            const std::uint32_t dim1631Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   7   ,   37  ,   29  ,   67  ,   109 ,   747 ,   723 ,   2631    ,   649 ,   13007   ,0 };
            const std::uint32_t dim1632Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   5   ,   55  ,   121 ,   203 ,   69  ,   515 ,   767 ,   861 ,   7189    ,   3327    ,0 };
            const std::uint32_t dim1633Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   27  ,   53  ,   91  ,   65  ,   247 ,   257 ,   799 ,   3115    ,   6301    ,   15527   ,0 };
            const std::uint32_t dim1634Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   27  ,   29  ,   19  ,   95  ,   343 ,   265 ,   53  ,   3227    ,   8011    ,   10223   ,0 };
            const std::uint32_t dim1635Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   23  ,   31  ,   89  ,   43  ,   455 ,   581 ,   2023    ,   845 ,   7765    ,   4811    ,0 };
            const std::uint32_t dim1636Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   31  ,   37  ,   117 ,   173 ,   343 ,   971 ,   491 ,   1447    ,   1547    ,   6737    ,0 };
            const std::uint32_t dim1637Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   7   ,   43  ,   75  ,   67  ,   407 ,   697 ,   51  ,   207 ,   2499    ,   9681    ,0 };
            const std::uint32_t dim1638Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   17  ,   27  ,   55  ,   3   ,   237 ,   983 ,   1   ,   1227    ,   2605    ,   8441    ,0 };
            const std::uint32_t dim1639Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   3   ,   31  ,   47  ,   65  ,   119 ,   823 ,   1055    ,   1047    ,   6067    ,   4267    ,0 };
            const std::uint32_t dim1640Kuo3Init[]   =   {   1   ,   3   ,   1   ,   15  ,   9   ,   11  ,   41  ,   211 ,   249 ,   739 ,   953 ,   1365    ,   4749    ,   3723    ,0 };
            const std::uint32_t dim1641Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   25  ,   29  ,   31  ,   75  ,   207 ,   395 ,   1843    ,   1737    ,   387 ,   11871   ,0 };
            const std::uint32_t dim1642Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   21  ,   5   ,   3   ,   221 ,   223 ,   975 ,   743 ,   2217    ,   7743    ,   4667    ,0 };
            const std::uint32_t dim1643Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   23  ,   63  ,   113 ,   149 ,   427 ,   499 ,   1259    ,   735 ,   2839    ,   503 ,0 };
            const std::uint32_t dim1644Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   19  ,   47  ,   53  ,   205 ,   385 ,   409 ,   475 ,   265 ,   8183    ,   11709   ,0 };
            const std::uint32_t dim1645Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   21  ,   25  ,   91  ,   143 ,   373 ,   967 ,   1735    ,   1149    ,   3077    ,   8809    ,0 };
            const std::uint32_t dim1646Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   23  ,   39  ,   39  ,   89  ,   241 ,   181 ,   1819    ,   3431    ,   1605    ,   2143    ,0 };
            const std::uint32_t dim1647Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   27  ,   21  ,   69  ,   35  ,   327 ,   233 ,   495 ,   157 ,   5961    ,   15785   ,0 };
            const std::uint32_t dim1648Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   1   ,   29  ,   77  ,   249 ,   471 ,   31  ,   1805    ,   1431    ,   1703    ,   3593    ,0 };
            const std::uint32_t dim1649Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   13  ,   31  ,   15  ,   89  ,   35  ,   143 ,   487 ,   4047    ,   7681    ,   1557    ,0 };
            const std::uint32_t dim1650Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   21  ,   3   ,   81  ,   1   ,   15  ,   531 ,   1443    ,   2421    ,   4465    ,   4431    ,0 };
            const std::uint32_t dim1651Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   5   ,   25  ,   83  ,   1   ,   47  ,   723 ,   1427    ,   1013    ,   1525    ,   8877    ,0 };
            const std::uint32_t dim1652Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   25  ,   23  ,   71  ,   87  ,   13  ,   543 ,   1715    ,   2449    ,   4639    ,   8339    ,0 };
            const std::uint32_t dim1653Kuo3Init[]   =   {   1   ,   1   ,   7   ,   9   ,   1   ,   27  ,   101 ,   129 ,   81  ,   747 ,   1745    ,   2545    ,   455 ,   14103   ,0 };
            const std::uint32_t dim1654Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   23  ,   59  ,   125 ,   49  ,   323 ,   989 ,   1959    ,   2349    ,   2835    ,   115 ,0 };
            const std::uint32_t dim1655Kuo3Init[]   =   {   1   ,   3   ,   1   ,   11  ,   29  ,   23  ,   31  ,   185 ,   273 ,   43  ,   1093    ,   323 ,   751 ,   7473    ,0 };
            const std::uint32_t dim1656Kuo3Init[]   =   {   1   ,   1   ,   5   ,   7   ,   3   ,   51  ,   65  ,   231 ,   147 ,   69  ,   1635    ,   1593    ,   7385    ,   1251    ,0 };
            const std::uint32_t dim1657Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   21  ,   7   ,   109 ,   61  ,   387 ,   819 ,   417 ,   1393    ,   5535    ,   12201   ,0 };
            const std::uint32_t dim1658Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   11  ,   17  ,   41  ,   61  ,   361 ,   891 ,   69  ,   935 ,   2793    ,   1631    ,0 };
            const std::uint32_t dim1659Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   25  ,   31  ,   43  ,   47  ,   247 ,   723 ,   1703    ,   1499    ,   139 ,   8809    ,0 };
            const std::uint32_t dim1660Kuo3Init[]   =   {   1   ,   3   ,   5   ,   1   ,   9   ,   47  ,   45  ,   117 ,   95  ,   345 ,   1431    ,   975 ,   6575    ,   1213    ,0 };
            const std::uint32_t dim1661Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   29  ,   37  ,   45  ,   91  ,   443 ,   471 ,   1363    ,   1839    ,   6263    ,   3289    ,0 };
            const std::uint32_t dim1662Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   17  ,   17  ,   57  ,   193 ,   477 ,   283 ,   1307    ,   967 ,   1793    ,   12551   ,0 };
            const std::uint32_t dim1663Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   17  ,   1   ,   103 ,   67  ,   113 ,   805 ,   1993    ,   3019    ,   1911    ,   11961   ,0 };
            const std::uint32_t dim1664Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   23  ,   47  ,   19  ,   137 ,   511 ,   685 ,   1525    ,   1703    ,   2513    ,   12541   ,0 };
            const std::uint32_t dim1665Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   3   ,   7   ,   29  ,   45  ,   279 ,   855 ,   1931    ,   2261    ,   2097    ,   2373    ,0 };
            const std::uint32_t dim1666Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   13  ,   23  ,   105 ,   119 ,   473 ,   809 ,   925 ,   3295    ,   7547    ,   4229    ,0 };
            const std::uint32_t dim1667Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   27  ,   37  ,   3   ,   109 ,   257 ,   743 ,   1233    ,   2973    ,   3313    ,   2949    ,0 };
            const std::uint32_t dim1668Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   25  ,   37  ,   103 ,   157 ,   333 ,   127 ,   1893    ,   649 ,   7773    ,   15639   ,0 };
            const std::uint32_t dim1669Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   13  ,   53  ,   21  ,   67  ,   161 ,   859 ,   1715    ,   3303    ,   2527    ,   9487    ,0 };
            const std::uint32_t dim1670Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   7   ,   27  ,   47  ,   173 ,   103 ,   413 ,   719 ,   2865    ,   2337    ,   2963    ,0 };
            const std::uint32_t dim1671Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   25  ,   17  ,   3   ,   105 ,   85  ,   731 ,   933 ,   3967    ,   279 ,   14649   ,0 };
            const std::uint32_t dim1672Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   11  ,   15  ,   37  ,   197 ,   443 ,   667 ,   1373    ,   2961    ,   615 ,   6011    ,0 };
            const std::uint32_t dim1673Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   11  ,   45  ,   9   ,   43  ,   339 ,   203 ,   27  ,   3047    ,   6531    ,   1071    ,0 };
            const std::uint32_t dim1674Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   1   ,   23  ,   111 ,   185 ,   485 ,   425 ,   2043    ,   3375    ,   4037    ,   8751    ,0 };
            const std::uint32_t dim1675Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   21  ,   35  ,   37  ,   87  ,   393 ,   149 ,   1475    ,   4027    ,   8125    ,   16021   ,0 };
            const std::uint32_t dim1676Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   21  ,   51  ,   125 ,   229 ,   49  ,   611 ,   919 ,   3103    ,   7239    ,   3553    ,0 };
            const std::uint32_t dim1677Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   5   ,   27  ,   77  ,   99  ,   313 ,   667 ,   413 ,   1933    ,   7977    ,   8903    ,0 };
            const std::uint32_t dim1678Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   5   ,   47  ,   47  ,   99  ,   181 ,   253 ,   433 ,   3385    ,   5789    ,   9043    ,0 };
            const std::uint32_t dim1679Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   9   ,   9   ,   117 ,   51  ,   93  ,   615 ,   1159    ,   251 ,   3345    ,   925 ,0 };
            const std::uint32_t dim1680Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   21  ,   27  ,   75  ,   201 ,   489 ,   901 ,   643 ,   2511    ,   3803    ,   11525   ,0 };
            const std::uint32_t dim1681Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   15  ,   27  ,   117 ,   1   ,   69  ,   1019    ,   1853    ,   3745    ,   3549    ,   5721    ,0 };
            const std::uint32_t dim1682Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   23  ,   63  ,   113 ,   235 ,   315 ,   613 ,   1691    ,   2725    ,   2941    ,   11339   ,0 };
            const std::uint32_t dim1683Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   19  ,   1   ,   3   ,   157 ,   251 ,   443 ,   217 ,   2229    ,   6723    ,   15045   ,0 };
            const std::uint32_t dim1684Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   1   ,   1   ,   93  ,   133 ,   69  ,   897 ,   197 ,   2241    ,   1727    ,   3645    ,0 };
            const std::uint32_t dim1685Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   31  ,   33  ,   83  ,   21  ,   3   ,   243 ,   1857    ,   1343    ,   1359    ,   2631    ,0 };
            const std::uint32_t dim1686Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   27  ,   17  ,   1   ,   147 ,   113 ,   849 ,   1899    ,   1037    ,   5029    ,   6829    ,0 };
            const std::uint32_t dim1687Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   21  ,   3   ,   95  ,   69  ,   425 ,   185 ,   1983    ,   3887    ,   843 ,   14881   ,0 };
            const std::uint32_t dim1688Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   11  ,   31  ,   49  ,   35  ,   349 ,   429 ,   1173    ,   3783    ,   7979    ,   13651   ,0 };
            const std::uint32_t dim1689Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   25  ,   13  ,   49  ,   97  ,   293 ,   661 ,   387 ,   79  ,   5863    ,   9315    ,0 };
            const std::uint32_t dim1690Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   27  ,   25  ,   9   ,   51  ,   185 ,   569 ,   1129    ,   2657    ,   6609    ,   8383    ,0 };
            const std::uint32_t dim1691Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   29  ,   7   ,   67  ,   77  ,   77  ,   661 ,   259 ,   2365    ,   3649    ,   9989    ,0 };
            const std::uint32_t dim1692Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   29  ,   59  ,   43  ,   241 ,   279 ,   177 ,   721 ,   1329    ,   3709    ,   8987    ,0 };
            const std::uint32_t dim1693Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   25  ,   35  ,   51  ,   213 ,   367 ,   735 ,   11  ,   1061    ,   497 ,   13593   ,0 };
            const std::uint32_t dim1694Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   1   ,   39  ,   79  ,   31  ,   497 ,   799 ,   1575    ,   2627    ,   2821    ,   4815    ,0 };
            const std::uint32_t dim1695Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   15  ,   31  ,   99  ,   199 ,   369 ,   829 ,   721 ,   3509    ,   3973    ,   9491    ,0 };
            const std::uint32_t dim1696Kuo3Init[]   =   {   1   ,   1   ,   1   ,   15  ,   7   ,   49  ,   125 ,   249 ,   295 ,   907 ,   1243    ,   155 ,   2519    ,   2295    ,0 };
            const std::uint32_t dim1697Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   7   ,   1   ,   63  ,   141 ,   505 ,   865 ,   1389    ,   1041    ,   191 ,   4109    ,0 };
            const std::uint32_t dim1698Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   5   ,   45  ,   5   ,   53  ,   77  ,   525 ,   579 ,   3077    ,   6737    ,   6839    ,0 };
            const std::uint32_t dim1699Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   23  ,   5   ,   127 ,   61  ,   421 ,   353 ,   589 ,   4095    ,   2841    ,   8095    ,0 };
            const std::uint32_t dim1700Kuo3Init[]   =   {   1   ,   1   ,   7   ,   9   ,   3   ,   11  ,   49  ,   103 ,   75  ,   403 ,   441 ,   3513    ,   6535    ,   7811    ,0 };
            const std::uint32_t dim1701Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   21  ,   57  ,   115 ,   59  ,   341 ,   673 ,   759 ,   81  ,   6585    ,   9727    ,0 };
            const std::uint32_t dim1702Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   29  ,   33  ,   35  ,   201 ,   149 ,   41  ,   175 ,   1355    ,   5311    ,   85  ,0 };
            const std::uint32_t dim1703Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   31  ,   5   ,   51  ,   83  ,   225 ,   123 ,   1347    ,   2017    ,   6259    ,   1553    ,0 };
            const std::uint32_t dim1704Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   17  ,   57  ,   77  ,   1   ,   393 ,   875 ,   887 ,   1   ,   4007    ,   6391    ,0 };
            const std::uint32_t dim1705Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   3   ,   31  ,   83  ,   167 ,   511 ,   19  ,   525 ,   323 ,   6991    ,   10411   ,0 };
            const std::uint32_t dim1706Kuo3Init[]   =   {   1   ,   1   ,   7   ,   9   ,   15  ,   61  ,   77  ,   189 ,   43  ,   651 ,   305 ,   3107    ,   6433    ,   3035    ,0 };
            const std::uint32_t dim1707Kuo3Init[]   =   {   1   ,   3   ,   1   ,   11  ,   25  ,   15  ,   51  ,   233 ,   395 ,   867 ,   145 ,   2215    ,   917 ,   13815   ,0 };
            const std::uint32_t dim1708Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   23  ,   15  ,   3   ,   103 ,   439 ,   691 ,   283 ,   3917    ,   5525    ,   11007   ,0 };
            const std::uint32_t dim1709Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   11  ,   49  ,   39  ,   31  ,   127 ,   521 ,   1327    ,   43  ,   1509    ,   679 ,0 };
            const std::uint32_t dim1710Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   17  ,   27  ,   17  ,   181 ,   337 ,   85  ,   1687    ,   3245    ,   5315    ,   5653    ,0 };
            const std::uint32_t dim1711Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   31  ,   33  ,   3   ,   229 ,   103 ,   337 ,   1337    ,   1961    ,   6053    ,   8661    ,0 };
            const std::uint32_t dim1712Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   31  ,   63  ,   15  ,   135 ,   77  ,   583 ,   697 ,   1353    ,   6543    ,   291 ,0 };
            const std::uint32_t dim1713Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   17  ,   53  ,   55  ,   59  ,   149 ,   995 ,   1059    ,   1829    ,   7759    ,   10901   ,0 };
            const std::uint32_t dim1714Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   5   ,   63  ,   51  ,   123 ,   369 ,   861 ,   1835    ,   3369    ,   4555    ,   1623    ,0 };
            const std::uint32_t dim1715Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   23  ,   31  ,   21  ,   247 ,   417 ,   565 ,   689 ,   1401    ,   405 ,   6657    ,0 };
            const std::uint32_t dim1716Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   21  ,   21  ,   37  ,   123 ,   359 ,   133 ,   397 ,   173 ,   2135    ,   12407   ,0 };
            const std::uint32_t dim1717Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   1   ,   23  ,   91  ,   97  ,   421 ,   531 ,   975 ,   2647    ,   4337    ,   7775    ,0 };
            const std::uint32_t dim1718Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   5   ,   9   ,   57  ,   149 ,   243 ,   225 ,   79  ,   2745    ,   523 ,   16133   ,0 };
            const std::uint32_t dim1719Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   7   ,   5   ,   97  ,   91  ,   15  ,   217 ,   991 ,   1465    ,   3975    ,   8467    ,0 };
            const std::uint32_t dim1720Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   9   ,   61  ,   97  ,   153 ,   411 ,   801 ,   59  ,   603 ,   5919    ,   9509    ,0 };
            const std::uint32_t dim1721Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   29  ,   11  ,   71  ,   111 ,   473 ,   985 ,   931 ,   1211    ,   653 ,   13933   ,0 };
            const std::uint32_t dim1722Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   29  ,   49  ,   71  ,   105 ,   29  ,   333 ,   1261    ,   3791    ,   5349    ,   15675   ,0 };
            const std::uint32_t dim1723Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   3   ,   53  ,   73  ,   77  ,   451 ,   547 ,   51  ,   669 ,   7355    ,   8325    ,0 };
            const std::uint32_t dim1724Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   7   ,   9   ,   37  ,   87  ,   273 ,   275 ,   191 ,   469 ,   7529    ,   1955    ,0 };
            const std::uint32_t dim1725Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   21  ,   5   ,   121 ,   195 ,   327 ,   477 ,   1661    ,   3499    ,   7903    ,   9053    ,0 };
            const std::uint32_t dim1726Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   29  ,   41  ,   25  ,   13  ,   429 ,   351 ,   723 ,   3901    ,   5841    ,   9783    ,0 };
            const std::uint32_t dim1727Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   1   ,   25  ,   15  ,   203 ,   47  ,   289 ,   67  ,   847 ,   5547    ,   15845   ,0 };
            const std::uint32_t dim1728Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   21  ,   7   ,   53  ,   39  ,   461 ,   153 ,   1739    ,   4021    ,   307 ,   1435    ,0 };
            const std::uint32_t dim1729Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   7   ,   17  ,   87  ,   23  ,   47  ,   839 ,   1841    ,   3877    ,   2401    ,   853 ,0 };
            const std::uint32_t dim1730Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   31  ,   37  ,   15  ,   49  ,   171 ,   757 ,   499 ,   1455    ,   2151    ,   6169    ,0 };
            const std::uint32_t dim1731Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   31  ,   19  ,   33  ,   87  ,   507 ,   685 ,   1765    ,   3109    ,   7221    ,   8047    ,0 };
            const std::uint32_t dim1732Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   23  ,   7   ,   25  ,   45  ,   167 ,   865 ,   465 ,   3377    ,   7203    ,   7825    ,0 };
            const std::uint32_t dim1733Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   15  ,   53  ,   79  ,   111 ,   391 ,   777 ,   367 ,   1445    ,   5243    ,   1929    ,0 };
            const std::uint32_t dim1734Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   11  ,   11  ,   57  ,   115 ,   239 ,   77  ,   797 ,   2073    ,   831 ,   11879   ,0 };
            const std::uint32_t dim1735Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   23  ,   11  ,   91  ,   153 ,   29  ,   729 ,   241 ,   2627    ,   6447    ,   13239   ,0 };
            const std::uint32_t dim1736Kuo3Init[]   =   {   1   ,   1   ,   7   ,   9   ,   31  ,   11  ,   59  ,   243 ,   105 ,   83  ,   363 ,   3473    ,   315 ,   2371    ,0 };
            const std::uint32_t dim1737Kuo3Init[]   =   {   1   ,   3   ,   5   ,   1   ,   19  ,   31  ,   111 ,   91  ,   215 ,   697 ,   103 ,   3323    ,   7259    ,   13625   ,0 };
            const std::uint32_t dim1738Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   5   ,   59  ,   83  ,   129 ,   45  ,   223 ,   835 ,   1965    ,   3975    ,   15233   ,0 };
            const std::uint32_t dim1739Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   19  ,   11  ,   31  ,   225 ,   175 ,   209 ,   619 ,   3127    ,   4943    ,   9701    ,0 };
            const std::uint32_t dim1740Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   3   ,   19  ,   21  ,   133 ,   7   ,   151 ,   1017    ,   3867    ,   3699    ,   13051   ,0 };
            const std::uint32_t dim1741Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   27  ,   17  ,   81  ,   139 ,   439 ,   11  ,   265 ,   659 ,   1329    ,   4259    ,0 };
            const std::uint32_t dim1742Kuo3Init[]   =   {   1   ,   3   ,   5   ,   1   ,   1   ,   59  ,   105 ,   251 ,   131 ,   817 ,   1215    ,   3005    ,   3417    ,   5637    ,0 };
            const std::uint32_t dim1743Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   31  ,   37  ,   27  ,   243 ,   225 ,   631 ,   2023    ,   2509    ,   249 ,   593 ,0 };
            const std::uint32_t dim1744Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   27  ,   51  ,   89  ,   33  ,   423 ,   423 ,   789 ,   3627    ,   2995    ,   8477    ,0 };
            const std::uint32_t dim1745Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   5   ,   31  ,   69  ,   65  ,   381 ,   375 ,   221 ,   477 ,   3311    ,   12103   ,0 };
            const std::uint32_t dim1746Kuo3Init[]   =   {   1   ,   3   ,   1   ,   15  ,   31  ,   1   ,   75  ,   97  ,   143 ,   749 ,   581 ,   4019    ,   4655    ,   15571   ,0 };
            const std::uint32_t dim1747Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   1   ,   31  ,   51  ,   151 ,   127 ,   917 ,   975 ,   2839    ,   3815    ,   7405    ,0 };
            const std::uint32_t dim1748Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   9   ,   61  ,   93  ,   49  ,   41  ,   881 ,   1205    ,   2425    ,   7727    ,   2687    ,0 };
            const std::uint32_t dim1749Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   27  ,   11  ,   99  ,   51  ,   51  ,   937 ,   1511    ,   3891    ,   3955    ,   6055    ,0 };
            const std::uint32_t dim1750Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   3   ,   27  ,   81  ,   107 ,   409 ,   895 ,   1869    ,   2721    ,   1505    ,   9877    ,0 };
            const std::uint32_t dim1751Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   11  ,   43  ,   101 ,   7   ,   263 ,   881 ,   1029    ,   1491    ,   4147    ,   10339   ,0 };
            const std::uint32_t dim1752Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   25  ,   21  ,   85  ,   145 ,   489 ,   335 ,   643 ,   4019    ,   951 ,   5885    ,0 };
            const std::uint32_t dim1753Kuo3Init[]   =   {   1   ,   1   ,   1   ,   15  ,   3   ,   55  ,   113 ,   87  ,   53  ,   839 ,   381 ,   1961    ,   3865    ,   2841    ,0 };
            const std::uint32_t dim1754Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   11  ,   33  ,   25  ,   95  ,   47  ,   321 ,   649 ,   1641    ,   1715    ,   3815    ,0 };
            const std::uint32_t dim1755Kuo3Init[]   =   {   1   ,   1   ,   1   ,   15  ,   23  ,   59  ,   5   ,   3   ,   451 ,   781 ,   867 ,   747 ,   793 ,   6147    ,0 };
            const std::uint32_t dim1756Kuo3Init[]   =   {   1   ,   1   ,   1   ,   15  ,   3   ,   27  ,   31  ,   125 ,   355 ,   837 ,   689 ,   3599    ,   1451    ,   2167    ,0 };
            const std::uint32_t dim1757Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   21  ,   5   ,   101 ,   37  ,   465 ,   115 ,   1607    ,   2999    ,   631 ,   1435    ,0 };
            const std::uint32_t dim1758Kuo3Init[]   =   {   1   ,   3   ,   5   ,   9   ,   19  ,   41  ,   91  ,   241 ,   375 ,   707 ,   1573    ,   105 ,   863 ,   11273   ,0 };
            const std::uint32_t dim1759Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   17  ,   63  ,   95  ,   83  ,   273 ,   617 ,   1299    ,   1259    ,   7997    ,   5225    ,0 };
            const std::uint32_t dim1760Kuo3Init[]   =   {   1   ,   3   ,   5   ,   9   ,   11  ,   5   ,   127 ,   67  ,   189 ,   733 ,   1175    ,   3099    ,   6561    ,   7771    ,0 };
            const std::uint32_t dim1761Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   13  ,   45  ,   75  ,   101 ,   279 ,   147 ,   177 ,   225 ,   557 ,   9413    ,0 };
            const std::uint32_t dim1762Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   11  ,   53  ,   49  ,   71  ,   451 ,   327 ,   567 ,   531 ,   589 ,   15395   ,0 };
            const std::uint32_t dim1763Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   29  ,   51  ,   95  ,   227 ,   87  ,   171 ,   1769    ,   2799    ,   2589    ,   7255    ,0 };
            const std::uint32_t dim1764Kuo3Init[]   =   {   1   ,   1   ,   5   ,   7   ,   1   ,   51  ,   109 ,   135 ,   99  ,   957 ,   1681    ,   2217    ,   2247    ,   6567    ,0 };
            const std::uint32_t dim1765Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   27  ,   57  ,   101 ,   51  ,   237 ,   835 ,   1339    ,   955 ,   5969    ,   12511   ,0 };
            const std::uint32_t dim1766Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   21  ,   9   ,   95  ,   247 ,   309 ,   413 ,   17  ,   3473    ,   3961    ,   8555    ,0 };
            const std::uint32_t dim1767Kuo3Init[]   =   {   1   ,   1   ,   1   ,   1   ,   21  ,   47  ,   29  ,   33  ,   135 ,   447 ,   1387    ,   107 ,   4781    ,   10987   ,0 };
            const std::uint32_t dim1768Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   5   ,   17  ,   41  ,   103 ,   83  ,   829 ,   1449    ,   4047    ,   4807    ,   7277    ,0 };
            const std::uint32_t dim1769Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   5   ,   1   ,   75  ,   241 ,   235 ,   701 ,   1529    ,   1621    ,   7995    ,   6243    ,0 };
            const std::uint32_t dim1770Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   23  ,   49  ,   31  ,   173 ,   83  ,   961 ,   1293    ,   1279    ,   2495    ,   10805   ,0 };
            const std::uint32_t dim1771Kuo3Init[]   =   {   1   ,   1   ,   1   ,   1   ,   15  ,   39  ,   17  ,   81  ,   167 ,   209 ,   685 ,   1089    ,   7197    ,   15773   ,0 };
            const std::uint32_t dim1772Kuo3Init[]   =   {   1   ,   1   ,   1   ,   15  ,   29  ,   1   ,   73  ,   113 ,   21  ,   301 ,   1087    ,   2529    ,   6835    ,   8089    ,0 };
            const std::uint32_t dim1773Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   1   ,   7   ,   99  ,   87  ,   177 ,   537 ,   283 ,   205 ,   6241    ,   12489   ,0 };
            const std::uint32_t dim1774Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   11  ,   13  ,   89  ,   43  ,   37  ,   859 ,   263 ,   2623    ,   6941    ,   7433    ,0 };
            const std::uint32_t dim1775Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   9   ,   47  ,   13  ,   155 ,   109 ,   507 ,   343 ,   1049    ,   4915    ,   14873   ,0 };
            const std::uint32_t dim1776Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   5   ,   37  ,   5   ,   71  ,   1   ,   17  ,   417 ,   3137    ,   3045    ,   5835    ,0 };
            const std::uint32_t dim1777Kuo3Init[]   =   {   1   ,   3   ,   3   ,   5   ,   15  ,   43  ,   31  ,   235 ,   379 ,   807 ,   89  ,   3375    ,   123 ,   9783    ,0 };
            const std::uint32_t dim1778Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   19  ,   23  ,   53  ,   129 ,   493 ,   393 ,   91  ,   2345    ,   1959    ,   745 ,0 };
            const std::uint32_t dim1779Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   21  ,   33  ,   31  ,   125 ,   99  ,   167 ,   685 ,   733 ,   6479    ,   10391   ,0 };
            const std::uint32_t dim1780Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   1   ,   17  ,   9   ,   245 ,   75  ,   281 ,   1427    ,   675 ,   5393    ,   8841    ,0 };
            const std::uint32_t dim1781Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   15  ,   63  ,   31  ,   83  ,   359 ,   643 ,   77  ,   3941    ,   5477    ,   3435    ,0 };
            const std::uint32_t dim1782Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   31  ,   21  ,   3   ,   111 ,   233 ,   745 ,   1819    ,   2617    ,   5735    ,   15237   ,0 };
            const std::uint32_t dim1783Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   29  ,   23  ,   99  ,   25  ,   119 ,   69  ,   1063    ,   651 ,   4983    ,   14079   ,0 };
            const std::uint32_t dim1784Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   9   ,   53  ,   47  ,   127 ,   443 ,   113 ,   1651    ,   2967    ,   6633    ,   10025   ,0 };
            const std::uint32_t dim1785Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   19  ,   11  ,   5   ,   49  ,   23  ,   567 ,   1095    ,   3815    ,   4187    ,   5305    ,0 };
            const std::uint32_t dim1786Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   29  ,   63  ,   85  ,   147 ,   105 ,   307 ,   1829    ,   27  ,   7499    ,   15661   ,0 };
            const std::uint32_t dim1787Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   15  ,   19  ,   97  ,   65  ,   71  ,   597 ,   551 ,   947 ,   8047    ,   8513    ,0 };
            const std::uint32_t dim1788Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   29  ,   31  ,   1   ,   135 ,   159 ,   769 ,   997 ,   3027    ,   1485    ,   12627   ,0 };
            const std::uint32_t dim1789Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   29  ,   47  ,   37  ,   43  ,   45  ,   649 ,   719 ,   1757    ,   4619    ,   11571   ,0 };
            const std::uint32_t dim1790Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   9   ,   9   ,   117 ,   207 ,   107 ,   651 ,   1155    ,   2047    ,   7489    ,   5959    ,0 };
            const std::uint32_t dim1791Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   29  ,   37  ,   69  ,   243 ,   347 ,   849 ,   1503    ,   3985    ,   6081    ,   1471    ,0 };
            const std::uint32_t dim1792Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   1   ,   21  ,   107 ,   9   ,   377 ,   147 ,   925 ,   3055    ,   397 ,   11337   ,0 };
            const std::uint32_t dim1793Kuo3Init[]   =   {   1   ,   3   ,   5   ,   9   ,   27  ,   45  ,   57  ,   177 ,   229 ,   925 ,   855 ,   2203    ,   8065    ,   299 ,0 };
            const std::uint32_t dim1794Kuo3Init[]   =   {   1   ,   3   ,   1   ,   11  ,   5   ,   1   ,   77  ,   149 ,   339 ,   1023    ,   89  ,   3509    ,   4315    ,   6571    ,0 };
            const std::uint32_t dim1795Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   19  ,   51  ,   49  ,   191 ,   179 ,   941 ,   1409    ,   1789    ,   3363    ,   11507   ,0 };
            const std::uint32_t dim1796Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   29  ,   25  ,   47  ,   61  ,   121 ,   243 ,   1155    ,   3915    ,   5397    ,   6289    ,0 };
            const std::uint32_t dim1797Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   31  ,   55  ,   25  ,   125 ,   239 ,   277 ,   165 ,   3631    ,   3609    ,   13607   ,0 };
            const std::uint32_t dim1798Kuo3Init[]   =   {   1   ,   3   ,   1   ,   15  ,   11  ,   23  ,   41  ,   199 ,   239 ,   805 ,   2021    ,   3377    ,   3103    ,   10657   ,0 };
            const std::uint32_t dim1799Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   27  ,   49  ,   9   ,   219 ,   383 ,   523 ,   1357    ,   501 ,   733 ,   631 ,0 };
            const std::uint32_t dim1800Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   1   ,   51  ,   125 ,   185 ,   205 ,   231 ,   247 ,   2579    ,   1283    ,   3383    ,0 };
            const std::uint32_t dim1801Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   13  ,   49  ,   81  ,   243 ,   111 ,   219 ,   409 ,   3755    ,   3783    ,   8159    ,0 };
            const std::uint32_t dim1802Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   13  ,   33  ,   109 ,   245 ,   141 ,   391 ,   101 ,   2043    ,   4091    ,   379 ,0 };
            const std::uint32_t dim1803Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   27  ,   39  ,   7   ,   223 ,   107 ,   969 ,   1117    ,   3599    ,   8063    ,   7737    ,0 };
            const std::uint32_t dim1804Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   11  ,   19  ,   9   ,   47  ,   41  ,   571 ,   1831    ,   3   ,   5721    ,   14897   ,0 };
            const std::uint32_t dim1805Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   11  ,   25  ,   75  ,   159 ,   77  ,   843 ,   61  ,   2283    ,   4033    ,   15099   ,0 };
            const std::uint32_t dim1806Kuo3Init[]   =   {   1   ,   3   ,   7   ,   1   ,   5   ,   23  ,   57  ,   117 ,   45  ,   373 ,   831 ,   3047    ,   5829    ,   3205    ,0 };
            const std::uint32_t dim1807Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   31  ,   29  ,   45  ,   129 ,   25  ,   519 ,   661 ,   2033    ,   3003    ,   12469   ,0 };
            const std::uint32_t dim1808Kuo3Init[]   =   {   1   ,   3   ,   1   ,   15  ,   5   ,   37  ,   55  ,   247 ,   129 ,   299 ,   1317    ,   3543    ,   421 ,   12299   ,0 };
            const std::uint32_t dim1809Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   23  ,   63  ,   5   ,   117 ,   425 ,   883 ,   1997    ,   1701    ,   415 ,   3279    ,0 };
            const std::uint32_t dim1810Kuo3Init[]   =   {   1   ,   3   ,   3   ,   5   ,   1   ,   21  ,   23  ,   109 ,   55  ,   377 ,   1565    ,   2821    ,   4995    ,   3151    ,0 };
            const std::uint32_t dim1811Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   19  ,   39  ,   43  ,   169 ,   141 ,   353 ,   459 ,   2509    ,   1503    ,   3597    ,0 };
            const std::uint32_t dim1812Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   17  ,   55  ,   121 ,   49  ,   229 ,   589 ,   579 ,   2935    ,   4647    ,   12887   ,0 };
            const std::uint32_t dim1813Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   11  ,   47  ,   11  ,   119 ,   83  ,   701 ,   197 ,   583 ,   7997    ,   11635   ,0 };
            const std::uint32_t dim1814Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   25  ,   47  ,   85  ,   21  ,   317 ,   887 ,   1551    ,   2309    ,   4227    ,   8115    ,0 };
            const std::uint32_t dim1815Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   13  ,   23  ,   71  ,   7   ,   419 ,   873 ,   1423    ,   2213    ,   7485    ,   13237   ,0 };
            const std::uint32_t dim1816Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   25  ,   55  ,   43  ,   141 ,   125 ,   583 ,   451 ,   3897    ,   4059    ,   7409    ,0 };
            const std::uint32_t dim1817Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   19  ,   55  ,   13  ,   61  ,   461 ,   353 ,   981 ,   2271    ,   4881    ,   12761   ,0 };
            const std::uint32_t dim1818Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   31  ,   61  ,   105 ,   105 ,   497 ,   173 ,   1111    ,   873 ,   1869    ,   9027    ,0 };
            const std::uint32_t dim1819Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   31  ,   31  ,   93  ,   119 ,   399 ,   617 ,   1977    ,   3913    ,   8061    ,   13017   ,0 };
            const std::uint32_t dim1820Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   17  ,   7   ,   89  ,   149 ,   119 ,   791 ,   839 ,   3643    ,   7545    ,   13329   ,0 };
            const std::uint32_t dim1821Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   13  ,   59  ,   35  ,   231 ,   3   ,   703 ,   881 ,   45  ,   5979    ,   3249    ,0 };
            const std::uint32_t dim1822Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   1   ,   21  ,   117 ,   105 ,   3   ,   791 ,   1563    ,   2303    ,   3533    ,   7853    ,0 };
            const std::uint32_t dim1823Kuo3Init[]   =   {   1   ,   3   ,   3   ,   5   ,   11  ,   11  ,   109 ,   115 ,   233 ,   471 ,   509 ,   821 ,   7209    ,   15463   ,0 };
            const std::uint32_t dim1824Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   13  ,   1   ,   83  ,   99  ,   21  ,   369 ,   751 ,   277 ,   881 ,   8963    ,0 };
            const std::uint32_t dim1825Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   27  ,   57  ,   3   ,   219 ,   509 ,   337 ,   1469    ,   2881    ,   7911    ,   1983    ,0 };
            const std::uint32_t dim1826Kuo3Init[]   =   {   1   ,   1   ,   7   ,   15  ,   1   ,   25  ,   35  ,   243 ,   243 ,   491 ,   1031    ,   2905    ,   4293    ,   8387    ,0 };
            const std::uint32_t dim1827Kuo3Init[]   =   {   1   ,   1   ,   1   ,   15  ,   5   ,   1   ,   121 ,   71  ,   129 ,   333 ,   1121    ,   917 ,   6627    ,   3291    ,0 };
            const std::uint32_t dim1828Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   7   ,   37  ,   13  ,   7   ,   115 ,   863 ,   345 ,   603 ,   1471    ,   15843   ,0 };
            const std::uint32_t dim1829Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   3   ,   49  ,   29  ,   79  ,   185 ,   685 ,   1691    ,   3469    ,   7111    ,   915 ,0 };
            const std::uint32_t dim1830Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   19  ,   61  ,   67  ,   143 ,   133 ,   457 ,   1865    ,   3403    ,   2557    ,   2603    ,0 };
            const std::uint32_t dim1831Kuo3Init[]   =   {   1   ,   1   ,   1   ,   15  ,   27  ,   25  ,   9   ,   87  ,   489 ,   23  ,   1251    ,   1995    ,   4737    ,   3099    ,0 };
            const std::uint32_t dim1832Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   5   ,   43  ,   55  ,   85  ,   43  ,   621 ,   145 ,   1507    ,   4895    ,   687 ,0 };
            const std::uint32_t dim1833Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   7   ,   35  ,   101 ,   19  ,   35  ,   609 ,   1433    ,   3877    ,   3661    ,   2517    ,0 };
            const std::uint32_t dim1834Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   31  ,   47  ,   89  ,   225 ,   95  ,   941 ,   287 ,   1163    ,   6537    ,   10907   ,0 };
            const std::uint32_t dim1835Kuo3Init[]   =   {   1   ,   3   ,   7   ,   1   ,   15  ,   61  ,   65  ,   205 ,   413 ,   147 ,   833 ,   2097    ,   5465    ,   6309    ,0 };
            const std::uint32_t dim1836Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   27  ,   55  ,   37  ,   185 ,   265 ,   343 ,   805 ,   325 ,   283 ,   1935    ,0 };
            const std::uint32_t dim1837Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   29  ,   7   ,   55  ,   243 ,   101 ,   87  ,   2015    ,   2897    ,   2087    ,   47  ,0 };
            const std::uint32_t dim1838Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   27  ,   1   ,   125 ,   65  ,   205 ,   525 ,   655 ,   3881    ,   993 ,   3967    ,0 };
            const std::uint32_t dim1839Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   3   ,   61  ,   85  ,   31  ,   257 ,   257 ,   1227    ,   3329    ,   731 ,   7223    ,0 };
            const std::uint32_t dim1840Kuo3Init[]   =   {   1   ,   1   ,   7   ,   15  ,   29  ,   49  ,   49  ,   171 ,   95  ,   475 ,   601 ,   1325    ,   3995    ,   14421   ,0 };
            const std::uint32_t dim1841Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   21  ,   23  ,   97  ,   65  ,   53  ,   417 ,   181 ,   551 ,   6583    ,   12835   ,0 };
            const std::uint32_t dim1842Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   27  ,   37  ,   37  ,   143 ,   181 ,   59  ,   1011    ,   97  ,   2757    ,   15537   ,0 };
            const std::uint32_t dim1843Kuo3Init[]   =   {   1   ,   3   ,   5   ,   9   ,   5   ,   47  ,   121 ,   91  ,   297 ,   897 ,   813 ,   2563    ,   1779    ,   12675   ,0 };
            const std::uint32_t dim1844Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   17  ,   61  ,   31  ,   47  ,   509 ,   55  ,   1401    ,   2251    ,   4327    ,   10409   ,0 };
            const std::uint32_t dim1845Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   15  ,   29  ,   97  ,   37  ,   295 ,   271 ,   893 ,   1135    ,   1651    ,   9271    ,0 };
            const std::uint32_t dim1846Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   29  ,   37  ,   65  ,   247 ,   247 ,   341 ,   865 ,   2163    ,   6827    ,   1849    ,0 };
            const std::uint32_t dim1847Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   27  ,   27  ,   105 ,   67  ,   283 ,   221 ,   1445    ,   3283    ,   865 ,   3747    ,0 };
            const std::uint32_t dim1848Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   7   ,   33  ,   63  ,   193 ,   219 ,   357 ,   1755    ,   2521    ,   5375    ,   10049   ,0 };
            const std::uint32_t dim1849Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   17  ,   43  ,   113 ,   171 ,   237 ,   75  ,   1257    ,   251 ,   4681    ,   14793   ,0 };
            const std::uint32_t dim1850Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   15  ,   15  ,   103 ,   163 ,   61  ,   263 ,   1165    ,   4021    ,   6833    ,   2675    ,0 };
            const std::uint32_t dim1851Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   21  ,   63  ,   69  ,   29  ,   237 ,   473 ,   1457    ,   3545    ,   1457    ,   7595    ,0 };
            const std::uint32_t dim1852Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   29  ,   33  ,   85  ,   103 ,   469 ,   579 ,   387 ,   2113    ,   5365    ,   7955    ,0 };
            const std::uint32_t dim1853Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   7   ,   37  ,   99  ,   87  ,   147 ,   401 ,   125 ,   1233    ,   1463    ,   15067   ,0 };
            const std::uint32_t dim1854Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   29  ,   11  ,   17  ,   89  ,   55  ,   273 ,   1069    ,   203 ,   941 ,   13667   ,0 };
            const std::uint32_t dim1855Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   3   ,   53  ,   75  ,   163 ,   79  ,   63  ,   1851    ,   1495    ,   6537    ,   6329    ,0 };
            const std::uint32_t dim1856Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   7   ,   53  ,   39  ,   35  ,   211 ,   275 ,   553 ,   1247    ,   3137    ,   11513   ,0 };
            const std::uint32_t dim1857Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   25  ,   37  ,   15  ,   249 ,   79  ,   227 ,   1297    ,   277 ,   7693    ,   2431    ,0 };
            const std::uint32_t dim1858Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   15  ,   53  ,   61  ,   27  ,   313 ,   817 ,   699 ,   3743    ,   6683    ,   11909   ,0 };
            const std::uint32_t dim1859Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   9   ,   3   ,   77  ,   25  ,   421 ,   403 ,   1729    ,   1349    ,   5995    ,   7579    ,0 };
            const std::uint32_t dim1860Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   29  ,   25  ,   1   ,   3   ,   69  ,   479 ,   699 ,   1317    ,   6729    ,   7701    ,0 };
            const std::uint32_t dim1861Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   15  ,   51  ,   41  ,   227 ,   195 ,   101 ,   1783    ,   485 ,   1157    ,   1849    ,0 };
            const std::uint32_t dim1862Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   1   ,   31  ,   111 ,   149 ,   361 ,   291 ,   1353    ,   3531    ,   473 ,   8545    ,0 };
            const std::uint32_t dim1863Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   9   ,   35  ,   31  ,   165 ,   175 ,   617 ,   1063    ,   179 ,   957 ,   1395    ,0 };
            const std::uint32_t dim1864Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   1   ,   5   ,   21  ,   191 ,   379 ,   293 ,   439 ,   1575    ,   243 ,   5013    ,0 };
            const std::uint32_t dim1865Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   1   ,   21  ,   107 ,   91  ,   473 ,   809 ,   993 ,   2599    ,   8151    ,   10927   ,0 };
            const std::uint32_t dim1866Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   13  ,   35  ,   71  ,   37  ,   173 ,   545 ,   1279    ,   225 ,   3275    ,   8823    ,0 };
            const std::uint32_t dim1867Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   3   ,   21  ,   97  ,   23  ,   197 ,   535 ,   741 ,   3481    ,   919 ,   14675   ,   14019   ,0 };
            const std::uint32_t dim1868Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   23  ,   25  ,   73  ,   203 ,   405 ,   287 ,   1167    ,   2313    ,   3065    ,   6385    ,   16509   ,0 };
            const std::uint32_t dim1869Kuo3Init[]   =   {   1   ,   1   ,   7   ,   15  ,   9   ,   23  ,   59  ,   241 ,   245 ,   865 ,   97  ,   931 ,   3317    ,   747 ,   14415   ,0 };
            const std::uint32_t dim1870Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   7   ,   13  ,   73  ,   213 ,   345 ,   707 ,   1223    ,   517 ,   4427    ,   9539    ,   2669    ,0 };
            const std::uint32_t dim1871Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   29  ,   41  ,   75  ,   149 ,   445 ,   933 ,   1727    ,   1967    ,   1927    ,   1205    ,   30051   ,0 };
            const std::uint32_t dim1872Kuo3Init[]   =   {   1   ,   1   ,   7   ,   9   ,   17  ,   57  ,   119 ,   115 ,   39  ,   957 ,   309 ,   3197    ,   6849    ,   7151    ,   1771    ,0 };
            const std::uint32_t dim1873Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   19  ,   57  ,   25  ,   89  ,   223 ,   921 ,   1741    ,   2695    ,   3571    ,   11933   ,   4973    ,0 };
            const std::uint32_t dim1874Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   29  ,   37  ,   77  ,   239 ,   63  ,   231 ,   639 ,   1311    ,   725 ,   5699    ,   15709   ,0 };
            const std::uint32_t dim1875Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   31  ,   23  ,   53  ,   27  ,   353 ,   851 ,   685 ,   169 ,   5325    ,   13675   ,   21493   ,0 };
            const std::uint32_t dim1876Kuo3Init[]   =   {   1   ,   3   ,   5   ,   9   ,   31  ,   13  ,   37  ,   7   ,   51  ,   211 ,   1807    ,   3107    ,   6485    ,   12595   ,   1097    ,0 };
            const std::uint32_t dim1877Kuo3Init[]   =   {   1   ,   1   ,   7   ,   15  ,   9   ,   3   ,   33  ,   197 ,   357 ,   841 ,   1233    ,   2065    ,   5009    ,   5863    ,   11287   ,0 };
            const std::uint32_t dim1878Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   27  ,   15  ,   75  ,   195 ,   223 ,   689 ,   1181    ,   1597    ,   2553    ,   7985    ,   13593   ,0 };
            const std::uint32_t dim1879Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   21  ,   41  ,   97  ,   121 ,   293 ,   639 ,   1799    ,   689 ,   6941    ,   14179   ,   11007   ,0 };
            const std::uint32_t dim1880Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   21  ,   61  ,   91  ,   177 ,   213 ,   757 ,   123 ,   2021    ,   1493    ,   2365    ,   9713    ,0 };
            const std::uint32_t dim1881Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   3   ,   57  ,   33  ,   229 ,   45  ,   351 ,   1671    ,   2047    ,   7685    ,   14375   ,   5773    ,0 };
            const std::uint32_t dim1882Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   23  ,   55  ,   19  ,   83  ,   11  ,   463 ,   83  ,   3071    ,   5257    ,   2741    ,   31137   ,0 };
            const std::uint32_t dim1883Kuo3Init[]   =   {   1   ,   3   ,   3   ,   5   ,   5   ,   31  ,   53  ,   135 ,   255 ,   711 ,   1873    ,   609 ,   3395    ,   16137   ,   19947   ,0 };
            const std::uint32_t dim1884Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   13  ,   29  ,   117 ,   203 ,   387 ,   529 ,   1301    ,   3199    ,   1843    ,   5381    ,   12491   ,0 };
            const std::uint32_t dim1885Kuo3Init[]   =   {   1   ,   3   ,   1   ,   15  ,   25  ,   61  ,   21  ,   75  ,   111 ,   757 ,   1611    ,   2911    ,   5805    ,   5787    ,   5099    ,0 };
            const std::uint32_t dim1886Kuo3Init[]   =   {   1   ,   3   ,   3   ,   5   ,   1   ,   33  ,   51  ,   45  ,   115 ,   45  ,   1155    ,   951 ,   6471    ,   10233   ,   8053    ,0 };
            const std::uint32_t dim1887Kuo3Init[]   =   {   1   ,   3   ,   7   ,   1   ,   11  ,   13  ,   17  ,   167 ,   391 ,   219 ,   277 ,   3311    ,   1761    ,   6741    ,   6253    ,0 };
            const std::uint32_t dim1888Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   3   ,   9   ,   43  ,   187 ,   113 ,   747 ,   1207    ,   3513    ,   1055    ,   15145   ,   3793    ,0 };
            const std::uint32_t dim1889Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   3   ,   33  ,   127 ,   95  ,   47  ,   663 ,   1581    ,   489 ,   2303    ,   15183   ,   21671   ,0 };
            const std::uint32_t dim1890Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   15  ,   7   ,   53  ,   143 ,   313 ,   167 ,   425 ,   3153    ,   7241    ,   3019    ,   27323   ,0 };
            const std::uint32_t dim1891Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   1   ,   47  ,   47  ,   211 ,   79  ,   495 ,   1383    ,   2373    ,   141 ,   2933    ,   11535   ,0 };
            const std::uint32_t dim1892Kuo3Init[]   =   {   1   ,   3   ,   1   ,   11  ,   13  ,   35  ,   79  ,   105 ,   329 ,   235 ,   667 ,   2431    ,   6427    ,   15335   ,   15013   ,0 };
            const std::uint32_t dim1893Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   25  ,   33  ,   27  ,   241 ,   153 ,   197 ,   221 ,   3149    ,   2357    ,   4485    ,   17877   ,0 };
            const std::uint32_t dim1894Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   31  ,   29  ,   43  ,   39  ,   439 ,   799 ,   293 ,   727 ,   6387    ,   12257   ,   15701   ,0 };
            const std::uint32_t dim1895Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   17  ,   47  ,   105 ,   33  ,   275 ,   269 ,   259 ,   2293    ,   1829    ,   13141   ,   3015    ,0 };
            const std::uint32_t dim1896Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   29  ,   27  ,   43  ,   161 ,   131 ,   95  ,   851 ,   1269    ,   491 ,   4073    ,   3481    ,0 };
            const std::uint32_t dim1897Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   23  ,   13  ,   35  ,   137 ,   405 ,   899 ,   1521    ,   2193    ,   725 ,   11967   ,   16937   ,0 };
            const std::uint32_t dim1898Kuo3Init[]   =   {   1   ,   3   ,   1   ,   15  ,   5   ,   15  ,   113 ,   139 ,   307 ,   125 ,   635 ,   477 ,   493 ,   9879    ,   21125   ,0 };
            const std::uint32_t dim1899Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   19  ,   9   ,   117 ,   173 ,   447 ,   485 ,   1073    ,   2893    ,   1767    ,   10299   ,   31449   ,0 };
            const std::uint32_t dim1900Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   11  ,   53  ,   99  ,   109 ,   393 ,   281 ,   187 ,   1557    ,   3597    ,   5215    ,   4033    ,0 };
            const std::uint32_t dim1901Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   5   ,   15  ,   33  ,   33  ,   37  ,   445 ,   1415    ,   2885    ,   2625    ,   465 ,   2745    ,0 };
            const std::uint32_t dim1902Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   7   ,   13  ,   93  ,   141 ,   427 ,   663 ,   1863    ,   991 ,   2001    ,   701 ,   18287   ,0 };
            const std::uint32_t dim1903Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   19  ,   47  ,   65  ,   49  ,   425 ,   691 ,   1487    ,   2725    ,   6145    ,   4983    ,   11871   ,0 };
            const std::uint32_t dim1904Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   27  ,   35  ,   89  ,   147 ,   413 ,   1007    ,   755 ,   3883    ,   4737    ,   10399   ,   19073   ,0 };
            const std::uint32_t dim1905Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   11  ,   41  ,   27  ,   225 ,   237 ,   407 ,   461 ,   1881    ,   3761    ,   6587    ,   28923   ,0 };
            const std::uint32_t dim1906Kuo3Init[]   =   {   1   ,   3   ,   5   ,   9   ,   1   ,   3   ,   93  ,   179 ,   157 ,   227 ,   571 ,   1901    ,   1407    ,   12059   ,   15281   ,0 };
            const std::uint32_t dim1907Kuo3Init[]   =   {   1   ,   3   ,   1   ,   15  ,   27  ,   29  ,   55  ,   169 ,   65  ,   517 ,   1801    ,   177 ,   5687    ,   9597    ,   5167    ,0 };
            const std::uint32_t dim1908Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   25  ,   47  ,   57  ,   15  ,   491 ,   631 ,   1567    ,   25  ,   2087    ,   7513    ,   15107   ,0 };
            const std::uint32_t dim1909Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   15  ,   55  ,   13  ,   39  ,   203 ,   487 ,   1235    ,   389 ,   281 ,   499 ,   20119   ,0 };
            const std::uint32_t dim1910Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   29  ,   53  ,   127 ,   211 ,   301 ,   509 ,   611 ,   1293    ,   6495    ,   10211   ,   4905    ,0 };
            const std::uint32_t dim1911Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   13  ,   15  ,   31  ,   205 ,   237 ,   429 ,   1721    ,   3953    ,   8153    ,   16275   ,   30421   ,0 };
            const std::uint32_t dim1912Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   27  ,   17  ,   43  ,   123 ,   503 ,   507 ,   257 ,   447 ,   6315    ,   5023    ,   6995    ,0 };
            const std::uint32_t dim1913Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   27  ,   33  ,   127 ,   33  ,   241 ,   1001    ,   1009    ,   1263    ,   4627    ,   9329    ,   29191   ,0 };
            const std::uint32_t dim1914Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   13  ,   45  ,   125 ,   77  ,   247 ,   123 ,   1581    ,   537 ,   799 ,   15417   ,   30457   ,0 };
            const std::uint32_t dim1915Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   9   ,   29  ,   39  ,   211 ,   243 ,   871 ,   1581    ,   4029    ,   4791    ,   13393   ,   25341   ,0 };
            const std::uint32_t dim1916Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   15  ,   17  ,   123 ,   123 ,   303 ,   207 ,   1551    ,   3633    ,   5591    ,   2725    ,   5707    ,0 };
            const std::uint32_t dim1917Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   29  ,   41  ,   111 ,   73  ,   163 ,   511 ,   1305    ,   3235    ,   4725    ,   13589   ,   9611    ,0 };
            const std::uint32_t dim1918Kuo3Init[]   =   {   1   ,   1   ,   1   ,   1   ,   19  ,   51  ,   17  ,   225 ,   499 ,   1013    ,   7   ,   1793    ,   7073    ,   10115   ,   18195   ,0 };
            const std::uint32_t dim1919Kuo3Init[]   =   {   1   ,   1   ,   7   ,   9   ,   17  ,   35  ,   107 ,   87  ,   251 ,   19  ,   959 ,   1389    ,   6725    ,   8555    ,   14571   ,0 };
            const std::uint32_t dim1920Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   1   ,   13  ,   79  ,   163 ,   17  ,   87  ,   1121    ,   1813    ,   1213    ,   3325    ,   18083   ,0 };
            const std::uint32_t dim1921Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   27  ,   5   ,   107 ,   143 ,   211 ,   459 ,   257 ,   957 ,   1183    ,   2367    ,   24687   ,0 };
            const std::uint32_t dim1922Kuo3Init[]   =   {   1   ,   1   ,   7   ,   15  ,   1   ,   33  ,   51  ,   25  ,   379 ,   829 ,   1657    ,   273 ,   4507    ,   9609    ,   879 ,0 };
            const std::uint32_t dim1923Kuo3Init[]   =   {   1   ,   1   ,   7   ,   15  ,   1   ,   31  ,   43  ,   181 ,   147 ,   373 ,   83  ,   2179    ,   6363    ,   1871    ,   10209   ,0 };
            const std::uint32_t dim1924Kuo3Init[]   =   {   1   ,   1   ,   1   ,   15  ,   9   ,   29  ,   105 ,   255 ,   483 ,   573 ,   1841    ,   1101    ,   2987    ,   1619    ,   18837   ,0 };
            const std::uint32_t dim1925Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   17  ,   19  ,   67  ,   109 ,   13  ,   247 ,   1365    ,   2153    ,   5597    ,   5785    ,   25877   ,0 };
            const std::uint32_t dim1926Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   17  ,   49  ,   121 ,   163 ,   49  ,   689 ,   1917    ,   2161    ,   7979    ,   8153    ,   12889   ,0 };
            const std::uint32_t dim1927Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   5   ,   49  ,   39  ,   251 ,   311 ,   69  ,   553 ,   2789    ,   2415    ,   6521    ,   26847   ,0 };
            const std::uint32_t dim1928Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   15  ,   51  ,   67  ,   227 ,   245 ,   893 ,   493 ,   1191    ,   3061    ,   249 ,   16603   ,0 };
            const std::uint32_t dim1929Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   17  ,   63  ,   35  ,   41  ,   269 ,   75  ,   147 ,   3229    ,   7985    ,   5789    ,   6365    ,0 };
            const std::uint32_t dim1930Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   21  ,   33  ,   125 ,   39  ,   343 ,   133 ,   389 ,   2467    ,   4079    ,   14315   ,   17047   ,0 };
            const std::uint32_t dim1931Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   27  ,   61  ,   73  ,   107 ,   143 ,   665 ,   155 ,   2865    ,   3017    ,   7307    ,   8771    ,0 };
            const std::uint32_t dim1932Kuo3Init[]   =   {   1   ,   1   ,   5   ,   7   ,   25  ,   57  ,   57  ,   39  ,   195 ,   405 ,   1863    ,   2985    ,   5775    ,   9609    ,   24409   ,0 };
            const std::uint32_t dim1933Kuo3Init[]   =   {   1   ,   3   ,   3   ,   5   ,   11  ,   27  ,   91  ,   169 ,   343 ,   673 ,   1317    ,   1763    ,   1603    ,   527 ,   18945   ,0 };
            const std::uint32_t dim1934Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   17  ,   39  ,   113 ,   47  ,   483 ,   793 ,   1295    ,   1305    ,   7025    ,   14849   ,   17703   ,0 };
            const std::uint32_t dim1935Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   5   ,   43  ,   119 ,   149 ,   103 ,   63  ,   1369    ,   3791    ,   3081    ,   10587   ,   12711   ,0 };
            const std::uint32_t dim1936Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   9   ,   55  ,   105 ,   171 ,   199 ,   883 ,   1113    ,   3559    ,   1979    ,   8823    ,   12407   ,0 };
            const std::uint32_t dim1937Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   27  ,   51  ,   105 ,   163 ,   203 ,   25  ,   1579    ,   351 ,   8071    ,   5921    ,   28935   ,0 };
            const std::uint32_t dim1938Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   15  ,   43  ,   115 ,   115 ,   5   ,   283 ,   1935    ,   2619    ,   2543    ,   7603    ,   2877    ,0 };
            const std::uint32_t dim1939Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   31  ,   29  ,   17  ,   67  ,   121 ,   187 ,   563 ,   377 ,   3947    ,   7699    ,   8677    ,0 };
            const std::uint32_t dim1940Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   5   ,   1   ,   121 ,   211 ,   109 ,   955 ,   1605    ,   3681    ,   5395    ,   797 ,   19243   ,0 };
            const std::uint32_t dim1941Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   7   ,   63  ,   73  ,   215 ,   403 ,   465 ,   1317    ,   3141    ,   4511    ,   12579   ,   20839   ,0 };
            const std::uint32_t dim1942Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   9   ,   63  ,   39  ,   55  ,   353 ,   395 ,   233 ,   1189    ,   1781    ,   9167    ,   887 ,0 };
            const std::uint32_t dim1943Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   1   ,   55  ,   93  ,   63  ,   211 ,   635 ,   1767    ,   827 ,   7257    ,   119 ,   26333   ,0 };
            const std::uint32_t dim1944Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   9   ,   33  ,   17  ,   205 ,   303 ,   713 ,   65  ,   3539    ,   5069    ,   8895    ,   3843    ,0 };
            const std::uint32_t dim1945Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   3   ,   59  ,   45  ,   135 ,   103 ,   293 ,   731 ,   359 ,   3631    ,   7967    ,   30043   ,0 };
            const std::uint32_t dim1946Kuo3Init[]   =   {   1   ,   3   ,   3   ,   7   ,   25  ,   7   ,   27  ,   161 ,   9   ,   509 ,   1345    ,   3759    ,   7957    ,   5975    ,   17981   ,0 };
            const std::uint32_t dim1947Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   13  ,   41  ,   105 ,   241 ,   331 ,   437 ,   2027    ,   2589    ,   5201    ,   11373   ,   22581   ,0 };
            const std::uint32_t dim1948Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   5   ,   3   ,   37  ,   43  ,   125 ,   521 ,   1059    ,   291 ,   4421    ,   5215    ,   16835   ,0 };
            const std::uint32_t dim1949Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   13  ,   15  ,   85  ,   175 ,   221 ,   527 ,   173 ,   1333    ,   7505    ,   883 ,   2215    ,0 };
            const std::uint32_t dim1950Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   27  ,   63  ,   5   ,   215 ,   85  ,   229 ,   165 ,   525 ,   2693    ,   15089   ,   4907    ,0 };
            const std::uint32_t dim1951Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   25  ,   13  ,   91  ,   81  ,   81  ,   189 ,   671 ,   539 ,   2393    ,   9627    ,   17667   ,0 };
            const std::uint32_t dim1952Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   5   ,   9   ,   45  ,   43  ,   337 ,   841 ,   853 ,   3969    ,   5917    ,   5837    ,   17265   ,0 };
            const std::uint32_t dim1953Kuo3Init[]   =   {   1   ,   1   ,   7   ,   9   ,   1   ,   57  ,   33  ,   29  ,   235 ,   69  ,   815 ,   147 ,   7251    ,   2933    ,   32405   ,0 };
            const std::uint32_t dim1954Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   29  ,   1   ,   3   ,   13  ,   483 ,   825 ,   31  ,   2289    ,   185 ,   9075    ,   15495   ,0 };
            const std::uint32_t dim1955Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   1   ,   33  ,   127 ,   53  ,   229 ,   975 ,   91  ,   3259    ,   7969    ,   4193    ,   18433   ,0 };
            const std::uint32_t dim1956Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   7   ,   43  ,   89  ,   193 ,   51  ,   563 ,   1961    ,   3959    ,   1901    ,   10393   ,   679 ,0 };
            const std::uint32_t dim1957Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   29  ,   11  ,   57  ,   227 ,   163 ,   169 ,   1969    ,   3087    ,   3221    ,   15499   ,   12255   ,0 };
            const std::uint32_t dim1958Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   31  ,   47  ,   45  ,   37  ,   257 ,   383 ,   1347    ,   3923    ,   7963    ,   13459   ,   8755    ,0 };
            const std::uint32_t dim1959Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   5   ,   53  ,   19  ,   219 ,   261 ,   313 ,   1889    ,   3185    ,   5309    ,   14049   ,   5231    ,0 };
            const std::uint32_t dim1960Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   29  ,   19  ,   49  ,   221 ,   443 ,   125 ,   929 ,   2445    ,   6713    ,   5639    ,   2657    ,0 };
            const std::uint32_t dim1961Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   17  ,   59  ,   87  ,   227 ,   305 ,   67  ,   311 ,   3473    ,   4785    ,   10761   ,   2871    ,0 };
            const std::uint32_t dim1962Kuo3Init[]   =   {   1   ,   1   ,   5   ,   7   ,   31  ,   63  ,   103 ,   127 ,   49  ,   839 ,   1991    ,   41  ,   5019    ,   12779   ,   25489   ,0 };
            const std::uint32_t dim1963Kuo3Init[]   =   {   1   ,   3   ,   5   ,   9   ,   9   ,   45  ,   127 ,   29  ,   441 ,   481 ,   49  ,   1975    ,   1523    ,   759 ,   847 ,0 };
            const std::uint32_t dim1964Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   1   ,   25  ,   89  ,   19  ,   53  ,   17  ,   1449    ,   603 ,   473 ,   9965    ,   14455   ,0 };
            const std::uint32_t dim1965Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   19  ,   9   ,   27  ,   97  ,   321 ,   1007    ,   1283    ,   3805    ,   539 ,   2979    ,   4631    ,0 };
            const std::uint32_t dim1966Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   9   ,   3   ,   9   ,   237 ,   349 ,   277 ,   1791    ,   3325    ,   865 ,   4305    ,   29293   ,0 };
            const std::uint32_t dim1967Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   13  ,   23  ,   63  ,   33  ,   381 ,   711 ,   1921    ,   1385    ,   5949    ,   8837    ,   3589    ,0 };
            const std::uint32_t dim1968Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   15  ,   5   ,   7   ,   175 ,   15  ,   343 ,   1587    ,   2917    ,   4189    ,   14973   ,   1691    ,0 };
            const std::uint32_t dim1969Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   17  ,   59  ,   123 ,   195 ,   377 ,   35  ,   917 ,   1045    ,   721 ,   9759    ,   15287   ,0 };
            const std::uint32_t dim1970Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   29  ,   3   ,   15  ,   147 ,   283 ,   449 ,   175 ,   1771    ,   2359    ,   7541    ,   11657   ,0 };
            const std::uint32_t dim1971Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   1   ,   11  ,   45  ,   117 ,   235 ,   75  ,   247 ,   917 ,   6135    ,   13817   ,   27365   ,0 };
            const std::uint32_t dim1972Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   1   ,   45  ,   31  ,   97  ,   281 ,   739 ,   829 ,   1837    ,   1709    ,   877 ,   25275   ,0 };
            const std::uint32_t dim1973Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   3   ,   35  ,   11  ,   55  ,   233 ,   471 ,   1239    ,   1345    ,   2475    ,   13391   ,   25447   ,0 };
            const std::uint32_t dim1974Kuo3Init[]   =   {   1   ,   1   ,   5   ,   7   ,   27  ,   33  ,   111 ,   89  ,   173 ,   361 ,   1641    ,   381 ,   1629    ,   5663    ,   17715   ,0 };
            const std::uint32_t dim1975Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   31  ,   59  ,   11  ,   165 ,   129 ,   513 ,   1729    ,   2707    ,   4665    ,   3381    ,   7915    ,0 };
            const std::uint32_t dim1976Kuo3Init[]   =   {   1   ,   3   ,   1   ,   11  ,   19  ,   15  ,   3   ,   99  ,   21  ,   255 ,   515 ,   1619    ,   1819    ,   4143    ,   24317   ,0 };
            const std::uint32_t dim1977Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   11  ,   33  ,   13  ,   143 ,   39  ,   557 ,   901 ,   187 ,   2963    ,   13413   ,   5641    ,0 };
            const std::uint32_t dim1978Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   5   ,   27  ,   87  ,   63  ,   41  ,   57  ,   2009    ,   493 ,   2565    ,   14931   ,   24071   ,0 };
            const std::uint32_t dim1979Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   7   ,   11  ,   31  ,   107 ,   343 ,   395 ,   841 ,   467 ,   1019    ,   3861    ,   19595   ,0 };
            const std::uint32_t dim1980Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   5   ,   15  ,   113 ,   23  ,   421 ,   693 ,   1421    ,   2213    ,   3589    ,   3713    ,   1353    ,0 };
            const std::uint32_t dim1981Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   17  ,   1   ,   87  ,   217 ,   333 ,   797 ,   1971    ,   917 ,   3527    ,   10061   ,   19353   ,0 };
            const std::uint32_t dim1982Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   5   ,   51  ,   17  ,   239 ,   275 ,   221 ,   1621    ,   215 ,   319 ,   12041   ,   15669   ,0 };
            const std::uint32_t dim1983Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   27  ,   33  ,   31  ,   19  ,   365 ,   951 ,   1453    ,   141 ,   1249    ,   16313   ,   30607   ,0 };
            const std::uint32_t dim1984Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   15  ,   19  ,   127 ,   247 ,   161 ,   921 ,   195 ,   2857    ,   1573    ,   11077   ,   15997   ,0 };
            const std::uint32_t dim1985Kuo3Init[]   =   {   1   ,   1   ,   1   ,   1   ,   9   ,   43  ,   57  ,   103 ,   215 ,   337 ,   1705    ,   961 ,   6895    ,   2671    ,   7157    ,0 };
            const std::uint32_t dim1986Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   13  ,   55  ,   123 ,   19  ,   279 ,   571 ,   1039    ,   2545    ,   5961    ,   12373   ,   11479   ,0 };
            const std::uint32_t dim1987Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   7   ,   35  ,   85  ,   89  ,   407 ,   359 ,   1897    ,   231 ,   7653    ,   9215    ,   9957    ,0 };
            const std::uint32_t dim1988Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   23  ,   53  ,   13  ,   153 ,   221 ,   363 ,   1481    ,   1069    ,   1023    ,   8573    ,   29385   ,0 };
            const std::uint32_t dim1989Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   15  ,   63  ,   1   ,   57  ,   373 ,   35  ,   725 ,   135 ,   5593    ,   5593    ,   8365    ,0 };
            const std::uint32_t dim1990Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   7   ,   35  ,   25  ,   69  ,   441 ,   451 ,   1109    ,   1723    ,   1617    ,   3947    ,   22349   ,0 };
            const std::uint32_t dim1991Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   27  ,   55  ,   75  ,   231 ,   245 ,   831 ,   1641    ,   1475    ,   51  ,   2683    ,   12489   ,0 };
            const std::uint32_t dim1992Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   17  ,   5   ,   61  ,   167 ,   389 ,   149 ,   43  ,   825 ,   6079    ,   12955   ,   20121   ,0 };
            const std::uint32_t dim1993Kuo3Init[]   =   {   1   ,   1   ,   5   ,   7   ,   15  ,   43  ,   63  ,   83  ,   187 ,   1005    ,   1675    ,   2907    ,   2357    ,   5459    ,   18621   ,0 };
            const std::uint32_t dim1994Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   27  ,   53  ,   49  ,   93  ,   9   ,   629 ,   1507    ,   357 ,   3207    ,   9209    ,   13697   ,0 };
            const std::uint32_t dim1995Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   19  ,   49  ,   65  ,   31  ,   359 ,   13  ,   617 ,   815 ,   4673    ,   2475    ,   27491   ,0 };
            const std::uint32_t dim1996Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   21  ,   39  ,   79  ,   107 ,   485 ,   905 ,   51  ,   987 ,   6579    ,   3899    ,   28785   ,0 };
            const std::uint32_t dim1997Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   7   ,   11  ,   111 ,   223 ,   249 ,   767 ,   141 ,   691 ,   4711    ,   583 ,   7917    ,0 };
            const std::uint32_t dim1998Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   9   ,   43  ,   115 ,   179 ,   313 ,   783 ,   2047    ,   1773    ,   2307    ,   5011    ,   7215    ,0 };
            const std::uint32_t dim1999Kuo3Init[]   =   {   1   ,   3   ,   3   ,   5   ,   23  ,   23  ,   85  ,   193 ,   83  ,   809 ,   1827    ,   3375    ,   5177    ,   2041    ,   19271   ,0 };
            const std::uint32_t dim2000Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   23  ,   17  ,   31  ,   111 ,   75  ,   265 ,   1171    ,   219 ,   6309    ,   2263    ,   3807    ,0 };
            const std::uint32_t dim2001Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   27  ,   7   ,   65  ,   117 ,   291 ,   811 ,   1797    ,   3395    ,   3495    ,   829 ,   23911   ,0 };
            const std::uint32_t dim2002Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   19  ,   31  ,   43  ,   229 ,   361 ,   219 ,   1029    ,   1407    ,   5855    ,   12411   ,   16117   ,0 };
            const std::uint32_t dim2003Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   5   ,   1   ,   99  ,   245 ,   21  ,   925 ,   1807    ,   2529    ,   627 ,   3363    ,   853 ,0 };
            const std::uint32_t dim2004Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   17  ,   41  ,   83  ,   31  ,   207 ,   615 ,   851 ,   1631    ,   6789    ,   12061   ,   12327   ,0 };
            const std::uint32_t dim2005Kuo3Init[]   =   {   1   ,   1   ,   7   ,   15  ,   27  ,   19  ,   75  ,   3   ,   51  ,   655 ,   73  ,   2433    ,   7973    ,   1425    ,   31309   ,0 };
            const std::uint32_t dim2006Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   25  ,   47  ,   73  ,   119 ,   91  ,   981 ,   1671    ,   2145    ,   3101    ,   3765    ,   8719    ,0 };
            const std::uint32_t dim2007Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   31  ,   37  ,   51  ,   181 ,   289 ,   273 ,   1889    ,   1017    ,   2793    ,   9513    ,   32549   ,0 };
            const std::uint32_t dim2008Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   5   ,   39  ,   57  ,   51  ,   135 ,   689 ,   1913    ,   709 ,   4759    ,   12223   ,   17377   ,0 };
            const std::uint32_t dim2009Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   31  ,   9   ,   57  ,   245 ,   159 ,   97  ,   1485    ,   2229    ,   1393    ,   9699    ,   5807    ,0 };
            const std::uint32_t dim2010Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   11  ,   3   ,   11  ,   169 ,   81  ,   667 ,   357 ,   2307    ,   7305    ,   8631    ,   2555    ,0 };
            const std::uint32_t dim2011Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   15  ,   17  ,   119 ,   143 ,   15  ,   567 ,   1879    ,   1363    ,   1617    ,   8231    ,   23071   ,0 };
            const std::uint32_t dim2012Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   5   ,   39  ,   49  ,   45  ,   371 ,   641 ,   943 ,   1231    ,   8139    ,   14423   ,   11057   ,0 };
            const std::uint32_t dim2013Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   27  ,   51  ,   25  ,   111 ,   205 ,   655 ,   317 ,   1381    ,   2359    ,   8785    ,   31503   ,0 };
            const std::uint32_t dim2014Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   9   ,   13  ,   127 ,   211 ,   423 ,   147 ,   735 ,   1323    ,   5801    ,   9291    ,   10059   ,0 };
            const std::uint32_t dim2015Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   19  ,   1   ,   11  ,   85  ,   343 ,   781 ,   1661    ,   1803    ,   4541    ,   2271    ,   20541   ,0 };
            const std::uint32_t dim2016Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   11  ,   15  ,   77  ,   63  ,   345 ,   71  ,   1311    ,   3809    ,   7535    ,   1269    ,   13949   ,0 };
            const std::uint32_t dim2017Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   19  ,   27  ,   3   ,   107 ,   439 ,   195 ,   2007    ,   4009    ,   305 ,   3111    ,   17775   ,0 };
            const std::uint32_t dim2018Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   27  ,   31  ,   25  ,   123 ,   177 ,   161 ,   287 ,   3389    ,   3013    ,   11427   ,   9165    ,0 };
            const std::uint32_t dim2019Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   27  ,   15  ,   83  ,   131 ,   201 ,   277 ,   267 ,   3557    ,   1337    ,   4427    ,   2389    ,0 };
            const std::uint32_t dim2020Kuo3Init[]   =   {   1   ,   1   ,   5   ,   7   ,   25  ,   27  ,   75  ,   211 ,   147 ,   37  ,   491 ,   3467    ,   4525    ,   13073   ,   15289   ,0 };
            const std::uint32_t dim2021Kuo3Init[]   =   {   1   ,   3   ,   5   ,   9   ,   13  ,   37  ,   117 ,   159 ,   145 ,   453 ,   1451    ,   667 ,   1861    ,   6855    ,   25389   ,0 };
            const std::uint32_t dim2022Kuo3Init[]   =   {   1   ,   1   ,   5   ,   7   ,   19  ,   37  ,   3   ,   157 ,   251 ,   901 ,   433 ,   3289    ,   2723    ,   11941   ,   10103   ,0 };
            const std::uint32_t dim2023Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   31  ,   51  ,   125 ,   211 ,   317 ,   775 ,   801 ,   3887    ,   2257    ,   13947   ,   2421    ,0 };
            const std::uint32_t dim2024Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   11  ,   21  ,   67  ,   223 ,   203 ,   409 ,   1927    ,   3565    ,   679 ,   14197   ,   24987   ,0 };
            const std::uint32_t dim2025Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   23  ,   29  ,   37  ,   203 ,   311 ,   825 ,   1957    ,   3069    ,   5295    ,   4073    ,   4407    ,0 };
            const std::uint32_t dim2026Kuo3Init[]   =   {   1   ,   3   ,   1   ,   15  ,   1   ,   49  ,   111 ,   205 ,   441 ,   907 ,   481 ,   225 ,   6589    ,   7523    ,   19807   ,0 };
            const std::uint32_t dim2027Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   1   ,   55  ,   43  ,   121 ,   9   ,   239 ,   723 ,   3109    ,   5639    ,   9547    ,   20455   ,0 };
            const std::uint32_t dim2028Kuo3Init[]   =   {   1   ,   1   ,   1   ,   15  ,   29  ,   17  ,   121 ,   61  ,   233 ,   873 ,   1447    ,   1313    ,   5073    ,   12259   ,   32305   ,0 };
            const std::uint32_t dim2029Kuo3Init[]   =   {   1   ,   1   ,   5   ,   7   ,   25  ,   57  ,   15  ,   45  ,   243 ,   297 ,   219 ,   2307    ,   1459    ,   16005   ,   10041   ,0 };
            const std::uint32_t dim2030Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   5   ,   53  ,   57  ,   187 ,   287 ,   243 ,   1223    ,   1625    ,   669 ,   5165    ,   8395    ,0 };
            const std::uint32_t dim2031Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   23  ,   23  ,   25  ,   225 ,   471 ,   661 ,   905 ,   2293    ,   1131    ,   8469    ,   7929    ,0 };
            const std::uint32_t dim2032Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   11  ,   33  ,   11  ,   129 ,   237 ,   855 ,   1417    ,   3661    ,   1561    ,   9635    ,   31905   ,0 };
            const std::uint32_t dim2033Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   15  ,   45  ,   3   ,   253 ,   125 ,   449 ,   1675    ,   1707    ,   3917    ,   11829   ,   27439   ,0 };
            const std::uint32_t dim2034Kuo3Init[]   =   {   1   ,   3   ,   7   ,   1   ,   1   ,   55  ,   83  ,   69  ,   83  ,   745 ,   1225    ,   977 ,   7117    ,   15045   ,   28067   ,0 };
            const std::uint32_t dim2035Kuo3Init[]   =   {   1   ,   1   ,   7   ,   9   ,   3   ,   51  ,   23  ,   205 ,   5   ,   625 ,   531 ,   3557    ,   4101    ,   5709    ,   29487   ,0 };
            const std::uint32_t dim2036Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   9   ,   23  ,   69  ,   99  ,   203 ,   355 ,   1935    ,   3165    ,   5701    ,   15491   ,   18151   ,0 };
            const std::uint32_t dim2037Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   31  ,   41  ,   89  ,   85  ,   273 ,   227 ,   785 ,   1057    ,   4409    ,   9155    ,   11573   ,0 };
            const std::uint32_t dim2038Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   17  ,   49  ,   117 ,   31  ,   181 ,   799 ,   417 ,   3931    ,   6069    ,   1253    ,   25793   ,0 };
            const std::uint32_t dim2039Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   27  ,   23  ,   33  ,   189 ,   5   ,   841 ,   901 ,   2023    ,   331 ,   10015   ,   3781    ,0 };
            const std::uint32_t dim2040Kuo3Init[]   =   {   1   ,   3   ,   3   ,   5   ,   19  ,   47  ,   73  ,   103 ,   373 ,   1011    ,   1015    ,   1657    ,   6181    ,   69  ,   16243   ,0 };
            const std::uint32_t dim2041Kuo3Init[]   =   {   1   ,   1   ,   7   ,   9   ,   13  ,   9   ,   95  ,   161 ,   413 ,   155 ,   367 ,   3519    ,   1557    ,   14897   ,   31331   ,0 };
            const std::uint32_t dim2042Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   15  ,   25  ,   105 ,   145 ,   157 ,   525 ,   1541    ,   3361    ,   1531    ,   7473    ,   28187   ,0 };
            const std::uint32_t dim2043Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   15  ,   7   ,   119 ,   135 ,   395 ,   441 ,   1443    ,   537 ,   5185    ,   793 ,   13205   ,0 };
            const std::uint32_t dim2044Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   15  ,   7   ,   101 ,   43  ,   437 ,   761 ,   1471    ,   3843    ,   6765    ,   4135    ,   7883    ,0 };
            const std::uint32_t dim2045Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   23  ,   31  ,   125 ,   119 ,   361 ,   65  ,   1907    ,   1335    ,   1309    ,   10591   ,   11167   ,0 };
            const std::uint32_t dim2046Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   21  ,   9   ,   29  ,   149 ,   371 ,   201 ,   1531    ,   2955    ,   1755    ,   14047   ,   5867    ,0 };
            const std::uint32_t dim2047Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   19  ,   9   ,   13  ,   13  ,   313 ,   621 ,   595 ,   2765    ,   2963    ,   13081   ,   21795   ,0 };
            const std::uint32_t dim2048Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   21  ,   61  ,   7   ,   113 ,   295 ,   995 ,   1649    ,   1715    ,   4737    ,   4769    ,   13945   ,0 };
            const std::uint32_t dim2049Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   17  ,   53  ,   73  ,   15  ,   83  ,   813 ,   1757    ,   471 ,   6031    ,   7871    ,   32569   ,0 };
            const std::uint32_t dim2050Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   29  ,   55  ,   45  ,   173 ,   231 ,   167 ,   415 ,   1487    ,   6403    ,   13823   ,   10121   ,0 };
            const std::uint32_t dim2051Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   19  ,   25  ,   107 ,   177 ,   97  ,   703 ,   1349    ,   2217    ,   3863    ,   11211   ,   28875   ,0 };
            const std::uint32_t dim2052Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   1   ,   9   ,   37  ,   127 ,   435 ,   917 ,   709 ,   2227    ,   7449    ,   13927   ,   1187    ,0 };
            const std::uint32_t dim2053Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   19  ,   17  ,   19  ,   127 ,   343 ,   235 ,   931 ,   589 ,   6439    ,   8839    ,   18027   ,0 };
            const std::uint32_t dim2054Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   25  ,   25  ,   71  ,   141 ,   343 ,   35  ,   15  ,   1439    ,   3163    ,   8063    ,   15337   ,0 };
            const std::uint32_t dim2055Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   27  ,   31  ,   91  ,   215 ,   67  ,   835 ,   673 ,   3355    ,   7633    ,   11711   ,   31479   ,0 };
            const std::uint32_t dim2056Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   5   ,   9   ,   35  ,   23  ,   415 ,   341 ,   1813    ,   3761    ,   5053    ,   9497    ,   10147   ,0 };
            const std::uint32_t dim2057Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   25  ,   59  ,   107 ,   57  ,   43  ,   955 ,   1049    ,   2613    ,   7003    ,   5749    ,   28211   ,0 };
            const std::uint32_t dim2058Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   5   ,   61  ,   25  ,   17  ,   41  ,   477 ,   131 ,   3331    ,   1193    ,   14291   ,   1467    ,0 };
            const std::uint32_t dim2059Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   5   ,   7   ,   37  ,   41  ,   215 ,   723 ,   1735    ,   3735    ,   3981    ,   13405   ,   5837    ,0 };
            const std::uint32_t dim2060Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   17  ,   9   ,   21  ,   51  ,   451 ,   691 ,   1853    ,   779 ,   635 ,   15461   ,   14789   ,0 };
            const std::uint32_t dim2061Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   9   ,   51  ,   21  ,   183 ,   33  ,   565 ,   529 ,   393 ,   6847    ,   10149   ,   23807   ,0 };
            const std::uint32_t dim2062Kuo3Init[]   =   {   1   ,   3   ,   1   ,   15  ,   9   ,   27  ,   1   ,   245 ,   459 ,   935 ,   1219    ,   2277    ,   6309    ,   13511   ,   31255   ,0 };
            const std::uint32_t dim2063Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   21  ,   63  ,   121 ,   95  ,   5   ,   545 ,   995 ,   1011    ,   2073    ,   6145    ,   4635    ,0 };
            const std::uint32_t dim2064Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   11  ,   1   ,   61  ,   53  ,   445 ,   33  ,   153 ,   2179    ,   2899    ,   7633    ,   20417   ,0 };
            const std::uint32_t dim2065Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   29  ,   47  ,   65  ,   55  ,   509 ,   175 ,   1875    ,   2669    ,   4583    ,   775 ,   27621   ,0 };
            const std::uint32_t dim2066Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   5   ,   21  ,   43  ,   37  ,   349 ,   89  ,   1581    ,   2105    ,   6753    ,   14577   ,   14339   ,0 };
            const std::uint32_t dim2067Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   21  ,   17  ,   55  ,   11  ,   87  ,   323 ,   647 ,   955 ,   1343    ,   10799   ,   15375   ,0 };
            const std::uint32_t dim2068Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   11  ,   43  ,   23  ,   25  ,   327 ,   797 ,   1111    ,   231 ,   4423    ,   5907    ,   16191   ,0 };
            const std::uint32_t dim2069Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   1   ,   15  ,   109 ,   43  ,   217 ,   905 ,   1295    ,   2373    ,   497 ,   11643   ,   14371   ,0 };
            const std::uint32_t dim2070Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   3   ,   43  ,   125 ,   249 ,   343 ,   947 ,   1523    ,   2393    ,   3073    ,   11301   ,   18751   ,0 };
            const std::uint32_t dim2071Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   31  ,   27  ,   23  ,   241 ,   103 ,   503 ,   1715    ,   877 ,   5269    ,   10665   ,   23927   ,0 };
            const std::uint32_t dim2072Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   21  ,   1   ,   91  ,   55  ,   297 ,   941 ,   1419    ,   3391    ,   811 ,   8399    ,   8513    ,0 };
            const std::uint32_t dim2073Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   7   ,   3   ,   17  ,   139 ,   461 ,   1007    ,   1835    ,   165 ,   1575    ,   15075   ,   18673   ,0 };
            const std::uint32_t dim2074Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   21  ,   63  ,   11  ,   123 ,   229 ,   767 ,   201 ,   3415    ,   4997    ,   14791   ,   27193   ,0 };
            const std::uint32_t dim2075Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   5   ,   13  ,   71  ,   163 ,   499 ,   933 ,   1829    ,   2321    ,   1773    ,   5255    ,   18219   ,0 };
            const std::uint32_t dim2076Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   15  ,   5   ,   47  ,   81  ,   167 ,   27  ,   773 ,   3607    ,   25  ,   12437   ,   11525   ,0 };
            const std::uint32_t dim2077Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   3   ,   21  ,   41  ,   1   ,   441 ,   1013    ,   1409    ,   3097    ,   5671    ,   3953    ,   51  ,0 };
            const std::uint32_t dim2078Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   15  ,   13  ,   93  ,   111 ,   355 ,   207 ,   1653    ,   2711    ,   81  ,   7801    ,   14105   ,0 };
            const std::uint32_t dim2079Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   15  ,   57  ,   47  ,   53  ,   79  ,   255 ,   517 ,   4015    ,   8123    ,   5557    ,   4245    ,0 };
            const std::uint32_t dim2080Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   25  ,   45  ,   97  ,   107 ,   107 ,   365 ,   1647    ,   3831    ,   5567    ,   167 ,   26977   ,0 };
            const std::uint32_t dim2081Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   31  ,   21  ,   79  ,   155 ,   391 ,   347 ,   1295    ,   255 ,   6439    ,   8201    ,   31975   ,0 };
            const std::uint32_t dim2082Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   19  ,   57  ,   9   ,   167 ,   359 ,   833 ,   709 ,   3437    ,   5031    ,   16221   ,   18491   ,0 };
            const std::uint32_t dim2083Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   17  ,   37  ,   39  ,   167 ,   271 ,   801 ,   601 ,   461 ,   3949    ,   5237    ,   3425    ,0 };
            const std::uint32_t dim2084Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   29  ,   47  ,   51  ,   161 ,   427 ,   421 ,   671 ,   2545    ,   4793    ,   10083   ,   3499    ,0 };
            const std::uint32_t dim2085Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   27  ,   25  ,   59  ,   75  ,   431 ,   891 ,   1557    ,   3615    ,   4759    ,   11267   ,   8473    ,0 };
            const std::uint32_t dim2086Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   7   ,   31  ,   63  ,   89  ,   353 ,   761 ,   1333    ,   1367    ,   5963    ,   12311   ,   20717   ,0 };
            const std::uint32_t dim2087Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   27  ,   19  ,   93  ,   209 ,   291 ,   119 ,   513 ,   3757    ,   3477    ,   2541    ,   4919    ,0 };
            const std::uint32_t dim2088Kuo3Init[]   =   {   1   ,   3   ,   7   ,   1   ,   15  ,   9   ,   109 ,   41  ,   401 ,   365 ,   907 ,   3603    ,   6401    ,   12115   ,   28691   ,0 };
            const std::uint32_t dim2089Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   3   ,   21  ,   121 ,   27  ,   355 ,   571 ,   133 ,   1073    ,   4875    ,   13351   ,   13197   ,0 };
            const std::uint32_t dim2090Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   1   ,   31  ,   35  ,   171 ,   201 ,   617 ,   1181    ,   3621    ,   823 ,   8599    ,   4407    ,0 };
            const std::uint32_t dim2091Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   31  ,   61  ,   45  ,   19  ,   191 ,   843 ,   909 ,   391 ,   5899    ,   14059   ,   7879    ,0 };
            const std::uint32_t dim2092Kuo3Init[]   =   {   1   ,   1   ,   7   ,   9   ,   19  ,   51  ,   123 ,   201 ,   163 ,   737 ,   153 ,   161 ,   7949    ,   2865    ,   17357   ,0 };
            const std::uint32_t dim2093Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   23  ,   51  ,   121 ,   165 ,   459 ,   959 ,   647 ,   535 ,   7903    ,   2935    ,   24895   ,0 };
            const std::uint32_t dim2094Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   1   ,   63  ,   73  ,   179 ,   485 ,   661 ,   255 ,   1423    ,   7277    ,   2109    ,   25113   ,0 };
            const std::uint32_t dim2095Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   27  ,   51  ,   79  ,   151 ,   389 ,   251 ,   277 ,   1785    ,   4073    ,   1729    ,   22705   ,0 };
            const std::uint32_t dim2096Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   23  ,   15  ,   105 ,   205 ,   413 ,   253 ,   1181    ,   2605    ,   6181    ,   1771    ,   17869   ,0 };
            const std::uint32_t dim2097Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   29  ,   45  ,   95  ,   37  ,   319 ,   609 ,   369 ,   3311    ,   5717    ,   7219    ,   25157   ,0 };
            const std::uint32_t dim2098Kuo3Init[]   =   {   1   ,   1   ,   7   ,   15  ,   23  ,   3   ,   61  ,   125 ,   429 ,   29  ,   479 ,   1151    ,   4479    ,   8909    ,   9763    ,0 };
            const std::uint32_t dim2099Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   25  ,   21  ,   11  ,   147 ,   61  ,   903 ,   1719    ,   3065    ,   7089    ,   15041   ,   6387    ,0 };
            const std::uint32_t dim2100Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   17  ,   33  ,   43  ,   1   ,   271 ,   223 ,   363 ,   2799    ,   1043    ,   3929    ,   25991   ,0 };
            const std::uint32_t dim2101Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   3   ,   15  ,   115 ,   245 ,   383 ,   881 ,   221 ,   2045    ,   621 ,   14543   ,   1027    ,0 };
            const std::uint32_t dim2102Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   1   ,   45  ,   19  ,   133 ,   339 ,   883 ,   1643    ,   853 ,   7141    ,   6259    ,   6373    ,0 };
            const std::uint32_t dim2103Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   27  ,   23  ,   123 ,   159 ,   185 ,   693 ,   577 ,   473 ,   313 ,   13579   ,   19317   ,0 };
            const std::uint32_t dim2104Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   27  ,   19  ,   43  ,   23  ,   183 ,   925 ,   1987    ,   1945    ,   6341    ,   10771   ,   9669    ,0 };
            const std::uint32_t dim2105Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   15  ,   27  ,   49  ,   117 ,   347 ,   149 ,   23  ,   103 ,   3613    ,   3123    ,   32759   ,0 };
            const std::uint32_t dim2106Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   1   ,   37  ,   13  ,   111 ,   407 ,   319 ,   563 ,   1499    ,   6551    ,   13333   ,   659 ,0 };
            const std::uint32_t dim2107Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   23  ,   21  ,   9   ,   109 ,   393 ,   115 ,   415 ,   351 ,   6113    ,   2417    ,   14151   ,0 };
            const std::uint32_t dim2108Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   25  ,   7   ,   35  ,   41  ,   43  ,   663 ,   1809    ,   535 ,   7437    ,   12487   ,   1059    ,0 };
            const std::uint32_t dim2109Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   13  ,   13  ,   123 ,   111 ,   391 ,   199 ,   69  ,   2357    ,   4779    ,   7461    ,   5003    ,0 };
            const std::uint32_t dim2110Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   17  ,   63  ,   5   ,   163 ,   107 ,   609 ,   1979    ,   3389    ,   499 ,   13111   ,   219 ,0 };
            const std::uint32_t dim2111Kuo3Init[]   =   {   1   ,   3   ,   7   ,   1   ,   19  ,   41  ,   43  ,   29  ,   35  ,   371 ,   1773    ,   3563    ,   2005    ,   8217    ,   5131    ,0 };
            const std::uint32_t dim2112Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   13  ,   53  ,   43  ,   167 ,   201 ,   259 ,   1855    ,   3971    ,   1179    ,   8591    ,   21425   ,0 };
            const std::uint32_t dim2113Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   27  ,   21  ,   45  ,   47  ,   185 ,   753 ,   531 ,   2553    ,   5515    ,   11501   ,   4623    ,0 };
            const std::uint32_t dim2114Kuo3Init[]   =   {   1   ,   1   ,   7   ,   9   ,   9   ,   49  ,   29  ,   207 ,   441 ,   265 ,   1059    ,   1703    ,   1625    ,   9371    ,   23045   ,0 };
            const std::uint32_t dim2115Kuo3Init[]   =   {   1   ,   3   ,   5   ,   9   ,   13  ,   29  ,   33  ,   185 ,   233 ,   11  ,   381 ,   3917    ,   4931    ,   3497    ,   24713   ,0 };
            const std::uint32_t dim2116Kuo3Init[]   =   {   1   ,   3   ,   1   ,   11  ,   13  ,   61  ,   43  ,   147 ,   505 ,   251 ,   1875    ,   3009    ,   4695    ,   6793    ,   3083    ,0 };
            const std::uint32_t dim2117Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   31  ,   17  ,   119 ,   35  ,   111 ,   767 ,   211 ,   3227    ,   2539    ,   10755   ,   26177   ,0 };
            const std::uint32_t dim2118Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   9   ,   63  ,   3   ,   45  ,   195 ,   515 ,   103 ,   2327    ,   5967    ,   8087    ,   9849    ,0 };
            const std::uint32_t dim2119Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   31  ,   51  ,   55  ,   231 ,   451 ,   259 ,   1025    ,   2671    ,   5317    ,   7087    ,   7365    ,0 };
            const std::uint32_t dim2120Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   5   ,   41  ,   33  ,   255 ,   305 ,   831 ,   1279    ,   4013    ,   3899    ,   171 ,   8543    ,0 };
            const std::uint32_t dim2121Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   7   ,   9   ,   97  ,   125 ,   123 ,   3   ,   121 ,   4041    ,   3941    ,   1655    ,   25583   ,0 };
            const std::uint32_t dim2122Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   9   ,   63  ,   99  ,   53  ,   85  ,   57  ,   1117    ,   969 ,   7067    ,   1393    ,   17497   ,0 };
            const std::uint32_t dim2123Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   9   ,   51  ,   1   ,   207 ,   443 ,   967 ,   1387    ,   2515    ,   1789    ,   1493    ,   20941   ,0 };
            const std::uint32_t dim2124Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   15  ,   37  ,   11  ,   191 ,   503 ,   823 ,   1789    ,   4071    ,   3355    ,   9177    ,   27281   ,0 };
            const std::uint32_t dim2125Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   3   ,   61  ,   83  ,   19  ,   325 ,   543 ,   19  ,   239 ,   3513    ,   16147   ,   32395   ,0 };
            const std::uint32_t dim2126Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   1   ,   17  ,   101 ,   23  ,   379 ,   649 ,   853 ,   3045    ,   1301    ,   7215    ,   18851   ,0 };
            const std::uint32_t dim2127Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   25  ,   11  ,   41  ,   213 ,   137 ,   705 ,   1829    ,   1055    ,   3061    ,   9335    ,   5797    ,0 };
            const std::uint32_t dim2128Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   11  ,   21  ,   17  ,   117 ,   473 ,   687 ,   125 ,   4007    ,   5283    ,   11961   ,   15365   ,0 };
            const std::uint32_t dim2129Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   11  ,   19  ,   3   ,   189 ,   393 ,   219 ,   1229    ,   1521    ,   7137    ,   1811    ,   6745    ,0 };
            const std::uint32_t dim2130Kuo3Init[]   =   {   1   ,   1   ,   7   ,   9   ,   21  ,   59  ,   23  ,   193 ,   321 ,   691 ,   735 ,   3731    ,   593 ,   9351    ,   6571    ,0 };
            const std::uint32_t dim2131Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   23  ,   55  ,   43  ,   107 ,   217 ,   111 ,   921 ,   1017    ,   7055    ,   16059   ,   8181    ,0 };
            const std::uint32_t dim2132Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   29  ,   57  ,   93  ,   91  ,   9   ,   453 ,   1245    ,   691 ,   1571    ,   5755    ,   13387   ,0 };
            const std::uint32_t dim2133Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   1   ,   23  ,   87  ,   239 ,   373 ,   433 ,   553 ,   2205    ,   4495    ,   3975    ,   25819   ,0 };
            const std::uint32_t dim2134Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   23  ,   7   ,   9   ,   227 ,   503 ,   87  ,   819 ,   3167    ,   4135    ,   9281    ,   8443    ,0 };
            const std::uint32_t dim2135Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   7   ,   27  ,   17  ,   81  ,   295 ,   131 ,   955 ,   4065    ,   797 ,   16165   ,   2385    ,0 };
            const std::uint32_t dim2136Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   9   ,   47  ,   113 ,   105 ,   277 ,   187 ,   1983    ,   2833    ,   2749    ,   4473    ,   31275   ,0 };
            const std::uint32_t dim2137Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   19  ,   61  ,   41  ,   51  ,   435 ,   933 ,   961 ,   459 ,   4187    ,   6619    ,   777 ,0 };
            const std::uint32_t dim2138Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   11  ,   25  ,   51  ,   219 ,   203 ,   897 ,   777 ,   3047    ,   2601    ,   4387    ,   14185   ,0 };
            const std::uint32_t dim2139Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   23  ,   17  ,   103 ,   55  ,   387 ,   127 ,   197 ,   1045    ,   3973    ,   10503   ,   23443   ,0 };
            const std::uint32_t dim2140Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   13  ,   59  ,   87  ,   253 ,   7   ,   879 ,   1335    ,   1349    ,   6353    ,   5897    ,   10021   ,0 };
            const std::uint32_t dim2141Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   19  ,   49  ,   107 ,   65  ,   229 ,   317 ,   169 ,   509 ,   1819    ,   2267    ,   13269   ,0 };
            const std::uint32_t dim2142Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   21  ,   25  ,   11  ,   143 ,   511 ,   107 ,   637 ,   3237    ,   3985    ,   15197   ,   23343   ,0 };
            const std::uint32_t dim2143Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   1   ,   15  ,   67  ,   91  ,   131 ,   501 ,   1803    ,   699 ,   2031    ,   11015   ,   17989   ,0 };
            const std::uint32_t dim2144Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   3   ,   55  ,   103 ,   245 ,   229 ,   121 ,   245 ,   1299    ,   3357    ,   3283    ,   26181   ,0 };
            const std::uint32_t dim2145Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   19  ,   53  ,   101 ,   125 ,   35  ,   963 ,   887 ,   3119    ,   1407    ,   723 ,   29169   ,0 };
            const std::uint32_t dim2146Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   27  ,   39  ,   29  ,   71  ,   7   ,   529 ,   329 ,   2811    ,   4627    ,   2865    ,   26837   ,0 };
            const std::uint32_t dim2147Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   29  ,   55  ,   71  ,   129 ,   455 ,   465 ,   1949    ,   3895    ,   6971    ,   15621   ,   26819   ,0 };
            const std::uint32_t dim2148Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   5   ,   63  ,   95  ,   15  ,   425 ,   347 ,   835 ,   1973    ,   5171    ,   3963    ,   23691   ,0 };
            const std::uint32_t dim2149Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   27  ,   23  ,   87  ,   237 ,   261 ,   349 ,   1777    ,   287 ,   3543    ,   35  ,   31891   ,0 };
            const std::uint32_t dim2150Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   17  ,   59  ,   7   ,   65  ,   45  ,   733 ,   239 ,   221 ,   6419    ,   9161    ,   17499   ,0 };
            const std::uint32_t dim2151Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   7   ,   53  ,   121 ,   97  ,   127 ,   583 ,   501 ,   1667    ,   6265    ,   3233    ,   19187   ,0 };
            const std::uint32_t dim2152Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   29  ,   17  ,   121 ,   89  ,   107 ,   787 ,   1699    ,   3389    ,   6191    ,   11503   ,   2461    ,0 };
            const std::uint32_t dim2153Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   13  ,   27  ,   97  ,   49  ,   447 ,   851 ,   147 ,   439 ,   277 ,   11129   ,   2201    ,0 };
            const std::uint32_t dim2154Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   29  ,   47  ,   93  ,   243 ,   101 ,   627 ,   1607    ,   459 ,   27  ,   10635   ,   1345    ,0 };
            const std::uint32_t dim2155Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   19  ,   11  ,   61  ,   253 ,   345 ,   523 ,   317 ,   1599    ,   5625    ,   14385   ,   3461    ,0 };
            const std::uint32_t dim2156Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   27  ,   59  ,   33  ,   251 ,   29  ,   787 ,   1655    ,   3383    ,   2451    ,   2499    ,   10719   ,0 };
            const std::uint32_t dim2157Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   1   ,   29  ,   97  ,   233 ,   193 ,   459 ,   1667    ,   47  ,   3059    ,   8713    ,   13259   ,0 };
            const std::uint32_t dim2158Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   29  ,   63  ,   127 ,   35  ,   105 ,   95  ,   887 ,   2337    ,   5999    ,   13553   ,   30225   ,0 };
            const std::uint32_t dim2159Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   17  ,   43  ,   47  ,   205 ,   497 ,   835 ,   1565    ,   3863    ,   785 ,   6149    ,   17595   ,0 };
            const std::uint32_t dim2160Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   29  ,   17  ,   47  ,   37  ,   339 ,   131 ,   1219    ,   3545    ,   3499    ,   2223    ,   3107    ,0 };
            const std::uint32_t dim2161Kuo3Init[]   =   {   1   ,   1   ,   1   ,   15  ,   7   ,   17  ,   39  ,   25  ,   97  ,   691 ,   1645    ,   3333    ,   95  ,   15593   ,   11667   ,0 };
            const std::uint32_t dim2162Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   13  ,   21  ,   61  ,   147 ,   115 ,   249 ,   981 ,   665 ,   1245    ,   14397   ,   9571    ,0 };
            const std::uint32_t dim2163Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   15  ,   5   ,   7   ,   129 ,   151 ,   947 ,   375 ,   1631    ,   3247    ,   1321    ,   19495   ,0 };
            const std::uint32_t dim2164Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   5   ,   5   ,   69  ,   247 ,   53  ,   37  ,   683 ,   1581    ,   2997    ,   5897    ,   4797    ,0 };
            const std::uint32_t dim2165Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   5   ,   45  ,   115 ,   65  ,   509 ,   557 ,   1749    ,   2167    ,   4795    ,   629 ,   10749   ,0 };
            const std::uint32_t dim2166Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   25  ,   23  ,   99  ,   93  ,   99  ,   721 ,   1235    ,   1259    ,   2739    ,   11797   ,   15985   ,0 };
            const std::uint32_t dim2167Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   15  ,   29  ,   97  ,   103 ,   21  ,   981 ,   1717    ,   1483    ,   711 ,   12419   ,   14401   ,0 };
            const std::uint32_t dim2168Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   5   ,   5   ,   125 ,   159 ,   301 ,   733 ,   1987    ,   1679    ,   7459    ,   3493    ,   29377   ,0 };
            const std::uint32_t dim2169Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   29  ,   45  ,   53  ,   197 ,   303 ,   303 ,   931 ,   1171    ,   1771    ,   14895   ,   21525   ,0 };
            const std::uint32_t dim2170Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   11  ,   59  ,   93  ,   113 ,   219 ,   557 ,   397 ,   2639    ,   5089    ,   6833    ,   20455   ,0 };
            const std::uint32_t dim2171Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   11  ,   33  ,   117 ,   163 ,   359 ,   431 ,   915 ,   3285    ,   2443    ,   8225    ,   16341   ,0 };
            const std::uint32_t dim2172Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   19  ,   1   ,   105 ,   65  ,   3   ,   71  ,   705 ,   2047    ,   2169    ,   13129   ,   8575    ,0 };
            const std::uint32_t dim2173Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   23  ,   63  ,   67  ,   203 ,   429 ,   897 ,   1453    ,   101 ,   1445    ,   8553    ,   16355   ,0 };
            const std::uint32_t dim2174Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   13  ,   61  ,   79  ,   217 ,   83  ,   339 ,   529 ,   3573    ,   4075    ,   5929    ,   2687    ,0 };
            const std::uint32_t dim2175Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   27  ,   9   ,   93  ,   105 ,   179 ,   479 ,   1093    ,   3551    ,   5697    ,   8989    ,   1099    ,0 };
            const std::uint32_t dim2176Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   15  ,   9   ,   21  ,   59  ,   193 ,   231 ,   1817    ,   463 ,   1945    ,   13795   ,   28655   ,0 };
            const std::uint32_t dim2177Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   3   ,   27  ,   49  ,   179 ,   205 ,   49  ,   355 ,   667 ,   6573    ,   4317    ,   26599   ,0 };
            const std::uint32_t dim2178Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   9   ,   45  ,   121 ,   219 ,   309 ,   371 ,   1119    ,   1991    ,   5889    ,   14257   ,   1105    ,0 };
            const std::uint32_t dim2179Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   7   ,   19  ,   111 ,   191 ,   321 ,   77  ,   39  ,   1921    ,   563 ,   1049    ,   26623   ,0 };
            const std::uint32_t dim2180Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   13  ,   43  ,   21  ,   121 ,   181 ,   185 ,   629 ,   211 ,   7897    ,   9445    ,   12679   ,0 };
            const std::uint32_t dim2181Kuo3Init[]   =   {   1   ,   1   ,   7   ,   15  ,   3   ,   19  ,   61  ,   159 ,   337 ,   711 ,   155 ,   2099    ,   2201    ,   14337   ,   21633   ,0 };
            const std::uint32_t dim2182Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   27  ,   63  ,   43  ,   209 ,   17  ,   565 ,   225 ,   2381    ,   4577    ,   15793   ,   4861    ,0 };
            const std::uint32_t dim2183Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   25  ,   51  ,   65  ,   187 ,   235 ,   479 ,   293 ,   789 ,   2453    ,   4367    ,   15835   ,0 };
            const std::uint32_t dim2184Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   17  ,   7   ,   115 ,   165 ,   3   ,   457 ,   455 ,   969 ,   5859    ,   2663    ,   15337   ,0 };
            const std::uint32_t dim2185Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   19  ,   1   ,   55  ,   177 ,   365 ,   395 ,   1043    ,   1095    ,   6531    ,   8599    ,   12867   ,0 };
            const std::uint32_t dim2186Kuo3Init[]   =   {   1   ,   3   ,   7   ,   1   ,   29  ,   57  ,   55  ,   139 ,   187 ,   649 ,   1899    ,   355 ,   6447    ,   4521    ,   31497   ,0 };
            const std::uint32_t dim2187Kuo3Init[]   =   {   1   ,   3   ,   5   ,   1   ,   19  ,   55  ,   73  ,   163 ,   127 ,   893 ,   1189    ,   2425    ,   5145    ,   15965   ,   5937    ,0 };
            const std::uint32_t dim2188Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   21  ,   33  ,   91  ,   81  ,   75  ,   39  ,   1   ,   397 ,   2799    ,   11987   ,   27829   ,0 };
            const std::uint32_t dim2189Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   25  ,   15  ,   95  ,   61  ,   351 ,   377 ,   1949    ,   3141    ,   6259    ,   135 ,   19307   ,0 };
            const std::uint32_t dim2190Kuo3Init[]   =   {   1   ,   3   ,   3   ,   7   ,   7   ,   45  ,   1   ,   197 ,   235 ,   747 ,   1333    ,   3293    ,   1439    ,   7447    ,   26119   ,0 };
            const std::uint32_t dim2191Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   25  ,   31  ,   113 ,   159 ,   335 ,   587 ,   733 ,   1045    ,   5015    ,   9677    ,   21777   ,0 };
            const std::uint32_t dim2192Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   15  ,   55  ,   91  ,   181 ,   465 ,   409 ,   995 ,   3243    ,   6165    ,   1547    ,   31785   ,0 };
            const std::uint32_t dim2193Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   7   ,   47  ,   27  ,   87  ,   399 ,   265 ,   945 ,   1675    ,   5383    ,   4847    ,   27859   ,0 };
            const std::uint32_t dim2194Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   21  ,   53  ,   69  ,   107 ,   121 ,   855 ,   629 ,   1947    ,   8149    ,   10707   ,   2981    ,0 };
            const std::uint32_t dim2195Kuo3Init[]   =   {   1   ,   3   ,   1   ,   11  ,   3   ,   25  ,   53  ,   87  ,   349 ,   237 ,   1745    ,   3705    ,   4273    ,   4109    ,   26059   ,0 };
            const std::uint32_t dim2196Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   25  ,   19  ,   11  ,   179 ,   301 ,   27  ,   1343    ,   79  ,   2475    ,   5581    ,   27225   ,0 };
            const std::uint32_t dim2197Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   29  ,   55  ,   119 ,   107 ,   431 ,   943 ,   1567    ,   3727    ,   7415    ,   2565    ,   24957   ,0 };
            const std::uint32_t dim2198Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   15  ,   27  ,   91  ,   159 ,   285 ,   781 ,   357 ,   643 ,   7445    ,   9931    ,   11881   ,0 };
            const std::uint32_t dim2199Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   5   ,   53  ,   65  ,   195 ,   273 ,   37  ,   1785    ,   467 ,   5211    ,   25  ,   1749    ,0 };
            const std::uint32_t dim2200Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   7   ,   11  ,   43  ,   143 ,   305 ,   825 ,   1055    ,   2995    ,   3907    ,   7581    ,   9679    ,0 };
            const std::uint32_t dim2201Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   31  ,   29  ,   93  ,   3   ,   299 ,   1   ,   1851    ,   395 ,   239 ,   8323    ,   18201   ,0 };
            const std::uint32_t dim2202Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   29  ,   29  ,   75  ,   3   ,   273 ,   759 ,   801 ,   2841    ,   5789    ,   6651    ,   19351   ,0 };
            const std::uint32_t dim2203Kuo3Init[]   =   {   1   ,   3   ,   7   ,   1   ,   1   ,   11  ,   11  ,   215 ,   27  ,   955 ,   1397    ,   3483    ,   1317    ,   223 ,   20559   ,0 };
            const std::uint32_t dim2204Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   21  ,   23  ,   39  ,   189 ,   295 ,   255 ,   1457    ,   2821    ,   3145    ,   15437   ,   26997   ,0 };
            const std::uint32_t dim2205Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   9   ,   43  ,   13  ,   97  ,   259 ,   23  ,   933 ,   3867    ,   5921    ,   4199    ,   24721   ,0 };
            const std::uint32_t dim2206Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   1   ,   19  ,   89  ,   87  ,   17  ,   247 ,   1535    ,   2629    ,   2893    ,   12209   ,   23739   ,0 };
            const std::uint32_t dim2207Kuo3Init[]   =   {   1   ,   1   ,   1   ,   1   ,   31  ,   15  ,   81  ,   37  ,   235 ,   249 ,   1437    ,   1485    ,   5889    ,   10017   ,   18593   ,0 };
            const std::uint32_t dim2208Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   17  ,   33  ,   117 ,   5   ,   31  ,   63  ,   2015    ,   3063    ,   5139    ,   14771   ,   29107   ,0 };
            const std::uint32_t dim2209Kuo3Init[]   =   {   1   ,   1   ,   7   ,   15  ,   13  ,   3   ,   25  ,   127 ,   419 ,   945 ,   1739    ,   175 ,   1591    ,   4443    ,   27289   ,0 };
            const std::uint32_t dim2210Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   11  ,   59  ,   99  ,   119 ,   307 ,   857 ,   1711    ,   1201    ,   1623    ,   11429   ,   5663    ,0 };
            const std::uint32_t dim2211Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   17  ,   45  ,   65  ,   225 ,   131 ,   279 ,   587 ,   3487    ,   1123    ,   2753    ,   30789   ,0 };
            const std::uint32_t dim2212Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   21  ,   55  ,   17  ,   141 ,   109 ,   1021    ,   1387    ,   1407    ,   8163    ,   1983    ,   25971   ,0 };
            const std::uint32_t dim2213Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   21  ,   51  ,   103 ,   243 ,   435 ,   481 ,   857 ,   3353    ,   2717    ,   2295    ,   7999    ,0 };
            const std::uint32_t dim2214Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   7   ,   27  ,   83  ,   45  ,   359 ,   191 ,   259 ,   3229    ,   7869    ,   10729   ,   28587   ,0 };
            const std::uint32_t dim2215Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   19  ,   25  ,   51  ,   103 ,   37  ,   429 ,   995 ,   415 ,   2879    ,   2283    ,   29981   ,0 };
            const std::uint32_t dim2216Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   21  ,   19  ,   29  ,   35  ,   401 ,   19  ,   1761    ,   3735    ,   7775    ,   3365    ,   31767   ,0 };
            const std::uint32_t dim2217Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   29  ,   1   ,   9   ,   195 ,   279 ,   1003    ,   999 ,   4043    ,   3761    ,   11341   ,   7117    ,0 };
            const std::uint32_t dim2218Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   19  ,   7   ,   97  ,   181 ,   37  ,   929 ,   667 ,   993 ,   2517    ,   12683   ,   24487   ,0 };
            const std::uint32_t dim2219Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   31  ,   15  ,   47  ,   143 ,   511 ,   525 ,   1799    ,   1743    ,   3237    ,   12839   ,   2287    ,0 };
            const std::uint32_t dim2220Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   31  ,   59  ,   59  ,   205 ,   99  ,   233 ,   1857    ,   2469    ,   2661    ,   3675    ,   391 ,0 };
            const std::uint32_t dim2221Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   31  ,   23  ,   23  ,   1   ,   313 ,   401 ,   605 ,   3771    ,   2703    ,   6037    ,   7943    ,0 };
            const std::uint32_t dim2222Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   21  ,   19  ,   55  ,   139 ,   273 ,   725 ,   1239    ,   595 ,   549 ,   15279   ,   20887   ,0 };
            const std::uint32_t dim2223Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   13  ,   9   ,   39  ,   83  ,   257 ,   323 ,   1801    ,   167 ,   3747    ,   2867    ,   30151   ,0 };
            const std::uint32_t dim2224Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   17  ,   3   ,   67  ,   163 ,   325 ,   569 ,   1099    ,   4037    ,   5003    ,   6985    ,   7445    ,0 };
            const std::uint32_t dim2225Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   31  ,   37  ,   13  ,   91  ,   21  ,   763 ,   785 ,   1461    ,   5257    ,   15307   ,   16389   ,0 };
            const std::uint32_t dim2226Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   1   ,   35  ,   27  ,   179 ,   429 ,   21  ,   865 ,   775 ,   4993    ,   335 ,   12479   ,0 };
            const std::uint32_t dim2227Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   19  ,   1   ,   111 ,   201 ,   219 ,   709 ,   1539    ,   1905    ,   647 ,   8605    ,   14129   ,0 };
            const std::uint32_t dim2228Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   21  ,   7   ,   117 ,   251 ,   311 ,   689 ,   1125    ,   1931    ,   6363    ,   7409    ,   4189    ,0 };
            const std::uint32_t dim2229Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   1   ,   27  ,   93  ,   5   ,   395 ,   117 ,   113 ,   1297    ,   501 ,   13073   ,   30483   ,0 };
            const std::uint32_t dim2230Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   19  ,   57  ,   65  ,   67  ,   13  ,   893 ,   551 ,   539 ,   2861    ,   10635   ,   16057   ,0 };
            const std::uint32_t dim2231Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   19  ,   5   ,   41  ,   43  ,   161 ,   1015    ,   33  ,   471 ,   229 ,   13315   ,   10791   ,0 };
            const std::uint32_t dim2232Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   1   ,   13  ,   97  ,   149 ,   321 ,   131 ,   1389    ,   715 ,   5421    ,   343 ,   4129    ,0 };
            const std::uint32_t dim2233Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   15  ,   51  ,   91  ,   57  ,   229 ,   1007    ,   709 ,   2745    ,   147 ,   10427   ,   21151   ,0 };
            const std::uint32_t dim2234Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   1   ,   31  ,   65  ,   251 ,   75  ,   553 ,   133 ,   1027    ,   4857    ,   7139    ,   10591   ,0 };
            const std::uint32_t dim2235Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   13  ,   11  ,   49  ,   183 ,   263 ,   121 ,   981 ,   1421    ,   7781    ,   5313    ,   3245    ,0 };
            const std::uint32_t dim2236Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   31  ,   27  ,   109 ,   85  ,   327 ,   999 ,   1063    ,   705 ,   6047    ,   13227   ,   5817    ,0 };
            const std::uint32_t dim2237Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   9   ,   5   ,   99  ,   69  ,   91  ,   637 ,   1353    ,   2471    ,   7003    ,   9429    ,   25235   ,0 };
            const std::uint32_t dim2238Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   1   ,   25  ,   77  ,   67  ,   173 ,   929 ,   1919    ,   4021    ,   5587    ,   3333    ,   12769   ,0 };
            const std::uint32_t dim2239Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   15  ,   9   ,   11  ,   71  ,   465 ,   831 ,   1127    ,   3439    ,   6793    ,   1269    ,   1699    ,0 };
            const std::uint32_t dim2240Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   17  ,   43  ,   45  ,   181 ,   147 ,   501 ,   283 ,   3875    ,   7221    ,   14487   ,   2549    ,0 };
            const std::uint32_t dim2241Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   1   ,   21  ,   125 ,   179 ,   479 ,   367 ,   1961    ,   607 ,   255 ,   913 ,   16143   ,0 };
            const std::uint32_t dim2242Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   7   ,   49  ,   117 ,   97  ,   45  ,   729 ,   1331    ,   1373    ,   2147    ,   11673   ,   9779    ,0 };
            const std::uint32_t dim2243Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   1   ,   11  ,   105 ,   231 ,   237 ,   449 ,   1195    ,   33  ,   4531    ,   11591   ,   29539   ,0 };
            const std::uint32_t dim2244Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   27  ,   47  ,   105 ,   85  ,   25  ,   663 ,   47  ,   3213    ,   6777    ,   11947   ,   28993   ,0 };
            const std::uint32_t dim2245Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   11  ,   57  ,   121 ,   107 ,   327 ,   631 ,   285 ,   921 ,   3721    ,   7983    ,   9199    ,0 };
            const std::uint32_t dim2246Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   3   ,   61  ,   49  ,   101 ,   415 ,   187 ,   1645    ,   2139    ,   143 ,   12033   ,   11409   ,0 };
            const std::uint32_t dim2247Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   7   ,   15  ,   27  ,   143 ,   17  ,   977 ,   495 ,   2479    ,   1507    ,   10621   ,   2119    ,0 };
            const std::uint32_t dim2248Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   11  ,   9   ,   53  ,   159 ,   479 ,   333 ,   1423    ,   2559    ,   5497    ,   12611   ,   22627   ,0 };
            const std::uint32_t dim2249Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   7   ,   55  ,   3   ,   137 ,   421 ,   661 ,   113 ,   925 ,   1649    ,   12405   ,   30035   ,0 };
            const std::uint32_t dim2250Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   9   ,   31  ,   25  ,   233 ,   241 ,   239 ,   505 ,   2685    ,   223 ,   4389    ,   28191   ,0 };
            const std::uint32_t dim2251Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   23  ,   59  ,   5   ,   181 ,   491 ,   111 ,   1289    ,   3717    ,   4429    ,   15091   ,   25375   ,0 };
            const std::uint32_t dim2252Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   25  ,   3   ,   3   ,   7   ,   163 ,   247 ,   1673    ,   3061    ,   2355    ,   12779   ,   20039   ,0 };
            const std::uint32_t dim2253Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   3   ,   35  ,   5   ,   107 ,   387 ,   99  ,   1841    ,   3607    ,   2027    ,   6353    ,   15929   ,0 };
            const std::uint32_t dim2254Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   29  ,   45  ,   43  ,   207 ,   383 ,   681 ,   769 ,   3939    ,   8161    ,   10235   ,   24209   ,0 };
            const std::uint32_t dim2255Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   5   ,   13  ,   73  ,   99  ,   233 ,   327 ,   1429    ,   487 ,   3925    ,   5169    ,   5477    ,0 };
            const std::uint32_t dim2256Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   21  ,   63  ,   39  ,   17  ,   227 ,   455 ,   1559    ,   113 ,   3993    ,   7935    ,   8995    ,0 };
            const std::uint32_t dim2257Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   17  ,   51  ,   43  ,   231 ,   69  ,   475 ,   761 ,   4011    ,   4007    ,   14829   ,   29961   ,0 };
            const std::uint32_t dim2258Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   19  ,   37  ,   49  ,   197 ,   277 ,   391 ,   583 ,   2711    ,   4041    ,   6029    ,   29559   ,0 };
            const std::uint32_t dim2259Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   7   ,   53  ,   33  ,   33  ,   325 ,   171 ,   63  ,   2929    ,   641 ,   7143    ,   12585   ,0 };
            const std::uint32_t dim2260Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   1   ,   31  ,   23  ,   157 ,   437 ,   355 ,   595 ,   239 ,   1275    ,   4917    ,   31055   ,0 };
            const std::uint32_t dim2261Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   15  ,   43  ,   39  ,   51  ,   431 ,   131 ,   741 ,   3473    ,   1947    ,   4223    ,   27943   ,0 };
            const std::uint32_t dim2262Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   27  ,   49  ,   5   ,   197 ,   33  ,   611 ,   1131    ,   429 ,   4931    ,   1243    ,   5787    ,0 };
            const std::uint32_t dim2263Kuo3Init[]   =   {   1   ,   1   ,   7   ,   9   ,   29  ,   19  ,   89  ,   139 ,   239 ,   421 ,   951 ,   3749    ,   1557    ,   3803    ,   7155    ,0 };
            const std::uint32_t dim2264Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   15  ,   53  ,   121 ,   123 ,   99  ,   677 ,   1519    ,   3051    ,   5235    ,   8061    ,   21353   ,0 };
            const std::uint32_t dim2265Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   21  ,   53  ,   65  ,   35  ,   389 ,   141 ,   253 ,   2867    ,   803 ,   11525   ,   9901    ,0 };
            const std::uint32_t dim2266Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   21  ,   37  ,   81  ,   53  ,   121 ,   15  ,   1741    ,   2225    ,   183 ,   7155    ,   7597    ,0 };
            const std::uint32_t dim2267Kuo3Init[]   =   {   1   ,   1   ,   7   ,   15  ,   29  ,   29  ,   13  ,   197 ,   291 ,   765 ,   1479    ,   2211    ,   5949    ,   5045    ,   32519   ,0 };
            const std::uint32_t dim2268Kuo3Init[]   =   {   1   ,   3   ,   3   ,   5   ,   5   ,   19  ,   121 ,   219 ,   121 ,   17  ,   1223    ,   2685    ,   8179    ,   391 ,   31257   ,0 };
            const std::uint32_t dim2269Kuo3Init[]   =   {   1   ,   1   ,   5   ,   7   ,   13  ,   27  ,   29  ,   71  ,   7   ,   95  ,   255 ,   9   ,   2375    ,   3325    ,   29915   ,0 };
            const std::uint32_t dim2270Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   1   ,   3   ,   11  ,   43  ,   233 ,   663 ,   715 ,   585 ,   3701    ,   13559   ,   3197    ,0 };
            const std::uint32_t dim2271Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   17  ,   45  ,   103 ,   209 ,   61  ,   923 ,   517 ,   249 ,   5775    ,   14537   ,   15371   ,0 };
            const std::uint32_t dim2272Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   7   ,   5   ,   123 ,   99  ,   137 ,   277 ,   1071    ,   3371    ,   7095    ,   2765    ,   28945   ,0 };
            const std::uint32_t dim2273Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   1   ,   59  ,   85  ,   5   ,   475 ,   855 ,   1793    ,   2479    ,   4989    ,   7155    ,   6403    ,0 };
            const std::uint32_t dim2274Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   3   ,   29  ,   41  ,   129 ,   373 ,   839 ,   1031    ,   2845    ,   6911    ,   4793    ,   25609   ,0 };
            const std::uint32_t dim2275Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   23  ,   55  ,   79  ,   209 ,   131 ,   893 ,   1933    ,   1391    ,   6873    ,   407 ,   28823   ,0 };
            const std::uint32_t dim2276Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   15  ,   57  ,   37  ,   153 ,   415 ,   947 ,   1959    ,   1513    ,   7961    ,   4931    ,   749 ,0 };
            const std::uint32_t dim2277Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   21  ,   5   ,   27  ,   169 ,   349 ,   541 ,   533 ,   3411    ,   945 ,   5275    ,   665 ,0 };
            const std::uint32_t dim2278Kuo3Init[]   =   {   1   ,   1   ,   7   ,   15  ,   15  ,   17  ,   97  ,   225 ,   85  ,   887 ,   1251    ,   1485    ,   3987    ,   10753   ,   18013   ,0 };
            const std::uint32_t dim2279Kuo3Init[]   =   {   1   ,   3   ,   1   ,   15  ,   19  ,   53  ,   117 ,   153 ,   279 ,   397 ,   1929    ,   3621    ,   3887    ,   7753    ,   22075   ,0 };
            const std::uint32_t dim2280Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   7   ,   21  ,   97  ,   63  ,   403 ,   715 ,   579 ,   1645    ,   2069    ,   9279    ,   14291   ,0 };
            const std::uint32_t dim2281Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   21  ,   17  ,   63  ,   61  ,   207 ,   795 ,   737 ,   4047    ,   3559    ,   6971    ,   14903   ,0 };
            const std::uint32_t dim2282Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   29  ,   1   ,   103 ,   109 ,   57  ,   485 ,   1373    ,   3399    ,   6351    ,   13037   ,   17193   ,0 };
            const std::uint32_t dim2283Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   5   ,   15  ,   105 ,   225 ,   215 ,   53  ,   1125    ,   3255    ,   3277    ,   2125    ,   23359   ,0 };
            const std::uint32_t dim2284Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   31  ,   39  ,   19  ,   163 ,   197 ,   831 ,   1959    ,   1227    ,   6515    ,   8839    ,   20105   ,0 };
            const std::uint32_t dim2285Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   27  ,   31  ,   89  ,   133 ,   451 ,   371 ,   1513    ,   1595    ,   771 ,   7637    ,   32403   ,0 };
            const std::uint32_t dim2286Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   29  ,   45  ,   29  ,   157 ,   117 ,   461 ,   913 ,   3907    ,   4225    ,   5617    ,   28917   ,0 };
            const std::uint32_t dim2287Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   13  ,   63  ,   113 ,   49  ,   137 ,   641 ,   275 ,   1179    ,   8139    ,   519 ,   5851    ,0 };
            const std::uint32_t dim2288Kuo3Init[]   =   {   1   ,   1   ,   1   ,   1   ,   31  ,   43  ,   61  ,   193 ,   173 ,   651 ,   1491    ,   1005    ,   7559    ,   1963    ,   8323    ,0 };
            const std::uint32_t dim2289Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   23  ,   23  ,   11  ,   111 ,   95  ,   487 ,   1091    ,   175 ,   25  ,   10557   ,   24493   ,0 };
            const std::uint32_t dim2290Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   1   ,   31  ,   97  ,   175 ,   249 ,   309 ,   1005    ,   3777    ,   5551    ,   2605    ,   28071   ,0 };
            const std::uint32_t dim2291Kuo3Init[]   =   {   1   ,   3   ,   3   ,   7   ,   13  ,   1   ,   113 ,   103 ,   169 ,   853 ,   35  ,   3645    ,   6907    ,   13713   ,   12811   ,0 };
            const std::uint32_t dim2292Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   25  ,   49  ,   53  ,   23  ,   33  ,   967 ,   2039    ,   2057    ,   799 ,   1527    ,   3427    ,0 };
            const std::uint32_t dim2293Kuo3Init[]   =   {   1   ,   1   ,   5   ,   7   ,   29  ,   43  ,   81  ,   155 ,   59  ,   201 ,   1571    ,   1719    ,   3343    ,   3231    ,   27929   ,0 };
            const std::uint32_t dim2294Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   27  ,   17  ,   1   ,   159 ,   209 ,   749 ,   1883    ,   1885    ,   2511    ,   15957   ,   3471    ,0 };
            const std::uint32_t dim2295Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   7   ,   51  ,   15  ,   245 ,   57  ,   627 ,   1315    ,   673 ,   5329    ,   1043    ,   555 ,0 };
            const std::uint32_t dim2296Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   13  ,   55  ,   103 ,   157 ,   329 ,   171 ,   393 ,   3967    ,   373 ,   7225    ,   25133   ,0 };
            const std::uint32_t dim2297Kuo3Init[]   =   {   1   ,   1   ,   5   ,   7   ,   5   ,   51  ,   109 ,   11  ,   111 ,   859 ,   165 ,   3991    ,   7187    ,   697 ,   28035   ,0 };
            const std::uint32_t dim2298Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   23  ,   55  ,   59  ,   173 ,   55  ,   105 ,   1103    ,   1569    ,   3099    ,   10483   ,   18821   ,0 };
            const std::uint32_t dim2299Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   21  ,   3   ,   23  ,   247 ,   13  ,   59  ,   1327    ,   2393    ,   5023    ,   11163   ,   21443   ,0 };
            const std::uint32_t dim2300Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   19  ,   47  ,   79  ,   45  ,   127 ,   313 ,   1609    ,   273 ,   4729    ,   7363    ,   13541   ,0 };
            const std::uint32_t dim2301Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   21  ,   61  ,   91  ,   247 ,   477 ,   539 ,   1969    ,   3541    ,   3983    ,   8339    ,   32499   ,0 };
            const std::uint32_t dim2302Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   13  ,   7   ,   47  ,   57  ,   299 ,   907 ,   701 ,   2039    ,   5509    ,   7489    ,   30175   ,0 };
            const std::uint32_t dim2303Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   9   ,   21  ,   125 ,   241 ,   69  ,   405 ,   1989    ,   3777    ,   613 ,   9827    ,   19447   ,0 };
            const std::uint32_t dim2304Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   19  ,   39  ,   19  ,   43  ,   1   ,   1007    ,   1829    ,   3099    ,   4001    ,   2181    ,   5849    ,0 };
            const std::uint32_t dim2305Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   9   ,   49  ,   21  ,   103 ,   107 ,   473 ,   1913    ,   2983    ,   5669    ,   977 ,   21281   ,0 };
            const std::uint32_t dim2306Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   3   ,   37  ,   79  ,   239 ,   425 ,   949 ,   1953    ,   3867    ,   2537    ,   16117   ,   945 ,0 };
            const std::uint32_t dim2307Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   23  ,   7   ,   119 ,   221 ,   321 ,   881 ,   1505    ,   3993    ,   3677    ,   4095    ,   10501   ,0 };
            const std::uint32_t dim2308Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   7   ,   17  ,   5   ,   223 ,   3   ,   891 ,   1699    ,   823 ,   3839    ,   4113    ,   16039   ,0 };
            const std::uint32_t dim2309Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   27  ,   35  ,   67  ,   89  ,   291 ,   521 ,   411 ,   3025    ,   1427    ,   12131   ,   4449    ,0 };
            const std::uint32_t dim2310Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   13  ,   61  ,   103 ,   113 ,   195 ,   269 ,   75  ,   3879    ,   7669    ,   9403    ,   13341   ,0 };
            const std::uint32_t dim2311Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   21  ,   17  ,   101 ,   135 ,   153 ,   615 ,   755 ,   2589    ,   653 ,   11187   ,   2997    ,0 };
            const std::uint32_t dim2312Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   11  ,   53  ,   61  ,   171 ,   423 ,   857 ,   465 ,   819 ,   4341    ,   6377    ,   21305   ,0 };
            const std::uint32_t dim2313Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   17  ,   37  ,   63  ,   91  ,   157 ,   877 ,   1801    ,   587 ,   6183    ,   12923   ,   15991   ,0 };
            const std::uint32_t dim2314Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   27  ,   63  ,   123 ,   27  ,   243 ,   375 ,   191 ,   3333    ,   965 ,   889 ,   15771   ,0 };
            const std::uint32_t dim2315Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   23  ,   51  ,   49  ,   187 ,   201 ,   861 ,   1581    ,   1045    ,   493 ,   9939    ,   30893   ,0 };
            const std::uint32_t dim2316Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   1   ,   31  ,   93  ,   125 ,   57  ,   147 ,   663 ,   2733    ,   4601    ,   16043   ,   6875    ,0 };
            const std::uint32_t dim2317Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   15  ,   1   ,   45  ,   251 ,   173 ,   807 ,   1301    ,   507 ,   645 ,   10383   ,   14737   ,0 };
            const std::uint32_t dim2318Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   27  ,   3   ,   3   ,   127 ,   153 ,   151 ,   1987    ,   2255    ,   5201    ,   11095   ,   20757   ,0 };
            const std::uint32_t dim2319Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   13  ,   49  ,   69  ,   55  ,   205 ,   547 ,   701 ,   1449    ,   6689    ,   3047    ,   12025   ,0 };
            const std::uint32_t dim2320Kuo3Init[]   =   {   1   ,   1   ,   7   ,   9   ,   13  ,   27  ,   31  ,   87  ,   263 ,   499 ,   1573    ,   619 ,   6697    ,   9797    ,   7673    ,0 };
            const std::uint32_t dim2321Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   1   ,   43  ,   45  ,   81  ,   241 ,   143 ,   2045    ,   2847    ,   7361    ,   12253   ,   27815   ,0 };
            const std::uint32_t dim2322Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   27  ,   13  ,   71  ,   119 ,   365 ,   245 ,   113 ,   2635    ,   7157    ,   4951    ,   3381    ,0 };
            const std::uint32_t dim2323Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   25  ,   23  ,   101 ,   21  ,   247 ,   149 ,   431 ,   3165    ,   4109    ,   14305   ,   22549   ,0 };
            const std::uint32_t dim2324Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   3   ,   51  ,   79  ,   7   ,   473 ,   337 ,   709 ,   127 ,   555 ,   12147   ,   19843   ,0 };
            const std::uint32_t dim2325Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   21  ,   35  ,   125 ,   51  ,   373 ,   859 ,   1429    ,   2623    ,   787 ,   9669    ,   14933   ,0 };
            const std::uint32_t dim2326Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   25  ,   45  ,   47  ,   251 ,   475 ,   823 ,   1361    ,   1393    ,   6787    ,   14571   ,   11311   ,0 };
            const std::uint32_t dim2327Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   1   ,   27  ,   75  ,   153 ,   19  ,   373 ,   209 ,   3083    ,   8071    ,   15401   ,   14619   ,0 };
            const std::uint32_t dim2328Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   25  ,   39  ,   73  ,   235 ,   251 ,   245 ,   247 ,   1909    ,   2057    ,   14937   ,   16509   ,0 };
            const std::uint32_t dim2329Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   31  ,   15  ,   117 ,   167 ,   79  ,   911 ,   403 ,   3595    ,   4633    ,   11017   ,   5021    ,0 };
            const std::uint32_t dim2330Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   9   ,   37  ,   19  ,   179 ,   417 ,   285 ,   1237    ,   2667    ,   2131    ,   5943    ,   21265   ,0 };
            const std::uint32_t dim2331Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   29  ,   53  ,   89  ,   223 ,   37  ,   101 ,   1255    ,   97  ,   3813    ,   8543    ,   17949   ,0 };
            const std::uint32_t dim2332Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   25  ,   61  ,   33  ,   145 ,   271 ,   639 ,   1539    ,   2967    ,   1043    ,   10259   ,   27997   ,0 };
            const std::uint32_t dim2333Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   11  ,   17  ,   21  ,   21  ,   159 ,   485 ,   1855    ,   3139    ,   6605    ,   9567    ,   21401   ,0 };
            const std::uint32_t dim2334Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   27  ,   23  ,   23  ,   121 ,   17  ,   45  ,   537 ,   3155    ,   2409    ,   15359   ,   16105   ,0 };
            const std::uint32_t dim2335Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   11  ,   51  ,   87  ,   251 ,   297 ,   227 ,   411 ,   3737    ,   3649    ,   14697   ,   665 ,0 };
            const std::uint32_t dim2336Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   23  ,   23  ,   3   ,   75  ,   99  ,   149 ,   1505    ,   1137    ,   6495    ,   12629   ,   29339   ,0 };
            const std::uint32_t dim2337Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   29  ,   1   ,   83  ,   233 ,   387 ,   801 ,   1387    ,   2721    ,   1399    ,   2275    ,   19865   ,0 };
            const std::uint32_t dim2338Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   31  ,   33  ,   1   ,   253 ,   71  ,   435 ,   781 ,   2991    ,   6881    ,   13183   ,   10419   ,0 };
            const std::uint32_t dim2339Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   19  ,   61  ,   25  ,   167 ,   79  ,   173 ,   447 ,   911 ,   6509    ,   5531    ,   9387    ,0 };
            const std::uint32_t dim2340Kuo3Init[]   =   {   1   ,   1   ,   1   ,   15  ,   31  ,   23  ,   117 ,   1   ,   119 ,   939 ,   1277    ,   2517    ,   2019    ,   4979    ,   4065    ,0 };
            const std::uint32_t dim2341Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   5   ,   49  ,   87  ,   187 ,   159 ,   941 ,   303 ,   217 ,   5931    ,   9065    ,   20043   ,0 };
            const std::uint32_t dim2342Kuo3Init[]   =   {   1   ,   3   ,   1   ,   11  ,   31  ,   43  ,   25  ,   45  ,   61  ,   361 ,   2043    ,   817 ,   8023    ,   14309   ,   6781    ,0 };
            const std::uint32_t dim2343Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   27  ,   45  ,   97  ,   189 ,   387 ,   379 ,   621 ,   2449    ,   39  ,   10313   ,   14603   ,0 };
            const std::uint32_t dim2344Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   5   ,   45  ,   89  ,   251 ,   103 ,   33  ,   1141    ,   2957    ,   6511    ,   8497    ,   16609   ,0 };
            const std::uint32_t dim2345Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   19  ,   11  ,   115 ,   255 ,   277 ,   419 ,   15  ,   999 ,   7509    ,   14191   ,   2749    ,0 };
            const std::uint32_t dim2346Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   7   ,   51  ,   127 ,   225 ,   295 ,   389 ,   1039    ,   2775    ,   5531    ,   10645   ,   13391   ,0 };
            const std::uint32_t dim2347Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   13  ,   63  ,   37  ,   5   ,   3   ,   737 ,   123 ,   777 ,   1469    ,   4009    ,   17037   ,0 };
            const std::uint32_t dim2348Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   31  ,   43  ,   59  ,   119 ,   287 ,   973 ,   541 ,   751 ,   5697    ,   7909    ,   28673   ,0 };
            const std::uint32_t dim2349Kuo3Init[]   =   {   1   ,   1   ,   5   ,   7   ,   15  ,   61  ,   71  ,   213 ,   465 ,   961 ,   1399    ,   3227    ,   571 ,   10759   ,   13947   ,0 };
            const std::uint32_t dim2350Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   17  ,   53  ,   85  ,   11  ,   185 ,   397 ,   567 ,   3763    ,   483 ,   6243    ,   31191   ,0 };
            const std::uint32_t dim2351Kuo3Init[]   =   {   1   ,   3   ,   7   ,   1   ,   31  ,   57  ,   13  ,   255 ,   495 ,   315 ,   763 ,   3153    ,   5543    ,   5719    ,   2235    ,0 };
            const std::uint32_t dim2352Kuo3Init[]   =   {   1   ,   1   ,   1   ,   1   ,   13  ,   25  ,   43  ,   125 ,   391 ,   483 ,   1029    ,   3739    ,   4991    ,   891 ,   24935   ,0 };
            const std::uint32_t dim2353Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   21  ,   3   ,   79  ,   205 ,   87  ,   3   ,   1859    ,   1467    ,   6129    ,   14431   ,   18881   ,0 };
            const std::uint32_t dim2354Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   15  ,   21  ,   79  ,   145 ,   253 ,   595 ,   1939    ,   2195    ,   5735    ,   5383    ,   5311    ,0 };
            const std::uint32_t dim2355Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   13  ,   61  ,   89  ,   3   ,   231 ,   867 ,   1385    ,   183 ,   957 ,   791 ,   2879    ,0 };
            const std::uint32_t dim2356Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   1   ,   39  ,   47  ,   107 ,   217 ,   725 ,   1707    ,   2241    ,   2813    ,   5373    ,   23191   ,0 };
            const std::uint32_t dim2357Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   27  ,   29  ,   119 ,   159 ,   287 ,   343 ,   693 ,   519 ,   2127    ,   6083    ,   2991    ,0 };
            const std::uint32_t dim2358Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   3   ,   51  ,   11  ,   119 ,   337 ,   567 ,   1175    ,   235 ,   6801    ,   1643    ,   26593   ,0 };
            const std::uint32_t dim2359Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   27  ,   49  ,   91  ,   249 ,   489 ,   257 ,   1735    ,   3227    ,   1419    ,   4401    ,   12263   ,0 };
            const std::uint32_t dim2360Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   27  ,   37  ,   101 ,   43  ,   289 ,   313 ,   1031    ,   2921    ,   3655    ,   6781    ,   29593   ,0 };
            const std::uint32_t dim2361Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   17  ,   23  ,   117 ,   129 ,   261 ,   919 ,   265 ,   1561    ,   1297    ,   815 ,   4315    ,0 };
            const std::uint32_t dim2362Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   23  ,   31  ,   95  ,   231 ,   99  ,   909 ,   1477    ,   3385    ,   5679    ,   15319   ,   28849   ,0 };
            const std::uint32_t dim2363Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   25  ,   27  ,   69  ,   83  ,   15  ,   31  ,   1469    ,   751 ,   2339    ,   3251    ,   17343   ,0 };
            const std::uint32_t dim2364Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   5   ,   19  ,   49  ,   25  ,   145 ,   763 ,   667 ,   2003    ,   6905    ,   15623   ,   3533    ,0 };
            const std::uint32_t dim2365Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   5   ,   17  ,   65  ,   151 ,   333 ,   639 ,   1885    ,   3561    ,   1083    ,   7875    ,   22647   ,0 };
            const std::uint32_t dim2366Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   25  ,   45  ,   79  ,   175 ,   87  ,   305 ,   1447    ,   1935    ,   3627    ,   6007    ,   27877   ,0 };
            const std::uint32_t dim2367Kuo3Init[]   =   {   1   ,   3   ,   7   ,   1   ,   11  ,   37  ,   63  ,   37  ,   323 ,   405 ,   1851    ,   435 ,   1501    ,   1345    ,   13729   ,0 };
            const std::uint32_t dim2368Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   9   ,   37  ,   115 ,   151 ,   255 ,   795 ,   811 ,   681 ,   5631    ,   489 ,   21813   ,0 };
            const std::uint32_t dim2369Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   13  ,   25  ,   61  ,   91  ,   367 ,   289 ,   1093    ,   41  ,   5073    ,   1105    ,   28059   ,0 };
            const std::uint32_t dim2370Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   29  ,   53  ,   13  ,   173 ,   83  ,   313 ,   1223    ,   719 ,   517 ,   11689   ,   28719   ,0 };
            const std::uint32_t dim2371Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   5   ,   21  ,   71  ,   229 ,   95  ,   187 ,   739 ,   2607    ,   601 ,   2359    ,   10603   ,0 };
            const std::uint32_t dim2372Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   25  ,   35  ,   55  ,   131 ,   173 ,   677 ,   1887    ,   3293    ,   7641    ,   13535   ,   25561   ,0 };
            const std::uint32_t dim2373Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   29  ,   47  ,   27  ,   1   ,   131 ,   345 ,   1751    ,   1807    ,   235 ,   1891    ,   5909    ,0 };
            const std::uint32_t dim2374Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   15  ,   41  ,   55  ,   201 ,   263 ,   831 ,   401 ,   2685    ,   7403    ,   11827   ,   15353   ,0 };
            const std::uint32_t dim2375Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   5   ,   3   ,   99  ,   61  ,   433 ,   641 ,   1817    ,   891 ,   1937    ,   7179    ,   14391   ,0 };
            const std::uint32_t dim2376Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   19  ,   33  ,   37  ,   223 ,   329 ,   5   ,   1897    ,   2737    ,   4339    ,   9325    ,   12199   ,0 };
            const std::uint32_t dim2377Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   3   ,   23  ,   47  ,   125 ,   85  ,   61  ,   1133    ,   2467    ,   1991    ,   8059    ,   153 ,0 };
            const std::uint32_t dim2378Kuo3Init[]   =   {   1   ,   1   ,   1   ,   15  ,   29  ,   45  ,   117 ,   133 ,   447 ,   627 ,   525 ,   173 ,   1165    ,   11939   ,   21807   ,0 };
            const std::uint32_t dim2379Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   1   ,   15  ,   5   ,   49  ,   237 ,   675 ,   717 ,   2783    ,   4287    ,   11485   ,   3797    ,0 };
            const std::uint32_t dim2380Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   19  ,   63  ,   23  ,   79  ,   313 ,   1007    ,   1321    ,   229 ,   7537    ,   825 ,   29127   ,0 };
            const std::uint32_t dim2381Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   15  ,   55  ,   1   ,   229 ,   221 ,   359 ,   1021    ,   3307    ,   4993    ,   8781    ,   29275   ,0 };
            const std::uint32_t dim2382Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   17  ,   57  ,   37  ,   207 ,   283 ,   599 ,   1867    ,   31  ,   6631    ,   10605   ,   29671   ,0 };
            const std::uint32_t dim2383Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   25  ,   9   ,   111 ,   87  ,   325 ,   515 ,   1249    ,   2027    ,   7783    ,   6473    ,   23737   ,0 };
            const std::uint32_t dim2384Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   31  ,   11  ,   39  ,   161 ,   65  ,   259 ,   1747    ,   597 ,   913 ,   12397   ,   25611   ,0 };
            const std::uint32_t dim2385Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   31  ,   37  ,   27  ,   157 ,   411 ,   785 ,   1699    ,   467 ,   3993    ,   6357    ,   11039   ,0 };
            const std::uint32_t dim2386Kuo3Init[]   =   {   1   ,   3   ,   3   ,   7   ,   5   ,   41  ,   61  ,   103 ,   33  ,   789 ,   1861    ,   319 ,   7667    ,   10169   ,   10823   ,0 };
            const std::uint32_t dim2387Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   31  ,   37  ,   45  ,   175 ,   453 ,   423 ,   291 ,   3989    ,   2215    ,   11379   ,   28713   ,0 };
            const std::uint32_t dim2388Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   23  ,   39  ,   75  ,   103 ,   341 ,   961 ,   2039    ,   1539    ,   7831    ,   1665    ,   18579   ,0 };
            const std::uint32_t dim2389Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   19  ,   25  ,   27  ,   183 ,   241 ,   539 ,   257 ,   3   ,   3709    ,   8133    ,   31081   ,0 };
            const std::uint32_t dim2390Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   1   ,   53  ,   27  ,   229 ,   299 ,   913 ,   1277    ,   2687    ,   831 ,   1065    ,   4409    ,0 };
            const std::uint32_t dim2391Kuo3Init[]   =   {   1   ,   1   ,   7   ,   9   ,   13  ,   47  ,   127 ,   145 ,   481 ,   751 ,   1745    ,   3645    ,   2853    ,   5601    ,   14991   ,0 };
            const std::uint32_t dim2392Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   3   ,   39  ,   31  ,   191 ,   69  ,   707 ,   1757    ,   223 ,   5055    ,   14777   ,   4433    ,0 };
            const std::uint32_t dim2393Kuo3Init[]   =   {   1   ,   1   ,   7   ,   15  ,   27  ,   33  ,   77  ,   75  ,   357 ,   1007    ,   1373    ,   3445    ,   2597    ,   6085    ,   19441   ,0 };
            const std::uint32_t dim2394Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   13  ,   53  ,   77  ,   61  ,   425 ,   245 ,   1149    ,   1239    ,   1989    ,   1293    ,   12971   ,0 };
            const std::uint32_t dim2395Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   23  ,   43  ,   29  ,   89  ,   349 ,   411 ,   2021    ,   2075    ,   4917    ,   11387   ,   27045   ,0 };
            const std::uint32_t dim2396Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   27  ,   63  ,   71  ,   19  ,   363 ,   289 ,   1147    ,   2541    ,   4427    ,   591 ,   21287   ,0 };
            const std::uint32_t dim2397Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   27  ,   3   ,   1   ,   159 ,   85  ,   651 ,   1109    ,   1885    ,   5639    ,   11725   ,   1527    ,0 };
            const std::uint32_t dim2398Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   11  ,   63  ,   77  ,   185 ,   233 ,   129 ,   1721    ,   2419    ,   2043    ,   3121    ,   2159    ,0 };
            const std::uint32_t dim2399Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   11  ,   27  ,   83  ,   193 ,   143 ,   89  ,   1927    ,   3753    ,   4041    ,   10397   ,   1973    ,0 };
            const std::uint32_t dim2400Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   9   ,   61  ,   49  ,   29  ,   333 ,   621 ,   1555    ,   4051    ,   3011    ,   12075   ,   4699    ,0 };
            const std::uint32_t dim2401Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   25  ,   37  ,   69  ,   81  ,   271 ,   827 ,   763 ,   2973    ,   3729    ,   2339    ,   4783    ,0 };
            const std::uint32_t dim2402Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   23  ,   1   ,   95  ,   143 ,   417 ,   517 ,   1991    ,   1423    ,   7511    ,   125 ,   18675   ,0 };
            const std::uint32_t dim2403Kuo3Init[]   =   {   1   ,   3   ,   5   ,   9   ,   3   ,   43  ,   71  ,   73  ,   443 ,   335 ,   737 ,   1121    ,   8001    ,   13165   ,   11155   ,0 };
            const std::uint32_t dim2404Kuo3Init[]   =   {   1   ,   3   ,   1   ,   11  ,   1   ,   21  ,   39  ,   149 ,   261 ,   963 ,   117 ,   3421    ,   2603    ,   4035    ,   4801    ,0 };
            const std::uint32_t dim2405Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   23  ,   63  ,   101 ,   71  ,   495 ,   649 ,   469 ,   2559    ,   541 ,   4499    ,   20357   ,0 };
            const std::uint32_t dim2406Kuo3Init[]   =   {   1   ,   1   ,   5   ,   7   ,   31  ,   37  ,   107 ,   239 ,   197 ,   695 ,   1403    ,   2193    ,   5583    ,   16019   ,   11599   ,0 };
            const std::uint32_t dim2407Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   21  ,   25  ,   127 ,   255 ,   259 ,   209 ,   1491    ,   349 ,   737 ,   9781    ,   3697    ,0 };
            const std::uint32_t dim2408Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   3   ,   47  ,   43  ,   123 ,   315 ,   983 ,   349 ,   2139    ,   6233    ,   731 ,   745 ,0 };
            const std::uint32_t dim2409Kuo3Init[]   =   {   1   ,   1   ,   1   ,   1   ,   25  ,   63  ,   95  ,   101 ,   483 ,   439 ,   1073    ,   1813    ,   3809    ,   11987   ,   4607    ,0 };
            const std::uint32_t dim2410Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   23  ,   11  ,   11  ,   101 ,   9   ,   599 ,   931 ,   39  ,   6593    ,   14875   ,   13557   ,0 };
            const std::uint32_t dim2411Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   21  ,   59  ,   107 ,   131 ,   221 ,   351 ,   1057    ,   3689    ,   7471    ,   4659    ,   27303   ,0 };
            const std::uint32_t dim2412Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   19  ,   59  ,   79  ,   81  ,   169 ,   927 ,   1439    ,   2305    ,   2413    ,   2935    ,   28571   ,0 };
            const std::uint32_t dim2413Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   17  ,   37  ,   81  ,   125 ,   347 ,   81  ,   1029    ,   705 ,   7321    ,   4877    ,   28743   ,0 };
            const std::uint32_t dim2414Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   21  ,   27  ,   113 ,   161 ,   177 ,   49  ,   1655    ,   4035    ,   4987    ,   5545    ,   13137   ,0 };
            const std::uint32_t dim2415Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   5   ,   19  ,   117 ,   13  ,   379 ,   449 ,   765 ,   1395    ,   1051    ,   14783   ,   22283   ,0 };
            const std::uint32_t dim2416Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   25  ,   57  ,   59  ,   47  ,   15  ,   425 ,   1359    ,   1019    ,   4933    ,   6289    ,   2943    ,0 };
            const std::uint32_t dim2417Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   7   ,   31  ,   95  ,   245 ,   243 ,   515 ,   893 ,   2451    ,   83  ,   6561    ,   20993   ,0 };
            const std::uint32_t dim2418Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   7   ,   45  ,   39  ,   227 ,   245 ,   793 ,   1103    ,   3279    ,   6967    ,   14771   ,   23199   ,0 };
            const std::uint32_t dim2419Kuo3Init[]   =   {   1   ,   3   ,   5   ,   9   ,   21  ,   5   ,   103 ,   27  ,   509 ,   187 ,   1727    ,   1281    ,   923 ,   8305    ,   29315   ,0 };
            const std::uint32_t dim2420Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   13  ,   3   ,   3   ,   57  ,   231 ,   609 ,   695 ,   3461    ,   6565    ,   16003   ,   12719   ,0 };
            const std::uint32_t dim2421Kuo3Init[]   =   {   1   ,   1   ,   5   ,   7   ,   13  ,   55  ,   49  ,   111 ,   111 ,   947 ,   1047    ,   3745    ,   8141    ,   13181   ,   25703   ,0 };
            const std::uint32_t dim2422Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   17  ,   51  ,   37  ,   253 ,   97  ,   363 ,   1617    ,   1201    ,   3199    ,   11871   ,   29389   ,0 };
            const std::uint32_t dim2423Kuo3Init[]   =   {   1   ,   3   ,   3   ,   5   ,   23  ,   13  ,   73  ,   85  ,   53  ,   699 ,   1707    ,   2137    ,   4537    ,   15375   ,   28251   ,0 };
            const std::uint32_t dim2424Kuo3Init[]   =   {   1   ,   3   ,   3   ,   7   ,   17  ,   35  ,   29  ,   251 ,   455 ,   153 ,   1703    ,   1535    ,   4801    ,   12889   ,   5959    ,0 };
            const std::uint32_t dim2425Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   15  ,   61  ,   75  ,   21  ,   211 ,   425 ,   1459    ,   1347    ,   7525    ,   15465   ,   28191   ,0 };
            const std::uint32_t dim2426Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   3   ,   1   ,   7   ,   163 ,   317 ,   85  ,   385 ,   3183    ,   1901    ,   6265    ,   13773   ,0 };
            const std::uint32_t dim2427Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   31  ,   43  ,   63  ,   15  ,   157 ,   711 ,   617 ,   2283    ,   1269    ,   15661   ,   28559   ,0 };
            const std::uint32_t dim2428Kuo3Init[]   =   {   1   ,   3   ,   5   ,   1   ,   19  ,   57  ,   1   ,   149 ,   183 ,   9   ,   1587    ,   2711    ,   6563    ,   9291    ,   287 ,0 };
            const std::uint32_t dim2429Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   3   ,   47  ,   11  ,   85  ,   97  ,   245 ,   1673    ,   1147    ,   2187    ,   2361    ,   4417    ,0 };
            const std::uint32_t dim2430Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   9   ,   17  ,   75  ,   3   ,   449 ,   145 ,   1695    ,   597 ,   6931    ,   2281    ,   27291   ,0 };
            const std::uint32_t dim2431Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   7   ,   51  ,   53  ,   53  ,   463 ,   669 ,   677 ,   3579    ,   2609    ,   4147    ,   27567   ,0 };
            const std::uint32_t dim2432Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   29  ,   63  ,   3   ,   195 ,   507 ,   43  ,   425 ,   2121    ,   8147    ,   1287    ,   15137   ,0 };
            const std::uint32_t dim2433Kuo3Init[]   =   {   1   ,   1   ,   7   ,   9   ,   17  ,   7   ,   3   ,   139 ,   301 ,   647 ,   817 ,   3657    ,   3217    ,   4651    ,   21497   ,0 };
            const std::uint32_t dim2434Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   11  ,   43  ,   87  ,   139 ,   441 ,   13  ,   1555    ,   2855    ,   4891    ,   3835    ,   17465   ,0 };
            const std::uint32_t dim2435Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   15  ,   47  ,   29  ,   99  ,   481 ,   377 ,   455 ,   929 ,   1977    ,   7221    ,   2517    ,0 };
            const std::uint32_t dim2436Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   7   ,   41  ,   65  ,   19  ,   17  ,   573 ,   1007    ,   2097    ,   4251    ,   4067    ,   17217   ,0 };
            const std::uint32_t dim2437Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   27  ,   53  ,   41  ,   223 ,   67  ,   747 ,   163 ,   1483    ,   1827    ,   11977   ,   17451   ,0 };
            const std::uint32_t dim2438Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   17  ,   51  ,   109 ,   11  ,   105 ,   481 ,   239 ,   787 ,   5337    ,   14103   ,   10499   ,0 };
            const std::uint32_t dim2439Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   31  ,   25  ,   13  ,   139 ,   37  ,   307 ,   331 ,   633 ,   7907    ,   4705    ,   26019   ,0 };
            const std::uint32_t dim2440Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   25  ,   27  ,   11  ,   33  ,   463 ,   141 ,   1409    ,   2449    ,   2211    ,   10729   ,   28935   ,0 };
            const std::uint32_t dim2441Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   1   ,   39  ,   53  ,   81  ,   117 ,   79  ,   563 ,   3735    ,   253 ,   10483   ,   28129   ,0 };
            const std::uint32_t dim2442Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   7   ,   7   ,   103 ,   233 ,   341 ,   765 ,   11  ,   3735    ,   4011    ,   8075    ,   10239   ,0 };
            const std::uint32_t dim2443Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   25  ,   23  ,   83  ,   139 ,   255 ,   441 ,   611 ,   1583    ,   733 ,   673 ,   21145   ,0 };
            const std::uint32_t dim2444Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   29  ,   7   ,   49  ,   31  ,   417 ,   41  ,   133 ,   2119    ,   3871    ,   16029   ,   25649   ,0 };
            const std::uint32_t dim2445Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   13  ,   17  ,   99  ,   213 ,   149 ,   1015    ,   987 ,   2497    ,   7419    ,   183 ,   27645   ,0 };
            const std::uint32_t dim2446Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   25  ,   13  ,   107 ,   211 ,   113 ,   909 ,   1625    ,   2893    ,   3957    ,   10657   ,   16739   ,0 };
            const std::uint32_t dim2447Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   5   ,   3   ,   97  ,   61  ,   189 ,   779 ,   1633    ,   71  ,   3751    ,   4589    ,   30795   ,0 };
            const std::uint32_t dim2448Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   3   ,   15  ,   33  ,   175 ,   307 ,   937 ,   1713    ,   833 ,   2141    ,   1019    ,   26093   ,0 };
            const std::uint32_t dim2449Kuo3Init[]   =   {   1   ,   1   ,   7   ,   9   ,   15  ,   31  ,   9   ,   45  ,   197 ,   905 ,   1343    ,   27  ,   6835    ,   4353    ,   7229    ,0 };
            const std::uint32_t dim2450Kuo3Init[]   =   {   1   ,   1   ,   7   ,   15  ,   23  ,   15  ,   73  ,   217 ,   283 ,   853 ,   987 ,   389 ,   3875    ,   4353    ,   26667   ,0 };
            const std::uint32_t dim2451Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   9   ,   1   ,   121 ,   39  ,   343 ,   225 ,   143 ,   343 ,   5573    ,   14997   ,   15723   ,0 };
            const std::uint32_t dim2452Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   19  ,   35  ,   73  ,   177 ,   15  ,   697 ,   885 ,   3917    ,   6267    ,   14557   ,   30395   ,0 };
            const std::uint32_t dim2453Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   3   ,   47  ,   59  ,   253 ,   107 ,   251 ,   1081    ,   3115    ,   1295    ,   9261    ,   22389   ,0 };
            const std::uint32_t dim2454Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   29  ,   47  ,   113 ,   153 ,   205 ,   5   ,   507 ,   1313    ,   3329    ,   3043    ,   10135   ,0 };
            const std::uint32_t dim2455Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   29  ,   39  ,   15  ,   147 ,   439 ,   975 ,   415 ,   3385    ,   5379    ,   8957    ,   3441    ,0 };
            const std::uint32_t dim2456Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   23  ,   35  ,   97  ,   251 ,   399 ,   653 ,   1327    ,   3805    ,   6475    ,   1729    ,   29557   ,0 };
            const std::uint32_t dim2457Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   1   ,   5   ,   63  ,   67  ,   209 ,   1005    ,   383 ,   2279    ,   509 ,   7039    ,   24973   ,0 };
            const std::uint32_t dim2458Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   17  ,   59  ,   1   ,   5   ,   325 ,   703 ,   1937    ,   2699    ,   163 ,   10115   ,   8407    ,0 };
            const std::uint32_t dim2459Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   25  ,   27  ,   73  ,   183 ,   41  ,   373 ,   909 ,   3957    ,   7135    ,   2401    ,   24963   ,0 };
            const std::uint32_t dim2460Kuo3Init[]   =   {   1   ,   1   ,   5   ,   7   ,   21  ,   3   ,   113 ,   19  ,   279 ,   729 ,   669 ,   1403    ,   881 ,   3581    ,   29297   ,0 };
            const std::uint32_t dim2461Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   29  ,   9   ,   39  ,   97  ,   133 ,   369 ,   515 ,   1279    ,   2061    ,   5785    ,   29799   ,0 };
            const std::uint32_t dim2462Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   15  ,   9   ,   33  ,   227 ,   13  ,   117 ,   1903    ,   2437    ,   451 ,   10029   ,   27469   ,0 };
            const std::uint32_t dim2463Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   25  ,   3   ,   17  ,   11  ,   439 ,   701 ,   1319    ,   3357    ,   5487    ,   11165   ,   14077   ,0 };
            const std::uint32_t dim2464Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   19  ,   61  ,   115 ,   83  ,   381 ,   261 ,   1025    ,   3215    ,   6889    ,   6123    ,   3761    ,0 };
            const std::uint32_t dim2465Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   21  ,   17  ,   37  ,   151 ,   447 ,   683 ,   811 ,   2551    ,   6735    ,   16189   ,   13109   ,0 };
            const std::uint32_t dim2466Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   5   ,   61  ,   11  ,   223 ,   221 ,   755 ,   65  ,   913 ,   6285    ,   13337   ,   27473   ,0 };
            const std::uint32_t dim2467Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   15  ,   37  ,   93  ,   7   ,   249 ,   809 ,   1819    ,   3297    ,   4555    ,   9013    ,   16243   ,0 };
            const std::uint32_t dim2468Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   3   ,   1   ,   13  ,   45  ,   407 ,   203 ,   963 ,   1055    ,   727 ,   2269    ,   18663   ,0 };
            const std::uint32_t dim2469Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   3   ,   19  ,   95  ,   87  ,   341 ,   337 ,   557 ,   307 ,   7827    ,   15479   ,   24617   ,0 };
            const std::uint32_t dim2470Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   31  ,   3   ,   125 ,   163 ,   439 ,   971 ,   815 ,   1785    ,   2637    ,   2973    ,   15405   ,0 };
            const std::uint32_t dim2471Kuo3Init[]   =   {   1   ,   3   ,   1   ,   15  ,   13  ,   61  ,   25  ,   151 ,   227 ,   173 ,   215 ,   3151    ,   4201    ,   6011    ,   13655   ,0 };
            const std::uint32_t dim2472Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   27  ,   7   ,   13  ,   95  ,   511 ,   373 ,   2023    ,   1019    ,   3229    ,   2513    ,   20929   ,0 };
            const std::uint32_t dim2473Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   11  ,   19  ,   93  ,   159 ,   461 ,   209 ,   549 ,   119 ,   7419    ,   6969    ,   29707   ,0 };
            const std::uint32_t dim2474Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   17  ,   41  ,   53  ,   239 ,   121 ,   529 ,   27  ,   2129    ,   4675    ,   5159    ,   5767    ,0 };
            const std::uint32_t dim2475Kuo3Init[]   =   {   1   ,   1   ,   1   ,   15  ,   23  ,   45  ,   31  ,   189 ,   427 ,   583 ,   191 ,   1123    ,   3183    ,   5499    ,   25925   ,0 };
            const std::uint32_t dim2476Kuo3Init[]   =   {   1   ,   3   ,   7   ,   1   ,   3   ,   17  ,   39  ,   15  ,   257 ,   567 ,   459 ,   3731    ,   1315    ,   10975   ,   23725   ,0 };
            const std::uint32_t dim2477Kuo3Init[]   =   {   1   ,   3   ,   1   ,   11  ,   27  ,   43  ,   31  ,   101 ,   285 ,   249 ,   1467    ,   3937    ,   6413    ,   611 ,   10287   ,0 };
            const std::uint32_t dim2478Kuo3Init[]   =   {   1   ,   1   ,   5   ,   7   ,   19  ,   35  ,   5   ,   225 ,   211 ,   57  ,   1849    ,   3915    ,   5275    ,   13909   ,   18885   ,0 };
            const std::uint32_t dim2479Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   17  ,   45  ,   45  ,   197 ,   311 ,   777 ,   2013    ,   927 ,   6209    ,   15495   ,   30027   ,0 };
            const std::uint32_t dim2480Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   9   ,   13  ,   37  ,   81  ,   389 ,   459 ,   671 ,   2567    ,   7357    ,   5339    ,   13729   ,0 };
            const std::uint32_t dim2481Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   29  ,   31  ,   63  ,   189 ,   271 ,   543 ,   229 ,   1385    ,   2031    ,   8993    ,   5665    ,0 };
            const std::uint32_t dim2482Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   5   ,   25  ,   39  ,   225 ,   121 ,   207 ,   1161    ,   1739    ,   6627    ,   11129   ,   475 ,0 };
            const std::uint32_t dim2483Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   19  ,   7   ,   29  ,   83  ,   25  ,   707 ,   197 ,   335 ,   2613    ,   10035   ,   20157   ,0 };
            const std::uint32_t dim2484Kuo3Init[]   =   {   1   ,   3   ,   3   ,   7   ,   7   ,   63  ,   99  ,   169 ,   221 ,   125 ,   563 ,   1351    ,   3867    ,   14903   ,   27469   ,0 };
            const std::uint32_t dim2485Kuo3Init[]   =   {   1   ,   3   ,   3   ,   7   ,   25  ,   5   ,   31  ,   151 ,   213 ,   555 ,   481 ,   3955    ,   4347    ,   8811    ,   30687   ,0 };
            const std::uint32_t dim2486Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   23  ,   9   ,   59  ,   149 ,   351 ,   819 ,   311 ,   233 ,   4409    ,   3539    ,   6509    ,0 };
            const std::uint32_t dim2487Kuo3Init[]   =   {   1   ,   3   ,   3   ,   7   ,   1   ,   11  ,   3   ,   161 ,   473 ,   65  ,   1793    ,   367 ,   5115    ,   15743   ,   27175   ,0 };
            const std::uint32_t dim2488Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   15  ,   61  ,   5   ,   125 ,   53  ,   523 ,   1365    ,   1909    ,   7689    ,   10799   ,   29199   ,0 };
            const std::uint32_t dim2489Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   13  ,   43  ,   31  ,   179 ,   73  ,   611 ,   293 ,   2349    ,   4873    ,   11271   ,   29827   ,0 };
            const std::uint32_t dim2490Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   27  ,   31  ,   107 ,   197 ,   409 ,   405 ,   789 ,   1529    ,   7793    ,   5679    ,   25127   ,0 };
            const std::uint32_t dim2491Kuo3Init[]   =   {   1   ,   3   ,   5   ,   1   ,   23  ,   35  ,   37  ,   119 ,   99  ,   891 ,   877 ,   1799    ,   5647    ,   13983   ,   22321   ,0 };
            const std::uint32_t dim2492Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   9   ,   49  ,   29  ,   245 ,   447 ,   963 ,   211 ,   3233    ,   2883    ,   5467    ,   24057   ,0 };
            const std::uint32_t dim2493Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   7   ,   29  ,   77  ,   7   ,   47  ,   141 ,   799 ,   2009    ,   7731    ,   4371    ,   24529   ,0 };
            const std::uint32_t dim2494Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   19  ,   31  ,   65  ,   21  ,   417 ,   395 ,   653 ,   1751    ,   2989    ,   6721    ,   28155   ,0 };
            const std::uint32_t dim2495Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   1   ,   5   ,   117 ,   119 ,   39  ,   949 ,   1081    ,   1919    ,   5689    ,   8367    ,   19043   ,0 };
            const std::uint32_t dim2496Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   29  ,   45  ,   73  ,   49  ,   393 ,   545 ,   581 ,   689 ,   2597    ,   5757    ,   26953   ,0 };
            const std::uint32_t dim2497Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   3   ,   13  ,   1   ,   97  ,   73  ,   517 ,   795 ,   2755    ,   5109    ,   15771   ,   19297   ,0 };
            const std::uint32_t dim2498Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   11  ,   5   ,   117 ,   179 ,   507 ,   483 ,   143 ,   1441    ,   3247    ,   7557    ,   10939   ,0 };
            const std::uint32_t dim2499Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   7   ,   9   ,   1   ,   1   ,   465 ,   1019    ,   37  ,   2011    ,   4065    ,   725 ,   10133   ,0 };
            const std::uint32_t dim2500Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   15  ,   39  ,   69  ,   167 ,   399 ,   571 ,   1089    ,   1787    ,   8097    ,   3209    ,   25689   ,0 };
            const std::uint32_t dim2501Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   7   ,   23  ,   17  ,   197 ,   43  ,   727 ,   543 ,   1307    ,   2701    ,   4121    ,   29165   ,0 };
            const std::uint32_t dim2502Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   3   ,   29  ,   57  ,   89  ,   269 ,   667 ,   705 ,   2427    ,   47  ,   5535    ,   21861   ,0 };
            const std::uint32_t dim2503Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   3   ,   43  ,   55  ,   55  ,   337 ,   567 ,   63  ,   3061    ,   5191    ,   16365   ,   24415   ,0 };
            const std::uint32_t dim2504Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   3   ,   31  ,   123 ,   101 ,   149 ,   131 ,   1037    ,   3925    ,   861 ,   12811   ,   23787   ,0 };
            const std::uint32_t dim2505Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   1   ,   5   ,   71  ,   7   ,   113 ,   797 ,   863 ,   1199    ,   1911    ,   2551    ,   12423   ,0 };
            const std::uint32_t dim2506Kuo3Init[]   =   {   1   ,   3   ,   1   ,   11  ,   19  ,   17  ,   25  ,   231 ,   7   ,   137 ,   127 ,   2297    ,   3345    ,   729 ,   909 ,0 };
            const std::uint32_t dim2507Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   17  ,   13  ,   5   ,   227 ,   327 ,   335 ,   1463    ,   2685    ,   6301    ,   15547   ,   13151   ,0 };
            const std::uint32_t dim2508Kuo3Init[]   =   {   1   ,   3   ,   5   ,   9   ,   9   ,   25  ,   87  ,   53  ,   107 ,   219 ,   861 ,   1615    ,   371 ,   4983    ,   6445    ,0 };
            const std::uint32_t dim2509Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   21  ,   59  ,   109 ,   53  ,   365 ,   293 ,   1373    ,   147 ,   4215    ,   1007    ,   20401   ,0 };
            const std::uint32_t dim2510Kuo3Init[]   =   {   1   ,   3   ,   3   ,   5   ,   5   ,   25  ,   113 ,   233 ,   317 ,   121 ,   427 ,   3561    ,   701 ,   10169   ,   23449   ,0 };
            const std::uint32_t dim2511Kuo3Init[]   =   {   1   ,   3   ,   5   ,   9   ,   9   ,   41  ,   123 ,   199 ,   305 ,   639 ,   1131    ,   3635    ,   8125    ,   4007    ,   6883    ,0 };
            const std::uint32_t dim2512Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   23  ,   5   ,   105 ,   25  ,   281 ,   301 ,   1011    ,   3647    ,   263 ,   3389    ,   5527    ,0 };
            const std::uint32_t dim2513Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   17  ,   59  ,   33  ,   175 ,   115 ,   625 ,   975 ,   3189    ,   6973    ,   8291    ,   14201   ,0 };
            const std::uint32_t dim2514Kuo3Init[]   =   {   1   ,   3   ,   3   ,   5   ,   1   ,   41  ,   39  ,   231 ,   57  ,   95  ,   623 ,   2199    ,   3821    ,   1627    ,   4035    ,0 };
            const std::uint32_t dim2515Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   25  ,   5   ,   1   ,   21  ,   457 ,   875 ,   355 ,   389 ,   1623    ,   9575    ,   1283    ,0 };
            const std::uint32_t dim2516Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   21  ,   29  ,   83  ,   45  ,   315 ,   735 ,   1253    ,   3743    ,   7163    ,   5163    ,   10833   ,0 };
            const std::uint32_t dim2517Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   1   ,   5   ,   47  ,   21  ,   231 ,   1019    ,   1851    ,   21  ,   1699    ,   851 ,   11857   ,0 };
            const std::uint32_t dim2518Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   19  ,   9   ,   61  ,   241 ,   175 ,   191 ,   415 ,   1197    ,   5643    ,   9765    ,   17375   ,0 };
            const std::uint32_t dim2519Kuo3Init[]   =   {   1   ,   3   ,   5   ,   1   ,   3   ,   5   ,   35  ,   231 ,   471 ,   175 ,   1715    ,   487 ,   2299    ,   12355   ,   5113    ,0 };
            const std::uint32_t dim2520Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   15  ,   45  ,   33  ,   93  ,   289 ,   371 ,   275 ,   1703    ,   6925    ,   5511    ,   3203    ,0 };
            const std::uint32_t dim2521Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   21  ,   55  ,   105 ,   199 ,   435 ,   955 ,   731 ,   719 ,   1571    ,   7341    ,   5255    ,0 };
            const std::uint32_t dim2522Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   1   ,   3   ,   127 ,   85  ,   11  ,   165 ,   1423    ,   3889    ,   7509    ,   14687   ,   23383   ,0 };
            const std::uint32_t dim2523Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   31  ,   61  ,   9   ,   141 ,   357 ,   801 ,   1785    ,   3813    ,   3437    ,   10853   ,   17191   ,0 };
            const std::uint32_t dim2524Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   23  ,   59  ,   17  ,   205 ,   449 ,   107 ,   1123    ,   1089    ,   5499    ,   12251   ,   653 ,0 };
            const std::uint32_t dim2525Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   3   ,   25  ,   71  ,   229 ,   263 ,   423 ,   1357    ,   3709    ,   1719    ,   2799    ,   10943   ,0 };
            const std::uint32_t dim2526Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   1   ,   23  ,   97  ,   209 ,   401 ,   809 ,   783 ,   2455    ,   1137    ,   13941   ,   12751   ,0 };
            const std::uint32_t dim2527Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   21  ,   47  ,   25  ,   29  ,   471 ,   677 ,   1129    ,   2689    ,   929 ,   5635    ,   26509   ,0 };
            const std::uint32_t dim2528Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   7   ,   27  ,   5   ,   195 ,   435 ,   255 ,   395 ,   2775    ,   297 ,   6909    ,   2289    ,0 };
            const std::uint32_t dim2529Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   7   ,   53  ,   109 ,   85  ,   141 ,   243 ,   1433    ,   1531    ,   5461    ,   1111    ,   7889    ,0 };
            const std::uint32_t dim2530Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   13  ,   47  ,   91  ,   51  ,   489 ,   433 ,   1667    ,   2955    ,   5135    ,   11949   ,   14123   ,0 };
            const std::uint32_t dim2531Kuo3Init[]   =   {   1   ,   1   ,   7   ,   15  ,   5   ,   57  ,   57  ,   147 ,   97  ,   709 ,   1757    ,   1493    ,   2715    ,   12583   ,   18991   ,0 };
            const std::uint32_t dim2532Kuo3Init[]   =   {   1   ,   3   ,   1   ,   15  ,   7   ,   17  ,   79  ,   75  ,   397 ,   555 ,   787 ,   1405    ,   4749    ,   6723    ,   3749    ,0 };
            const std::uint32_t dim2533Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   21  ,   59  ,   5   ,   211 ,   215 ,   393 ,   1445    ,   4057    ,   5115    ,   821 ,   7783    ,0 };
            const std::uint32_t dim2534Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   29  ,   1   ,   97  ,   201 ,   21  ,   287 ,   1735    ,   2397    ,   3401    ,   2017    ,   32229   ,0 };
            const std::uint32_t dim2535Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   17  ,   43  ,   71  ,   25  ,   243 ,   423 ,   733 ,   1917    ,   1235    ,   3527    ,   22695   ,0 };
            const std::uint32_t dim2536Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   27  ,   7   ,   25  ,   239 ,   493 ,   945 ,   397 ,   3837    ,   5465    ,   12273   ,   26025   ,0 };
            const std::uint32_t dim2537Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   17  ,   17  ,   61  ,   7   ,   487 ,   439 ,   1433    ,   1761    ,   6507    ,   487 ,   32633   ,0 };
            const std::uint32_t dim2538Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   21  ,   29  ,   83  ,   27  ,   321 ,   73  ,   1247    ,   2593    ,   6935    ,   7009    ,   31617   ,0 };
            const std::uint32_t dim2539Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   25  ,   37  ,   99  ,   177 ,   357 ,   527 ,   1259    ,   3625    ,   4277    ,   15243   ,   28615   ,0 };
            const std::uint32_t dim2540Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   29  ,   31  ,   59  ,   177 ,   73  ,   1007    ,   1809    ,   2143    ,   7375    ,   4321    ,   3771    ,0 };
            const std::uint32_t dim2541Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   21  ,   7   ,   123 ,   253 ,   87  ,   995 ,   103 ,   561 ,   7639    ,   10087   ,   4149    ,0 };
            const std::uint32_t dim2542Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   11  ,   31  ,   53  ,   249 ,   435 ,   361 ,   367 ,   783 ,   7525    ,   5361    ,   21535   ,0 };
            const std::uint32_t dim2543Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   15  ,   25  ,   31  ,   9   ,   29  ,   907 ,   77  ,   2585    ,   2929    ,   12153   ,   19401   ,0 };
            const std::uint32_t dim2544Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   15  ,   1   ,   101 ,   99  ,   209 ,   583 ,   679 ,   1005    ,   2271    ,   269 ,   29527   ,0 };
            const std::uint32_t dim2545Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   13  ,   35  ,   85  ,   83  ,   77  ,   999 ,   1485    ,   2817    ,   7001    ,   13659   ,   25061   ,0 };
            const std::uint32_t dim2546Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   19  ,   15  ,   19  ,   65  ,   195 ,   693 ,   1399    ,   2875    ,   255 ,   6617    ,   7907    ,0 };
            const std::uint32_t dim2547Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   13  ,   25  ,   67  ,   195 ,   131 ,   481 ,   1831    ,   873 ,   6281    ,   4935    ,   2311    ,0 };
            const std::uint32_t dim2548Kuo3Init[]   =   {   1   ,   1   ,   1   ,   15  ,   27  ,   47  ,   85  ,   209 ,   323 ,   809 ,   605 ,   2087    ,   1917    ,   8061    ,   13659   ,0 };
            const std::uint32_t dim2549Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   5   ,   63  ,   69  ,   197 ,   241 ,   349 ,   813 ,   3943    ,   6267    ,   16197   ,   1417    ,0 };
            const std::uint32_t dim2550Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   13  ,   21  ,   85  ,   55  ,   21  ,   791 ,   795 ,   4087    ,   2697    ,   6545    ,   30253   ,0 };
            const std::uint32_t dim2551Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   31  ,   13  ,   117 ,   237 ,   99  ,   803 ,   1367    ,   251 ,   5143    ,   12153   ,   27565   ,0 };
            const std::uint32_t dim2552Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   11  ,   7   ,   17  ,   47  ,   305 ,   9   ,   941 ,   3529    ,   6131    ,   11027   ,   20319   ,0 };
            const std::uint32_t dim2553Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   19  ,   51  ,   1   ,   113 ,   277 ,   573 ,   1717    ,   1757    ,   4541    ,   943 ,   349 ,0 };
            const std::uint32_t dim2554Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   21  ,   23  ,   11  ,   143 ,   413 ,   171 ,   355 ,   2801    ,   2431    ,   11597   ,   16833   ,0 };
            const std::uint32_t dim2555Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   13  ,   31  ,   111 ,   109 ,   73  ,   125 ,   1011    ,   2249    ,   4039    ,   8757    ,   2765    ,0 };
            const std::uint32_t dim2556Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   15  ,   53  ,   33  ,   133 ,   511 ,   595 ,   139 ,   815 ,   6093    ,   10215   ,   9507    ,0 };
            const std::uint32_t dim2557Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   29  ,   1   ,   93  ,   13  ,   169 ,   435 ,   527 ,   3861    ,   3867    ,   9337    ,   26855   ,0 };
            const std::uint32_t dim2558Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   13  ,   29  ,   91  ,   73  ,   257 ,   645 ,   679 ,   3245    ,   6467    ,   5917    ,   17891   ,0 };
            const std::uint32_t dim2559Kuo3Init[]   =   {   1   ,   1   ,   7   ,   15  ,   27  ,   1   ,   45  ,   17  ,   429 ,   571 ,   1127    ,   3843    ,   3801    ,   4773    ,   16577   ,0 };
            const std::uint32_t dim2560Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   29  ,   29  ,   65  ,   111 ,   415 ,   941 ,   1411    ,   3003    ,   3945    ,   15281   ,   16851   ,0 };
            const std::uint32_t dim2561Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   3   ,   29  ,   39  ,   121 ,   165 ,   285 ,   1895    ,   283 ,   4393    ,   13281   ,   3349    ,0 };
            const std::uint32_t dim2562Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   27  ,   1   ,   35  ,   119 ,   91  ,   445 ,   1045    ,   1427    ,   6271    ,   955 ,   509 ,0 };
            const std::uint32_t dim2563Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   11  ,   15  ,   3   ,   181 ,   17  ,   3   ,   1865    ,   2465    ,   357 ,   12149   ,   7359    ,0 };
            const std::uint32_t dim2564Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   11  ,   47  ,   5   ,   65  ,   105 ,   53  ,   1341    ,   3729    ,   4883    ,   5179    ,   29353   ,0 };
            const std::uint32_t dim2565Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   15  ,   53  ,   23  ,   181 ,   125 ,   441 ,   511 ,   3933    ,   2327    ,   1305    ,   14629   ,0 };
            const std::uint32_t dim2566Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   3   ,   11  ,   91  ,   187 ,   177 ,   649 ,   1849    ,   2545    ,   3349    ,   6563    ,   8139    ,0 };
            const std::uint32_t dim2567Kuo3Init[]   =   {   1   ,   3   ,   1   ,   11  ,   31  ,   35  ,   71  ,   51  ,   235 ,   295 ,   521 ,   3869    ,   3083    ,   1327    ,   3277    ,0 };
            const std::uint32_t dim2568Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   11  ,   11  ,   125 ,   163 ,   71  ,   721 ,   449 ,   3443    ,   1347    ,   6221    ,   19489   ,0 };
            const std::uint32_t dim2569Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   25  ,   13  ,   13  ,   149 ,   115 ,   563 ,   311 ,   1823    ,   2687    ,   5997    ,   23063   ,0 };
            const std::uint32_t dim2570Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   7   ,   47  ,   115 ,   19  ,   419 ,   395 ,   591 ,   2413    ,   7143    ,   11235   ,   25795   ,0 };
            const std::uint32_t dim2571Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   17  ,   37  ,   63  ,   57  ,   175 ,   301 ,   493 ,   1849    ,   1903    ,   13149   ,   21429   ,0 };
            const std::uint32_t dim2572Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   1   ,   53  ,   15  ,   91  ,   315 ,   687 ,   473 ,   1639    ,   7769    ,   11621   ,   24245   ,0 };
            const std::uint32_t dim2573Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   13  ,   35  ,   13  ,   235 ,   365 ,   677 ,   611 ,   3175    ,   6349    ,   445 ,   13739   ,0 };
            const std::uint32_t dim2574Kuo3Init[]   =   {   1   ,   1   ,   1   ,   15  ,   17  ,   49  ,   49  ,   15  ,   205 ,   755 ,   665 ,   3865    ,   6499    ,   6521    ,   31925   ,0 };
            const std::uint32_t dim2575Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   9   ,   49  ,   57  ,   119 ,   489 ,   633 ,   1407    ,   957 ,   4005    ,   14503   ,   2783    ,0 };
            const std::uint32_t dim2576Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   17  ,   41  ,   73  ,   137 ,   195 ,   457 ,   1361    ,   3209    ,   3701    ,   9675    ,   26499   ,0 };
            const std::uint32_t dim2577Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   31  ,   49  ,   71  ,   83  ,   141 ,   1009    ,   1503    ,   3393    ,   4653    ,   8051    ,   25861   ,0 };
            const std::uint32_t dim2578Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   31  ,   17  ,   83  ,   211 ,   3   ,   81  ,   1579    ,   387 ,   4471    ,   5407    ,   28849   ,0 };
            const std::uint32_t dim2579Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   3   ,   51  ,   45  ,   157 ,   197 ,   195 ,   1121    ,   2451    ,   3885    ,   9317    ,   29157   ,0 };
            const std::uint32_t dim2580Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   23  ,   19  ,   49  ,   89  ,   107 ,   369 ,   129 ,   2381    ,   383 ,   8279    ,   29277   ,0 };
            const std::uint32_t dim2581Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   21  ,   7   ,   123 ,   221 ,   85  ,   819 ,   1857    ,   1211    ,   7495    ,   2921    ,   9529    ,0 };
            const std::uint32_t dim2582Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   19  ,   13  ,   63  ,   47  ,   465 ,   739 ,   1961    ,   2779    ,   7989    ,   8419    ,   19249   ,0 };
            const std::uint32_t dim2583Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   25  ,   49  ,   65  ,   39  ,   333 ,   193 ,   443 ,   1221    ,   245 ,   523 ,   31885   ,0 };
            const std::uint32_t dim2584Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   31  ,   3   ,   69  ,   173 ,   19  ,   593 ,   61  ,   1545    ,   415 ,   14489   ,   9723    ,0 };
            const std::uint32_t dim2585Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   5   ,   9   ,   121 ,   87  ,   431 ,   893 ,   1031    ,   3589    ,   4263    ,   11355   ,   22725   ,0 };
            const std::uint32_t dim2586Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   21  ,   9   ,   47  ,   151 ,   165 ,   941 ,   1369    ,   3991    ,   989 ,   1515    ,   12725   ,0 };
            const std::uint32_t dim2587Kuo3Init[]   =   {   1   ,   3   ,   7   ,   1   ,   7   ,   47  ,   57  ,   153 ,   239 ,   397 ,   1723    ,   1681    ,   521 ,   8173    ,   14567   ,0 };
            const std::uint32_t dim2588Kuo3Init[]   =   {   1   ,   3   ,   3   ,   5   ,   23  ,   9   ,   77  ,   201 ,   61  ,   969 ,   345 ,   2817    ,   4391    ,   2193    ,   18739   ,0 };
            const std::uint32_t dim2589Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   15  ,   45  ,   83  ,   165 ,   421 ,   967 ,   449 ,   3419    ,   2475    ,   7283    ,   18199   ,0 };
            const std::uint32_t dim2590Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   25  ,   37  ,   3   ,   175 ,   327 ,   35  ,   1179    ,   927 ,   5263    ,   1723    ,   32015   ,0 };
            const std::uint32_t dim2591Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   29  ,   17  ,   63  ,   45  ,   495 ,   107 ,   459 ,   2223    ,   989 ,   11823   ,   6547    ,0 };
            const std::uint32_t dim2592Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   17  ,   15  ,   127 ,   223 ,   369 ,   409 ,   303 ,   2229    ,   7349    ,   10165   ,   28327   ,0 };
            const std::uint32_t dim2593Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   15  ,   17  ,   119 ,   185 ,   55  ,   299 ,   113 ,   3585    ,   2289    ,   7793    ,   26217   ,0 };
            const std::uint32_t dim2594Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   21  ,   33  ,   3   ,   5   ,   169 ,   615 ,   1607    ,   1069    ,   1827    ,   6165    ,   16245   ,0 };
            const std::uint32_t dim2595Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   21  ,   59  ,   119 ,   253 ,   181 ,   1001    ,   2001    ,   887 ,   4129    ,   3953    ,   29979   ,0 };
            const std::uint32_t dim2596Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   29  ,   17  ,   33  ,   3   ,   375 ,   973 ,   989 ,   1725    ,   731 ,   12845   ,   21133   ,0 };
            const std::uint32_t dim2597Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   21  ,   25  ,   65  ,   41  ,   379 ,   693 ,   1507    ,   1601    ,   2087    ,   8181    ,   12723   ,0 };
            const std::uint32_t dim2598Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   21  ,   37  ,   117 ,   187 ,   483 ,   779 ,   1279    ,   685 ,   5479    ,   12039   ,   12559   ,0 };
            const std::uint32_t dim2599Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   7   ,   39  ,   49  ,   79  ,   361 ,   191 ,   1749    ,   507 ,   19  ,   10671   ,   4745    ,0 };
            const std::uint32_t dim2600Kuo3Init[]   =   {   1   ,   1   ,   1   ,   15  ,   15  ,   45  ,   37  ,   49  ,   85  ,   311 ,   577 ,   2417    ,   4061    ,   1409    ,   19187   ,0 };
            const std::uint32_t dim2601Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   5   ,   1   ,   41  ,   73  ,   313 ,   741 ,   1081    ,   3325    ,   977 ,   1693    ,   15249   ,0 };
            const std::uint32_t dim2602Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   19  ,   49  ,   29  ,   169 ,   153 ,   665 ,   413 ,   907 ,   6129    ,   4961    ,   21295   ,0 };
            const std::uint32_t dim2603Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   23  ,   17  ,   91  ,   27  ,   375 ,   231 ,   513 ,   1459    ,   7245    ,   8117    ,   19583   ,0 };
            const std::uint32_t dim2604Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   19  ,   57  ,   111 ,   195 ,   491 ,   771 ,   1841    ,   1339    ,   5045    ,   12901   ,   17307   ,0 };
            const std::uint32_t dim2605Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   1   ,   61  ,   61  ,   11  ,   151 ,   403 ,   173 ,   3629    ,   2157    ,   6125    ,   29233   ,0 };
            const std::uint32_t dim2606Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   29  ,   63  ,   55  ,   9   ,   465 ,   439 ,   9   ,   1527    ,   4635    ,   4533    ,   13633   ,0 };
            const std::uint32_t dim2607Kuo3Init[]   =   {   1   ,   3   ,   5   ,   1   ,   15  ,   57  ,   113 ,   137 ,   483 ,   753 ,   1971    ,   1141    ,   2765    ,   7865    ,   32733   ,0 };
            const std::uint32_t dim2608Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   9   ,   23  ,   125 ,   81  ,   471 ,   457 ,   1475    ,   3419    ,   6089    ,   4899    ,   19805   ,0 };
            const std::uint32_t dim2609Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   25  ,   29  ,   1   ,   115 ,   273 ,   281 ,   899 ,   3129    ,   4877    ,   15459   ,   24615   ,0 };
            const std::uint32_t dim2610Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   19  ,   41  ,   59  ,   165 ,   115 ,   369 ,   1173    ,   2545    ,   4285    ,   10899   ,   3823    ,0 };
            const std::uint32_t dim2611Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   17  ,   47  ,   107 ,   191 ,   53  ,   1003    ,   747 ,   583 ,   6457    ,   12141   ,   2541    ,0 };
            const std::uint32_t dim2612Kuo3Init[]   =   {   1   ,   3   ,   7   ,   1   ,   9   ,   51  ,   33  ,   201 ,   399 ,   209 ,   271 ,   679 ,   2401    ,   10521   ,   9949    ,0 };
            const std::uint32_t dim2613Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   5   ,   53  ,   117 ,   157 ,   137 ,   757 ,   257 ,   1407    ,   4831    ,   11205   ,   25075   ,0 };
            const std::uint32_t dim2614Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   29  ,   63  ,   25  ,   11  ,   255 ,   251 ,   1393    ,   2089    ,   1701    ,   11773   ,   24011   ,0 };
            const std::uint32_t dim2615Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   17  ,   5   ,   69  ,   119 ,   287 ,   607 ,   779 ,   2369    ,   55  ,   12381   ,   26051   ,0 };
            const std::uint32_t dim2616Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   25  ,   1   ,   97  ,   109 ,   79  ,   453 ,   795 ,   2821    ,   4113    ,   3085    ,   30667   ,0 };
            const std::uint32_t dim2617Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   25  ,   17  ,   87  ,   163 ,   483 ,   803 ,   315 ,   2755    ,   7147    ,   12537   ,   7707    ,0 };
            const std::uint32_t dim2618Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   23  ,   29  ,   93  ,   129 ,   47  ,   181 ,   1577    ,   2645    ,   4103    ,   10753   ,   27119   ,0 };
            const std::uint32_t dim2619Kuo3Init[]   =   {   1   ,   1   ,   1   ,   1   ,   17  ,   61  ,   37  ,   175 ,   451 ,   5   ,   879 ,   1625    ,   7981    ,   11249   ,   12573   ,0 };
            const std::uint32_t dim2620Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   9   ,   17  ,   85  ,   131 ,   111 ,   621 ,   903 ,   3143    ,   5951    ,   6567    ,   32227   ,0 };
            const std::uint32_t dim2621Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   1   ,   49  ,   53  ,   255 ,   435 ,   845 ,   225 ,   2535    ,   7925    ,   8043    ,   17519   ,0 };
            const std::uint32_t dim2622Kuo3Init[]   =   {   1   ,   3   ,   3   ,   5   ,   23  ,   7   ,   63  ,   117 ,   79  ,   637 ,   1265    ,   2747    ,   6531    ,   7327    ,   17329   ,0 };
            const std::uint32_t dim2623Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   27  ,   35  ,   69  ,   253 ,   489 ,   495 ,   561 ,   3615    ,   917 ,   6595    ,   10673   ,0 };
            const std::uint32_t dim2624Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   25  ,   7   ,   99  ,   99  ,   499 ,   251 ,   1651    ,   3603    ,   689 ,   5837    ,   347 ,0 };
            const std::uint32_t dim2625Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   1   ,   27  ,   55  ,   91  ,   137 ,   291 ,   517 ,   2149    ,   1097    ,   2187    ,   16191   ,0 };
            const std::uint32_t dim2626Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   29  ,   3   ,   103 ,   81  ,   335 ,   85  ,   549 ,   1667    ,   5319    ,   5929    ,   15885   ,0 };
            const std::uint32_t dim2627Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   7   ,   41  ,   103 ,   141 ,   103 ,   655 ,   179 ,   1513    ,   7105    ,   1919    ,   2245    ,0 };
            const std::uint32_t dim2628Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   11  ,   13  ,   127 ,   65  ,   493 ,   233 ,   859 ,   3179    ,   5449    ,   13255   ,   14495   ,0 };
            const std::uint32_t dim2629Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   27  ,   49  ,   119 ,   29  ,   55  ,   717 ,   1293    ,   1193    ,   7883    ,   4475    ,   13745   ,0 };
            const std::uint32_t dim2630Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   21  ,   9   ,   1   ,   43  ,   425 ,   385 ,   447 ,   3135    ,   7671    ,   12317   ,   5649    ,0 };
            const std::uint32_t dim2631Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   21  ,   51  ,   103 ,   199 ,   119 ,   875 ,   1457    ,   461 ,   6521    ,   7849    ,   7725    ,0 };
            const std::uint32_t dim2632Kuo3Init[]   =   {   1   ,   1   ,   1   ,   15  ,   9   ,   25  ,   89  ,   125 ,   395 ,   269 ,   1533    ,   1545    ,   2613    ,   11175   ,   17167   ,0 };
            const std::uint32_t dim2633Kuo3Init[]   =   {   1   ,   3   ,   5   ,   9   ,   17  ,   41  ,   113 ,   37  ,   253 ,   407 ,   795 ,   2117    ,   3041    ,   9269    ,   30097   ,0 };
            const std::uint32_t dim2634Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   31  ,   13  ,   23  ,   29  ,   385 ,   603 ,   1721    ,   3817    ,   3453    ,   2021    ,   8829    ,0 };
            const std::uint32_t dim2635Kuo3Init[]   =   {   1   ,   1   ,   7   ,   9   ,   21  ,   3   ,   107 ,   121 ,   267 ,   385 ,   261 ,   3967    ,   5607    ,   13991   ,   8639    ,0 };
            const std::uint32_t dim2636Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   17  ,   19  ,   99  ,   195 ,   415 ,   19  ,   865 ,   4049    ,   3819    ,   7581    ,   10779   ,0 };
            const std::uint32_t dim2637Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   25  ,   29  ,   125 ,   105 ,   337 ,   153 ,   2023    ,   1475    ,   2741    ,   7779    ,   16929   ,0 };
            const std::uint32_t dim2638Kuo3Init[]   =   {   1   ,   3   ,   3   ,   5   ,   11  ,   1   ,   111 ,   157 ,   441 ,   751 ,   865 ,   3499    ,   6425    ,   9567    ,   6659    ,0 };
            const std::uint32_t dim2639Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   23  ,   41  ,   57  ,   91  ,   413 ,   81  ,   1977    ,   2227    ,   2289    ,   1291    ,   19339   ,0 };
            const std::uint32_t dim2640Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   15  ,   49  ,   47  ,   115 ,   153 ,   593 ,   1243    ,   2029    ,   1177    ,   8121    ,   14893   ,0 };
            const std::uint32_t dim2641Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   29  ,   11  ,   55  ,   23  ,   173 ,   145 ,   143 ,   2275    ,   4537    ,   13221   ,   32575   ,0 };
            const std::uint32_t dim2642Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   29  ,   53  ,   103 ,   37  ,   327 ,   543 ,   1327    ,   899 ,   6343    ,   6707    ,   1247    ,0 };
            const std::uint32_t dim2643Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   21  ,   49  ,   113 ,   205 ,   349 ,   451 ,   1277    ,   989 ,   3387    ,   9275    ,   6629    ,0 };
            const std::uint32_t dim2644Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   31  ,   59  ,   79  ,   65  ,   285 ,   841 ,   287 ,   1453    ,   1507    ,   14813   ,   14705   ,0 };
            const std::uint32_t dim2645Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   9   ,   11  ,   79  ,   109 ,   313 ,   339 ,   1939    ,   2399    ,   5127    ,   8747    ,   11989   ,0 };
            const std::uint32_t dim2646Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   9   ,   27  ,   83  ,   135 ,   249 ,   101 ,   1181    ,   451 ,   6063    ,   609 ,   15371   ,0 };
            const std::uint32_t dim2647Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   15  ,   61  ,   77  ,   221 ,   19  ,   643 ,   1535    ,   1223    ,   7165    ,   10969   ,   10367   ,0 };
            const std::uint32_t dim2648Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   5   ,   9   ,   61  ,   95  ,   493 ,   709 ,   71  ,   1571    ,   6805    ,   9687    ,   12217   ,0 };
            const std::uint32_t dim2649Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   17  ,   55  ,   57  ,   179 ,   217 ,   699 ,   943 ,   127 ,   1603    ,   6851    ,   8579    ,0 };
            const std::uint32_t dim2650Kuo3Init[]   =   {   1   ,   3   ,   1   ,   11  ,   25  ,   51  ,   127 ,   13  ,   429 ,   15  ,   949 ,   2337    ,   5743    ,   14255   ,   15137   ,0 };
            const std::uint32_t dim2651Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   5   ,   39  ,   39  ,   105 ,   119 ,   355 ,   1655    ,   3819    ,   1313    ,   5173    ,   7791    ,0 };
            const std::uint32_t dim2652Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   3   ,   47  ,   93  ,   85  ,   19  ,   399 ,   303 ,   1333    ,   5435    ,   9425    ,   6503    ,0 };
            const std::uint32_t dim2653Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   21  ,   33  ,   71  ,   253 ,   489 ,   149 ,   227 ,   797 ,   955 ,   6839    ,   23037   ,0 };
            const std::uint32_t dim2654Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   27  ,   59  ,   15  ,   47  ,   249 ,   557 ,   1477    ,   1837    ,   4409    ,   14723   ,   14933   ,0 };
            const std::uint32_t dim2655Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   1   ,   47  ,   11  ,   205 ,   131 ,   17  ,   373 ,   2039    ,   1873    ,   3041    ,   22869   ,0 };
            const std::uint32_t dim2656Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   11  ,   27  ,   99  ,   135 ,   195 ,   419 ,   561 ,   1027    ,   1849    ,   13533   ,   7701    ,0 };
            const std::uint32_t dim2657Kuo3Init[]   =   {   1   ,   1   ,   7   ,   15  ,   27  ,   23  ,   77  ,   111 ,   157 ,   417 ,   591 ,   3435    ,   5999    ,   9481    ,   17073   ,0 };
            const std::uint32_t dim2658Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   9   ,   61  ,   57  ,   43  ,   85  ,   585 ,   1861    ,   703 ,   2337    ,   8565    ,   16233   ,0 };
            const std::uint32_t dim2659Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   7   ,   17  ,   41  ,   213 ,   145 ,   325 ,   1847    ,   3205    ,   3515    ,   1117    ,   285 ,0 };
            const std::uint32_t dim2660Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   7   ,   35  ,   95  ,   127 ,   57  ,   123 ,   759 ,   129 ,   4335    ,   15183   ,   2107    ,0 };
            const std::uint32_t dim2661Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   13  ,   1   ,   87  ,   193 ,   63  ,   201 ,   741 ,   2087    ,   1625    ,   1677    ,   31603   ,0 };
            const std::uint32_t dim2662Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   13  ,   53  ,   127 ,   235 ,   489 ,   173 ,   1551    ,   1897    ,   5877    ,   15559   ,   24445   ,0 };
            const std::uint32_t dim2663Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   9   ,   53  ,   59  ,   247 ,   83  ,   521 ,   2029    ,   3677    ,   2083    ,   11635   ,   30517   ,0 };
            const std::uint32_t dim2664Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   9   ,   19  ,   71  ,   99  ,   213 ,   663 ,   947 ,   1929    ,   5275    ,   9715    ,   10033   ,0 };
            const std::uint32_t dim2665Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   25  ,   31  ,   33  ,   239 ,   137 ,   445 ,   1227    ,   1051    ,   7405    ,   7983    ,   10079   ,0 };
            const std::uint32_t dim2666Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   27  ,   35  ,   51  ,   207 ,   167 ,   519 ,   303 ,   3399    ,   4393    ,   1623    ,   21225   ,0 };
            const std::uint32_t dim2667Kuo3Init[]   =   {   1   ,   3   ,   1   ,   11  ,   17  ,   13  ,   41  ,   229 ,   441 ,   879 ,   1695    ,   1351    ,   5745    ,   1907    ,   15517   ,0 };
            const std::uint32_t dim2668Kuo3Init[]   =   {   1   ,   3   ,   7   ,   1   ,   3   ,   1   ,   95  ,   105 ,   333 ,   11  ,   1709    ,   2783    ,   3011    ,   5579    ,   14939   ,0 };
            const std::uint32_t dim2669Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   5   ,   33  ,   67  ,   103 ,   71  ,   707 ,   325 ,   315 ,   567 ,   11969   ,   23071   ,0 };
            const std::uint32_t dim2670Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   5   ,   61  ,   47  ,   131 ,   413 ,   507 ,   991 ,   27  ,   3873    ,   13151   ,   4115    ,0 };
            const std::uint32_t dim2671Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   9   ,   31  ,   103 ,   91  ,   297 ,   419 ,   1251    ,   1155    ,   5539    ,   10347   ,   26811   ,0 };
            const std::uint32_t dim2672Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   15  ,   37  ,   37  ,   167 ,   307 ,   397 ,   561 ,   2431    ,   6219    ,   3401    ,   23551   ,0 };
            const std::uint32_t dim2673Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   29  ,   11  ,   33  ,   7   ,   177 ,   625 ,   853 ,   2317    ,   7371    ,   7435    ,   18135   ,0 };
            const std::uint32_t dim2674Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   29  ,   7   ,   107 ,   97  ,   3   ,   97  ,   901 ,   717 ,   1911    ,   3877    ,   29583   ,0 };
            const std::uint32_t dim2675Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   27  ,   33  ,   33  ,   105 ,   285 ,   3   ,   1427    ,   13  ,   3941    ,   299 ,   12025   ,0 };
            const std::uint32_t dim2676Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   13  ,   57  ,   81  ,   131 ,   327 ,   587 ,   445 ,   1313    ,   4797    ,   8587    ,   5915    ,0 };
            const std::uint32_t dim2677Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   21  ,   29  ,   43  ,   89  ,   499 ,   893 ,   501 ,   2409    ,   3145    ,   9435    ,   10831   ,0 };
            const std::uint32_t dim2678Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   25  ,   21  ,   23  ,   211 ,   37  ,   993 ,   199 ,   3791    ,   291 ,   465 ,   32513   ,0 };
            const std::uint32_t dim2679Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   15  ,   53  ,   123 ,   91  ,   407 ,   925 ,   1125    ,   927 ,   6793    ,   1905    ,   27477   ,0 };
            const std::uint32_t dim2680Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   27  ,   51  ,   1   ,   77  ,   5   ,   273 ,   1363    ,   3835    ,   1627    ,   14925   ,   9431    ,0 };
            const std::uint32_t dim2681Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   29  ,   47  ,   47  ,   79  ,   305 ,   655 ,   1171    ,   899 ,   95  ,   9413    ,   14371   ,0 };
            const std::uint32_t dim2682Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   31  ,   45  ,   5   ,   211 ,   331 ,   677 ,   1045    ,   929 ,   975 ,   2377    ,   15407   ,0 };
            const std::uint32_t dim2683Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   21  ,   59  ,   61  ,   111 ,   449 ,   641 ,   597 ,   4023    ,   6333    ,   4439    ,   605 ,0 };
            const std::uint32_t dim2684Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   29  ,   7   ,   89  ,   21  ,   373 ,   311 ,   433 ,   1091    ,   4871    ,   8951    ,   22591   ,0 };
            const std::uint32_t dim2685Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   27  ,   17  ,   81  ,   77  ,   119 ,   1005    ,   873 ,   2299    ,   6919    ,   657 ,   12479   ,0 };
            const std::uint32_t dim2686Kuo3Init[]   =   {   1   ,   3   ,   3   ,   5   ,   29  ,   41  ,   31  ,   133 ,   411 ,   655 ,   1753    ,   1365    ,   1807    ,   15975   ,   23783   ,0 };
            const std::uint32_t dim2687Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   21  ,   11  ,   79  ,   65  ,   149 ,   121 ,   1393    ,   983 ,   885 ,   6991    ,   14943   ,0 };
            const std::uint32_t dim2688Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   17  ,   39  ,   123 ,   35  ,   101 ,   363 ,   1991    ,   3309    ,   2117    ,   16229   ,   3017    ,0 };
            const std::uint32_t dim2689Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   19  ,   61  ,   41  ,   201 ,   267 ,   985 ,   1635    ,   2681    ,   883 ,   13343   ,   22061   ,0 };
            const std::uint32_t dim2690Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   9   ,   13  ,   15  ,   139 ,   25  ,   989 ,   1817    ,   867 ,   5913    ,   16197   ,   7521    ,0 };
            const std::uint32_t dim2691Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   11  ,   29  ,   49  ,   75  ,   135 ,   705 ,   315 ,   2769    ,   3539    ,   13655   ,   11443   ,0 };
            const std::uint32_t dim2692Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   25  ,   9   ,   53  ,   81  ,   217 ,   391 ,   1789    ,   3837    ,   1191    ,   12359   ,   21831   ,0 };
            const std::uint32_t dim2693Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   3   ,   39  ,   1   ,   81  ,   367 ,   893 ,   1661    ,   3693    ,   9   ,   4061    ,   15321   ,0 };
            const std::uint32_t dim2694Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   27  ,   21  ,   11  ,   23  ,   287 ,   901 ,   1695    ,   469 ,   1993    ,   11435   ,   12637   ,0 };
            const std::uint32_t dim2695Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   21  ,   25  ,   113 ,   161 ,   361 ,   583 ,   2023    ,   831 ,   7161    ,   5125    ,   21097   ,0 };
            const std::uint32_t dim2696Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   11  ,   29  ,   21  ,   221 ,   255 ,   255 ,   693 ,   701 ,   989 ,   10323   ,   3165    ,0 };
            const std::uint32_t dim2697Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   5   ,   27  ,   107 ,   213 ,   85  ,   325 ,   1359    ,   735 ,   161 ,   11505   ,   24007   ,0 };
            const std::uint32_t dim2698Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   1   ,   47  ,   17  ,   241 ,   53  ,   563 ,   635 ,   3159    ,   3231    ,   12167   ,   221 ,0 };
            const std::uint32_t dim2699Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   21  ,   51  ,   15  ,   1   ,   491 ,   283 ,   1933    ,   1455    ,   6921    ,   10547   ,   29725   ,0 };
            const std::uint32_t dim2700Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   31  ,   43  ,   123 ,   103 ,   291 ,   479 ,   1207    ,   1703    ,   5591    ,   6555    ,   37  ,0 };
            const std::uint32_t dim2701Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   13  ,   53  ,   29  ,   155 ,   101 ,   651 ,   423 ,   2705    ,   6469    ,   13795   ,   9903    ,0 };
            const std::uint32_t dim2702Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   23  ,   27  ,   39  ,   181 ,   47  ,   297 ,   353 ,   327 ,   6723    ,   5981    ,   8333    ,0 };
            const std::uint32_t dim2703Kuo3Init[]   =   {   1   ,   1   ,   1   ,   1   ,   29  ,   41  ,   55  ,   177 ,   459 ,   933 ,   675 ,   177 ,   1459    ,   6371    ,   8301    ,0 };
            const std::uint32_t dim2704Kuo3Init[]   =   {   1   ,   3   ,   5   ,   1   ,   11  ,   29  ,   45  ,   119 ,   145 ,   793 ,   1771    ,   2295    ,   2349    ,   13825   ,   10389   ,0 };
            const std::uint32_t dim2705Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   13  ,   9   ,   85  ,   201 ,   509 ,   285 ,   1613    ,   2571    ,   3925    ,   4303    ,   14625   ,0 };
            const std::uint32_t dim2706Kuo3Init[]   =   {   1   ,   3   ,   5   ,   1   ,   17  ,   53  ,   89  ,   93  ,   401 ,   429 ,   865 ,   679 ,   1995    ,   13567   ,   32275   ,0 };
            const std::uint32_t dim2707Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   17  ,   23  ,   97  ,   39  ,   309 ,   67  ,   1445    ,   101 ,   4305    ,   12195   ,   18559   ,0 };
            const std::uint32_t dim2708Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   27  ,   35  ,   119 ,   67  ,   411 ,   461 ,   1149    ,   1651    ,   6149    ,   1543    ,   19747   ,0 };
            const std::uint32_t dim2709Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   23  ,   51  ,   25  ,   109 ,   283 ,   331 ,   1651    ,   691 ,   7953    ,   1979    ,   7425    ,0 };
            const std::uint32_t dim2710Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   31  ,   63  ,   113 ,   191 ,   481 ,   467 ,   589 ,   2375    ,   4619    ,   3745    ,   4343    ,0 };
            const std::uint32_t dim2711Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   27  ,   35  ,   61  ,   29  ,   115 ,   909 ,   107 ,   815 ,   1579    ,   8373    ,   32657   ,0 };
            const std::uint32_t dim2712Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   21  ,   45  ,   101 ,   27  ,   229 ,   1011    ,   497 ,   841 ,   7653    ,   5429    ,   17329   ,0 };
            const std::uint32_t dim2713Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   27  ,   5   ,   105 ,   171 ,   75  ,   45  ,   865 ,   4061    ,   7947    ,   4979    ,   20577   ,0 };
            const std::uint32_t dim2714Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   9   ,   45  ,   67  ,   221 ,   27  ,   31  ,   187 ,   2063    ,   4733    ,   10087   ,   23091   ,0 };
            const std::uint32_t dim2715Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   3   ,   51  ,   79  ,   117 ,   379 ,   687 ,   721 ,   3645    ,   6639    ,   14161   ,   16187   ,0 };
            const std::uint32_t dim2716Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   5   ,   15  ,   117 ,   177 ,   163 ,   577 ,   279 ,   1549    ,   2397    ,   8099    ,   2125    ,0 };
            const std::uint32_t dim2717Kuo3Init[]   =   {   1   ,   3   ,   3   ,   5   ,   17  ,   11  ,   121 ,   89  ,   313 ,   541 ,   47  ,   1993    ,   3313    ,   159 ,   3761    ,0 };
            const std::uint32_t dim2718Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   11  ,   43  ,   7   ,   165 ,   283 ,   7   ,   1275    ,   3391    ,   417 ,   11697   ,   22357   ,0 };
            const std::uint32_t dim2719Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   27  ,   47  ,   65  ,   51  ,   83  ,   223 ,   2015    ,   2939    ,   6121    ,   3873    ,   27573   ,0 };
            const std::uint32_t dim2720Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   19  ,   55  ,   115 ,   105 ,   345 ,   393 ,   1609    ,   3131    ,   109 ,   11443   ,   23475   ,0 };
            const std::uint32_t dim2721Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   21  ,   61  ,   39  ,   69  ,   381 ,   279 ,   1473    ,   1239    ,   661 ,   781 ,   21603   ,0 };
            const std::uint32_t dim2722Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   3   ,   7   ,   7   ,   129 ,   229 ,   233 ,   77  ,   845 ,   7871    ,   3013    ,   14469   ,0 };
            const std::uint32_t dim2723Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   17  ,   9   ,   3   ,   17  ,   375 ,   27  ,   473 ,   945 ,   4111    ,   7645    ,   7899    ,0 };
            const std::uint32_t dim2724Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   25  ,   31  ,   71  ,   157 ,   269 ,   1003    ,   1875    ,   3573    ,   8121    ,   14073   ,   26019   ,0 };
            const std::uint32_t dim2725Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   17  ,   25  ,   57  ,   1   ,   63  ,   425 ,   507 ,   2341    ,   4891    ,   12643   ,   32083   ,0 };
            const std::uint32_t dim2726Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   23  ,   47  ,   55  ,   145 ,   269 ,   417 ,   559 ,   2065    ,   5801    ,   13751   ,   15617   ,0 };
            const std::uint32_t dim2727Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   3   ,   39  ,   45  ,   143 ,   131 ,   713 ,   1549    ,   779 ,   1427    ,   10819   ,   10629   ,0 };
            const std::uint32_t dim2728Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   13  ,   61  ,   99  ,   145 ,   293 ,   393 ,   1181    ,   4011    ,   6843    ,   12667   ,   21301   ,0 };
            const std::uint32_t dim2729Kuo3Init[]   =   {   1   ,   3   ,   7   ,   1   ,   19  ,   29  ,   105 ,   109 ,   391 ,   569 ,   1933    ,   1799    ,   8045    ,   509 ,   13251   ,0 };
            const std::uint32_t dim2730Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   21  ,   55  ,   123 ,   239 ,   65  ,   891 ,   635 ,   3107    ,   2701    ,   9041    ,   28249   ,0 };
            const std::uint32_t dim2731Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   1   ,   11  ,   9   ,   49  ,   51  ,   243 ,   51  ,   3   ,   6813    ,   14995   ,   27065   ,0 };
            const std::uint32_t dim2732Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   29  ,   35  ,   107 ,   19  ,   415 ,   273 ,   881 ,   49  ,   3267    ,   4791    ,   9609    ,0 };
            const std::uint32_t dim2733Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   5   ,   39  ,   59  ,   127 ,   267 ,   215 ,   375 ,   133 ,   8057    ,   8497    ,   23595   ,0 };
            const std::uint32_t dim2734Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   1   ,   41  ,   81  ,   199 ,   287 ,   907 ,   743 ,   2875    ,   3873    ,   2851    ,   7385    ,0 };
            const std::uint32_t dim2735Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   13  ,   49  ,   25  ,   43  ,   105 ,   511 ,   1483    ,   3277    ,   7561    ,   7211    ,   20671   ,0 };
            const std::uint32_t dim2736Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   19  ,   21  ,   37  ,   87  ,   439 ,   69  ,   1145    ,   141 ,   6187    ,   6329    ,   26923   ,0 };
            const std::uint32_t dim2737Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   13  ,   59  ,   123 ,   155 ,   189 ,   803 ,   1807    ,   363 ,   2239    ,   547 ,   30801   ,0 };
            const std::uint32_t dim2738Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   1   ,   61  ,   93  ,   25  ,   205 ,   275 ,   1591    ,   1575    ,   3951    ,   12313   ,   9399    ,0 };
            const std::uint32_t dim2739Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   11  ,   49  ,   43  ,   241 ,   435 ,   515 ,   283 ,   3667    ,   2089    ,   4755    ,   19427   ,0 };
            const std::uint32_t dim2740Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   19  ,   57  ,   5   ,   23  ,   271 ,   113 ,   481 ,   2619    ,   4507    ,   15191   ,   2227    ,0 };
            const std::uint32_t dim2741Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   11  ,   15  ,   49  ,   51  ,   121 ,   463 ,   1015    ,   791 ,   3993    ,   14311   ,   8723    ,0 };
            const std::uint32_t dim2742Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   17  ,   19  ,   55  ,   137 ,   211 ,   307 ,   1647    ,   2719    ,   5231    ,   13005   ,   17527   ,0 };
            const std::uint32_t dim2743Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   1   ,   25  ,   5   ,   119 ,   271 ,   611 ,   1799    ,   3149    ,   2159    ,   9147    ,   30765   ,0 };
            const std::uint32_t dim2744Kuo3Init[]   =   {   1   ,   1   ,   1   ,   15  ,   5   ,   19  ,   75  ,   137 ,   483 ,   457 ,   1913    ,   31  ,   9   ,   8333    ,   3315    ,0 };
            const std::uint32_t dim2745Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   5   ,   11  ,   95  ,   83  ,   269 ,   105 ,   67  ,   2021    ,   6423    ,   10315   ,   28017   ,0 };
            const std::uint32_t dim2746Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   27  ,   49  ,   7   ,   45  ,   297 ,   899 ,   665 ,   2473    ,   2863    ,   2171    ,   10693   ,0 };
            const std::uint32_t dim2747Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   25  ,   17  ,   41  ,   155 ,   101 ,   355 ,   197 ,   3853    ,   2381    ,   9663    ,   25187   ,0 };
            const std::uint32_t dim2748Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   15  ,   53  ,   119 ,   233 ,   79  ,   545 ,   1203    ,   1535    ,   3563    ,   2469    ,   29449   ,0 };
            const std::uint32_t dim2749Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   27  ,   57  ,   113 ,   189 ,   3   ,   253 ,   1743    ,   3735    ,   5257    ,   10521   ,   18679   ,0 };
            const std::uint32_t dim2750Kuo3Init[]   =   {   1   ,   3   ,   7   ,   1   ,   5   ,   29  ,   117 ,   207 ,   101 ,   293 ,   615 ,   401 ,   7201    ,   11451   ,   13705   ,0 };
            const std::uint32_t dim2751Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   13  ,   59  ,   55  ,   101 ,   253 ,   801 ,   1947    ,   3509    ,   655 ,   5555    ,   15517   ,0 };
            const std::uint32_t dim2752Kuo3Init[]   =   {   1   ,   3   ,   3   ,   5   ,   3   ,   19  ,   31  ,   93  ,   3   ,   1009    ,   1535    ,   261 ,   2259    ,   9835    ,   5797    ,0 };
            const std::uint32_t dim2753Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   9   ,   53  ,   1   ,   213 ,   123 ,   271 ,   1137    ,   11  ,   6331    ,   9907    ,   13219   ,0 };
            const std::uint32_t dim2754Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   17  ,   9   ,   83  ,   153 ,   231 ,   3   ,   1179    ,   735 ,   553 ,   10627   ,   4643    ,0 };
            const std::uint32_t dim2755Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   25  ,   21  ,   127 ,   85  ,   17  ,   541 ,   535 ,   1041    ,   5071    ,   15451   ,   909 ,0 };
            const std::uint32_t dim2756Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   29  ,   31  ,   75  ,   91  ,   67  ,   253 ,   971 ,   327 ,   7491    ,   7627    ,   31857   ,0 };
            const std::uint32_t dim2757Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   23  ,   19  ,   79  ,   197 ,   25  ,   83  ,   1427    ,   2023    ,   1861    ,   1617    ,   10129   ,0 };
            const std::uint32_t dim2758Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   27  ,   55  ,   113 ,   191 ,   119 ,   301 ,   1243    ,   333 ,   7609    ,   4875    ,   19035   ,0 };
            const std::uint32_t dim2759Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   7   ,   51  ,   59  ,   157 ,   21  ,   697 ,   171 ,   2857    ,   3875    ,   15413   ,   28749   ,0 };
            const std::uint32_t dim2760Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   13  ,   45  ,   49  ,   161 ,   389 ,   715 ,   991 ,   839 ,   2655    ,   11399   ,   5261    ,0 };
            const std::uint32_t dim2761Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   17  ,   51  ,   87  ,   75  ,   65  ,   67  ,   1283    ,   1991    ,   7735    ,   9063    ,   313 ,0 };
            const std::uint32_t dim2762Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   29  ,   39  ,   109 ,   159 ,   63  ,   103 ,   587 ,   1941    ,   3883    ,   1119    ,   4303    ,0 };
            const std::uint32_t dim2763Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   15  ,   27  ,   69  ,   49  ,   417 ,   281 ,   1207    ,   289 ,   1873    ,   12287   ,   19321   ,0 };
            const std::uint32_t dim2764Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   9   ,   57  ,   77  ,   81  ,   267 ,   45  ,   835 ,   671 ,   4569    ,   12713   ,   32657   ,0 };
            const std::uint32_t dim2765Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   25  ,   25  ,   73  ,   165 ,   413 ,   845 ,   529 ,   2987    ,   2051    ,   6155    ,   29133   ,0 };
            const std::uint32_t dim2766Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   3   ,   41  ,   107 ,   85  ,   429 ,   323 ,   1509    ,   649 ,   5897    ,   10309   ,   30927   ,0 };
            const std::uint32_t dim2767Kuo3Init[]   =   {   1   ,   1   ,   7   ,   9   ,   1   ,   1   ,   105 ,   213 ,   479 ,   755 ,   1863    ,   1429    ,   5927    ,   9923    ,   18531   ,0 };
            const std::uint32_t dim2768Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   9   ,   13  ,   45  ,   105 ,   133 ,   117 ,   1837    ,   3019    ,   3809    ,   8713    ,   19865   ,0 };
            const std::uint32_t dim2769Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   13  ,   7   ,   31  ,   175 ,   209 ,   313 ,   1095    ,   1093    ,   2707    ,   11955   ,   11137   ,0 };
            const std::uint32_t dim2770Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   9   ,   31  ,   79  ,   25  ,   205 ,   309 ,   1977    ,   1207    ,   5629    ,   6869    ,   24269   ,0 };
            const std::uint32_t dim2771Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   5   ,   43  ,   31  ,   81  ,   251 ,   569 ,   2033    ,   299 ,   345 ,   7437    ,   2183    ,0 };
            const std::uint32_t dim2772Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   23  ,   17  ,   107 ,   143 ,   31  ,   349 ,   1501    ,   2487    ,   6911    ,   12591   ,   17599   ,0 };
            const std::uint32_t dim2773Kuo3Init[]   =   {   1   ,   1   ,   7   ,   9   ,   5   ,   13  ,   99  ,   145 ,   141 ,   947 ,   1587    ,   3691    ,   6029    ,   13153   ,   13971   ,0 };
            const std::uint32_t dim2774Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   21  ,   37  ,   87  ,   19  ,   195 ,   263 ,   85  ,   3285    ,   1733    ,   11057   ,   6293    ,0 };
            const std::uint32_t dim2775Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   31  ,   29  ,   97  ,   81  ,   479 ,   879 ,   2011    ,   1041    ,   8141    ,   14891   ,   175 ,0 };
            const std::uint32_t dim2776Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   13  ,   35  ,   61  ,   219 ,   103 ,   161 ,   1187    ,   3925    ,   2041    ,   2609    ,   30195   ,0 };
            const std::uint32_t dim2777Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   15  ,   43  ,   31  ,   163 ,   401 ,   451 ,   1881    ,   1307    ,   4201    ,   6821    ,   3717    ,0 };
            const std::uint32_t dim2778Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   5   ,   3   ,   85  ,   149 ,   47  ,   1003    ,   405 ,   1801    ,   6695    ,   897 ,   28005   ,0 };
            const std::uint32_t dim2779Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   19  ,   37  ,   81  ,   41  ,   315 ,   729 ,   303 ,   501 ,   7483    ,   10841   ,   12649   ,0 };
            const std::uint32_t dim2780Kuo3Init[]   =   {   1   ,   1   ,   1   ,   1   ,   1   ,   51  ,   121 ,   129 ,   49  ,   511 ,   719 ,   2235    ,   827 ,   9331    ,   22551   ,0 };
            const std::uint32_t dim2781Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   21  ,   41  ,   47  ,   17  ,   157 ,   771 ,   867 ,   3685    ,   2387    ,   7409    ,   13889   ,0 };
            const std::uint32_t dim2782Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   11  ,   53  ,   119 ,   19  ,   289 ,   337 ,   551 ,   2529    ,   321 ,   2599    ,   11153   ,0 };
            const std::uint32_t dim2783Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   7   ,   33  ,   19  ,   7   ,   459 ,   729 ,   281 ,   947 ,   5469    ,   7497    ,   22893   ,0 };
            const std::uint32_t dim2784Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   11  ,   41  ,   91  ,   217 ,   195 ,   483 ,   1659    ,   1619    ,   4201    ,   15825   ,   3357    ,0 };
            const std::uint32_t dim2785Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   9   ,   29  ,   87  ,   153 ,   175 ,   967 ,   75  ,   385 ,   719 ,   12269   ,   28729   ,0 };
            const std::uint32_t dim2786Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   13  ,   21  ,   115 ,   55  ,   303 ,   853 ,   1735    ,   3763    ,   31  ,   2547    ,   9735    ,0 };
            const std::uint32_t dim2787Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   17  ,   25  ,   109 ,   207 ,   465 ,   627 ,   1171    ,   557 ,   2577    ,   13873   ,   30945   ,0 };
            const std::uint32_t dim2788Kuo3Init[]   =   {   1   ,   1   ,   1   ,   1   ,   27  ,   25  ,   65  ,   131 ,   373 ,   297 ,   1561    ,   2481    ,   3491    ,   3175    ,   12527   ,0 };
            const std::uint32_t dim2789Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   13  ,   33  ,   81  ,   81  ,   337 ,   249 ,   739 ,   1451    ,   4479    ,   10253   ,   3585    ,0 };
            const std::uint32_t dim2790Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   3   ,   9   ,   11  ,   109 ,   261 ,   663 ,   507 ,   897 ,   4081    ,   12393   ,   21621   ,0 };
            const std::uint32_t dim2791Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   27  ,   35  ,   13  ,   191 ,   433 ,   111 ,   1567    ,   851 ,   6303    ,   2411    ,   25985   ,0 };
            const std::uint32_t dim2792Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   7   ,   41  ,   91  ,   217 ,   203 ,   821 ,   883 ,   1549    ,   37  ,   1837    ,   19549   ,0 };
            const std::uint32_t dim2793Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   23  ,   49  ,   27  ,   81  ,   475 ,   251 ,   985 ,   2527    ,   3857    ,   4579    ,   30231   ,0 };
            const std::uint32_t dim2794Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   7   ,   33  ,   71  ,   207 ,   179 ,   77  ,   743 ,   375 ,   5649    ,   3165    ,   25063   ,0 };
            const std::uint32_t dim2795Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   25  ,   47  ,   21  ,   109 ,   375 ,   525 ,   671 ,   1117    ,   5663    ,   9835    ,   19675   ,0 };
            const std::uint32_t dim2796Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   19  ,   31  ,   9   ,   167 ,   501 ,   477 ,   1015    ,   109 ,   6233    ,   14131   ,   30015   ,0 };
            const std::uint32_t dim2797Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   25  ,   9   ,   91  ,   121 ,   373 ,   511 ,   1925    ,   3609    ,   7681    ,   7321    ,   19931   ,0 };
            const std::uint32_t dim2798Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   23  ,   23  ,   63  ,   225 ,   511 ,   407 ,   573 ,   587 ,   6877    ,   4747    ,   31503   ,0 };
            const std::uint32_t dim2799Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   7   ,   11  ,   61  ,   119 ,   149 ,   119 ,   1497    ,   165 ,   5833    ,   14727   ,   21075   ,0 };
            const std::uint32_t dim2800Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   23  ,   27  ,   113 ,   99  ,   97  ,   385 ,   563 ,   1745    ,   4321    ,   2201    ,   5707    ,0 };
            const std::uint32_t dim2801Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   5   ,   51  ,   49  ,   213 ,   111 ,   587 ,   1433    ,   1473    ,   4673    ,   369 ,   31405   ,0 };
            const std::uint32_t dim2802Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   25  ,   49  ,   67  ,   163 ,   109 ,   679 ,   975 ,   3711    ,   6627    ,   2273    ,   13451   ,0 };
            const std::uint32_t dim2803Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   9   ,   3   ,   75  ,   123 ,   71  ,   181 ,   1007    ,   2459    ,   5671    ,   2805    ,   15839   ,0 };
            const std::uint32_t dim2804Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   7   ,   51  ,   49  ,   19  ,   89  ,   209 ,   1097    ,   359 ,   2487    ,   12969   ,   24243   ,0 };
            const std::uint32_t dim2805Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   1   ,   47  ,   61  ,   65  ,   161 ,   801 ,   511 ,   3711    ,   237 ,   14741   ,   14239   ,0 };
            const std::uint32_t dim2806Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   31  ,   25  ,   11  ,   175 ,   151 ,   79  ,   1749    ,   751 ,   6129    ,   12139   ,   30837   ,0 };
            const std::uint32_t dim2807Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   19  ,   13  ,   71  ,   75  ,   479 ,   211 ,   395 ,   1935    ,   7949    ,   12049   ,   31539   ,0 };
            const std::uint32_t dim2808Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   19  ,   9   ,   93  ,   79  ,   69  ,   1001    ,   673 ,   1963    ,   8047    ,   8023    ,   8199    ,0 };
            const std::uint32_t dim2809Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   11  ,   9   ,   107 ,   39  ,   319 ,   835 ,   1297    ,   1667    ,   393 ,   5619    ,   15019   ,0 };
            const std::uint32_t dim2810Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   17  ,   25  ,   71  ,   227 ,   219 ,   455 ,   29  ,   1503    ,   4207    ,   11523   ,   13077   ,0 };
            const std::uint32_t dim2811Kuo3Init[]   =   {   1   ,   3   ,   7   ,   1   ,   11  ,   11  ,   91  ,   203 ,   483 ,   959 ,   911 ,   979 ,   4327    ,   15113   ,   23415   ,0 };
            const std::uint32_t dim2812Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   5   ,   63  ,   57  ,   253 ,   369 ,   609 ,   1831    ,   2895    ,   1025    ,   2567    ,   14017   ,0 };
            const std::uint32_t dim2813Kuo3Init[]   =   {   1   ,   3   ,   5   ,   1   ,   19  ,   39  ,   107 ,   169 ,   107 ,   863 ,   591 ,   4077    ,   7441    ,   3201    ,   269 ,0 };
            const std::uint32_t dim2814Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   7   ,   45  ,   19  ,   103 ,   119 ,   539 ,   9   ,   2909    ,   8135    ,   7913    ,   1403    ,0 };
            const std::uint32_t dim2815Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   17  ,   39  ,   125 ,   57  ,   417 ,   543 ,   1067    ,   3807    ,   397 ,   11947   ,   7655    ,0 };
            const std::uint32_t dim2816Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   31  ,   49  ,   65  ,   23  ,   197 ,   777 ,   1669    ,   1373    ,   773 ,   6947    ,   2835    ,0 };
            const std::uint32_t dim2817Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   25  ,   45  ,   115 ,   31  ,   351 ,   203 ,   1791    ,   2931    ,   7127    ,   12117   ,   10781   ,0 };
            const std::uint32_t dim2818Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   21  ,   61  ,   47  ,   59  ,   393 ,   621 ,   811 ,   2321    ,   7801    ,   2255    ,   13513   ,0 };
            const std::uint32_t dim2819Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   27  ,   15  ,   85  ,   53  ,   379 ,   597 ,   19  ,   267 ,   5511    ,   8167    ,   14843   ,0 };
            const std::uint32_t dim2820Kuo3Init[]   =   {   1   ,   1   ,   7   ,   9   ,   19  ,   11  ,   43  ,   101 ,   309 ,   125 ,   2023    ,   689 ,   589 ,   3621    ,   10593   ,0 };
            const std::uint32_t dim2821Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   25  ,   57  ,   55  ,   57  ,   111 ,   743 ,   1773    ,   2223    ,   6567    ,   7401    ,   14843   ,0 };
            const std::uint32_t dim2822Kuo3Init[]   =   {   1   ,   3   ,   1   ,   11  ,   17  ,   43  ,   1   ,   11  ,   155 ,   287 ,   519 ,   4051    ,   311 ,   10079   ,   29753   ,0 };
            const std::uint32_t dim2823Kuo3Init[]   =   {   1   ,   3   ,   7   ,   1   ,   15  ,   33  ,   47  ,   117 ,   343 ,   667 ,   1489    ,   1985    ,   5105    ,   11887   ,   29117   ,0 };
            const std::uint32_t dim2824Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   9   ,   33  ,   115 ,   211 ,   7   ,   391 ,   475 ,   1843    ,   3277    ,   11067   ,   12857   ,0 };
            const std::uint32_t dim2825Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   31  ,   11  ,   17  ,   147 ,   129 ,   875 ,   845 ,   2999    ,   6395    ,   361 ,   7395    ,0 };
            const std::uint32_t dim2826Kuo3Init[]   =   {   1   ,   3   ,   5   ,   1   ,   27  ,   17  ,   55  ,   115 ,   35  ,   989 ,   153 ,   77  ,   5713    ,   14653   ,   587 ,0 };
            const std::uint32_t dim2827Kuo3Init[]   =   {   1   ,   3   ,   3   ,   5   ,   3   ,   37  ,   107 ,   57  ,   201 ,   631 ,   1549    ,   3709    ,   3615    ,   12567   ,   21729   ,0 };
            const std::uint32_t dim2828Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   15  ,   19  ,   21  ,   205 ,   253 ,   431 ,   915 ,   1057    ,   359 ,   431 ,   31417   ,0 };
            const std::uint32_t dim2829Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   11  ,   47  ,   107 ,   101 ,   461 ,   805 ,   1569    ,   1215    ,   765 ,   1547    ,   32531   ,0 };
            const std::uint32_t dim2830Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   21  ,   55  ,   61  ,   171 ,   75  ,   337 ,   231 ,   1925    ,   7415    ,   1073    ,   17519   ,0 };
            const std::uint32_t dim2831Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   5   ,   23  ,   39  ,   119 ,   399 ,   265 ,   601 ,   3487    ,   1129    ,   10731   ,   14795   ,0 };
            const std::uint32_t dim2832Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   11  ,   57  ,   33  ,   99  ,   283 ,   581 ,   1791    ,   1723    ,   411 ,   5779    ,   8989    ,0 };
            const std::uint32_t dim2833Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   19  ,   33  ,   81  ,   245 ,   375 ,   763 ,   77  ,   175 ,   5417    ,   12525   ,   18197   ,0 };
            const std::uint32_t dim2834Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   29  ,   31  ,   59  ,   207 ,   19  ,   369 ,   1449    ,   165 ,   6115    ,   15417   ,   14227   ,0 };
            const std::uint32_t dim2835Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   7   ,   15  ,   109 ,   171 ,   179 ,   541 ,   1907    ,   2545    ,   5633    ,   8039    ,   23495   ,0 };
            const std::uint32_t dim2836Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   5   ,   5   ,   51  ,   5   ,   347 ,   351 ,   177 ,   965 ,   6583    ,   3631    ,   26493   ,0 };
            const std::uint32_t dim2837Kuo3Init[]   =   {   1   ,   1   ,   1   ,   15  ,   21  ,   55  ,   101 ,   137 ,   165 ,   947 ,   1149    ,   2615    ,   3709    ,   8231    ,   2033    ,0 };
            const std::uint32_t dim2838Kuo3Init[]   =   {   1   ,   3   ,   5   ,   1   ,   1   ,   11  ,   29  ,   5   ,   353 ,   675 ,   2045    ,   2111    ,   2477    ,   7803    ,   18925   ,0 };
            const std::uint32_t dim2839Kuo3Init[]   =   {   1   ,   3   ,   3   ,   7   ,   11  ,   5   ,   43  ,   241 ,   103 ,   87  ,   1841    ,   841 ,   277 ,   7647    ,   6953    ,0 };
            const std::uint32_t dim2840Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   23  ,   15  ,   77  ,   199 ,   457 ,   183 ,   1719    ,   4077    ,   2751    ,   6285    ,   2741    ,0 };
            const std::uint32_t dim2841Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   11  ,   7   ,   119 ,   207 ,   89  ,   415 ,   1501    ,   2333    ,   2155    ,   13559   ,   9701    ,0 };
            const std::uint32_t dim2842Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   9   ,   29  ,   119 ,   171 ,   259 ,   849 ,   493 ,   3103    ,   2559    ,   4323    ,   8993    ,0 };
            const std::uint32_t dim2843Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   5   ,   3   ,   35  ,   29  ,   177 ,   19  ,   565 ,   2111    ,   4781    ,   13603   ,   10759   ,0 };
            const std::uint32_t dim2844Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   7   ,   41  ,   45  ,   181 ,   55  ,   575 ,   685 ,   2407    ,   3499    ,   10073   ,   5717    ,0 };
            const std::uint32_t dim2845Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   25  ,   31  ,   97  ,   247 ,   411 ,   663 ,   413 ,   771 ,   2325    ,   4849    ,   18605   ,0 };
            const std::uint32_t dim2846Kuo3Init[]   =   {   1   ,   1   ,   1   ,   1   ,   11  ,   55  ,   77  ,   183 ,   131 ,   873 ,   315 ,   3403    ,   7219    ,   5419    ,   9943    ,0 };
            const std::uint32_t dim2847Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   17  ,   49  ,   125 ,   1   ,   379 ,   995 ,   1911    ,   9   ,   1201    ,   14599   ,   3237    ,0 };
            const std::uint32_t dim2848Kuo3Init[]   =   {   1   ,   1   ,   5   ,   7   ,   5   ,   47  ,   25  ,   47  ,   93  ,   1009    ,   361 ,   3111    ,   6221    ,   15799   ,   11049   ,0 };
            const std::uint32_t dim2849Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   31  ,   41  ,   27  ,   119 ,   463 ,   357 ,   1399    ,   3023    ,   8145    ,   7233    ,   10461   ,0 };
            const std::uint32_t dim2850Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   25  ,   1   ,   89  ,   167 ,   13  ,   477 ,   989 ,   1109    ,   3279    ,   1893    ,   22091   ,0 };
            const std::uint32_t dim2851Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   27  ,   27  ,   127 ,   85  ,   135 ,   975 ,   557 ,   2247    ,   5675    ,   7397    ,   28829   ,0 };
            const std::uint32_t dim2852Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   5   ,   57  ,   87  ,   115 ,   399 ,   189 ,   497 ,   2525    ,   323 ,   2849    ,   1539    ,0 };
            const std::uint32_t dim2853Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   31  ,   57  ,   49  ,   13  ,   151 ,   483 ,   1117    ,   2177    ,   4011    ,   2467    ,   5465    ,0 };
            const std::uint32_t dim2854Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   17  ,   49  ,   31  ,   167 ,   385 ,   183 ,   225 ,   465 ,   2099    ,   475 ,   28001   ,0 };
            const std::uint32_t dim2855Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   23  ,   39  ,   37  ,   63  ,   419 ,   95  ,   1217    ,   1147    ,   7599    ,   985 ,   23455   ,0 };
            const std::uint32_t dim2856Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   15  ,   53  ,   17  ,   221 ,   441 ,   303 ,   1595    ,   3731    ,   7833    ,   14649   ,   30843   ,0 };
            const std::uint32_t dim2857Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   13  ,   63  ,   29  ,   137 ,   263 ,   79  ,   591 ,   679 ,   4681    ,   4121    ,   22733   ,0 };
            const std::uint32_t dim2858Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   27  ,   31  ,   97  ,   191 ,   295 ,   601 ,   1353    ,   3817    ,   2305    ,   427 ,   5985    ,0 };
            const std::uint32_t dim2859Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   29  ,   27  ,   27  ,   249 ,   441 ,   415 ,   489 ,   779 ,   5927    ,   10569   ,   7539    ,0 };
            const std::uint32_t dim2860Kuo3Init[]   =   {   1   ,   3   ,   7   ,   1   ,   1   ,   59  ,   21  ,   115 ,   25  ,   715 ,   697 ,   3585    ,   383 ,   8043    ,   21457   ,0 };
            const std::uint32_t dim2861Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   3   ,   37  ,   25  ,   239 ,   25  ,   213 ,   1449    ,   1975    ,   1805    ,   11867   ,   24163   ,0 };
            const std::uint32_t dim2862Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   9   ,   37  ,   95  ,   19  ,   105 ,   787 ,   249 ,   2501    ,   5073    ,   2677    ,   2871    ,0 };
            const std::uint32_t dim2863Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   25  ,   17  ,   59  ,   79  ,   467 ,   489 ,   1981    ,   169 ,   7713    ,   3035    ,   6135    ,0 };
            const std::uint32_t dim2864Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   21  ,   41  ,   75  ,   59  ,   495 ,   475 ,   803 ,   3117    ,   4999    ,   5153    ,   20541   ,0 };
            const std::uint32_t dim2865Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   21  ,   5   ,   43  ,   69  ,   167 ,   743 ,   1395    ,   3701    ,   1329    ,   12039   ,   26595   ,0 };
            const std::uint32_t dim2866Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   7   ,   51  ,   7   ,   191 ,   341 ,   561 ,   617 ,   803 ,   965 ,   7995    ,   7605    ,0 };
            const std::uint32_t dim2867Kuo3Init[]   =   {   1   ,   3   ,   5   ,   1   ,   25  ,   21  ,   21  ,   141 ,   461 ,   353 ,   1909    ,   1089    ,   4603    ,   7285    ,   30359   ,0 };
            const std::uint32_t dim2868Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   13  ,   17  ,   47  ,   173 ,   151 ,   1003    ,   1823    ,   1463    ,   6441    ,   8647    ,   8671    ,0 };
            const std::uint32_t dim2869Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   29  ,   29  ,   111 ,   237 ,   341 ,   693 ,   773 ,   637 ,   741 ,   7737    ,   12077   ,0 };
            const std::uint32_t dim2870Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   1   ,   27  ,   71  ,   177 ,   379 ,   289 ,   1659    ,   697 ,   4765    ,   15945   ,   24463   ,0 };
            const std::uint32_t dim2871Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   15  ,   13  ,   77  ,   59  ,   5   ,   483 ,   581 ,   2193    ,   7765    ,   14443   ,   21545   ,0 };
            const std::uint32_t dim2872Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   9   ,   17  ,   111 ,   13  ,   427 ,   405 ,   1765    ,   2029    ,   4989    ,   1995    ,   18581   ,0 };
            const std::uint32_t dim2873Kuo3Init[]   =   {   1   ,   1   ,   1   ,   1   ,   17  ,   15  ,   9   ,   43  ,   177 ,   277 ,   217 ,   1869    ,   2847    ,   11839   ,   5483    ,0 };
            const std::uint32_t dim2874Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   1   ,   61  ,   87  ,   211 ,   367 ,   317 ,   1681    ,   3913    ,   2635    ,   5095    ,   2993    ,0 };
            const std::uint32_t dim2875Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   13  ,   47  ,   123 ,   111 ,   139 ,   193 ,   1575    ,   3549    ,   2113    ,   2997    ,   2319    ,0 };
            const std::uint32_t dim2876Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   17  ,   29  ,   67  ,   195 ,   455 ,   137 ,   1159    ,   367 ,   469 ,   4663    ,   13811   ,0 };
            const std::uint32_t dim2877Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   21  ,   55  ,   27  ,   165 ,   483 ,   487 ,   1199    ,   2989    ,   3195    ,   8847    ,   12465   ,0 };
            const std::uint32_t dim2878Kuo3Init[]   =   {   1   ,   3   ,   3   ,   5   ,   13  ,   31  ,   5   ,   77  ,   283 ,   837 ,   827 ,   3477    ,   5555    ,   15411   ,   803 ,0 };
            const std::uint32_t dim2879Kuo3Init[]   =   {   1   ,   3   ,   5   ,   1   ,   5   ,   47  ,   23  ,   21  ,   255 ,   193 ,   67  ,   1489    ,   5785    ,   3247    ,   18425   ,0 };
            const std::uint32_t dim2880Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   3   ,   41  ,   1   ,   37  ,   281 ,   767 ,   419 ,   1067    ,   749 ,   4985    ,   18525   ,0 };
            const std::uint32_t dim2881Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   29  ,   47  ,   37  ,   195 ,   359 ,   517 ,   1809    ,   2111    ,   419 ,   1895    ,   17813   ,0 };
            const std::uint32_t dim2882Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   13  ,   61  ,   99  ,   183 ,   311 ,   515 ,   1359    ,   1077    ,   835 ,   12945   ,   27707   ,0 };
            const std::uint32_t dim2883Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   5   ,   25  ,   77  ,   7   ,   249 ,   325 ,   929 ,   3121    ,   4183    ,   9347    ,   1209    ,0 };
            const std::uint32_t dim2884Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   13  ,   59  ,   9   ,   251 ,   323 ,   479 ,   1791    ,   555 ,   2591    ,   417 ,   23821   ,0 };
            const std::uint32_t dim2885Kuo3Init[]   =   {   1   ,   3   ,   7   ,   1   ,   31  ,   25  ,   43  ,   167 ,   337 ,   321 ,   1223    ,   3693    ,   1945    ,   4937    ,   15613   ,0 };
            const std::uint32_t dim2886Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   23  ,   27  ,   71  ,   3   ,   249 ,   427 ,   1259    ,   2493    ,   3463    ,   8339    ,   2361    ,0 };
            const std::uint32_t dim2887Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   25  ,   49  ,   19  ,   167 ,   189 ,   211 ,   1247    ,   2883    ,   6983    ,   14573   ,   1021    ,0 };
            const std::uint32_t dim2888Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   5   ,   53  ,   119 ,   115 ,   497 ,   57  ,   1255    ,   2771    ,   6055    ,   865 ,   2735    ,0 };
            const std::uint32_t dim2889Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   25  ,   63  ,   83  ,   115 ,   185 ,   615 ,   1135    ,   1577    ,   3097    ,   2955    ,   7667    ,0 };
            const std::uint32_t dim2890Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   19  ,   33  ,   61  ,   121 ,   339 ,   153 ,   89  ,   1841    ,   3219    ,   10177   ,   13655   ,0 };
            const std::uint32_t dim2891Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   23  ,   51  ,   111 ,   149 ,   283 ,   863 ,   1687    ,   813 ,   951 ,   10593   ,   2491    ,0 };
            const std::uint32_t dim2892Kuo3Init[]   =   {   1   ,   1   ,   5   ,   7   ,   19  ,   63  ,   47  ,   73  ,   91  ,   501 ,   1837    ,   4079    ,   313 ,   14141   ,   7843    ,0 };
            const std::uint32_t dim2893Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   9   ,   15  ,   49  ,   195 ,   433 ,   289 ,   1109    ,   3929    ,   5589    ,   8943    ,   6325    ,0 };
            const std::uint32_t dim2894Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   13  ,   1   ,   97  ,   111 ,   379 ,   963 ,   837 ,   3681    ,   3281    ,   153 ,   9133    ,0 };
            const std::uint32_t dim2895Kuo3Init[]   =   {   1   ,   3   ,   5   ,   1   ,   19  ,   37  ,   7   ,   81  ,   443 ,   555 ,   1885    ,   3123    ,   7667    ,   2579    ,   3521    ,0 };
            const std::uint32_t dim2896Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   21  ,   17  ,   77  ,   121 ,   157 ,   993 ,   627 ,   893 ,   7633    ,   6421    ,   7315    ,0 };
            const std::uint32_t dim2897Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   25  ,   21  ,   105 ,   187 ,   17  ,   239 ,   1745    ,   13  ,   1021    ,   13319   ,   8511    ,0 };
            const std::uint32_t dim2898Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   5   ,   19  ,   67  ,   79  ,   79  ,   361 ,   1189    ,   3967    ,   6643    ,   2367    ,   18247   ,0 };
            const std::uint32_t dim2899Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   5   ,   15  ,   17  ,   139 ,   405 ,   229 ,   1819    ,   369 ,   4011    ,   11369   ,   5271    ,0 };
            const std::uint32_t dim2900Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   19  ,   3   ,   97  ,   121 ,   345 ,   917 ,   1473    ,   1439    ,   1007    ,   2535    ,   17107   ,0 };
            const std::uint32_t dim2901Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   3   ,   55  ,   117 ,   183 ,   65  ,   589 ,   107 ,   3933    ,   6911    ,   6425    ,   28363   ,0 };
            const std::uint32_t dim2902Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   25  ,   55  ,   57  ,   45  ,   217 ,   213 ,   281 ,   2211    ,   6851    ,   11553   ,   30021   ,0 };
            const std::uint32_t dim2903Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   29  ,   5   ,   1   ,   15  ,   477 ,   233 ,   677 ,   311 ,   3207    ,   10527   ,   5543    ,0 };
            const std::uint32_t dim2904Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   21  ,   57  ,   43  ,   9   ,   145 ,   369 ,   1367    ,   3241    ,   2821    ,   8753    ,   18579   ,0 };
            const std::uint32_t dim2905Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   13  ,   15  ,   99  ,   237 ,   101 ,   983 ,   657 ,   1169    ,   617 ,   12859   ,   32279   ,0 };
            const std::uint32_t dim2906Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   11  ,   61  ,   53  ,   39  ,   487 ,   967 ,   1239    ,   1899    ,   7063    ,   7943    ,   6739    ,0 };
            const std::uint32_t dim2907Kuo3Init[]   =   {   1   ,   1   ,   7   ,   15  ,   1   ,   17  ,   27  ,   121 ,   13  ,   519 ,   1049    ,   3613    ,   2777    ,   11077   ,   28601   ,0 };
            const std::uint32_t dim2908Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   27  ,   47  ,   39  ,   71  ,   179 ,   899 ,   1871    ,   3783    ,   2029    ,   2653    ,   5711    ,0 };
            const std::uint32_t dim2909Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   15  ,   13  ,   67  ,   113 ,   321 ,   1017    ,   1615    ,   1575    ,   3879    ,   6113    ,   31893   ,0 };
            const std::uint32_t dim2910Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   25  ,   45  ,   3   ,   121 ,   275 ,   313 ,   205 ,   1743    ,   5349    ,   4535    ,   22849   ,0 };
            const std::uint32_t dim2911Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   3   ,   19  ,   21  ,   97  ,   455 ,   1021    ,   773 ,   1825    ,   6985    ,   9389    ,   21107   ,0 };
            const std::uint32_t dim2912Kuo3Init[]   =   {   1   ,   3   ,   5   ,   9   ,   5   ,   3   ,   29  ,   9   ,   261 ,   575 ,   1111    ,   1983    ,   7629    ,   15743   ,   11009   ,0 };
            const std::uint32_t dim2913Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   25  ,   25  ,   79  ,   181 ,   417 ,   109 ,   29  ,   777 ,   4753    ,   6131    ,   4939    ,0 };
            const std::uint32_t dim2914Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   1   ,   1   ,   73  ,   175 ,   377 ,   531 ,   1829    ,   37  ,   497 ,   12055   ,   24991   ,0 };
            const std::uint32_t dim2915Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   27  ,   7   ,   63  ,   115 ,   381 ,   525 ,   1183    ,   1035    ,   5115    ,   2943    ,   2947    ,0 };
            const std::uint32_t dim2916Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   13  ,   17  ,   25  ,   203 ,   479 ,   887 ,   1465    ,   249 ,   4347    ,   12201   ,   10365   ,0 };
            const std::uint32_t dim2917Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   7   ,   19  ,   11  ,   173 ,   505 ,   509 ,   1311    ,   3535    ,   403 ,   13245   ,   25357   ,0 };
            const std::uint32_t dim2918Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   11  ,   53  ,   111 ,   243 ,   509 ,   17  ,   1281    ,   1149    ,   4561    ,   4705    ,   5783    ,0 };
            const std::uint32_t dim2919Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   29  ,   7   ,   39  ,   75  ,   385 ,   921 ,   147 ,   3419    ,   237 ,   12609   ,   10103   ,0 };
            const std::uint32_t dim2920Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   5   ,   21  ,   75  ,   109 ,   451 ,   371 ,   743 ,   3   ,   5277    ,   10917   ,   2677    ,0 };
            const std::uint32_t dim2921Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   21  ,   29  ,   85  ,   79  ,   359 ,   607 ,   191 ,   2481    ,   2089    ,   13441   ,   23575   ,0 };
            const std::uint32_t dim2922Kuo3Init[]   =   {   1   ,   3   ,   1   ,   11  ,   1   ,   43  ,   35  ,   119 ,   363 ,   477 ,   159 ,   3999    ,   7731    ,   15279   ,   20611   ,0 };
            const std::uint32_t dim2923Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   1   ,   9   ,   111 ,   19  ,   191 ,   899 ,   2039    ,   1153    ,   7893    ,   1627    ,   32325   ,0 };
            const std::uint32_t dim2924Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   1   ,   1   ,   43  ,   199 ,   329 ,   245 ,   1643    ,   2869    ,   5563    ,   3911    ,   21837   ,0 };
            const std::uint32_t dim2925Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   11  ,   15  ,   35  ,   153 ,   489 ,   383 ,   1313    ,   1881    ,   5895    ,   10085   ,   2489    ,0 };
            const std::uint32_t dim2926Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   27  ,   29  ,   15  ,   209 ,   27  ,   291 ,   77  ,   1759    ,   1565    ,   5477    ,   18701   ,0 };
            const std::uint32_t dim2927Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   19  ,   39  ,   35  ,   207 ,   345 ,   625 ,   1797    ,   2563    ,   8043    ,   1559    ,   18415   ,0 };
            const std::uint32_t dim2928Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   21  ,   43  ,   101 ,   89  ,   229 ,   435 ,   1445    ,   2789    ,   6903    ,   11629   ,   29933   ,0 };
            const std::uint32_t dim2929Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   21  ,   23  ,   107 ,   21  ,   377 ,   67  ,   1007    ,   2323    ,   2957    ,   6553    ,   3225    ,0 };
            const std::uint32_t dim2930Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   3   ,   13  ,   121 ,   119 ,   253 ,   391 ,   215 ,   851 ,   5047    ,   4577    ,   17691   ,0 };
            const std::uint32_t dim2931Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   3   ,   37  ,   65  ,   103 ,   395 ,   745 ,   1897    ,   3031    ,   2321    ,   5731    ,   4657    ,0 };
            const std::uint32_t dim2932Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   17  ,   19  ,   61  ,   159 ,   459 ,   207 ,   397 ,   1101    ,   5835    ,   1947    ,   28479   ,0 };
            const std::uint32_t dim2933Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   23  ,   13  ,   63  ,   7   ,   231 ,   15  ,   855 ,   375 ,   673 ,   12523   ,   20981   ,0 };
            const std::uint32_t dim2934Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   21  ,   13  ,   109 ,   93  ,   7   ,   767 ,   477 ,   2301    ,   3587    ,   6053    ,   427 ,0 };
            const std::uint32_t dim2935Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   23  ,   9   ,   97  ,   175 ,   139 ,   983 ,   993 ,   2447    ,   2183    ,   16143   ,   10059   ,0 };
            const std::uint32_t dim2936Kuo3Init[]   =   {   1   ,   1   ,   1   ,   1   ,   17  ,   61  ,   9   ,   13  ,   241 ,   825 ,   707 ,   3385    ,   6551    ,   7321    ,   1825    ,0 };
            const std::uint32_t dim2937Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   9   ,   63  ,   101 ,   33  ,   151 ,   629 ,   1903    ,   3159    ,   1083    ,   11109   ,   27679   ,0 };
            const std::uint32_t dim2938Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   11  ,   57  ,   123 ,   191 ,   41  ,   765 ,   1039    ,   2639    ,   3793    ,   1403    ,   20745   ,0 };
            const std::uint32_t dim2939Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   23  ,   45  ,   21  ,   39  ,   259 ,   531 ,   1205    ,   3537    ,   1927    ,   4357    ,   16185   ,0 };
            const std::uint32_t dim2940Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   5   ,   59  ,   127 ,   187 ,   67  ,   377 ,   1577    ,   401 ,   4523    ,   8433    ,   20965   ,0 };
            const std::uint32_t dim2941Kuo3Init[]   =   {   1   ,   3   ,   3   ,   7   ,   9   ,   37  ,   9   ,   221 ,   459 ,   301 ,   1937    ,   283 ,   6973    ,   3545    ,   203 ,0 };
            const std::uint32_t dim2942Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   27  ,   29  ,   59  ,   47  ,   11  ,   791 ,   1863    ,   1725    ,   2797    ,   2673    ,   9551    ,0 };
            const std::uint32_t dim2943Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   9   ,   17  ,   75  ,   167 ,   31  ,   879 ,   1841    ,   801 ,   5659    ,   10199   ,   8639    ,0 };
            const std::uint32_t dim2944Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   27  ,   35  ,   99  ,   97  ,   153 ,   987 ,   1847    ,   2209    ,   8139    ,   647 ,   30087   ,0 };
            const std::uint32_t dim2945Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   3   ,   9   ,   85  ,   105 ,   503 ,   279 ,   1919    ,   1407    ,   8161    ,   3601    ,   26729   ,0 };
            const std::uint32_t dim2946Kuo3Init[]   =   {   1   ,   3   ,   7   ,   1   ,   23  ,   37  ,   71  ,   131 ,   315 ,   401 ,   389 ,   547 ,   7305    ,   581 ,   14619   ,0 };
            const std::uint32_t dim2947Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   3   ,   47  ,   125 ,   87  ,   255 ,   397 ,   1561    ,   433 ,   7057    ,   4595    ,   17785   ,0 };
            const std::uint32_t dim2948Kuo3Init[]   =   {   1   ,   1   ,   5   ,   7   ,   17  ,   59  ,   107 ,   141 ,   437 ,   335 ,   397 ,   3913    ,   3777    ,   8625    ,   25539   ,0 };
            const std::uint32_t dim2949Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   9   ,   21  ,   43  ,   13  ,   75  ,   667 ,   287 ,   347 ,   1503    ,   15905   ,   17281   ,0 };
            const std::uint32_t dim2950Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   7   ,   1   ,   25  ,   91  ,   337 ,   909 ,   1555    ,   1719    ,   1169    ,   8537    ,   8859    ,0 };
            const std::uint32_t dim2951Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   11  ,   17  ,   3   ,   67  ,   305 ,   565 ,   2023    ,   1175    ,   1135    ,   4453    ,   21431   ,0 };
            const std::uint32_t dim2952Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   5   ,   17  ,   23  ,   41  ,   317 ,   63  ,   775 ,   3699    ,   3141    ,   12917   ,   1847    ,0 };
            const std::uint32_t dim2953Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   13  ,   41  ,   27  ,   229 ,   113 ,   223 ,   1411    ,   2733    ,   7769    ,   831 ,   20447   ,0 };
            const std::uint32_t dim2954Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   9   ,   15  ,   9   ,   235 ,   501 ,   709 ,   643 ,   79  ,   2163    ,   10511   ,   8763    ,0 };
            const std::uint32_t dim2955Kuo3Init[]   =   {   1   ,   3   ,   3   ,   7   ,   13  ,   3   ,   61  ,   173 ,   507 ,   619 ,   1169    ,   3133    ,   533 ,   7989    ,   14071   ,0 };
            const std::uint32_t dim2956Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   9   ,   11  ,   63  ,   147 ,   73  ,   501 ,   371 ,   489 ,   5689    ,   3289    ,   23459   ,0 };
            const std::uint32_t dim2957Kuo3Init[]   =   {   1   ,   1   ,   1   ,   1   ,   23  ,   21  ,   83  ,   127 ,   507 ,   395 ,   445 ,   4021    ,   7401    ,   14939   ,   781 ,0 };
            const std::uint32_t dim2958Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   21  ,   15  ,   57  ,   9   ,   223 ,   603 ,   271 ,   2277    ,   7509    ,   5183    ,   9645    ,0 };
            const std::uint32_t dim2959Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   3   ,   37  ,   59  ,   75  ,   325 ,   481 ,   1503    ,   2891    ,   3333    ,   5251    ,   24987   ,0 };
            const std::uint32_t dim2960Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   25  ,   3   ,   95  ,   55  ,   437 ,   809 ,   1459    ,   957 ,   4037    ,   4139    ,   22307   ,0 };
            const std::uint32_t dim2961Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   7   ,   43  ,   111 ,   183 ,   321 ,   475 ,   633 ,   3183    ,   2885    ,   2083    ,   2515    ,0 };
            const std::uint32_t dim2962Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   1   ,   1   ,   9   ,   159 ,   257 ,   257 ,   431 ,   3433    ,   6191    ,   15379   ,   29129   ,0 };
            const std::uint32_t dim2963Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   19  ,   7   ,   69  ,   119 ,   391 ,   381 ,   1355    ,   877 ,   245 ,   5287    ,   451 ,0 };
            const std::uint32_t dim2964Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   15  ,   27  ,   47  ,   19  ,   213 ,   213 ,   1435    ,   3835    ,   3639    ,   16037   ,   32613   ,0 };
            const std::uint32_t dim2965Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   19  ,   9   ,   115 ,   1   ,   319 ,   893 ,   29  ,   3363    ,   2491    ,   8091    ,   29797   ,0 };
            const std::uint32_t dim2966Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   19  ,   9   ,   111 ,   181 ,   37  ,   819 ,   843 ,   3591    ,   3617    ,   11209   ,   1731    ,0 };
            const std::uint32_t dim2967Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   17  ,   31  ,   107 ,   147 ,   469 ,   409 ,   1391    ,   927 ,   4483    ,   15859   ,   11231   ,0 };
            const std::uint32_t dim2968Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   17  ,   37  ,   37  ,   165 ,   289 ,   857 ,   243 ,   3803    ,   8131    ,   7409    ,   12197   ,0 };
            const std::uint32_t dim2969Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   17  ,   61  ,   75  ,   177 ,   63  ,   835 ,   731 ,   2015    ,   7287    ,   11803   ,   11595   ,0 };
            const std::uint32_t dim2970Kuo3Init[]   =   {   1   ,   3   ,   1   ,   15  ,   17  ,   43  ,   33  ,   151 ,   259 ,   951 ,   73  ,   2229    ,   4851    ,   7875    ,   21497   ,0 };
            const std::uint32_t dim2971Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   25  ,   5   ,   91  ,   15  ,   231 ,   729 ,   865 ,   545 ,   3043    ,   8925    ,   9111    ,0 };
            const std::uint32_t dim2972Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   27  ,   13  ,   67  ,   175 ,   135 ,   999 ,   997 ,   2237    ,   617 ,   14805   ,   31347   ,0 };
            const std::uint32_t dim2973Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   5   ,   37  ,   59  ,   155 ,   11  ,   401 ,   421 ,   305 ,   4727    ,   7087    ,   27231   ,0 };
            const std::uint32_t dim2974Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   7   ,   39  ,   105 ,   215 ,   241 ,   959 ,   1065    ,   2045    ,   5807    ,   1219    ,   12545   ,0 };
            const std::uint32_t dim2975Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   3   ,   61  ,   3   ,   141 ,   363 ,   677 ,   1149    ,   1143    ,   1697    ,   11339   ,   10503   ,0 };
            const std::uint32_t dim2976Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   15  ,   1   ,   37  ,   183 ,   279 ,   885 ,   571 ,   1537    ,   5489    ,   12111   ,   4867    ,0 };
            const std::uint32_t dim2977Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   7   ,   49  ,   49  ,   37  ,   323 ,   407 ,   1555    ,   1209    ,   8159    ,   12171   ,   4457    ,0 };
            const std::uint32_t dim2978Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   9   ,   17  ,   111 ,   19  ,   353 ,   273 ,   1271    ,   975 ,   3935    ,   9689    ,   18355   ,0 };
            const std::uint32_t dim2979Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   17  ,   37  ,   21  ,   127 ,   115 ,   19  ,   771 ,   667 ,   4219    ,   1829    ,   18899   ,0 };
            const std::uint32_t dim2980Kuo3Init[]   =   {   1   ,   3   ,   3   ,   7   ,   3   ,   43  ,   67  ,   43  ,   119 ,   319 ,   1165    ,   2759    ,   5389    ,   10891   ,   16529   ,0 };
            const std::uint32_t dim2981Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   29  ,   17  ,   53  ,   137 ,   329 ,   71  ,   1499    ,   3381    ,   3533    ,   15551   ,   30561   ,0 };
            const std::uint32_t dim2982Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   5   ,   61  ,   45  ,   109 ,   389 ,   505 ,   1803    ,   1845    ,   2165    ,   267 ,   14573   ,0 };
            const std::uint32_t dim2983Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   25  ,   55  ,   47  ,   17  ,   421 ,   711 ,   613 ,   1537    ,   5255    ,   13437   ,   3425    ,0 };
            const std::uint32_t dim2984Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   25  ,   51  ,   25  ,   67  ,   409 ,   309 ,   951 ,   131 ,   2781    ,   7445    ,   1487    ,0 };
            const std::uint32_t dim2985Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   27  ,   21  ,   45  ,   73  ,   465 ,   977 ,   1327    ,   837 ,   1311    ,   11167   ,   21265   ,0 };
            const std::uint32_t dim2986Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   17  ,   61  ,   27  ,   83  ,   271 ,   245 ,   187 ,   1947    ,   7989    ,   13633   ,   27023   ,0 };
            const std::uint32_t dim2987Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   17  ,   7   ,   35  ,   195 ,   465 ,   745 ,   1833    ,   3231    ,   3061    ,   1631    ,   9081    ,0 };
            const std::uint32_t dim2988Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   5   ,   39  ,   83  ,   13  ,   199 ,   821 ,   839 ,   3509    ,   3857    ,   12389   ,   28771   ,0 };
            const std::uint32_t dim2989Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   5   ,   15  ,   91  ,   199 ,   239 ,   97  ,   1699    ,   549 ,   4735    ,   15127   ,   7407    ,0 };
            const std::uint32_t dim2990Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   13  ,   1   ,   7   ,   109 ,   93  ,   733 ,   1221    ,   3361    ,   7765    ,   11317   ,   431 ,0 };
            const std::uint32_t dim2991Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   31  ,   23  ,   17  ,   97  ,   477 ,   497 ,   1123    ,   2731    ,   3157    ,   5217    ,   23901   ,0 };
            const std::uint32_t dim2992Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   1   ,   41  ,   63  ,   11  ,   507 ,   55  ,   1927    ,   2193    ,   6177    ,   3013    ,   24095   ,0 };
            const std::uint32_t dim2993Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   25  ,   57  ,   113 ,   99  ,   383 ,   831 ,   1455    ,   2603    ,   4619    ,   9495    ,   5073    ,0 };
            const std::uint32_t dim2994Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   25  ,   35  ,   67  ,   83  ,   125 ,   909 ,   227 ,   1337    ,   3729    ,   7623    ,   27899   ,0 };
            const std::uint32_t dim2995Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   15  ,   23  ,   117 ,   73  ,   285 ,   341 ,   241 ,   3569    ,   7401    ,   16185   ,   18571   ,0 };
            const std::uint32_t dim2996Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   23  ,   9   ,   123 ,   93  ,   287 ,   881 ,   1857    ,   195 ,   3999    ,   81  ,   26173   ,0 };
            const std::uint32_t dim2997Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   21  ,   27  ,   57  ,   251 ,   321 ,   109 ,   811 ,   3665    ,   4575    ,   15971   ,   24111   ,0 };
            const std::uint32_t dim2998Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   11  ,   53  ,   71  ,   11  ,   67  ,   433 ,   549 ,   3121    ,   193 ,   13099   ,   6635    ,0 };
            const std::uint32_t dim2999Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   1   ,   39  ,   75  ,   163 ,   259 ,   523 ,   941 ,   3025    ,   3757    ,   2589    ,   15403   ,0 };
            const std::uint32_t dim3000Kuo3Init[]   =   {   1   ,   3   ,   5   ,   1   ,   1   ,   15  ,   47  ,   83  ,   33  ,   881 ,   215 ,   1717    ,   2255    ,   7349    ,   27345   ,0 };
            const std::uint32_t dim3001Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   15  ,   55  ,   95  ,   125 ,   511 ,   829 ,   1021    ,   2095    ,   1107    ,   13071   ,   29279   ,0 };
            const std::uint32_t dim3002Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   15  ,   63  ,   15  ,   123 ,   233 ,   351 ,   1687    ,   3383    ,   287 ,   2721    ,   20109   ,0 };
            const std::uint32_t dim3003Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   7   ,   19  ,   103 ,   29  ,   349 ,   875 ,   1631    ,   119 ,   6095    ,   7623    ,   4063    ,0 };
            const std::uint32_t dim3004Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   21  ,   41  ,   45  ,   91  ,   445 ,   193 ,   1077    ,   3849    ,   163 ,   15123   ,   9677    ,0 };
            const std::uint32_t dim3005Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   7   ,   39  ,   127 ,   75  ,   53  ,   233 ,   531 ,   635 ,   8055    ,   8789    ,   6205    ,0 };
            const std::uint32_t dim3006Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   21  ,   19  ,   53  ,   197 ,   207 ,   791 ,   1193    ,   365 ,   5747    ,   12155   ,   30361   ,0 };
            const std::uint32_t dim3007Kuo3Init[]   =   {   1   ,   1   ,   1   ,   15  ,   23  ,   39  ,   95  ,   75  ,   239 ,   639 ,   253 ,   3329    ,   6017    ,   6647    ,   16381   ,0 };
            const std::uint32_t dim3008Kuo3Init[]   =   {   1   ,   3   ,   3   ,   7   ,   5   ,   37  ,   85  ,   45  ,   473 ,   299 ,   767 ,   3795    ,   6895    ,   16255   ,   20411   ,0 };
            const std::uint32_t dim3009Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   31  ,   33  ,   83  ,   79  ,   341 ,   11  ,   561 ,   2051    ,   485 ,   8653    ,   7751    ,0 };
            const std::uint32_t dim3010Kuo3Init[]   =   {   1   ,   1   ,   1   ,   1   ,   9   ,   39  ,   127 ,   115 ,   55  ,   281 ,   1439    ,   2527    ,   3975    ,   9037    ,   32221   ,0 };
            const std::uint32_t dim3011Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   27  ,   45  ,   117 ,   67  ,   471 ,   101 ,   927 ,   2391    ,   4935    ,   14477   ,   17515   ,0 };
            const std::uint32_t dim3012Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   5   ,   1   ,   45  ,   93  ,   169 ,   181 ,   609 ,   3489    ,   4779    ,   11641   ,   16535   ,0 };
            const std::uint32_t dim3013Kuo3Init[]   =   {   1   ,   3   ,   3   ,   5   ,   1   ,   53  ,   21  ,   169 ,   199 ,   769 ,   813 ,   1799    ,   5199    ,   13499   ,   25677   ,0 };
            const std::uint32_t dim3014Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   13  ,   43  ,   127 ,   169 ,   503 ,   935 ,   1315    ,   1449    ,   1497    ,   6173    ,   20437   ,0 };
            const std::uint32_t dim3015Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   19  ,   31  ,   83  ,   167 ,   23  ,   1019    ,   1223    ,   2705    ,   6471    ,   11619   ,   10589   ,0 };
            const std::uint32_t dim3016Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   7   ,   39  ,   117 ,   67  ,   159 ,   301 ,   553 ,   2005    ,   5455    ,   10049   ,   3441    ,0 };
            const std::uint32_t dim3017Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   7   ,   45  ,   59  ,   73  ,   105 ,   507 ,   387 ,   2697    ,   5679    ,   9825    ,   7689    ,0 };
            const std::uint32_t dim3018Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   3   ,   35  ,   93  ,   129 ,   273 ,   165 ,   1615    ,   3631    ,   1391    ,   10631   ,   27157   ,0 };
            const std::uint32_t dim3019Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   9   ,   25  ,   23  ,   101 ,   1   ,   741 ,   1539    ,   1893    ,   1573    ,   10037   ,   3079    ,0 };
            const std::uint32_t dim3020Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   29  ,   63  ,   119 ,   83  ,   239 ,   993 ,   1663    ,   391 ,   1583    ,   11393   ,   8361    ,0 };
            const std::uint32_t dim3021Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   11  ,   55  ,   41  ,   155 ,   439 ,   631 ,   1949    ,   1529    ,   5249    ,   883 ,   25125   ,0 };
            const std::uint32_t dim3022Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   19  ,   15  ,   35  ,   175 ,   33  ,   199 ,   1979    ,   4025    ,   1543    ,   6451    ,   11485   ,0 };
            const std::uint32_t dim3023Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   17  ,   63  ,   127 ,   191 ,   463 ,   973 ,   1509    ,   1925    ,   3469    ,   15967   ,   10661   ,0 };
            const std::uint32_t dim3024Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   7   ,   57  ,   111 ,   127 ,   475 ,   625 ,   553 ,   1941    ,   2923    ,   5203    ,   16915   ,0 };
            const std::uint32_t dim3025Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   15  ,   23  ,   61  ,   93  ,   251 ,   865 ,   2011    ,   2607    ,   1691    ,   10359   ,   4667    ,0 };
            const std::uint32_t dim3026Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   29  ,   19  ,   5   ,   101 ,   205 ,   515 ,   1953    ,   3543    ,   929 ,   8745    ,   1773    ,0 };
            const std::uint32_t dim3027Kuo3Init[]   =   {   1   ,   1   ,   7   ,   15  ,   19  ,   29  ,   127 ,   153 ,   383 ,   799 ,   639 ,   3271    ,   6487    ,   2989    ,   8965    ,0 };
            const std::uint32_t dim3028Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   7   ,   7   ,   73  ,   239 ,   117 ,   261 ,   1147    ,   3761    ,   1531    ,   15613   ,   13545   ,0 };
            const std::uint32_t dim3029Kuo3Init[]   =   {   1   ,   3   ,   1   ,   11  ,   17  ,   29  ,   53  ,   161 ,   47  ,   933 ,   1763    ,   1543    ,   3661    ,   9369    ,   14239   ,0 };
            const std::uint32_t dim3030Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   13  ,   47  ,   19  ,   139 ,   115 ,   239 ,   799 ,   2211    ,   6205    ,   5273    ,   31205   ,0 };
            const std::uint32_t dim3031Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   29  ,   53  ,   121 ,   3   ,   89  ,   253 ,   1201    ,   89  ,   297 ,   11561   ,   9655    ,0 };
            const std::uint32_t dim3032Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   25  ,   43  ,   25  ,   165 ,   135 ,   789 ,   891 ,   1711    ,   711 ,   269 ,   17895   ,0 };
            const std::uint32_t dim3033Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   27  ,   57  ,   63  ,   89  ,   33  ,   897 ,   691 ,   3129    ,   7253    ,   2041    ,   14341   ,0 };
            const std::uint32_t dim3034Kuo3Init[]   =   {   1   ,   1   ,   1   ,   1   ,   5   ,   25  ,   21  ,   65  ,   383 ,   687 ,   57  ,   2267    ,   1837    ,   7091    ,   5941    ,0 };
            const std::uint32_t dim3035Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   9   ,   37  ,   75  ,   113 ,   243 ,   419 ,   387 ,   3479    ,   3295    ,   3659    ,   29215   ,0 };
            const std::uint32_t dim3036Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   1   ,   39  ,   97  ,   237 ,   509 ,   51  ,   1239    ,   1889    ,   915 ,   15313   ,   3487    ,0 };
            const std::uint32_t dim3037Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   1   ,   5   ,   81  ,   153 ,   83  ,   977 ,   1667    ,   571 ,   1161    ,   9347    ,   32353   ,0 };
            const std::uint32_t dim3038Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   11  ,   13  ,   45  ,   91  ,   265 ,   815 ,   1141    ,   1187    ,   41  ,   15723   ,   5573    ,0 };
            const std::uint32_t dim3039Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   31  ,   29  ,   27  ,   23  ,   163 ,   605 ,   1457    ,   37  ,   2075    ,   4581    ,   10571   ,0 };
            const std::uint32_t dim3040Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   13  ,   31  ,   119 ,   241 ,   379 ,   427 ,   333 ,   1299    ,   3303    ,   13049   ,   15233   ,0 };
            const std::uint32_t dim3041Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   23  ,   35  ,   69  ,   195 ,   149 ,   273 ,   41  ,   289 ,   3173    ,   13177   ,   10865   ,0 };
            const std::uint32_t dim3042Kuo3Init[]   =   {   1   ,   3   ,   3   ,   7   ,   1   ,   5   ,   85  ,   245 ,   417 ,   887 ,   1821    ,   3623    ,   1591    ,   15871   ,   10837   ,0 };
            const std::uint32_t dim3043Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   19  ,   55  ,   11  ,   65  ,   227 ,   273 ,   1065    ,   1937    ,   5197    ,   7695    ,   24827   ,0 };
            const std::uint32_t dim3044Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   11  ,   55  ,   11  ,   49  ,   141 ,   607 ,   509 ,   3785    ,   8009    ,   4127    ,   4757    ,0 };
            const std::uint32_t dim3045Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   31  ,   23  ,   33  ,   241 ,   347 ,   261 ,   1609    ,   3177    ,   4065    ,   13767   ,   24607   ,0 };
            const std::uint32_t dim3046Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   13  ,   7   ,   73  ,   63  ,   493 ,   607 ,   869 ,   1599    ,   7725    ,   2405    ,   12945   ,0 };
            const std::uint32_t dim3047Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   9   ,   57  ,   85  ,   173 ,   259 ,   749 ,   1661    ,   2911    ,   7833    ,   7577    ,   21209   ,0 };
            const std::uint32_t dim3048Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   7   ,   27  ,   61  ,   91  ,   417 ,   369 ,   1181    ,   1385    ,   2991    ,   12503   ,   13073   ,0 };
            const std::uint32_t dim3049Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   17  ,   11  ,   51  ,   101 ,   45  ,   45  ,   1247    ,   4069    ,   3079    ,   9081    ,   12443   ,0 };
            const std::uint32_t dim3050Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   13  ,   57  ,   63  ,   43  ,   451 ,   743 ,   1045    ,   2967    ,   6437    ,   93  ,   4589    ,0 };
            const std::uint32_t dim3051Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   25  ,   17  ,   113 ,   89  ,   457 ,   261 ,   827 ,   197 ,   7177    ,   4135    ,   19733   ,0 };
            const std::uint32_t dim3052Kuo3Init[]   =   {   1   ,   3   ,   5   ,   9   ,   23  ,   59  ,   29  ,   207 ,   19  ,   623 ,   101 ,   1675    ,   579 ,   3255    ,   16259   ,0 };
            const std::uint32_t dim3053Kuo3Init[]   =   {   1   ,   1   ,   1   ,   1   ,   21  ,   23  ,   103 ,   123 ,   61  ,   233 ,   71  ,   897 ,   6147    ,   3335    ,   1027    ,0 };
            const std::uint32_t dim3054Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   9   ,   11  ,   101 ,   55  ,   247 ,   285 ,   1387    ,   2063    ,   6853    ,   409 ,   10715   ,0 };
            const std::uint32_t dim3055Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   11  ,   41  ,   5   ,   157 ,   325 ,   975 ,   1403    ,   3187    ,   4107    ,   4093    ,   18165   ,0 };
            const std::uint32_t dim3056Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   25  ,   15  ,   69  ,   93  ,   87  ,   711 ,   1699    ,   733 ,   7703    ,   2191    ,   12293   ,0 };
            const std::uint32_t dim3057Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   21  ,   41  ,   31  ,   229 ,   325 ,   507 ,   2019    ,   2225    ,   1733    ,   4447    ,   32477   ,0 };
            const std::uint32_t dim3058Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   23  ,   41  ,   19  ,   1   ,   467 ,   315 ,   1513    ,   1671    ,   4159    ,   12477   ,   6199    ,0 };
            const std::uint32_t dim3059Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   27  ,   61  ,   35  ,   115 ,   215 ,   979 ,   1887    ,   1913    ,   689 ,   3847    ,   11451   ,0 };
            const std::uint32_t dim3060Kuo3Init[]   =   {   1   ,   3   ,   3   ,   7   ,   25  ,   29  ,   65  ,   233 ,   433 ,   113 ,   1031    ,   2455    ,   6743    ,   5227    ,   7207    ,0 };
            const std::uint32_t dim3061Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   5   ,   9   ,   85  ,   103 ,   185 ,   699 ,   663 ,   441 ,   8013    ,   1227    ,   12875   ,0 };
            const std::uint32_t dim3062Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   9   ,   59  ,   35  ,   223 ,   131 ,   409 ,   125 ,   3437    ,   2015    ,   217 ,   16351   ,0 };
            const std::uint32_t dim3063Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   9   ,   27  ,   43  ,   211 ,   365 ,   855 ,   1249    ,   3127    ,   3611    ,   9339    ,   16083   ,0 };
            const std::uint32_t dim3064Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   29  ,   11  ,   61  ,   27  ,   195 ,   963 ,   1905    ,   1679    ,   1811    ,   7   ,   27243   ,0 };
            const std::uint32_t dim3065Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   3   ,   41  ,   21  ,   31  ,   461 ,   3   ,   1033    ,   459 ,   1831    ,   12289   ,   19645   ,0 };
            const std::uint32_t dim3066Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   15  ,   7   ,   25  ,   207 ,   37  ,   177 ,   973 ,   3207    ,   5329    ,   8541    ,   7929    ,0 };
            const std::uint32_t dim3067Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   29  ,   35  ,   77  ,   251 ,   429 ,   681 ,   391 ,   3789    ,   5953    ,   13339   ,   16991   ,0 };
            const std::uint32_t dim3068Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   5   ,   39  ,   21  ,   131 ,   511 ,   11  ,   921 ,   3073    ,   3239    ,   561 ,   28595   ,0 };
            const std::uint32_t dim3069Kuo3Init[]   =   {   1   ,   3   ,   1   ,   11  ,   3   ,   11  ,   71  ,   231 ,   439 ,   523 ,   209 ,   3213    ,   211 ,   13449   ,   23311   ,0 };
            const std::uint32_t dim3070Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   31  ,   27  ,   59  ,   161 ,   71  ,   619 ,   1643    ,   3687    ,   753 ,   7443    ,   25743   ,0 };
            const std::uint32_t dim3071Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   13  ,   49  ,   33  ,   223 ,   443 ,   463 ,   1833    ,   3757    ,   299 ,   9633    ,   16339   ,0 };
            const std::uint32_t dim3072Kuo3Init[]   =   {   1   ,   3   ,   7   ,   1   ,   21  ,   57  ,   63  ,   31  ,   491 ,   53  ,   75  ,   3059    ,   3013    ,   965 ,   6209    ,0 };
            const std::uint32_t dim3073Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   3   ,   45  ,   63  ,   25  ,   511 ,   501 ,   1003    ,   1499    ,   887 ,   5583    ,   6329    ,0 };
            const std::uint32_t dim3074Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   9   ,   11  ,   49  ,   225 ,   511 ,   563 ,   495 ,   1697    ,   7943    ,   13561   ,   16159   ,0 };
            const std::uint32_t dim3075Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   11  ,   1   ,   95  ,   255 ,   437 ,   979 ,   1669    ,   179 ,   2189    ,   14431   ,   23919   ,0 };
            const std::uint32_t dim3076Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   13  ,   5   ,   23  ,   233 ,   327 ,   903 ,   167 ,   797 ,   5205    ,   2203    ,   22137   ,0 };
            const std::uint32_t dim3077Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   25  ,   63  ,   43  ,   113 ,   251 ,   39  ,   163 ,   1631    ,   2731    ,   12241   ,   32567   ,0 };
            const std::uint32_t dim3078Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   3   ,   35  ,   9   ,   21  ,   477 ,   139 ,   1107    ,   1975    ,   6883    ,   6651    ,   20847   ,0 };
            const std::uint32_t dim3079Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   25  ,   39  ,   89  ,   217 ,   95  ,   457 ,   1741    ,   2725    ,   5391    ,   13381   ,   2411    ,0 };
            const std::uint32_t dim3080Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   1   ,   27  ,   9   ,   51  ,   3   ,   915 ,   1803    ,   931 ,   7651    ,   6497    ,   6635    ,0 };
            const std::uint32_t dim3081Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   21  ,   53  ,   9   ,   151 ,   155 ,   827 ,   453 ,   4071    ,   3153    ,   2711    ,   25143   ,0 };
            const std::uint32_t dim3082Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   21  ,   15  ,   5   ,   169 ,   27  ,   479 ,   911 ,   3949    ,   2819    ,   387 ,   2919    ,0 };
            const std::uint32_t dim3083Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   27  ,   59  ,   27  ,   225 ,   507 ,   403 ,   1333    ,   747 ,   7731    ,   13007   ,   16283   ,0 };
            const std::uint32_t dim3084Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   29  ,   11  ,   65  ,   169 ,   197 ,   209 ,   1703    ,   3503    ,   2661    ,   14703   ,   28529   ,0 };
            const std::uint32_t dim3085Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   17  ,   63  ,   73  ,   11  ,   495 ,   603 ,   687 ,   2773    ,   3955    ,   12761   ,   13899   ,0 };
            const std::uint32_t dim3086Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   7   ,   31  ,   55  ,   133 ,   197 ,   619 ,   1747    ,   3531    ,   1157    ,   7143    ,   19347   ,0 };
            const std::uint32_t dim3087Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   15  ,   47  ,   5   ,   117 ,   329 ,   169 ,   2023    ,   901 ,   397 ,   15681   ,   8931    ,0 };
            const std::uint32_t dim3088Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   29  ,   5   ,   79  ,   73  ,   463 ,   125 ,   1539    ,   2149    ,   4353    ,   15123   ,   27853   ,0 };
            const std::uint32_t dim3089Kuo3Init[]   =   {   1   ,   1   ,   5   ,   7   ,   13  ,   55  ,   59  ,   151 ,   105 ,   79  ,   1023    ,   1839    ,   3889    ,   3843    ,   6129    ,0 };
            const std::uint32_t dim3090Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   9   ,   15  ,   109 ,   63  ,   95  ,   573 ,   385 ,   3773    ,   535 ,   11307   ,   4719    ,0 };
            const std::uint32_t dim3091Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   9   ,   9   ,   91  ,   245 ,   403 ,   841 ,   1771    ,   2121    ,   6927    ,   1029    ,   26767   ,0 };
            const std::uint32_t dim3092Kuo3Init[]   =   {   1   ,   3   ,   1   ,   11  ,   25  ,   55  ,   21  ,   173 ,   327 ,   327 ,   1747    ,   1771    ,   6829    ,   12155   ,   29375   ,0 };
            const std::uint32_t dim3093Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   17  ,   15  ,   31  ,   189 ,   179 ,   849 ,   1895    ,   3333    ,   7385    ,   4473    ,   18003   ,0 };
            const std::uint32_t dim3094Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   29  ,   37  ,   11  ,   81  ,   181 ,   197 ,   1231    ,   167 ,   6611    ,   3437    ,   8857    ,0 };
            const std::uint32_t dim3095Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   17  ,   53  ,   63  ,   51  ,   497 ,   725 ,   917 ,   2661    ,   2013    ,   10887   ,   29145   ,0 };
            const std::uint32_t dim3096Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   15  ,   53  ,   75  ,   209 ,   429 ,   927 ,   1867    ,   677 ,   5305    ,   15901   ,   5079    ,0 };
            const std::uint32_t dim3097Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   19  ,   57  ,   105 ,   169 ,   113 ,   701 ,   1123    ,   2203    ,   285 ,   12447   ,   18301   ,0 };
            const std::uint32_t dim3098Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   25  ,   53  ,   51  ,   35  ,   245 ,   173 ,   1047    ,   1905    ,   1773    ,   10699   ,   32057   ,0 };
            const std::uint32_t dim3099Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   31  ,   33  ,   15  ,   233 ,   105 ,   943 ,   201 ,   2681    ,   3121    ,   14145   ,   23741   ,0 };
            const std::uint32_t dim3100Kuo3Init[]   =   {   1   ,   1   ,   1   ,   1   ,   27  ,   61  ,   121 ,   199 ,   437 ,   717 ,   1481    ,   2421    ,   6681    ,   2457    ,   4411    ,0 };
            const std::uint32_t dim3101Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   31  ,   9   ,   93  ,   149 ,   379 ,   639 ,   1889    ,   1385    ,   3513    ,   10105   ,   13933   ,0 };
            const std::uint32_t dim3102Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   9   ,   37  ,   41  ,   221 ,   323 ,   989 ,   445 ,   3083    ,   6855    ,   11577   ,   29849   ,0 };
            const std::uint32_t dim3103Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   27  ,   55  ,   53  ,   171 ,   87  ,   529 ,   1555    ,   2065    ,   1685    ,   1953    ,   20561   ,0 };
            const std::uint32_t dim3104Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   1   ,   15  ,   11  ,   91  ,   81  ,   217 ,   7   ,   1687    ,   493 ,   13345   ,   14009   ,0 };
            const std::uint32_t dim3105Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   5   ,   31  ,   89  ,   33  ,   39  ,   747 ,   753 ,   2193    ,   1937    ,   9685    ,   17689   ,0 };
            const std::uint32_t dim3106Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   13  ,   61  ,   101 ,   89  ,   305 ,   123 ,   1773    ,   411 ,   595 ,   10113   ,   4725    ,0 };
            const std::uint32_t dim3107Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   3   ,   13  ,   25  ,   205 ,   343 ,   869 ,   115 ,   2413    ,   4531    ,   13185   ,   15699   ,0 };
            const std::uint32_t dim3108Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   25  ,   37  ,   71  ,   125 ,   85  ,   995 ,   769 ,   2737    ,   2495    ,   7571    ,   26825   ,0 };
            const std::uint32_t dim3109Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   21  ,   3   ,   109 ,   175 ,   479 ,   605 ,   569 ,   2753    ,   2927    ,   10529   ,   28345   ,0 };
            const std::uint32_t dim3110Kuo3Init[]   =   {   1   ,   3   ,   7   ,   1   ,   5   ,   57  ,   75  ,   79  ,   383 ,   637 ,   1411    ,   3955    ,   5535    ,   9403    ,   10463   ,0 };
            const std::uint32_t dim3111Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   27  ,   25  ,   67  ,   35  ,   95  ,   25  ,   1585    ,   1725    ,   7003    ,   2261    ,   3575    ,0 };
            const std::uint32_t dim3112Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   11  ,   11  ,   85  ,   141 ,   389 ,   903 ,   995 ,   2625    ,   7163    ,   7229    ,   18205   ,0 };
            const std::uint32_t dim3113Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   3   ,   53  ,   69  ,   141 ,   213 ,   675 ,   1799    ,   235 ,   3433    ,   2305    ,   29607   ,0 };
            const std::uint32_t dim3114Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   21  ,   45  ,   119 ,   229 ,   493 ,   691 ,   1551    ,   3801    ,   663 ,   9693    ,   5255    ,0 };
            const std::uint32_t dim3115Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   11  ,   37  ,   69  ,   65  ,   163 ,   61  ,   1567    ,   1879    ,   1853    ,   11099   ,   4523    ,0 };
            const std::uint32_t dim3116Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   5   ,   43  ,   75  ,   93  ,   81  ,   555 ,   803 ,   129 ,   4391    ,   3025    ,   1013    ,0 };
            const std::uint32_t dim3117Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   9   ,   49  ,   69  ,   185 ,   441 ,   567 ,   203 ,   2641    ,   4169    ,   15585   ,   10963   ,0 };
            const std::uint32_t dim3118Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   9   ,   35  ,   121 ,   117 ,   509 ,   93  ,   1381    ,   1329    ,   751 ,   2351    ,   11079   ,0 };
            const std::uint32_t dim3119Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   5   ,   61  ,   117 ,   83  ,   383 ,   961 ,   779 ,   1499    ,   4695    ,   3679    ,   20383   ,0 };
            const std::uint32_t dim3120Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   21  ,   63  ,   105 ,   15  ,   297 ,   923 ,   1867    ,   1667    ,   3523    ,   12387   ,   14977   ,0 };
            const std::uint32_t dim3121Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   7   ,   37  ,   123 ,   161 ,   343 ,   959 ,   1807    ,   1695    ,   6121    ,   8415    ,   5373    ,0 };
            const std::uint32_t dim3122Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   29  ,   51  ,   107 ,   151 ,   5   ,   715 ,   3   ,   3005    ,   1917    ,   12243   ,   13903   ,0 };
            const std::uint32_t dim3123Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   25  ,   29  ,   125 ,   165 ,   57  ,   729 ,   1187    ,   2273    ,   2869    ,   13149   ,   2831    ,0 };
            const std::uint32_t dim3124Kuo3Init[]   =   {   1   ,   1   ,   7   ,   15  ,   1   ,   15  ,   37  ,   15  ,   489 ,   879 ,   89  ,   2399    ,   547 ,   1959    ,   20073   ,0 };
            const std::uint32_t dim3125Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   5   ,   43  ,   101 ,   27  ,   425 ,   531 ,   1681    ,   3301    ,   5741    ,   7005    ,   6607    ,0 };
            const std::uint32_t dim3126Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   17  ,   53  ,   61  ,   165 ,   375 ,   7   ,   761 ,   1891    ,   1253    ,   2431    ,   15273   ,0 };
            const std::uint32_t dim3127Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   13  ,   23  ,   27  ,   229 ,   215 ,   729 ,   9   ,   779 ,   3583    ,   9109    ,   19059   ,0 };
            const std::uint32_t dim3128Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   3   ,   45  ,   99  ,   193 ,   203 ,   57  ,   147 ,   3953    ,   5263    ,   14641   ,   24729   ,0 };
            const std::uint32_t dim3129Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   11  ,   49  ,   57  ,   121 ,   413 ,   293 ,   1251    ,   3791    ,   1803    ,   12549   ,   3743    ,0 };
            const std::uint32_t dim3130Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   19  ,   55  ,   85  ,   1   ,   169 ,   539 ,   1565    ,   2157    ,   4493    ,   9169    ,   27583   ,0 };
            const std::uint32_t dim3131Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   19  ,   59  ,   95  ,   171 ,   471 ,   881 ,   663 ,   1489    ,   8013    ,   8981    ,   11443   ,0 };
            const std::uint32_t dim3132Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   17  ,   59  ,   25  ,   115 ,   439 ,   967 ,   1939    ,   905 ,   4141    ,   4177    ,   24827   ,0 };
            const std::uint32_t dim3133Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   29  ,   17  ,   23  ,   241 ,   49  ,   815 ,   1409    ,   3997    ,   1073    ,   2331    ,   455 ,0 };
            const std::uint32_t dim3134Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   27  ,   53  ,   51  ,   67  ,   405 ,   853 ,   1229    ,   2647    ,   4817    ,   521 ,   14343   ,0 };
            const std::uint32_t dim3135Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   1   ,   55  ,   83  ,   15  ,   41  ,   327 ,   1501    ,   1967    ,   5787    ,   3557    ,   7461    ,0 };
            const std::uint32_t dim3136Kuo3Init[]   =   {   1   ,   3   ,   5   ,   1   ,   23  ,   43  ,   93  ,   179 ,   373 ,   173 ,   1625    ,   487 ,   6973    ,   12479   ,   24659   ,0 };
            const std::uint32_t dim3137Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   3   ,   27  ,   9   ,   69  ,   501 ,   287 ,   945 ,   681 ,   3667    ,   7499    ,   24259   ,0 };
            const std::uint32_t dim3138Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   21  ,   55  ,   55  ,   13  ,   191 ,   25  ,   1339    ,   185 ,   4345    ,   13649   ,   17793   ,0 };
            const std::uint32_t dim3139Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   9   ,   13  ,   95  ,   127 ,   305 ,   961 ,   141 ,   3071    ,   683 ,   2141    ,   13757   ,0 };
            const std::uint32_t dim3140Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   21  ,   59  ,   83  ,   39  ,   137 ,   259 ,   689 ,   339 ,   105 ,   147 ,   26143   ,0 };
            const std::uint32_t dim3141Kuo3Init[]   =   {   1   ,   1   ,   5   ,   7   ,   31  ,   21  ,   121 ,   45  ,   103 ,   507 ,   1243    ,   3325    ,   441 ,   6743    ,   31937   ,0 };
            const std::uint32_t dim3142Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   7   ,   35  ,   5   ,   117 ,   433 ,   47  ,   261 ,   2405    ,   3361    ,   4361    ,   14397   ,0 };
            const std::uint32_t dim3143Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   19  ,   7   ,   19  ,   129 ,   79  ,   247 ,   35  ,   1483    ,   285 ,   4923    ,   14255   ,0 };
            const std::uint32_t dim3144Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   13  ,   3   ,   117 ,   169 ,   3   ,   527 ,   1295    ,   295 ,   2317    ,   5391    ,   27073   ,0 };
            const std::uint32_t dim3145Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   3   ,   53  ,   9   ,   175 ,   157 ,   917 ,   1297    ,   1917    ,   5575    ,   16183   ,   20165   ,0 };
            const std::uint32_t dim3146Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   25  ,   47  ,   61  ,   71  ,   129 ,   923 ,   367 ,   1623    ,   4281    ,   11241   ,   14759   ,0 };
            const std::uint32_t dim3147Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   23  ,   29  ,   53  ,   135 ,   381 ,   943 ,   1611    ,   1609    ,   5897    ,   393 ,   24647   ,0 };
            const std::uint32_t dim3148Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   3   ,   55  ,   5   ,   191 ,   305 ,   385 ,   1383    ,   913 ,   1017    ,   6463    ,   32323   ,0 };
            const std::uint32_t dim3149Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   3   ,   57  ,   113 ,   189 ,   41  ,   413 ,   1685    ,   2145    ,   6071    ,   7229    ,   11413   ,0 };
            const std::uint32_t dim3150Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   21  ,   5   ,   95  ,   87  ,   247 ,   175 ,   1265    ,   83  ,   511 ,   2821    ,   9881    ,0 };
            const std::uint32_t dim3151Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   31  ,   41  ,   127 ,   115 ,   457 ,   809 ,   2017    ,   3979    ,   3425    ,   159 ,   15903   ,0 };
            const std::uint32_t dim3152Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   29  ,   9   ,   85  ,   109 ,   299 ,   607 ,   1991    ,   3717    ,   4593    ,   8529    ,   10759   ,0 };
            const std::uint32_t dim3153Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   15  ,   49  ,   123 ,   61  ,   49  ,   413 ,   1599    ,   3697    ,   2481    ,   739 ,   1641    ,0 };
            const std::uint32_t dim3154Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   13  ,   55  ,   35  ,   217 ,   79  ,   167 ,   1215    ,   2687    ,   7303    ,   10331   ,   29985   ,0 };
            const std::uint32_t dim3155Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   29  ,   29  ,   37  ,   177 ,   63  ,   515 ,   1551    ,   1053    ,   893 ,   6831    ,   18039   ,0 };
            const std::uint32_t dim3156Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   25  ,   47  ,   57  ,   209 ,   345 ,   805 ,   999 ,   307 ,   3465    ,   13411   ,   17721   ,0 };
            const std::uint32_t dim3157Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   3   ,   63  ,   95  ,   243 ,   163 ,   923 ,   1181    ,   3319    ,   5903    ,   8195    ,   21217   ,0 };
            const std::uint32_t dim3158Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   15  ,   51  ,   75  ,   237 ,   25  ,   907 ,   395 ,   3721    ,   3371    ,   12425   ,   3795    ,0 };
            const std::uint32_t dim3159Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   15  ,   61  ,   127 ,   39  ,   359 ,   381 ,   1879    ,   2605    ,   7511    ,   4329    ,   28251   ,0 };
            const std::uint32_t dim3160Kuo3Init[]   =   {   1   ,   3   ,   5   ,   9   ,   11  ,   61  ,   1   ,   215 ,   503 ,   939 ,   419 ,   3353    ,   3013    ,   5391    ,   12567   ,0 };
            const std::uint32_t dim3161Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   7   ,   57  ,   123 ,   5   ,   473 ,   931 ,   759 ,   571 ,   2407    ,   13057   ,   7443    ,0 };
            const std::uint32_t dim3162Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   31  ,   17  ,   55  ,   181 ,   359 ,   913 ,   271 ,   935 ,   5911    ,   9767    ,   23  ,0 };
            const std::uint32_t dim3163Kuo3Init[]   =   {   1   ,   1   ,   1   ,   15  ,   1   ,   35  ,   93  ,   233 ,   109 ,   135 ,   1793    ,   2453    ,   6547    ,   15435   ,   16227   ,0 };
            const std::uint32_t dim3164Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   5   ,   37  ,   87  ,   51  ,   165 ,   455 ,   621 ,   881 ,   2377    ,   7977    ,   29763   ,0 };
            const std::uint32_t dim3165Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   31  ,   3   ,   119 ,   113 ,   141 ,   179 ,   621 ,   677 ,   1047    ,   2405    ,   28777   ,0 };
            const std::uint32_t dim3166Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   11  ,   25  ,   37  ,   15  ,   117 ,   509 ,   853 ,   747 ,   3065    ,   11569   ,   11731   ,0 };
            const std::uint32_t dim3167Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   31  ,   9   ,   27  ,   219 ,   71  ,   919 ,   1553    ,   3067    ,   6315    ,   17  ,   18511   ,0 };
            const std::uint32_t dim3168Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   27  ,   39  ,   111 ,   127 ,   315 ,   671 ,   845 ,   179 ,   8129    ,   15409   ,   21565   ,0 };
            const std::uint32_t dim3169Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   31  ,   37  ,   105 ,   67  ,   37  ,   725 ,   1947    ,   2743    ,   6241    ,   5465    ,   15025   ,0 };
            const std::uint32_t dim3170Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   7   ,   63  ,   63  ,   209 ,   431 ,   171 ,   845 ,   2067    ,   4829    ,   5627    ,   32333   ,0 };
            const std::uint32_t dim3171Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   7   ,   61  ,   105 ,   35  ,   113 ,   551 ,   1227    ,   867 ,   5907    ,   4389    ,   13281   ,0 };
            const std::uint32_t dim3172Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   31  ,   13  ,   123 ,   255 ,   497 ,   365 ,   921 ,   2009    ,   5365    ,   15443   ,   23455   ,0 };
            const std::uint32_t dim3173Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   5   ,   45  ,   91  ,   199 ,   417 ,   557 ,   827 ,   1911    ,   4173    ,   8705    ,   19437   ,0 };
            const std::uint32_t dim3174Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   31  ,   51  ,   69  ,   247 ,   407 ,   791 ,   1811    ,   1127    ,   6775    ,   8343    ,   19723   ,0 };
            const std::uint32_t dim3175Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   21  ,   43  ,   71  ,   191 ,   339 ,   219 ,   1809    ,   3735    ,   151 ,   3743    ,   11803   ,0 };
            const std::uint32_t dim3176Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   13  ,   21  ,   1   ,   233 ,   395 ,   335 ,   1929    ,   547 ,   2939    ,   9205    ,   22309   ,0 };
            const std::uint32_t dim3177Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   7   ,   5   ,   97  ,   189 ,   195 ,   191 ,   833 ,   269 ,   3255    ,   15301   ,   11593   ,0 };
            const std::uint32_t dim3178Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   31  ,   35  ,   53  ,   193 ,   143 ,   241 ,   763 ,   3221    ,   3217    ,   14915   ,   5603    ,0 };
            const std::uint32_t dim3179Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   3   ,   15  ,   47  ,   171 ,   349 ,   995 ,   1803    ,   2123    ,   8009    ,   10339   ,   1827    ,0 };
            const std::uint32_t dim3180Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   11  ,   37  ,   125 ,   149 ,   261 ,   507 ,   1603    ,   683 ,   137 ,   353 ,   26313   ,0 };
            const std::uint32_t dim3181Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   5   ,   19  ,   7   ,   97  ,   257 ,   439 ,   825 ,   265 ,   2493    ,   5567    ,   8575    ,0 };
            const std::uint32_t dim3182Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   9   ,   25  ,   101 ,   207 ,   345 ,   823 ,   1787    ,   2449    ,   4377    ,   10581   ,   19169   ,0 };
            const std::uint32_t dim3183Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   19  ,   5   ,   15  ,   19  ,   405 ,   665 ,   715 ,   3743    ,   23  ,   5061    ,   21145   ,0 };
            const std::uint32_t dim3184Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   11  ,   7   ,   73  ,   39  ,   77  ,   763 ,   1251    ,   3533    ,   6379    ,   16101   ,   8719    ,0 };
            const std::uint32_t dim3185Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   15  ,   55  ,   89  ,   249 ,   475 ,   641 ,   511 ,   111 ,   5797    ,   5627    ,   2187    ,0 };
            const std::uint32_t dim3186Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   7   ,   27  ,   117 ,   153 ,   387 ,   295 ,   309 ,   3293    ,   5197    ,   8359    ,   16643   ,0 };
            const std::uint32_t dim3187Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   5   ,   35  ,   45  ,   159 ,   495 ,   311 ,   463 ,   1249    ,   5163    ,   7939    ,   21405   ,0 };
            const std::uint32_t dim3188Kuo3Init[]   =   {   1   ,   3   ,   3   ,   7   ,   31  ,   39  ,   125 ,   167 ,   43  ,   41  ,   589 ,   3329    ,   5511    ,   7983    ,   17329   ,0 };
            const std::uint32_t dim3189Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   1   ,   17  ,   43  ,   95  ,   465 ,   587 ,   1189    ,   2629    ,   7613    ,   15115   ,   22299   ,0 };
            const std::uint32_t dim3190Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   21  ,   57  ,   73  ,   241 ,   149 ,   531 ,   827 ,   731 ,   7431    ,   14375   ,   16307   ,0 };
            const std::uint32_t dim3191Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   7   ,   25  ,   113 ,   115 ,   381 ,   951 ,   811 ,   305 ,   935 ,   2927    ,   18755   ,0 };
            const std::uint32_t dim3192Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   11  ,   53  ,   91  ,   197 ,   497 ,   9   ,   1009    ,   25  ,   2473    ,   2467    ,   8827    ,0 };
            const std::uint32_t dim3193Kuo3Init[]   =   {   1   ,   3   ,   3   ,   7   ,   23  ,   23  ,   15  ,   3   ,   131 ,   591 ,   379 ,   1227    ,   3479    ,   8409    ,   20177   ,0 };
            const std::uint32_t dim3194Kuo3Init[]   =   {   1   ,   3   ,   5   ,   9   ,   17  ,   47  ,   91  ,   107 ,   17  ,   175 ,   1181    ,   2097    ,   457 ,   10253   ,   24291   ,0 };
            const std::uint32_t dim3195Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   31  ,   57  ,   25  ,   117 ,   97  ,   707 ,   1875    ,   4059    ,   6997    ,   3533    ,   27781   ,0 };
            const std::uint32_t dim3196Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   7   ,   7   ,   53  ,   137 ,   255 ,   1017    ,   501 ,   847 ,   4569    ,   3665    ,   21377   ,0 };
            const std::uint32_t dim3197Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   19  ,   57  ,   39  ,   213 ,   67  ,   221 ,   149 ,   357 ,   1137    ,   12625   ,   13945   ,0 };
            const std::uint32_t dim3198Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   19  ,   53  ,   75  ,   67  ,   71  ,   811 ,   837 ,   3399    ,   3993    ,   3119    ,   13459   ,0 };
            const std::uint32_t dim3199Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   29  ,   7   ,   77  ,   249 ,   97  ,   159 ,   1097    ,   161 ,   1649    ,   4663    ,   8635    ,0 };
            const std::uint32_t dim3200Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   9   ,   11  ,   69  ,   151 ,   419 ,   11  ,   1457    ,   2357    ,   7259    ,   4059    ,   6189    ,0 };
            const std::uint32_t dim3201Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   29  ,   1   ,   109 ,   103 ,   129 ,   561 ,   1629    ,   237 ,   643 ,   14519   ,   22839   ,0 };
            const std::uint32_t dim3202Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   17  ,   25  ,   109 ,   213 ,   253 ,   427 ,   849 ,   4053    ,   3845    ,   8935    ,   21233   ,0 };
            const std::uint32_t dim3203Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   15  ,   53  ,   81  ,   127 ,   131 ,   523 ,   1303    ,   451 ,   3363    ,   14105   ,   28881   ,0 };
            const std::uint32_t dim3204Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   1   ,   29  ,   105 ,   75  ,   235 ,   407 ,   1555    ,   1247    ,   2329    ,   1259    ,   8653    ,0 };
            const std::uint32_t dim3205Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   31  ,   45  ,   9   ,   199 ,   315 ,   375 ,   205 ,   3157    ,   4247    ,   11961   ,   4039    ,0 };
            const std::uint32_t dim3206Kuo3Init[]   =   {   1   ,   3   ,   3   ,   5   ,   3   ,   39  ,   13  ,   125 ,   103 ,   359 ,   287 ,   3529    ,   2015    ,   3187    ,   26261   ,0 };
            const std::uint32_t dim3207Kuo3Init[]   =   {   1   ,   3   ,   3   ,   7   ,   3   ,   63  ,   81  ,   157 ,   169 ,   1005    ,   889 ,   2271    ,   7773    ,   8739    ,   11171   ,0 };
            const std::uint32_t dim3208Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   11  ,   63  ,   61  ,   67  ,   1   ,   919 ,   349 ,   1645    ,   8155    ,   219 ,   357 ,0 };
            const std::uint32_t dim3209Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   17  ,   39  ,   1   ,   253 ,   497 ,   409 ,   631 ,   1425    ,   7763    ,   3239    ,   5405    ,0 };
            const std::uint32_t dim3210Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   21  ,   57  ,   97  ,   231 ,   445 ,   417 ,   1567    ,   739 ,   6413    ,   13499   ,   16947   ,0 };
            const std::uint32_t dim3211Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   13  ,   59  ,   17  ,   15  ,   75  ,   197 ,   267 ,   1295    ,   3867    ,   6607    ,   31623   ,0 };
            const std::uint32_t dim3212Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   27  ,   1   ,   83  ,   97  ,   381 ,   931 ,   1133    ,   4091    ,   341 ,   7105    ,   28761   ,0 };
            const std::uint32_t dim3213Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   3   ,   39  ,   49  ,   237 ,   437 ,   353 ,   321 ,   3609    ,   4555    ,   8987    ,   28727   ,0 };
            const std::uint32_t dim3214Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   15  ,   49  ,   101 ,   255 ,   409 ,   231 ,   355 ,   2333    ,   7277    ,   2549    ,   1613    ,0 };
            const std::uint32_t dim3215Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   11  ,   49  ,   99  ,   201 ,   57  ,   705 ,   413 ,   2791    ,   5947    ,   8533    ,   22155   ,0 };
            const std::uint32_t dim3216Kuo3Init[]   =   {   1   ,   3   ,   1   ,   15  ,   13  ,   51  ,   91  ,   47  ,   165 ,   995 ,   1293    ,   3601    ,   5841    ,   4671    ,   27379   ,0 };
            const std::uint32_t dim3217Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   15  ,   47  ,   43  ,   97  ,   151 ,   75  ,   1229    ,   2525    ,   5085    ,   10969   ,   5195    ,0 };
            const std::uint32_t dim3218Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   7   ,   15  ,   65  ,   161 ,   423 ,   773 ,   291 ,   1081    ,   2127    ,   15861   ,   16051   ,0 };
            const std::uint32_t dim3219Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   11  ,   47  ,   47  ,   157 ,   369 ,   889 ,   221 ,   83  ,   3165    ,   12911   ,   20687   ,0 };
            const std::uint32_t dim3220Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   23  ,   63  ,   97  ,   191 ,   185 ,   863 ,   1611    ,   241 ,   4177    ,   14965   ,   22205   ,0 };
            const std::uint32_t dim3221Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   13  ,   11  ,   85  ,   109 ,   13  ,   401 ,   1365    ,   2637    ,   2119    ,   14673   ,   28813   ,0 };
            const std::uint32_t dim3222Kuo3Init[]   =   {   1   ,   1   ,   5   ,   7   ,   23  ,   13  ,   11  ,   9   ,   105 ,   891 ,   1511    ,   3969    ,   2097    ,   2089    ,   18535   ,0 };
            const std::uint32_t dim3223Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   3   ,   23  ,   67  ,   197 ,   309 ,   883 ,   1635    ,   359 ,   5023    ,   10693   ,   28537   ,0 };
            const std::uint32_t dim3224Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   1   ,   25  ,   63  ,   233 ,   445 ,   665 ,   1971    ,   1713    ,   1827    ,   14269   ,   19539   ,0 };
            const std::uint32_t dim3225Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   25  ,   27  ,   79  ,   131 ,   441 ,   465 ,   613 ,   2027    ,   2521    ,   11109   ,   14443   ,0 };
            const std::uint32_t dim3226Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   27  ,   1   ,   27  ,   123 ,   405 ,   567 ,   159 ,   2319    ,   5625    ,   4643    ,   1185    ,0 };
            const std::uint32_t dim3227Kuo3Init[]   =   {   1   ,   1   ,   7   ,   15  ,   15  ,   55  ,   21  ,   105 ,   353 ,   431 ,   955 ,   3341    ,   2891    ,   13667   ,   17787   ,0 };
            const std::uint32_t dim3228Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   25  ,   61  ,   11  ,   251 ,   459 ,   985 ,   1285    ,   811 ,   4279    ,   4579    ,   14313   ,0 };
            const std::uint32_t dim3229Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   13  ,   1   ,   63  ,   103 ,   113 ,   91  ,   1241    ,   2513    ,   767 ,   9037    ,   29591   ,0 };
            const std::uint32_t dim3230Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   31  ,   39  ,   87  ,   215 ,   421 ,   875 ,   913 ,   3593    ,   2215    ,   4889    ,   14595   ,0 };
            const std::uint32_t dim3231Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   17  ,   61  ,   99  ,   13  ,   475 ,   331 ,   541 ,   2363    ,   5697    ,   14867   ,   11483   ,0 };
            const std::uint32_t dim3232Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   17  ,   15  ,   7   ,   217 ,   219 ,   327 ,   1775    ,   939 ,   3953    ,   2393    ,   28241   ,0 };
            const std::uint32_t dim3233Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   11  ,   57  ,   75  ,   139 ,   123 ,   607 ,   87  ,   539 ,   4955    ,   6533    ,   31827   ,0 };
            const std::uint32_t dim3234Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   15  ,   15  ,   43  ,   127 ,   485 ,   1009    ,   1201    ,   919 ,   761 ,   385 ,   29889   ,0 };
            const std::uint32_t dim3235Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   3   ,   53  ,   47  ,   101 ,   463 ,   899 ,   523 ,   1009    ,   3541    ,   11191   ,   2257    ,0 };
            const std::uint32_t dim3236Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   31  ,   43  ,   9   ,   39  ,   201 ,   469 ,   839 ,   2509    ,   5645    ,   2861    ,   25533   ,0 };
            const std::uint32_t dim3237Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   19  ,   27  ,   69  ,   45  ,   367 ,   267 ,   953 ,   3711    ,   603 ,   3511    ,   13419   ,0 };
            const std::uint32_t dim3238Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   25  ,   39  ,   33  ,   89  ,   459 ,   573 ,   1643    ,   3291    ,   2371    ,   1749    ,   20693   ,0 };
            const std::uint32_t dim3239Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   11  ,   29  ,   103 ,   213 ,   13  ,   219 ,   2023    ,   1327    ,   4315    ,   13933   ,   19559   ,0 };
            const std::uint32_t dim3240Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   17  ,   49  ,   11  ,   241 ,   227 ,   157 ,   745 ,   1377    ,   5739    ,   14285   ,   26107   ,0 };
            const std::uint32_t dim3241Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   23  ,   11  ,   5   ,   213 ,   405 ,   415 ,   1911    ,   3763    ,   3403    ,   16079   ,   10957   ,0 };
            const std::uint32_t dim3242Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   31  ,   27  ,   79  ,   153 ,   403 ,   747 ,   269 ,   4039    ,   2791    ,   4711    ,   501 ,0 };
            const std::uint32_t dim3243Kuo3Init[]   =   {   1   ,   1   ,   7   ,   15  ,   1   ,   29  ,   105 ,   29  ,   131 ,   913 ,   265 ,   871 ,   2899    ,   11547   ,   20351   ,0 };
            const std::uint32_t dim3244Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   9   ,   47  ,   55  ,   121 ,   487 ,   349 ,   233 ,   1657    ,   3015    ,   12345   ,   2213    ,0 };
            const std::uint32_t dim3245Kuo3Init[]   =   {   1   ,   1   ,   7   ,   9   ,   1   ,   45  ,   49  ,   241 ,   81  ,   673 ,   1933    ,   3203    ,   7433    ,   14745   ,   5811    ,0 };
            const std::uint32_t dim3246Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   31  ,   31  ,   97  ,   97  ,   377 ,   795 ,   417 ,   3851    ,   4725    ,   9803    ,   16785   ,0 };
            const std::uint32_t dim3247Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   9   ,   5   ,   45  ,   141 ,   361 ,   523 ,   297 ,   2535    ,   4433    ,   16353   ,   28191   ,0 };
            const std::uint32_t dim3248Kuo3Init[]   =   {   1   ,   3   ,   3   ,   7   ,   9   ,   29  ,   47  ,   19  ,   419 ,   49  ,   825 ,   1771    ,   5439    ,   8611    ,   12659   ,0 };
            const std::uint32_t dim3249Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   19  ,   3   ,   89  ,   107 ,   407 ,   567 ,   807 ,   623 ,   7915    ,   8083    ,   6761    ,0 };
            const std::uint32_t dim3250Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   23  ,   35  ,   109 ,   23  ,   461 ,   401 ,   713 ,   965 ,   7687    ,   9729    ,   17287   ,0 };
            const std::uint32_t dim3251Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   11  ,   43  ,   79  ,   197 ,   249 ,   423 ,   953 ,   1621    ,   4045    ,   3913    ,   11143   ,0 };
            const std::uint32_t dim3252Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   19  ,   59  ,   91  ,   217 ,   481 ,   861 ,   1915    ,   1689    ,   2061    ,   5377    ,   8535    ,0 };
            const std::uint32_t dim3253Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   15  ,   57  ,   5   ,   81  ,   133 ,   833 ,   49  ,   3231    ,   6315    ,   9771    ,   5667    ,0 };
            const std::uint32_t dim3254Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   27  ,   15  ,   83  ,   11  ,   483 ,   799 ,   1423    ,   2121    ,   5385    ,   4541    ,   597 ,0 };
            const std::uint32_t dim3255Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   19  ,   25  ,   5   ,   111 ,   493 ,   531 ,   317 ,   5   ,   2601    ,   6909    ,   11515   ,0 };
            const std::uint32_t dim3256Kuo3Init[]   =   {   1   ,   3   ,   3   ,   7   ,   15  ,   33  ,   63  ,   89  ,   425 ,   913 ,   831 ,   3881    ,   2055    ,   4285    ,   13015   ,0 };
            const std::uint32_t dim3257Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   11  ,   5   ,   87  ,   255 ,   17  ,   731 ,   1149    ,   115 ,   1223    ,   413 ,   579 ,0 };
            const std::uint32_t dim3258Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   11  ,   27  ,   125 ,   97  ,   73  ,   221 ,   687 ,   623 ,   1617    ,   13347   ,   1369    ,0 };
            const std::uint32_t dim3259Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   19  ,   19  ,   39  ,   9   ,   273 ,   687 ,   805 ,   1105    ,   267 ,   8321    ,   17899   ,0 };
            const std::uint32_t dim3260Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   31  ,   25  ,   5   ,   209 ,   3   ,   503 ,   1757    ,   2071    ,   6251    ,   12821   ,   28241   ,0 };
            const std::uint32_t dim3261Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   7   ,   51  ,   25  ,   37  ,   197 ,   143 ,   1261    ,   1069    ,   6559    ,   5625    ,   30631   ,0 };
            const std::uint32_t dim3262Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   17  ,   15  ,   53  ,   71  ,   433 ,   133 ,   867 ,   3883    ,   3281    ,   3785    ,   11523   ,0 };
            const std::uint32_t dim3263Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   1   ,   31  ,   89  ,   165 ,   239 ,   525 ,   507 ,   3637    ,   4423    ,   1295    ,   9441    ,0 };
            const std::uint32_t dim3264Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   7   ,   11  ,   127 ,   151 ,   151 ,   821 ,   381 ,   23  ,   173 ,   14027   ,   8391    ,0 };
            const std::uint32_t dim3265Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   1   ,   51  ,   85  ,   67  ,   321 ,   797 ,   1625    ,   475 ,   313 ,   8189    ,   13315   ,0 };
            const std::uint32_t dim3266Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   25  ,   49  ,   1   ,   155 ,   497 ,   771 ,   457 ,   2097    ,   5997    ,   11363   ,   14715   ,0 };
            const std::uint32_t dim3267Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   15  ,   5   ,   89  ,   219 ,   441 ,   997 ,   127 ,   699 ,   5245    ,   3941    ,   14083   ,0 };
            const std::uint32_t dim3268Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   21  ,   13  ,   35  ,   239 ,   115 ,   57  ,   1479    ,   2813    ,   5249    ,   7733    ,   3135    ,0 };
            const std::uint32_t dim3269Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   11  ,   59  ,   49  ,   55  ,   183 ,   631 ,   365 ,   323 ,   6891    ,   3727    ,   24231   ,0 };
            const std::uint32_t dim3270Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   9   ,   29  ,   101 ,   59  ,   257 ,   995 ,   145 ,   3037    ,   7291    ,   16021   ,   31971   ,0 };
            const std::uint32_t dim3271Kuo3Init[]   =   {   1   ,   1   ,   1   ,   1   ,   19  ,   5   ,   51  ,   21  ,   207 ,   767 ,   1301    ,   3111    ,   7133    ,   9555    ,   24043   ,0 };
            const std::uint32_t dim3272Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   23  ,   45  ,   25  ,   149 ,   225 ,   141 ,   827 ,   37  ,   3767    ,   16305   ,   30229   ,0 };
            const std::uint32_t dim3273Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   21  ,   15  ,   51  ,   155 ,   185 ,   551 ,   243 ,   2493    ,   653 ,   10615   ,   28137   ,0 };
            const std::uint32_t dim3274Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   13  ,   55  ,   77  ,   71  ,   383 ,   605 ,   957 ,   1605    ,   6905    ,   12193   ,   26729   ,0 };
            const std::uint32_t dim3275Kuo3Init[]   =   {   1   ,   3   ,   1   ,   15  ,   13  ,   19  ,   95  ,   219 ,   435 ,   165 ,   1531    ,   2733    ,   4213    ,   3739    ,   10943   ,0 };
            const std::uint32_t dim3276Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   31  ,   35  ,   3   ,   85  ,   331 ,   161 ,   1167    ,   3627    ,   7075    ,   16189   ,   385 ,0 };
            const std::uint32_t dim3277Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   3   ,   17  ,   103 ,   205 ,   299 ,   917 ,   105 ,   1675    ,   3461    ,   895 ,   3279    ,0 };
            const std::uint32_t dim3278Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   25  ,   11  ,   47  ,   77  ,   91  ,   263 ,   1575    ,   1337    ,   5603    ,   6561    ,   4941    ,0 };
            const std::uint32_t dim3279Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   15  ,   17  ,   77  ,   69  ,   413 ,   343 ,   1923    ,   2013    ,   269 ,   12245   ,   14611   ,0 };
            const std::uint32_t dim3280Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   1   ,   29  ,   99  ,   83  ,   69  ,   871 ,   945 ,   1271    ,   5741    ,   2505    ,   4743    ,0 };
            const std::uint32_t dim3281Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   23  ,   55  ,   95  ,   17  ,   321 ,   929 ,   1499    ,   205 ,   5529    ,   3819    ,   29763   ,0 };
            const std::uint32_t dim3282Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   1   ,   47  ,   15  ,   151 ,   273 ,   991 ,   1993    ,   2325    ,   3633    ,   9033    ,   795 ,0 };
            const std::uint32_t dim3283Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   19  ,   59  ,   115 ,   79  ,   51  ,   585 ,   253 ,   1545    ,   2871    ,   2303    ,   23189   ,0 };
            const std::uint32_t dim3284Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   5   ,   49  ,   77  ,   79  ,   103 ,   719 ,   965 ,   2115    ,   2431    ,   7761    ,   7267    ,0 };
            const std::uint32_t dim3285Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   1   ,   33  ,   13  ,   121 ,   297 ,   217 ,   1143    ,   2185    ,   6007    ,   13233   ,   4529    ,0 };
            const std::uint32_t dim3286Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   1   ,   15  ,   17  ,   155 ,   321 ,   19  ,   1071    ,   3195    ,   3589    ,   12159   ,   30323   ,0 };
            const std::uint32_t dim3287Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   3   ,   57  ,   35  ,   197 ,   247 ,   449 ,   557 ,   809 ,   909 ,   9141    ,   26613   ,0 };
            const std::uint32_t dim3288Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   13  ,   43  ,   61  ,   177 ,   21  ,   161 ,   1823    ,   1077    ,   6523    ,   10765   ,   17427   ,0 };
            const std::uint32_t dim3289Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   13  ,   27  ,   77  ,   77  ,   315 ,   763 ,   853 ,   3801    ,   1505    ,   13801   ,   28217   ,0 };
            const std::uint32_t dim3290Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   15  ,   27  ,   45  ,   131 ,   271 ,   703 ,   1509    ,   443 ,   7739    ,   3011    ,   32463   ,0 };
            const std::uint32_t dim3291Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   17  ,   3   ,   93  ,   55  ,   331 ,   785 ,   585 ,   3451    ,   283 ,   2623    ,   21459   ,0 };
            const std::uint32_t dim3292Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   3   ,   3   ,   101 ,   25  ,   235 ,   721 ,   257 ,   3961    ,   7049    ,   9861    ,   21259   ,0 };
            const std::uint32_t dim3293Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   9   ,   31  ,   17  ,   17  ,   473 ,   155 ,   677 ,   603 ,   7503    ,   2845    ,   21089   ,0 };
            const std::uint32_t dim3294Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   11  ,   29  ,   5   ,   135 ,   141 ,   587 ,   1073    ,   461 ,   883 ,   16191   ,   16139   ,0 };
            const std::uint32_t dim3295Kuo3Init[]   =   {   1   ,   3   ,   1   ,   15  ,   25  ,   17  ,   87  ,   231 ,   63  ,   563 ,   1061    ,   3207    ,   2291    ,   913 ,   11871   ,0 };
            const std::uint32_t dim3296Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   7   ,   45  ,   53  ,   79  ,   247 ,   21  ,   1203    ,   1857    ,   5095    ,   7533    ,   4427    ,0 };
            const std::uint32_t dim3297Kuo3Init[]   =   {   1   ,   3   ,   5   ,   9   ,   17  ,   57  ,   29  ,   181 ,   345 ,   709 ,   1889    ,   2625    ,   8157    ,   4681    ,   21681   ,0 };
            const std::uint32_t dim3298Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   9   ,   63  ,   63  ,   183 ,   123 ,   957 ,   27  ,   3113    ,   1873    ,   8917    ,   8669    ,0 };
            const std::uint32_t dim3299Kuo3Init[]   =   {   1   ,   3   ,   5   ,   9   ,   29  ,   59  ,   31  ,   211 ,   459 ,   679 ,   259 ,   1885    ,   1895    ,   12815   ,   2437    ,0 };
            const std::uint32_t dim3300Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   13  ,   51  ,   125 ,   5   ,   15  ,   865 ,   901 ,   1803    ,   3277    ,   2879    ,   13057   ,0 };
            const std::uint32_t dim3301Kuo3Init[]   =   {   1   ,   1   ,   7   ,   9   ,   27  ,   39  ,   115 ,   67  ,   389 ,   1   ,   649 ,   639 ,   7183    ,   15929   ,   12953   ,0 };
            const std::uint32_t dim3302Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   3   ,   7   ,   21  ,   219 ,   241 ,   977 ,   1233    ,   1717    ,   7077    ,   8657    ,   1389    ,0 };
            const std::uint32_t dim3303Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   9   ,   51  ,   101 ,   127 ,   383 ,   801 ,   657 ,   2793    ,   1037    ,   11525   ,   7195    ,0 };
            const std::uint32_t dim3304Kuo3Init[]   =   {   1   ,   3   ,   3   ,   7   ,   1   ,   29  ,   71  ,   227 ,   19  ,   371 ,   363 ,   809 ,   4241    ,   5739    ,   26497   ,0 };
            const std::uint32_t dim3305Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   25  ,   23  ,   65  ,   161 ,   259 ,   135 ,   1047    ,   3943    ,   5749    ,   2931    ,   20647   ,0 };
            const std::uint32_t dim3306Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   1   ,   55  ,   1   ,   85  ,   271 ,   67  ,   1813    ,   77  ,   5435    ,   11867   ,   28375   ,0 };
            const std::uint32_t dim3307Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   31  ,   53  ,   43  ,   47  ,   285 ,   901 ,   901 ,   977 ,   733 ,   5291    ,   7043    ,0 };
            const std::uint32_t dim3308Kuo3Init[]   =   {   1   ,   3   ,   3   ,   7   ,   1   ,   59  ,   79  ,   123 ,   355 ,   721 ,   365 ,   2871    ,   6253    ,   14511   ,   4209    ,0 };
            const std::uint32_t dim3309Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   5   ,   49  ,   77  ,   107 ,   237 ,   257 ,   703 ,   1013    ,   4563    ,   8603    ,   10469   ,0 };
            const std::uint32_t dim3310Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   27  ,   59  ,   9   ,   129 ,   21  ,   991 ,   1283    ,   2871    ,   759 ,   5435    ,   30419   ,0 };
            const std::uint32_t dim3311Kuo3Init[]   =   {   1   ,   3   ,   5   ,   1   ,   19  ,   5   ,   5   ,   215 ,   91  ,   117 ,   939 ,   3595    ,   4331    ,   16083   ,   23279   ,0 };
            const std::uint32_t dim3312Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   7   ,   45  ,   45  ,   71  ,   75  ,   261 ,   685 ,   63  ,   3553    ,   16349   ,   6803    ,0 };
            const std::uint32_t dim3313Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   1   ,   23  ,   101 ,   11  ,   331 ,   407 ,   547 ,   1553    ,   7471    ,   6125    ,   3965    ,0 };
            const std::uint32_t dim3314Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   19  ,   29  ,   1   ,   53  ,   125 ,   775 ,   1381    ,   1885    ,   2655    ,   7199    ,   24073   ,0 };
            const std::uint32_t dim3315Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   27  ,   21  ,   79  ,   211 ,   433 ,   993 ,   143 ,   2241    ,   2607    ,   15447   ,   6121    ,0 };
            const std::uint32_t dim3316Kuo3Init[]   =   {   1   ,   3   ,   3   ,   7   ,   29  ,   39  ,   93  ,   65  ,   39  ,   577 ,   1471    ,   3491    ,   4413    ,   10553   ,   1339    ,0 };
            const std::uint32_t dim3317Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   21  ,   23  ,   75  ,   237 ,   439 ,   171 ,   361 ,   3283    ,   4145    ,   15267   ,   19917   ,0 };
            const std::uint32_t dim3318Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   9   ,   55  ,   39  ,   171 ,   423 ,   211 ,   43  ,   2597    ,   7135    ,   2437    ,   28965   ,0 };
            const std::uint32_t dim3319Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   11  ,   15  ,   71  ,   109 ,   337 ,   907 ,   135 ,   3557    ,   7359    ,   3539    ,   26953   ,0 };
            const std::uint32_t dim3320Kuo3Init[]   =   {   1   ,   1   ,   1   ,   15  ,   15  ,   63  ,   9   ,   47  ,   153 ,   157 ,   457 ,   857 ,   6985    ,   3559    ,   23285   ,0 };
            const std::uint32_t dim3321Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   21  ,   21  ,   3   ,   223 ,   67  ,   429 ,   497 ,   1303    ,   869 ,   3909    ,   17491   ,0 };
            const std::uint32_t dim3322Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   23  ,   37  ,   7   ,   197 ,   223 ,   597 ,   421 ,   845 ,   1397    ,   927 ,   20621   ,0 };
            const std::uint32_t dim3323Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   5   ,   37  ,   41  ,   83  ,   241 ,   301 ,   1157    ,   1087    ,   2365    ,   10905   ,   25195   ,0 };
            const std::uint32_t dim3324Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   25  ,   11  ,   75  ,   9   ,   31  ,   5   ,   1909    ,   681 ,   2891    ,   867 ,   4661    ,0 };
            const std::uint32_t dim3325Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   21  ,   33  ,   127 ,   233 ,   369 ,   381 ,   711 ,   133 ,   4463    ,   14119   ,   8877    ,0 };
            const std::uint32_t dim3326Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   21  ,   13  ,   5   ,   61  ,   29  ,   247 ,   923 ,   3533    ,   2831    ,   9645    ,   1537    ,0 };
            const std::uint32_t dim3327Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   29  ,   13  ,   29  ,   177 ,   195 ,   299 ,   445 ,   3753    ,   3699    ,   9383    ,   3249    ,0 };
            const std::uint32_t dim3328Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   17  ,   55  ,   21  ,   245 ,   11  ,   93  ,   1097    ,   1601    ,   4431    ,   5847    ,   21521   ,0 };
            const std::uint32_t dim3329Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   3   ,   37  ,   9   ,   179 ,   465 ,   123 ,   333 ,   3765    ,   1599    ,   8709    ,   11007   ,0 };
            const std::uint32_t dim3330Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   15  ,   25  ,   23  ,   217 ,   193 ,   767 ,   1433    ,   3435    ,   4891    ,   4109    ,   32061   ,0 };
            const std::uint32_t dim3331Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   21  ,   25  ,   123 ,   111 ,   377 ,   951 ,   1791    ,   2173    ,   569 ,   12831   ,   30045   ,0 };
            const std::uint32_t dim3332Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   11  ,   19  ,   75  ,   63  ,   497 ,   1005    ,   1215    ,   3957    ,   4137    ,   4851    ,   23547   ,0 };
            const std::uint32_t dim3333Kuo3Init[]   =   {   1   ,   1   ,   1   ,   15  ,   15  ,   9   ,   59  ,   143 ,   27  ,   941 ,   117 ,   3035    ,   1201    ,   4373    ,   19291   ,0 };
            const std::uint32_t dim3334Kuo3Init[]   =   {   1   ,   3   ,   3   ,   5   ,   1   ,   3   ,   37  ,   187 ,   115 ,   901 ,   617 ,   1959    ,   2243    ,   6563    ,   3087    ,0 };
            const std::uint32_t dim3335Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   17  ,   31  ,   67  ,   243 ,   35  ,   667 ,   1863    ,   1017    ,   6501    ,   9279    ,   18089   ,0 };
            const std::uint32_t dim3336Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   25  ,   19  ,   25  ,   255 ,   371 ,   27  ,   763 ,   2575    ,   695 ,   6155    ,   27761   ,0 };
            const std::uint32_t dim3337Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   5   ,   49  ,   79  ,   149 ,   331 ,   601 ,   199 ,   2927    ,   6293    ,   12449   ,   16397   ,0 };
            const std::uint32_t dim3338Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   29  ,   41  ,   29  ,   161 ,   191 ,   519 ,   445 ,   1159    ,   3009    ,   3413    ,   21757   ,0 };
            const std::uint32_t dim3339Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   23  ,   57  ,   93  ,   211 ,   57  ,   269 ,   1627    ,   3393    ,   873 ,   8189    ,   26059   ,0 };
            const std::uint32_t dim3340Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   27  ,   59  ,   125 ,   251 ,   259 ,   251 ,   79  ,   2693    ,   1815    ,   8759    ,   15667   ,0 };
            const std::uint32_t dim3341Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   31  ,   47  ,   15  ,   51  ,   17  ,   761 ,   589 ,   537 ,   3991    ,   2883    ,   6899    ,0 };
            const std::uint32_t dim3342Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   19  ,   39  ,   95  ,   143 ,   37  ,   183 ,   1719    ,   1819    ,   1659    ,   1043    ,   31929   ,0 };
            const std::uint32_t dim3343Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   15  ,   47  ,   105 ,   45  ,   67  ,   665 ,   1273    ,   221 ,   5423    ,   679 ,   8375    ,0 };
            const std::uint32_t dim3344Kuo3Init[]   =   {   1   ,   3   ,   1   ,   15  ,   23  ,   37  ,   123 ,   233 ,   117 ,   743 ,   785 ,   3871    ,   6031    ,   14379   ,   3339    ,0 };
            const std::uint32_t dim3345Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   1   ,   47  ,   33  ,   63  ,   309 ,   961 ,   83  ,   2539    ,   5935    ,   3121    ,   27671   ,0 };
            const std::uint32_t dim3346Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   21  ,   11  ,   103 ,   87  ,   433 ,   39  ,   293 ,   3217    ,   1533    ,   4511    ,   24493   ,0 };
            const std::uint32_t dim3347Kuo3Init[]   =   {   1   ,   1   ,   5   ,   7   ,   9   ,   51  ,   41  ,   133 ,   443 ,   605 ,   913 ,   377 ,   5969    ,   8401    ,   25427   ,0 };
            const std::uint32_t dim3348Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   21  ,   27  ,   59  ,   41  ,   155 ,   35  ,   897 ,   2317    ,   6557    ,   679 ,   7863    ,0 };
            const std::uint32_t dim3349Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   19  ,   47  ,   39  ,   53  ,   401 ,   199 ,   271 ,   1385    ,   3505    ,   719 ,   12963   ,0 };
            const std::uint32_t dim3350Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   13  ,   7   ,   11  ,   131 ,   455 ,   605 ,   523 ,   3435    ,   2313    ,   9861    ,   22437   ,0 };
            const std::uint32_t dim3351Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   19  ,   5   ,   125 ,   71  ,   425 ,   321 ,   1151    ,   231 ,   2585    ,   12899   ,   4789    ,0 };
            const std::uint32_t dim3352Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   15  ,   27  ,   35  ,   13  ,   187 ,   863 ,   795 ,   1005    ,   6443    ,   3011    ,   5275    ,0 };
            const std::uint32_t dim3353Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   25  ,   61  ,   33  ,   201 ,   343 ,   337 ,   1441    ,   2647    ,   3469    ,   5537    ,   30595   ,0 };
            const std::uint32_t dim3354Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   17  ,   13  ,   73  ,   209 ,   121 ,   411 ,   1027    ,   1879    ,   845 ,   14019   ,   4269    ,0 };
            const std::uint32_t dim3355Kuo3Init[]   =   {   1   ,   3   ,   5   ,   9   ,   11  ,   51  ,   69  ,   103 ,   245 ,   677 ,   409 ,   135 ,   3775    ,   15781   ,   24159   ,0 };
            const std::uint32_t dim3356Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   11  ,   9   ,   117 ,   101 ,   205 ,   745 ,   941 ,   125 ,   5915    ,   16305   ,   12547   ,0 };
            const std::uint32_t dim3357Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   9   ,   51  ,   37  ,   135 ,   79  ,   327 ,   1695    ,   2517    ,   2685    ,   1103    ,   6035    ,0 };
            const std::uint32_t dim3358Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   21  ,   33  ,   33  ,   229 ,   201 ,   939 ,   1625    ,   2043    ,   6661    ,   11821   ,   22881   ,0 };
            const std::uint32_t dim3359Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   23  ,   3   ,   23  ,   5   ,   329 ,   467 ,   963 ,   3833    ,   7345    ,   3225    ,   3709    ,0 };
            const std::uint32_t dim3360Kuo3Init[]   =   {   1   ,   3   ,   1   ,   11  ,   27  ,   21  ,   35  ,   159 ,   255 ,   707 ,   353 ,   3095    ,   6701    ,   14311   ,   839 ,0 };
            const std::uint32_t dim3361Kuo3Init[]   =   {   1   ,   1   ,   5   ,   7   ,   7   ,   63  ,   107 ,   227 ,   233 ,   303 ,   1523    ,   2019    ,   227 ,   14695   ,   20253   ,0 };
            const std::uint32_t dim3362Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   17  ,   29  ,   1   ,   167 ,   331 ,   795 ,   2027    ,   2333    ,   361 ,   1841    ,   4053    ,0 };
            const std::uint32_t dim3363Kuo3Init[]   =   {   1   ,   1   ,   7   ,   9   ,   1   ,   41  ,   71  ,   173 ,   103 ,   43  ,   635 ,   3311    ,   5883    ,   6517    ,   467 ,0 };
            const std::uint32_t dim3364Kuo3Init[]   =   {   1   ,   3   ,   7   ,   1   ,   3   ,   15  ,   101 ,   197 ,   449 ,   393 ,   889 ,   1189    ,   2665    ,   3647    ,   21977   ,0 };
            const std::uint32_t dim3365Kuo3Init[]   =   {   1   ,   3   ,   1   ,   11  ,   23  ,   5   ,   103 ,   199 ,   417 ,   729 ,   137 ,   1667    ,   5   ,   4769    ,   11981   ,0 };
            const std::uint32_t dim3366Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   17  ,   37  ,   73  ,   231 ,   195 ,   497 ,   1835    ,   1597    ,   403 ,   12569   ,   24761   ,0 };
            const std::uint32_t dim3367Kuo3Init[]   =   {   1   ,   3   ,   3   ,   7   ,   31  ,   37  ,   33  ,   39  ,   359 ,   961 ,   1745    ,   2353    ,   827 ,   6439    ,   27419   ,0 };
            const std::uint32_t dim3368Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   25  ,   25  ,   97  ,   111 ,   149 ,   799 ,   593 ,   1011    ,   5439    ,   2613    ,   3669    ,0 };
            const std::uint32_t dim3369Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   5   ,   21  ,   55  ,   37  ,   483 ,   407 ,   1059    ,   905 ,   5225    ,   9441    ,   17461   ,0 };
            const std::uint32_t dim3370Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   27  ,   15  ,   93  ,   87  ,   423 ,   625 ,   285 ,   4051    ,   7931    ,   9005    ,   4033    ,0 };
            const std::uint32_t dim3371Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   13  ,   17  ,   13  ,   221 ,   29  ,   179 ,   645 ,   2721    ,   4781    ,   6151    ,   6435    ,0 };
            const std::uint32_t dim3372Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   11  ,   59  ,   53  ,   249 ,   13  ,   295 ,   467 ,   1781    ,   2381    ,   2897    ,   11175   ,0 };
            const std::uint32_t dim3373Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   5   ,   41  ,   111 ,   129 ,   159 ,   363 ,   1109    ,   1547    ,   1209    ,   15035   ,   17367   ,0 };
            const std::uint32_t dim3374Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   23  ,   51  ,   55  ,   129 ,   435 ,   671 ,   947 ,   349 ,   1741    ,   15317   ,   28069   ,0 };
            const std::uint32_t dim3375Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   13  ,   9   ,   17  ,   111 ,   309 ,   987 ,   1521    ,   1243    ,   1815    ,   10055   ,   4883    ,0 };
            const std::uint32_t dim3376Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   21  ,   9   ,   19  ,   179 ,   315 ,   547 ,   1899    ,   1421    ,   589 ,   2563    ,   27523   ,0 };
            const std::uint32_t dim3377Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   25  ,   23  ,   115 ,   229 ,   439 ,   225 ,   1957    ,   3251    ,   4377    ,   12751   ,   2983    ,0 };
            const std::uint32_t dim3378Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   21  ,   23  ,   57  ,   187 ,   469 ,   575 ,   1587    ,   1983    ,   4353    ,   8605    ,   27269   ,0 };
            const std::uint32_t dim3379Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   11  ,   17  ,   51  ,   131 ,   93  ,   599 ,   487 ,   3397    ,   761 ,   11503   ,   13405   ,0 };
            const std::uint32_t dim3380Kuo3Init[]   =   {   1   ,   3   ,   1   ,   15  ,   27  ,   7   ,   13  ,   105 ,   189 ,   141 ,   715 ,   1571    ,   8103    ,   3233    ,   10481   ,0 };
            const std::uint32_t dim3381Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   21  ,   17  ,   103 ,   121 ,   229 ,   865 ,   1819    ,   171 ,   7281    ,   14085   ,   4483    ,0 };
            const std::uint32_t dim3382Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   21  ,   47  ,   105 ,   233 ,   325 ,   49  ,   1305    ,   2269    ,   7717    ,   2771    ,   27583   ,0 };
            const std::uint32_t dim3383Kuo3Init[]   =   {   1   ,   3   ,   3   ,   5   ,   17  ,   11  ,   101 ,   55  ,   191 ,   115 ,   1749    ,   3015    ,   1493    ,   15301   ,   1629    ,0 };
            const std::uint32_t dim3384Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   3   ,   39  ,   111 ,   51  ,   269 ,   451 ,   1327    ,   3389    ,   6461    ,   7361    ,   1311    ,0 };
            const std::uint32_t dim3385Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   23  ,   21  ,   103 ,   241 ,   3   ,   295 ,   981 ,   3969    ,   1631    ,   6301    ,   9481    ,0 };
            const std::uint32_t dim3386Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   17  ,   63  ,   49  ,   163 ,   89  ,   183 ,   555 ,   597 ,   3099    ,   8057    ,   28653   ,0 };
            const std::uint32_t dim3387Kuo3Init[]   =   {   1   ,   1   ,   7   ,   15  ,   9   ,   29  ,   35  ,   255 ,   173 ,   295 ,   2015    ,   283 ,   1179    ,   1677    ,   26417   ,0 };
            const std::uint32_t dim3388Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   11  ,   29  ,   73  ,   67  ,   5   ,   995 ,   1563    ,   2611    ,   7605    ,   13831   ,   7405    ,0 };
            const std::uint32_t dim3389Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   1   ,   27  ,   7   ,   251 ,   175 ,   683 ,   603 ,   2895    ,   6033    ,   4133    ,   2753    ,0 };
            const std::uint32_t dim3390Kuo3Init[]   =   {   1   ,   1   ,   7   ,   15  ,   23  ,   47  ,   45  ,   179 ,   289 ,   317 ,   1111    ,   1241    ,   7221    ,   8661    ,   31853   ,0 };
            const std::uint32_t dim3391Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   19  ,   19  ,   35  ,   139 ,   145 ,   469 ,   1455    ,   2335    ,   8009    ,   6609    ,   14847   ,0 };
            const std::uint32_t dim3392Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   17  ,   59  ,   115 ,   71  ,   197 ,   143 ,   1791    ,   3515    ,   3443    ,   5065    ,   22885   ,0 };
            const std::uint32_t dim3393Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   25  ,   19  ,   47  ,   223 ,   469 ,   745 ,   107 ,   2801    ,   6279    ,   16311   ,   15699   ,0 };
            const std::uint32_t dim3394Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   29  ,   47  ,   21  ,   227 ,   219 ,   331 ,   1179    ,   3409    ,   1787    ,   9113    ,   8359    ,0 };
            const std::uint32_t dim3395Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   7   ,   29  ,   43  ,   135 ,   137 ,   203 ,   241 ,   2421    ,   3125    ,   3883    ,   23519   ,0 };
            const std::uint32_t dim3396Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   3   ,   63  ,   5   ,   5   ,   425 ,   863 ,   1483    ,   4049    ,   2505    ,   3173    ,   3021    ,0 };
            const std::uint32_t dim3397Kuo3Init[]   =   {   1   ,   1   ,   1   ,   1   ,   31  ,   11  ,   37  ,   133 ,   349 ,   33  ,   1617    ,   7   ,   4945    ,   8143    ,   22027   ,0 };
            const std::uint32_t dim3398Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   13  ,   61  ,   61  ,   111 ,   203 ,   255 ,   1107    ,   425 ,   4571    ,   1537    ,   2547    ,0 };
            const std::uint32_t dim3399Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   19  ,   35  ,   5   ,   99  ,   33  ,   271 ,   203 ,   545 ,   1917    ,   8645    ,   30737   ,0 };
            const std::uint32_t dim3400Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   31  ,   33  ,   125 ,   119 ,   475 ,   497 ,   1341    ,   593 ,   3497    ,   2191    ,   28715   ,0 };
            const std::uint32_t dim3401Kuo3Init[]   =   {   1   ,   1   ,   7   ,   15  ,   17  ,   57  ,   87  ,   101 ,   487 ,   659 ,   497 ,   1243    ,   3353    ,   4803    ,   11445   ,0 };
            const std::uint32_t dim3402Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   31  ,   13  ,   55  ,   79  ,   233 ,   327 ,   1825    ,   245 ,   2693    ,   11761   ,   21155   ,0 };
            const std::uint32_t dim3403Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   21  ,   1   ,   15  ,   183 ,   113 ,   871 ,   251 ,   3573    ,   517 ,   9973    ,   28567   ,0 };
            const std::uint32_t dim3404Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   23  ,   53  ,   47  ,   143 ,   435 ,   107 ,   1091    ,   2139    ,   5985    ,   12541   ,   9857    ,0 };
            const std::uint32_t dim3405Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   23  ,   47  ,   125 ,   95  ,   333 ,   13  ,   285 ,   1691    ,   1899    ,   5625    ,   29883   ,0 };
            const std::uint32_t dim3406Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   1   ,   3   ,   21  ,   69  ,   425 ,   179 ,   1815    ,   2231    ,   6257    ,   1387    ,   26423   ,0 };
            const std::uint32_t dim3407Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   23  ,   11  ,   37  ,   223 ,   259 ,   767 ,   1521    ,   2445    ,   7725    ,   2013    ,   8365    ,0 };
            const std::uint32_t dim3408Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   13  ,   25  ,   125 ,   167 ,   423 ,   457 ,   1793    ,   4043    ,   913 ,   14917   ,   4577    ,0 };
            const std::uint32_t dim3409Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   13  ,   49  ,   95  ,   145 ,   251 ,   305 ,   1883    ,   3717    ,   7927    ,   6635    ,   9647    ,0 };
            const std::uint32_t dim3410Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   31  ,   33  ,   87  ,   189 ,   499 ,   933 ,   115 ,   3407    ,   1517    ,   157 ,   11815   ,0 };
            const std::uint32_t dim3411Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   15  ,   1   ,   7   ,   155 ,   493 ,   413 ,   231 ,   69  ,   3433    ,   13471   ,   26705   ,0 };
            const std::uint32_t dim3412Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   3   ,   59  ,   21  ,   81  ,   309 ,   445 ,   1467    ,   2655    ,   4871    ,   1667    ,   24557   ,0 };
            const std::uint32_t dim3413Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   11  ,   25  ,   73  ,   181 ,   355 ,   887 ,   967 ,   1131    ,   5137    ,   12695   ,   8561    ,0 };
            const std::uint32_t dim3414Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   27  ,   51  ,   19  ,   95  ,   165 ,   991 ,   2039    ,   3269    ,   2839    ,   12065   ,   26791   ,0 };
            const std::uint32_t dim3415Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   29  ,   15  ,   47  ,   89  ,   251 ,   149 ,   7   ,   447 ,   1945    ,   157 ,   3865    ,0 };
            const std::uint32_t dim3416Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   27  ,   33  ,   99  ,   211 ,   481 ,   95  ,   1361    ,   2933    ,   509 ,   16383   ,   11581   ,0 };
            const std::uint32_t dim3417Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   29  ,   43  ,   103 ,   141 ,   117 ,   505 ,   733 ,   2719    ,   2281    ,   4753    ,   27511   ,0 };
            const std::uint32_t dim3418Kuo3Init[]   =   {   1   ,   3   ,   1   ,   15  ,   5   ,   15  ,   25  ,   87  ,   255 ,   819 ,   1589    ,   2623    ,   2043    ,   7735    ,   7813    ,0 };
            const std::uint32_t dim3419Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   23  ,   57  ,   125 ,   145 ,   387 ,   729 ,   1845    ,   2809    ,   8067    ,   3487    ,   19919   ,0 };
            const std::uint32_t dim3420Kuo3Init[]   =   {   1   ,   3   ,   3   ,   5   ,   17  ,   59  ,   45  ,   11  ,   15  ,   505 ,   1859    ,   2193    ,   4581    ,   15553   ,   767 ,0 };
            const std::uint32_t dim3421Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   27  ,   47  ,   95  ,   147 ,   493 ,   259 ,   759 ,   4013    ,   5611    ,   1379    ,   13017   ,0 };
            const std::uint32_t dim3422Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   13  ,   3   ,   7   ,   193 ,   203 ,   379 ,   1445    ,   1599    ,   5915    ,   6025    ,   8037    ,0 };
            const std::uint32_t dim3423Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   7   ,   33  ,   77  ,   5   ,   449 ,   509 ,   1409    ,   2711    ,   5603    ,   9343    ,   10613   ,0 };
            const std::uint32_t dim3424Kuo3Init[]   =   {   1   ,   3   ,   5   ,   1   ,   31  ,   19  ,   65  ,   169 ,   429 ,   951 ,   1659    ,   3045    ,   735 ,   5089    ,   27215   ,0 };
            const std::uint32_t dim3425Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   13  ,   43  ,   73  ,   67  ,   449 ,   357 ,   285 ,   2291    ,   3493    ,   1575    ,   9281    ,0 };
            const std::uint32_t dim3426Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   7   ,   59  ,   15  ,   119 ,   479 ,   523 ,   201 ,   1381    ,   3245    ,   15591   ,   18785   ,0 };
            const std::uint32_t dim3427Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   13  ,   13  ,   29  ,   105 ,   65  ,   231 ,   161 ,   375 ,   3725    ,   5097    ,   23183   ,0 };
            const std::uint32_t dim3428Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   7   ,   21  ,   103 ,   155 ,   357 ,   661 ,   1035    ,   2421    ,   5989    ,   14613   ,   11499   ,0 };
            const std::uint32_t dim3429Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   13  ,   7   ,   45  ,   221 ,   189 ,   405 ,   1845    ,   3791    ,   2989    ,   495 ,   13899   ,0 };
            const std::uint32_t dim3430Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   27  ,   23  ,   91  ,   39  ,   385 ,   59  ,   1367    ,   3177    ,   1945    ,   15335   ,   7543    ,0 };
            const std::uint32_t dim3431Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   25  ,   49  ,   43  ,   215 ,   7   ,   1003    ,   831 ,   611 ,   183 ,   4627    ,   29423   ,0 };
            const std::uint32_t dim3432Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   29  ,   15  ,   57  ,   7   ,   259 ,   543 ,   1313    ,   449 ,   2497    ,   4337    ,   20879   ,0 };
            const std::uint32_t dim3433Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   17  ,   23  ,   111 ,   99  ,   185 ,   183 ,   1215    ,   1775    ,   8129    ,   4487    ,   7927    ,0 };
            const std::uint32_t dim3434Kuo3Init[]   =   {   1   ,   1   ,   1   ,   1   ,   21  ,   23  ,   55  ,   195 ,   219 ,   595 ,   703 ,   97  ,   7599    ,   15673   ,   25677   ,0 };
            const std::uint32_t dim3435Kuo3Init[]   =   {   1   ,   3   ,   1   ,   11  ,   19  ,   11  ,   121 ,   145 ,   237 ,   719 ,   201 ,   1335    ,   5147    ,   2195    ,   22909   ,0 };
            const std::uint32_t dim3436Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   27  ,   27  ,   45  ,   185 ,   251 ,   329 ,   1253    ,   1071    ,   2097    ,   9669    ,   2999    ,0 };
            const std::uint32_t dim3437Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   27  ,   35  ,   91  ,   183 ,   161 ,   393 ,   1269    ,   1945    ,   727 ,   9985    ,   9275    ,0 };
            const std::uint32_t dim3438Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   15  ,   43  ,   109 ,   25  ,   431 ,   641 ,   1291    ,   1169    ,   649 ,   16145   ,   27663   ,0 };
            const std::uint32_t dim3439Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   11  ,   59  ,   77  ,   193 ,   59  ,   325 ,   531 ,   365 ,   7285    ,   5111    ,   26647   ,0 };
            const std::uint32_t dim3440Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   15  ,   1   ,   33  ,   51  ,   427 ,   513 ,   575 ,   3739    ,   4593    ,   6669    ,   25369   ,0 };
            const std::uint32_t dim3441Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   5   ,   31  ,   109 ,   155 ,   83  ,   405 ,   657 ,   1095    ,   5087    ,   13835   ,   30395   ,0 };
            const std::uint32_t dim3442Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   11  ,   21  ,   115 ,   129 ,   389 ,   25  ,   657 ,   3455    ,   1357    ,   1501    ,   10589   ,0 };
            const std::uint32_t dim3443Kuo3Init[]   =   {   1   ,   3   ,   5   ,   9   ,   29  ,   21  ,   67  ,   153 ,   197 ,   703 ,   123 ,   1645    ,   2175    ,   5581    ,   26465   ,0 };
            const std::uint32_t dim3444Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   1   ,   21  ,   79  ,   71  ,   49  ,   719 ,   909 ,   3783    ,   5081    ,   13235   ,   19387   ,0 };
            const std::uint32_t dim3445Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   11  ,   47  ,   93  ,   213 ,   305 ,   673 ,   191 ,   2787    ,   3293    ,   6721    ,   19105   ,0 };
            const std::uint32_t dim3446Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   19  ,   1   ,   127 ,   189 ,   25  ,   201 ,   1867    ,   3541    ,   3215    ,   14025   ,   15823   ,0 };
            const std::uint32_t dim3447Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   9   ,   43  ,   75  ,   129 ,   335 ,   73  ,   995 ,   15  ,   4423    ,   6817    ,   14311   ,0 };
            const std::uint32_t dim3448Kuo3Init[]   =   {   1   ,   3   ,   3   ,   7   ,   13  ,   53  ,   97  ,   29  ,   311 ,   749 ,   1025    ,   5   ,   6001    ,   6831    ,   24699   ,0 };
            const std::uint32_t dim3449Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   29  ,   21  ,   117 ,   245 ,   389 ,   785 ,   405 ,   1455    ,   4249    ,   9663    ,   30027   ,0 };
            const std::uint32_t dim3450Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   13  ,   27  ,   113 ,   221 ,   293 ,   583 ,   1329    ,   3387    ,   4233    ,   11511   ,   30005   ,0 };
            const std::uint32_t dim3451Kuo3Init[]   =   {   1   ,   3   ,   1   ,   11  ,   11  ,   59  ,   85  ,   23  ,   435 ,   769 ,   889 ,   2993    ,   8075    ,   10831   ,   23109   ,0 };
            const std::uint32_t dim3452Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   31  ,   9   ,   59  ,   247 ,   387 ,   27  ,   791 ,   1381    ,   1881    ,   15223   ,   29481   ,0 };
            const std::uint32_t dim3453Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   1   ,   39  ,   93  ,   67  ,   293 ,   777 ,   1463    ,   1363    ,   3159    ,   6569    ,   18361   ,0 };
            const std::uint32_t dim3454Kuo3Init[]   =   {   1   ,   3   ,   1   ,   11  ,   25  ,   31  ,   49  ,   133 ,   459 ,   399 ,   593 ,   3907    ,   701 ,   9321    ,   28589   ,0 };
            const std::uint32_t dim3455Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   7   ,   35  ,   85  ,   247 ,   247 ,   577 ,   245 ,   1615    ,   337 ,   11289   ,   32149   ,0 };
            const std::uint32_t dim3456Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   21  ,   35  ,   67  ,   37  ,   77  ,   395 ,   907 ,   595 ,   883 ,   14931   ,   21875   ,0 };
            const std::uint32_t dim3457Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   5   ,   25  ,   1   ,   69  ,   307 ,   419 ,   1875    ,   3075    ,   15  ,   5853    ,   3177    ,0 };
            const std::uint32_t dim3458Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   15  ,   7   ,   15  ,   17  ,   67  ,   577 ,   1525    ,   1847    ,   481 ,   15451   ,   21229   ,0 };
            const std::uint32_t dim3459Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   23  ,   35  ,   79  ,   179 ,   397 ,   403 ,   1935    ,   3371    ,   3511    ,   13593   ,   30241   ,0 };
            const std::uint32_t dim3460Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   13  ,   11  ,   79  ,   215 ,   409 ,   577 ,   1301    ,   451 ,   5171    ,   1555    ,   18445   ,0 };
            const std::uint32_t dim3461Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   25  ,   35  ,   71  ,   65  ,   371 ,   667 ,   247 ,   3815    ,   4383    ,   6429    ,   4667    ,0 };
            const std::uint32_t dim3462Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   17  ,   45  ,   115 ,   217 ,   353 ,   501 ,   1087    ,   1521    ,   2621    ,   4847    ,   12647   ,0 };
            const std::uint32_t dim3463Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   5   ,   25  ,   75  ,   33  ,   421 ,   39  ,   1857    ,   2189    ,   2383    ,   4401    ,   11737   ,0 };
            const std::uint32_t dim3464Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   7   ,   23  ,   123 ,   155 ,   343 ,   85  ,   879 ,   595 ,   6419    ,   3789    ,   31233   ,0 };
            const std::uint32_t dim3465Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   29  ,   55  ,   75  ,   203 ,   319 ,   465 ,   1903    ,   595 ,   8127    ,   9773    ,   4083    ,0 };
            const std::uint32_t dim3466Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   27  ,   31  ,   55  ,   147 ,   17  ,   893 ,   33  ,   3239    ,   1773    ,   2111    ,   19833   ,0 };
            const std::uint32_t dim3467Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   27  ,   39  ,   3   ,   131 ,   401 ,   843 ,   1229    ,   227 ,   5221    ,   5845    ,   29029   ,0 };
            const std::uint32_t dim3468Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   15  ,   47  ,   113 ,   11  ,   361 ,   95  ,   1303    ,   333 ,   5139    ,   8393    ,   2225    ,0 };
            const std::uint32_t dim3469Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   27  ,   53  ,   45  ,   111 ,   377 ,   41  ,   985 ,   931 ,   3901    ,   13921   ,   25305   ,0 };
            const std::uint32_t dim3470Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   23  ,   23  ,   95  ,   227 ,   207 ,   71  ,   525 ,   3843    ,   6025    ,   16335   ,   30519   ,0 };
            const std::uint32_t dim3471Kuo3Init[]   =   {   1   ,   3   ,   5   ,   1   ,   9   ,   55  ,   95  ,   69  ,   457 ,   823 ,   479 ,   4073    ,   3227    ,   1355    ,   12937   ,0 };
            const std::uint32_t dim3472Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   7   ,   17  ,   67  ,   143 ,   189 ,   79  ,   653 ,   2791    ,   1193    ,   9409    ,   3561    ,0 };
            const std::uint32_t dim3473Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   29  ,   53  ,   67  ,   253 ,   471 ,   649 ,   669 ,   1621    ,   1199    ,   12889   ,   27943   ,0 };
            const std::uint32_t dim3474Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   15  ,   3   ,   93  ,   33  ,   335 ,   899 ,   1897    ,   1689    ,   2753    ,   473 ,   21935   ,0 };
            const std::uint32_t dim3475Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   27  ,   29  ,   17  ,   167 ,   467 ,   261 ,   671 ,   2449    ,   7433    ,   5669    ,   77  ,0 };
            const std::uint32_t dim3476Kuo3Init[]   =   {   1   ,   1   ,   7   ,   9   ,   5   ,   37  ,   85  ,   103 ,   19  ,   971 ,   1851    ,   231 ,   7897    ,   1783    ,   12659   ,0 };
            const std::uint32_t dim3477Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   17  ,   57  ,   1   ,   7   ,   491 ,   887 ,   341 ,   3859    ,   2783    ,   9547    ,   26867   ,0 };
            const std::uint32_t dim3478Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   29  ,   45  ,   77  ,   219 ,   131 ,   573 ,   1015    ,   765 ,   6211    ,   3243    ,   32547   ,0 };
            const std::uint32_t dim3479Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   19  ,   51  ,   61  ,   27  ,   415 ,   125 ,   69  ,   2151    ,   3385    ,   1405    ,   25509   ,0 };
            const std::uint32_t dim3480Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   23  ,   17  ,   19  ,   35  ,   489 ,   869 ,   687 ,   1047    ,   6031    ,   589 ,   3611    ,0 };
            const std::uint32_t dim3481Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   19  ,   27  ,   47  ,   175 ,   23  ,   427 ,   137 ,   2733    ,   1795    ,   483 ,   11083   ,0 };
            const std::uint32_t dim3482Kuo3Init[]   =   {   1   ,   1   ,   1   ,   1   ,   23  ,   41  ,   93  ,   229 ,   407 ,   751 ,   635 ,   3125    ,   831 ,   2121    ,   8463    ,0 };
            const std::uint32_t dim3483Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   27  ,   61  ,   27  ,   21  ,   337 ,   33  ,   1373    ,   37  ,   89  ,   7527    ,   21165   ,0 };
            const std::uint32_t dim3484Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   25  ,   55  ,   51  ,   111 ,   497 ,   737 ,   1097    ,   165 ,   7879    ,   1509    ,   5025    ,0 };
            const std::uint32_t dim3485Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   3   ,   51  ,   61  ,   19  ,   75  ,   1001    ,   1535    ,   2689    ,   2903    ,   9675    ,   22209   ,0 };
            const std::uint32_t dim3486Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   27  ,   7   ,   89  ,   219 ,   459 ,   403 ,   1963    ,   979 ,   3987    ,   4165    ,   5027    ,0 };
            const std::uint32_t dim3487Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   15  ,   51  ,   113 ,   37  ,   105 ,   57  ,   589 ,   3583    ,   7205    ,   107 ,   29687   ,0 };
            const std::uint32_t dim3488Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   1   ,   57  ,   125 ,   131 ,   265 ,   957 ,   461 ,   1413    ,   3961    ,   10543   ,   14951   ,0 };
            const std::uint32_t dim3489Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   19  ,   53  ,   125 ,   41  ,   417 ,   629 ,   153 ,   2531    ,   5655    ,   1919    ,   14615   ,0 };
            const std::uint32_t dim3490Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   1   ,   21  ,   19  ,   123 ,   3   ,   601 ,   1781    ,   2237    ,   705 ,   14229   ,   6739    ,0 };
            const std::uint32_t dim3491Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   3   ,   3   ,   23  ,   71  ,   225 ,   507 ,   619 ,   493 ,   5917    ,   1145    ,   7303    ,0 };
            const std::uint32_t dim3492Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   3   ,   19  ,   89  ,   237 ,   497 ,   3   ,   91  ,   2559    ,   6347    ,   8925    ,   9845    ,0 };
            const std::uint32_t dim3493Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   11  ,   47  ,   85  ,   147 ,   339 ,   499 ,   511 ,   731 ,   3063    ,   5363    ,   19841   ,0 };
            const std::uint32_t dim3494Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   19  ,   41  ,   105 ,   225 ,   37  ,   181 ,   127 ,   2167    ,   4247    ,   915 ,   14507   ,0 };
            const std::uint32_t dim3495Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   31  ,   7   ,   23  ,   229 ,   165 ,   485 ,   693 ,   3279    ,   7407    ,   9883    ,   31803   ,0 };
            const std::uint32_t dim3496Kuo3Init[]   =   {   1   ,   3   ,   5   ,   9   ,   15  ,   33  ,   1   ,   99  ,   79  ,   589 ,   411 ,   2783    ,   3437    ,   2151    ,   11585   ,0 };
            const std::uint32_t dim3497Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   25  ,   15  ,   95  ,   221 ,   399 ,   793 ,   617 ,   2431    ,   6859    ,   2893    ,   8919    ,0 };
            const std::uint32_t dim3498Kuo3Init[]   =   {   1   ,   3   ,   1   ,   11  ,   21  ,   57  ,   127 ,   1   ,   81  ,   657 ,   1935    ,   1937    ,   1635    ,   4079    ,   6677    ,0 };
            const std::uint32_t dim3499Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   17  ,   7   ,   19  ,   167 ,   483 ,   53  ,   49  ,   1187    ,   789 ,   1787    ,   4103    ,0 };
            const std::uint32_t dim3500Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   11  ,   1   ,   83  ,   223 ,   289 ,   119 ,   1263    ,   2995    ,   5697    ,   5835    ,   7127    ,0 };
            const std::uint32_t dim3501Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   1   ,   25  ,   59  ,   59  ,   223 ,   309 ,   1133    ,   773 ,   8171    ,   12881   ,   21959   ,0 };
            const std::uint32_t dim3502Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   7   ,   43  ,   63  ,   99  ,   503 ,   527 ,   1915    ,   1147    ,   2729    ,   8311    ,   13451   ,0 };
            const std::uint32_t dim3503Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   25  ,   37  ,   61  ,   41  ,   25  ,   681 ,   1029    ,   1715    ,   63  ,   6913    ,   31299   ,0 };
            const std::uint32_t dim3504Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   29  ,   41  ,   25  ,   135 ,   241 ,   331 ,   51  ,   2305    ,   5149    ,   12295   ,   8891    ,0 };
            const std::uint32_t dim3505Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   7   ,   53  ,   25  ,   127 ,   227 ,   711 ,   1165    ,   2563    ,   2681    ,   1331    ,   8435    ,0 };
            const std::uint32_t dim3506Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   29  ,   43  ,   27  ,   105 ,   371 ,   691 ,   77  ,   1847    ,   6097    ,   1253    ,   1163    ,0 };
            const std::uint32_t dim3507Kuo3Init[]   =   {   1   ,   3   ,   5   ,   1   ,   23  ,   43  ,   23  ,   185 ,   287 ,   407 ,   1523    ,   1923    ,   2121    ,   3297    ,   21549   ,0 };
            const std::uint32_t dim3508Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   31  ,   45  ,   19  ,   85  ,   323 ,   837 ,   99  ,   581 ,   6607    ,   3685    ,   21853   ,0 };
            const std::uint32_t dim3509Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   31  ,   27  ,   107 ,   55  ,   79  ,   339 ,   1739    ,   2373    ,   6393    ,   6557    ,   20651   ,0 };
            const std::uint32_t dim3510Kuo3Init[]   =   {   1   ,   3   ,   1   ,   11  ,   7   ,   23  ,   63  ,   43  ,   237 ,   753 ,   1347    ,   1775    ,   6663    ,   2907    ,   2905    ,0 };
            const std::uint32_t dim3511Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   1   ,   3   ,   99  ,   135 ,   247 ,   249 ,   757 ,   619 ,   3497    ,   2421    ,   6601    ,0 };
            const std::uint32_t dim3512Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   5   ,   61  ,   91  ,   151 ,   283 ,   723 ,   1931    ,   3799    ,   2737    ,   14833   ,   2363    ,0 };
            const std::uint32_t dim3513Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   9   ,   15  ,   53  ,   233 ,   365 ,   323 ,   1141    ,   3523    ,   7771    ,   707 ,   1837    ,0 };
            const std::uint32_t dim3514Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   11  ,   43  ,   87  ,   63  ,   425 ,   149 ,   1121    ,   4051    ,   5391    ,   591 ,   19849   ,0 };
            const std::uint32_t dim3515Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   15  ,   39  ,   55  ,   233 ,   401 ,   337 ,   289 ,   693 ,   3659    ,   10381   ,   25723   ,0 };
            const std::uint32_t dim3516Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   3   ,   11  ,   55  ,   89  ,   293 ,   235 ,   893 ,   853 ,   1281    ,   13845   ,   7123    ,0 };
            const std::uint32_t dim3517Kuo3Init[]   =   {   1   ,   1   ,   7   ,   15  ,   11  ,   1   ,   41  ,   187 ,   297 ,   557 ,   1951    ,   4007    ,   2429    ,   493 ,   31645   ,0 };
            const std::uint32_t dim3518Kuo3Init[]   =   {   1   ,   1   ,   1   ,   1   ,   31  ,   39  ,   113 ,   3   ,   11  ,   217 ,   1841    ,   545 ,   1953    ,   1667    ,   28317   ,0 };
            const std::uint32_t dim3519Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   31  ,   31  ,   125 ,   217 ,   127 ,   561 ,   983 ,   3651    ,   6649    ,   11859   ,   3887    ,0 };
            const std::uint32_t dim3520Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   17  ,   51  ,   107 ,   25  ,   511 ,   777 ,   771 ,   2359    ,   275 ,   16351   ,   15639   ,0 };
            const std::uint32_t dim3521Kuo3Init[]   =   {   1   ,   3   ,   5   ,   1   ,   11  ,   13  ,   9   ,   167 ,   505 ,   667 ,   155 ,   2857    ,   4043    ,   12145   ,   3369    ,0 };
            const std::uint32_t dim3522Kuo3Init[]   =   {   1   ,   3   ,   7   ,   1   ,   15  ,   33  ,   83  ,   217 ,   333 ,   847 ,   679 ,   3981    ,   925 ,   3465    ,   1217    ,0 };
            const std::uint32_t dim3523Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   13  ,   55  ,   111 ,   101 ,   455 ,   929 ,   1755    ,   2177    ,   931 ,   8083    ,   1207    ,0 };
            const std::uint32_t dim3524Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   21  ,   29  ,   25  ,   213 ,   113 ,   51  ,   1913    ,   1131    ,   1981    ,   16221   ,   32569   ,0 };
            const std::uint32_t dim3525Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   13  ,   9   ,   105 ,   153 ,   317 ,   755 ,   363 ,   2833    ,   4463    ,   2607    ,   17587   ,0 };
            const std::uint32_t dim3526Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   7   ,   15  ,   71  ,   133 ,   141 ,   639 ,   273 ,   1445    ,   4571    ,   13313   ,   319 ,0 };
            const std::uint32_t dim3527Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   23  ,   17  ,   55  ,   49  ,   159 ,   713 ,   1127    ,   2537    ,   4927    ,   4389    ,   8361    ,0 };
            const std::uint32_t dim3528Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   31  ,   23  ,   35  ,   237 ,   7   ,   801 ,   1939    ,   2243    ,   3891    ,   12379   ,   251 ,0 };
            const std::uint32_t dim3529Kuo3Init[]   =   {   1   ,   1   ,   7   ,   15  ,   17  ,   11  ,   33  ,   89  ,   39  ,   87  ,   1963    ,   1591    ,   7775    ,   5091    ,   23503   ,0 };
            const std::uint32_t dim3530Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   31  ,   63  ,   93  ,   55  ,   197 ,   627 ,   1887    ,   899 ,   2491    ,   7713    ,   9921    ,0 };
            const std::uint32_t dim3531Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   27  ,   17  ,   27  ,   33  ,   413 ,   131 ,   1713    ,   615 ,   1775    ,   237 ,   2775    ,0 };
            const std::uint32_t dim3532Kuo3Init[]   =   {   1   ,   3   ,   5   ,   9   ,   23  ,   3   ,   83  ,   69  ,   113 ,   311 ,   1199    ,   2593    ,   3745    ,   14473   ,   727 ,0 };
            const std::uint32_t dim3533Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   3   ,   57  ,   111 ,   195 ,   303 ,   713 ,   1305    ,   955 ,   7415    ,   15625   ,   6491    ,0 };
            const std::uint32_t dim3534Kuo3Init[]   =   {   1   ,   3   ,   1   ,   15  ,   25  ,   37  ,   3   ,   149 ,   7   ,   923 ,   1367    ,   3743    ,   5887    ,   5683    ,   17437   ,0 };
            const std::uint32_t dim3535Kuo3Init[]   =   {   1   ,   3   ,   3   ,   7   ,   5   ,   33  ,   85  ,   149 ,   339 ,   223 ,   1359    ,   1881    ,   4383    ,   8949    ,   1331    ,0 };
            const std::uint32_t dim3536Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   21  ,   27  ,   85  ,   209 ,   205 ,   597 ,   655 ,   2759    ,   109 ,   4963    ,   13055   ,0 };
            const std::uint32_t dim3537Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   3   ,   29  ,   99  ,   15  ,   399 ,   233 ,   1697    ,   2613    ,   1819    ,   9059    ,   10329   ,0 };
            const std::uint32_t dim3538Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   19  ,   13  ,   69  ,   87  ,   451 ,   389 ,   1065    ,   665 ,   7217    ,   12907   ,   32423   ,0 };
            const std::uint32_t dim3539Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   23  ,   57  ,   127 ,   107 ,   181 ,   231 ,   1233    ,   1593    ,   6365    ,   13919   ,   29379   ,0 };
            const std::uint32_t dim3540Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   29  ,   43  ,   11  ,   119 ,   165 ,   835 ,   323 ,   3051    ,   3641    ,   13841   ,   26399   ,0 };
            const std::uint32_t dim3541Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   15  ,   27  ,   41  ,   97  ,   317 ,   565 ,   1589    ,   2091    ,   1213    ,   12143   ,   26777   ,0 };
            const std::uint32_t dim3542Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   3   ,   17  ,   65  ,   221 ,   183 ,   265 ,   363 ,   1013    ,   7269    ,   13731   ,   25029   ,0 };
            const std::uint32_t dim3543Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   13  ,   13  ,   123 ,   59  ,   193 ,   95  ,   1909    ,   1701    ,   6123    ,   5599    ,   17805   ,0 };
            const std::uint32_t dim3544Kuo3Init[]   =   {   1   ,   1   ,   1   ,   1   ,   3   ,   51  ,   1   ,   155 ,   59  ,   199 ,   1751    ,   813 ,   441 ,   5615    ,   28115   ,0 };
            const std::uint32_t dim3545Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   13  ,   33  ,   37  ,   245 ,   343 ,   21  ,   1083    ,   2177    ,   4593    ,   13995   ,   12465   ,0 };
            const std::uint32_t dim3546Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   21  ,   57  ,   31  ,   65  ,   15  ,   427 ,   981 ,   1047    ,   7731    ,   763 ,   26335   ,0 };
            const std::uint32_t dim3547Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   1   ,   15  ,   19  ,   207 ,   127 ,   623 ,   949 ,   663 ,   2691    ,   505 ,   10667   ,0 };
            const std::uint32_t dim3548Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   3   ,   7   ,   31  ,   175 ,   225 ,   707 ,   1393    ,   1661    ,   2761    ,   4675    ,   16195   ,0 };
            const std::uint32_t dim3549Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   21  ,   35  ,   17  ,   61  ,   337 ,   307 ,   191 ,   1077    ,   7331    ,   8965    ,   18963   ,0 };
            const std::uint32_t dim3550Kuo3Init[]   =   {   1   ,   3   ,   3   ,   7   ,   23  ,   53  ,   37  ,   95  ,   229 ,   125 ,   813 ,   2279    ,   4915    ,   10637   ,   15533   ,0 };
            const std::uint32_t dim3551Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   21  ,   9   ,   61  ,   183 ,   457 ,   997 ,   929 ,   2245    ,   6213    ,   11179   ,   1803    ,0 };
            const std::uint32_t dim3552Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   11  ,   63  ,   21  ,   235 ,   259 ,   161 ,   1347    ,   2807    ,   3991    ,   14205   ,   26369   ,0 };
            const std::uint32_t dim3553Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   13  ,   3   ,   33  ,   237 ,   473 ,   167 ,   1341    ,   3617    ,   3671    ,   15041   ,   29603   ,0 };
            const std::uint32_t dim3554Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   17  ,   1   ,   105 ,   169 ,   25  ,   825 ,   1703    ,   751 ,   5461    ,   13121   ,   30917   ,0 };
            const std::uint32_t dim3555Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   9   ,   31  ,   19  ,   231 ,   137 ,   601 ,   1177    ,   327 ,   3811    ,   7553    ,   13453   ,0 };
            const std::uint32_t dim3556Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   7   ,   43  ,   7   ,   231 ,   171 ,   695 ,   331 ,   1493    ,   2437    ,   12487   ,   25451   ,0 };
            const std::uint32_t dim3557Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   27  ,   19  ,   103 ,   157 ,   145 ,   267 ,   1417    ,   3867    ,   7477    ,   15399   ,   31311   ,0 };
            const std::uint32_t dim3558Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   5   ,   11  ,   111 ,   89  ,   45  ,   685 ,   1283    ,   2581    ,   819 ,   3675    ,   25143   ,0 };
            const std::uint32_t dim3559Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   31  ,   5   ,   85  ,   143 ,   113 ,   693 ,   529 ,   321 ,   5407    ,   14411   ,   27513   ,0 };
            const std::uint32_t dim3560Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   19  ,   5   ,   103 ,   79  ,   439 ,   327 ,   1769    ,   3371    ,   7191    ,   5827    ,   10145   ,0 };
            const std::uint32_t dim3561Kuo3Init[]   =   {   1   ,   3   ,   1   ,   15  ,   1   ,   3   ,   63  ,   57  ,   331 ,   525 ,   239 ,   307 ,   4927    ,   13525   ,   26383   ,0 };
            const std::uint32_t dim3562Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   11  ,   31  ,   49  ,   137 ,   407 ,   335 ,   905 ,   3441    ,   623 ,   11301   ,   8933    ,0 };
            const std::uint32_t dim3563Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   29  ,   59  ,   41  ,   143 ,   103 ,   255 ,   1195    ,   3033    ,   6785    ,   12717   ,   5789    ,0 };
            const std::uint32_t dim3564Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   11  ,   3   ,   107 ,   121 ,   173 ,   481 ,   3   ,   1485    ,   4557    ,   11095   ,   24611   ,0 };
            const std::uint32_t dim3565Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   3   ,   47  ,   17  ,   107 ,   77  ,   323 ,   1349    ,   2285    ,   871 ,   7301    ,   27811   ,0 };
            const std::uint32_t dim3566Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   9   ,   49  ,   95  ,   53  ,   337 ,   323 ,   1231    ,   3825    ,   7403    ,   12851   ,   31133   ,0 };
            const std::uint32_t dim3567Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   29  ,   59  ,   123 ,   239 ,   251 ,   513 ,   259 ,   529 ,   1267    ,   13323   ,   15509   ,0 };
            const std::uint32_t dim3568Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   25  ,   61  ,   91  ,   75  ,   83  ,   575 ,   671 ,   2575    ,   2871    ,   11909   ,   31371   ,0 };
            const std::uint32_t dim3569Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   15  ,   63  ,   99  ,   161 ,   77  ,   539 ,   1069    ,   1263    ,   4173    ,   12691   ,   18091   ,0 };
            const std::uint32_t dim3570Kuo3Init[]   =   {   1   ,   3   ,   7   ,   1   ,   15  ,   55  ,   39  ,   33  ,   257 ,   925 ,   839 ,   4091    ,   2621    ,   315 ,   28153   ,0 };
            const std::uint32_t dim3571Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   9   ,   9   ,   17  ,   207 ,   369 ,   773 ,   1661    ,   3175    ,   2367    ,   6363    ,   5363    ,0 };
            const std::uint32_t dim3572Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   31  ,   11  ,   41  ,   145 ,   381 ,   969 ,   327 ,   487 ,   5545    ,   16163   ,   13891   ,0 };
            const std::uint32_t dim3573Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   19  ,   15  ,   125 ,   183 ,   445 ,   771 ,   829 ,   3653    ,   7487    ,   14429   ,   14535   ,0 };
            const std::uint32_t dim3574Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   5   ,   55  ,   41  ,   171 ,   163 ,   677 ,   1549    ,   2769    ,   3961    ,   4051    ,   25883   ,0 };
            const std::uint32_t dim3575Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   15  ,   5   ,   121 ,   113 ,   423 ,   607 ,   1623    ,   2899    ,   7839    ,   8107    ,   13963   ,0 };
            const std::uint32_t dim3576Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   17  ,   55  ,   85  ,   139 ,   93  ,   453 ,   75  ,   2405    ,   7601    ,   15647   ,   25349   ,0 };
            const std::uint32_t dim3577Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   11  ,   27  ,   1   ,   11  ,   361 ,   811 ,   599 ,   405 ,   6981    ,   5705    ,   16427   ,0 };
            const std::uint32_t dim3578Kuo3Init[]   =   {   1   ,   3   ,   5   ,   9   ,   23  ,   61  ,   27  ,   7   ,   99  ,   495 ,   473 ,   477 ,   1733    ,   8043    ,   24843   ,0 };
            const std::uint32_t dim3579Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   21  ,   27  ,   71  ,   157 ,   357 ,   175 ,   829 ,   2411    ,   2305    ,   4669    ,   24933   ,0 };
            const std::uint32_t dim3580Kuo3Init[]   =   {   1   ,   3   ,   5   ,   9   ,   21  ,   13  ,   121 ,   123 ,   119 ,   59  ,   429 ,   3757    ,   5833    ,   11263   ,   16013   ,0 };
            const std::uint32_t dim3581Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   11  ,   49  ,   7   ,   31  ,   375 ,   647 ,   413 ,   2979    ,   7731    ,   15953   ,   13637   ,0 };
            const std::uint32_t dim3582Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   9   ,   59  ,   121 ,   115 ,   239 ,   739 ,   121 ,   791 ,   769 ,   14223   ,   15127   ,0 };
            const std::uint32_t dim3583Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   17  ,   31  ,   69  ,   9   ,   189 ,   503 ,   565 ,   1373    ,   6467    ,   15291   ,   20621   ,0 };
            const std::uint32_t dim3584Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   31  ,   13  ,   71  ,   15  ,   197 ,   855 ,   1923    ,   2923    ,   2375    ,   7201    ,   29767   ,0 };
            const std::uint32_t dim3585Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   17  ,   13  ,   53  ,   131 ,   447 ,   337 ,   1059    ,   1365    ,   1269    ,   6035    ,   32075   ,0 };
            const std::uint32_t dim3586Kuo3Init[]   =   {   1   ,   3   ,   5   ,   1   ,   15  ,   13  ,   43  ,   151 ,   207 ,   591 ,   717 ,   971 ,   5801    ,   10975   ,   3889    ,0 };
            const std::uint32_t dim3587Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   15  ,   45  ,   125 ,   193 ,   17  ,   605 ,   651 ,   1987    ,   577 ,   2835    ,   6801    ,0 };
            const std::uint32_t dim3588Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   31  ,   53  ,   83  ,   137 ,   399 ,   781 ,   135 ,   2863    ,   4901    ,   2861    ,   14025   ,0 };
            const std::uint32_t dim3589Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   29  ,   45  ,   99  ,   43  ,   121 ,   141 ,   753 ,   11  ,   4033    ,   2011    ,   7493    ,0 };
            const std::uint32_t dim3590Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   7   ,   39  ,   95  ,   199 ,   365 ,   9   ,   381 ,   3923    ,   3803    ,   6607    ,   30777   ,0 };
            const std::uint32_t dim3591Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   13  ,   49  ,   17  ,   25  ,   195 ,   269 ,   83  ,   2115    ,   4013    ,   8817    ,   28017   ,0 };
            const std::uint32_t dim3592Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   23  ,   49  ,   51  ,   49  ,   303 ,   439 ,   1353    ,   2385    ,   4547    ,   14405   ,   24115   ,0 };
            const std::uint32_t dim3593Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   9   ,   3   ,   87  ,   159 ,   449 ,   139 ,   461 ,   465 ,   5585    ,   9313    ,   6337    ,0 };
            const std::uint32_t dim3594Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   23  ,   17  ,   103 ,   167 ,   209 ,   179 ,   137 ,   57  ,   4265    ,   1743    ,   27575   ,0 };
            const std::uint32_t dim3595Kuo3Init[]   =   {   1   ,   3   ,   1   ,   15  ,   15  ,   17  ,   7   ,   93  ,   173 ,   277 ,   497 ,   4047    ,   2205    ,   10403   ,   6319    ,0 };
            const std::uint32_t dim3596Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   13  ,   55  ,   37  ,   153 ,   69  ,   989 ,   1609    ,   1939    ,   1153    ,   5671    ,   16563   ,0 };
            const std::uint32_t dim3597Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   3   ,   41  ,   67  ,   41  ,   253 ,   293 ,   1495    ,   3935    ,   271 ,   12067   ,   3891    ,0 };
            const std::uint32_t dim3598Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   27  ,   21  ,   39  ,   41  ,   43  ,   713 ,   747 ,   995 ,   5389    ,   9811    ,   20489   ,0 };
            const std::uint32_t dim3599Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   11  ,   47  ,   41  ,   155 ,   301 ,   867 ,   1467    ,   1503    ,   893 ,   6819    ,   6923    ,0 };
            const std::uint32_t dim3600Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   29  ,   15  ,   57  ,   25  ,   219 ,   65  ,   997 ,   2109    ,   1921    ,   1771    ,   5997    ,0 };
            const std::uint32_t dim3601Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   11  ,   59  ,   89  ,   59  ,   319 ,   841 ,   1   ,   1339    ,   5635    ,   3141    ,   8735    ,0 };
            const std::uint32_t dim3602Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   17  ,   25  ,   13  ,   201 ,   37  ,   561 ,   1101    ,   1407    ,   3003    ,   99  ,   20189   ,0 };
            const std::uint32_t dim3603Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   9   ,   7   ,   65  ,   27  ,   203 ,   399 ,   555 ,   2605    ,   7951    ,   833 ,   6103    ,0 };
            const std::uint32_t dim3604Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   15  ,   25  ,   87  ,   215 ,   499 ,   935 ,   563 ,   1091    ,   6601    ,   12097   ,   22935   ,0 };
            const std::uint32_t dim3605Kuo3Init[]   =   {   1   ,   3   ,   5   ,   9   ,   3   ,   21  ,   63  ,   51  ,   353 ,   187 ,   1609    ,   2321    ,   1743    ,   12665   ,   9313    ,0 };
            const std::uint32_t dim3606Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   21  ,   7   ,   101 ,   27  ,   15  ,   467 ,   833 ,   2439    ,   3559    ,   10509   ,   16327   ,0 };
            const std::uint32_t dim3607Kuo3Init[]   =   {   1   ,   3   ,   5   ,   1   ,   21  ,   37  ,   107 ,   77  ,   147 ,   107 ,   1493    ,   969 ,   7895    ,   14293   ,   14557   ,0 };
            const std::uint32_t dim3608Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   1   ,   13  ,   57  ,   183 ,   303 ,   93  ,   1755    ,   845 ,   6857    ,   11061   ,   13661   ,0 };
            const std::uint32_t dim3609Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   11  ,   23  ,   25  ,   77  ,   75  ,   279 ,   1375    ,   1235    ,   3225    ,   8143    ,   4055    ,0 };
            const std::uint32_t dim3610Kuo3Init[]   =   {   1   ,   3   ,   1   ,   11  ,   5   ,   1   ,   85  ,   1   ,   221 ,   831 ,   1673    ,   633 ,   4837    ,   14409   ,   28993   ,0 };
            const std::uint32_t dim3611Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   23  ,   33  ,   51  ,   181 ,   201 ,   947 ,   697 ,   3417    ,   6169    ,   757 ,   9343    ,0 };
            const std::uint32_t dim3612Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   21  ,   51  ,   45  ,   81  ,   447 ,   17  ,   789 ,   3773    ,   3647    ,   5913    ,   25419   ,0 };
            const std::uint32_t dim3613Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   29  ,   39  ,   33  ,   67  ,   157 ,   583 ,   653 ,   43  ,   4441    ,   9571    ,   9895    ,0 };
            const std::uint32_t dim3614Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   21  ,   13  ,   53  ,   3   ,   135 ,   61  ,   1975    ,   2107    ,   1395    ,   11395   ,   1741    ,0 };
            const std::uint32_t dim3615Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   21  ,   29  ,   35  ,   25  ,   495 ,   783 ,   407 ,   1765    ,   1959    ,   3975    ,   23157   ,0 };
            const std::uint32_t dim3616Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   1   ,   57  ,   107 ,   73  ,   483 ,   945 ,   73  ,   2757    ,   7211    ,   1053    ,   7625    ,0 };
            const std::uint32_t dim3617Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   25  ,   53  ,   61  ,   117 ,   231 ,   261 ,   901 ,   1823    ,   3401    ,   8399    ,   17953   ,0 };
            const std::uint32_t dim3618Kuo3Init[]   =   {   1   ,   1   ,   7   ,   15  ,   29  ,   13  ,   55  ,   51  ,   469 ,   457 ,   1529    ,   2381    ,   6017    ,   10953   ,   18639   ,0 };
            const std::uint32_t dim3619Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   21  ,   17  ,   45  ,   1   ,   457 ,   821 ,   367 ,   453 ,   1015    ,   1017    ,   21745   ,0 };
            const std::uint32_t dim3620Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   15  ,   21  ,   121 ,   149 ,   417 ,   287 ,   897 ,   2595    ,   327 ,   16157   ,   11971   ,0 };
            const std::uint32_t dim3621Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   17  ,   29  ,   41  ,   191 ,   475 ,   457 ,   1487    ,   1885    ,   6959    ,   10869   ,   7435    ,0 };
            const std::uint32_t dim3622Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   9   ,   57  ,   29  ,   41  ,   81  ,   179 ,   1023    ,   3683    ,   4313    ,   4849    ,   14211   ,0 };
            const std::uint32_t dim3623Kuo3Init[]   =   {   1   ,   3   ,   1   ,   15  ,   15  ,   3   ,   123 ,   5   ,   201 ,   387 ,   1175    ,   1285    ,   4367    ,   459 ,   7771    ,0 };
            const std::uint32_t dim3624Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   25  ,   47  ,   113 ,   41  ,   299 ,   217 ,   495 ,   565 ,   2337    ,   9877    ,   28731   ,0 };
            const std::uint32_t dim3625Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   17  ,   11  ,   119 ,   187 ,   389 ,   19  ,   1947    ,   2607    ,   1119    ,   7677    ,   1561    ,0 };
            const std::uint32_t dim3626Kuo3Init[]   =   {   1   ,   1   ,   7   ,   9   ,   23  ,   59  ,   63  ,   175 ,   103 ,   211 ,   125 ,   3465    ,   2535    ,   14899   ,   1239    ,0 };
            const std::uint32_t dim3627Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   17  ,   37  ,   111 ,   225 ,   51  ,   455 ,   1911    ,   1579    ,   841 ,   11451   ,   31521   ,0 };
            const std::uint32_t dim3628Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   13  ,   1   ,   63  ,   33  ,   113 ,   83  ,   513 ,   3903    ,   5399    ,   5855    ,   11151   ,0 };
            const std::uint32_t dim3629Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   1   ,   15  ,   55  ,   181 ,   453 ,   15  ,   333 ,   185 ,   2031    ,   14809   ,   6187    ,0 };
            const std::uint32_t dim3630Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   27  ,   37  ,   41  ,   197 ,   191 ,   365 ,   1863    ,   559 ,   7731    ,   821 ,   8477    ,0 };
            const std::uint32_t dim3631Kuo3Init[]   =   {   1   ,   1   ,   1   ,   15  ,   19  ,   53  ,   91  ,   119 ,   185 ,   515 ,   1041    ,   3933    ,   601 ,   2971    ,   25445   ,0 };
            const std::uint32_t dim3632Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   25  ,   57  ,   11  ,   79  ,   299 ,   5   ,   1433    ,   2811    ,   1807    ,   4057    ,   3283    ,0 };
            const std::uint32_t dim3633Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   17  ,   17  ,   41  ,   157 ,   357 ,   981 ,   1323    ,   1189    ,   1249    ,   2857    ,   10163   ,0 };
            const std::uint32_t dim3634Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   15  ,   47  ,   109 ,   249 ,   37  ,   403 ,   1611    ,   281 ,   2521    ,   14179   ,   3095    ,0 };
            const std::uint32_t dim3635Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   23  ,   25  ,   5   ,   83  ,   503 ,   203 ,   1961    ,   1915    ,   5111    ,   4265    ,   27243   ,0 };
            const std::uint32_t dim3636Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   7   ,   29  ,   43  ,   19  ,   139 ,   487 ,   1847    ,   1569    ,   643 ,   15999   ,   21539   ,0 };
            const std::uint32_t dim3637Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   3   ,   7   ,   31  ,   217 ,   103 ,   127 ,   1389    ,   87  ,   7911    ,   12751   ,   11907   ,0 };
            const std::uint32_t dim3638Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   31  ,   25  ,   27  ,   69  ,   477 ,   471 ,   1375    ,   2485    ,   4221    ,   175 ,   16841   ,0 };
            const std::uint32_t dim3639Kuo3Init[]   =   {   1   ,   3   ,   1   ,   15  ,   9   ,   31  ,   125 ,   233 ,   175 ,   649 ,   641 ,   3751    ,   7857    ,   3849    ,   8859    ,0 };
            const std::uint32_t dim3640Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   25  ,   7   ,   31  ,   197 ,   435 ,   453 ,   1715    ,   3187    ,   6131    ,   12375   ,   29367   ,0 };
            const std::uint32_t dim3641Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   9   ,   41  ,   75  ,   107 ,   205 ,   919 ,   1709    ,   2515    ,   7143    ,   10433   ,   6179    ,0 };
            const std::uint32_t dim3642Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   27  ,   11  ,   107 ,   177 ,   17  ,   675 ,   677 ,   547 ,   7101    ,   7789    ,   29465   ,0 };
            const std::uint32_t dim3643Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   9   ,   7   ,   123 ,   209 ,   443 ,   221 ,   35  ,   4045    ,   2871    ,   16167   ,   31745   ,0 };
            const std::uint32_t dim3644Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   15  ,   59  ,   127 ,   173 ,   163 ,   151 ,   813 ,   967 ,   1165    ,   4147    ,   29355   ,0 };
            const std::uint32_t dim3645Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   21  ,   17  ,   33  ,   35  ,   87  ,   897 ,   393 ,   2205    ,   2885    ,   7327    ,   28521   ,0 };
            const std::uint32_t dim3646Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   1   ,   47  ,   67  ,   87  ,   371 ,   217 ,   1943    ,   1277    ,   27  ,   7205    ,   9751    ,0 };
            const std::uint32_t dim3647Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   1   ,   25  ,   51  ,   103 ,   61  ,   279 ,   1151    ,   3745    ,   4159    ,   1895    ,   15869   ,0 };
            const std::uint32_t dim3648Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   5   ,   59  ,   29  ,   83  ,   415 ,   851 ,   1415    ,   3719    ,   4345    ,   13897   ,   22409   ,0 };
            const std::uint32_t dim3649Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   29  ,   19  ,   7   ,   23  ,   87  ,   1   ,   2035    ,   2287    ,   4985    ,   1371    ,   9323    ,0 };
            const std::uint32_t dim3650Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   17  ,   33  ,   55  ,   49  ,   285 ,   953 ,   131 ,   3679    ,   3811    ,   6125    ,   18827   ,0 };
            const std::uint32_t dim3651Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   9   ,   51  ,   61  ,   119 ,   163 ,   829 ,   1579    ,   2047    ,   909 ,   3499    ,   26535   ,0 };
            const std::uint32_t dim3652Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   27  ,   49  ,   127 ,   239 ,   193 ,   359 ,   695 ,   1471    ,   6481    ,   3549    ,   22337   ,0 };
            const std::uint32_t dim3653Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   29  ,   7   ,   83  ,   57  ,   509 ,   15  ,   391 ,   2287    ,   1023    ,   13993   ,   6073    ,0 };
            const std::uint32_t dim3654Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   3   ,   21  ,   23  ,   217 ,   147 ,   511 ,   1817    ,   2425    ,   2347    ,   1433    ,   10625   ,0 };
            const std::uint32_t dim3655Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   23  ,   21  ,   29  ,   197 ,   189 ,   367 ,   619 ,   1305    ,   5463    ,   7099    ,   3307    ,0 };
            const std::uint32_t dim3656Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   27  ,   7   ,   33  ,   221 ,   107 ,   85  ,   633 ,   3325    ,   3109    ,   16377   ,   25633   ,0 };
            const std::uint32_t dim3657Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   13  ,   59  ,   57  ,   251 ,   321 ,   45  ,   451 ,   237 ,   4499    ,   10549   ,   16473   ,0 };
            const std::uint32_t dim3658Kuo3Init[]   =   {   1   ,   1   ,   7   ,   15  ,   11  ,   39  ,   17  ,   85  ,   233 ,   865 ,   1285    ,   1771    ,   2913    ,   7729    ,   3815    ,0 };
            const std::uint32_t dim3659Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   9   ,   1   ,   51  ,   47  ,   113 ,   917 ,   1007    ,   1883    ,   4087    ,   4061    ,   27965   ,0 };
            const std::uint32_t dim3660Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   29  ,   33  ,   123 ,   183 ,   347 ,   99  ,   1215    ,   893 ,   7555    ,   6835    ,   1729    ,0 };
            const std::uint32_t dim3661Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   5   ,   25  ,   7   ,   255 ,   315 ,   559 ,   51  ,   899 ,   7165    ,   2021    ,   17413   ,0 };
            const std::uint32_t dim3662Kuo3Init[]   =   {   1   ,   3   ,   3   ,   7   ,   3   ,   19  ,   7   ,   89  ,   77  ,   599 ,   1021    ,   3269    ,   3615    ,   10023   ,   31043   ,0 };
            const std::uint32_t dim3663Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   9   ,   7   ,   119 ,   199 ,   315 ,   835 ,   1401    ,   1547    ,   609 ,   9015    ,   27589   ,0 };
            const std::uint32_t dim3664Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   7   ,   33  ,   109 ,   239 ,   329 ,   213 ,   215 ,   1989    ,   1495    ,   7765    ,   3123    ,0 };
            const std::uint32_t dim3665Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   31  ,   23  ,   79  ,   181 ,   211 ,   189 ,   1   ,   2103    ,   4247    ,   7209    ,   3733    ,0 };
            const std::uint32_t dim3666Kuo3Init[]   =   {   1   ,   3   ,   3   ,   7   ,   19  ,   31  ,   59  ,   103 ,   291 ,   877 ,   459 ,   3893    ,   4303    ,   10033   ,   31859   ,0 };
            const std::uint32_t dim3667Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   11  ,   1   ,   11  ,   163 ,   477 ,   925 ,   659 ,   143 ,   3705    ,   11335   ,   23667   ,   53273   ,0 };
            const std::uint32_t dim3668Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   21  ,   29  ,   119 ,   195 ,   303 ,   185 ,   1353    ,   1285    ,   2525    ,   11801   ,   10663   ,   49201   ,0 };
            const std::uint32_t dim3669Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   29  ,   41  ,   115 ,   115 ,   389 ,   763 ,   1625    ,   691 ,   3425    ,   6451    ,   3355    ,   26967   ,0 };
            const std::uint32_t dim3670Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   1   ,   3   ,   71  ,   129 ,   25  ,   231 ,   1849    ,   2087    ,   3253    ,   13151   ,   17039   ,   21893   ,0 };
            const std::uint32_t dim3671Kuo3Init[]   =   {   1   ,   3   ,   5   ,   9   ,   11  ,   57  ,   99  ,   187 ,   245 ,   965 ,   1437    ,   3431    ,   4657    ,   12581   ,   14883   ,   54985   ,0 };
            const std::uint32_t dim3672Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   27  ,   55  ,   41  ,   203 ,   261 ,   271 ,   327 ,   71  ,   3659    ,   4517    ,   24071   ,   56297   ,0 };
            const std::uint32_t dim3673Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   13  ,   63  ,   37  ,   109 ,   437 ,   611 ,   649 ,   1123    ,   4365    ,   10259   ,   26507   ,   60715   ,0 };
            const std::uint32_t dim3674Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   21  ,   51  ,   113 ,   95  ,   221 ,   157 ,   843 ,   1429    ,   781 ,   13193   ,   16453   ,   26883   ,0 };
            const std::uint32_t dim3675Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   29  ,   15  ,   13  ,   5   ,   441 ,   7   ,   139 ,   773 ,   1495    ,   2283    ,   31549   ,   4105    ,0 };
            const std::uint32_t dim3676Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   27  ,   59  ,   51  ,   51  ,   211 ,   871 ,   1971    ,   1213    ,   7459    ,   14001   ,   32175   ,   53975   ,0 };
            const std::uint32_t dim3677Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   3   ,   29  ,   47  ,   131 ,   263 ,   879 ,   731 ,   1063    ,   3647    ,   8729    ,   5407    ,   4001    ,0 };
            const std::uint32_t dim3678Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   21  ,   45  ,   93  ,   143 ,   443 ,   295 ,   1683    ,   2335    ,   4213    ,   6297    ,   26611   ,   56661   ,0 };
            const std::uint32_t dim3679Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   9   ,   63  ,   97  ,   143 ,   101 ,   579 ,   435 ,   3339    ,   7333    ,   6267    ,   1589    ,   30997   ,0 };
            const std::uint32_t dim3680Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   31  ,   51  ,   81  ,   125 ,   285 ,   879 ,   1377    ,   107 ,   827 ,   7185    ,   27265   ,   54517   ,0 };
            const std::uint32_t dim3681Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   9   ,   9   ,   121 ,   167 ,   195 ,   625 ,   1167    ,   1533    ,   3697    ,   7545    ,   27799   ,   11613   ,0 };
            const std::uint32_t dim3682Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   21  ,   55  ,   65  ,   63  ,   355 ,   525 ,   1441    ,   3057    ,   1779    ,   1613    ,   6277    ,   37655   ,0 };
            const std::uint32_t dim3683Kuo3Init[]   =   {   1   ,   1   ,   7   ,   15  ,   9   ,   61  ,   7   ,   211 ,   11  ,   955 ,   499 ,   2795    ,   4017    ,   1459    ,   4323    ,   1453    ,0 };
            const std::uint32_t dim3684Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   25  ,   17  ,   75  ,   219 ,   383 ,   721 ,   1661    ,   3325    ,   5917    ,   11423   ,   19265   ,   41063   ,0 };
            const std::uint32_t dim3685Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   15  ,   39  ,   93  ,   9   ,   463 ,   611 ,   547 ,   173 ,   4179    ,   4641    ,   28201   ,   32139   ,0 };
            const std::uint32_t dim3686Kuo3Init[]   =   {   1   ,   1   ,   5   ,   7   ,   29  ,   51  ,   41  ,   157 ,   93  ,   289 ,   935 ,   3299    ,   2103    ,   4371    ,   15485   ,   62685   ,0 };
            const std::uint32_t dim3687Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   31  ,   49  ,   93  ,   205 ,   13  ,   551 ,   1809    ,   4051    ,   5481    ,   2693    ,   6615    ,   18123   ,0 };
            const std::uint32_t dim3688Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   1   ,   41  ,   27  ,   105 ,   469 ,   759 ,   625 ,   1579    ,   4253    ,   7435    ,   20545   ,   4365    ,0 };
            const std::uint32_t dim3689Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   17  ,   45  ,   111 ,   91  ,   357 ,   651 ,   5   ,   937 ,   3199    ,   6485    ,   21145   ,   35085   ,0 };
            const std::uint32_t dim3690Kuo3Init[]   =   {   1   ,   3   ,   5   ,   1   ,   7   ,   21  ,   33  ,   213 ,   399 ,   735 ,   1923    ,   1047    ,   2765    ,   11057   ,   19007   ,   58345   ,0 };
            const std::uint32_t dim3691Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   31  ,   57  ,   113 ,   81  ,   75  ,   985 ,   479 ,   1353    ,   1041    ,   13489   ,   12011   ,   52749   ,0 };
            const std::uint32_t dim3692Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   23  ,   23  ,   83  ,   167 ,   473 ,   471 ,   171 ,   3303    ,   7167    ,   1109    ,   29263   ,   30047   ,0 };
            const std::uint32_t dim3693Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   11  ,   63  ,   57  ,   73  ,   49  ,   921 ,   457 ,   1683    ,   4447    ,   14549   ,   5819    ,   18291   ,0 };
            const std::uint32_t dim3694Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   27  ,   1   ,   127 ,   233 ,   509 ,   229 ,   1553    ,   3875    ,   2243    ,   16005   ,   17985   ,   28437   ,0 };
            const std::uint32_t dim3695Kuo3Init[]   =   {   1   ,   1   ,   1   ,   15  ,   7   ,   27  ,   75  ,   191 ,   433 ,   585 ,   1659    ,   3373    ,   4067    ,   55  ,   11095   ,   37179   ,0 };
            const std::uint32_t dim3696Kuo3Init[]   =   {   1   ,   1   ,   7   ,   15  ,   27  ,   31  ,   21  ,   105 ,   95  ,   357 ,   2019    ,   2193    ,   741 ,   8509    ,   349 ,   24797   ,0 };
            const std::uint32_t dim3697Kuo3Init[]   =   {   1   ,   1   ,   1   ,   15  ,   1   ,   51  ,   77  ,   139 ,   205 ,   81  ,   1849    ,   1687    ,   1597    ,   1531    ,   115 ,   50163   ,0 };
            const std::uint32_t dim3698Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   7   ,   61  ,   113 ,   111 ,   69  ,   443 ,   179 ,   2955    ,   7   ,   13237   ,   26787   ,   33917   ,0 };
            const std::uint32_t dim3699Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   21  ,   37  ,   11  ,   209 ,   177 ,   433 ,   1423    ,   1629    ,   5807    ,   4655    ,   19377   ,   58963   ,0 };
            const std::uint32_t dim3700Kuo3Init[]   =   {   1   ,   3   ,   5   ,   1   ,   11  ,   29  ,   107 ,   17  ,   135 ,   801 ,   1441    ,   3119    ,   4573    ,   8903    ,   11267   ,   2845    ,0 };
            const std::uint32_t dim3701Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   21  ,   41  ,   115 ,   19  ,   473 ,   447 ,   1879    ,   4095    ,   2743    ,   10007   ,   5751    ,   36845   ,0 };
            const std::uint32_t dim3702Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   19  ,   13  ,   85  ,   131 ,   85  ,   849 ,   1179    ,   1919    ,   3631    ,   13807   ,   10467   ,   24081   ,0 };
            const std::uint32_t dim3703Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   5   ,   17  ,   21  ,   125 ,   169 ,   369 ,   761 ,   1419    ,   7795    ,   9041    ,   7613    ,   6125    ,0 };
            const std::uint32_t dim3704Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   21  ,   53  ,   119 ,   55  ,   97  ,   563 ,   1531    ,   847 ,   3709    ,   10573   ,   18469   ,   29625   ,0 };
            const std::uint32_t dim3705Kuo3Init[]   =   {   1   ,   1   ,   5   ,   7   ,   23  ,   15  ,   99  ,   251 ,   415 ,   55  ,   563 ,   3535    ,   8017    ,   7771    ,   23601   ,   52955   ,0 };
            const std::uint32_t dim3706Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   29  ,   11  ,   73  ,   251 ,   139 ,   215 ,   825 ,   1735    ,   7859    ,   10171   ,   17351   ,   24971   ,0 };
            const std::uint32_t dim3707Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   21  ,   21  ,   21  ,   21  ,   107 ,   901 ,   1321    ,   647 ,   7521    ,   5505    ,   965 ,   36217   ,0 };
            const std::uint32_t dim3708Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   9   ,   39  ,   87  ,   173 ,   201 ,   705 ,   563 ,   3479    ,   437 ,   1733    ,   18001   ,   39161   ,0 };
            const std::uint32_t dim3709Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   31  ,   31  ,   89  ,   119 ,   471 ,   633 ,   249 ,   187 ,   3735    ,   4045    ,   1611    ,   10045   ,0 };
            const std::uint32_t dim3710Kuo3Init[]   =   {   1   ,   3   ,   5   ,   1   ,   7   ,   31  ,   117 ,   249 ,   175 ,   515 ,   1825    ,   3417    ,   307 ,   10909   ,   4453    ,   43833   ,0 };
            const std::uint32_t dim3711Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   1   ,   21  ,   59  ,   103 ,   243 ,   105 ,   2037    ,   1759    ,   689 ,   15389   ,   16981   ,   35545   ,0 };
            const std::uint32_t dim3712Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   13  ,   15  ,   105 ,   89  ,   463 ,   513 ,   191 ,   1489    ,   5239    ,   3723    ,   20511   ,   52139   ,0 };
            const std::uint32_t dim3713Kuo3Init[]   =   {   1   ,   3   ,   5   ,   1   ,   1   ,   25  ,   71  ,   89  ,   167 ,   1009    ,   829 ,   2267    ,   375 ,   10217   ,   31677   ,   58309   ,0 };
            const std::uint32_t dim3714Kuo3Init[]   =   {   1   ,   3   ,   5   ,   1   ,   31  ,   19  ,   21  ,   225 ,   331 ,   621 ,   1047    ,   3385    ,   5247    ,   1763    ,   19985   ,   9013    ,0 };
            const std::uint32_t dim3715Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   5   ,   19  ,   69  ,   11  ,   15  ,   361 ,   617 ,   823 ,   2645    ,   207 ,   18775   ,   60509   ,0 };
            const std::uint32_t dim3716Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   15  ,   1   ,   37  ,   3   ,   249 ,   277 ,   1729    ,   3599    ,   115 ,   9557    ,   12865   ,   6257    ,0 };
            const std::uint32_t dim3717Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   15  ,   51  ,   21  ,   147 ,   23  ,   527 ,   167 ,   1673    ,   2299    ,   923 ,   22755   ,   48627   ,0 };
            const std::uint32_t dim3718Kuo3Init[]   =   {   1   ,   3   ,   7   ,   1   ,   17  ,   55  ,   23  ,   1   ,   213 ,   479 ,   287 ,   2741    ,   7255    ,   4571    ,   6581    ,   57509   ,0 };
            const std::uint32_t dim3719Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   15  ,   49  ,   13  ,   149 ,   103 ,   513 ,   1977    ,   2275    ,   5535    ,   7867    ,   16305   ,   24713   ,0 };
            const std::uint32_t dim3720Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   29  ,   41  ,   69  ,   211 ,   131 ,   87  ,   859 ,   3631    ,   611 ,   11463   ,   18029   ,   38771   ,0 };
            const std::uint32_t dim3721Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   17  ,   23  ,   37  ,   149 ,   271 ,   547 ,   1129    ,   3615    ,   6647    ,   7023    ,   103 ,   29257   ,0 };
            const std::uint32_t dim3722Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   1   ,   55  ,   71  ,   51  ,   249 ,   141 ,   1937    ,   3869    ,   5897    ,   13227   ,   22279   ,   11733   ,0 };
            const std::uint32_t dim3723Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   1   ,   29  ,   85  ,   255 ,   93  ,   741 ,   687 ,   2195    ,   519 ,   8235    ,   21305   ,   19681   ,0 };
            const std::uint32_t dim3724Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   13  ,   17  ,   103 ,   65  ,   211 ,   603 ,   543 ,   3629    ,   235 ,   7337    ,   27477   ,   2735    ,0 };
            const std::uint32_t dim3725Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   17  ,   63  ,   75  ,   183 ,   107 ,   583 ,   1849    ,   545 ,   7987    ,   13679   ,   22797   ,   40095   ,0 };
            const std::uint32_t dim3726Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   31  ,   13  ,   33  ,   21  ,   479 ,   879 ,   1223    ,   3925    ,   3003    ,   9975    ,   23465   ,   27775   ,0 };
            const std::uint32_t dim3727Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   7   ,   23  ,   65  ,   107 ,   239 ,   867 ,   1245    ,   1549    ,   5981    ,   4677    ,   3761    ,   61449   ,0 };
            const std::uint32_t dim3728Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   5   ,   31  ,   25  ,   53  ,   59  ,   79  ,   1545    ,   3721    ,   6979    ,   16351   ,   7305    ,   41653   ,0 };
            const std::uint32_t dim3729Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   27  ,   53  ,   9   ,   7   ,   159 ,   353 ,   121 ,   2525    ,   8049    ,   12997   ,   3933    ,   19835   ,0 };
            const std::uint32_t dim3730Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   1   ,   33  ,   127 ,   163 ,   399 ,   125 ,   1869    ,   569 ,   3853    ,   4819    ,   4403    ,   34367   ,0 };
            const std::uint32_t dim3731Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   11  ,   23  ,   21  ,   95  ,   329 ,   937 ,   689 ,   3731    ,   1157    ,   9613    ,   12593   ,   58609   ,0 };
            const std::uint32_t dim3732Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   13  ,   23  ,   7   ,   237 ,   413 ,   139 ,   523 ,   3517    ,   6829    ,   17  ,   17673   ,   57889   ,0 };
            const std::uint32_t dim3733Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   3   ,   49  ,   63  ,   87  ,   147 ,   359 ,   2027    ,   1513    ,   3933    ,   13911   ,   25459   ,   11391   ,0 };
            const std::uint32_t dim3734Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   23  ,   17  ,   81  ,   249 ,   487 ,   71  ,   395 ,   3635    ,   4773    ,   14909   ,   13523   ,   32617   ,0 };
            const std::uint32_t dim3735Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   19  ,   39  ,   13  ,   91  ,   475 ,   899 ,   353 ,   3275    ,   4161    ,   2203    ,   20375   ,   14795   ,0 };
            const std::uint32_t dim3736Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   17  ,   15  ,   117 ,   145 ,   223 ,   393 ,   1267    ,   1089    ,   6745    ,   10485   ,   20385   ,   25991   ,0 };
            const std::uint32_t dim3737Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   27  ,   21  ,   57  ,   237 ,   405 ,   513 ,   1411    ,   2791    ,   1685    ,   11529   ,   2115    ,   36631   ,0 };
            const std::uint32_t dim3738Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   5   ,   17  ,   111 ,   55  ,   277 ,   639 ,   1541    ,   2347    ,   1119    ,   10101   ,   8533    ,   15383   ,0 };
            const std::uint32_t dim3739Kuo3Init[]   =   {   1   ,   3   ,   5   ,   9   ,   1   ,   47  ,   123 ,   39  ,   473 ,   471 ,   299 ,   3785    ,   6589    ,   9415    ,   29193   ,   24367   ,0 };
            const std::uint32_t dim3740Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   13  ,   17  ,   9   ,   131 ,   9   ,   309 ,   1529    ,   3721    ,   5927    ,   6699    ,   17439   ,   60313   ,0 };
            const std::uint32_t dim3741Kuo3Init[]   =   {   1   ,   3   ,   3   ,   7   ,   17  ,   3   ,   93  ,   33  ,   287 ,   47  ,   1295    ,   1021    ,   4267    ,   403 ,   31111   ,   5399    ,0 };
            const std::uint32_t dim3742Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   29  ,   27  ,   73  ,   117 ,   123 ,   1007    ,   2003    ,   2921    ,   4875    ,   2043    ,   12221   ,   57865   ,0 };
            const std::uint32_t dim3743Kuo3Init[]   =   {   1   ,   3   ,   1   ,   15  ,   15  ,   51  ,   31  ,   217 ,   429 ,   1009    ,   1761    ,   389 ,   4859    ,   13667   ,   17955   ,   29493   ,0 };
            const std::uint32_t dim3744Kuo3Init[]   =   {   1   ,   3   ,   3   ,   7   ,   25  ,   11  ,   65  ,   109 ,   241 ,   421 ,   363 ,   2641    ,   781 ,   711 ,   5363    ,   9603    ,0 };
            const std::uint32_t dim3745Kuo3Init[]   =   {   1   ,   3   ,   1   ,   11  ,   1   ,   41  ,   99  ,   181 ,   103 ,   503 ,   1887    ,   1917    ,   4791    ,   6405    ,   27701   ,   62353   ,0 };
            const std::uint32_t dim3746Kuo3Init[]   =   {   1   ,   1   ,   5   ,   7   ,   25  ,   43  ,   23  ,   49  ,   333 ,   205 ,   903 ,   3915    ,   2899    ,   2719    ,   7887    ,   17313   ,0 };
            const std::uint32_t dim3747Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   27  ,   19  ,   59  ,   125 ,   409 ,   979 ,   1203    ,   1737    ,   5269    ,   14755   ,   32173   ,   2127    ,0 };
            const std::uint32_t dim3748Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   29  ,   19  ,   73  ,   63  ,   81  ,   717 ,   933 ,   2939    ,   2863    ,   5993    ,   25953   ,   31733   ,0 };
            const std::uint32_t dim3749Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   11  ,   19  ,   55  ,   223 ,   51  ,   661 ,   547 ,   4055    ,   4849    ,   3009    ,   22303   ,   25  ,0 };
            const std::uint32_t dim3750Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   7   ,   3   ,   55  ,   167 ,   207 ,   819 ,   791 ,   3813    ,   2455    ,   1305    ,   4661    ,   51189   ,0 };
            const std::uint32_t dim3751Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   29  ,   1   ,   31  ,   191 ,   267 ,   705 ,   181 ,   3091    ,   4725    ,   12351   ,   31521   ,   56163   ,0 };
            const std::uint32_t dim3752Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   19  ,   11  ,   27  ,   215 ,   249 ,   713 ,   723 ,   143 ,   2179    ,   11075   ,   22059   ,   62629   ,0 };
            const std::uint32_t dim3753Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   23  ,   45  ,   101 ,   25  ,   115 ,   353 ,   565 ,   3491    ,   285 ,   2133    ,   27117   ,   42699   ,0 };
            const std::uint32_t dim3754Kuo3Init[]   =   {   1   ,   1   ,   5   ,   7   ,   1   ,   51  ,   113 ,   165 ,   157 ,   431 ,   1043    ,   3003    ,   5971    ,   15699   ,   20799   ,   13989   ,0 };
            const std::uint32_t dim3755Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   23  ,   21  ,   121 ,   85  ,   69  ,   169 ,   1761    ,   1023    ,   5501    ,   1255    ,   25683   ,   48699   ,0 };
            const std::uint32_t dim3756Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   21  ,   31  ,   95  ,   5   ,   237 ,   607 ,   1525    ,   763 ,   4725    ,   4221    ,   22769   ,   40899   ,0 };
            const std::uint32_t dim3757Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   1   ,   9   ,   105 ,   225 ,   171 ,   999 ,   547 ,   2331    ,   4389    ,   12847   ,   18107   ,   11939   ,0 };
            const std::uint32_t dim3758Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   15  ,   47  ,   73  ,   237 ,   463 ,   501 ,   1611    ,   2259    ,   1679    ,   1709    ,   24527   ,   53529   ,0 };
            const std::uint32_t dim3759Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   21  ,   27  ,   27  ,   25  ,   463 ,   73  ,   2021    ,   3899    ,   487 ,   667 ,   5063    ,   5017    ,0 };
            const std::uint32_t dim3760Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   15  ,   3   ,   87  ,   145 ,   45  ,   473 ,   1455    ,   1857    ,   2379    ,   4805    ,   10557   ,   27485   ,0 };
            const std::uint32_t dim3761Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   17  ,   15  ,   13  ,   237 ,   177 ,   835 ,   1019    ,   975 ,   7085    ,   2871    ,   16473   ,   23693   ,0 };
            const std::uint32_t dim3762Kuo3Init[]   =   {   1   ,   1   ,   1   ,   1   ,   13  ,   61  ,   31  ,   197 ,   127 ,   213 ,   173 ,   3751    ,   3819    ,   2899    ,   22675   ,   23095   ,0 };
            const std::uint32_t dim3763Kuo3Init[]   =   {   1   ,   3   ,   1   ,   15  ,   7   ,   63  ,   89  ,   95  ,   497 ,   1021    ,   1751    ,   1379    ,   3809    ,   9493    ,   7941    ,   35217   ,0 };
            const std::uint32_t dim3764Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   7   ,   63  ,   33  ,   155 ,   171 ,   651 ,   773 ,   1861    ,   4225    ,   1081    ,   29141   ,   53413   ,0 };
            const std::uint32_t dim3765Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   15  ,   27  ,   31  ,   183 ,   377 ,   341 ,   205 ,   1817    ,   6185    ,   13047   ,   19585   ,   1533    ,0 };
            const std::uint32_t dim3766Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   27  ,   23  ,   23  ,   117 ,   463 ,   73  ,   529 ,   1727    ,   6989    ,   15911   ,   11783   ,   1011    ,0 };
            const std::uint32_t dim3767Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   9   ,   43  ,   55  ,   191 ,   203 ,   471 ,   515 ,   1315    ,   7911    ,   14281   ,   4767    ,   15725   ,0 };
            const std::uint32_t dim3768Kuo3Init[]   =   {   1   ,   1   ,   1   ,   15  ,   23  ,   13  ,   61  ,   231 ,   423 ,   79  ,   421 ,   1619    ,   7951    ,   15541   ,   20985   ,   42181   ,0 };
            const std::uint32_t dim3769Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   31  ,   29  ,   81  ,   125 ,   217 ,   643 ,   449 ,   477 ,   4521    ,   2973    ,   13295   ,   943 ,0 };
            const std::uint32_t dim3770Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   15  ,   37  ,   81  ,   167 ,   11  ,   53  ,   1455    ,   3719    ,   1777    ,   7253    ,   16365   ,   17021   ,0 };
            const std::uint32_t dim3771Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   25  ,   39  ,   95  ,   189 ,   453 ,   697 ,   1761    ,   3837    ,   4697    ,   8429    ,   10455   ,   17239   ,0 };
            const std::uint32_t dim3772Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   13  ,   43  ,   127 ,   251 ,   497 ,   475 ,   105 ,   3137    ,   5927    ,   7569    ,   5645    ,   25315   ,0 };
            const std::uint32_t dim3773Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   1   ,   23  ,   15  ,   129 ,   165 ,   887 ,   1719    ,   2343    ,   1663    ,   1153    ,   25889   ,   10961   ,0 };
            const std::uint32_t dim3774Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   29  ,   7   ,   37  ,   147 ,   369 ,   697 ,   481 ,   1845    ,   4499    ,   4885    ,   3201    ,   6773    ,0 };
            const std::uint32_t dim3775Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   25  ,   23  ,   49  ,   149 ,   435 ,   561 ,   1233    ,   2821    ,   3121    ,   2825    ,   21237   ,   47491   ,0 };
            const std::uint32_t dim3776Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   3   ,   59  ,   85  ,   205 ,   89  ,   423 ,   701 ,   1179    ,   4875    ,   3351    ,   17863   ,   35111   ,0 };
            const std::uint32_t dim3777Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   5   ,   51  ,   105 ,   85  ,   411 ,   561 ,   155 ,   2809    ,   63  ,   8711    ,   12523   ,   28827   ,0 };
            const std::uint32_t dim3778Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   29  ,   43  ,   103 ,   153 ,   105 ,   819 ,   1861    ,   1725    ,   2225    ,   1821    ,   25551   ,   65399   ,0 };
            const std::uint32_t dim3779Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   7   ,   51  ,   71  ,   177 ,   49  ,   605 ,   1375    ,   737 ,   7325    ,   9597    ,   10239   ,   64761   ,0 };
            const std::uint32_t dim3780Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   5   ,   15  ,   117 ,   187 ,   19  ,   149 ,   119 ,   3375    ,   3203    ,   6827    ,   22073   ,   35757   ,0 };
            const std::uint32_t dim3781Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   13  ,   25  ,   7   ,   157 ,   23  ,   741 ,   465 ,   2225    ,   6697    ,   14371   ,   25115   ,   29699   ,0 };
            const std::uint32_t dim3782Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   5   ,   29  ,   95  ,   209 ,   123 ,   947 ,   1631    ,   423 ,   1217    ,   12353   ,   7561    ,   1415    ,0 };
            const std::uint32_t dim3783Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   3   ,   17  ,   63  ,   65  ,   371 ,   355 ,   1793    ,   1197    ,   2375    ,   3629    ,   13283   ,   41727   ,0 };
            const std::uint32_t dim3784Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   5   ,   19  ,   103 ,   85  ,   271 ,   123 ,   1939    ,   2741    ,   5105    ,   8693    ,   4291    ,   49389   ,0 };
            const std::uint32_t dim3785Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   31  ,   1   ,   57  ,   13  ,   265 ,   941 ,   1169    ,   3639    ,   5317    ,   10565   ,   30263   ,   64329   ,0 };
            const std::uint32_t dim3786Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   7   ,   9   ,   115 ,   111 ,   301 ,   365 ,   1   ,   3093    ,   3209    ,   2607    ,   5749    ,   17047   ,0 };
            const std::uint32_t dim3787Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   5   ,   41  ,   113 ,   73  ,   407 ,   427 ,   1271    ,   1361    ,   4869    ,   14845   ,   29515   ,   38769   ,0 };
            const std::uint32_t dim3788Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   19  ,   47  ,   77  ,   27  ,   57  ,   43  ,   1633    ,   197 ,   5465    ,   14735   ,   25187   ,   38621   ,0 };
            const std::uint32_t dim3789Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   11  ,   55  ,   23  ,   213 ,   495 ,   929 ,   697 ,   2829    ,   4185    ,   8321    ,   12673   ,   22759   ,0 };
            const std::uint32_t dim3790Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   17  ,   29  ,   7   ,   41  ,   75  ,   139 ,   1165    ,   3387    ,   6015    ,   3679    ,   8353    ,   29981   ,0 };
            const std::uint32_t dim3791Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   21  ,   47  ,   95  ,   163 ,   121 ,   877 ,   245 ,   3947    ,   3839    ,   15097   ,   4695    ,   26037   ,0 };
            const std::uint32_t dim3792Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   19  ,   19  ,   7   ,   93  ,   77  ,   887 ,   153 ,   237 ,   543 ,   2631    ,   22023   ,   17207   ,0 };
            const std::uint32_t dim3793Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   7   ,   23  ,   39  ,   181 ,   107 ,   313 ,   131 ,   3799    ,   981 ,   11145   ,   10969   ,   28733   ,0 };
            const std::uint32_t dim3794Kuo3Init[]   =   {   1   ,   3   ,   1   ,   11  ,   15  ,   45  ,   105 ,   187 ,   457 ,   41  ,   1739    ,   3229    ,   4289    ,   107 ,   2685    ,   15601   ,0 };
            const std::uint32_t dim3795Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   15  ,   53  ,   11  ,   87  ,   421 ,   733 ,   1031    ,   121 ,   2413    ,   3383    ,   6525    ,   35781   ,0 };
            const std::uint32_t dim3796Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   23  ,   15  ,   81  ,   13  ,   215 ,   573 ,   1953    ,   379 ,   6857    ,   2137    ,   2599    ,   29589   ,0 };
            const std::uint32_t dim3797Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   29  ,   17  ,   25  ,   121 ,   291 ,   317 ,   81  ,   4073    ,   7111    ,   5045    ,   32685   ,   21527   ,0 };
            const std::uint32_t dim3798Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   31  ,   53  ,   115 ,   179 ,   81  ,   919 ,   955 ,   2301    ,   647 ,   11433   ,   17761   ,   8187    ,0 };
            const std::uint32_t dim3799Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   17  ,   15  ,   105 ,   55  ,   303 ,   505 ,   223 ,   1757    ,   3567    ,   9079    ,   29415   ,   37845   ,0 };
            const std::uint32_t dim3800Kuo3Init[]   =   {   1   ,   3   ,   7   ,   1   ,   23  ,   33  ,   33  ,   199 ,   119 ,   911 ,   349 ,   3641    ,   5339    ,   12803   ,   27979   ,   17951   ,0 };
            const std::uint32_t dim3801Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   15  ,   53  ,   43  ,   25  ,   31  ,   609 ,   49  ,   1307    ,   6477    ,   2173    ,   32245   ,   34123   ,0 };
            const std::uint32_t dim3802Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   11  ,   35  ,   55  ,   85  ,   381 ,   733 ,   1407    ,   2821    ,   1547    ,   9843    ,   13861   ,   13529   ,0 };
            const std::uint32_t dim3803Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   13  ,   11  ,   35  ,   255 ,   421 ,   673 ,   387 ,   3429    ,   3137    ,   13619   ,   28689   ,   11145   ,0 };
            const std::uint32_t dim3804Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   23  ,   61  ,   81  ,   25  ,   163 ,   595 ,   769 ,   3455    ,   5371    ,   9711    ,   14937   ,   34383   ,0 };
            const std::uint32_t dim3805Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   11  ,   11  ,   115 ,   93  ,   307 ,   807 ,   1667    ,   483 ,   4815    ,   6305    ,   5197    ,   281 ,0 };
            const std::uint32_t dim3806Kuo3Init[]   =   {   1   ,   1   ,   7   ,   15  ,   29  ,   31  ,   113 ,   129 ,   483 ,   369 ,   855 ,   643 ,   7503    ,   1699    ,   20681   ,   51497   ,0 };
            const std::uint32_t dim3807Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   3   ,   41  ,   7   ,   255 ,   171 ,   1003    ,   559 ,   775 ,   5333    ,   11563   ,   22473   ,   44299   ,0 };
            const std::uint32_t dim3808Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   23  ,   51  ,   101 ,   161 ,   433 ,   757 ,   713 ,   403 ,   1789    ,   5353    ,   28901   ,   14249   ,0 };
            const std::uint32_t dim3809Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   27  ,   5   ,   9   ,   71  ,   47  ,   287 ,   369 ,   653 ,   7595    ,   10127   ,   12547   ,   34119   ,0 };
            const std::uint32_t dim3810Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   5   ,   33  ,   19  ,   183 ,   497 ,   209 ,   1999    ,   2897    ,   2553    ,   633 ,   7413    ,   7847    ,0 };
            const std::uint32_t dim3811Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   27  ,   19  ,   73  ,   181 ,   15  ,   297 ,   1485    ,   2167    ,   5033    ,   11191   ,   24999   ,   30177   ,0 };
            const std::uint32_t dim3812Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   5   ,   47  ,   111 ,   239 ,   259 ,   1019    ,   241 ,   2521    ,   1599    ,   4655    ,   5725    ,   56623   ,0 };
            const std::uint32_t dim3813Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   29  ,   37  ,   29  ,   223 ,   413 ,   307 ,   939 ,   2009    ,   3961    ,   9481    ,   9121    ,   23927   ,0 };
            const std::uint32_t dim3814Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   17  ,   37  ,   7   ,   121 ,   387 ,   573 ,   1751    ,   3431    ,   7199    ,   15041   ,   14453   ,   45757   ,0 };
            const std::uint32_t dim3815Kuo3Init[]   =   {   1   ,   3   ,   3   ,   7   ,   31  ,   53  ,   29  ,   247 ,   23  ,   579 ,   1919    ,   2925    ,   321 ,   653 ,   25925   ,   49439   ,0 };
            const std::uint32_t dim3816Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   5   ,   55  ,   109 ,   193 ,   125 ,   823 ,   1707    ,   2389    ,   4135    ,   5197    ,   12563   ,   5977    ,0 };
            const std::uint32_t dim3817Kuo3Init[]   =   {   1   ,   3   ,   3   ,   7   ,   25  ,   47  ,   1   ,   145 ,   491 ,   661 ,   1125    ,   2567    ,   6783    ,   15009   ,   31871   ,   46645   ,0 };
            const std::uint32_t dim3818Kuo3Init[]   =   {   1   ,   3   ,   3   ,   7   ,   13  ,   43  ,   105 ,   69  ,   25  ,   157 ,   923 ,   1997    ,   4383    ,   14935   ,   8821    ,   6383    ,0 };
            const std::uint32_t dim3819Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   23  ,   41  ,   51  ,   215 ,   509 ,   117 ,   1871    ,   3025    ,   4295    ,   8327    ,   23887   ,   53039   ,0 };
            const std::uint32_t dim3820Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   17  ,   9   ,   41  ,   89  ,   227 ,   909 ,   523 ,   3755    ,   3527    ,   12117   ,   12455   ,   18087   ,0 };
            const std::uint32_t dim3821Kuo3Init[]   =   {   1   ,   3   ,   1   ,   11  ,   19  ,   1   ,   77  ,   73  ,   139 ,   707 ,   163 ,   2715    ,   819 ,   8401    ,   24751   ,   24619   ,0 };
            const std::uint32_t dim3822Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   11  ,   55  ,   31  ,   89  ,   383 ,   429 ,   269 ,   1593    ,   4929    ,   12037   ,   17279   ,   6489    ,0 };
            const std::uint32_t dim3823Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   5   ,   19  ,   65  ,   43  ,   257 ,   711 ,   349 ,   3231    ,   3169    ,   11759   ,   19069   ,   29043   ,0 };
            const std::uint32_t dim3824Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   5   ,   51  ,   31  ,   245 ,   197 ,   685 ,   1527    ,   3409    ,   4925    ,   8923    ,   10927   ,   62873   ,0 };
            const std::uint32_t dim3825Kuo3Init[]   =   {   1   ,   1   ,   7   ,   15  ,   31  ,   31  ,   61  ,   111 ,   327 ,   785 ,   97  ,   2659    ,   4777    ,   14187   ,   19731   ,   5195    ,0 };
            const std::uint32_t dim3826Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   7   ,   53  ,   3   ,   97  ,   109 ,   537 ,   1395    ,   1919    ,   4447    ,   4067    ,   30137   ,   60659   ,0 };
            const std::uint32_t dim3827Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   19  ,   45  ,   51  ,   107 ,   161 ,   269 ,   1003    ,   2363    ,   311 ,   7051    ,   25943   ,   20881   ,0 };
            const std::uint32_t dim3828Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   27  ,   49  ,   79  ,   187 ,   265 ,   903 ,   1547    ,   1147    ,   8049    ,   10451   ,   15371   ,   43705   ,0 };
            const std::uint32_t dim3829Kuo3Init[]   =   {   1   ,   3   ,   5   ,   1   ,   9   ,   25  ,   29  ,   229 ,   229 ,   337 ,   1821    ,   2377    ,   1325    ,   15079   ,   28661   ,   46107   ,0 };
            const std::uint32_t dim3830Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   29  ,   13  ,   121 ,   121 ,   229 ,   523 ,   707 ,   2577    ,   7637    ,   9257    ,   31031   ,   56527   ,0 };
            const std::uint32_t dim3831Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   11  ,   41  ,   111 ,   59  ,   347 ,   295 ,   895 ,   3477    ,   149 ,   6747    ,   14671   ,   3405    ,0 };
            const std::uint32_t dim3832Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   17  ,   17  ,   77  ,   105 ,   65  ,   831 ,   1969    ,   41  ,   1001    ,   2753    ,   4427    ,   25655   ,0 };
            const std::uint32_t dim3833Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   7   ,   37  ,   55  ,   121 ,   51  ,   155 ,   443 ,   321 ,   1845    ,   11587   ,   28855   ,   13905   ,0 };
            const std::uint32_t dim3834Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   9   ,   51  ,   1   ,   1   ,   453 ,   193 ,   1615    ,   2085    ,   3685    ,   15933   ,   18913   ,   46073   ,0 };
            const std::uint32_t dim3835Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   31  ,   29  ,   59  ,   55  ,   33  ,   413 ,   1261    ,   1367    ,   1895    ,   10291   ,   575 ,   12241   ,0 };
            const std::uint32_t dim3836Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   7   ,   11  ,   1   ,   207 ,   351 ,   357 ,   77  ,   4059    ,   3951    ,   4589    ,   11861   ,   43855   ,0 };
            const std::uint32_t dim3837Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   15  ,   1   ,   77  ,   227 ,   377 ,   25  ,   1665    ,   3693    ,   8129    ,   10059   ,   19517   ,   51103   ,0 };
            const std::uint32_t dim3838Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   25  ,   43  ,   103 ,   3   ,   477 ,   87  ,   1943    ,   1163    ,   7619    ,   8345    ,   25321   ,   36191   ,0 };
            const std::uint32_t dim3839Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   13  ,   5   ,   99  ,   11  ,   33  ,   113 ,   1905    ,   2559    ,   2679    ,   15005   ,   12859   ,   19233   ,0 };
            const std::uint32_t dim3840Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   9   ,   61  ,   79  ,   95  ,   71  ,   963 ,   1367    ,   1843    ,   3179    ,   10633   ,   5451    ,   64379   ,0 };
            const std::uint32_t dim3841Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   11  ,   11  ,   67  ,   11  ,   133 ,   759 ,   1823    ,   3281    ,   6741    ,   4995    ,   21753   ,   17093   ,0 };
            const std::uint32_t dim3842Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   29  ,   41  ,   31  ,   17  ,   381 ,   741 ,   567 ,   1009    ,   4781    ,   8953    ,   12397   ,   51833   ,0 };
            const std::uint32_t dim3843Kuo3Init[]   =   {   1   ,   3   ,   3   ,   7   ,   9   ,   61  ,   35  ,   203 ,   69  ,   633 ,   477 ,   2839    ,   1917    ,   12097   ,   28693   ,   42999   ,0 };
            const std::uint32_t dim3844Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   29  ,   25  ,   1   ,   219 ,   343 ,   249 ,   1077    ,   125 ,   3197    ,   5877    ,   28407   ,   59627   ,0 };
            const std::uint32_t dim3845Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   25  ,   37  ,   113 ,   125 ,   253 ,   947 ,   1103    ,   1283    ,   3493    ,   7129    ,   17881   ,   21279   ,0 };
            const std::uint32_t dim3846Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   29  ,   43  ,   125 ,   203 ,   495 ,   421 ,   1725    ,   1673    ,   3635    ,   8161    ,   3753    ,   46323   ,0 };
            const std::uint32_t dim3847Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   9   ,   7   ,   73  ,   117 ,   397 ,   521 ,   1699    ,   2715    ,   6149    ,   2337    ,   30623   ,   3943    ,0 };
            const std::uint32_t dim3848Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   13  ,   17  ,   121 ,   163 ,   491 ,   111 ,   1589    ,   351 ,   303 ,   7395    ,   5731    ,   65513   ,0 };
            const std::uint32_t dim3849Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   11  ,   1   ,   19  ,   179 ,   295 ,   595 ,   897 ,   1929    ,   1379    ,   13651   ,   19067   ,   43507   ,0 };
            const std::uint32_t dim3850Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   29  ,   51  ,   19  ,   221 ,   67  ,   507 ,   213 ,   1873    ,   6051    ,   11191   ,   31475   ,   23447   ,0 };
            const std::uint32_t dim3851Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   13  ,   35  ,   97  ,   75  ,   195 ,   569 ,   1047    ,   2607    ,   1549    ,   9495    ,   5945    ,   7581    ,0 };
            const std::uint32_t dim3852Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   23  ,   41  ,   125 ,   101 ,   415 ,   927 ,   1421    ,   2043    ,   8035    ,   4077    ,   11133   ,   17333   ,0 };
            const std::uint32_t dim3853Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   5   ,   51  ,   111 ,   129 ,   29  ,   469 ,   991 ,   2595    ,   165 ,   13987   ,   30077   ,   63491   ,0 };
            const std::uint32_t dim3854Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   1   ,   17  ,   93  ,   7   ,   511 ,   3   ,   861 ,   3979    ,   2173    ,   6571    ,   30099   ,   12907   ,0 };
            const std::uint32_t dim3855Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   9   ,   29  ,   43  ,   153 ,   83  ,   961 ,   1585    ,   3615    ,   4409    ,   1937    ,   24107   ,   45235   ,0 };
            const std::uint32_t dim3856Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   19  ,   29  ,   81  ,   183 ,   197 ,   565 ,   1455    ,   2993    ,   6731    ,   2749    ,   1013    ,   27777   ,0 };
            const std::uint32_t dim3857Kuo3Init[]   =   {   1   ,   3   ,   7   ,   1   ,   17  ,   11  ,   121 ,   245 ,   103 ,   851 ,   1367    ,   141 ,   1257    ,   719 ,   25581   ,   48999   ,0 };
            const std::uint32_t dim3858Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   15  ,   17  ,   33  ,   255 ,   113 ,   715 ,   1497    ,   3137    ,   1415    ,   7791    ,   28563   ,   28415   ,0 };
            const std::uint32_t dim3859Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   7   ,   45  ,   19  ,   143 ,   73  ,   95  ,   317 ,   1777    ,   7263    ,   11833   ,   25181   ,   27137   ,0 };
            const std::uint32_t dim3860Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   15  ,   49  ,   71  ,   57  ,   101 ,   95  ,   667 ,   2745    ,   6387    ,   14167   ,   661 ,   31809   ,0 };
            const std::uint32_t dim3861Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   7   ,   11  ,   119 ,   5   ,   3   ,   383 ,   933 ,   293 ,   5507    ,   3025    ,   18865   ,   26577   ,0 };
            const std::uint32_t dim3862Kuo3Init[]   =   {   1   ,   1   ,   7   ,   9   ,   21  ,   57  ,   113 ,   173 ,   103 ,   743 ,   1573    ,   2165    ,   2909    ,   14253   ,   2303    ,   51939   ,0 };
            const std::uint32_t dim3863Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   11  ,   29  ,   85  ,   239 ,   501 ,   123 ,   1149    ,   165 ,   6341    ,   10205   ,   18829   ,   32327   ,0 };
            const std::uint32_t dim3864Kuo3Init[]   =   {   1   ,   3   ,   1   ,   15  ,   21  ,   15  ,   63  ,   117 ,   217 ,   701 ,   299 ,   2887    ,   1341    ,   1617    ,   15163   ,   45899   ,0 };
            const std::uint32_t dim3865Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   25  ,   63  ,   91  ,   225 ,   399 ,   765 ,   1719    ,   3169    ,   1645    ,   10445   ,   1109    ,   13021   ,0 };
            const std::uint32_t dim3866Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   3   ,   9   ,   115 ,   35  ,   59  ,   145 ,   551 ,   2601    ,   1737    ,   9753    ,   7665    ,   30995   ,0 };
            const std::uint32_t dim3867Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   1   ,   33  ,   37  ,   173 ,   385 ,   635 ,   1419    ,   1377    ,   3161    ,   1915    ,   30933   ,   46117   ,0 };
            const std::uint32_t dim3868Kuo3Init[]   =   {   1   ,   1   ,   7   ,   9   ,   21  ,   35  ,   65  ,   227 ,   329 ,   797 ,   61  ,   3409    ,   3911    ,   751 ,   21951   ,   11969   ,0 };
            const std::uint32_t dim3869Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   13  ,   33  ,   29  ,   197 ,   183 ,   979 ,   979 ,   1629    ,   6017    ,   8645    ,   4007    ,   52377   ,0 };
            const std::uint32_t dim3870Kuo3Init[]   =   {   1   ,   1   ,   5   ,   7   ,   5   ,   17  ,   29  ,   117 ,   197 ,   163 ,   685 ,   2561    ,   2849    ,   5441    ,   32031   ,   25761   ,0 };
            const std::uint32_t dim3871Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   9   ,   17  ,   59  ,   237 ,   33  ,   11  ,   399 ,   3543    ,   7273    ,   8239    ,   15191   ,   57529   ,0 };
            const std::uint32_t dim3872Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   1   ,   45  ,   75  ,   107 ,   123 ,   909 ,   389 ,   3549    ,   4961    ,   15671   ,   14139   ,   29273   ,0 };
            const std::uint32_t dim3873Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   23  ,   3   ,   93  ,   73  ,   265 ,   889 ,   27  ,   805 ,   6021    ,   5851    ,   7181    ,   35309   ,0 };
            const std::uint32_t dim3874Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   23  ,   61  ,   17  ,   89  ,   495 ,   813 ,   1189    ,   1137    ,   7363    ,   6075    ,   3053    ,   28313   ,0 };
            const std::uint32_t dim3875Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   3   ,   1   ,   9   ,   133 ,   63  ,   417 ,   843 ,   2481    ,   5703    ,   11095   ,   867 ,   28097   ,0 };
            const std::uint32_t dim3876Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   23  ,   15  ,   113 ,   23  ,   199 ,   863 ,   1751    ,   765 ,   1917    ,   2145    ,   5391    ,   4629    ,0 };
            const std::uint32_t dim3877Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   13  ,   59  ,   127 ,   115 ,   341 ,   311 ,   677 ,   2305    ,   19  ,   13871   ,   9297    ,   4023    ,0 };
            const std::uint32_t dim3878Kuo3Init[]   =   {   1   ,   1   ,   5   ,   7   ,   13  ,   3   ,   25  ,   195 ,   403 ,   323 ,   515 ,   2809    ,   983 ,   8699    ,   10205   ,   14719   ,0 };
            const std::uint32_t dim3879Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   5   ,   33  ,   123 ,   213 ,   99  ,   889 ,   1151    ,   3339    ,   4855    ,   3677    ,   30627   ,   23225   ,0 };
            const std::uint32_t dim3880Kuo3Init[]   =   {   1   ,   1   ,   7   ,   9   ,   21  ,   19  ,   77  ,   85  ,   155 ,   379 ,   119 ,   81  ,   1937    ,   3589    ,   22645   ,   51585   ,0 };
            const std::uint32_t dim3881Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   5   ,   11  ,   121 ,   111 ,   423 ,   927 ,   1551    ,   2207    ,   3589    ,   691 ,   8519    ,   61261   ,0 };
            const std::uint32_t dim3882Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   1   ,   59  ,   25  ,   111 ,   415 ,   41  ,   623 ,   2505    ,   6075    ,   973 ,   10419   ,   26877   ,0 };
            const std::uint32_t dim3883Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   15  ,   57  ,   43  ,   27  ,   177 ,   733 ,   1521    ,   3629    ,   3003    ,   15351   ,   26327   ,   32921   ,0 };
            const std::uint32_t dim3884Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   1   ,   37  ,   3   ,   183 ,   349 ,   731 ,   1583    ,   2787    ,   6233    ,   14787   ,   16299   ,   4663    ,0 };
            const std::uint32_t dim3885Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   29  ,   47  ,   59  ,   79  ,   265 ,   193 ,   503 ,   2393    ,   643 ,   14341   ,   21055   ,   43803   ,0 };
            const std::uint32_t dim3886Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   11  ,   43  ,   75  ,   77  ,   493 ,   411 ,   145 ,   227 ,   3045    ,   363 ,   19879   ,   41017   ,0 };
            const std::uint32_t dim3887Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   1   ,   49  ,   87  ,   3   ,   377 ,   795 ,   1905    ,   2959    ,   3743    ,   1459    ,   32493   ,   6283    ,0 };
            const std::uint32_t dim3888Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   13  ,   13  ,   39  ,   83  ,   131 ,   935 ,   599 ,   1871    ,   7293    ,   11749   ,   6627    ,   58295   ,0 };
            const std::uint32_t dim3889Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   15  ,   9   ,   107 ,   239 ,   453 ,   53  ,   1825    ,   1493    ,   3611    ,   9993    ,   12535   ,   38879   ,0 };
            const std::uint32_t dim3890Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   1   ,   21  ,   93  ,   189 ,   477 ,   923 ,   13  ,   3797    ,   8147    ,   8417    ,   21473   ,   62305   ,0 };
            const std::uint32_t dim3891Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   21  ,   47  ,   75  ,   183 ,   425 ,   281 ,   813 ,   571 ,   1017    ,   565 ,   8541    ,   52977   ,0 };
            const std::uint32_t dim3892Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   29  ,   53  ,   25  ,   217 ,   111 ,   605 ,   1771    ,   1827    ,   7245    ,   16063   ,   10769   ,   57483   ,0 };
            const std::uint32_t dim3893Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   9   ,   27  ,   99  ,   75  ,   171 ,   299 ,   1751    ,   841 ,   4717    ,   7373    ,   14241   ,   7435    ,0 };
            const std::uint32_t dim3894Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   27  ,   13  ,   121 ,   69  ,   453 ,   1009    ,   1353    ,   3289    ,   3221    ,   9127    ,   29967   ,   60919   ,0 };
            const std::uint32_t dim3895Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   5   ,   41  ,   81  ,   151 ,   479 ,   599 ,   1751    ,   2841    ,   5721    ,   1725    ,   3465    ,   23385   ,0 };
            const std::uint32_t dim3896Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   7   ,   7   ,   35  ,   169 ,   35  ,   255 ,   1657    ,   297 ,   3855    ,   2071    ,   10929   ,   15907   ,0 };
            const std::uint32_t dim3897Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   25  ,   1   ,   43  ,   139 ,   165 ,   535 ,   95  ,   2769    ,   8105    ,   6865    ,   20297   ,   64539   ,0 };
            const std::uint32_t dim3898Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   21  ,   27  ,   11  ,   209 ,   279 ,   769 ,   1961    ,   101 ,   2103    ,   4529    ,   4987    ,   29097   ,0 };
            const std::uint32_t dim3899Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   29  ,   37  ,   45  ,   65  ,   75  ,   729 ,   1773    ,   4023    ,   7671    ,   6259    ,   22339   ,   45735   ,0 };
            const std::uint32_t dim3900Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   25  ,   3   ,   41  ,   139 ,   365 ,   915 ,   111 ,   611 ,   7609    ,   6259    ,   12247   ,   58671   ,0 };
            const std::uint32_t dim3901Kuo3Init[]   =   {   1   ,   1   ,   7   ,   15  ,   11  ,   45  ,   95  ,   121 ,   3   ,   491 ,   1779    ,   1055    ,   7051    ,   15499   ,   17301   ,   13081   ,0 };
            const std::uint32_t dim3902Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   5   ,   43  ,   105 ,   173 ,   267 ,   263 ,   873 ,   953 ,   5945    ,   11417   ,   23799   ,   54591   ,0 };
            const std::uint32_t dim3903Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   1   ,   55  ,   15  ,   73  ,   87  ,   49  ,   1651    ,   775 ,   6485    ,   9543    ,   26199   ,   30419   ,0 };
            const std::uint32_t dim3904Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   11  ,   5   ,   35  ,   37  ,   451 ,   85  ,   943 ,   4017    ,   6795    ,   8915    ,   28551   ,   45097   ,0 };
            const std::uint32_t dim3905Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   11  ,   51  ,   93  ,   237 ,   487 ,   515 ,   1511    ,   383 ,   7571    ,   4673    ,   29395   ,   21659   ,0 };
            const std::uint32_t dim3906Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   11  ,   63  ,   113 ,   253 ,   99  ,   733 ,   2001    ,   3767    ,   7431    ,   12131   ,   25203   ,   22251   ,0 };
            const std::uint32_t dim3907Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   11  ,   29  ,   37  ,   181 ,   299 ,   9   ,   11  ,   317 ,   1079    ,   13441   ,   8925    ,   15847   ,0 };
            const std::uint32_t dim3908Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   5   ,   9   ,   77  ,   67  ,   165 ,   273 ,   1161    ,   65  ,   7157    ,   13531   ,   2987    ,   1169    ,0 };
            const std::uint32_t dim3909Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   9   ,   57  ,   17  ,   209 ,   357 ,   901 ,   1113    ,   61  ,   5751    ,   2255    ,   29677   ,   56397   ,0 };
            const std::uint32_t dim3910Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   7   ,   5   ,   7   ,   53  ,   397 ,   279 ,   1387    ,   2447    ,   115 ,   2043    ,   19287   ,   45753   ,0 };
            const std::uint32_t dim3911Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   25  ,   41  ,   45  ,   33  ,   167 ,   801 ,   1929    ,   1173    ,   1525    ,   3725    ,   22407   ,   37077   ,0 };
            const std::uint32_t dim3912Kuo3Init[]   =   {   1   ,   3   ,   1   ,   11  ,   13  ,   61  ,   107 ,   181 ,   179 ,   51  ,   1379    ,   3573    ,   7319    ,   4843    ,   10023   ,   28725   ,0 };
            const std::uint32_t dim3913Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   11  ,   61  ,   61  ,   1   ,   211 ,   557 ,   417 ,   899 ,   4651    ,   3375    ,   19423   ,   11719   ,0 };
            const std::uint32_t dim3914Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   9   ,   5   ,   117 ,   217 ,   193 ,   911 ,   991 ,   155 ,   3011    ,   4759    ,   30953   ,   63939   ,0 };
            const std::uint32_t dim3915Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   21  ,   7   ,   77  ,   29  ,   457 ,   923 ,   871 ,   147 ,   5177    ,   13949   ,   1977    ,   27515   ,0 };
            const std::uint32_t dim3916Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   5   ,   39  ,   83  ,   133 ,   471 ,   355 ,   615 ,   1627    ,   2471    ,   59  ,   21449   ,   52293   ,0 };
            const std::uint32_t dim3917Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   23  ,   57  ,   97  ,   3   ,   385 ,   255 ,   1565    ,   3479    ,   5587    ,   15101   ,   27153   ,   9239    ,0 };
            const std::uint32_t dim3918Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   13  ,   25  ,   99  ,   19  ,   49  ,   655 ,   1823    ,   641 ,   619 ,   5913    ,   11379   ,   23781   ,0 };
            const std::uint32_t dim3919Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   21  ,   1   ,   91  ,   3   ,   31  ,   19  ,   19  ,   3627    ,   1575    ,   1439    ,   7473    ,   36215   ,0 };
            const std::uint32_t dim3920Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   29  ,   61  ,   1   ,   151 ,   291 ,   315 ,   965 ,   3435    ,   1849    ,   13069   ,   9785    ,   41345   ,0 };
            const std::uint32_t dim3921Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   17  ,   9   ,   97  ,   69  ,   233 ,   925 ,   1933    ,   3861    ,   89  ,   7889    ,   28853   ,   64959   ,0 };
            const std::uint32_t dim3922Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   5   ,   51  ,   67  ,   175 ,   341 ,   191 ,   1643    ,   3327    ,   763 ,   327 ,   28069   ,   15317   ,0 };
            const std::uint32_t dim3923Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   3   ,   37  ,   109 ,   43  ,   465 ,   57  ,   489 ,   915 ,   6943    ,   7947    ,   9229    ,   5647    ,0 };
            const std::uint32_t dim3924Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   27  ,   1   ,   85  ,   171 ,   185 ,   615 ,   1451    ,   237 ,   1597    ,   4255    ,   24429   ,   34357   ,0 };
            const std::uint32_t dim3925Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   29  ,   35  ,   69  ,   237 ,   117 ,   841 ,   1549    ,   2093    ,   105 ,   10197   ,   5229    ,   59299   ,0 };
            const std::uint32_t dim3926Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   7   ,   33  ,   73  ,   81  ,   385 ,   177 ,   1849    ,   773 ,   1085    ,   5539    ,   29213   ,   30635   ,0 };
            const std::uint32_t dim3927Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   15  ,   47  ,   53  ,   207 ,   337 ,   479 ,   775 ,   2851    ,   725 ,   14779   ,   29653   ,   35949   ,0 };
            const std::uint32_t dim3928Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   15  ,   53  ,   53  ,   87  ,   315 ,   929 ,   919 ,   907 ,   6893    ,   4647    ,   2019    ,   57879   ,0 };
            const std::uint32_t dim3929Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   5   ,   31  ,   21  ,   9   ,   215 ,   599 ,   617 ,   3737    ,   787 ,   10513   ,   17907   ,   22221   ,0 };
            const std::uint32_t dim3930Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   27  ,   5   ,   27  ,   157 ,   423 ,   197 ,   1757    ,   2451    ,   6317    ,   1557    ,   6641    ,   12621   ,0 };
            const std::uint32_t dim3931Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   19  ,   17  ,   109 ,   37  ,   329 ,   217 ,   1265    ,   3073    ,   6243    ,   6179    ,   25921   ,   9001    ,0 };
            const std::uint32_t dim3932Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   13  ,   13  ,   103 ,   79  ,   399 ,   897 ,   1241    ,   2847    ,   5913    ,   2267    ,   5367    ,   26337   ,0 };
            const std::uint32_t dim3933Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   17  ,   41  ,   19  ,   213 ,   123 ,   123 ,   1103    ,   1125    ,   2819    ,   7643    ,   26391   ,   20935   ,0 };
            const std::uint32_t dim3934Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   29  ,   27  ,   79  ,   143 ,   93  ,   311 ,   433 ,   1945    ,   2783    ,   13787   ,   4473    ,   23279   ,0 };
            const std::uint32_t dim3935Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   13  ,   49  ,   39  ,   21  ,   117 ,   933 ,   169 ,   551 ,   2871    ,   9879    ,   3715    ,   25143   ,0 };
            const std::uint32_t dim3936Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   29  ,   15  ,   5   ,   89  ,   255 ,   779 ,   495 ,   2335    ,   6029    ,   8733    ,   5687    ,   40189   ,0 };
            const std::uint32_t dim3937Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   5   ,   61  ,   37  ,   231 ,   395 ,   175 ,   711 ,   1149    ,   4819    ,   10119   ,   24929   ,   37155   ,0 };
            const std::uint32_t dim3938Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   7   ,   49  ,   81  ,   221 ,   193 ,   685 ,   2029    ,   3979    ,   5071    ,   2965    ,   18951   ,   21497   ,0 };
            const std::uint32_t dim3939Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   11  ,   17  ,   29  ,   153 ,   379 ,   387 ,   1271    ,   1261    ,   817 ,   5913    ,   22395   ,   885 ,0 };
            const std::uint32_t dim3940Kuo3Init[]   =   {   1   ,   1   ,   1   ,   1   ,   3   ,   37  ,   89  ,   255 ,   337 ,   135 ,   535 ,   1087    ,   7987    ,   8107    ,   22953   ,   18709   ,0 };
            const std::uint32_t dim3941Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   25  ,   29  ,   15  ,   223 ,   181 ,   879 ,   1661    ,   1605    ,   3777    ,   5221    ,   7253    ,   22951   ,0 };
            const std::uint32_t dim3942Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   3   ,   9   ,   57  ,   239 ,   439 ,   669 ,   1069    ,   2001    ,   2689    ,   9569    ,   24151   ,   54337   ,0 };
            const std::uint32_t dim3943Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   7   ,   47  ,   21  ,   31  ,   35  ,   739 ,   1229    ,   2929    ,   5221    ,   6715    ,   32275   ,   42743   ,0 };
            const std::uint32_t dim3944Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   19  ,   3   ,   85  ,   55  ,   397 ,   875 ,   949 ,   2835    ,   6077    ,   1069    ,   13307   ,   5897    ,0 };
            const std::uint32_t dim3945Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   11  ,   57  ,   113 ,   193 ,   191 ,   53  ,   1319    ,   1585    ,   4797    ,   13903   ,   24875   ,   50229   ,0 };
            const std::uint32_t dim3946Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   15  ,   17  ,   29  ,   125 ,   387 ,   775 ,   411 ,   1283    ,   6069    ,   10909   ,   14221   ,   52811   ,0 };
            const std::uint32_t dim3947Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   17  ,   47  ,   73  ,   143 ,   133 ,   1009    ,   1671    ,   2307    ,   2991    ,   10319   ,   3161    ,   665 ,0 };
            const std::uint32_t dim3948Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   23  ,   29  ,   115 ,   77  ,   167 ,   667 ,   1983    ,   3985    ,   1449    ,   10055   ,   27947   ,   63501   ,0 };
            const std::uint32_t dim3949Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   27  ,   61  ,   83  ,   173 ,   427 ,   161 ,   1349    ,   297 ,   1579    ,   9929    ,   32663   ,   44385   ,0 };
            const std::uint32_t dim3950Kuo3Init[]   =   {   1   ,   1   ,   7   ,   9   ,   19  ,   31  ,   73  ,   233 ,   109 ,   991 ,   1381    ,   3223    ,   4033    ,   4447    ,   4773    ,   61631   ,0 };
            const std::uint32_t dim3951Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   17  ,   53  ,   71  ,   201 ,   181 ,   395 ,   1305    ,   2049    ,   4317    ,   12689   ,   23133   ,   13401   ,0 };
            const std::uint32_t dim3952Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   13  ,   63  ,   17  ,   107 ,   149 ,   739 ,   1829    ,   2441    ,   3491    ,   1649    ,   15839   ,   13021   ,0 };
            const std::uint32_t dim3953Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   3   ,   15  ,   35  ,   247 ,   95  ,   973 ,   1625    ,   3097    ,   6075    ,   14331   ,   8345    ,   12225   ,0 };
            const std::uint32_t dim3954Kuo3Init[]   =   {   1   ,   3   ,   3   ,   7   ,   9   ,   21  ,   5   ,   85  ,   431 ,   317 ,   1313    ,   1981    ,   7761    ,   2857    ,   18659   ,   58677   ,0 };
            const std::uint32_t dim3955Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   25  ,   23  ,   5   ,   213 ,   345 ,   119 ,   1979    ,   1023    ,   6849    ,   9587    ,   2519    ,   57219   ,0 };
            const std::uint32_t dim3956Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   17  ,   1   ,   15  ,   213 ,   21  ,   435 ,   1719    ,   3065    ,   6197    ,   8993    ,   8479    ,   17383   ,0 };
            const std::uint32_t dim3957Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   17  ,   35  ,   97  ,   167 ,   411 ,   57  ,   145 ,   663 ,   1319    ,   16029   ,   1649    ,   13097   ,0 };
            const std::uint32_t dim3958Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   13  ,   1   ,   89  ,   179 ,   355 ,   655 ,   1217    ,   1421    ,   4303    ,   2705    ,   30107   ,   45801   ,0 };
            const std::uint32_t dim3959Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   23  ,   49  ,   67  ,   119 ,   139 ,   397 ,   983 ,   3537    ,   1463    ,   10395   ,   4717    ,   50885   ,0 };
            const std::uint32_t dim3960Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   9   ,   9   ,   95  ,   75  ,   489 ,   459 ,   951 ,   1829    ,   5017    ,   8703    ,   6229    ,   18921   ,0 };
            const std::uint32_t dim3961Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   7   ,   55  ,   89  ,   75  ,   231 ,   141 ,   1611    ,   2275    ,   1953    ,   6389    ,   12899   ,   45117   ,0 };
            const std::uint32_t dim3962Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   25  ,   53  ,   91  ,   25  ,   425 ,   275 ,   189 ,   863 ,   5777    ,   6179    ,   12273   ,   3473    ,0 };
            const std::uint32_t dim3963Kuo3Init[]   =   {   1   ,   1   ,   7   ,   15  ,   5   ,   17  ,   75  ,   83  ,   357 ,   523 ,   1075    ,   1981    ,   3993    ,   13133   ,   16441   ,   53935   ,0 };
            const std::uint32_t dim3964Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   15  ,   13  ,   103 ,   89  ,   309 ,   961 ,   771 ,   1441    ,   1449    ,   15867   ,   20019   ,   22303   ,0 };
            const std::uint32_t dim3965Kuo3Init[]   =   {   1   ,   3   ,   5   ,   9   ,   7   ,   47  ,   33  ,   117 ,   151 ,   77  ,   893 ,   867 ,   2523    ,   13975   ,   20649   ,   15673   ,0 };
            const std::uint32_t dim3966Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   5   ,   15  ,   57  ,   149 ,   405 ,   523 ,   763 ,   4071    ,   5915    ,   3255    ,   22243   ,   46779   ,0 };
            const std::uint32_t dim3967Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   17  ,   39  ,   53  ,   181 ,   65  ,   541 ,   1995    ,   3213    ,   3837    ,   3527    ,   2433    ,   23527   ,0 };
            const std::uint32_t dim3968Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   17  ,   9   ,   5   ,   79  ,   299 ,   441 ,   1891    ,   3607    ,   5087    ,   14629   ,   31767   ,   21443   ,0 };
            const std::uint32_t dim3969Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   1   ,   47  ,   25  ,   13  ,   201 ,   691 ,   507 ,   2041    ,   3169    ,   2909    ,   5341    ,   7643    ,0 };
            const std::uint32_t dim3970Kuo3Init[]   =   {   1   ,   1   ,   1   ,   1   ,   31  ,   55  ,   109 ,   97  ,   335 ,   835 ,   933 ,   839 ,   3271    ,   14323   ,   25319   ,   18807   ,0 };
            const std::uint32_t dim3971Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   19  ,   21  ,   19  ,   79  ,   449 ,   1007    ,   1559    ,   3143    ,   2633    ,   11691   ,   3273    ,   17381   ,0 };
            const std::uint32_t dim3972Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   3   ,   61  ,   105 ,   255 ,   327 ,   649 ,   11  ,   715 ,   2629    ,   8425    ,   165 ,   6235    ,0 };
            const std::uint32_t dim3973Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   9   ,   39  ,   45  ,   161 ,   421 ,   243 ,   1589    ,   157 ,   5309    ,   9769    ,   28229   ,   12947   ,0 };
            const std::uint32_t dim3974Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   15  ,   17  ,   75  ,   23  ,   189 ,   601 ,   737 ,   687 ,   3387    ,   11913   ,   17245   ,   16073   ,0 };
            const std::uint32_t dim3975Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   25  ,   45  ,   73  ,   243 ,   171 ,   179 ,   617 ,   2039    ,   4937    ,   963 ,   10791   ,   48989   ,0 };
            const std::uint32_t dim3976Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   3   ,   61  ,   123 ,   27  ,   3   ,   385 ,   1357    ,   3773    ,   1639    ,   353 ,   21277   ,   52013   ,0 };
            const std::uint32_t dim3977Kuo3Init[]   =   {   1   ,   3   ,   5   ,   9   ,   27  ,   19  ,   49  ,   255 ,   213 ,   753 ,   297 ,   601 ,   4905    ,   15889   ,   18055   ,   31511   ,0 };
            const std::uint32_t dim3978Kuo3Init[]   =   {   1   ,   1   ,   7   ,   9   ,   1   ,   19  ,   93  ,   251 ,   279 ,   21  ,   891 ,   859 ,   4637    ,   2587    ,   17659   ,   19485   ,0 };
            const std::uint32_t dim3979Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   29  ,   55  ,   69  ,   151 ,   445 ,   947 ,   719 ,   3935    ,   4625    ,   9321    ,   25645   ,   39153   ,0 };
            const std::uint32_t dim3980Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   23  ,   57  ,   79  ,   21  ,   353 ,   7   ,   295 ,   3379    ,   3505    ,   15409   ,   9117    ,   19745   ,0 };
            const std::uint32_t dim3981Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   7   ,   5   ,   41  ,   249 ,   429 ,   999 ,   1945    ,   1097    ,   795 ,   8647    ,   23297   ,   60707   ,0 };
            const std::uint32_t dim3982Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   3   ,   57  ,   105 ,   175 ,   345 ,   53  ,   455 ,   1549    ,   5291    ,   6757    ,   12637   ,   45159   ,0 };
            const std::uint32_t dim3983Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   5   ,   31  ,   5   ,   69  ,   373 ,   453 ,   1861    ,   1061    ,   6339    ,   3857    ,   13979   ,   24015   ,0 };
            const std::uint32_t dim3984Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   19  ,   41  ,   113 ,   183 ,   299 ,   197 ,   397 ,   1597    ,   6471    ,   14855   ,   26067   ,   2705    ,0 };
            const std::uint32_t dim3985Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   15  ,   59  ,   89  ,   73  ,   45  ,   891 ,   1285    ,   1565    ,   4675    ,   10669   ,   3067    ,   40585   ,0 };
            const std::uint32_t dim3986Kuo3Init[]   =   {   1   ,   1   ,   5   ,   7   ,   1   ,   51  ,   59  ,   27  ,   275 ,   961 ,   765 ,   3003    ,   1677    ,   2093    ,   15083   ,   51929   ,0 };
            const std::uint32_t dim3987Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   19  ,   37  ,   101 ,   247 ,   223 ,   39  ,   2009    ,   3155    ,   6357    ,   13513   ,   30965   ,   36485   ,0 };
            const std::uint32_t dim3988Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   27  ,   9   ,   71  ,   231 ,   115 ,   1   ,   719 ,   873 ,   4895    ,   4031    ,   23581   ,   17529   ,0 };
            const std::uint32_t dim3989Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   1   ,   63  ,   13  ,   187 ,   325 ,   199 ,   1165    ,   491 ,   1361    ,   15377   ,   9463    ,   5077    ,0 };
            const std::uint32_t dim3990Kuo3Init[]   =   {   1   ,   3   ,   3   ,   7   ,   9   ,   13  ,   71  ,   17  ,   213 ,   915 ,   1779    ,   401 ,   5315    ,   2161    ,   14765   ,   11301   ,0 };
            const std::uint32_t dim3991Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   5   ,   5   ,   3   ,   137 ,   17  ,   197 ,   1559    ,   3077    ,   4615    ,   923 ,   2143    ,   16743   ,0 };
            const std::uint32_t dim3992Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   13  ,   19  ,   77  ,   155 ,   285 ,   209 ,   1089    ,   2213    ,   3131    ,   11685   ,   13287   ,   10439   ,0 };
            const std::uint32_t dim3993Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   7   ,   11  ,   35  ,   113 ,   165 ,   795 ,   1657    ,   483 ,   4937    ,   5209    ,   19801   ,   13831   ,0 };
            const std::uint32_t dim3994Kuo3Init[]   =   {   1   ,   1   ,   7   ,   9   ,   29  ,   1   ,   67  ,   131 ,   277 ,   919 ,   1267    ,   3907    ,   2561    ,   2469    ,   25321   ,   17769   ,0 };
            const std::uint32_t dim3995Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   25  ,   39  ,   93  ,   5   ,   151 ,   905 ,   201 ,   1499    ,   4069    ,   4691    ,   8293    ,   945 ,0 };
            const std::uint32_t dim3996Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   3   ,   59  ,   47  ,   13  ,   79  ,   157 ,   231 ,   1105    ,   5449    ,   10889   ,   2625    ,   53303   ,0 };
            const std::uint32_t dim3997Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   13  ,   23  ,   25  ,   171 ,   391 ,   497 ,   57  ,   4089    ,   3849    ,   6121    ,   1561    ,   29977   ,0 };
            const std::uint32_t dim3998Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   17  ,   19  ,   33  ,   193 ,   351 ,   189 ,   619 ,   2091    ,   7881    ,   12689   ,   3799    ,   1199    ,0 };
            const std::uint32_t dim3999Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   5   ,   35  ,   23  ,   219 ,   247 ,   377 ,   439 ,   3421    ,   2729    ,   7169    ,   24373   ,   48533   ,0 };
            const std::uint32_t dim4000Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   23  ,   33  ,   77  ,   37  ,   347 ,   831 ,   1525    ,   2383    ,   6483    ,   15377   ,   22761   ,   51647   ,0 };
            const std::uint32_t dim4001Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   5   ,   51  ,   89  ,   207 ,   131 ,   969 ,   463 ,   3917    ,   5985    ,   10797   ,   25183   ,   35637   ,0 };
            const std::uint32_t dim4002Kuo3Init[]   =   {   1   ,   1   ,   1   ,   15  ,   9   ,   45  ,   99  ,   25  ,   7   ,   279 ,   541 ,   879 ,   6681    ,   2591    ,   31667   ,   51957   ,0 };
            const std::uint32_t dim4003Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   19  ,   13  ,   59  ,   119 ,   195 ,   385 ,   1715    ,   823 ,   7631    ,   9547    ,   27099   ,   30967   ,0 };
            const std::uint32_t dim4004Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   21  ,   29  ,   9   ,   17  ,   51  ,   819 ,   365 ,   1855    ,   1505    ,   13923   ,   27397   ,   25347   ,0 };
            const std::uint32_t dim4005Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   21  ,   1   ,   17  ,   109 ,   435 ,   887 ,   1951    ,   923 ,   181 ,   8365    ,   1531    ,   5533    ,0 };
            const std::uint32_t dim4006Kuo3Init[]   =   {   1   ,   3   ,   1   ,   15  ,   7   ,   29  ,   101 ,   221 ,   151 ,   49  ,   1655    ,   2889    ,   7179    ,   1019    ,   10765   ,   49489   ,0 };
            const std::uint32_t dim4007Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   27  ,   15  ,   25  ,   249 ,   31  ,   187 ,   1875    ,   2937    ,   5831    ,   13499   ,   27997   ,   8003    ,0 };
            const std::uint32_t dim4008Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   13  ,   55  ,   111 ,   231 ,   71  ,   245 ,   479 ,   2487    ,   7967    ,   10911   ,   12853   ,   56217   ,0 };
            const std::uint32_t dim4009Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   15  ,   13  ,   77  ,   37  ,   497 ,   899 ,   1527    ,   275 ,   517 ,   10323   ,   2329    ,   19267   ,0 };
            const std::uint32_t dim4010Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   13  ,   1   ,   17  ,   201 ,   211 ,   153 ,   1377    ,   347 ,   3481    ,   6785    ,   23745   ,   54849   ,0 };
            const std::uint32_t dim4011Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   23  ,   29  ,   55  ,   91  ,   249 ,   815 ,   1375    ,   3081    ,   1445    ,   13763   ,   29983   ,   24581   ,0 };
            const std::uint32_t dim4012Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   23  ,   19  ,   65  ,   31  ,   105 ,   797 ,   957 ,   1741    ,   4189    ,   3313    ,   17183   ,   34345   ,0 };
            const std::uint32_t dim4013Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   23  ,   51  ,   13  ,   119 ,   19  ,   901 ,   1985    ,   3269    ,   3753    ,   5365    ,   3871    ,   30099   ,0 };
            const std::uint32_t dim4014Kuo3Init[]   =   {   1   ,   1   ,   1   ,   1   ,   13  ,   11  ,   3   ,   59  ,   45  ,   1007    ,   121 ,   1433    ,   1559    ,   15593   ,   187 ,   55939   ,0 };
            const std::uint32_t dim4015Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   7   ,   15  ,   17  ,   227 ,   143 ,   889 ,   1011    ,   1195    ,   3849    ,   12643   ,   27303   ,   10473   ,0 };
            const std::uint32_t dim4016Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   9   ,   63  ,   35  ,   181 ,   301 ,   945 ,   853 ,   877 ,   2983    ,   9945    ,   31237   ,   12011   ,0 };
            const std::uint32_t dim4017Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   23  ,   17  ,   111 ,   15  ,   429 ,   925 ,   299 ,   173 ,   3379    ,   2407    ,   11999   ,   44485   ,0 };
            const std::uint32_t dim4018Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   31  ,   55  ,   103 ,   227 ,   93  ,   15  ,   399 ,   1559    ,   3107    ,   5729    ,   24069   ,   55711   ,0 };
            const std::uint32_t dim4019Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   25  ,   5   ,   107 ,   57  ,   23  ,   1005    ,   27  ,   2881    ,   2591    ,   10939   ,   8613    ,   50351   ,0 };
            const std::uint32_t dim4020Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   19  ,   23  ,   107 ,   65  ,   11  ,   643 ,   1337    ,   3197    ,   1583    ,   8797    ,   6047    ,   55749   ,0 };
            const std::uint32_t dim4021Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   3   ,   61  ,   31  ,   67  ,   369 ,   755 ,   1263    ,   2711    ,   1341    ,   15465   ,   25337   ,   20607   ,0 };
            const std::uint32_t dim4022Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   23  ,   53  ,   95  ,   223 ,   225 ,   627 ,   471 ,   1203    ,   7689    ,   3211    ,   24697   ,   21153   ,0 };
            const std::uint32_t dim4023Kuo3Init[]   =   {   1   ,   3   ,   7   ,   1   ,   3   ,   29  ,   45  ,   15  ,   247 ,   45  ,   345 ,   4063    ,   3819    ,   263 ,   9705    ,   27991   ,0 };
            const std::uint32_t dim4024Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   3   ,   55  ,   127 ,   247 ,   87  ,   969 ,   1409    ,   2105    ,   4133    ,   1213    ,   2719    ,   37043   ,0 };
            const std::uint32_t dim4025Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   9   ,   15  ,   71  ,   9   ,   421 ,   1   ,   1367    ,   2557    ,   2121    ,   2919    ,   29167   ,   7035    ,0 };
            const std::uint32_t dim4026Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   21  ,   35  ,   7   ,   1   ,   429 ,   491 ,   1077    ,   499 ,   2915    ,   13217   ,   25153   ,   327 ,0 };
            const std::uint32_t dim4027Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   7   ,   57  ,   37  ,   235 ,   97  ,   357 ,   1171    ,   705 ,   7111    ,   5217    ,   13167   ,   38395   ,0 };
            const std::uint32_t dim4028Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   9   ,   55  ,   43  ,   173 ,   429 ,   287 ,   355 ,   3009    ,   1667    ,   1845    ,   11477   ,   25437   ,0 };
            const std::uint32_t dim4029Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   13  ,   41  ,   41  ,   239 ,   421 ,   347 ,   1423    ,   797 ,   7435    ,   16195   ,   3501    ,   56213   ,0 };
            const std::uint32_t dim4030Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   25  ,   59  ,   67  ,   49  ,   363 ,   125 ,   365 ,   2517    ,   915 ,   2865    ,   25361   ,   24823   ,0 };
            const std::uint32_t dim4031Kuo3Init[]   =   {   1   ,   3   ,   7   ,   1   ,   31  ,   55  ,   109 ,   213 ,   19  ,   843 ,   1457    ,   851 ,   7245    ,   13587   ,   30111   ,   58737   ,0 };
            const std::uint32_t dim4032Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   7   ,   29  ,   111 ,   121 ,   511 ,   401 ,   411 ,   3073    ,   3617    ,   4447    ,   12443   ,   49051   ,0 };
            const std::uint32_t dim4033Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   5   ,   55  ,   89  ,   231 ,   343 ,   869 ,   465 ,   1421    ,   701 ,   13565   ,   12469   ,   62381   ,0 };
            const std::uint32_t dim4034Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   7   ,   9   ,   91  ,   147 ,   37  ,   917 ,   1717    ,   2221    ,   5795    ,   7127    ,   21599   ,   28335   ,0 };
            const std::uint32_t dim4035Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   9   ,   51  ,   109 ,   43  ,   411 ,   477 ,   549 ,   1901    ,   4295    ,   2915    ,   5701    ,   29005   ,0 };
            const std::uint32_t dim4036Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   11  ,   51  ,   5   ,   81  ,   413 ,   461 ,   143 ,   2695    ,   2091    ,   8435    ,   14217   ,   60831   ,0 };
            const std::uint32_t dim4037Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   1   ,   15  ,   17  ,   239 ,   219 ,   75  ,   339 ,   1565    ,   5029    ,   6351    ,   19429   ,   21483   ,0 };
            const std::uint32_t dim4038Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   13  ,   7   ,   101 ,   215 ,   395 ,   387 ,   1215    ,   1967    ,   4141    ,   643 ,   14623   ,   58609   ,0 };
            const std::uint32_t dim4039Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   17  ,   29  ,   85  ,   201 ,   327 ,   855 ,   1971    ,   335 ,   6201    ,   5933    ,   6131    ,   3179    ,0 };
            const std::uint32_t dim4040Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   3   ,   49  ,   25  ,   223 ,   207 ,   477 ,   671 ,   1881    ,   3639    ,   10867   ,   22953   ,   58725   ,0 };
            const std::uint32_t dim4041Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   21  ,   23  ,   31  ,   57  ,   387 ,   881 ,   343 ,   1781    ,   3241    ,   10939   ,   5569    ,   37555   ,0 };
            const std::uint32_t dim4042Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   25  ,   3   ,   117 ,   153 ,   155 ,   61  ,   127 ,   3871    ,   7883    ,   11791   ,   18529   ,   55395   ,0 };
            const std::uint32_t dim4043Kuo3Init[]   =   {   1   ,   1   ,   7   ,   9   ,   15  ,   15  ,   89  ,   197 ,   109 ,   221 ,   317 ,   2827    ,   2159    ,   847 ,   2527    ,   9463    ,0 };
            const std::uint32_t dim4044Kuo3Init[]   =   {   1   ,   3   ,   5   ,   9   ,   25  ,   11  ,   39  ,   185 ,   457 ,   831 ,   637 ,   527 ,   2829    ,   4411    ,   4713    ,   53597   ,0 };
            const std::uint32_t dim4045Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   5   ,   27  ,   45  ,   123 ,   385 ,   217 ,   907 ,   2877    ,   2703    ,   15987   ,   24963   ,   41659   ,0 };
            const std::uint32_t dim4046Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   9   ,   31  ,   7   ,   225 ,   77  ,   227 ,   175 ,   1471    ,   3305    ,   4521    ,   6345    ,   55509   ,0 };
            const std::uint32_t dim4047Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   21  ,   33  ,   37  ,   3   ,   121 ,   605 ,   1121    ,   537 ,   1771    ,   14415   ,   8323    ,   21795   ,0 };
            const std::uint32_t dim4048Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   23  ,   23  ,   45  ,   231 ,   97  ,   535 ,   861 ,   1349    ,   6611    ,   7445    ,   25231   ,   50737   ,0 };
            const std::uint32_t dim4049Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   11  ,   13  ,   61  ,   155 ,   483 ,   391 ,   615 ,   899 ,   5099    ,   4895    ,   2919    ,   60239   ,0 };
            const std::uint32_t dim4050Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   31  ,   9   ,   47  ,   209 ,   405 ,   493 ,   103 ,   59  ,   3609    ,   12889   ,   6501    ,   32869   ,0 };
            const std::uint32_t dim4051Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   15  ,   57  ,   23  ,   153 ,   57  ,   369 ,   1833    ,   1287    ,   4487    ,   3195    ,   19587   ,   24373   ,0 };
            const std::uint32_t dim4052Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   25  ,   45  ,   51  ,   117 ,   293 ,   701 ,   1909    ,   659 ,   637 ,   3375    ,   23223   ,   29707   ,0 };
            const std::uint32_t dim4053Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   1   ,   27  ,   13  ,   227 ,   369 ,   143 ,   1167    ,   1787    ,   4815    ,   1143    ,   7789    ,   16467   ,0 };
            const std::uint32_t dim4054Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   13  ,   5   ,   63  ,   75  ,   13  ,   411 ,   1123    ,   459 ,   6323    ,   10445   ,   1303    ,   43103   ,0 };
            const std::uint32_t dim4055Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   29  ,   21  ,   93  ,   49  ,   135 ,   525 ,   121 ,   1299    ,   5931    ,   13115   ,   32567   ,   60605   ,0 };
            const std::uint32_t dim4056Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   25  ,   59  ,   77  ,   181 ,   39  ,   345 ,   1375    ,   2067    ,   3909    ,   8023    ,   6409    ,   12571   ,0 };
            const std::uint32_t dim4057Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   15  ,   55  ,   95  ,   183 ,   269 ,   931 ,   285 ,   1945    ,   2105    ,   10589   ,   19787   ,   64461   ,0 };
            const std::uint32_t dim4058Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   31  ,   19  ,   51  ,   109 ,   455 ,   877 ,   905 ,   2403    ,   2021    ,   573 ,   29837   ,   46871   ,0 };
            const std::uint32_t dim4059Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   21  ,   23  ,   9   ,   201 ,   143 ,   661 ,   289 ,   621 ,   6729    ,   9573    ,   6359    ,   14981   ,0 };
            const std::uint32_t dim4060Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   15  ,   53  ,   41  ,   57  ,   201 ,   37  ,   2047    ,   4045    ,   6501    ,   15641   ,   22031   ,   25851   ,0 };
            const std::uint32_t dim4061Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   17  ,   3   ,   31  ,   31  ,   165 ,   765 ,   1101    ,   1161    ,   7247    ,   16383   ,   27715   ,   20835   ,0 };
            const std::uint32_t dim4062Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   7   ,   41  ,   81  ,   55  ,   345 ,   913 ,   1457    ,   3801    ,   6937    ,   3781    ,   21125   ,   36899   ,0 };
            const std::uint32_t dim4063Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   21  ,   61  ,   57  ,   89  ,   341 ,   877 ,   639 ,   3051    ,   6541    ,   2133    ,   11187   ,   9613    ,0 };
            const std::uint32_t dim4064Kuo3Init[]   =   {   1   ,   3   ,   3   ,   5   ,   3   ,   29  ,   3   ,   193 ,   331 ,   333 ,   1613    ,   3755    ,   6489    ,   4851    ,   10421   ,   11257   ,0 };
            const std::uint32_t dim4065Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   15  ,   29  ,   115 ,   135 ,   283 ,   363 ,   905 ,   3199    ,   733 ,   7785    ,   5237    ,   20657   ,0 };
            const std::uint32_t dim4066Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   3   ,   31  ,   89  ,   219 ,   61  ,   573 ,   1773    ,   677 ,   7447    ,   4625    ,   17011   ,   57851   ,0 };
            const std::uint32_t dim4067Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   9   ,   31  ,   121 ,   219 ,   27  ,   583 ,   1769    ,   3667    ,   4415    ,   6789    ,   28069   ,   11833   ,0 };
            const std::uint32_t dim4068Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   29  ,   11  ,   63  ,   201 ,   33  ,   153 ,   1075    ,   641 ,   5923    ,   10485   ,   24573   ,   29423   ,0 };
            const std::uint32_t dim4069Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   17  ,   5   ,   87  ,   237 ,   243 ,   231 ,   915 ,   1755    ,   4021    ,   2127    ,   26147   ,   28397   ,0 };
            const std::uint32_t dim4070Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   21  ,   49  ,   53  ,   163 ,   415 ,   553 ,   505 ,   3309    ,   4987    ,   16163   ,   14439   ,   30921   ,0 };
            const std::uint32_t dim4071Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   9   ,   59  ,   89  ,   113 ,   203 ,   485 ,   177 ,   2243    ,   5267    ,   7105    ,   5297    ,   23333   ,0 };
            const std::uint32_t dim4072Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   13  ,   21  ,   107 ,   183 ,   243 ,   985 ,   499 ,   385 ,   2409    ,   9317    ,   17393   ,   1913    ,0 };
            const std::uint32_t dim4073Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   21  ,   47  ,   59  ,   21  ,   71  ,   523 ,   1843    ,   3131    ,   5907    ,   15401   ,   7957    ,   51365   ,0 };
            const std::uint32_t dim4074Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   17  ,   19  ,   75  ,   195 ,   171 ,   11  ,   57  ,   303 ,   6801    ,   1825    ,   25027   ,   28587   ,0 };
            const std::uint32_t dim4075Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   13  ,   47  ,   19  ,   161 ,   47  ,   385 ,   1227    ,   261 ,   5855    ,   1439    ,   18605   ,   55645   ,0 };
            const std::uint32_t dim4076Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   23  ,   13  ,   87  ,   197 ,   507 ,   921 ,   1813    ,   579 ,   3585    ,   5117    ,   30913   ,   5739    ,0 };
            const std::uint32_t dim4077Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   21  ,   7   ,   3   ,   103 ,   475 ,   929 ,   1189    ,   1005    ,   2933    ,   1377    ,   30183   ,   58513   ,0 };
            const std::uint32_t dim4078Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   27  ,   51  ,   25  ,   139 ,   431 ,   275 ,   1541    ,   1459    ,   5787    ,   9865    ,   15077   ,   25965   ,0 };
            const std::uint32_t dim4079Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   19  ,   33  ,   85  ,   5   ,   119 ,   523 ,   11  ,   1459    ,   3807    ,   3959    ,   31321   ,   1905    ,0 };
            const std::uint32_t dim4080Kuo3Init[]   =   {   1   ,   3   ,   1   ,   15  ,   9   ,   25  ,   107 ,   51  ,   149 ,   437 ,   995 ,   397 ,   753 ,   12421   ,   30637   ,   22865   ,0 };
            const std::uint32_t dim4081Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   25  ,   13  ,   11  ,   129 ,   371 ,   497 ,   597 ,   1257    ,   7291    ,   4021    ,   16223   ,   21489   ,0 };
            const std::uint32_t dim4082Kuo3Init[]   =   {   1   ,   3   ,   5   ,   1   ,   5   ,   17  ,   119 ,   107 ,   267 ,   27  ,   87  ,   3641    ,   593 ,   4671    ,   16129   ,   25645   ,0 };
            const std::uint32_t dim4083Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   19  ,   55  ,   39  ,   159 ,   283 ,   551 ,   321 ,   1979    ,   1259    ,   10049   ,   15195   ,   62799   ,0 };
            const std::uint32_t dim4084Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   23  ,   43  ,   63  ,   187 ,   399 ,   725 ,   419 ,   1759    ,   5477    ,   4743    ,   13397   ,   21347   ,0 };
            const std::uint32_t dim4085Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   3   ,   45  ,   55  ,   207 ,   33  ,   695 ,   1109    ,   1427    ,   5425    ,   4743    ,   28949   ,   54665   ,0 };
            const std::uint32_t dim4086Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   19  ,   1   ,   97  ,   151 ,   465 ,   767 ,   1931    ,   1097    ,   7001    ,   5761    ,   30323   ,   17501   ,0 };
            const std::uint32_t dim4087Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   9   ,   11  ,   9   ,   165 ,   181 ,   711 ,   45  ,   1163    ,   11  ,   9127    ,   31361   ,   11259   ,0 };
            const std::uint32_t dim4088Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   23  ,   23  ,   7   ,   115 ,   243 ,   281 ,   847 ,   3091    ,   6383    ,   4593    ,   13507   ,   58001   ,0 };
            const std::uint32_t dim4089Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   27  ,   3   ,   123 ,   91  ,   47  ,   483 ,   1913    ,   2139    ,   3877    ,   16373   ,   31969   ,   42977   ,0 };
            const std::uint32_t dim4090Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   11  ,   9   ,   35  ,   3   ,   155 ,   585 ,   1193    ,   1887    ,   1657    ,   2479    ,   18803   ,   47309   ,0 };
            const std::uint32_t dim4091Kuo3Init[]   =   {   1   ,   3   ,   3   ,   5   ,   5   ,   57  ,   79  ,   77  ,   205 ,   361 ,   505 ,   2505    ,   2959    ,   1345    ,   8165    ,   46001   ,0 };
            const std::uint32_t dim4092Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   29  ,   25  ,   35  ,   209 ,   193 ,   177 ,   291 ,   1095    ,   7137    ,   4323    ,   673 ,   37571   ,0 };
            const std::uint32_t dim4093Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   27  ,   29  ,   107 ,   161 ,   93  ,   585 ,   1061    ,   3281    ,   5565    ,   5093    ,   4511    ,   45327   ,0 };
            const std::uint32_t dim4094Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   15  ,   43  ,   41  ,   61  ,   425 ,   451 ,   1775    ,   345 ,   7851    ,   12907   ,   9467    ,   25705   ,0 };
            const std::uint32_t dim4095Kuo3Init[]   =   {   1   ,   1   ,   1   ,   15  ,   31  ,   37  ,   105 ,   227 ,   155 ,   201 ,   653 ,   2343    ,   4601    ,   1331    ,   9193    ,   28423   ,0 };
            const std::uint32_t dim4096Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   31  ,   61  ,   19  ,   165 ,   491 ,   121 ,   159 ,   485 ,   7847    ,   4993    ,   30405   ,   22889   ,0 };
            const std::uint32_t dim4097Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   27  ,   35  ,   81  ,   231 ,   345 ,   519 ,   849 ,   539 ,   627 ,   16141   ,   26509   ,   8965    ,0 };
            const std::uint32_t dim4098Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   7   ,   33  ,   81  ,   51  ,   415 ,   785 ,   1617    ,   669 ,   4749    ,   737 ,   15557   ,   61779   ,0 };
            const std::uint32_t dim4099Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   5   ,   39  ,   47  ,   199 ,   313 ,   193 ,   1797    ,   2425    ,   327 ,   5111    ,   275 ,   45933   ,0 };
            const std::uint32_t dim4100Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   1   ,   27  ,   61  ,   1   ,   435 ,   1005    ,   665 ,   3099    ,   1153    ,   12721   ,   25537   ,   62559   ,0 };
            const std::uint32_t dim4101Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   29  ,   43  ,   97  ,   213 ,   43  ,   333 ,   25  ,   3085    ,   2709    ,   5917    ,   5887    ,   3847    ,0 };
            const std::uint32_t dim4102Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   17  ,   27  ,   93  ,   45  ,   205 ,   29  ,   2035    ,   4053    ,   6525    ,   12321   ,   26175   ,   43979   ,0 };
            const std::uint32_t dim4103Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   9   ,   41  ,   23  ,   215 ,   163 ,   531 ,   1753    ,   2377    ,   5533    ,   8681    ,   12213   ,   36789   ,0 };
            const std::uint32_t dim4104Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   7   ,   13  ,   25  ,   111 ,   439 ,   695 ,   1855    ,   2437    ,   4477    ,   10207   ,   4089    ,   43521   ,0 };
            const std::uint32_t dim4105Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   23  ,   7   ,   85  ,   123 ,   361 ,   913 ,   1817    ,   1547    ,   7969    ,   9731    ,   10553   ,   53879   ,0 };
            const std::uint32_t dim4106Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   29  ,   25  ,   5   ,   129 ,   211 ,   511 ,   45  ,   907 ,   1997    ,   15657   ,   9003    ,   47267   ,0 };
            const std::uint32_t dim4107Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   15  ,   49  ,   13  ,   131 ,   43  ,   295 ,   1569    ,   2675    ,   7857    ,   15515   ,   9189    ,   33061   ,0 };
            const std::uint32_t dim4108Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   29  ,   3   ,   85  ,   125 ,   403 ,   583 ,   1507    ,   73  ,   4701    ,   1117    ,   12271   ,   11387   ,0 };
            const std::uint32_t dim4109Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   3   ,   15  ,   1   ,   63  ,   319 ,   43  ,   913 ,   3029    ,   557 ,   3087    ,   18605   ,   39477   ,0 };
            const std::uint32_t dim4110Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   31  ,   51  ,   99  ,   103 ,   343 ,   835 ,   313 ,   2025    ,   7109    ,   5373    ,   20821   ,   55649   ,0 };
            const std::uint32_t dim4111Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   7   ,   21  ,   53  ,   123 ,   189 ,   1013    ,   427 ,   2773    ,   6567    ,   5241    ,   29647   ,   41591   ,0 };
            const std::uint32_t dim4112Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   29  ,   53  ,   127 ,   159 ,   327 ,   999 ,   1357    ,   989 ,   4401    ,   10949   ,   32555   ,   5097    ,0 };
            const std::uint32_t dim4113Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   31  ,   11  ,   75  ,   47  ,   307 ,   251 ,   1845    ,   1543    ,   6901    ,   3959    ,   18371   ,   40149   ,0 };
            const std::uint32_t dim4114Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   31  ,   47  ,   81  ,   17  ,   17  ,   21  ,   807 ,   3115    ,   5447    ,   11191   ,   2357    ,   2263    ,0 };
            const std::uint32_t dim4115Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   25  ,   41  ,   93  ,   135 ,   251 ,   165 ,   805 ,   1805    ,   2895    ,   11725   ,   6389    ,   21875   ,0 };
            const std::uint32_t dim4116Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   19  ,   37  ,   19  ,   247 ,   25  ,   241 ,   767 ,   2883    ,   5951    ,   531 ,   22893   ,   47493   ,0 };
            const std::uint32_t dim4117Kuo3Init[]   =   {   1   ,   3   ,   1   ,   11  ,   31  ,   49  ,   23  ,   199 ,   337 ,   311 ,   1929    ,   2703    ,   4339    ,   6477    ,   1821    ,   4729    ,0 };
            const std::uint32_t dim4118Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   7   ,   59  ,   119 ,   3   ,   289 ,   951 ,   1387    ,   2999    ,   6617    ,   14551   ,   22081   ,   14187   ,0 };
            const std::uint32_t dim4119Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   13  ,   33  ,   37  ,   97  ,   501 ,   247 ,   651 ,   209 ,   7517    ,   2847    ,   3549    ,   16479   ,0 };
            const std::uint32_t dim4120Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   25  ,   45  ,   83  ,   207 ,   115 ,   1023    ,   543 ,   2851    ,   3383    ,   4177    ,   25567   ,   2797    ,0 };
            const std::uint32_t dim4121Kuo3Init[]   =   {   1   ,   3   ,   3   ,   5   ,   7   ,   9   ,   127 ,   243 ,   501 ,   653 ,   1071    ,   2547    ,   6995    ,   10811   ,   4791    ,   50157   ,0 };
            const std::uint32_t dim4122Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   27  ,   61  ,   65  ,   117 ,   373 ,   191 ,   1643    ,   1057    ,   6013    ,   15167   ,   18815   ,   4225    ,0 };
            const std::uint32_t dim4123Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   9   ,   25  ,   105 ,   225 ,   247 ,   609 ,   325 ,   2761    ,   515 ,   9985    ,   6977    ,   57207   ,0 };
            const std::uint32_t dim4124Kuo3Init[]   =   {   1   ,   1   ,   7   ,   15  ,   5   ,   43  ,   33  ,   45  ,   301 ,   1017    ,   1881    ,   83  ,   95  ,   10417   ,   2307    ,   6915    ,0 };
            const std::uint32_t dim4125Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   25  ,   43  ,   27  ,   81  ,   249 ,   239 ,   1671    ,   1215    ,   3139    ,   7961    ,   28509   ,   27099   ,0 };
            const std::uint32_t dim4126Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   17  ,   29  ,   49  ,   81  ,   503 ,   429 ,   2037    ,   2243    ,   7509    ,   12359   ,   14681   ,   21661   ,0 };
            const std::uint32_t dim4127Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   3   ,   63  ,   71  ,   71  ,   375 ,   999 ,   11  ,   2475    ,   4491    ,   7439    ,   5915    ,   63169   ,0 };
            const std::uint32_t dim4128Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   31  ,   35  ,   91  ,   27  ,   151 ,   893 ,   525 ,   1913    ,   2795    ,   10377   ,   1173    ,   44175   ,0 };
            const std::uint32_t dim4129Kuo3Init[]   =   {   1   ,   1   ,   7   ,   15  ,   23  ,   11  ,   69  ,   77  ,   133 ,   307 ,   1589    ,   2795    ,   1183    ,   1491    ,   4661    ,   51315   ,0 };
            const std::uint32_t dim4130Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   27  ,   37  ,   9   ,   67  ,   481 ,   113 ,   7   ,   1679    ,   217 ,   6195    ,   18147   ,   50839   ,0 };
            const std::uint32_t dim4131Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   3   ,   37  ,   53  ,   127 ,   19  ,   177 ,   1851    ,   921 ,   1009    ,   9577    ,   24637   ,   2491    ,0 };
            const std::uint32_t dim4132Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   19  ,   33  ,   65  ,   25  ,   333 ,   749 ,   1577    ,   143 ,   6731    ,   2411    ,   25579   ,   57987   ,0 };
            const std::uint32_t dim4133Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   29  ,   45  ,   89  ,   179 ,   147 ,   411 ,   1831    ,   2209    ,   499 ,   3141    ,   17357   ,   23229   ,0 };
            const std::uint32_t dim4134Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   25  ,   41  ,   105 ,   165 ,   369 ,   241 ,   299 ,   875 ,   1231    ,   469 ,   4203    ,   27117   ,0 };
            const std::uint32_t dim4135Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   29  ,   35  ,   95  ,   235 ,   229 ,   797 ,   411 ,   71  ,   4571    ,   2341    ,   4095    ,   28185   ,0 };
            const std::uint32_t dim4136Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   21  ,   33  ,   23  ,   59  ,   195 ,   539 ,   1131    ,   3799    ,   8093    ,   8247    ,   6283    ,   44143   ,0 };
            const std::uint32_t dim4137Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   11  ,   15  ,   45  ,   99  ,   73  ,   983 ,   1047    ,   361 ,   2925    ,   1985    ,   20379   ,   63235   ,0 };
            const std::uint32_t dim4138Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   25  ,   7   ,   29  ,   129 ,   257 ,   1015    ,   1823    ,   23  ,   5031    ,   12153   ,   13511   ,   57897   ,0 };
            const std::uint32_t dim4139Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   15  ,   39  ,   57  ,   173 ,   391 ,   979 ,   569 ,   2051    ,   3221    ,   9561    ,   24331   ,   39791   ,0 };
            const std::uint32_t dim4140Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   1   ,   51  ,   25  ,   79  ,   373 ,   639 ,   5   ,   3237    ,   2983    ,   12491   ,   15991   ,   12467   ,0 };
            const std::uint32_t dim4141Kuo3Init[]   =   {   1   ,   1   ,   7   ,   15  ,   17  ,   21  ,   103 ,   55  ,   233 ,   605 ,   597 ,   1867    ,   2147    ,   11047   ,   1173    ,   27237   ,0 };
            const std::uint32_t dim4142Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   11  ,   25  ,   43  ,   63  ,   143 ,   829 ,   1357    ,   2199    ,   5219    ,   15981   ,   15615   ,   22207   ,0 };
            const std::uint32_t dim4143Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   17  ,   53  ,   121 ,   131 ,   501 ,   355 ,   533 ,   2343    ,   6515    ,   9115    ,   29065   ,   64569   ,0 };
            const std::uint32_t dim4144Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   27  ,   57  ,   5   ,   105 ,   327 ,   861 ,   931 ,   3085    ,   5051    ,   12687   ,   22409   ,   57487   ,0 };
            const std::uint32_t dim4145Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   1   ,   53  ,   65  ,   97  ,   315 ,   413 ,   37  ,   2563    ,   4805    ,   2327    ,   10261   ,   7281    ,0 };
            const std::uint32_t dim4146Kuo3Init[]   =   {   1   ,   3   ,   5   ,   9   ,   19  ,   57  ,   15  ,   75  ,   161 ,   245 ,   1215    ,   1735    ,   4567    ,   109 ,   8467    ,   43139   ,0 };
            const std::uint32_t dim4147Kuo3Init[]   =   {   1   ,   3   ,   1   ,   11  ,   21  ,   55  ,   95  ,   11  ,   193 ,   959 ,   793 ,   3321    ,   5865    ,   301 ,   7887    ,   7389    ,0 };
            const std::uint32_t dim4148Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   31  ,   35  ,   27  ,   89  ,   247 ,   491 ,   1087    ,   3955    ,   6317    ,   1337    ,   21619   ,   11739   ,0 };
            const std::uint32_t dim4149Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   21  ,   59  ,   53  ,   211 ,   403 ,   851 ,   887 ,   1457    ,   539 ,   4493    ,   16571   ,   55429   ,0 };
            const std::uint32_t dim4150Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   23  ,   33  ,   69  ,   129 ,   33  ,   203 ,   267 ,   3261    ,   4179    ,   9653    ,   22523   ,   18779   ,0 };
            const std::uint32_t dim4151Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   31  ,   35  ,   7   ,   189 ,   253 ,   583 ,   1475    ,   939 ,   2977    ,   5573    ,   20047   ,   38915   ,0 };
            const std::uint32_t dim4152Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   19  ,   25  ,   61  ,   237 ,   479 ,   821 ,   1173    ,   599 ,   7035    ,   12695   ,   433 ,   26499   ,0 };
            const std::uint32_t dim4153Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   27  ,   47  ,   29  ,   31  ,   327 ,   687 ,   495 ,   987 ,   1655    ,   951 ,   29265   ,   28641   ,0 };
            const std::uint32_t dim4154Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   25  ,   29  ,   15  ,   139 ,   417 ,   837 ,   2011    ,   3703    ,   7809    ,   421 ,   207 ,   18961   ,0 };
            const std::uint32_t dim4155Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   7   ,   29  ,   19  ,   63  ,   257 ,   695 ,   161 ,   3023    ,   149 ,   10707   ,   20873   ,   61881   ,0 };
            const std::uint32_t dim4156Kuo3Init[]   =   {   1   ,   3   ,   3   ,   7   ,   5   ,   9   ,   69  ,   31  ,   487 ,   525 ,   1441    ,   5   ,   3891    ,   14473   ,   22123   ,   40041   ,0 };
            const std::uint32_t dim4157Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   13  ,   37  ,   75  ,   181 ,   431 ,   753 ,   1587    ,   595 ,   2567    ,   8155    ,   23199   ,   50647   ,0 };
            const std::uint32_t dim4158Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   21  ,   63  ,   39  ,   245 ,   171 ,   217 ,   1643    ,   887 ,   2349    ,   2415    ,   31673   ,   51007   ,0 };
            const std::uint32_t dim4159Kuo3Init[]   =   {   1   ,   3   ,   5   ,   9   ,   19  ,   33  ,   107 ,   227 ,   187 ,   163 ,   1071    ,   2385    ,   2701    ,   15969   ,   18665   ,   62089   ,0 };
            const std::uint32_t dim4160Kuo3Init[]   =   {   1   ,   1   ,   1   ,   15  ,   27  ,   47  ,   25  ,   219 ,   139 ,   879 ,   459 ,   1521    ,   2153    ,   3429    ,   28293   ,   57703   ,0 };
            const std::uint32_t dim4161Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   15  ,   63  ,   23  ,   237 ,   137 ,   271 ,   117 ,   3047    ,   3973    ,   3379    ,   11527   ,   52555   ,0 };
            const std::uint32_t dim4162Kuo3Init[]   =   {   1   ,   3   ,   7   ,   1   ,   19  ,   27  ,   19  ,   111 ,   441 ,   279 ,   321 ,   2015    ,   4451    ,   11841   ,   17223   ,   51691   ,0 };
            const std::uint32_t dim4163Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   15  ,   35  ,   19  ,   31  ,   277 ,   977 ,   1125    ,   2435    ,   5171    ,   81  ,   31729   ,   18883   ,0 };
            const std::uint32_t dim4164Kuo3Init[]   =   {   1   ,   3   ,   1   ,   15  ,   19  ,   31  ,   105 ,   13  ,   117 ,   533 ,   191 ,   3651    ,   6915    ,   2423    ,   31819   ,   47709   ,0 };
            const std::uint32_t dim4165Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   29  ,   45  ,   17  ,   51  ,   283 ,   297 ,   1605    ,   3009    ,   3137    ,   2665    ,   27799   ,   2293    ,0 };
            const std::uint32_t dim4166Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   29  ,   61  ,   91  ,   7   ,   23  ,   835 ,   1809    ,   3283    ,   1091    ,   10443   ,   26547   ,   10685   ,0 };
            const std::uint32_t dim4167Kuo3Init[]   =   {   1   ,   3   ,   5   ,   1   ,   1   ,   29  ,   121 ,   181 ,   43  ,   827 ,   871 ,   3547    ,   4285    ,   12551   ,   2079    ,   19385   ,0 };
            const std::uint32_t dim4168Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   3   ,   53  ,   73  ,   39  ,   1   ,   499 ,   1905    ,   3785    ,   1597    ,   1529    ,   9423    ,   11555   ,0 };
            const std::uint32_t dim4169Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   27  ,   25  ,   33  ,   59  ,   327 ,   419 ,   1527    ,   255 ,   6877    ,   3927    ,   11877   ,   21747   ,0 };
            const std::uint32_t dim4170Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   27  ,   37  ,   99  ,   161 ,   213 ,   321 ,   1127    ,   523 ,   5327    ,   7885    ,   17403   ,   2097    ,0 };
            const std::uint32_t dim4171Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   5   ,   11  ,   119 ,   153 ,   503 ,   1007    ,   187 ,   1705    ,   7499    ,   12739   ,   16185   ,   11121   ,0 };
            const std::uint32_t dim4172Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   27  ,   63  ,   29  ,   239 ,   5   ,   377 ,   831 ,   2883    ,   2167    ,   2551    ,   29891   ,   6165    ,0 };
            const std::uint32_t dim4173Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   5   ,   57  ,   33  ,   15  ,   425 ,   93  ,   1435    ,   1449    ,   1629    ,   999 ,   27037   ,   51171   ,0 };
            const std::uint32_t dim4174Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   1   ,   31  ,   83  ,   19  ,   373 ,   497 ,   1173    ,   775 ,   439 ,   5757    ,   32143   ,   52487   ,0 };
            const std::uint32_t dim4175Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   15  ,   43  ,   73  ,   19  ,   259 ,   145 ,   1771    ,   2133    ,   6969    ,   8571    ,   29821   ,   19581   ,0 };
            const std::uint32_t dim4176Kuo3Init[]   =   {   1   ,   3   ,   3   ,   5   ,   25  ,   63  ,   43  ,   95  ,   215 ,   853 ,   127 ,   3737    ,   4803    ,   10089   ,   3537    ,   14671   ,0 };
            const std::uint32_t dim4177Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   31  ,   17  ,   1   ,   139 ,   199 ,   841 ,   1859    ,   1767    ,   1545    ,   4869    ,   14501   ,   11729   ,0 };
            const std::uint32_t dim4178Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   29  ,   57  ,   43  ,   143 ,   55  ,   893 ,   1219    ,   2415    ,   7605    ,   11091   ,   3441    ,   45749   ,0 };
            const std::uint32_t dim4179Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   27  ,   11  ,   27  ,   15  ,   67  ,   49  ,   967 ,   1919    ,   1773    ,   9135    ,   4607    ,   65495   ,0 };
            const std::uint32_t dim4180Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   7   ,   11  ,   63  ,   39  ,   209 ,   41  ,   951 ,   63  ,   1537    ,   9971    ,   9659    ,   17825   ,0 };
            const std::uint32_t dim4181Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   27  ,   25  ,   57  ,   53  ,   91  ,   1013    ,   591 ,   261 ,   721 ,   2061    ,   629 ,   37817   ,0 };
            const std::uint32_t dim4182Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   23  ,   35  ,   71  ,   43  ,   343 ,   329 ,   295 ,   3523    ,   275 ,   2119    ,   15165   ,   2809    ,0 };
            const std::uint32_t dim4183Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   19  ,   3   ,   121 ,   67  ,   165 ,   909 ,   1731    ,   437 ,   8055    ,   11683   ,   12735   ,   29129   ,0 };
            const std::uint32_t dim4184Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   21  ,   47  ,   113 ,   55  ,   169 ,   133 ,   2029    ,   825 ,   4079    ,   14651   ,   22373   ,   15009   ,0 };
            const std::uint32_t dim4185Kuo3Init[]   =   {   1   ,   1   ,   5   ,   7   ,   25  ,   23  ,   61  ,   147 ,   211 ,   665 ,   395 ,   505 ,   3757    ,   14545   ,   10683   ,   53211   ,0 };
            const std::uint32_t dim4186Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   17  ,   25  ,   111 ,   171 ,   493 ,   815 ,   847 ,   2109    ,   8013    ,   751 ,   26793   ,   62903   ,0 };
            const std::uint32_t dim4187Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   7   ,   27  ,   91  ,   61  ,   385 ,   3   ,   577 ,   3515    ,   4335    ,   4261    ,   6053    ,   62513   ,0 };
            const std::uint32_t dim4188Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   17  ,   5   ,   21  ,   217 ,   227 ,   443 ,   1479    ,   2855    ,   2581    ,   6255    ,   23363   ,   37437   ,0 };
            const std::uint32_t dim4189Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   5   ,   51  ,   5   ,   213 ,   233 ,   787 ,   719 ,   463 ,   2595    ,   4019    ,   16839   ,   14671   ,0 };
            const std::uint32_t dim4190Kuo3Init[]   =   {   1   ,   1   ,   1   ,   15  ,   11  ,   5   ,   49  ,   135 ,   85  ,   773 ,   1719    ,   2187    ,   449 ,   14913   ,   19721   ,   59583   ,0 };
            const std::uint32_t dim4191Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   3   ,   49  ,   77  ,   217 ,   289 ,   889 ,   63  ,   2547    ,   5547    ,   14005   ,   18657   ,   65109   ,0 };
            const std::uint32_t dim4192Kuo3Init[]   =   {   1   ,   3   ,   5   ,   9   ,   11  ,   47  ,   19  ,   251 ,   77  ,   623 ,   1253    ,   635 ,   1047    ,   525 ,   8573    ,   25951   ,0 };
            const std::uint32_t dim4193Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   5   ,   21  ,   35  ,   187 ,   395 ,   547 ,   2003    ,   3189    ,   4107    ,   567 ,   29239   ,   32647   ,0 };
            const std::uint32_t dim4194Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   13  ,   61  ,   59  ,   57  ,   91  ,   881 ,   1665    ,   453 ,   6313    ,   2291    ,   19523   ,   60439   ,0 };
            const std::uint32_t dim4195Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   7   ,   7   ,   7   ,   127 ,   411 ,   643 ,   1415    ,   2933    ,   6649    ,   4219    ,   31781   ,   8733    ,0 };
            const std::uint32_t dim4196Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   25  ,   29  ,   127 ,   235 ,   271 ,   831 ,   1909    ,   2347    ,   7085    ,   8339    ,   22459   ,   48791   ,0 };
            const std::uint32_t dim4197Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   21  ,   19  ,   31  ,   5   ,   509 ,   713 ,   767 ,   1801    ,   6937    ,   1763    ,   20703   ,   10153   ,0 };
            const std::uint32_t dim4198Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   9   ,   35  ,   55  ,   215 ,   75  ,   733 ,   1773    ,   1373    ,   43  ,   5045    ,   17675   ,   29615   ,0 };
            const std::uint32_t dim4199Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   25  ,   27  ,   33  ,   167 ,   277 ,   231 ,   449 ,   1055    ,   6227    ,   1441    ,   29535   ,   30421   ,0 };
            const std::uint32_t dim4200Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   31  ,   63  ,   69  ,   137 ,   41  ,   67  ,   965 ,   3737    ,   3191    ,   2613    ,   8229    ,   47453   ,0 };
            const std::uint32_t dim4201Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   9   ,   13  ,   97  ,   31  ,   279 ,   525 ,   185 ,   1673    ,   1269    ,   8305    ,   29745   ,   5799    ,0 };
            const std::uint32_t dim4202Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   27  ,   47  ,   97  ,   185 ,   483 ,   787 ,   1049    ,   4073    ,   1985    ,   2129    ,   15099   ,   33307   ,0 };
            const std::uint32_t dim4203Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   21  ,   25  ,   97  ,   49  ,   377 ,   75  ,   1875    ,   2389    ,   1381    ,   6691    ,   30447   ,   23969   ,0 };
            const std::uint32_t dim4204Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   3   ,   55  ,   111 ,   185 ,   371 ,   331 ,   1471    ,   1211    ,   1523    ,   5393    ,   21763   ,   44333   ,0 };
            const std::uint32_t dim4205Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   19  ,   39  ,   35  ,   49  ,   433 ,   937 ,   869 ,   239 ,   7775    ,   9591    ,   16969   ,   43455   ,0 };
            const std::uint32_t dim4206Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   21  ,   11  ,   11  ,   201 ,   187 ,   409 ,   1603    ,   3471    ,   1473    ,   5283    ,   7109    ,   53219   ,0 };
            const std::uint32_t dim4207Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   13  ,   55  ,   91  ,   37  ,   71  ,   837 ,   1779    ,   1097    ,   7433    ,   5969    ,   22781   ,   28547   ,0 };
            const std::uint32_t dim4208Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   9   ,   41  ,   29  ,   125 ,   151 ,   51  ,   667 ,   1387    ,   6695    ,   7957    ,   20469   ,   20987   ,0 };
            const std::uint32_t dim4209Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   23  ,   17  ,   91  ,   79  ,   249 ,   123 ,   1141    ,   2201    ,   7139    ,   5749    ,   20655   ,   18111   ,0 };
            const std::uint32_t dim4210Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   1   ,   35  ,   5   ,   219 ,   255 ,   549 ,   1159    ,   1641    ,   5063    ,   457 ,   24023   ,   61667   ,0 };
            const std::uint32_t dim4211Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   23  ,   45  ,   85  ,   81  ,   41  ,   327 ,   1923    ,   2043    ,   6737    ,   13609   ,   1833    ,   30563   ,0 };
            const std::uint32_t dim4212Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   9   ,   15  ,   81  ,   137 ,   353 ,   509 ,   799 ,   787 ,   5371    ,   4863    ,   29781   ,   40405   ,0 };
            const std::uint32_t dim4213Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   31  ,   17  ,   109 ,   123 ,   455 ,   155 ,   253 ,   1541    ,   2265    ,   16015   ,   32309   ,   40837   ,0 };
            const std::uint32_t dim4214Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   21  ,   59  ,   109 ,   3   ,   367 ,   411 ,   1601    ,   3577    ,   3155    ,   1659    ,   15193   ,   32453   ,0 };
            const std::uint32_t dim4215Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   3   ,   21  ,   123 ,   125 ,   163 ,   233 ,   125 ,   947 ,   1023    ,   7435    ,   30777   ,   14615   ,0 };
            const std::uint32_t dim4216Kuo3Init[]   =   {   1   ,   3   ,   5   ,   9   ,   15  ,   29  ,   31  ,   101 ,   427 ,   379 ,   379 ,   1123    ,   1411    ,   10523   ,   24017   ,   43629   ,0 };
            const std::uint32_t dim4217Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   1   ,   27  ,   43  ,   239 ,   91  ,   967 ,   991 ,   2827    ,   6135    ,   1035    ,   25925   ,   42605   ,0 };
            const std::uint32_t dim4218Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   11  ,   53  ,   83  ,   127 ,   51  ,   1021    ,   2017    ,   593 ,   1445    ,   14597   ,   6517    ,   19667   ,0 };
            const std::uint32_t dim4219Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   9   ,   1   ,   17  ,   235 ,   321 ,   571 ,   1315    ,   3993    ,   5825    ,   8065    ,   13885   ,   48815   ,0 };
            const std::uint32_t dim4220Kuo3Init[]   =   {   1   ,   1   ,   1   ,   15  ,   3   ,   7   ,   5   ,   197 ,   89  ,   23  ,   711 ,   1601    ,   3577    ,   737 ,   27565   ,   43365   ,0 };
            const std::uint32_t dim4221Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   19  ,   35  ,   15  ,   99  ,   177 ,   1013    ,   905 ,   755 ,   667 ,   21  ,   27039   ,   56601   ,0 };
            const std::uint32_t dim4222Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   13  ,   37  ,   37  ,   73  ,   75  ,   827 ,   169 ,   2417    ,   5457    ,   13851   ,   5443    ,   15731   ,0 };
            const std::uint32_t dim4223Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   11  ,   23  ,   21  ,   159 ,   59  ,   633 ,   1719    ,   203 ,   5655    ,   15887   ,   9067    ,   33597   ,0 };
            const std::uint32_t dim4224Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   27  ,   11  ,   55  ,   139 ,   309 ,   721 ,   99  ,   3371    ,   1411    ,   4531    ,   12751   ,   37745   ,0 };
            const std::uint32_t dim4225Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   31  ,   33  ,   37  ,   43  ,   125 ,   11  ,   1441    ,   3947    ,   7455    ,   6097    ,   15333   ,   32601   ,0 };
            const std::uint32_t dim4226Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   9   ,   43  ,   79  ,   217 ,   247 ,   229 ,   171 ,   3607    ,   4155    ,   1675    ,   3945    ,   41499   ,0 };
            const std::uint32_t dim4227Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   5   ,   59  ,   25  ,   175 ,   209 ,   291 ,   1419    ,   2339    ,   7039    ,   1327    ,   19653   ,   11563   ,0 };
            const std::uint32_t dim4228Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   5   ,   1   ,   103 ,   197 ,   111 ,   891 ,   163 ,   361 ,   2885    ,   3443    ,   25481   ,   47399   ,0 };
            const std::uint32_t dim4229Kuo3Init[]   =   {   1   ,   3   ,   7   ,   1   ,   21  ,   49  ,   35  ,   179 ,   339 ,   505 ,   1121    ,   2393    ,   1181    ,   11389   ,   5851    ,   30553   ,0 };
            const std::uint32_t dim4230Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   31  ,   3   ,   23  ,   205 ,   3   ,   861 ,   1767    ,   1971    ,   2279    ,   4901    ,   22077   ,   54183   ,0 };
            const std::uint32_t dim4231Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   11  ,   1   ,   3   ,   165 ,   129 ,   767 ,   2007    ,   1913    ,   3701    ,   5761    ,   1985    ,   42383   ,0 };
            const std::uint32_t dim4232Kuo3Init[]   =   {   1   ,   3   ,   3   ,   5   ,   3   ,   39  ,   31  ,   73  ,   55  ,   805 ,   545 ,   1577    ,   1409    ,   5693    ,   31995   ,   58057   ,0 };
            const std::uint32_t dim4233Kuo3Init[]   =   {   1   ,   3   ,   1   ,   15  ,   21  ,   9   ,   69  ,   17  ,   497 ,   1003    ,   1123    ,   4023    ,   1921    ,   723 ,   19815   ,   11583   ,0 };
            const std::uint32_t dim4234Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   13  ,   31  ,   61  ,   189 ,   1   ,   805 ,   1321    ,   1973    ,   4133    ,   7789    ,   9735    ,   50237   ,0 };
            const std::uint32_t dim4235Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   1   ,   39  ,   67  ,   189 ,   139 ,   891 ,   171 ,   693 ,   5639    ,   12841   ,   12223   ,   64009   ,0 };
            const std::uint32_t dim4236Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   7   ,   1   ,   115 ,   41  ,   283 ,   463 ,   53  ,   1349    ,   3233    ,   7247    ,   28515   ,   23931   ,0 };
            const std::uint32_t dim4237Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   25  ,   31  ,   49  ,   177 ,   339 ,   103 ,   701 ,   3059    ,   6557    ,   8669    ,   13923   ,   46913   ,0 };
            const std::uint32_t dim4238Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   7   ,   47  ,   7   ,   153 ,   481 ,   1005    ,   615 ,   2483    ,   3519    ,   5297    ,   21749   ,   55945   ,0 };
            const std::uint32_t dim4239Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   15  ,   43  ,   105 ,   121 ,   419 ,   181 ,   1945    ,   3501    ,   3443    ,   5555    ,   27925   ,   18357   ,0 };
            const std::uint32_t dim4240Kuo3Init[]   =   {   1   ,   3   ,   3   ,   5   ,   5   ,   63  ,   107 ,   225 ,   17  ,   503 ,   2033    ,   2059    ,   2621    ,   12675   ,   25015   ,   15115   ,0 };
            const std::uint32_t dim4241Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   5   ,   33  ,   39  ,   143 ,   293 ,   793 ,   159 ,   1349    ,   5483    ,   9303    ,   8269    ,   58221   ,0 };
            const std::uint32_t dim4242Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   13  ,   21  ,   15  ,   11  ,   489 ,   921 ,   47  ,   7   ,   7677    ,   3281    ,   1339    ,   1447    ,0 };
            const std::uint32_t dim4243Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   19  ,   61  ,   29  ,   45  ,   355 ,   671 ,   1029    ,   455 ,   5611    ,   14655   ,   22871   ,   17303   ,0 };
            const std::uint32_t dim4244Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   3   ,   29  ,   93  ,   83  ,   425 ,   689 ,   437 ,   1943    ,   457 ,   2497    ,   2573    ,   56827   ,0 };
            const std::uint32_t dim4245Kuo3Init[]   =   {   1   ,   3   ,   7   ,   1   ,   3   ,   39  ,   17  ,   243 ,   475 ,   13  ,   199 ,   413 ,   5503    ,   1559    ,   8615    ,   5339    ,0 };
            const std::uint32_t dim4246Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   7   ,   17  ,   55  ,   243 ,   465 ,   957 ,   1347    ,   3247    ,   4613    ,   10821   ,   17377   ,   21765   ,0 };
            const std::uint32_t dim4247Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   15  ,   49  ,   109 ,   113 ,   19  ,   1007    ,   967 ,   685 ,   3195    ,   467 ,   1269    ,   27705   ,0 };
            const std::uint32_t dim4248Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   31  ,   25  ,   73  ,   73  ,   483 ,   565 ,   1739    ,   641 ,   4085    ,   10481   ,   30053   ,   52773   ,0 };
            const std::uint32_t dim4249Kuo3Init[]   =   {   1   ,   1   ,   1   ,   1   ,   31  ,   17  ,   35  ,   85  ,   339 ,   93  ,   479 ,   2833    ,   681 ,   3123    ,   3753    ,   63989   ,0 };
            const std::uint32_t dim4250Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   25  ,   17  ,   23  ,   47  ,   83  ,   59  ,   1525    ,   2445    ,   4831    ,   2605    ,   20711   ,   34129   ,0 };
            const std::uint32_t dim4251Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   11  ,   29  ,   111 ,   239 ,   81  ,   855 ,   2039    ,   4051    ,   4619    ,   14095   ,   15765   ,   17195   ,0 };
            const std::uint32_t dim4252Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   17  ,   29  ,   105 ,   175 ,   497 ,   741 ,   1151    ,   767 ,   7211    ,   14699   ,   9351    ,   22163   ,0 };
            const std::uint32_t dim4253Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   23  ,   17  ,   23  ,   193 ,   25  ,   883 ,   347 ,   2429    ,   4023    ,   5477    ,   9365    ,   30625   ,0 };
            const std::uint32_t dim4254Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   31  ,   57  ,   115 ,   119 ,   413 ,   733 ,   1095    ,   3877    ,   4021    ,   8415    ,   16129   ,   49425   ,0 };
            const std::uint32_t dim4255Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   13  ,   39  ,   127 ,   97  ,   389 ,   993 ,   1941    ,   847 ,   5109    ,   8499    ,   18653   ,   20615   ,0 };
            const std::uint32_t dim4256Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   9   ,   33  ,   21  ,   11  ,   357 ,   653 ,   1423    ,   3525    ,   277 ,   13085   ,   2525    ,   16547   ,0 };
            const std::uint32_t dim4257Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   3   ,   63  ,   55  ,   137 ,   229 ,   359 ,   703 ,   2555    ,   3117    ,   9323    ,   3483    ,   52999   ,0 };
            const std::uint32_t dim4258Kuo3Init[]   =   {   1   ,   3   ,   7   ,   1   ,   23  ,   7   ,   67  ,   119 ,   239 ,   951 ,   495 ,   645 ,   3047    ,   12393   ,   14837   ,   33015   ,0 };
            const std::uint32_t dim4259Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   23  ,   33  ,   19  ,   75  ,   365 ,   419 ,   905 ,   3485    ,   1097    ,   10639   ,   8627    ,   57441   ,0 };
            const std::uint32_t dim4260Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   5   ,   37  ,   83  ,   163 ,   483 ,   403 ,   1467    ,   309 ,   5113    ,   3567    ,   28425   ,   63963   ,0 };
            const std::uint32_t dim4261Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   21  ,   63  ,   59  ,   103 ,   261 ,   355 ,   1779    ,   1589    ,   7447    ,   10909   ,   23197   ,   31539   ,0 };
            const std::uint32_t dim4262Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   9   ,   39  ,   121 ,   7   ,   383 ,   975 ,   179 ,   505 ,   1551    ,   15397   ,   28277   ,   53023   ,0 };
            const std::uint32_t dim4263Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   31  ,   15  ,   29  ,   81  ,   291 ,   843 ,   507 ,   1291    ,   4533    ,   5333    ,   18841   ,   58999   ,0 };
            const std::uint32_t dim4264Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   3   ,   15  ,   107 ,   93  ,   15  ,   349 ,   1359    ,   151 ,   4859    ,   10435   ,   3669    ,   31713   ,0 };
            const std::uint32_t dim4265Kuo3Init[]   =   {   1   ,   3   ,   5   ,   1   ,   21  ,   1   ,   45  ,   167 ,   25  ,   123 ,   905 ,   115 ,   2953    ,   15029   ,   31475   ,   37235   ,0 };
            const std::uint32_t dim4266Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   9   ,   35  ,   115 ,   49  ,   61  ,   29  ,   1529    ,   1311    ,   6293    ,   13505   ,   15033   ,   31879   ,0 };
            const std::uint32_t dim4267Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   1   ,   19  ,   21  ,   199 ,   489 ,   463 ,   1761    ,   2295    ,   2011    ,   14179   ,   22955   ,   22451   ,0 };
            const std::uint32_t dim4268Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   21  ,   59  ,   71  ,   27  ,   425 ,   459 ,   177 ,   2301    ,   4703    ,   5589    ,   12799   ,   44729   ,0 };
            const std::uint32_t dim4269Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   11  ,   43  ,   103 ,   207 ,   315 ,   805 ,   469 ,   4009    ,   4589    ,   9627    ,   13309   ,   929 ,0 };
            const std::uint32_t dim4270Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   3   ,   45  ,   49  ,   59  ,   25  ,   371 ,   859 ,   2687    ,   3767    ,   7395    ,   24579   ,   2657    ,0 };
            const std::uint32_t dim4271Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   13  ,   1   ,   39  ,   115 ,   497 ,   291 ,   1187    ,   3109    ,   6731    ,   7591    ,   2551    ,   49121   ,0 };
            const std::uint32_t dim4272Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   11  ,   37  ,   75  ,   39  ,   377 ,   67  ,   291 ,   1275    ,   7893    ,   16261   ,   27093   ,   30007   ,0 };
            const std::uint32_t dim4273Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   27  ,   31  ,   117 ,   145 ,   435 ,   739 ,   1855    ,   2703    ,   6125    ,   16333   ,   16209   ,   11649   ,0 };
            const std::uint32_t dim4274Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   5   ,   37  ,   3   ,   173 ,   461 ,   535 ,   295 ,   3097    ,   6275    ,   15703   ,   20079   ,   45413   ,0 };
            const std::uint32_t dim4275Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   9   ,   39  ,   39  ,   113 ,   113 ,   315 ,   697 ,   2433    ,   7637    ,   9895    ,   17979   ,   13837   ,0 };
            const std::uint32_t dim4276Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   7   ,   35  ,   113 ,   255 ,   309 ,   389 ,   757 ,   1649    ,   1871    ,   311 ,   3531    ,   15617   ,0 };
            const std::uint32_t dim4277Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   25  ,   7   ,   87  ,   99  ,   249 ,   687 ,   57  ,   2291    ,   3315    ,   14677   ,   15225   ,   16859   ,0 };
            const std::uint32_t dim4278Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   11  ,   23  ,   91  ,   25  ,   209 ,   227 ,   567 ,   183 ,   7419    ,   9873    ,   10653   ,   41705   ,0 };
            const std::uint32_t dim4279Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   19  ,   17  ,   47  ,   79  ,   187 ,   185 ,   187 ,   3959    ,   4221    ,   389 ,   1733    ,   62413   ,0 };
            const std::uint32_t dim4280Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   1   ,   27  ,   109 ,   59  ,   223 ,   451 ,   865 ,   3623    ,   2545    ,   6531    ,   14837   ,   40749   ,0 };
            const std::uint32_t dim4281Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   5   ,   9   ,   69  ,   201 ,   145 ,   445 ,   1787    ,   1995    ,   691 ,   11387   ,   21391   ,   19185   ,0 };
            const std::uint32_t dim4282Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   15  ,   31  ,   61  ,   121 ,   295 ,   93  ,   1157    ,   2821    ,   2907    ,   6995    ,   17563   ,   4613    ,0 };
            const std::uint32_t dim4283Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   3   ,   41  ,   43  ,   199 ,   319 ,   903 ,   1699    ,   3599    ,   6567    ,   12851   ,   21253   ,   49715   ,0 };
            const std::uint32_t dim4284Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   25  ,   59  ,   7   ,   107 ,   405 ,   365 ,   1159    ,   2357    ,   1645    ,   16353   ,   31521   ,   13587   ,0 };
            const std::uint32_t dim4285Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   29  ,   25  ,   109 ,   181 ,   475 ,   117 ,   809 ,   2741    ,   5113    ,   9973    ,   31763   ,   20201   ,0 };
            const std::uint32_t dim4286Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   29  ,   43  ,   51  ,   239 ,   359 ,   137 ,   419 ,   43  ,   4091    ,   11107   ,   2121    ,   5057    ,0 };
            const std::uint32_t dim4287Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   13  ,   17  ,   65  ,   151 ,   289 ,   37  ,   1321    ,   3853    ,   7513    ,   3161    ,   6517    ,   27777   ,0 };
            const std::uint32_t dim4288Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   13  ,   31  ,   125 ,   13  ,   507 ,   491 ,   669 ,   2913    ,   8067    ,   4257    ,   11413   ,   8003    ,0 };
            const std::uint32_t dim4289Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   23  ,   57  ,   125 ,   227 ,   341 ,   647 ,   907 ,   1503    ,   1541    ,   14311   ,   10591   ,   49967   ,0 };
            const std::uint32_t dim4290Kuo3Init[]   =   {   1   ,   3   ,   1   ,   15  ,   25  ,   29  ,   83  ,   39  ,   141 ,   545 ,   1213    ,   2001    ,   6627    ,   8701    ,   19205   ,   2859    ,0 };
            const std::uint32_t dim4291Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   11  ,   25  ,   93  ,   91  ,   471 ,   907 ,   793 ,   3045    ,   8137    ,   5095    ,   12445   ,   41967   ,0 };
            const std::uint32_t dim4292Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   25  ,   45  ,   13  ,   191 ,   373 ,   371 ,   1321    ,   3381    ,   3945    ,   9097    ,   7785    ,   44469   ,0 };
            const std::uint32_t dim4293Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   13  ,   19  ,   53  ,   189 ,   183 ,   115 ,   1957    ,   91  ,   113 ,   5839    ,   23783   ,   63959   ,0 };
            const std::uint32_t dim4294Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   3   ,   19  ,   71  ,   219 ,   393 ,   369 ,   107 ,   3729    ,   7457    ,   12379   ,   28647   ,   54159   ,0 };
            const std::uint32_t dim4295Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   5   ,   43  ,   15  ,   125 ,   297 ,   145 ,   1837    ,   2143    ,   305 ,   793 ,   14663   ,   313 ,0 };
            const std::uint32_t dim4296Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   17  ,   57  ,   67  ,   51  ,   211 ,   817 ,   2023    ,   1615    ,   4379    ,   12165   ,   30433   ,   44479   ,0 };
            const std::uint32_t dim4297Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   9   ,   49  ,   71  ,   231 ,   159 ,   179 ,   2027    ,   4043    ,   1053    ,   3679    ,   9035    ,   4173    ,0 };
            const std::uint32_t dim4298Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   17  ,   5   ,   33  ,   151 ,   223 ,   331 ,   1777    ,   2467    ,   7949    ,   2571    ,   9099    ,   58751   ,0 };
            const std::uint32_t dim4299Kuo3Init[]   =   {   1   ,   3   ,   1   ,   15  ,   5   ,   23  ,   85  ,   113 ,   369 ,   607 ,   505 ,   1791    ,   1597    ,   12933   ,   28853   ,   13207   ,0 };
            const std::uint32_t dim4300Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   11  ,   39  ,   107 ,   81  ,   345 ,   815 ,   2025    ,   803 ,   1779    ,   15499   ,   26197   ,   6045    ,0 };
            const std::uint32_t dim4301Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   1   ,   3   ,   41  ,   29  ,   213 ,   295 ,   1561    ,   2631    ,   6231    ,   3255    ,   11309   ,   22853   ,0 };
            const std::uint32_t dim4302Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   19  ,   21  ,   127 ,   57  ,   425 ,   551 ,   171 ,   903 ,   7747    ,   5251    ,   11457   ,   57735   ,0 };
            const std::uint32_t dim4303Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   29  ,   5   ,   33  ,   221 ,   91  ,   435 ,   1341    ,   1627    ,   4269    ,   8689    ,   19  ,   9609    ,0 };
            const std::uint32_t dim4304Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   11  ,   1   ,   101 ,   219 ,   45  ,   317 ,   793 ,   823 ,   2449    ,   7911    ,   3739    ,   2441    ,0 };
            const std::uint32_t dim4305Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   25  ,   51  ,   103 ,   179 ,   481 ,   999 ,   675 ,   1693    ,   193 ,   9987    ,   18519   ,   16777   ,0 };
            const std::uint32_t dim4306Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   15  ,   59  ,   83  ,   61  ,   329 ,   537 ,   1293    ,   459 ,   5059    ,   7943    ,   3569    ,   34727   ,0 };
            const std::uint32_t dim4307Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   29  ,   17  ,   41  ,   171 ,   303 ,   123 ,   1945    ,   1383    ,   5823    ,   1569    ,   10699   ,   14585   ,0 };
            const std::uint32_t dim4308Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   7   ,   11  ,   35  ,   193 ,   69  ,   487 ,   879 ,   693 ,   6367    ,   7381    ,   11463   ,   50741   ,0 };
            const std::uint32_t dim4309Kuo3Init[]   =   {   1   ,   3   ,   1   ,   11  ,   9   ,   17  ,   5   ,   155 ,   443 ,   543 ,   643 ,   1595    ,   319 ,   2877    ,   27849   ,   8365    ,0 };
            const std::uint32_t dim4310Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   3   ,   43  ,   111 ,   219 ,   35  ,   595 ,   541 ,   3299    ,   4117    ,   265 ,   2817    ,   60825   ,0 };
            const std::uint32_t dim4311Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   13  ,   15  ,   45  ,   211 ,   21  ,   1019    ,   1015    ,   1051    ,   2879    ,   15077   ,   19851   ,   6615    ,0 };
            const std::uint32_t dim4312Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   15  ,   59  ,   7   ,   201 ,   215 ,   217 ,   967 ,   2013    ,   907 ,   12073   ,   9105    ,   44873   ,0 };
            const std::uint32_t dim4313Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   1   ,   3   ,   117 ,   253 ,   493 ,   727 ,   1997    ,   3325    ,   2757    ,   11313   ,   7439    ,   18863   ,0 };
            const std::uint32_t dim4314Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   5   ,   23  ,   97  ,   169 ,   63  ,   243 ,   419 ,   3259    ,   2521    ,   13055   ,   3223    ,   36055   ,0 };
            const std::uint32_t dim4315Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   9   ,   9   ,   63  ,   69  ,   305 ,   391 ,   1901    ,   2785    ,   7877    ,   7219    ,   10727   ,   13115   ,0 };
            const std::uint32_t dim4316Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   1   ,   63  ,   83  ,   27  ,   417 ,   537 ,   1969    ,   3083    ,   4267    ,   11153   ,   11205   ,   61249   ,0 };
            const std::uint32_t dim4317Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   11  ,   47  ,   79  ,   201 ,   449 ,   569 ,   809 ,   1575    ,   271 ,   651 ,   5459    ,   24805   ,0 };
            const std::uint32_t dim4318Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   29  ,   25  ,   103 ,   95  ,   57  ,   209 ,   1175    ,   2579    ,   3735    ,   1969    ,   29903   ,   65397   ,0 };
            const std::uint32_t dim4319Kuo3Init[]   =   {   1   ,   3   ,   5   ,   1   ,   25  ,   41  ,   7   ,   239 ,   175 ,   395 ,   1261    ,   2567    ,   4875    ,   279 ,   25905   ,   43603   ,0 };
            const std::uint32_t dim4320Kuo3Init[]   =   {   1   ,   3   ,   7   ,   1   ,   27  ,   7   ,   89  ,   111 ,   467 ,   691 ,   39  ,   1213    ,   5377    ,   13247   ,   31513   ,   58015   ,0 };
            const std::uint32_t dim4321Kuo3Init[]   =   {   1   ,   1   ,   1   ,   15  ,   25  ,   1   ,   55  ,   131 ,   259 ,   923 ,   1623    ,   125 ,   2273    ,   4221    ,   21857   ,   49621   ,0 };
            const std::uint32_t dim4322Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   27  ,   1   ,   99  ,   95  ,   199 ,   773 ,   87  ,   2981    ,   8127    ,   6493    ,   27507   ,   52789   ,0 };
            const std::uint32_t dim4323Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   11  ,   39  ,   7   ,   7   ,   145 ,   933 ,   1301    ,   2975    ,   5237    ,   11619   ,   1423    ,   46351   ,0 };
            const std::uint32_t dim4324Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   17  ,   3   ,   29  ,   233 ,   195 ,   727 ,   1893    ,   3709    ,   1285    ,   12877   ,   30821   ,   30383   ,0 };
            const std::uint32_t dim4325Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   1   ,   7   ,   115 ,   55  ,   231 ,   769 ,   849 ,   1043    ,   3041    ,   5187    ,   14613   ,   58821   ,0 };
            const std::uint32_t dim4326Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   13  ,   41  ,   5   ,   245 ,   109 ,   785 ,   187 ,   391 ,   3333    ,   8193    ,   823 ,   27985   ,0 };
            const std::uint32_t dim4327Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   9   ,   33  ,   25  ,   231 ,   347 ,   313 ,   31  ,   59  ,   6189    ,   4249    ,   26963   ,   56975   ,0 };
            const std::uint32_t dim4328Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   27  ,   57  ,   87  ,   77  ,   209 ,   231 ,   173 ,   3691    ,   8095    ,   10353   ,   14217   ,   3263    ,0 };
            const std::uint32_t dim4329Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   1   ,   55  ,   115 ,   63  ,   13  ,   705 ,   865 ,   1901    ,   4209    ,   8195    ,   25245   ,   2313    ,0 };
            const std::uint32_t dim4330Kuo3Init[]   =   {   1   ,   3   ,   5   ,   1   ,   13  ,   3   ,   53  ,   215 ,   345 ,   635 ,   1601    ,   241 ,   6491    ,   911 ,   5825    ,   34247   ,0 };
            const std::uint32_t dim4331Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   27  ,   21  ,   69  ,   83  ,   451 ,   33  ,   773 ,   2663    ,   5325    ,   16207   ,   15073   ,   32259   ,0 };
            const std::uint32_t dim4332Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   25  ,   33  ,   1   ,   35  ,   335 ,   355 ,   2005    ,   3087    ,   4577    ,   10533   ,   23641   ,   45297   ,0 };
            const std::uint32_t dim4333Kuo3Init[]   =   {   1   ,   3   ,   3   ,   7   ,   21  ,   43  ,   103 ,   223 ,   269 ,   781 ,   1445    ,   461 ,   6777    ,   5251    ,   6483    ,   14425   ,0 };
            const std::uint32_t dim4334Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   21  ,   55  ,   113 ,   227 ,   227 ,   173 ,   575 ,   3187    ,   3965    ,   13569   ,   4809    ,   16217   ,0 };
            const std::uint32_t dim4335Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   23  ,   23  ,   67  ,   99  ,   257 ,   651 ,   495 ,   3427    ,   7653    ,   505 ,   2549    ,   9283    ,0 };
            const std::uint32_t dim4336Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   15  ,   39  ,   123 ,   27  ,   1   ,   5   ,   107 ,   4055    ,   7347    ,   6411    ,   28857   ,   45591   ,0 };
            const std::uint32_t dim4337Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   29  ,   57  ,   77  ,   67  ,   365 ,   25  ,   1475    ,   3583    ,   4315    ,   6725    ,   22635   ,   62003   ,0 };
            const std::uint32_t dim4338Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   11  ,   9   ,   19  ,   25  ,   399 ,   467 ,   501 ,   2081    ,   977 ,   7695    ,   12997   ,   11841   ,0 };
            const std::uint32_t dim4339Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   19  ,   37  ,   39  ,   69  ,   75  ,   343 ,   525 ,   433 ,   6771    ,   8697    ,   6041    ,   49701   ,0 };
            const std::uint32_t dim4340Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   21  ,   31  ,   5   ,   193 ,   467 ,   161 ,   929 ,   3967    ,   2629    ,   3031    ,   30715   ,   45539   ,0 };
            const std::uint32_t dim4341Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   25  ,   17  ,   87  ,   179 ,   385 ,   491 ,   965 ,   2809    ,   6937    ,   2669    ,   20963   ,   13333   ,0 };
            const std::uint32_t dim4342Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   25  ,   1   ,   83  ,   47  ,   99  ,   425 ,   1007    ,   2903    ,   2959    ,   12403   ,   19707   ,   60863   ,0 };
            const std::uint32_t dim4343Kuo3Init[]   =   {   1   ,   1   ,   1   ,   15  ,   5   ,   19  ,   3   ,   181 ,   255 ,   135 ,   791 ,   3473    ,   3123    ,   5247    ,   28349   ,   5581    ,0 };
            const std::uint32_t dim4344Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   27  ,   13  ,   93  ,   215 ,   333 ,   667 ,   251 ,   2027    ,   6345    ,   8985    ,   22669   ,   46509   ,0 };
            const std::uint32_t dim4345Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   1   ,   27  ,   83  ,   107 ,   339 ,   699 ,   1197    ,   635 ,   2367    ,   6791    ,   9743    ,   9685    ,0 };
            const std::uint32_t dim4346Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   11  ,   43  ,   9   ,   37  ,   511 ,   177 ,   1957    ,   2697    ,   1879    ,   8219    ,   27525   ,   17737   ,0 };
            const std::uint32_t dim4347Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   3   ,   35  ,   81  ,   137 ,   193 ,   439 ,   35  ,   3743    ,   2973    ,   10245   ,   17111   ,   12025   ,0 };
            const std::uint32_t dim4348Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   3   ,   51  ,   7   ,   103 ,   65  ,   787 ,   1859    ,   1217    ,   8189    ,   2917    ,   2161    ,   64559   ,0 };
            const std::uint32_t dim4349Kuo3Init[]   =   {   1   ,   3   ,   5   ,   5   ,   31  ,   9   ,   53  ,   45  ,   167 ,   877 ,   1169    ,   2375    ,   6631    ,   9699    ,   8345    ,   27223   ,0 };
            const std::uint32_t dim4350Kuo3Init[]   =   {   1   ,   3   ,   5   ,   9   ,   1   ,   33  ,   113 ,   205 ,   153 ,   255 ,   63  ,   1517    ,   5225    ,   14485   ,   22053   ,   53333   ,0 };
            const std::uint32_t dim4351Kuo3Init[]   =   {   1   ,   1   ,   1   ,   1   ,   7   ,   45  ,   95  ,   211 ,   13  ,   769 ,   1909    ,   1049    ,   2465    ,   11581   ,   2983    ,   55267   ,0 };
            const std::uint32_t dim4352Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   7   ,   27  ,   3   ,   47  ,   503 ,   7   ,   1223    ,   1979    ,   815 ,   12593   ,   4229    ,   30539   ,0 };
            const std::uint32_t dim4353Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   9   ,   3   ,   103 ,   217 ,   199 ,   567 ,   943 ,   1527    ,   7191    ,   15243   ,   26311   ,   44263   ,0 };
            const std::uint32_t dim4354Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   29  ,   13  ,   107 ,   107 ,   35  ,   367 ,   849 ,   4047    ,   6027    ,   8155    ,   10963   ,   9941    ,0 };
            const std::uint32_t dim4355Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   27  ,   49  ,   89  ,   59  ,   479 ,   477 ,   1351    ,   2165    ,   7611    ,   9745    ,   7023    ,   22153   ,0 };
            const std::uint32_t dim4356Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   5   ,   7   ,   21  ,   91  ,   13  ,   547 ,   493 ,   813 ,   4325    ,   751 ,   14753   ,   52131   ,0 };
            const std::uint32_t dim4357Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   23  ,   7   ,   55  ,   69  ,   335 ,   127 ,   1669    ,   2171    ,   6033    ,   3713    ,   16855   ,   36479   ,0 };
            const std::uint32_t dim4358Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   17  ,   35  ,   117 ,   85  ,   415 ,   1019    ,   15  ,   3033    ,   2933    ,   2113    ,   10909   ,   107 ,0 };
            const std::uint32_t dim4359Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   13  ,   45  ,   61  ,   31  ,   115 ,   569 ,   21  ,   375 ,   1955    ,   10699   ,   17307   ,   20119   ,0 };
            const std::uint32_t dim4360Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   29  ,   29  ,   101 ,   137 ,   457 ,   845 ,   39  ,   461 ,   5113    ,   1429    ,   25443   ,   60127   ,0 };
            const std::uint32_t dim4361Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   29  ,   39  ,   35  ,   45  ,   269 ,   327 ,   2023    ,   2799    ,   4893    ,   3751    ,   7579    ,   56975   ,0 };
            const std::uint32_t dim4362Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   3   ,   49  ,   45  ,   219 ,   133 ,   279 ,   2003    ,   4007    ,   409 ,   3697    ,   11629   ,   19359   ,0 };
            const std::uint32_t dim4363Kuo3Init[]   =   {   1   ,   3   ,   5   ,   9   ,   25  ,   21  ,   85  ,   61  ,   131 ,   69  ,   1277    ,   249 ,   6265    ,   10245   ,   32575   ,   59735   ,0 };
            const std::uint32_t dim4364Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   1   ,   11  ,   63  ,   125 ,   57  ,   17  ,   111 ,   3521    ,   7397    ,   10985   ,   10193   ,   45493   ,0 };
            const std::uint32_t dim4365Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   31  ,   37  ,   115 ,   139 ,   203 ,   199 ,   559 ,   67  ,   7187    ,   5825    ,   6755    ,   43  ,0 };
            const std::uint32_t dim4366Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   7   ,   33  ,   41  ,   59  ,   487 ,   711 ,   247 ,   1095    ,   4113    ,   11349   ,   26331   ,   33159   ,0 };
            const std::uint32_t dim4367Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   25  ,   61  ,   57  ,   129 ,   409 ,   589 ,   1913    ,   1293    ,   7981    ,   8027    ,   789 ,   19655   ,0 };
            const std::uint32_t dim4368Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   29  ,   33  ,   55  ,   165 ,   315 ,   757 ,   1213    ,   2071    ,   4827    ,   6905    ,   7087    ,   22317   ,0 };
            const std::uint32_t dim4369Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   5   ,   7   ,   115 ,   161 ,   247 ,   91  ,   397 ,   1889    ,   2445    ,   13407   ,   20077   ,   50953   ,0 };
            const std::uint32_t dim4370Kuo3Init[]   =   {   1   ,   1   ,   5   ,   1   ,   31  ,   43  ,   53  ,   67  ,   183 ,   85  ,   285 ,   475 ,   3345    ,   7783    ,   25383   ,   26213   ,0 };
            const std::uint32_t dim4371Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   21  ,   27  ,   127 ,   229 ,   135 ,   795 ,   287 ,   937 ,   5645    ,   2271    ,   26095   ,   18407   ,0 };
            const std::uint32_t dim4372Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   27  ,   39  ,   109 ,   183 ,   1   ,   343 ,   695 ,   3825    ,   4347    ,   8399    ,   30219   ,   41839   ,0 };
            const std::uint32_t dim4373Kuo3Init[]   =   {   1   ,   1   ,   1   ,   3   ,   31  ,   3   ,   93  ,   139 ,   145 ,   107 ,   1311    ,   1919    ,   6631    ,   16363   ,   17473   ,   38661   ,0 };
            const std::uint32_t dim4374Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   23  ,   7   ,   17  ,   131 ,   505 ,   335 ,   19  ,   1037    ,   6985    ,   15181   ,   24857   ,   37363   ,0 };
            const std::uint32_t dim4375Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   5   ,   17  ,   51  ,   243 ,   221 ,   149 ,   801 ,   3179    ,   1929    ,   14145   ,   16541   ,   36911   ,0 };
            const std::uint32_t dim4376Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   15  ,   5   ,   19  ,   93  ,   117 ,   21  ,   1517    ,   2041    ,   5281    ,   7579    ,   23087   ,   37619   ,0 };
            const std::uint32_t dim4377Kuo3Init[]   =   {   1   ,   3   ,   5   ,   1   ,   21  ,   33  ,   5   ,   187 ,   471 ,   483 ,   249 ,   1075    ,   4831    ,   5467    ,   2921    ,   60803   ,0 };
            const std::uint32_t dim4378Kuo3Init[]   =   {   1   ,   1   ,   1   ,   1   ,   27  ,   57  ,   23  ,   185 ,   397 ,   945 ,   495 ,   2097    ,   7561    ,   1111    ,   30773   ,   61855   ,0 };
            const std::uint32_t dim4379Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   31  ,   53  ,   71  ,   125 ,   365 ,   947 ,   1685    ,   2871    ,   313 ,   5199    ,   11179   ,   18717   ,0 };
            const std::uint32_t dim4380Kuo3Init[]   =   {   1   ,   3   ,   7   ,   13  ,   23  ,   41  ,   83  ,   79  ,   427 ,   877 ,   281 ,   3205    ,   865 ,   8021    ,   3423    ,   28111   ,0 };
            const std::uint32_t dim4381Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   29  ,   39  ,   11  ,   247 ,   45  ,   339 ,   1153    ,   1179    ,   6495    ,   6861    ,   15247   ,   44515   ,0 };
            const std::uint32_t dim4382Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   1   ,   21  ,   41  ,   211 ,   379 ,   99  ,   887 ,   2035    ,   847 ,   4679    ,   9941    ,   49585   ,0 };
            const std::uint32_t dim4383Kuo3Init[]   =   {   1   ,   3   ,   1   ,   11  ,   17  ,   59  ,   29  ,   23  ,   355 ,   393 ,   323 ,   1843    ,   1373    ,   1995    ,   28417   ,   12167   ,0 };
            const std::uint32_t dim4384Kuo3Init[]   =   {   1   ,   3   ,   7   ,   1   ,   31  ,   55  ,   105 ,   239 ,   509 ,   709 ,   415 ,   4015    ,   4597    ,   13861   ,   11553   ,   87  ,0 };
            const std::uint32_t dim4385Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   25  ,   55  ,   13  ,   19  ,   333 ,   371 ,   1829    ,   3879    ,   7199    ,   2849    ,   16885   ,   52575   ,0 };
            const std::uint32_t dim4386Kuo3Init[]   =   {   1   ,   3   ,   5   ,   9   ,   27  ,   23  ,   55  ,   109 ,   465 ,   923 ,   905 ,   197 ,   4017    ,   2079    ,   10775   ,   55543   ,0 };
            const std::uint32_t dim4387Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   31  ,   49  ,   69  ,   181 ,   261 ,   71  ,   1727    ,   2717    ,   317 ,   13397   ,   26641   ,   37783   ,0 };
            const std::uint32_t dim4388Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   17  ,   55  ,   107 ,   201 ,   21  ,   279 ,   437 ,   3267    ,   999 ,   14787   ,   23727   ,   2563    ,0 };
            const std::uint32_t dim4389Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   27  ,   41  ,   19  ,   153 ,   435 ,   577 ,   327 ,   965 ,   7899    ,   11799   ,   4683    ,   49651   ,0 };
            const std::uint32_t dim4390Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   25  ,   47  ,   13  ,   243 ,   281 ,   201 ,   1455    ,   2369    ,   7947    ,   10993   ,   14715   ,   30099   ,0 };
            const std::uint32_t dim4391Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   17  ,   1   ,   49  ,   205 ,   303 ,   85  ,   823 ,   3721    ,   3155    ,   5473    ,   6019    ,   24837   ,0 };
            const std::uint32_t dim4392Kuo3Init[]   =   {   1   ,   3   ,   1   ,   7   ,   5   ,   27  ,   65  ,   177 ,   405 ,   841 ,   1523    ,   43  ,   2309    ,   14041   ,   6705    ,   18145   ,0 };
            const std::uint32_t dim4393Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   25  ,   35  ,   53  ,   177 ,   233 ,   287 ,   1265    ,   3305    ,   4961    ,   2751    ,   8715    ,   56605   ,0 };
            const std::uint32_t dim4394Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   7   ,   9   ,   45  ,   179 ,   65  ,   153 ,   1861    ,   111 ,   5501    ,   3671    ,   25663   ,   46493   ,0 };
            const std::uint32_t dim4395Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   11  ,   37  ,   25  ,   199 ,   339 ,   313 ,   1823    ,   2933    ,   6459    ,   3359    ,   8577    ,   64109   ,0 };
            const std::uint32_t dim4396Kuo3Init[]   =   {   1   ,   3   ,   1   ,   11  ,   5   ,   3   ,   127 ,   53  ,   77  ,   431 ,   931 ,   3159    ,   2267    ,   8123    ,   7581    ,   52237   ,0 };
            const std::uint32_t dim4397Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   1   ,   51  ,   41  ,   147 ,   481 ,   243 ,   2045    ,   3239    ,   8191    ,   7533    ,   25021   ,   46359   ,0 };
            const std::uint32_t dim4398Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   17  ,   1   ,   57  ,   141 ,   239 ,   375 ,   23  ,   3695    ,   827 ,   10783   ,   18109   ,   54029   ,0 };
            const std::uint32_t dim4399Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   13  ,   39  ,   35  ,   251 ,   271 ,   461 ,   313 ,   2807    ,   2927    ,   4639    ,   17175   ,   65325   ,0 };
            const std::uint32_t dim4400Kuo3Init[]   =   {   1   ,   1   ,   7   ,   15  ,   1   ,   9   ,   123 ,   243 ,   451 ,   433 ,   1339    ,   1223    ,   3399    ,   12669   ,   20663   ,   27505   ,0 };
            const std::uint32_t dim4401Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   31  ,   25  ,   41  ,   225 ,   61  ,   525 ,   527 ,   1559    ,   5469    ,   2299    ,   3169    ,   12435   ,0 };
            const std::uint32_t dim4402Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   3   ,   45  ,   21  ,   99  ,   89  ,   97  ,   379 ,   1815    ,   5883    ,   9437    ,   32597   ,   14795   ,0 };
            const std::uint32_t dim4403Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   5   ,   17  ,   109 ,   185 ,   389 ,   291 ,   1041    ,   847 ,   957 ,   13413   ,   29763   ,   39789   ,0 };
            const std::uint32_t dim4404Kuo3Init[]   =   {   1   ,   3   ,   5   ,   7   ,   31  ,   39  ,   63  ,   181 ,   297 ,   71  ,   199 ,   1655    ,   1497    ,   8981    ,   23785   ,   40839   ,0 };
            const std::uint32_t dim4405Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   23  ,   15  ,   25  ,   9   ,   361 ,   151 ,   1191    ,   943 ,   17  ,   715 ,   28593   ,   22609   ,0 };
            const std::uint32_t dim4406Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   27  ,   13  ,   99  ,   109 ,   97  ,   415 ,   1515    ,   701 ,   7153    ,   14207   ,   24417   ,   52673   ,0 };
            const std::uint32_t dim4407Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   15  ,   15  ,   15  ,   251 ,   23  ,   717 ,   219 ,   1783    ,   3657    ,   10141   ,   6525    ,   37683   ,0 };
            const std::uint32_t dim4408Kuo3Init[]   =   {   1   ,   1   ,   1   ,   1   ,   5   ,   55  ,   19  ,   213 ,   99  ,   73  ,   227 ,   2029    ,   1225    ,   14849   ,   17073   ,   30409   ,0 };
            const std::uint32_t dim4409Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   15  ,   49  ,   49  ,   11  ,   289 ,   287 ,   999 ,   743 ,   1081    ,   3185    ,   30613   ,   25163   ,0 };
            const std::uint32_t dim4410Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   15  ,   21  ,   33  ,   53  ,   465 ,   45  ,   113 ,   2865    ,   2641    ,   13797   ,   27785   ,   63159   ,0 };
            const std::uint32_t dim4411Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   27  ,   5   ,   41  ,   21  ,   53  ,   675 ,   1217    ,   239 ,   7925    ,   6659    ,   15025   ,   56589   ,0 };
            const std::uint32_t dim4412Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   15  ,   1   ,   7   ,   129 ,   377 ,   1017    ,   1015    ,   329 ,   3153    ,   5815    ,   7929    ,   62579   ,0 };
            const std::uint32_t dim4413Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   19  ,   37  ,   23  ,   115 ,   29  ,   813 ,   1761    ,   751 ,   3461    ,   13027   ,   30853   ,   51399   ,0 };
            const std::uint32_t dim4414Kuo3Init[]   =   {   1   ,   3   ,   1   ,   15  ,   1   ,   37  ,   125 ,   143 ,   117 ,   33  ,   321 ,   1917    ,   741 ,   1281    ,   4811    ,   30907   ,0 };
            const std::uint32_t dim4415Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   25  ,   55  ,   43  ,   69  ,   479 ,   37  ,   1891    ,   325 ,   7165    ,   11707   ,   11663   ,   9   ,0 };
            const std::uint32_t dim4416Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   13  ,   1   ,   37  ,   5   ,   195 ,   959 ,   1707    ,   3099    ,   2295    ,   1363    ,   14463   ,   37013   ,0 };
            const std::uint32_t dim4417Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   17  ,   45  ,   63  ,   189 ,   471 ,   273 ,   633 ,   977 ,   3377    ,   15191   ,   25127   ,   38949   ,0 };
            const std::uint32_t dim4418Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   11  ,   49  ,   107 ,   237 ,   365 ,   813 ,   841 ,   215 ,   5087    ,   4661    ,   8045    ,   39713   ,0 };
            const std::uint32_t dim4419Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   11  ,   39  ,   47  ,   23  ,   267 ,   929 ,   709 ,   2593    ,   3773    ,   8435    ,   15947   ,   43873   ,0 };
            const std::uint32_t dim4420Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   7   ,   45  ,   109 ,   121 ,   389 ,   15  ,   599 ,   2887    ,   4009    ,   13557   ,   6845    ,   10149   ,0 };
            const std::uint32_t dim4421Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   11  ,   45  ,   5   ,   39  ,   401 ,   467 ,   291 ,   1807    ,   3711    ,   13831   ,   11777   ,   28543   ,0 };
            const std::uint32_t dim4422Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   29  ,   29  ,   121 ,   33  ,   185 ,   135 ,   479 ,   3681    ,   4763    ,   6915    ,   6689    ,   45981   ,0 };
            const std::uint32_t dim4423Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   7   ,   57  ,   53  ,   39  ,   429 ,   985 ,   523 ,   2245    ,   8003    ,   3385    ,   31869   ,   30589   ,0 };
            const std::uint32_t dim4424Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   23  ,   21  ,   71  ,   229 ,   83  ,   327 ,   399 ,   1413    ,   5321    ,   10593   ,   19219   ,   32837   ,0 };
            const std::uint32_t dim4425Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   31  ,   37  ,   15  ,   119 ,   13  ,   949 ,   1589    ,   3247    ,   5671    ,   2141    ,   21189   ,   6353    ,0 };
            const std::uint32_t dim4426Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   13  ,   25  ,   77  ,   19  ,   261 ,   237 ,   1651    ,   1165    ,   4317    ,   3265    ,   13471   ,   34163   ,0 };
            const std::uint32_t dim4427Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   17  ,   53  ,   97  ,   245 ,   3   ,   177 ,   873 ,   2273    ,   3577    ,   10233   ,   3615    ,   38189   ,0 };
            const std::uint32_t dim4428Kuo3Init[]   =   {   1   ,   1   ,   7   ,   9   ,   23  ,   63  ,   5   ,   115 ,   55  ,   825 ,   877 ,   101 ,   1167    ,   10583   ,   14171   ,   42343   ,0 };
            const std::uint32_t dim4429Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   3   ,   25  ,   119 ,   185 ,   295 ,   349 ,   587 ,   2497    ,   6103    ,   5755    ,   25191   ,   50015   ,0 };
            const std::uint32_t dim4430Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   11  ,   55  ,   55  ,   37  ,   229 ,   803 ,   911 ,   3081    ,   1543    ,   297 ,   187 ,   51775   ,0 };
            const std::uint32_t dim4431Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   31  ,   53  ,   105 ,   17  ,   219 ,   145 ,   1129    ,   431 ,   5651    ,   1963    ,   693 ,   18177   ,0 };
            const std::uint32_t dim4432Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   7   ,   29  ,   61  ,   199 ,   101 ,   553 ,   1765    ,   1657    ,   1843    ,   12557   ,   27261   ,   4877    ,0 };
            const std::uint32_t dim4433Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   19  ,   57  ,   33  ,   233 ,   179 ,   437 ,   1835    ,   3081    ,   7241    ,   4227    ,   18707   ,   27027   ,0 };
            const std::uint32_t dim4434Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   7   ,   61  ,   45  ,   55  ,   153 ,   97  ,   1081    ,   2937    ,   2911    ,   3927    ,   17915   ,   275 ,0 };
            const std::uint32_t dim4435Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   19  ,   25  ,   95  ,   85  ,   27  ,   589 ,   121 ,   2003    ,   4891    ,   6737    ,   4835    ,   10443   ,0 };
            const std::uint32_t dim4436Kuo3Init[]   =   {   1   ,   1   ,   5   ,   7   ,   5   ,   61  ,   21  ,   7   ,   439 ,   351 ,   1119    ,   937 ,   5517    ,   5001    ,   18859   ,   12427   ,0 };
            const std::uint32_t dim4437Kuo3Init[]   =   {   1   ,   1   ,   1   ,   1   ,   13  ,   21  ,   87  ,   73  ,   61  ,   71  ,   885 ,   4029    ,   2893    ,   833 ,   18813   ,   18617   ,0 };
            const std::uint32_t dim4438Kuo3Init[]   =   {   1   ,   1   ,   5   ,   7   ,   23  ,   63  ,   111 ,   159 ,   39  ,   937 ,   719 ,   1641    ,   7901    ,   7349    ,   31397   ,   38111   ,0 };
            const std::uint32_t dim4439Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   9   ,   9   ,   105 ,   33  ,   205 ,   829 ,   1929    ,   1925    ,   1735    ,   10217   ,   1747    ,   38351   ,0 };
            const std::uint32_t dim4440Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   9   ,   13  ,   111 ,   39  ,   465 ,   635 ,   989 ,   2079    ,   7781    ,   13229   ,   1039    ,   21061   ,0 };
            const std::uint32_t dim4441Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   29  ,   15  ,   123 ,   137 ,   75  ,   561 ,   1699    ,   57  ,   8179    ,   5693    ,   6333    ,   25581   ,0 };
            const std::uint32_t dim4442Kuo3Init[]   =   {   1   ,   1   ,   7   ,   9   ,   3   ,   17  ,   27  ,   117 ,   95  ,   287 ,   1313    ,   1863    ,   7119    ,   16253   ,   27931   ,   42341   ,0 };
            const std::uint32_t dim4443Kuo3Init[]   =   {   1   ,   1   ,   1   ,   11  ,   21  ,   47  ,   83  ,   79  ,   451 ,   535 ,   1249    ,   1125    ,   5387    ,   11309   ,   12115   ,   45877   ,0 };
            const std::uint32_t dim4444Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   21  ,   17  ,   93  ,   125 ,   467 ,   465 ,   619 ,   1899    ,   5501    ,   233 ,   28371   ,   7199    ,0 };
            const std::uint32_t dim4445Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   3   ,   5   ,   5   ,   111 ,   107 ,   95  ,   2023    ,   3529    ,   5135    ,   3377    ,   22025   ,   41931   ,0 };
            const std::uint32_t dim4446Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   31  ,   19  ,   115 ,   155 ,   349 ,   911 ,   1893    ,   3617    ,   689 ,   16323   ,   13523   ,   20373   ,0 };
            const std::uint32_t dim4447Kuo3Init[]   =   {   1   ,   1   ,   3   ,   5   ,   25  ,   7   ,   57  ,   117 ,   65  ,   469 ,   1669    ,   407 ,   3693    ,   1743    ,   16697   ,   30749   ,0 };
            const std::uint32_t dim4448Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   29  ,   11  ,   117 ,   187 ,   13  ,   77  ,   45  ,   39  ,   6237    ,   9899    ,   28805   ,   9389    ,0 };
            const std::uint32_t dim4449Kuo3Init[]   =   {   1   ,   3   ,   1   ,   5   ,   5   ,   33  ,   43  ,   45  ,   331 ,   615 ,   961 ,   2143    ,   4403    ,   543 ,   22783   ,   47063   ,0 };
            const std::uint32_t dim4450Kuo3Init[]   =   {   1   ,   3   ,   1   ,   11  ,   7   ,   1   ,   93  ,   153 ,   417 ,   859 ,   451 ,   1211    ,   6439    ,   8043    ,   5759    ,   60265   ,0 };
            const std::uint32_t dim4451Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   19  ,   53  ,   57  ,   93  ,   295 ,   773 ,   533 ,   2685    ,   7429    ,   2855    ,   7665    ,   46257   ,0 };
            const std::uint32_t dim4452Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   29  ,   5   ,   93  ,   159 ,   7   ,   845 ,   337 ,   881 ,   2529    ,   15677   ,   9795    ,   31347   ,0 };
            const std::uint32_t dim4453Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   11  ,   49  ,   97  ,   59  ,   157 ,   695 ,   65  ,   1865    ,   4107    ,   15283   ,   2309    ,   13841   ,0 };
            const std::uint32_t dim4454Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   21  ,   31  ,   61  ,   85  ,   361 ,   893 ,   1223    ,   259 ,   2771    ,   4973    ,   18661   ,   16653   ,0 };
            const std::uint32_t dim4455Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   19  ,   31  ,   3   ,   223 ,   151 ,   785 ,   447 ,   2123    ,   3377    ,   14159   ,   933 ,   23357   ,0 };
            const std::uint32_t dim4456Kuo3Init[]   =   {   1   ,   3   ,   5   ,   11  ,   1   ,   55  ,   77  ,   107 ,   245 ,   193 ,   583 ,   2729    ,   831 ,   11019   ,   25433   ,   6541    ,0 };
            const std::uint32_t dim4457Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   3   ,   35  ,   19  ,   127 ,   419 ,   203 ,   1869    ,   1477    ,   5239    ,   6113    ,   4835    ,   21131   ,0 };
            const std::uint32_t dim4458Kuo3Init[]   =   {   1   ,   3   ,   3   ,   7   ,   17  ,   49  ,   17  ,   23  ,   111 ,   65  ,   1603    ,   157 ,   6433    ,   2965    ,   19845   ,   59041   ,0 };
            const std::uint32_t dim4459Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   17  ,   1   ,   17  ,   207 ,   245 ,   129 ,   1309    ,   413 ,   6933    ,   7575    ,   17179   ,   24075   ,0 };
            const std::uint32_t dim4460Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   29  ,   23  ,   65  ,   43  ,   157 ,   569 ,   645 ,   1821    ,   605 ,   3925    ,   2863    ,   55361   ,0 };
            const std::uint32_t dim4461Kuo3Init[]   =   {   1   ,   3   ,   3   ,   5   ,   15  ,   43  ,   1   ,   149 ,   253 ,   529 ,   37  ,   2589    ,   2851    ,   2529    ,   32689   ,   49303   ,0 };
            const std::uint32_t dim4462Kuo3Init[]   =   {   1   ,   3   ,   1   ,   15  ,   3   ,   29  ,   19  ,   241 ,   153 ,   189 ,   161 ,   797 ,   5419    ,   11269   ,   2159    ,   57893   ,0 };
            const std::uint32_t dim4463Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   19  ,   23  ,   49  ,   179 ,   459 ,   701 ,   1003    ,   2673    ,   1729    ,   1901    ,   26003   ,   51441   ,0 };
            const std::uint32_t dim4464Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   23  ,   19  ,   47  ,   85  ,   281 ,   371 ,   773 ,   2263    ,   3235    ,   647 ,   23085   ,   10053   ,0 };
            const std::uint32_t dim4465Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   13  ,   23  ,   13  ,   95  ,   41  ,   963 ,   213 ,   2317    ,   3889    ,   3981    ,   4749    ,   55409   ,0 };
            const std::uint32_t dim4466Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   9   ,   39  ,   33  ,   21  ,   17  ,   201 ,   1789    ,   2593    ,   1373    ,   14601   ,   17025   ,   31861   ,0 };
            const std::uint32_t dim4467Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   5   ,   43  ,   107 ,   169 ,   247 ,   361 ,   1245    ,   2371    ,   119 ,   4987    ,   32661   ,   19363   ,0 };
            const std::uint32_t dim4468Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   29  ,   35  ,   81  ,   13  ,   419 ,   1003    ,   701 ,   759 ,   4415    ,   11441   ,   28985   ,   46869   ,0 };
            const std::uint32_t dim4469Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   9   ,   57  ,   3   ,   39  ,   457 ,   455 ,   29  ,   2983    ,   4879    ,   14359   ,   12913   ,   64711   ,0 };
            const std::uint32_t dim4470Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   9   ,   31  ,   57  ,   47  ,   55  ,   525 ,   2015    ,   2053    ,   7101    ,   8487    ,   26865   ,   29149   ,0 };
            const std::uint32_t dim4471Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   11  ,   37  ,   67  ,   241 ,   509 ,   711 ,   263 ,   1565    ,   6803    ,   2095    ,   3055    ,   28847   ,0 };
            const std::uint32_t dim4472Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   25  ,   23  ,   53  ,   135 ,   391 ,   625 ,   673 ,   2807    ,   6511    ,   7465    ,   21959   ,   17561   ,0 };
            const std::uint32_t dim4473Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   23  ,   23  ,   47  ,   247 ,   297 ,   191 ,   1137    ,   3921    ,   3669    ,   4439    ,   707 ,   33529   ,0 };
            const std::uint32_t dim4474Kuo3Init[]   =   {   1   ,   1   ,   7   ,   15  ,   19  ,   35  ,   91  ,   75  ,   237 ,   585 ,   1047    ,   1389    ,   7147    ,   9043    ,   22363   ,   14287   ,0 };
            const std::uint32_t dim4475Kuo3Init[]   =   {   1   ,   3   ,   1   ,   15  ,   17  ,   35  ,   45  ,   181 ,   439 ,   307 ,   709 ,   2925    ,   3397    ,   4577    ,   30645   ,   25167   ,0 };
            const std::uint32_t dim4476Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   25  ,   1   ,   127 ,   173 ,   397 ,   477 ,   821 ,   2017    ,   1363    ,   8615    ,   8833    ,   12771   ,0 };
            const std::uint32_t dim4477Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   9   ,   1   ,   33  ,   137 ,   383 ,   465 ,   1211    ,   3563    ,   5035    ,   6609    ,   31667   ,   10853   ,0 };
            const std::uint32_t dim4478Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   11  ,   49  ,   61  ,   51  ,   31  ,   811 ,   623 ,   2213    ,   7131    ,   15679   ,   5335    ,   53001   ,0 };
            const std::uint32_t dim4479Kuo3Init[]   =   {   1   ,   1   ,   5   ,   7   ,   27  ,   55  ,   11  ,   229 ,   331 ,   109 ,   109 ,   877 ,   6087    ,   10023   ,   22627   ,   64253   ,0 };
            const std::uint32_t dim4480Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   11  ,   13  ,   105 ,   31  ,   357 ,   589 ,   869 ,   1583    ,   3441    ,   15783   ,   25579   ,   25335   ,0 };
            const std::uint32_t dim4481Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   7   ,   9   ,   35  ,   29  ,   153 ,   425 ,   1145    ,   2021    ,   115 ,   15865   ,   4305    ,   62417   ,0 };
            const std::uint32_t dim4482Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   27  ,   17  ,   3   ,   57  ,   111 ,   393 ,   711 ,   2519    ,   7223    ,   10117   ,   5509    ,   63361   ,0 };
            const std::uint32_t dim4483Kuo3Init[]   =   {   1   ,   1   ,   5   ,   7   ,   9   ,   55  ,   101 ,   199 ,   441 ,   141 ,   1349    ,   3017    ,   7625    ,   1457    ,   27947   ,   13269   ,0 };
            const std::uint32_t dim4484Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   5   ,   23  ,   3   ,   87  ,   61  ,   19  ,   1449    ,   2317    ,   4049    ,   3397    ,   6271    ,   53317   ,0 };
            const std::uint32_t dim4485Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   11  ,   35  ,   95  ,   141 ,   355 ,   749 ,   1247    ,   3495    ,   5719    ,   16201   ,   9649    ,   12395   ,0 };
            const std::uint32_t dim4486Kuo3Init[]   =   {   1   ,   3   ,   7   ,   11  ,   23  ,   29  ,   79  ,   171 ,   259 ,   923 ,   2035    ,   783 ,   3571    ,   14987   ,   30025   ,   19185   ,0 };
            const std::uint32_t dim4487Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   17  ,   31  ,   75  ,   141 ,   131 ,   391 ,   303 ,   2641    ,   5527    ,   12629   ,   1097    ,   47589   ,0 };
            const std::uint32_t dim4488Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   9   ,   55  ,   23  ,   207 ,   211 ,   633 ,   805 ,   3079    ,   5495    ,   4651    ,   26483   ,   59323   ,0 };
            const std::uint32_t dim4489Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   9   ,   17  ,   97  ,   173 ,   123 ,   139 ,   595 ,   3859    ,   4615    ,   15565   ,   9243    ,   19933   ,0 };
            const std::uint32_t dim4490Kuo3Init[]   =   {   1   ,   3   ,   5   ,   9   ,   31  ,   51  ,   1   ,   133 ,   213 ,   877 ,   23  ,   3661    ,   3451    ,   11705   ,   27943   ,   10995   ,0 };
            const std::uint32_t dim4491Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   5   ,   1   ,   91  ,   113 ,   147 ,   825 ,   795 ,   2871    ,   5175    ,   6843    ,   17829   ,   25375   ,0 };
            const std::uint32_t dim4492Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   7   ,   15  ,   105 ,   227 ,   97  ,   985 ,   347 ,   2833    ,   1237    ,   9419    ,   17853   ,   43467   ,0 };
            const std::uint32_t dim4493Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   17  ,   47  ,   3   ,   237 ,   97  ,   915 ,   1463    ,   477 ,   2237    ,   7755    ,   11779   ,   35897   ,0 };
            const std::uint32_t dim4494Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   17  ,   17  ,   97  ,   163 ,   181 ,   411 ,   1145    ,   623 ,   3017    ,   1335    ,   6999    ,   57149   ,0 };
            const std::uint32_t dim4495Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   27  ,   49  ,   57  ,   49  ,   217 ,   635 ,   973 ,   1153    ,   8097    ,   4669    ,   30691   ,   1949    ,0 };
            const std::uint32_t dim4496Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   13  ,   47  ,   107 ,   247 ,   269 ,   803 ,   1919    ,   3047    ,   2967    ,   63  ,   12287   ,   39925   ,0 };
            const std::uint32_t dim4497Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   27  ,   15  ,   27  ,   255 ,   27  ,   463 ,   621 ,   2443    ,   5615    ,   14589   ,   10869   ,   5013    ,0 };
            const std::uint32_t dim4498Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   25  ,   15  ,   75  ,   223 ,   17  ,   227 ,   911 ,   3069    ,   2583    ,   8811    ,   14191   ,   2819    ,0 };
            const std::uint32_t dim4499Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   25  ,   13  ,   19  ,   157 ,   495 ,   997 ,   1997    ,   3175    ,   1515    ,   15693   ,   15585   ,   2753    ,0 };
            const std::uint32_t dim4500Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   7   ,   5   ,   67  ,   95  ,   337 ,   539 ,   2019    ,   2009    ,   7171    ,   1089    ,   7955    ,   17557   ,0 };
            const std::uint32_t dim4501Kuo3Init[]   =   {   1   ,   3   ,   3   ,   3   ,   7   ,   63  ,   61  ,   31  ,   61  ,   483 ,   365 ,   1153    ,   495 ,   7357    ,   2831    ,   23191   ,0 };
            const std::uint32_t dim4502Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   17  ,   35  ,   121 ,   143 ,   411 ,   895 ,   1859    ,   2205    ,   6565    ,   11611   ,   20941   ,   47151   ,0 };
            const std::uint32_t dim4503Kuo3Init[]   =   {   1   ,   3   ,   7   ,   9   ,   27  ,   21  ,   53  ,   51  ,   77  ,   251 ,   1355    ,   175 ,   3949    ,   2903    ,   26991   ,   41571   ,0 };
            const std::uint32_t dim4504Kuo3Init[]   =   {   1   ,   1   ,   1   ,   15  ,   17  ,   1   ,   15  ,   253 ,   99  ,   611 ,   1949    ,   1917    ,   4363    ,   2887    ,   30421   ,   42197   ,0 };
            const std::uint32_t dim4505Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   29  ,   45  ,   111 ,   49  ,   389 ,   171 ,   1069    ,   3061    ,   6657    ,   12097   ,   533 ,   9459    ,0 };
            const std::uint32_t dim4506Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   5   ,   27  ,   39  ,   15  ,   381 ,   119 ,   137 ,   3641    ,   8047    ,   1391    ,   13093   ,   50659   ,0 };
            const std::uint32_t dim4507Kuo3Init[]   =   {   1   ,   1   ,   7   ,   9   ,   27  ,   59  ,   123 ,   235 ,   301 ,   933 ,   335 ,   3927    ,   2811    ,   16133   ,   5999    ,   19933   ,0 };
            const std::uint32_t dim4508Kuo3Init[]   =   {   1   ,   3   ,   3   ,   13  ,   15  ,   55  ,   69  ,   199 ,   353 ,   131 ,   753 ,   2765    ,   4005    ,   13575   ,   16607   ,   51253   ,0 };
            const std::uint32_t dim4509Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   19  ,   53  ,   31  ,   233 ,   289 ,   939 ,   31  ,   1741    ,   5467    ,   1987    ,   13923   ,   49857   ,0 };
            const std::uint32_t dim4510Kuo3Init[]   =   {   1   ,   1   ,   7   ,   7   ,   31  ,   45  ,   45  ,   237 ,   427 ,   305 ,   1753    ,   1237    ,   3573    ,   10813   ,   10609   ,   24187   ,0 };
            const std::uint32_t dim4511Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   21  ,   41  ,   81  ,   219 ,   185 ,   107 ,   71  ,   2017    ,   6587    ,   3351    ,   10207   ,   10545   ,0 };
            const std::uint32_t dim4512Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   5   ,   21  ,   127 ,   129 ,   209 ,   313 ,   1273    ,   3229    ,   6733    ,   4431    ,   7297    ,   41569   ,0 };
            const std::uint32_t dim4513Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   17  ,   61  ,   55  ,   127 ,   85  ,   913 ,   1173    ,   3837    ,   5579    ,   10309   ,   24659   ,   22697   ,0 };
            const std::uint32_t dim4514Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   11  ,   11  ,   91  ,   165 ,   367 ,   79  ,   43  ,   679 ,   3285    ,   15469   ,   21511   ,   57755   ,0 };
            const std::uint32_t dim4515Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   15  ,   1   ,   125 ,   47  ,   101 ,   999 ,   521 ,   543 ,   5535    ,   10191   ,   7497    ,   15677   ,0 };
            const std::uint32_t dim4516Kuo3Init[]   =   {   1   ,   3   ,   3   ,   9   ,   9   ,   15  ,   63  ,   239 ,   471 ,   903 ,   1473    ,   717 ,   6547    ,   8445    ,   20737   ,   41457   ,0 };
            const std::uint32_t dim4517Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   13  ,   31  ,   43  ,   93  ,   325 ,   393 ,   373 ,   971 ,   6045    ,   14981   ,   28011   ,   35997   ,0 };
            const std::uint32_t dim4518Kuo3Init[]   =   {   1   ,   3   ,   1   ,   15  ,   11  ,   45  ,   41  ,   35  ,   381 ,   779 ,   443 ,   3395    ,   2495    ,   14795   ,   4695    ,   22745   ,0 };
            const std::uint32_t dim4519Kuo3Init[]   =   {   1   ,   3   ,   3   ,   7   ,   21  ,   9   ,   89  ,   173 ,   233 ,   935 ,   683 ,   1533    ,   953 ,   2627    ,   30975   ,   43449   ,0 };
            const std::uint32_t dim4520Kuo3Init[]   =   {   1   ,   1   ,   5   ,   3   ,   25  ,   55  ,   107 ,   105 ,   99  ,   959 ,   1935    ,   3489    ,   3671    ,   14999   ,   11707   ,   10285   ,0 };
            const std::uint32_t dim4521Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   31  ,   17  ,   123 ,   119 ,   63  ,   169 ,   1283    ,   3691    ,   1411    ,   3437    ,   27941   ,   57089   ,0 };
            const std::uint32_t dim4522Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   17  ,   9   ,   115 ,   69  ,   481 ,   689 ,   2007    ,   3815    ,   4419    ,   11249   ,   31469   ,   55783   ,0 };
            const std::uint32_t dim4523Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   9   ,   39  ,   65  ,   125 ,   253 ,   413 ,   1283    ,   2073    ,   6563    ,   2111    ,   22865   ,   59393   ,0 };
            const std::uint32_t dim4524Kuo3Init[]   =   {   1   ,   3   ,   3   ,   15  ,   19  ,   1   ,   67  ,   253 ,   489 ,   185 ,   297 ,   261 ,   5203    ,   8685    ,   10515   ,   58595   ,0 };
            const std::uint32_t dim4525Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   23  ,   39  ,   95  ,   233 ,   171 ,   653 ,   2025    ,   2285    ,   4477    ,   9275    ,   9717    ,   43321   ,0 };
            const std::uint32_t dim4526Kuo3Init[]   =   {   1   ,   1   ,   7   ,   3   ,   23  ,   35  ,   77  ,   119 ,   193 ,   41  ,   1057    ,   4017    ,   235 ,   13819   ,   7911    ,   3981    ,0 };
            const std::uint32_t dim4527Kuo3Init[]   =   {   1   ,   3   ,   5   ,   9   ,   15  ,   33  ,   41  ,   221 ,   1   ,   307 ,   1325    ,   2899    ,   399 ,   801 ,   24611   ,   31941   ,0 };
            const std::uint32_t dim4528Kuo3Init[]   =   {   1   ,   1   ,   1   ,   15  ,   1   ,   7   ,   91  ,   27  ,   247 ,   667 ,   483 ,   573 ,   481 ,   11771   ,   31139   ,   31979   ,0 };
            const std::uint32_t dim4529Kuo3Init[]   =   {   1   ,   3   ,   5   ,   1   ,   3   ,   23  ,   39  ,   73  ,   101 ,   367 ,   1259    ,   4053    ,   3055    ,   1231    ,   27981   ,   54287   ,0 };
            const std::uint32_t dim4530Kuo3Init[]   =   {   1   ,   3   ,   3   ,   7   ,   3   ,   31  ,   9   ,   71  ,   339 ,   33  ,   1255    ,   1353    ,   5575    ,   12481   ,   27881   ,   17293   ,0 };
            const std::uint32_t dim4531Kuo3Init[]   =   {   1   ,   3   ,   5   ,   13  ,   5   ,   57  ,   123 ,   193 ,   443 ,   185 ,   851 ,   539 ,   4217    ,   915 ,   1247    ,   20163   ,0 };
            const std::uint32_t dim4532Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   11  ,   13  ,   99  ,   141 ,   439 ,   259 ,   1177    ,   453 ,   6037    ,   5813    ,   25147   ,   20381   ,0 };
            const std::uint32_t dim4533Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   25  ,   17  ,   105 ,   91  ,   33  ,   15  ,   2035    ,   3693    ,   2249    ,   5825    ,   29037   ,   12529   ,0 };
            const std::uint32_t dim4534Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   1   ,   33  ,   113 ,   237 ,   13  ,   845 ,   1127    ,   4067    ,   825 ,   8391    ,   1269    ,   51473   ,0 };
            const std::uint32_t dim4535Kuo3Init[]   =   {   1   ,   3   ,   5   ,   3   ,   27  ,   5   ,   77  ,   97  ,   33  ,   569 ,   1327    ,   751 ,   2817    ,   775 ,   32275   ,   55757   ,0 };
            const std::uint32_t dim4536Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   25  ,   1   ,   73  ,   105 ,   19  ,   1007    ,   371 ,   269 ,   4833    ,   13881   ,   21503   ,   35303   ,0 };
            const std::uint32_t dim4537Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   23  ,   39  ,   27  ,   203 ,   351 ,   433 ,   399 ,   405 ,   39  ,   7773    ,   27345   ,   57109   ,0 };
            const std::uint32_t dim4538Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   7   ,   7   ,   21  ,   33  ,   481 ,   201 ,   7   ,   2377    ,   1009    ,   7593    ,   19381   ,   10325   ,0 };
            const std::uint32_t dim4539Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   15  ,   61  ,   29  ,   59  ,   255 ,   213 ,   1207    ,   3783    ,   4375    ,   8137    ,   6733    ,   10809   ,0 };
            const std::uint32_t dim4540Kuo3Init[]   =   {   1   ,   1   ,   1   ,   9   ,   25  ,   37  ,   83  ,   169 ,   267 ,   21  ,   1211    ,   3099    ,   239 ,   2489    ,   12843   ,   4395    ,0 };
            const std::uint32_t dim4541Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   17  ,   47  ,   77  ,   63  ,   361 ,   567 ,   245 ,   3569    ,   7707    ,   15463   ,   29579   ,   55017   ,0 };
            const std::uint32_t dim4542Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   23  ,   3   ,   111 ,   21  ,   417 ,   609 ,   547 ,   3297    ,   7487    ,   3285    ,   16913   ,   34005   ,0 };
            const std::uint32_t dim4543Kuo3Init[]   =   {   1   ,   3   ,   7   ,   5   ,   9   ,   37  ,   39  ,   173 ,   129 ,   215 ,   1939    ,   2745    ,   319 ,   12707   ,   4665    ,   32065   ,0 };
            const std::uint32_t dim4544Kuo3Init[]   =   {   1   ,   1   ,   3   ,   3   ,   21  ,   39  ,   67  ,   85  ,   223 ,   591 ,   681 ,   1655    ,   6651    ,   3547    ,   22459   ,   291 ,0 };
            const std::uint32_t dim4545Kuo3Init[]   =   {   1   ,   1   ,   7   ,   11  ,   17  ,   9   ,   61  ,   121 ,   489 ,   129 ,   489 ,   1261    ,   2377    ,   9243    ,   15123   ,   59249   ,0 };
            const std::uint32_t dim4546Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   1   ,   31  ,   1   ,   171 ,   331 ,   233 ,   1033    ,   1975    ,   1515    ,   13295   ,   9383    ,   52107   ,0 };
            const std::uint32_t dim4547Kuo3Init[]   =   {   1   ,   1   ,   1   ,   13  ,   17  ,   45  ,   75  ,   209 ,   187 ,   441 ,   1227    ,   4063    ,   5699    ,   3397    ,   25793   ,   58187   ,0 };
            const std::uint32_t dim4548Kuo3Init[]   =   {   1   ,   3   ,   1   ,   3   ,   17  ,   13  ,   67  ,   73  ,   141 ,   451 ,   1307    ,   3115    ,   1273    ,   5275    ,   32383   ,   4663    ,0 };
            const std::uint32_t dim4549Kuo3Init[]   =   {   1   ,   1   ,   5   ,   15  ,   5   ,   37  ,   77  ,   159 ,   339 ,   443 ,   1663    ,   345 ,   1513    ,   3195    ,   15131   ,   32473   ,0 };
            const std::uint32_t dim4550Kuo3Init[]   =   {   1   ,   1   ,   3   ,   11  ,   29  ,   19  ,   13  ,   47  ,   409 ,   141 ,   1907    ,   3473    ,   4799    ,   213 ,   341 ,   45091   ,0 };
            const std::uint32_t dim4551Kuo3Init[]   =   {   1   ,   3   ,   1   ,   1   ,   15  ,   29  ,   27  ,   179 ,   367 ,   439 ,   1073    ,   1783    ,   735 ,   11731   ,   20101   ,   7889    ,0 };
            const std::uint32_t dim4552Kuo3Init[]   =   {   1   ,   1   ,   3   ,   15  ,   23  ,   35  ,   107 ,   53  ,   325 ,   51  ,   831 ,   1693    ,   5161    ,   13655   ,   31957   ,   60089   ,0 };
            const std::uint32_t dim4553Kuo3Init[]   =   {   1   ,   1   ,   5   ,   11  ,   31  ,   13  ,   103 ,   109 ,   71  ,   237 ,   1271    ,   629 ,   6813    ,   10253   ,   17161   ,   58597   ,0 };
            const std::uint32_t dim4554Kuo3Init[]   =   {   1   ,   3   ,   3   ,   1   ,   29  ,   37  ,   47  ,   173 ,   131 ,   787 ,   39  ,   879 ,   215 ,   13625   ,   4031    ,   56677   ,0 };
            const std::uint32_t dim4555Kuo3Init[]   =   {   1   ,   1   ,   7   ,   5   ,   29  ,   3   ,   61  ,   227 ,   23  ,   699 ,   1291    ,   3909    ,   6995    ,   4085    ,   8961    ,   40275   ,0 };
            const std::uint32_t dim4556Kuo3Init[]   =   {   1   ,   1   ,   5   ,   7   ,   27  ,   21  ,   25  ,   213 ,   359 ,   701 ,   1453    ,   3753    ,   5493    ,   5971    ,   30375   ,   54707   ,0 };
            const std::uint32_t dim4557Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   7   ,   63  ,   67  ,   47  ,   341 ,   451 ,   1205    ,   3125    ,   1575    ,   6229    ,   13951   ,   4539    ,0 };
            const std::uint32_t dim4558Kuo3Init[]   =   {   1   ,   1   ,   3   ,   13  ,   25  ,   3   ,   93  ,   91  ,   507 ,   843 ,   623 ,   865 ,   5873    ,   10397   ,   4135    ,   11313   ,0 };
            const std::uint32_t dim4559Kuo3Init[]   =   {   1   ,   3   ,   7   ,   15  ,   11  ,   39  ,   111 ,   149 ,   439 ,   519 ,   1015    ,   2777    ,   1643    ,   9703    ,   13767   ,   7351    ,0 };
            const std::uint32_t dim4560Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   27  ,   55  ,   79  ,   39  ,   23  ,   451 ,   1507    ,   2117    ,   6881    ,   4623    ,   26289   ,   23435   ,0 };
            const std::uint32_t dim4561Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   27  ,   29  ,   21  ,   63  ,   229 ,   173 ,   1777    ,   2163    ,   5185    ,   15487   ,   19661   ,   49185   ,0 };
            const std::uint32_t dim4562Kuo3Init[]   =   {   1   ,   3   ,   1   ,   9   ,   3   ,   29  ,   59  ,   63  ,   477 ,   51  ,   1257    ,   2301    ,   3495    ,   9475    ,   32201   ,   47511   ,0 };
            const std::uint32_t dim4563Kuo3Init[]   =   {   1   ,   1   ,   1   ,   7   ,   29  ,   45  ,   115 ,   235 ,   201 ,   847 ,   57  ,   1783    ,   2203    ,   13077   ,   4917    ,   6773    ,0 };
            const std::uint32_t dim4564Kuo3Init[]   =   {   1   ,   1   ,   5   ,   9   ,   13  ,   49  ,   77  ,   1   ,   105 ,   747 ,   1389    ,   2461    ,   3823    ,   3315    ,   25295   ,   24761   ,0 };
            const std::uint32_t dim4565Kuo3Init[]   =   {   1   ,   3   ,   7   ,   7   ,   19  ,   5   ,   83  ,   157 ,   37  ,   499 ,   1893    ,   2787    ,   6427    ,   8575    ,   26547   ,   28871   ,0 };
            const std::uint32_t dim4566Kuo3Init[]   =   {   1   ,   1   ,   3   ,   9   ,   29  ,   47  ,   109 ,   151 ,   125 ,   1005    ,   751 ,   2059    ,   7045    ,   15483   ,   5227    ,   58193   ,0 };
            const std::uint32_t dim4567Kuo3Init[]   =   {   1   ,   1   ,   3   ,   1   ,   11  ,   41  ,   63  ,   155 ,   175 ,   943 ,   161 ,   889 ,   6001    ,   3537    ,   23609   ,   23595   ,0 };
            const std::uint32_t dim4568Kuo3Init[]   =   {   1   ,   3   ,   1   ,   11  ,   5   ,   51  ,   121 ,   11  ,   81  ,   175 ,   1953    ,   451 ,   4723    ,   11083   ,   26527   ,   41887   ,0 };
            const std::uint32_t dim4569Kuo3Init[]   =   {   1   ,   1   ,   3   ,   7   ,   13  ,   59  ,   47  ,   205 ,   503 ,   249 ,   1263    ,   1767    ,   2553    ,   9755    ,   909 ,   27129   ,0 };
            const std::uint32_t dim4570Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   11  ,   19  ,   123 ,   1   ,   429 ,   455 ,   85  ,   1021    ,   7119    ,   8563    ,   11115   ,   24741   ,0 };
            const std::uint32_t dim4571Kuo3Init[]   =   {   1   ,   1   ,   1   ,   1   ,   5   ,   55  ,   1   ,   1   ,   17  ,   221 ,   1633    ,   4065    ,   9   ,   4091    ,   29557   ,   33855   ,0 };
            const std::uint32_t dim4572Kuo3Init[]   =   {   1   ,   3   ,   3   ,   11  ,   9   ,   3   ,   15  ,   159 ,   243 ,   245 ,   1845    ,   3841    ,   3321    ,   8631    ,   1131    ,   7327    ,0 };
            const std::uint32_t dim4573Kuo3Init[]   =   {   1   ,   1   ,   5   ,   5   ,   3   ,   9   ,   119 ,   99  ,   337 ,   969 ,   1313    ,   4083    ,   2053    ,   10277   ,   15941   ,   16969   ,0 };
            const std::uint32_t dim4574Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   15  ,   35  ,   25  ,   239 ,   345 ,   785 ,   747 ,   233 ,   7175    ,   10319   ,   23783   ,   55803   ,0 };
            const std::uint32_t dim4575Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   7   ,   5   ,   91  ,   119 ,   317 ,   831 ,   351 ,   2149    ,   7531    ,   16373   ,   23461   ,   19863   ,0 };
            const std::uint32_t dim4576Kuo3Init[]   =   {   1   ,   1   ,   7   ,   1   ,   29  ,   7   ,   5   ,   43  ,   7   ,   717 ,   1459    ,   713 ,   5453    ,   7471    ,   12909   ,   36941   ,0 };
            const std::uint32_t dim4577Kuo3Init[]   =   {   1   ,   3   ,   5   ,   15  ,   9   ,   53  ,   59  ,   201 ,   333 ,   603 ,   629 ,   1819    ,   3397    ,   2823    ,   6459    ,   16213   ,0 };
            const std::uint32_t dim4578Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   27  ,   47  ,   67  ,   119 ,   145 ,   81  ,   507 ,   53  ,   7407    ,   6327    ,   11387   ,   45391   ,0 };
            const std::uint32_t dim4579Kuo3Init[]   =   {   1   ,   1   ,   7   ,   13  ,   7   ,   63  ,   53  ,   171 ,   381 ,   523 ,   825 ,   2785    ,   7077    ,   13601   ,   329 ,   26677   ,0 };
            const std::uint32_t dim4580Kuo3Init[]   =   {   1   ,   1   ,   5   ,   13  ,   7   ,   25  ,   91  ,   67  ,   267 ,   463 ,   1869    ,   2041    ,   5949    ,   1635    ,   21551   ,   37331   ,0 };
            const std::uint32_t dim4581Kuo3Init[]   =   {   1   ,   1   ,   1   ,   5   ,   25  ,   1   ,   17  ,   113 ,   445 ,   685 ,   1201    ,   3299    ,   8139    ,   1463    ,   26067   ,   14613   ,0 };
            const std::uint32_t dim4582Kuo3Init[]   =   {   1   ,   3   ,   1   ,   13  ,   3   ,   19  ,   103 ,   159 ,   337 ,   999 ,   755 ,   3935    ,   5161    ,   8681    ,   17375   ,   20163   ,0 };
            const std::uint32_t dim4583Kuo3Init[]   =   {   1   ,   3   ,   5   ,   9   ,   1   ,   13  ,   117 ,   209 ,   93  ,   613 ,   271 ,   1321    ,   2265    ,   2739    ,   5055    ,   27581   ,0 };
            const std::uint32_t dim4584Kuo3Init[]   =   {   1   ,   1   ,   1   ,   1   ,   7   ,   21  ,   111 ,   45  ,   361 ,   665 ,   1243    ,   1485    ,   7833    ,   15515   ,   26437   ,   55983   ,0 };
            const std::uint32_t dim4585Kuo3Init[]   =   {   1   ,   1   ,   5   ,   7   ,   1   ,   31  ,   123 ,   199 ,   347 ,   235 ,   1367    ,   2451    ,   7211    ,   6095    ,   19245   ,   55993   ,0 };
            const std::uint32_t dim4586Kuo3Init[]   =   {   1   ,   3   ,   7   ,   3   ,   25  ,   9   ,   25  ,   117 ,   315 ,   497 ,   1235    ,   1969    ,   7981    ,   9743    ,   20951   ,   30635   ,0 };

            const std::uint32_t * const Kuo3initializers[4586]
            =
            {
                dim1Kuo3Init,
                dim2Kuo3Init,
                dim3Kuo3Init,
                dim4Kuo3Init,
                dim5Kuo3Init,
                dim6Kuo3Init,
                dim7Kuo3Init,
                dim8Kuo3Init,
                dim9Kuo3Init,
                dim10Kuo3Init,
                dim11Kuo3Init,
                dim12Kuo3Init,
                dim13Kuo3Init,
                dim14Kuo3Init,
                dim15Kuo3Init,
                dim16Kuo3Init,
                dim17Kuo3Init,
                dim18Kuo3Init,
                dim19Kuo3Init,
                dim20Kuo3Init,
                dim21Kuo3Init,
                dim22Kuo3Init,
                dim23Kuo3Init,
                dim24Kuo3Init,
                dim25Kuo3Init,
                dim26Kuo3Init,
                dim27Kuo3Init,
                dim28Kuo3Init,
                dim29Kuo3Init,
                dim30Kuo3Init,
                dim31Kuo3Init,
                dim32Kuo3Init,
                dim33Kuo3Init,
                dim34Kuo3Init,
                dim35Kuo3Init,
                dim36Kuo3Init,
                dim37Kuo3Init,
                dim38Kuo3Init,
                dim39Kuo3Init,
                dim40Kuo3Init,
                dim41Kuo3Init,
                dim42Kuo3Init,
                dim43Kuo3Init,
                dim44Kuo3Init,
                dim45Kuo3Init,
                dim46Kuo3Init,
                dim47Kuo3Init,
                dim48Kuo3Init,
                dim49Kuo3Init,
                dim50Kuo3Init,
                dim51Kuo3Init,
                dim52Kuo3Init,
                dim53Kuo3Init,
                dim54Kuo3Init,
                dim55Kuo3Init,
                dim56Kuo3Init,
                dim57Kuo3Init,
                dim58Kuo3Init,
                dim59Kuo3Init,
                dim60Kuo3Init,
                dim61Kuo3Init,
                dim62Kuo3Init,
                dim63Kuo3Init,
                dim64Kuo3Init,
                dim65Kuo3Init,
                dim66Kuo3Init,
                dim67Kuo3Init,
                dim68Kuo3Init,
                dim69Kuo3Init,
                dim70Kuo3Init,
                dim71Kuo3Init,
                dim72Kuo3Init,
                dim73Kuo3Init,
                dim74Kuo3Init,
                dim75Kuo3Init,
                dim76Kuo3Init,
                dim77Kuo3Init,
                dim78Kuo3Init,
                dim79Kuo3Init,
                dim80Kuo3Init,
                dim81Kuo3Init,
                dim82Kuo3Init,
                dim83Kuo3Init,
                dim84Kuo3Init,
                dim85Kuo3Init,
                dim86Kuo3Init,
                dim87Kuo3Init,
                dim88Kuo3Init,
                dim89Kuo3Init,
                dim90Kuo3Init,
                dim91Kuo3Init,
                dim92Kuo3Init,
                dim93Kuo3Init,
                dim94Kuo3Init,
                dim95Kuo3Init,
                dim96Kuo3Init,
                dim97Kuo3Init,
                dim98Kuo3Init,
                dim99Kuo3Init,
                dim100Kuo3Init,
                dim101Kuo3Init,
                dim102Kuo3Init,
                dim103Kuo3Init,
                dim104Kuo3Init,
                dim105Kuo3Init,
                dim106Kuo3Init,
                dim107Kuo3Init,
                dim108Kuo3Init,
                dim109Kuo3Init,
                dim110Kuo3Init,
                dim111Kuo3Init,
                dim112Kuo3Init,
                dim113Kuo3Init,
                dim114Kuo3Init,
                dim115Kuo3Init,
                dim116Kuo3Init,
                dim117Kuo3Init,
                dim118Kuo3Init,
                dim119Kuo3Init,
                dim120Kuo3Init,
                dim121Kuo3Init,
                dim122Kuo3Init,
                dim123Kuo3Init,
                dim124Kuo3Init,
                dim125Kuo3Init,
                dim126Kuo3Init,
                dim127Kuo3Init,
                dim128Kuo3Init,
                dim129Kuo3Init,
                dim130Kuo3Init,
                dim131Kuo3Init,
                dim132Kuo3Init,
                dim133Kuo3Init,
                dim134Kuo3Init,
                dim135Kuo3Init,
                dim136Kuo3Init,
                dim137Kuo3Init,
                dim138Kuo3Init,
                dim139Kuo3Init,
                dim140Kuo3Init,
                dim141Kuo3Init,
                dim142Kuo3Init,
                dim143Kuo3Init,
                dim144Kuo3Init,
                dim145Kuo3Init,
                dim146Kuo3Init,
                dim147Kuo3Init,
                dim148Kuo3Init,
                dim149Kuo3Init,
                dim150Kuo3Init,
                dim151Kuo3Init,
                dim152Kuo3Init,
                dim153Kuo3Init,
                dim154Kuo3Init,
                dim155Kuo3Init,
                dim156Kuo3Init,
                dim157Kuo3Init,
                dim158Kuo3Init,
                dim159Kuo3Init,
                dim160Kuo3Init,
                dim161Kuo3Init,
                dim162Kuo3Init,
                dim163Kuo3Init,
                dim164Kuo3Init,
                dim165Kuo3Init,
                dim166Kuo3Init,
                dim167Kuo3Init,
                dim168Kuo3Init,
                dim169Kuo3Init,
                dim170Kuo3Init,
                dim171Kuo3Init,
                dim172Kuo3Init,
                dim173Kuo3Init,
                dim174Kuo3Init,
                dim175Kuo3Init,
                dim176Kuo3Init,
                dim177Kuo3Init,
                dim178Kuo3Init,
                dim179Kuo3Init,
                dim180Kuo3Init,
                dim181Kuo3Init,
                dim182Kuo3Init,
                dim183Kuo3Init,
                dim184Kuo3Init,
                dim185Kuo3Init,
                dim186Kuo3Init,
                dim187Kuo3Init,
                dim188Kuo3Init,
                dim189Kuo3Init,
                dim190Kuo3Init,
                dim191Kuo3Init,
                dim192Kuo3Init,
                dim193Kuo3Init,
                dim194Kuo3Init,
                dim195Kuo3Init,
                dim196Kuo3Init,
                dim197Kuo3Init,
                dim198Kuo3Init,
                dim199Kuo3Init,
                dim200Kuo3Init,
                dim201Kuo3Init,
                dim202Kuo3Init,
                dim203Kuo3Init,
                dim204Kuo3Init,
                dim205Kuo3Init,
                dim206Kuo3Init,
                dim207Kuo3Init,
                dim208Kuo3Init,
                dim209Kuo3Init,
                dim210Kuo3Init,
                dim211Kuo3Init,
                dim212Kuo3Init,
                dim213Kuo3Init,
                dim214Kuo3Init,
                dim215Kuo3Init,
                dim216Kuo3Init,
                dim217Kuo3Init,
                dim218Kuo3Init,
                dim219Kuo3Init,
                dim220Kuo3Init,
                dim221Kuo3Init,
                dim222Kuo3Init,
                dim223Kuo3Init,
                dim224Kuo3Init,
                dim225Kuo3Init,
                dim226Kuo3Init,
                dim227Kuo3Init,
                dim228Kuo3Init,
                dim229Kuo3Init,
                dim230Kuo3Init,
                dim231Kuo3Init,
                dim232Kuo3Init,
                dim233Kuo3Init,
                dim234Kuo3Init,
                dim235Kuo3Init,
                dim236Kuo3Init,
                dim237Kuo3Init,
                dim238Kuo3Init,
                dim239Kuo3Init,
                dim240Kuo3Init,
                dim241Kuo3Init,
                dim242Kuo3Init,
                dim243Kuo3Init,
                dim244Kuo3Init,
                dim245Kuo3Init,
                dim246Kuo3Init,
                dim247Kuo3Init,
                dim248Kuo3Init,
                dim249Kuo3Init,
                dim250Kuo3Init,
                dim251Kuo3Init,
                dim252Kuo3Init,
                dim253Kuo3Init,
                dim254Kuo3Init,
                dim255Kuo3Init,
                dim256Kuo3Init,
                dim257Kuo3Init,
                dim258Kuo3Init,
                dim259Kuo3Init,
                dim260Kuo3Init,
                dim261Kuo3Init,
                dim262Kuo3Init,
                dim263Kuo3Init,
                dim264Kuo3Init,
                dim265Kuo3Init,
                dim266Kuo3Init,
                dim267Kuo3Init,
                dim268Kuo3Init,
                dim269Kuo3Init,
                dim270Kuo3Init,
                dim271Kuo3Init,
                dim272Kuo3Init,
                dim273Kuo3Init,
                dim274Kuo3Init,
                dim275Kuo3Init,
                dim276Kuo3Init,
                dim277Kuo3Init,
                dim278Kuo3Init,
                dim279Kuo3Init,
                dim280Kuo3Init,
                dim281Kuo3Init,
                dim282Kuo3Init,
                dim283Kuo3Init,
                dim284Kuo3Init,
                dim285Kuo3Init,
                dim286Kuo3Init,
                dim287Kuo3Init,
                dim288Kuo3Init,
                dim289Kuo3Init,
                dim290Kuo3Init,
                dim291Kuo3Init,
                dim292Kuo3Init,
                dim293Kuo3Init,
                dim294Kuo3Init,
                dim295Kuo3Init,
                dim296Kuo3Init,
                dim297Kuo3Init,
                dim298Kuo3Init,
                dim299Kuo3Init,
                dim300Kuo3Init,
                dim301Kuo3Init,
                dim302Kuo3Init,
                dim303Kuo3Init,
                dim304Kuo3Init,
                dim305Kuo3Init,
                dim306Kuo3Init,
                dim307Kuo3Init,
                dim308Kuo3Init,
                dim309Kuo3Init,
                dim310Kuo3Init,
                dim311Kuo3Init,
                dim312Kuo3Init,
                dim313Kuo3Init,
                dim314Kuo3Init,
                dim315Kuo3Init,
                dim316Kuo3Init,
                dim317Kuo3Init,
                dim318Kuo3Init,
                dim319Kuo3Init,
                dim320Kuo3Init,
                dim321Kuo3Init,
                dim322Kuo3Init,
                dim323Kuo3Init,
                dim324Kuo3Init,
                dim325Kuo3Init,
                dim326Kuo3Init,
                dim327Kuo3Init,
                dim328Kuo3Init,
                dim329Kuo3Init,
                dim330Kuo3Init,
                dim331Kuo3Init,
                dim332Kuo3Init,
                dim333Kuo3Init,
                dim334Kuo3Init,
                dim335Kuo3Init,
                dim336Kuo3Init,
                dim337Kuo3Init,
                dim338Kuo3Init,
                dim339Kuo3Init,
                dim340Kuo3Init,
                dim341Kuo3Init,
                dim342Kuo3Init,
                dim343Kuo3Init,
                dim344Kuo3Init,
                dim345Kuo3Init,
                dim346Kuo3Init,
                dim347Kuo3Init,
                dim348Kuo3Init,
                dim349Kuo3Init,
                dim350Kuo3Init,
                dim351Kuo3Init,
                dim352Kuo3Init,
                dim353Kuo3Init,
                dim354Kuo3Init,
                dim355Kuo3Init,
                dim356Kuo3Init,
                dim357Kuo3Init,
                dim358Kuo3Init,
                dim359Kuo3Init,
                dim360Kuo3Init,
                dim361Kuo3Init,
                dim362Kuo3Init,
                dim363Kuo3Init,
                dim364Kuo3Init,
                dim365Kuo3Init,
                dim366Kuo3Init,
                dim367Kuo3Init,
                dim368Kuo3Init,
                dim369Kuo3Init,
                dim370Kuo3Init,
                dim371Kuo3Init,
                dim372Kuo3Init,
                dim373Kuo3Init,
                dim374Kuo3Init,
                dim375Kuo3Init,
                dim376Kuo3Init,
                dim377Kuo3Init,
                dim378Kuo3Init,
                dim379Kuo3Init,
                dim380Kuo3Init,
                dim381Kuo3Init,
                dim382Kuo3Init,
                dim383Kuo3Init,
                dim384Kuo3Init,
                dim385Kuo3Init,
                dim386Kuo3Init,
                dim387Kuo3Init,
                dim388Kuo3Init,
                dim389Kuo3Init,
                dim390Kuo3Init,
                dim391Kuo3Init,
                dim392Kuo3Init,
                dim393Kuo3Init,
                dim394Kuo3Init,
                dim395Kuo3Init,
                dim396Kuo3Init,
                dim397Kuo3Init,
                dim398Kuo3Init,
                dim399Kuo3Init,
                dim400Kuo3Init,
                dim401Kuo3Init,
                dim402Kuo3Init,
                dim403Kuo3Init,
                dim404Kuo3Init,
                dim405Kuo3Init,
                dim406Kuo3Init,
                dim407Kuo3Init,
                dim408Kuo3Init,
                dim409Kuo3Init,
                dim410Kuo3Init,
                dim411Kuo3Init,
                dim412Kuo3Init,
                dim413Kuo3Init,
                dim414Kuo3Init,
                dim415Kuo3Init,
                dim416Kuo3Init,
                dim417Kuo3Init,
                dim418Kuo3Init,
                dim419Kuo3Init,
                dim420Kuo3Init,
                dim421Kuo3Init,
                dim422Kuo3Init,
                dim423Kuo3Init,
                dim424Kuo3Init,
                dim425Kuo3Init,
                dim426Kuo3Init,
                dim427Kuo3Init,
                dim428Kuo3Init,
                dim429Kuo3Init,
                dim430Kuo3Init,
                dim431Kuo3Init,
                dim432Kuo3Init,
                dim433Kuo3Init,
                dim434Kuo3Init,
                dim435Kuo3Init,
                dim436Kuo3Init,
                dim437Kuo3Init,
                dim438Kuo3Init,
                dim439Kuo3Init,
                dim440Kuo3Init,
                dim441Kuo3Init,
                dim442Kuo3Init,
                dim443Kuo3Init,
                dim444Kuo3Init,
                dim445Kuo3Init,
                dim446Kuo3Init,
                dim447Kuo3Init,
                dim448Kuo3Init,
                dim449Kuo3Init,
                dim450Kuo3Init,
                dim451Kuo3Init,
                dim452Kuo3Init,
                dim453Kuo3Init,
                dim454Kuo3Init,
                dim455Kuo3Init,
                dim456Kuo3Init,
                dim457Kuo3Init,
                dim458Kuo3Init,
                dim459Kuo3Init,
                dim460Kuo3Init,
                dim461Kuo3Init,
                dim462Kuo3Init,
                dim463Kuo3Init,
                dim464Kuo3Init,
                dim465Kuo3Init,
                dim466Kuo3Init,
                dim467Kuo3Init,
                dim468Kuo3Init,
                dim469Kuo3Init,
                dim470Kuo3Init,
                dim471Kuo3Init,
                dim472Kuo3Init,
                dim473Kuo3Init,
                dim474Kuo3Init,
                dim475Kuo3Init,
                dim476Kuo3Init,
                dim477Kuo3Init,
                dim478Kuo3Init,
                dim479Kuo3Init,
                dim480Kuo3Init,
                dim481Kuo3Init,
                dim482Kuo3Init,
                dim483Kuo3Init,
                dim484Kuo3Init,
                dim485Kuo3Init,
                dim486Kuo3Init,
                dim487Kuo3Init,
                dim488Kuo3Init,
                dim489Kuo3Init,
                dim490Kuo3Init,
                dim491Kuo3Init,
                dim492Kuo3Init,
                dim493Kuo3Init,
                dim494Kuo3Init,
                dim495Kuo3Init,
                dim496Kuo3Init,
                dim497Kuo3Init,
                dim498Kuo3Init,
                dim499Kuo3Init,
                dim500Kuo3Init,
                dim501Kuo3Init,
                dim502Kuo3Init,
                dim503Kuo3Init,
                dim504Kuo3Init,
                dim505Kuo3Init,
                dim506Kuo3Init,
                dim507Kuo3Init,
                dim508Kuo3Init,
                dim509Kuo3Init,
                dim510Kuo3Init,
                dim511Kuo3Init,
                dim512Kuo3Init,
                dim513Kuo3Init,
                dim514Kuo3Init,
                dim515Kuo3Init,
                dim516Kuo3Init,
                dim517Kuo3Init,
                dim518Kuo3Init,
                dim519Kuo3Init,
                dim520Kuo3Init,
                dim521Kuo3Init,
                dim522Kuo3Init,
                dim523Kuo3Init,
                dim524Kuo3Init,
                dim525Kuo3Init,
                dim526Kuo3Init,
                dim527Kuo3Init,
                dim528Kuo3Init,
                dim529Kuo3Init,
                dim530Kuo3Init,
                dim531Kuo3Init,
                dim532Kuo3Init,
                dim533Kuo3Init,
                dim534Kuo3Init,
                dim535Kuo3Init,
                dim536Kuo3Init,
                dim537Kuo3Init,
                dim538Kuo3Init,
                dim539Kuo3Init,
                dim540Kuo3Init,
                dim541Kuo3Init,
                dim542Kuo3Init,
                dim543Kuo3Init,
                dim544Kuo3Init,
                dim545Kuo3Init,
                dim546Kuo3Init,
                dim547Kuo3Init,
                dim548Kuo3Init,
                dim549Kuo3Init,
                dim550Kuo3Init,
                dim551Kuo3Init,
                dim552Kuo3Init,
                dim553Kuo3Init,
                dim554Kuo3Init,
                dim555Kuo3Init,
                dim556Kuo3Init,
                dim557Kuo3Init,
                dim558Kuo3Init,
                dim559Kuo3Init,
                dim560Kuo3Init,
                dim561Kuo3Init,
                dim562Kuo3Init,
                dim563Kuo3Init,
                dim564Kuo3Init,
                dim565Kuo3Init,
                dim566Kuo3Init,
                dim567Kuo3Init,
                dim568Kuo3Init,
                dim569Kuo3Init,
                dim570Kuo3Init,
                dim571Kuo3Init,
                dim572Kuo3Init,
                dim573Kuo3Init,
                dim574Kuo3Init,
                dim575Kuo3Init,
                dim576Kuo3Init,
                dim577Kuo3Init,
                dim578Kuo3Init,
                dim579Kuo3Init,
                dim580Kuo3Init,
                dim581Kuo3Init,
                dim582Kuo3Init,
                dim583Kuo3Init,
                dim584Kuo3Init,
                dim585Kuo3Init,
                dim586Kuo3Init,
                dim587Kuo3Init,
                dim588Kuo3Init,
                dim589Kuo3Init,
                dim590Kuo3Init,
                dim591Kuo3Init,
                dim592Kuo3Init,
                dim593Kuo3Init,
                dim594Kuo3Init,
                dim595Kuo3Init,
                dim596Kuo3Init,
                dim597Kuo3Init,
                dim598Kuo3Init,
                dim599Kuo3Init,
                dim600Kuo3Init,
                dim601Kuo3Init,
                dim602Kuo3Init,
                dim603Kuo3Init,
                dim604Kuo3Init,
                dim605Kuo3Init,
                dim606Kuo3Init,
                dim607Kuo3Init,
                dim608Kuo3Init,
                dim609Kuo3Init,
                dim610Kuo3Init,
                dim611Kuo3Init,
                dim612Kuo3Init,
                dim613Kuo3Init,
                dim614Kuo3Init,
                dim615Kuo3Init,
                dim616Kuo3Init,
                dim617Kuo3Init,
                dim618Kuo3Init,
                dim619Kuo3Init,
                dim620Kuo3Init,
                dim621Kuo3Init,
                dim622Kuo3Init,
                dim623Kuo3Init,
                dim624Kuo3Init,
                dim625Kuo3Init,
                dim626Kuo3Init,
                dim627Kuo3Init,
                dim628Kuo3Init,
                dim629Kuo3Init,
                dim630Kuo3Init,
                dim631Kuo3Init,
                dim632Kuo3Init,
                dim633Kuo3Init,
                dim634Kuo3Init,
                dim635Kuo3Init,
                dim636Kuo3Init,
                dim637Kuo3Init,
                dim638Kuo3Init,
                dim639Kuo3Init,
                dim640Kuo3Init,
                dim641Kuo3Init,
                dim642Kuo3Init,
                dim643Kuo3Init,
                dim644Kuo3Init,
                dim645Kuo3Init,
                dim646Kuo3Init,
                dim647Kuo3Init,
                dim648Kuo3Init,
                dim649Kuo3Init,
                dim650Kuo3Init,
                dim651Kuo3Init,
                dim652Kuo3Init,
                dim653Kuo3Init,
                dim654Kuo3Init,
                dim655Kuo3Init,
                dim656Kuo3Init,
                dim657Kuo3Init,
                dim658Kuo3Init,
                dim659Kuo3Init,
                dim660Kuo3Init,
                dim661Kuo3Init,
                dim662Kuo3Init,
                dim663Kuo3Init,
                dim664Kuo3Init,
                dim665Kuo3Init,
                dim666Kuo3Init,
                dim667Kuo3Init,
                dim668Kuo3Init,
                dim669Kuo3Init,
                dim670Kuo3Init,
                dim671Kuo3Init,
                dim672Kuo3Init,
                dim673Kuo3Init,
                dim674Kuo3Init,
                dim675Kuo3Init,
                dim676Kuo3Init,
                dim677Kuo3Init,
                dim678Kuo3Init,
                dim679Kuo3Init,
                dim680Kuo3Init,
                dim681Kuo3Init,
                dim682Kuo3Init,
                dim683Kuo3Init,
                dim684Kuo3Init,
                dim685Kuo3Init,
                dim686Kuo3Init,
                dim687Kuo3Init,
                dim688Kuo3Init,
                dim689Kuo3Init,
                dim690Kuo3Init,
                dim691Kuo3Init,
                dim692Kuo3Init,
                dim693Kuo3Init,
                dim694Kuo3Init,
                dim695Kuo3Init,
                dim696Kuo3Init,
                dim697Kuo3Init,
                dim698Kuo3Init,
                dim699Kuo3Init,
                dim700Kuo3Init,
                dim701Kuo3Init,
                dim702Kuo3Init,
                dim703Kuo3Init,
                dim704Kuo3Init,
                dim705Kuo3Init,
                dim706Kuo3Init,
                dim707Kuo3Init,
                dim708Kuo3Init,
                dim709Kuo3Init,
                dim710Kuo3Init,
                dim711Kuo3Init,
                dim712Kuo3Init,
                dim713Kuo3Init,
                dim714Kuo3Init,
                dim715Kuo3Init,
                dim716Kuo3Init,
                dim717Kuo3Init,
                dim718Kuo3Init,
                dim719Kuo3Init,
                dim720Kuo3Init,
                dim721Kuo3Init,
                dim722Kuo3Init,
                dim723Kuo3Init,
                dim724Kuo3Init,
                dim725Kuo3Init,
                dim726Kuo3Init,
                dim727Kuo3Init,
                dim728Kuo3Init,
                dim729Kuo3Init,
                dim730Kuo3Init,
                dim731Kuo3Init,
                dim732Kuo3Init,
                dim733Kuo3Init,
                dim734Kuo3Init,
                dim735Kuo3Init,
                dim736Kuo3Init,
                dim737Kuo3Init,
                dim738Kuo3Init,
                dim739Kuo3Init,
                dim740Kuo3Init,
                dim741Kuo3Init,
                dim742Kuo3Init,
                dim743Kuo3Init,
                dim744Kuo3Init,
                dim745Kuo3Init,
                dim746Kuo3Init,
                dim747Kuo3Init,
                dim748Kuo3Init,
                dim749Kuo3Init,
                dim750Kuo3Init,
                dim751Kuo3Init,
                dim752Kuo3Init,
                dim753Kuo3Init,
                dim754Kuo3Init,
                dim755Kuo3Init,
                dim756Kuo3Init,
                dim757Kuo3Init,
                dim758Kuo3Init,
                dim759Kuo3Init,
                dim760Kuo3Init,
                dim761Kuo3Init,
                dim762Kuo3Init,
                dim763Kuo3Init,
                dim764Kuo3Init,
                dim765Kuo3Init,
                dim766Kuo3Init,
                dim767Kuo3Init,
                dim768Kuo3Init,
                dim769Kuo3Init,
                dim770Kuo3Init,
                dim771Kuo3Init,
                dim772Kuo3Init,
                dim773Kuo3Init,
                dim774Kuo3Init,
                dim775Kuo3Init,
                dim776Kuo3Init,
                dim777Kuo3Init,
                dim778Kuo3Init,
                dim779Kuo3Init,
                dim780Kuo3Init,
                dim781Kuo3Init,
                dim782Kuo3Init,
                dim783Kuo3Init,
                dim784Kuo3Init,
                dim785Kuo3Init,
                dim786Kuo3Init,
                dim787Kuo3Init,
                dim788Kuo3Init,
                dim789Kuo3Init,
                dim790Kuo3Init,
                dim791Kuo3Init,
                dim792Kuo3Init,
                dim793Kuo3Init,
                dim794Kuo3Init,
                dim795Kuo3Init,
                dim796Kuo3Init,
                dim797Kuo3Init,
                dim798Kuo3Init,
                dim799Kuo3Init,
                dim800Kuo3Init,
                dim801Kuo3Init,
                dim802Kuo3Init,
                dim803Kuo3Init,
                dim804Kuo3Init,
                dim805Kuo3Init,
                dim806Kuo3Init,
                dim807Kuo3Init,
                dim808Kuo3Init,
                dim809Kuo3Init,
                dim810Kuo3Init,
                dim811Kuo3Init,
                dim812Kuo3Init,
                dim813Kuo3Init,
                dim814Kuo3Init,
                dim815Kuo3Init,
                dim816Kuo3Init,
                dim817Kuo3Init,
                dim818Kuo3Init,
                dim819Kuo3Init,
                dim820Kuo3Init,
                dim821Kuo3Init,
                dim822Kuo3Init,
                dim823Kuo3Init,
                dim824Kuo3Init,
                dim825Kuo3Init,
                dim826Kuo3Init,
                dim827Kuo3Init,
                dim828Kuo3Init,
                dim829Kuo3Init,
                dim830Kuo3Init,
                dim831Kuo3Init,
                dim832Kuo3Init,
                dim833Kuo3Init,
                dim834Kuo3Init,
                dim835Kuo3Init,
                dim836Kuo3Init,
                dim837Kuo3Init,
                dim838Kuo3Init,
                dim839Kuo3Init,
                dim840Kuo3Init,
                dim841Kuo3Init,
                dim842Kuo3Init,
                dim843Kuo3Init,
                dim844Kuo3Init,
                dim845Kuo3Init,
                dim846Kuo3Init,
                dim847Kuo3Init,
                dim848Kuo3Init,
                dim849Kuo3Init,
                dim850Kuo3Init,
                dim851Kuo3Init,
                dim852Kuo3Init,
                dim853Kuo3Init,
                dim854Kuo3Init,
                dim855Kuo3Init,
                dim856Kuo3Init,
                dim857Kuo3Init,
                dim858Kuo3Init,
                dim859Kuo3Init,
                dim860Kuo3Init,
                dim861Kuo3Init,
                dim862Kuo3Init,
                dim863Kuo3Init,
                dim864Kuo3Init,
                dim865Kuo3Init,
                dim866Kuo3Init,
                dim867Kuo3Init,
                dim868Kuo3Init,
                dim869Kuo3Init,
                dim870Kuo3Init,
                dim871Kuo3Init,
                dim872Kuo3Init,
                dim873Kuo3Init,
                dim874Kuo3Init,
                dim875Kuo3Init,
                dim876Kuo3Init,
                dim877Kuo3Init,
                dim878Kuo3Init,
                dim879Kuo3Init,
                dim880Kuo3Init,
                dim881Kuo3Init,
                dim882Kuo3Init,
                dim883Kuo3Init,
                dim884Kuo3Init,
                dim885Kuo3Init,
                dim886Kuo3Init,
                dim887Kuo3Init,
                dim888Kuo3Init,
                dim889Kuo3Init,
                dim890Kuo3Init,
                dim891Kuo3Init,
                dim892Kuo3Init,
                dim893Kuo3Init,
                dim894Kuo3Init,
                dim895Kuo3Init,
                dim896Kuo3Init,
                dim897Kuo3Init,
                dim898Kuo3Init,
                dim899Kuo3Init,
                dim900Kuo3Init,
                dim901Kuo3Init,
                dim902Kuo3Init,
                dim903Kuo3Init,
                dim904Kuo3Init,
                dim905Kuo3Init,
                dim906Kuo3Init,
                dim907Kuo3Init,
                dim908Kuo3Init,
                dim909Kuo3Init,
                dim910Kuo3Init,
                dim911Kuo3Init,
                dim912Kuo3Init,
                dim913Kuo3Init,
                dim914Kuo3Init,
                dim915Kuo3Init,
                dim916Kuo3Init,
                dim917Kuo3Init,
                dim918Kuo3Init,
                dim919Kuo3Init,
                dim920Kuo3Init,
                dim921Kuo3Init,
                dim922Kuo3Init,
                dim923Kuo3Init,
                dim924Kuo3Init,
                dim925Kuo3Init,
                dim926Kuo3Init,
                dim927Kuo3Init,
                dim928Kuo3Init,
                dim929Kuo3Init,
                dim930Kuo3Init,
                dim931Kuo3Init,
                dim932Kuo3Init,
                dim933Kuo3Init,
                dim934Kuo3Init,
                dim935Kuo3Init,
                dim936Kuo3Init,
                dim937Kuo3Init,
                dim938Kuo3Init,
                dim939Kuo3Init,
                dim940Kuo3Init,
                dim941Kuo3Init,
                dim942Kuo3Init,
                dim943Kuo3Init,
                dim944Kuo3Init,
                dim945Kuo3Init,
                dim946Kuo3Init,
                dim947Kuo3Init,
                dim948Kuo3Init,
                dim949Kuo3Init,
                dim950Kuo3Init,
                dim951Kuo3Init,
                dim952Kuo3Init,
                dim953Kuo3Init,
                dim954Kuo3Init,
                dim955Kuo3Init,
                dim956Kuo3Init,
                dim957Kuo3Init,
                dim958Kuo3Init,
                dim959Kuo3Init,
                dim960Kuo3Init,
                dim961Kuo3Init,
                dim962Kuo3Init,
                dim963Kuo3Init,
                dim964Kuo3Init,
                dim965Kuo3Init,
                dim966Kuo3Init,
                dim967Kuo3Init,
                dim968Kuo3Init,
                dim969Kuo3Init,
                dim970Kuo3Init,
                dim971Kuo3Init,
                dim972Kuo3Init,
                dim973Kuo3Init,
                dim974Kuo3Init,
                dim975Kuo3Init,
                dim976Kuo3Init,
                dim977Kuo3Init,
                dim978Kuo3Init,
                dim979Kuo3Init,
                dim980Kuo3Init,
                dim981Kuo3Init,
                dim982Kuo3Init,
                dim983Kuo3Init,
                dim984Kuo3Init,
                dim985Kuo3Init,
                dim986Kuo3Init,
                dim987Kuo3Init,
                dim988Kuo3Init,
                dim989Kuo3Init,
                dim990Kuo3Init,
                dim991Kuo3Init,
                dim992Kuo3Init,
                dim993Kuo3Init,
                dim994Kuo3Init,
                dim995Kuo3Init,
                dim996Kuo3Init,
                dim997Kuo3Init,
                dim998Kuo3Init,
                dim999Kuo3Init,
                dim1000Kuo3Init,
                dim1001Kuo3Init,
                dim1002Kuo3Init,
                dim1003Kuo3Init,
                dim1004Kuo3Init,
                dim1005Kuo3Init,
                dim1006Kuo3Init,
                dim1007Kuo3Init,
                dim1008Kuo3Init,
                dim1009Kuo3Init,
                dim1010Kuo3Init,
                dim1011Kuo3Init,
                dim1012Kuo3Init,
                dim1013Kuo3Init,
                dim1014Kuo3Init,
                dim1015Kuo3Init,
                dim1016Kuo3Init,
                dim1017Kuo3Init,
                dim1018Kuo3Init,
                dim1019Kuo3Init,
                dim1020Kuo3Init,
                dim1021Kuo3Init,
                dim1022Kuo3Init,
                dim1023Kuo3Init,
                dim1024Kuo3Init,
                dim1025Kuo3Init,
                dim1026Kuo3Init,
                dim1027Kuo3Init,
                dim1028Kuo3Init,
                dim1029Kuo3Init,
                dim1030Kuo3Init,
                dim1031Kuo3Init,
                dim1032Kuo3Init,
                dim1033Kuo3Init,
                dim1034Kuo3Init,
                dim1035Kuo3Init,
                dim1036Kuo3Init,
                dim1037Kuo3Init,
                dim1038Kuo3Init,
                dim1039Kuo3Init,
                dim1040Kuo3Init,
                dim1041Kuo3Init,
                dim1042Kuo3Init,
                dim1043Kuo3Init,
                dim1044Kuo3Init,
                dim1045Kuo3Init,
                dim1046Kuo3Init,
                dim1047Kuo3Init,
                dim1048Kuo3Init,
                dim1049Kuo3Init,
                dim1050Kuo3Init,
                dim1051Kuo3Init,
                dim1052Kuo3Init,
                dim1053Kuo3Init,
                dim1054Kuo3Init,
                dim1055Kuo3Init,
                dim1056Kuo3Init,
                dim1057Kuo3Init,
                dim1058Kuo3Init,
                dim1059Kuo3Init,
                dim1060Kuo3Init,
                dim1061Kuo3Init,
                dim1062Kuo3Init,
                dim1063Kuo3Init,
                dim1064Kuo3Init,
                dim1065Kuo3Init,
                dim1066Kuo3Init,
                dim1067Kuo3Init,
                dim1068Kuo3Init,
                dim1069Kuo3Init,
                dim1070Kuo3Init,
                dim1071Kuo3Init,
                dim1072Kuo3Init,
                dim1073Kuo3Init,
                dim1074Kuo3Init,
                dim1075Kuo3Init,
                dim1076Kuo3Init,
                dim1077Kuo3Init,
                dim1078Kuo3Init,
                dim1079Kuo3Init,
                dim1080Kuo3Init,
                dim1081Kuo3Init,
                dim1082Kuo3Init,
                dim1083Kuo3Init,
                dim1084Kuo3Init,
                dim1085Kuo3Init,
                dim1086Kuo3Init,
                dim1087Kuo3Init,
                dim1088Kuo3Init,
                dim1089Kuo3Init,
                dim1090Kuo3Init,
                dim1091Kuo3Init,
                dim1092Kuo3Init,
                dim1093Kuo3Init,
                dim1094Kuo3Init,
                dim1095Kuo3Init,
                dim1096Kuo3Init,
                dim1097Kuo3Init,
                dim1098Kuo3Init,
                dim1099Kuo3Init,
                dim1100Kuo3Init,
                dim1101Kuo3Init,
                dim1102Kuo3Init,
                dim1103Kuo3Init,
                dim1104Kuo3Init,
                dim1105Kuo3Init,
                dim1106Kuo3Init,
                dim1107Kuo3Init,
                dim1108Kuo3Init,
                dim1109Kuo3Init,
                dim1110Kuo3Init,
                dim1111Kuo3Init,
                dim1112Kuo3Init,
                dim1113Kuo3Init,
                dim1114Kuo3Init,
                dim1115Kuo3Init,
                dim1116Kuo3Init,
                dim1117Kuo3Init,
                dim1118Kuo3Init,
                dim1119Kuo3Init,
                dim1120Kuo3Init,
                dim1121Kuo3Init,
                dim1122Kuo3Init,
                dim1123Kuo3Init,
                dim1124Kuo3Init,
                dim1125Kuo3Init,
                dim1126Kuo3Init,
                dim1127Kuo3Init,
                dim1128Kuo3Init,
                dim1129Kuo3Init,
                dim1130Kuo3Init,
                dim1131Kuo3Init,
                dim1132Kuo3Init,
                dim1133Kuo3Init,
                dim1134Kuo3Init,
                dim1135Kuo3Init,
                dim1136Kuo3Init,
                dim1137Kuo3Init,
                dim1138Kuo3Init,
                dim1139Kuo3Init,
                dim1140Kuo3Init,
                dim1141Kuo3Init,
                dim1142Kuo3Init,
                dim1143Kuo3Init,
                dim1144Kuo3Init,
                dim1145Kuo3Init,
                dim1146Kuo3Init,
                dim1147Kuo3Init,
                dim1148Kuo3Init,
                dim1149Kuo3Init,
                dim1150Kuo3Init,
                dim1151Kuo3Init,
                dim1152Kuo3Init,
                dim1153Kuo3Init,
                dim1154Kuo3Init,
                dim1155Kuo3Init,
                dim1156Kuo3Init,
                dim1157Kuo3Init,
                dim1158Kuo3Init,
                dim1159Kuo3Init,
                dim1160Kuo3Init,
                dim1161Kuo3Init,
                dim1162Kuo3Init,
                dim1163Kuo3Init,
                dim1164Kuo3Init,
                dim1165Kuo3Init,
                dim1166Kuo3Init,
                dim1167Kuo3Init,
                dim1168Kuo3Init,
                dim1169Kuo3Init,
                dim1170Kuo3Init,
                dim1171Kuo3Init,
                dim1172Kuo3Init,
                dim1173Kuo3Init,
                dim1174Kuo3Init,
                dim1175Kuo3Init,
                dim1176Kuo3Init,
                dim1177Kuo3Init,
                dim1178Kuo3Init,
                dim1179Kuo3Init,
                dim1180Kuo3Init,
                dim1181Kuo3Init,
                dim1182Kuo3Init,
                dim1183Kuo3Init,
                dim1184Kuo3Init,
                dim1185Kuo3Init,
                dim1186Kuo3Init,
                dim1187Kuo3Init,
                dim1188Kuo3Init,
                dim1189Kuo3Init,
                dim1190Kuo3Init,
                dim1191Kuo3Init,
                dim1192Kuo3Init,
                dim1193Kuo3Init,
                dim1194Kuo3Init,
                dim1195Kuo3Init,
                dim1196Kuo3Init,
                dim1197Kuo3Init,
                dim1198Kuo3Init,
                dim1199Kuo3Init,
                dim1200Kuo3Init,
                dim1201Kuo3Init,
                dim1202Kuo3Init,
                dim1203Kuo3Init,
                dim1204Kuo3Init,
                dim1205Kuo3Init,
                dim1206Kuo3Init,
                dim1207Kuo3Init,
                dim1208Kuo3Init,
                dim1209Kuo3Init,
                dim1210Kuo3Init,
                dim1211Kuo3Init,
                dim1212Kuo3Init,
                dim1213Kuo3Init,
                dim1214Kuo3Init,
                dim1215Kuo3Init,
                dim1216Kuo3Init,
                dim1217Kuo3Init,
                dim1218Kuo3Init,
                dim1219Kuo3Init,
                dim1220Kuo3Init,
                dim1221Kuo3Init,
                dim1222Kuo3Init,
                dim1223Kuo3Init,
                dim1224Kuo3Init,
                dim1225Kuo3Init,
                dim1226Kuo3Init,
                dim1227Kuo3Init,
                dim1228Kuo3Init,
                dim1229Kuo3Init,
                dim1230Kuo3Init,
                dim1231Kuo3Init,
                dim1232Kuo3Init,
                dim1233Kuo3Init,
                dim1234Kuo3Init,
                dim1235Kuo3Init,
                dim1236Kuo3Init,
                dim1237Kuo3Init,
                dim1238Kuo3Init,
                dim1239Kuo3Init,
                dim1240Kuo3Init,
                dim1241Kuo3Init,
                dim1242Kuo3Init,
                dim1243Kuo3Init,
                dim1244Kuo3Init,
                dim1245Kuo3Init,
                dim1246Kuo3Init,
                dim1247Kuo3Init,
                dim1248Kuo3Init,
                dim1249Kuo3Init,
                dim1250Kuo3Init,
                dim1251Kuo3Init,
                dim1252Kuo3Init,
                dim1253Kuo3Init,
                dim1254Kuo3Init,
                dim1255Kuo3Init,
                dim1256Kuo3Init,
                dim1257Kuo3Init,
                dim1258Kuo3Init,
                dim1259Kuo3Init,
                dim1260Kuo3Init,
                dim1261Kuo3Init,
                dim1262Kuo3Init,
                dim1263Kuo3Init,
                dim1264Kuo3Init,
                dim1265Kuo3Init,
                dim1266Kuo3Init,
                dim1267Kuo3Init,
                dim1268Kuo3Init,
                dim1269Kuo3Init,
                dim1270Kuo3Init,
                dim1271Kuo3Init,
                dim1272Kuo3Init,
                dim1273Kuo3Init,
                dim1274Kuo3Init,
                dim1275Kuo3Init,
                dim1276Kuo3Init,
                dim1277Kuo3Init,
                dim1278Kuo3Init,
                dim1279Kuo3Init,
                dim1280Kuo3Init,
                dim1281Kuo3Init,
                dim1282Kuo3Init,
                dim1283Kuo3Init,
                dim1284Kuo3Init,
                dim1285Kuo3Init,
                dim1286Kuo3Init,
                dim1287Kuo3Init,
                dim1288Kuo3Init,
                dim1289Kuo3Init,
                dim1290Kuo3Init,
                dim1291Kuo3Init,
                dim1292Kuo3Init,
                dim1293Kuo3Init,
                dim1294Kuo3Init,
                dim1295Kuo3Init,
                dim1296Kuo3Init,
                dim1297Kuo3Init,
                dim1298Kuo3Init,
                dim1299Kuo3Init,
                dim1300Kuo3Init,
                dim1301Kuo3Init,
                dim1302Kuo3Init,
                dim1303Kuo3Init,
                dim1304Kuo3Init,
                dim1305Kuo3Init,
                dim1306Kuo3Init,
                dim1307Kuo3Init,
                dim1308Kuo3Init,
                dim1309Kuo3Init,
                dim1310Kuo3Init,
                dim1311Kuo3Init,
                dim1312Kuo3Init,
                dim1313Kuo3Init,
                dim1314Kuo3Init,
                dim1315Kuo3Init,
                dim1316Kuo3Init,
                dim1317Kuo3Init,
                dim1318Kuo3Init,
                dim1319Kuo3Init,
                dim1320Kuo3Init,
                dim1321Kuo3Init,
                dim1322Kuo3Init,
                dim1323Kuo3Init,
                dim1324Kuo3Init,
                dim1325Kuo3Init,
                dim1326Kuo3Init,
                dim1327Kuo3Init,
                dim1328Kuo3Init,
                dim1329Kuo3Init,
                dim1330Kuo3Init,
                dim1331Kuo3Init,
                dim1332Kuo3Init,
                dim1333Kuo3Init,
                dim1334Kuo3Init,
                dim1335Kuo3Init,
                dim1336Kuo3Init,
                dim1337Kuo3Init,
                dim1338Kuo3Init,
                dim1339Kuo3Init,
                dim1340Kuo3Init,
                dim1341Kuo3Init,
                dim1342Kuo3Init,
                dim1343Kuo3Init,
                dim1344Kuo3Init,
                dim1345Kuo3Init,
                dim1346Kuo3Init,
                dim1347Kuo3Init,
                dim1348Kuo3Init,
                dim1349Kuo3Init,
                dim1350Kuo3Init,
                dim1351Kuo3Init,
                dim1352Kuo3Init,
                dim1353Kuo3Init,
                dim1354Kuo3Init,
                dim1355Kuo3Init,
                dim1356Kuo3Init,
                dim1357Kuo3Init,
                dim1358Kuo3Init,
                dim1359Kuo3Init,
                dim1360Kuo3Init,
                dim1361Kuo3Init,
                dim1362Kuo3Init,
                dim1363Kuo3Init,
                dim1364Kuo3Init,
                dim1365Kuo3Init,
                dim1366Kuo3Init,
                dim1367Kuo3Init,
                dim1368Kuo3Init,
                dim1369Kuo3Init,
                dim1370Kuo3Init,
                dim1371Kuo3Init,
                dim1372Kuo3Init,
                dim1373Kuo3Init,
                dim1374Kuo3Init,
                dim1375Kuo3Init,
                dim1376Kuo3Init,
                dim1377Kuo3Init,
                dim1378Kuo3Init,
                dim1379Kuo3Init,
                dim1380Kuo3Init,
                dim1381Kuo3Init,
                dim1382Kuo3Init,
                dim1383Kuo3Init,
                dim1384Kuo3Init,
                dim1385Kuo3Init,
                dim1386Kuo3Init,
                dim1387Kuo3Init,
                dim1388Kuo3Init,
                dim1389Kuo3Init,
                dim1390Kuo3Init,
                dim1391Kuo3Init,
                dim1392Kuo3Init,
                dim1393Kuo3Init,
                dim1394Kuo3Init,
                dim1395Kuo3Init,
                dim1396Kuo3Init,
                dim1397Kuo3Init,
                dim1398Kuo3Init,
                dim1399Kuo3Init,
                dim1400Kuo3Init,
                dim1401Kuo3Init,
                dim1402Kuo3Init,
                dim1403Kuo3Init,
                dim1404Kuo3Init,
                dim1405Kuo3Init,
                dim1406Kuo3Init,
                dim1407Kuo3Init,
                dim1408Kuo3Init,
                dim1409Kuo3Init,
                dim1410Kuo3Init,
                dim1411Kuo3Init,
                dim1412Kuo3Init,
                dim1413Kuo3Init,
                dim1414Kuo3Init,
                dim1415Kuo3Init,
                dim1416Kuo3Init,
                dim1417Kuo3Init,
                dim1418Kuo3Init,
                dim1419Kuo3Init,
                dim1420Kuo3Init,
                dim1421Kuo3Init,
                dim1422Kuo3Init,
                dim1423Kuo3Init,
                dim1424Kuo3Init,
                dim1425Kuo3Init,
                dim1426Kuo3Init,
                dim1427Kuo3Init,
                dim1428Kuo3Init,
                dim1429Kuo3Init,
                dim1430Kuo3Init,
                dim1431Kuo3Init,
                dim1432Kuo3Init,
                dim1433Kuo3Init,
                dim1434Kuo3Init,
                dim1435Kuo3Init,
                dim1436Kuo3Init,
                dim1437Kuo3Init,
                dim1438Kuo3Init,
                dim1439Kuo3Init,
                dim1440Kuo3Init,
                dim1441Kuo3Init,
                dim1442Kuo3Init,
                dim1443Kuo3Init,
                dim1444Kuo3Init,
                dim1445Kuo3Init,
                dim1446Kuo3Init,
                dim1447Kuo3Init,
                dim1448Kuo3Init,
                dim1449Kuo3Init,
                dim1450Kuo3Init,
                dim1451Kuo3Init,
                dim1452Kuo3Init,
                dim1453Kuo3Init,
                dim1454Kuo3Init,
                dim1455Kuo3Init,
                dim1456Kuo3Init,
                dim1457Kuo3Init,
                dim1458Kuo3Init,
                dim1459Kuo3Init,
                dim1460Kuo3Init,
                dim1461Kuo3Init,
                dim1462Kuo3Init,
                dim1463Kuo3Init,
                dim1464Kuo3Init,
                dim1465Kuo3Init,
                dim1466Kuo3Init,
                dim1467Kuo3Init,
                dim1468Kuo3Init,
                dim1469Kuo3Init,
                dim1470Kuo3Init,
                dim1471Kuo3Init,
                dim1472Kuo3Init,
                dim1473Kuo3Init,
                dim1474Kuo3Init,
                dim1475Kuo3Init,
                dim1476Kuo3Init,
                dim1477Kuo3Init,
                dim1478Kuo3Init,
                dim1479Kuo3Init,
                dim1480Kuo3Init,
                dim1481Kuo3Init,
                dim1482Kuo3Init,
                dim1483Kuo3Init,
                dim1484Kuo3Init,
                dim1485Kuo3Init,
                dim1486Kuo3Init,
                dim1487Kuo3Init,
                dim1488Kuo3Init,
                dim1489Kuo3Init,
                dim1490Kuo3Init,
                dim1491Kuo3Init,
                dim1492Kuo3Init,
                dim1493Kuo3Init,
                dim1494Kuo3Init,
                dim1495Kuo3Init,
                dim1496Kuo3Init,
                dim1497Kuo3Init,
                dim1498Kuo3Init,
                dim1499Kuo3Init,
                dim1500Kuo3Init,
                dim1501Kuo3Init,
                dim1502Kuo3Init,
                dim1503Kuo3Init,
                dim1504Kuo3Init,
                dim1505Kuo3Init,
                dim1506Kuo3Init,
                dim1507Kuo3Init,
                dim1508Kuo3Init,
                dim1509Kuo3Init,
                dim1510Kuo3Init,
                dim1511Kuo3Init,
                dim1512Kuo3Init,
                dim1513Kuo3Init,
                dim1514Kuo3Init,
                dim1515Kuo3Init,
                dim1516Kuo3Init,
                dim1517Kuo3Init,
                dim1518Kuo3Init,
                dim1519Kuo3Init,
                dim1520Kuo3Init,
                dim1521Kuo3Init,
                dim1522Kuo3Init,
                dim1523Kuo3Init,
                dim1524Kuo3Init,
                dim1525Kuo3Init,
                dim1526Kuo3Init,
                dim1527Kuo3Init,
                dim1528Kuo3Init,
                dim1529Kuo3Init,
                dim1530Kuo3Init,
                dim1531Kuo3Init,
                dim1532Kuo3Init,
                dim1533Kuo3Init,
                dim1534Kuo3Init,
                dim1535Kuo3Init,
                dim1536Kuo3Init,
                dim1537Kuo3Init,
                dim1538Kuo3Init,
                dim1539Kuo3Init,
                dim1540Kuo3Init,
                dim1541Kuo3Init,
                dim1542Kuo3Init,
                dim1543Kuo3Init,
                dim1544Kuo3Init,
                dim1545Kuo3Init,
                dim1546Kuo3Init,
                dim1547Kuo3Init,
                dim1548Kuo3Init,
                dim1549Kuo3Init,
                dim1550Kuo3Init,
                dim1551Kuo3Init,
                dim1552Kuo3Init,
                dim1553Kuo3Init,
                dim1554Kuo3Init,
                dim1555Kuo3Init,
                dim1556Kuo3Init,
                dim1557Kuo3Init,
                dim1558Kuo3Init,
                dim1559Kuo3Init,
                dim1560Kuo3Init,
                dim1561Kuo3Init,
                dim1562Kuo3Init,
                dim1563Kuo3Init,
                dim1564Kuo3Init,
                dim1565Kuo3Init,
                dim1566Kuo3Init,
                dim1567Kuo3Init,
                dim1568Kuo3Init,
                dim1569Kuo3Init,
                dim1570Kuo3Init,
                dim1571Kuo3Init,
                dim1572Kuo3Init,
                dim1573Kuo3Init,
                dim1574Kuo3Init,
                dim1575Kuo3Init,
                dim1576Kuo3Init,
                dim1577Kuo3Init,
                dim1578Kuo3Init,
                dim1579Kuo3Init,
                dim1580Kuo3Init,
                dim1581Kuo3Init,
                dim1582Kuo3Init,
                dim1583Kuo3Init,
                dim1584Kuo3Init,
                dim1585Kuo3Init,
                dim1586Kuo3Init,
                dim1587Kuo3Init,
                dim1588Kuo3Init,
                dim1589Kuo3Init,
                dim1590Kuo3Init,
                dim1591Kuo3Init,
                dim1592Kuo3Init,
                dim1593Kuo3Init,
                dim1594Kuo3Init,
                dim1595Kuo3Init,
                dim1596Kuo3Init,
                dim1597Kuo3Init,
                dim1598Kuo3Init,
                dim1599Kuo3Init,
                dim1600Kuo3Init,
                dim1601Kuo3Init,
                dim1602Kuo3Init,
                dim1603Kuo3Init,
                dim1604Kuo3Init,
                dim1605Kuo3Init,
                dim1606Kuo3Init,
                dim1607Kuo3Init,
                dim1608Kuo3Init,
                dim1609Kuo3Init,
                dim1610Kuo3Init,
                dim1611Kuo3Init,
                dim1612Kuo3Init,
                dim1613Kuo3Init,
                dim1614Kuo3Init,
                dim1615Kuo3Init,
                dim1616Kuo3Init,
                dim1617Kuo3Init,
                dim1618Kuo3Init,
                dim1619Kuo3Init,
                dim1620Kuo3Init,
                dim1621Kuo3Init,
                dim1622Kuo3Init,
                dim1623Kuo3Init,
                dim1624Kuo3Init,
                dim1625Kuo3Init,
                dim1626Kuo3Init,
                dim1627Kuo3Init,
                dim1628Kuo3Init,
                dim1629Kuo3Init,
                dim1630Kuo3Init,
                dim1631Kuo3Init,
                dim1632Kuo3Init,
                dim1633Kuo3Init,
                dim1634Kuo3Init,
                dim1635Kuo3Init,
                dim1636Kuo3Init,
                dim1637Kuo3Init,
                dim1638Kuo3Init,
                dim1639Kuo3Init,
                dim1640Kuo3Init,
                dim1641Kuo3Init,
                dim1642Kuo3Init,
                dim1643Kuo3Init,
                dim1644Kuo3Init,
                dim1645Kuo3Init,
                dim1646Kuo3Init,
                dim1647Kuo3Init,
                dim1648Kuo3Init,
                dim1649Kuo3Init,
                dim1650Kuo3Init,
                dim1651Kuo3Init,
                dim1652Kuo3Init,
                dim1653Kuo3Init,
                dim1654Kuo3Init,
                dim1655Kuo3Init,
                dim1656Kuo3Init,
                dim1657Kuo3Init,
                dim1658Kuo3Init,
                dim1659Kuo3Init,
                dim1660Kuo3Init,
                dim1661Kuo3Init,
                dim1662Kuo3Init,
                dim1663Kuo3Init,
                dim1664Kuo3Init,
                dim1665Kuo3Init,
                dim1666Kuo3Init,
                dim1667Kuo3Init,
                dim1668Kuo3Init,
                dim1669Kuo3Init,
                dim1670Kuo3Init,
                dim1671Kuo3Init,
                dim1672Kuo3Init,
                dim1673Kuo3Init,
                dim1674Kuo3Init,
                dim1675Kuo3Init,
                dim1676Kuo3Init,
                dim1677Kuo3Init,
                dim1678Kuo3Init,
                dim1679Kuo3Init,
                dim1680Kuo3Init,
                dim1681Kuo3Init,
                dim1682Kuo3Init,
                dim1683Kuo3Init,
                dim1684Kuo3Init,
                dim1685Kuo3Init,
                dim1686Kuo3Init,
                dim1687Kuo3Init,
                dim1688Kuo3Init,
                dim1689Kuo3Init,
                dim1690Kuo3Init,
                dim1691Kuo3Init,
                dim1692Kuo3Init,
                dim1693Kuo3Init,
                dim1694Kuo3Init,
                dim1695Kuo3Init,
                dim1696Kuo3Init,
                dim1697Kuo3Init,
                dim1698Kuo3Init,
                dim1699Kuo3Init,
                dim1700Kuo3Init,
                dim1701Kuo3Init,
                dim1702Kuo3Init,
                dim1703Kuo3Init,
                dim1704Kuo3Init,
                dim1705Kuo3Init,
                dim1706Kuo3Init,
                dim1707Kuo3Init,
                dim1708Kuo3Init,
                dim1709Kuo3Init,
                dim1710Kuo3Init,
                dim1711Kuo3Init,
                dim1712Kuo3Init,
                dim1713Kuo3Init,
                dim1714Kuo3Init,
                dim1715Kuo3Init,
                dim1716Kuo3Init,
                dim1717Kuo3Init,
                dim1718Kuo3Init,
                dim1719Kuo3Init,
                dim1720Kuo3Init,
                dim1721Kuo3Init,
                dim1722Kuo3Init,
                dim1723Kuo3Init,
                dim1724Kuo3Init,
                dim1725Kuo3Init,
                dim1726Kuo3Init,
                dim1727Kuo3Init,
                dim1728Kuo3Init,
                dim1729Kuo3Init,
                dim1730Kuo3Init,
                dim1731Kuo3Init,
                dim1732Kuo3Init,
                dim1733Kuo3Init,
                dim1734Kuo3Init,
                dim1735Kuo3Init,
                dim1736Kuo3Init,
                dim1737Kuo3Init,
                dim1738Kuo3Init,
                dim1739Kuo3Init,
                dim1740Kuo3Init,
                dim1741Kuo3Init,
                dim1742Kuo3Init,
                dim1743Kuo3Init,
                dim1744Kuo3Init,
                dim1745Kuo3Init,
                dim1746Kuo3Init,
                dim1747Kuo3Init,
                dim1748Kuo3Init,
                dim1749Kuo3Init,
                dim1750Kuo3Init,
                dim1751Kuo3Init,
                dim1752Kuo3Init,
                dim1753Kuo3Init,
                dim1754Kuo3Init,
                dim1755Kuo3Init,
                dim1756Kuo3Init,
                dim1757Kuo3Init,
                dim1758Kuo3Init,
                dim1759Kuo3Init,
                dim1760Kuo3Init,
                dim1761Kuo3Init,
                dim1762Kuo3Init,
                dim1763Kuo3Init,
                dim1764Kuo3Init,
                dim1765Kuo3Init,
                dim1766Kuo3Init,
                dim1767Kuo3Init,
                dim1768Kuo3Init,
                dim1769Kuo3Init,
                dim1770Kuo3Init,
                dim1771Kuo3Init,
                dim1772Kuo3Init,
                dim1773Kuo3Init,
                dim1774Kuo3Init,
                dim1775Kuo3Init,
                dim1776Kuo3Init,
                dim1777Kuo3Init,
                dim1778Kuo3Init,
                dim1779Kuo3Init,
                dim1780Kuo3Init,
                dim1781Kuo3Init,
                dim1782Kuo3Init,
                dim1783Kuo3Init,
                dim1784Kuo3Init,
                dim1785Kuo3Init,
                dim1786Kuo3Init,
                dim1787Kuo3Init,
                dim1788Kuo3Init,
                dim1789Kuo3Init,
                dim1790Kuo3Init,
                dim1791Kuo3Init,
                dim1792Kuo3Init,
                dim1793Kuo3Init,
                dim1794Kuo3Init,
                dim1795Kuo3Init,
                dim1796Kuo3Init,
                dim1797Kuo3Init,
                dim1798Kuo3Init,
                dim1799Kuo3Init,
                dim1800Kuo3Init,
                dim1801Kuo3Init,
                dim1802Kuo3Init,
                dim1803Kuo3Init,
                dim1804Kuo3Init,
                dim1805Kuo3Init,
                dim1806Kuo3Init,
                dim1807Kuo3Init,
                dim1808Kuo3Init,
                dim1809Kuo3Init,
                dim1810Kuo3Init,
                dim1811Kuo3Init,
                dim1812Kuo3Init,
                dim1813Kuo3Init,
                dim1814Kuo3Init,
                dim1815Kuo3Init,
                dim1816Kuo3Init,
                dim1817Kuo3Init,
                dim1818Kuo3Init,
                dim1819Kuo3Init,
                dim1820Kuo3Init,
                dim1821Kuo3Init,
                dim1822Kuo3Init,
                dim1823Kuo3Init,
                dim1824Kuo3Init,
                dim1825Kuo3Init,
                dim1826Kuo3Init,
                dim1827Kuo3Init,
                dim1828Kuo3Init,
                dim1829Kuo3Init,
                dim1830Kuo3Init,
                dim1831Kuo3Init,
                dim1832Kuo3Init,
                dim1833Kuo3Init,
                dim1834Kuo3Init,
                dim1835Kuo3Init,
                dim1836Kuo3Init,
                dim1837Kuo3Init,
                dim1838Kuo3Init,
                dim1839Kuo3Init,
                dim1840Kuo3Init,
                dim1841Kuo3Init,
                dim1842Kuo3Init,
                dim1843Kuo3Init,
                dim1844Kuo3Init,
                dim1845Kuo3Init,
                dim1846Kuo3Init,
                dim1847Kuo3Init,
                dim1848Kuo3Init,
                dim1849Kuo3Init,
                dim1850Kuo3Init,
                dim1851Kuo3Init,
                dim1852Kuo3Init,
                dim1853Kuo3Init,
                dim1854Kuo3Init,
                dim1855Kuo3Init,
                dim1856Kuo3Init,
                dim1857Kuo3Init,
                dim1858Kuo3Init,
                dim1859Kuo3Init,
                dim1860Kuo3Init,
                dim1861Kuo3Init,
                dim1862Kuo3Init,
                dim1863Kuo3Init,
                dim1864Kuo3Init,
                dim1865Kuo3Init,
                dim1866Kuo3Init,
                dim1867Kuo3Init,
                dim1868Kuo3Init,
                dim1869Kuo3Init,
                dim1870Kuo3Init,
                dim1871Kuo3Init,
                dim1872Kuo3Init,
                dim1873Kuo3Init,
                dim1874Kuo3Init,
                dim1875Kuo3Init,
                dim1876Kuo3Init,
                dim1877Kuo3Init,
                dim1878Kuo3Init,
                dim1879Kuo3Init,
                dim1880Kuo3Init,
                dim1881Kuo3Init,
                dim1882Kuo3Init,
                dim1883Kuo3Init,
                dim1884Kuo3Init,
                dim1885Kuo3Init,
                dim1886Kuo3Init,
                dim1887Kuo3Init,
                dim1888Kuo3Init,
                dim1889Kuo3Init,
                dim1890Kuo3Init,
                dim1891Kuo3Init,
                dim1892Kuo3Init,
                dim1893Kuo3Init,
                dim1894Kuo3Init,
                dim1895Kuo3Init,
                dim1896Kuo3Init,
                dim1897Kuo3Init,
                dim1898Kuo3Init,
                dim1899Kuo3Init,
                dim1900Kuo3Init,
                dim1901Kuo3Init,
                dim1902Kuo3Init,
                dim1903Kuo3Init,
                dim1904Kuo3Init,
                dim1905Kuo3Init,
                dim1906Kuo3Init,
                dim1907Kuo3Init,
                dim1908Kuo3Init,
                dim1909Kuo3Init,
                dim1910Kuo3Init,
                dim1911Kuo3Init,
                dim1912Kuo3Init,
                dim1913Kuo3Init,
                dim1914Kuo3Init,
                dim1915Kuo3Init,
                dim1916Kuo3Init,
                dim1917Kuo3Init,
                dim1918Kuo3Init,
                dim1919Kuo3Init,
                dim1920Kuo3Init,
                dim1921Kuo3Init,
                dim1922Kuo3Init,
                dim1923Kuo3Init,
                dim1924Kuo3Init,
                dim1925Kuo3Init,
                dim1926Kuo3Init,
                dim1927Kuo3Init,
                dim1928Kuo3Init,
                dim1929Kuo3Init,
                dim1930Kuo3Init,
                dim1931Kuo3Init,
                dim1932Kuo3Init,
                dim1933Kuo3Init,
                dim1934Kuo3Init,
                dim1935Kuo3Init,
                dim1936Kuo3Init,
                dim1937Kuo3Init,
                dim1938Kuo3Init,
                dim1939Kuo3Init,
                dim1940Kuo3Init,
                dim1941Kuo3Init,
                dim1942Kuo3Init,
                dim1943Kuo3Init,
                dim1944Kuo3Init,
                dim1945Kuo3Init,
                dim1946Kuo3Init,
                dim1947Kuo3Init,
                dim1948Kuo3Init,
                dim1949Kuo3Init,
                dim1950Kuo3Init,
                dim1951Kuo3Init,
                dim1952Kuo3Init,
                dim1953Kuo3Init,
                dim1954Kuo3Init,
                dim1955Kuo3Init,
                dim1956Kuo3Init,
                dim1957Kuo3Init,
                dim1958Kuo3Init,
                dim1959Kuo3Init,
                dim1960Kuo3Init,
                dim1961Kuo3Init,
                dim1962Kuo3Init,
                dim1963Kuo3Init,
                dim1964Kuo3Init,
                dim1965Kuo3Init,
                dim1966Kuo3Init,
                dim1967Kuo3Init,
                dim1968Kuo3Init,
                dim1969Kuo3Init,
                dim1970Kuo3Init,
                dim1971Kuo3Init,
                dim1972Kuo3Init,
                dim1973Kuo3Init,
                dim1974Kuo3Init,
                dim1975Kuo3Init,
                dim1976Kuo3Init,
                dim1977Kuo3Init,
                dim1978Kuo3Init,
                dim1979Kuo3Init,
                dim1980Kuo3Init,
                dim1981Kuo3Init,
                dim1982Kuo3Init,
                dim1983Kuo3Init,
                dim1984Kuo3Init,
                dim1985Kuo3Init,
                dim1986Kuo3Init,
                dim1987Kuo3Init,
                dim1988Kuo3Init,
                dim1989Kuo3Init,
                dim1990Kuo3Init,
                dim1991Kuo3Init,
                dim1992Kuo3Init,
                dim1993Kuo3Init,
                dim1994Kuo3Init,
                dim1995Kuo3Init,
                dim1996Kuo3Init,
                dim1997Kuo3Init,
                dim1998Kuo3Init,
                dim1999Kuo3Init,
                dim2000Kuo3Init,
                dim2001Kuo3Init,
                dim2002Kuo3Init,
                dim2003Kuo3Init,
                dim2004Kuo3Init,
                dim2005Kuo3Init,
                dim2006Kuo3Init,
                dim2007Kuo3Init,
                dim2008Kuo3Init,
                dim2009Kuo3Init,
                dim2010Kuo3Init,
                dim2011Kuo3Init,
                dim2012Kuo3Init,
                dim2013Kuo3Init,
                dim2014Kuo3Init,
                dim2015Kuo3Init,
                dim2016Kuo3Init,
                dim2017Kuo3Init,
                dim2018Kuo3Init,
                dim2019Kuo3Init,
                dim2020Kuo3Init,
                dim2021Kuo3Init,
                dim2022Kuo3Init,
                dim2023Kuo3Init,
                dim2024Kuo3Init,
                dim2025Kuo3Init,
                dim2026Kuo3Init,
                dim2027Kuo3Init,
                dim2028Kuo3Init,
                dim2029Kuo3Init,
                dim2030Kuo3Init,
                dim2031Kuo3Init,
                dim2032Kuo3Init,
                dim2033Kuo3Init,
                dim2034Kuo3Init,
                dim2035Kuo3Init,
                dim2036Kuo3Init,
                dim2037Kuo3Init,
                dim2038Kuo3Init,
                dim2039Kuo3Init,
                dim2040Kuo3Init,
                dim2041Kuo3Init,
                dim2042Kuo3Init,
                dim2043Kuo3Init,
                dim2044Kuo3Init,
                dim2045Kuo3Init,
                dim2046Kuo3Init,
                dim2047Kuo3Init,
                dim2048Kuo3Init,
                dim2049Kuo3Init,
                dim2050Kuo3Init,
                dim2051Kuo3Init,
                dim2052Kuo3Init,
                dim2053Kuo3Init,
                dim2054Kuo3Init,
                dim2055Kuo3Init,
                dim2056Kuo3Init,
                dim2057Kuo3Init,
                dim2058Kuo3Init,
                dim2059Kuo3Init,
                dim2060Kuo3Init,
                dim2061Kuo3Init,
                dim2062Kuo3Init,
                dim2063Kuo3Init,
                dim2064Kuo3Init,
                dim2065Kuo3Init,
                dim2066Kuo3Init,
                dim2067Kuo3Init,
                dim2068Kuo3Init,
                dim2069Kuo3Init,
                dim2070Kuo3Init,
                dim2071Kuo3Init,
                dim2072Kuo3Init,
                dim2073Kuo3Init,
                dim2074Kuo3Init,
                dim2075Kuo3Init,
                dim2076Kuo3Init,
                dim2077Kuo3Init,
                dim2078Kuo3Init,
                dim2079Kuo3Init,
                dim2080Kuo3Init,
                dim2081Kuo3Init,
                dim2082Kuo3Init,
                dim2083Kuo3Init,
                dim2084Kuo3Init,
                dim2085Kuo3Init,
                dim2086Kuo3Init,
                dim2087Kuo3Init,
                dim2088Kuo3Init,
                dim2089Kuo3Init,
                dim2090Kuo3Init,
                dim2091Kuo3Init,
                dim2092Kuo3Init,
                dim2093Kuo3Init,
                dim2094Kuo3Init,
                dim2095Kuo3Init,
                dim2096Kuo3Init,
                dim2097Kuo3Init,
                dim2098Kuo3Init,
                dim2099Kuo3Init,
                dim2100Kuo3Init,
                dim2101Kuo3Init,
                dim2102Kuo3Init,
                dim2103Kuo3Init,
                dim2104Kuo3Init,
                dim2105Kuo3Init,
                dim2106Kuo3Init,
                dim2107Kuo3Init,
                dim2108Kuo3Init,
                dim2109Kuo3Init,
                dim2110Kuo3Init,
                dim2111Kuo3Init,
                dim2112Kuo3Init,
                dim2113Kuo3Init,
                dim2114Kuo3Init,
                dim2115Kuo3Init,
                dim2116Kuo3Init,
                dim2117Kuo3Init,
                dim2118Kuo3Init,
                dim2119Kuo3Init,
                dim2120Kuo3Init,
                dim2121Kuo3Init,
                dim2122Kuo3Init,
                dim2123Kuo3Init,
                dim2124Kuo3Init,
                dim2125Kuo3Init,
                dim2126Kuo3Init,
                dim2127Kuo3Init,
                dim2128Kuo3Init,
                dim2129Kuo3Init,
                dim2130Kuo3Init,
                dim2131Kuo3Init,
                dim2132Kuo3Init,
                dim2133Kuo3Init,
                dim2134Kuo3Init,
                dim2135Kuo3Init,
                dim2136Kuo3Init,
                dim2137Kuo3Init,
                dim2138Kuo3Init,
                dim2139Kuo3Init,
                dim2140Kuo3Init,
                dim2141Kuo3Init,
                dim2142Kuo3Init,
                dim2143Kuo3Init,
                dim2144Kuo3Init,
                dim2145Kuo3Init,
                dim2146Kuo3Init,
                dim2147Kuo3Init,
                dim2148Kuo3Init,
                dim2149Kuo3Init,
                dim2150Kuo3Init,
                dim2151Kuo3Init,
                dim2152Kuo3Init,
                dim2153Kuo3Init,
                dim2154Kuo3Init,
                dim2155Kuo3Init,
                dim2156Kuo3Init,
                dim2157Kuo3Init,
                dim2158Kuo3Init,
                dim2159Kuo3Init,
                dim2160Kuo3Init,
                dim2161Kuo3Init,
                dim2162Kuo3Init,
                dim2163Kuo3Init,
                dim2164Kuo3Init,
                dim2165Kuo3Init,
                dim2166Kuo3Init,
                dim2167Kuo3Init,
                dim2168Kuo3Init,
                dim2169Kuo3Init,
                dim2170Kuo3Init,
                dim2171Kuo3Init,
                dim2172Kuo3Init,
                dim2173Kuo3Init,
                dim2174Kuo3Init,
                dim2175Kuo3Init,
                dim2176Kuo3Init,
                dim2177Kuo3Init,
                dim2178Kuo3Init,
                dim2179Kuo3Init,
                dim2180Kuo3Init,
                dim2181Kuo3Init,
                dim2182Kuo3Init,
                dim2183Kuo3Init,
                dim2184Kuo3Init,
                dim2185Kuo3Init,
                dim2186Kuo3Init,
                dim2187Kuo3Init,
                dim2188Kuo3Init,
                dim2189Kuo3Init,
                dim2190Kuo3Init,
                dim2191Kuo3Init,
                dim2192Kuo3Init,
                dim2193Kuo3Init,
                dim2194Kuo3Init,
                dim2195Kuo3Init,
                dim2196Kuo3Init,
                dim2197Kuo3Init,
                dim2198Kuo3Init,
                dim2199Kuo3Init,
                dim2200Kuo3Init,
                dim2201Kuo3Init,
                dim2202Kuo3Init,
                dim2203Kuo3Init,
                dim2204Kuo3Init,
                dim2205Kuo3Init,
                dim2206Kuo3Init,
                dim2207Kuo3Init,
                dim2208Kuo3Init,
                dim2209Kuo3Init,
                dim2210Kuo3Init,
                dim2211Kuo3Init,
                dim2212Kuo3Init,
                dim2213Kuo3Init,
                dim2214Kuo3Init,
                dim2215Kuo3Init,
                dim2216Kuo3Init,
                dim2217Kuo3Init,
                dim2218Kuo3Init,
                dim2219Kuo3Init,
                dim2220Kuo3Init,
                dim2221Kuo3Init,
                dim2222Kuo3Init,
                dim2223Kuo3Init,
                dim2224Kuo3Init,
                dim2225Kuo3Init,
                dim2226Kuo3Init,
                dim2227Kuo3Init,
                dim2228Kuo3Init,
                dim2229Kuo3Init,
                dim2230Kuo3Init,
                dim2231Kuo3Init,
                dim2232Kuo3Init,
                dim2233Kuo3Init,
                dim2234Kuo3Init,
                dim2235Kuo3Init,
                dim2236Kuo3Init,
                dim2237Kuo3Init,
                dim2238Kuo3Init,
                dim2239Kuo3Init,
                dim2240Kuo3Init,
                dim2241Kuo3Init,
                dim2242Kuo3Init,
                dim2243Kuo3Init,
                dim2244Kuo3Init,
                dim2245Kuo3Init,
                dim2246Kuo3Init,
                dim2247Kuo3Init,
                dim2248Kuo3Init,
                dim2249Kuo3Init,
                dim2250Kuo3Init,
                dim2251Kuo3Init,
                dim2252Kuo3Init,
                dim2253Kuo3Init,
                dim2254Kuo3Init,
                dim2255Kuo3Init,
                dim2256Kuo3Init,
                dim2257Kuo3Init,
                dim2258Kuo3Init,
                dim2259Kuo3Init,
                dim2260Kuo3Init,
                dim2261Kuo3Init,
                dim2262Kuo3Init,
                dim2263Kuo3Init,
                dim2264Kuo3Init,
                dim2265Kuo3Init,
                dim2266Kuo3Init,
                dim2267Kuo3Init,
                dim2268Kuo3Init,
                dim2269Kuo3Init,
                dim2270Kuo3Init,
                dim2271Kuo3Init,
                dim2272Kuo3Init,
                dim2273Kuo3Init,
                dim2274Kuo3Init,
                dim2275Kuo3Init,
                dim2276Kuo3Init,
                dim2277Kuo3Init,
                dim2278Kuo3Init,
                dim2279Kuo3Init,
                dim2280Kuo3Init,
                dim2281Kuo3Init,
                dim2282Kuo3Init,
                dim2283Kuo3Init,
                dim2284Kuo3Init,
                dim2285Kuo3Init,
                dim2286Kuo3Init,
                dim2287Kuo3Init,
                dim2288Kuo3Init,
                dim2289Kuo3Init,
                dim2290Kuo3Init,
                dim2291Kuo3Init,
                dim2292Kuo3Init,
                dim2293Kuo3Init,
                dim2294Kuo3Init,
                dim2295Kuo3Init,
                dim2296Kuo3Init,
                dim2297Kuo3Init,
                dim2298Kuo3Init,
                dim2299Kuo3Init,
                dim2300Kuo3Init,
                dim2301Kuo3Init,
                dim2302Kuo3Init,
                dim2303Kuo3Init,
                dim2304Kuo3Init,
                dim2305Kuo3Init,
                dim2306Kuo3Init,
                dim2307Kuo3Init,
                dim2308Kuo3Init,
                dim2309Kuo3Init,
                dim2310Kuo3Init,
                dim2311Kuo3Init,
                dim2312Kuo3Init,
                dim2313Kuo3Init,
                dim2314Kuo3Init,
                dim2315Kuo3Init,
                dim2316Kuo3Init,
                dim2317Kuo3Init,
                dim2318Kuo3Init,
                dim2319Kuo3Init,
                dim2320Kuo3Init,
                dim2321Kuo3Init,
                dim2322Kuo3Init,
                dim2323Kuo3Init,
                dim2324Kuo3Init,
                dim2325Kuo3Init,
                dim2326Kuo3Init,
                dim2327Kuo3Init,
                dim2328Kuo3Init,
                dim2329Kuo3Init,
                dim2330Kuo3Init,
                dim2331Kuo3Init,
                dim2332Kuo3Init,
                dim2333Kuo3Init,
                dim2334Kuo3Init,
                dim2335Kuo3Init,
                dim2336Kuo3Init,
                dim2337Kuo3Init,
                dim2338Kuo3Init,
                dim2339Kuo3Init,
                dim2340Kuo3Init,
                dim2341Kuo3Init,
                dim2342Kuo3Init,
                dim2343Kuo3Init,
                dim2344Kuo3Init,
                dim2345Kuo3Init,
                dim2346Kuo3Init,
                dim2347Kuo3Init,
                dim2348Kuo3Init,
                dim2349Kuo3Init,
                dim2350Kuo3Init,
                dim2351Kuo3Init,
                dim2352Kuo3Init,
                dim2353Kuo3Init,
                dim2354Kuo3Init,
                dim2355Kuo3Init,
                dim2356Kuo3Init,
                dim2357Kuo3Init,
                dim2358Kuo3Init,
                dim2359Kuo3Init,
                dim2360Kuo3Init,
                dim2361Kuo3Init,
                dim2362Kuo3Init,
                dim2363Kuo3Init,
                dim2364Kuo3Init,
                dim2365Kuo3Init,
                dim2366Kuo3Init,
                dim2367Kuo3Init,
                dim2368Kuo3Init,
                dim2369Kuo3Init,
                dim2370Kuo3Init,
                dim2371Kuo3Init,
                dim2372Kuo3Init,
                dim2373Kuo3Init,
                dim2374Kuo3Init,
                dim2375Kuo3Init,
                dim2376Kuo3Init,
                dim2377Kuo3Init,
                dim2378Kuo3Init,
                dim2379Kuo3Init,
                dim2380Kuo3Init,
                dim2381Kuo3Init,
                dim2382Kuo3Init,
                dim2383Kuo3Init,
                dim2384Kuo3Init,
                dim2385Kuo3Init,
                dim2386Kuo3Init,
                dim2387Kuo3Init,
                dim2388Kuo3Init,
                dim2389Kuo3Init,
                dim2390Kuo3Init,
                dim2391Kuo3Init,
                dim2392Kuo3Init,
                dim2393Kuo3Init,
                dim2394Kuo3Init,
                dim2395Kuo3Init,
                dim2396Kuo3Init,
                dim2397Kuo3Init,
                dim2398Kuo3Init,
                dim2399Kuo3Init,
                dim2400Kuo3Init,
                dim2401Kuo3Init,
                dim2402Kuo3Init,
                dim2403Kuo3Init,
                dim2404Kuo3Init,
                dim2405Kuo3Init,
                dim2406Kuo3Init,
                dim2407Kuo3Init,
                dim2408Kuo3Init,
                dim2409Kuo3Init,
                dim2410Kuo3Init,
                dim2411Kuo3Init,
                dim2412Kuo3Init,
                dim2413Kuo3Init,
                dim2414Kuo3Init,
                dim2415Kuo3Init,
                dim2416Kuo3Init,
                dim2417Kuo3Init,
                dim2418Kuo3Init,
                dim2419Kuo3Init,
                dim2420Kuo3Init,
                dim2421Kuo3Init,
                dim2422Kuo3Init,
                dim2423Kuo3Init,
                dim2424Kuo3Init,
                dim2425Kuo3Init,
                dim2426Kuo3Init,
                dim2427Kuo3Init,
                dim2428Kuo3Init,
                dim2429Kuo3Init,
                dim2430Kuo3Init,
                dim2431Kuo3Init,
                dim2432Kuo3Init,
                dim2433Kuo3Init,
                dim2434Kuo3Init,
                dim2435Kuo3Init,
                dim2436Kuo3Init,
                dim2437Kuo3Init,
                dim2438Kuo3Init,
                dim2439Kuo3Init,
                dim2440Kuo3Init,
                dim2441Kuo3Init,
                dim2442Kuo3Init,
                dim2443Kuo3Init,
                dim2444Kuo3Init,
                dim2445Kuo3Init,
                dim2446Kuo3Init,
                dim2447Kuo3Init,
                dim2448Kuo3Init,
                dim2449Kuo3Init,
                dim2450Kuo3Init,
                dim2451Kuo3Init,
                dim2452Kuo3Init,
                dim2453Kuo3Init,
                dim2454Kuo3Init,
                dim2455Kuo3Init,
                dim2456Kuo3Init,
                dim2457Kuo3Init,
                dim2458Kuo3Init,
                dim2459Kuo3Init,
                dim2460Kuo3Init,
                dim2461Kuo3Init,
                dim2462Kuo3Init,
                dim2463Kuo3Init,
                dim2464Kuo3Init,
                dim2465Kuo3Init,
                dim2466Kuo3Init,
                dim2467Kuo3Init,
                dim2468Kuo3Init,
                dim2469Kuo3Init,
                dim2470Kuo3Init,
                dim2471Kuo3Init,
                dim2472Kuo3Init,
                dim2473Kuo3Init,
                dim2474Kuo3Init,
                dim2475Kuo3Init,
                dim2476Kuo3Init,
                dim2477Kuo3Init,
                dim2478Kuo3Init,
                dim2479Kuo3Init,
                dim2480Kuo3Init,
                dim2481Kuo3Init,
                dim2482Kuo3Init,
                dim2483Kuo3Init,
                dim2484Kuo3Init,
                dim2485Kuo3Init,
                dim2486Kuo3Init,
                dim2487Kuo3Init,
                dim2488Kuo3Init,
                dim2489Kuo3Init,
                dim2490Kuo3Init,
                dim2491Kuo3Init,
                dim2492Kuo3Init,
                dim2493Kuo3Init,
                dim2494Kuo3Init,
                dim2495Kuo3Init,
                dim2496Kuo3Init,
                dim2497Kuo3Init,
                dim2498Kuo3Init,
                dim2499Kuo3Init,
                dim2500Kuo3Init,
                dim2501Kuo3Init,
                dim2502Kuo3Init,
                dim2503Kuo3Init,
                dim2504Kuo3Init,
                dim2505Kuo3Init,
                dim2506Kuo3Init,
                dim2507Kuo3Init,
                dim2508Kuo3Init,
                dim2509Kuo3Init,
                dim2510Kuo3Init,
                dim2511Kuo3Init,
                dim2512Kuo3Init,
                dim2513Kuo3Init,
                dim2514Kuo3Init,
                dim2515Kuo3Init,
                dim2516Kuo3Init,
                dim2517Kuo3Init,
                dim2518Kuo3Init,
                dim2519Kuo3Init,
                dim2520Kuo3Init,
                dim2521Kuo3Init,
                dim2522Kuo3Init,
                dim2523Kuo3Init,
                dim2524Kuo3Init,
                dim2525Kuo3Init,
                dim2526Kuo3Init,
                dim2527Kuo3Init,
                dim2528Kuo3Init,
                dim2529Kuo3Init,
                dim2530Kuo3Init,
                dim2531Kuo3Init,
                dim2532Kuo3Init,
                dim2533Kuo3Init,
                dim2534Kuo3Init,
                dim2535Kuo3Init,
                dim2536Kuo3Init,
                dim2537Kuo3Init,
                dim2538Kuo3Init,
                dim2539Kuo3Init,
                dim2540Kuo3Init,
                dim2541Kuo3Init,
                dim2542Kuo3Init,
                dim2543Kuo3Init,
                dim2544Kuo3Init,
                dim2545Kuo3Init,
                dim2546Kuo3Init,
                dim2547Kuo3Init,
                dim2548Kuo3Init,
                dim2549Kuo3Init,
                dim2550Kuo3Init,
                dim2551Kuo3Init,
                dim2552Kuo3Init,
                dim2553Kuo3Init,
                dim2554Kuo3Init,
                dim2555Kuo3Init,
                dim2556Kuo3Init,
                dim2557Kuo3Init,
                dim2558Kuo3Init,
                dim2559Kuo3Init,
                dim2560Kuo3Init,
                dim2561Kuo3Init,
                dim2562Kuo3Init,
                dim2563Kuo3Init,
                dim2564Kuo3Init,
                dim2565Kuo3Init,
                dim2566Kuo3Init,
                dim2567Kuo3Init,
                dim2568Kuo3Init,
                dim2569Kuo3Init,
                dim2570Kuo3Init,
                dim2571Kuo3Init,
                dim2572Kuo3Init,
                dim2573Kuo3Init,
                dim2574Kuo3Init,
                dim2575Kuo3Init,
                dim2576Kuo3Init,
                dim2577Kuo3Init,
                dim2578Kuo3Init,
                dim2579Kuo3Init,
                dim2580Kuo3Init,
                dim2581Kuo3Init,
                dim2582Kuo3Init,
                dim2583Kuo3Init,
                dim2584Kuo3Init,
                dim2585Kuo3Init,
                dim2586Kuo3Init,
                dim2587Kuo3Init,
                dim2588Kuo3Init,
                dim2589Kuo3Init,
                dim2590Kuo3Init,
                dim2591Kuo3Init,
                dim2592Kuo3Init,
                dim2593Kuo3Init,
                dim2594Kuo3Init,
                dim2595Kuo3Init,
                dim2596Kuo3Init,
                dim2597Kuo3Init,
                dim2598Kuo3Init,
                dim2599Kuo3Init,
                dim2600Kuo3Init,
                dim2601Kuo3Init,
                dim2602Kuo3Init,
                dim2603Kuo3Init,
                dim2604Kuo3Init,
                dim2605Kuo3Init,
                dim2606Kuo3Init,
                dim2607Kuo3Init,
                dim2608Kuo3Init,
                dim2609Kuo3Init,
                dim2610Kuo3Init,
                dim2611Kuo3Init,
                dim2612Kuo3Init,
                dim2613Kuo3Init,
                dim2614Kuo3Init,
                dim2615Kuo3Init,
                dim2616Kuo3Init,
                dim2617Kuo3Init,
                dim2618Kuo3Init,
                dim2619Kuo3Init,
                dim2620Kuo3Init,
                dim2621Kuo3Init,
                dim2622Kuo3Init,
                dim2623Kuo3Init,
                dim2624Kuo3Init,
                dim2625Kuo3Init,
                dim2626Kuo3Init,
                dim2627Kuo3Init,
                dim2628Kuo3Init,
                dim2629Kuo3Init,
                dim2630Kuo3Init,
                dim2631Kuo3Init,
                dim2632Kuo3Init,
                dim2633Kuo3Init,
                dim2634Kuo3Init,
                dim2635Kuo3Init,
                dim2636Kuo3Init,
                dim2637Kuo3Init,
                dim2638Kuo3Init,
                dim2639Kuo3Init,
                dim2640Kuo3Init,
                dim2641Kuo3Init,
                dim2642Kuo3Init,
                dim2643Kuo3Init,
                dim2644Kuo3Init,
                dim2645Kuo3Init,
                dim2646Kuo3Init,
                dim2647Kuo3Init,
                dim2648Kuo3Init,
                dim2649Kuo3Init,
                dim2650Kuo3Init,
                dim2651Kuo3Init,
                dim2652Kuo3Init,
                dim2653Kuo3Init,
                dim2654Kuo3Init,
                dim2655Kuo3Init,
                dim2656Kuo3Init,
                dim2657Kuo3Init,
                dim2658Kuo3Init,
                dim2659Kuo3Init,
                dim2660Kuo3Init,
                dim2661Kuo3Init,
                dim2662Kuo3Init,
                dim2663Kuo3Init,
                dim2664Kuo3Init,
                dim2665Kuo3Init,
                dim2666Kuo3Init,
                dim2667Kuo3Init,
                dim2668Kuo3Init,
                dim2669Kuo3Init,
                dim2670Kuo3Init,
                dim2671Kuo3Init,
                dim2672Kuo3Init,
                dim2673Kuo3Init,
                dim2674Kuo3Init,
                dim2675Kuo3Init,
                dim2676Kuo3Init,
                dim2677Kuo3Init,
                dim2678Kuo3Init,
                dim2679Kuo3Init,
                dim2680Kuo3Init,
                dim2681Kuo3Init,
                dim2682Kuo3Init,
                dim2683Kuo3Init,
                dim2684Kuo3Init,
                dim2685Kuo3Init,
                dim2686Kuo3Init,
                dim2687Kuo3Init,
                dim2688Kuo3Init,
                dim2689Kuo3Init,
                dim2690Kuo3Init,
                dim2691Kuo3Init,
                dim2692Kuo3Init,
                dim2693Kuo3Init,
                dim2694Kuo3Init,
                dim2695Kuo3Init,
                dim2696Kuo3Init,
                dim2697Kuo3Init,
                dim2698Kuo3Init,
                dim2699Kuo3Init,
                dim2700Kuo3Init,
                dim2701Kuo3Init,
                dim2702Kuo3Init,
                dim2703Kuo3Init,
                dim2704Kuo3Init,
                dim2705Kuo3Init,
                dim2706Kuo3Init,
                dim2707Kuo3Init,
                dim2708Kuo3Init,
                dim2709Kuo3Init,
                dim2710Kuo3Init,
                dim2711Kuo3Init,
                dim2712Kuo3Init,
                dim2713Kuo3Init,
                dim2714Kuo3Init,
                dim2715Kuo3Init,
                dim2716Kuo3Init,
                dim2717Kuo3Init,
                dim2718Kuo3Init,
                dim2719Kuo3Init,
                dim2720Kuo3Init,
                dim2721Kuo3Init,
                dim2722Kuo3Init,
                dim2723Kuo3Init,
                dim2724Kuo3Init,
                dim2725Kuo3Init,
                dim2726Kuo3Init,
                dim2727Kuo3Init,
                dim2728Kuo3Init,
                dim2729Kuo3Init,
                dim2730Kuo3Init,
                dim2731Kuo3Init,
                dim2732Kuo3Init,
                dim2733Kuo3Init,
                dim2734Kuo3Init,
                dim2735Kuo3Init,
                dim2736Kuo3Init,
                dim2737Kuo3Init,
                dim2738Kuo3Init,
                dim2739Kuo3Init,
                dim2740Kuo3Init,
                dim2741Kuo3Init,
                dim2742Kuo3Init,
                dim2743Kuo3Init,
                dim2744Kuo3Init,
                dim2745Kuo3Init,
                dim2746Kuo3Init,
                dim2747Kuo3Init,
                dim2748Kuo3Init,
                dim2749Kuo3Init,
                dim2750Kuo3Init,
                dim2751Kuo3Init,
                dim2752Kuo3Init,
                dim2753Kuo3Init,
                dim2754Kuo3Init,
                dim2755Kuo3Init,
                dim2756Kuo3Init,
                dim2757Kuo3Init,
                dim2758Kuo3Init,
                dim2759Kuo3Init,
                dim2760Kuo3Init,
                dim2761Kuo3Init,
                dim2762Kuo3Init,
                dim2763Kuo3Init,
                dim2764Kuo3Init,
                dim2765Kuo3Init,
                dim2766Kuo3Init,
                dim2767Kuo3Init,
                dim2768Kuo3Init,
                dim2769Kuo3Init,
                dim2770Kuo3Init,
                dim2771Kuo3Init,
                dim2772Kuo3Init,
                dim2773Kuo3Init,
                dim2774Kuo3Init,
                dim2775Kuo3Init,
                dim2776Kuo3Init,
                dim2777Kuo3Init,
                dim2778Kuo3Init,
                dim2779Kuo3Init,
                dim2780Kuo3Init,
                dim2781Kuo3Init,
                dim2782Kuo3Init,
                dim2783Kuo3Init,
                dim2784Kuo3Init,
                dim2785Kuo3Init,
                dim2786Kuo3Init,
                dim2787Kuo3Init,
                dim2788Kuo3Init,
                dim2789Kuo3Init,
                dim2790Kuo3Init,
                dim2791Kuo3Init,
                dim2792Kuo3Init,
                dim2793Kuo3Init,
                dim2794Kuo3Init,
                dim2795Kuo3Init,
                dim2796Kuo3Init,
                dim2797Kuo3Init,
                dim2798Kuo3Init,
                dim2799Kuo3Init,
                dim2800Kuo3Init,
                dim2801Kuo3Init,
                dim2802Kuo3Init,
                dim2803Kuo3Init,
                dim2804Kuo3Init,
                dim2805Kuo3Init,
                dim2806Kuo3Init,
                dim2807Kuo3Init,
                dim2808Kuo3Init,
                dim2809Kuo3Init,
                dim2810Kuo3Init,
                dim2811Kuo3Init,
                dim2812Kuo3Init,
                dim2813Kuo3Init,
                dim2814Kuo3Init,
                dim2815Kuo3Init,
                dim2816Kuo3Init,
                dim2817Kuo3Init,
                dim2818Kuo3Init,
                dim2819Kuo3Init,
                dim2820Kuo3Init,
                dim2821Kuo3Init,
                dim2822Kuo3Init,
                dim2823Kuo3Init,
                dim2824Kuo3Init,
                dim2825Kuo3Init,
                dim2826Kuo3Init,
                dim2827Kuo3Init,
                dim2828Kuo3Init,
                dim2829Kuo3Init,
                dim2830Kuo3Init,
                dim2831Kuo3Init,
                dim2832Kuo3Init,
                dim2833Kuo3Init,
                dim2834Kuo3Init,
                dim2835Kuo3Init,
                dim2836Kuo3Init,
                dim2837Kuo3Init,
                dim2838Kuo3Init,
                dim2839Kuo3Init,
                dim2840Kuo3Init,
                dim2841Kuo3Init,
                dim2842Kuo3Init,
                dim2843Kuo3Init,
                dim2844Kuo3Init,
                dim2845Kuo3Init,
                dim2846Kuo3Init,
                dim2847Kuo3Init,
                dim2848Kuo3Init,
                dim2849Kuo3Init,
                dim2850Kuo3Init,
                dim2851Kuo3Init,
                dim2852Kuo3Init,
                dim2853Kuo3Init,
                dim2854Kuo3Init,
                dim2855Kuo3Init,
                dim2856Kuo3Init,
                dim2857Kuo3Init,
                dim2858Kuo3Init,
                dim2859Kuo3Init,
                dim2860Kuo3Init,
                dim2861Kuo3Init,
                dim2862Kuo3Init,
                dim2863Kuo3Init,
                dim2864Kuo3Init,
                dim2865Kuo3Init,
                dim2866Kuo3Init,
                dim2867Kuo3Init,
                dim2868Kuo3Init,
                dim2869Kuo3Init,
                dim2870Kuo3Init,
                dim2871Kuo3Init,
                dim2872Kuo3Init,
                dim2873Kuo3Init,
                dim2874Kuo3Init,
                dim2875Kuo3Init,
                dim2876Kuo3Init,
                dim2877Kuo3Init,
                dim2878Kuo3Init,
                dim2879Kuo3Init,
                dim2880Kuo3Init,
                dim2881Kuo3Init,
                dim2882Kuo3Init,
                dim2883Kuo3Init,
                dim2884Kuo3Init,
                dim2885Kuo3Init,
                dim2886Kuo3Init,
                dim2887Kuo3Init,
                dim2888Kuo3Init,
                dim2889Kuo3Init,
                dim2890Kuo3Init,
                dim2891Kuo3Init,
                dim2892Kuo3Init,
                dim2893Kuo3Init,
                dim2894Kuo3Init,
                dim2895Kuo3Init,
                dim2896Kuo3Init,
                dim2897Kuo3Init,
                dim2898Kuo3Init,
                dim2899Kuo3Init,
                dim2900Kuo3Init,
                dim2901Kuo3Init,
                dim2902Kuo3Init,
                dim2903Kuo3Init,
                dim2904Kuo3Init,
                dim2905Kuo3Init,
                dim2906Kuo3Init,
                dim2907Kuo3Init,
                dim2908Kuo3Init,
                dim2909Kuo3Init,
                dim2910Kuo3Init,
                dim2911Kuo3Init,
                dim2912Kuo3Init,
                dim2913Kuo3Init,
                dim2914Kuo3Init,
                dim2915Kuo3Init,
                dim2916Kuo3Init,
                dim2917Kuo3Init,
                dim2918Kuo3Init,
                dim2919Kuo3Init,
                dim2920Kuo3Init,
                dim2921Kuo3Init,
                dim2922Kuo3Init,
                dim2923Kuo3Init,
                dim2924Kuo3Init,
                dim2925Kuo3Init,
                dim2926Kuo3Init,
                dim2927Kuo3Init,
                dim2928Kuo3Init,
                dim2929Kuo3Init,
                dim2930Kuo3Init,
                dim2931Kuo3Init,
                dim2932Kuo3Init,
                dim2933Kuo3Init,
                dim2934Kuo3Init,
                dim2935Kuo3Init,
                dim2936Kuo3Init,
                dim2937Kuo3Init,
                dim2938Kuo3Init,
                dim2939Kuo3Init,
                dim2940Kuo3Init,
                dim2941Kuo3Init,
                dim2942Kuo3Init,
                dim2943Kuo3Init,
                dim2944Kuo3Init,
                dim2945Kuo3Init,
                dim2946Kuo3Init,
                dim2947Kuo3Init,
                dim2948Kuo3Init,
                dim2949Kuo3Init,
                dim2950Kuo3Init,
                dim2951Kuo3Init,
                dim2952Kuo3Init,
                dim2953Kuo3Init,
                dim2954Kuo3Init,
                dim2955Kuo3Init,
                dim2956Kuo3Init,
                dim2957Kuo3Init,
                dim2958Kuo3Init,
                dim2959Kuo3Init,
                dim2960Kuo3Init,
                dim2961Kuo3Init,
                dim2962Kuo3Init,
                dim2963Kuo3Init,
                dim2964Kuo3Init,
                dim2965Kuo3Init,
                dim2966Kuo3Init,
                dim2967Kuo3Init,
                dim2968Kuo3Init,
                dim2969Kuo3Init,
                dim2970Kuo3Init,
                dim2971Kuo3Init,
                dim2972Kuo3Init,
                dim2973Kuo3Init,
                dim2974Kuo3Init,
                dim2975Kuo3Init,
                dim2976Kuo3Init,
                dim2977Kuo3Init,
                dim2978Kuo3Init,
                dim2979Kuo3Init,
                dim2980Kuo3Init,
                dim2981Kuo3Init,
                dim2982Kuo3Init,
                dim2983Kuo3Init,
                dim2984Kuo3Init,
                dim2985Kuo3Init,
                dim2986Kuo3Init,
                dim2987Kuo3Init,
                dim2988Kuo3Init,
                dim2989Kuo3Init,
                dim2990Kuo3Init,
                dim2991Kuo3Init,
                dim2992Kuo3Init,
                dim2993Kuo3Init,
                dim2994Kuo3Init,
                dim2995Kuo3Init,
                dim2996Kuo3Init,
                dim2997Kuo3Init,
                dim2998Kuo3Init,
                dim2999Kuo3Init,
                dim3000Kuo3Init,
                dim3001Kuo3Init,
                dim3002Kuo3Init,
                dim3003Kuo3Init,
                dim3004Kuo3Init,
                dim3005Kuo3Init,
                dim3006Kuo3Init,
                dim3007Kuo3Init,
                dim3008Kuo3Init,
                dim3009Kuo3Init,
                dim3010Kuo3Init,
                dim3011Kuo3Init,
                dim3012Kuo3Init,
                dim3013Kuo3Init,
                dim3014Kuo3Init,
                dim3015Kuo3Init,
                dim3016Kuo3Init,
                dim3017Kuo3Init,
                dim3018Kuo3Init,
                dim3019Kuo3Init,
                dim3020Kuo3Init,
                dim3021Kuo3Init,
                dim3022Kuo3Init,
                dim3023Kuo3Init,
                dim3024Kuo3Init,
                dim3025Kuo3Init,
                dim3026Kuo3Init,
                dim3027Kuo3Init,
                dim3028Kuo3Init,
                dim3029Kuo3Init,
                dim3030Kuo3Init,
                dim3031Kuo3Init,
                dim3032Kuo3Init,
                dim3033Kuo3Init,
                dim3034Kuo3Init,
                dim3035Kuo3Init,
                dim3036Kuo3Init,
                dim3037Kuo3Init,
                dim3038Kuo3Init,
                dim3039Kuo3Init,
                dim3040Kuo3Init,
                dim3041Kuo3Init,
                dim3042Kuo3Init,
                dim3043Kuo3Init,
                dim3044Kuo3Init,
                dim3045Kuo3Init,
                dim3046Kuo3Init,
                dim3047Kuo3Init,
                dim3048Kuo3Init,
                dim3049Kuo3Init,
                dim3050Kuo3Init,
                dim3051Kuo3Init,
                dim3052Kuo3Init,
                dim3053Kuo3Init,
                dim3054Kuo3Init,
                dim3055Kuo3Init,
                dim3056Kuo3Init,
                dim3057Kuo3Init,
                dim3058Kuo3Init,
                dim3059Kuo3Init,
                dim3060Kuo3Init,
                dim3061Kuo3Init,
                dim3062Kuo3Init,
                dim3063Kuo3Init,
                dim3064Kuo3Init,
                dim3065Kuo3Init,
                dim3066Kuo3Init,
                dim3067Kuo3Init,
                dim3068Kuo3Init,
                dim3069Kuo3Init,
                dim3070Kuo3Init,
                dim3071Kuo3Init,
                dim3072Kuo3Init,
                dim3073Kuo3Init,
                dim3074Kuo3Init,
                dim3075Kuo3Init,
                dim3076Kuo3Init,
                dim3077Kuo3Init,
                dim3078Kuo3Init,
                dim3079Kuo3Init,
                dim3080Kuo3Init,
                dim3081Kuo3Init,
                dim3082Kuo3Init,
                dim3083Kuo3Init,
                dim3084Kuo3Init,
                dim3085Kuo3Init,
                dim3086Kuo3Init,
                dim3087Kuo3Init,
                dim3088Kuo3Init,
                dim3089Kuo3Init,
                dim3090Kuo3Init,
                dim3091Kuo3Init,
                dim3092Kuo3Init,
                dim3093Kuo3Init,
                dim3094Kuo3Init,
                dim3095Kuo3Init,
                dim3096Kuo3Init,
                dim3097Kuo3Init,
                dim3098Kuo3Init,
                dim3099Kuo3Init,
                dim3100Kuo3Init,
                dim3101Kuo3Init,
                dim3102Kuo3Init,
                dim3103Kuo3Init,
                dim3104Kuo3Init,
                dim3105Kuo3Init,
                dim3106Kuo3Init,
                dim3107Kuo3Init,
                dim3108Kuo3Init,
                dim3109Kuo3Init,
                dim3110Kuo3Init,
                dim3111Kuo3Init,
                dim3112Kuo3Init,
                dim3113Kuo3Init,
                dim3114Kuo3Init,
                dim3115Kuo3Init,
                dim3116Kuo3Init,
                dim3117Kuo3Init,
                dim3118Kuo3Init,
                dim3119Kuo3Init,
                dim3120Kuo3Init,
                dim3121Kuo3Init,
                dim3122Kuo3Init,
                dim3123Kuo3Init,
                dim3124Kuo3Init,
                dim3125Kuo3Init,
                dim3126Kuo3Init,
                dim3127Kuo3Init,
                dim3128Kuo3Init,
                dim3129Kuo3Init,
                dim3130Kuo3Init,
                dim3131Kuo3Init,
                dim3132Kuo3Init,
                dim3133Kuo3Init,
                dim3134Kuo3Init,
                dim3135Kuo3Init,
                dim3136Kuo3Init,
                dim3137Kuo3Init,
                dim3138Kuo3Init,
                dim3139Kuo3Init,
                dim3140Kuo3Init,
                dim3141Kuo3Init,
                dim3142Kuo3Init,
                dim3143Kuo3Init,
                dim3144Kuo3Init,
                dim3145Kuo3Init,
                dim3146Kuo3Init,
                dim3147Kuo3Init,
                dim3148Kuo3Init,
                dim3149Kuo3Init,
                dim3150Kuo3Init,
                dim3151Kuo3Init,
                dim3152Kuo3Init,
                dim3153Kuo3Init,
                dim3154Kuo3Init,
                dim3155Kuo3Init,
                dim3156Kuo3Init,
                dim3157Kuo3Init,
                dim3158Kuo3Init,
                dim3159Kuo3Init,
                dim3160Kuo3Init,
                dim3161Kuo3Init,
                dim3162Kuo3Init,
                dim3163Kuo3Init,
                dim3164Kuo3Init,
                dim3165Kuo3Init,
                dim3166Kuo3Init,
                dim3167Kuo3Init,
                dim3168Kuo3Init,
                dim3169Kuo3Init,
                dim3170Kuo3Init,
                dim3171Kuo3Init,
                dim3172Kuo3Init,
                dim3173Kuo3Init,
                dim3174Kuo3Init,
                dim3175Kuo3Init,
                dim3176Kuo3Init,
                dim3177Kuo3Init,
                dim3178Kuo3Init,
                dim3179Kuo3Init,
                dim3180Kuo3Init,
                dim3181Kuo3Init,
                dim3182Kuo3Init,
                dim3183Kuo3Init,
                dim3184Kuo3Init,
                dim3185Kuo3Init,
                dim3186Kuo3Init,
                dim3187Kuo3Init,
                dim3188Kuo3Init,
                dim3189Kuo3Init,
                dim3190Kuo3Init,
                dim3191Kuo3Init,
                dim3192Kuo3Init,
                dim3193Kuo3Init,
                dim3194Kuo3Init,
                dim3195Kuo3Init,
                dim3196Kuo3Init,
                dim3197Kuo3Init,
                dim3198Kuo3Init,
                dim3199Kuo3Init,
                dim3200Kuo3Init,
                dim3201Kuo3Init,
                dim3202Kuo3Init,
                dim3203Kuo3Init,
                dim3204Kuo3Init,
                dim3205Kuo3Init,
                dim3206Kuo3Init,
                dim3207Kuo3Init,
                dim3208Kuo3Init,
                dim3209Kuo3Init,
                dim3210Kuo3Init,
                dim3211Kuo3Init,
                dim3212Kuo3Init,
                dim3213Kuo3Init,
                dim3214Kuo3Init,
                dim3215Kuo3Init,
                dim3216Kuo3Init,
                dim3217Kuo3Init,
                dim3218Kuo3Init,
                dim3219Kuo3Init,
                dim3220Kuo3Init,
                dim3221Kuo3Init,
                dim3222Kuo3Init,
                dim3223Kuo3Init,
                dim3224Kuo3Init,
                dim3225Kuo3Init,
                dim3226Kuo3Init,
                dim3227Kuo3Init,
                dim3228Kuo3Init,
                dim3229Kuo3Init,
                dim3230Kuo3Init,
                dim3231Kuo3Init,
                dim3232Kuo3Init,
                dim3233Kuo3Init,
                dim3234Kuo3Init,
                dim3235Kuo3Init,
                dim3236Kuo3Init,
                dim3237Kuo3Init,
                dim3238Kuo3Init,
                dim3239Kuo3Init,
                dim3240Kuo3Init,
                dim3241Kuo3Init,
                dim3242Kuo3Init,
                dim3243Kuo3Init,
                dim3244Kuo3Init,
                dim3245Kuo3Init,
                dim3246Kuo3Init,
                dim3247Kuo3Init,
                dim3248Kuo3Init,
                dim3249Kuo3Init,
                dim3250Kuo3Init,
                dim3251Kuo3Init,
                dim3252Kuo3Init,
                dim3253Kuo3Init,
                dim3254Kuo3Init,
                dim3255Kuo3Init,
                dim3256Kuo3Init,
                dim3257Kuo3Init,
                dim3258Kuo3Init,
                dim3259Kuo3Init,
                dim3260Kuo3Init,
                dim3261Kuo3Init,
                dim3262Kuo3Init,
                dim3263Kuo3Init,
                dim3264Kuo3Init,
                dim3265Kuo3Init,
                dim3266Kuo3Init,
                dim3267Kuo3Init,
                dim3268Kuo3Init,
                dim3269Kuo3Init,
                dim3270Kuo3Init,
                dim3271Kuo3Init,
                dim3272Kuo3Init,
                dim3273Kuo3Init,
                dim3274Kuo3Init,
                dim3275Kuo3Init,
                dim3276Kuo3Init,
                dim3277Kuo3Init,
                dim3278Kuo3Init,
                dim3279Kuo3Init,
                dim3280Kuo3Init,
                dim3281Kuo3Init,
                dim3282Kuo3Init,
                dim3283Kuo3Init,
                dim3284Kuo3Init,
                dim3285Kuo3Init,
                dim3286Kuo3Init,
                dim3287Kuo3Init,
                dim3288Kuo3Init,
                dim3289Kuo3Init,
                dim3290Kuo3Init,
                dim3291Kuo3Init,
                dim3292Kuo3Init,
                dim3293Kuo3Init,
                dim3294Kuo3Init,
                dim3295Kuo3Init,
                dim3296Kuo3Init,
                dim3297Kuo3Init,
                dim3298Kuo3Init,
                dim3299Kuo3Init,
                dim3300Kuo3Init,
                dim3301Kuo3Init,
                dim3302Kuo3Init,
                dim3303Kuo3Init,
                dim3304Kuo3Init,
                dim3305Kuo3Init,
                dim3306Kuo3Init,
                dim3307Kuo3Init,
                dim3308Kuo3Init,
                dim3309Kuo3Init,
                dim3310Kuo3Init,
                dim3311Kuo3Init,
                dim3312Kuo3Init,
                dim3313Kuo3Init,
                dim3314Kuo3Init,
                dim3315Kuo3Init,
                dim3316Kuo3Init,
                dim3317Kuo3Init,
                dim3318Kuo3Init,
                dim3319Kuo3Init,
                dim3320Kuo3Init,
                dim3321Kuo3Init,
                dim3322Kuo3Init,
                dim3323Kuo3Init,
                dim3324Kuo3Init,
                dim3325Kuo3Init,
                dim3326Kuo3Init,
                dim3327Kuo3Init,
                dim3328Kuo3Init,
                dim3329Kuo3Init,
                dim3330Kuo3Init,
                dim3331Kuo3Init,
                dim3332Kuo3Init,
                dim3333Kuo3Init,
                dim3334Kuo3Init,
                dim3335Kuo3Init,
                dim3336Kuo3Init,
                dim3337Kuo3Init,
                dim3338Kuo3Init,
                dim3339Kuo3Init,
                dim3340Kuo3Init,
                dim3341Kuo3Init,
                dim3342Kuo3Init,
                dim3343Kuo3Init,
                dim3344Kuo3Init,
                dim3345Kuo3Init,
                dim3346Kuo3Init,
                dim3347Kuo3Init,
                dim3348Kuo3Init,
                dim3349Kuo3Init,
                dim3350Kuo3Init,
                dim3351Kuo3Init,
                dim3352Kuo3Init,
                dim3353Kuo3Init,
                dim3354Kuo3Init,
                dim3355Kuo3Init,
                dim3356Kuo3Init,
                dim3357Kuo3Init,
                dim3358Kuo3Init,
                dim3359Kuo3Init,
                dim3360Kuo3Init,
                dim3361Kuo3Init,
                dim3362Kuo3Init,
                dim3363Kuo3Init,
                dim3364Kuo3Init,
                dim3365Kuo3Init,
                dim3366Kuo3Init,
                dim3367Kuo3Init,
                dim3368Kuo3Init,
                dim3369Kuo3Init,
                dim3370Kuo3Init,
                dim3371Kuo3Init,
                dim3372Kuo3Init,
                dim3373Kuo3Init,
                dim3374Kuo3Init,
                dim3375Kuo3Init,
                dim3376Kuo3Init,
                dim3377Kuo3Init,
                dim3378Kuo3Init,
                dim3379Kuo3Init,
                dim3380Kuo3Init,
                dim3381Kuo3Init,
                dim3382Kuo3Init,
                dim3383Kuo3Init,
                dim3384Kuo3Init,
                dim3385Kuo3Init,
                dim3386Kuo3Init,
                dim3387Kuo3Init,
                dim3388Kuo3Init,
                dim3389Kuo3Init,
                dim3390Kuo3Init,
                dim3391Kuo3Init,
                dim3392Kuo3Init,
                dim3393Kuo3Init,
                dim3394Kuo3Init,
                dim3395Kuo3Init,
                dim3396Kuo3Init,
                dim3397Kuo3Init,
                dim3398Kuo3Init,
                dim3399Kuo3Init,
                dim3400Kuo3Init,
                dim3401Kuo3Init,
                dim3402Kuo3Init,
                dim3403Kuo3Init,
                dim3404Kuo3Init,
                dim3405Kuo3Init,
                dim3406Kuo3Init,
                dim3407Kuo3Init,
                dim3408Kuo3Init,
                dim3409Kuo3Init,
                dim3410Kuo3Init,
                dim3411Kuo3Init,
                dim3412Kuo3Init,
                dim3413Kuo3Init,
                dim3414Kuo3Init,
                dim3415Kuo3Init,
                dim3416Kuo3Init,
                dim3417Kuo3Init,
                dim3418Kuo3Init,
                dim3419Kuo3Init,
                dim3420Kuo3Init,
                dim3421Kuo3Init,
                dim3422Kuo3Init,
                dim3423Kuo3Init,
                dim3424Kuo3Init,
                dim3425Kuo3Init,
                dim3426Kuo3Init,
                dim3427Kuo3Init,
                dim3428Kuo3Init,
                dim3429Kuo3Init,
                dim3430Kuo3Init,
                dim3431Kuo3Init,
                dim3432Kuo3Init,
                dim3433Kuo3Init,
                dim3434Kuo3Init,
                dim3435Kuo3Init,
                dim3436Kuo3Init,
                dim3437Kuo3Init,
                dim3438Kuo3Init,
                dim3439Kuo3Init,
                dim3440Kuo3Init,
                dim3441Kuo3Init,
                dim3442Kuo3Init,
                dim3443Kuo3Init,
                dim3444Kuo3Init,
                dim3445Kuo3Init,
                dim3446Kuo3Init,
                dim3447Kuo3Init,
                dim3448Kuo3Init,
                dim3449Kuo3Init,
                dim3450Kuo3Init,
                dim3451Kuo3Init,
                dim3452Kuo3Init,
                dim3453Kuo3Init,
                dim3454Kuo3Init,
                dim3455Kuo3Init,
                dim3456Kuo3Init,
                dim3457Kuo3Init,
                dim3458Kuo3Init,
                dim3459Kuo3Init,
                dim3460Kuo3Init,
                dim3461Kuo3Init,
                dim3462Kuo3Init,
                dim3463Kuo3Init,
                dim3464Kuo3Init,
                dim3465Kuo3Init,
                dim3466Kuo3Init,
                dim3467Kuo3Init,
                dim3468Kuo3Init,
                dim3469Kuo3Init,
                dim3470Kuo3Init,
                dim3471Kuo3Init,
                dim3472Kuo3Init,
                dim3473Kuo3Init,
                dim3474Kuo3Init,
                dim3475Kuo3Init,
                dim3476Kuo3Init,
                dim3477Kuo3Init,
                dim3478Kuo3Init,
                dim3479Kuo3Init,
                dim3480Kuo3Init,
                dim3481Kuo3Init,
                dim3482Kuo3Init,
                dim3483Kuo3Init,
                dim3484Kuo3Init,
                dim3485Kuo3Init,
                dim3486Kuo3Init,
                dim3487Kuo3Init,
                dim3488Kuo3Init,
                dim3489Kuo3Init,
                dim3490Kuo3Init,
                dim3491Kuo3Init,
                dim3492Kuo3Init,
                dim3493Kuo3Init,
                dim3494Kuo3Init,
                dim3495Kuo3Init,
                dim3496Kuo3Init,
                dim3497Kuo3Init,
                dim3498Kuo3Init,
                dim3499Kuo3Init,
                dim3500Kuo3Init,
                dim3501Kuo3Init,
                dim3502Kuo3Init,
                dim3503Kuo3Init,
                dim3504Kuo3Init,
                dim3505Kuo3Init,
                dim3506Kuo3Init,
                dim3507Kuo3Init,
                dim3508Kuo3Init,
                dim3509Kuo3Init,
                dim3510Kuo3Init,
                dim3511Kuo3Init,
                dim3512Kuo3Init,
                dim3513Kuo3Init,
                dim3514Kuo3Init,
                dim3515Kuo3Init,
                dim3516Kuo3Init,
                dim3517Kuo3Init,
                dim3518Kuo3Init,
                dim3519Kuo3Init,
                dim3520Kuo3Init,
                dim3521Kuo3Init,
                dim3522Kuo3Init,
                dim3523Kuo3Init,
                dim3524Kuo3Init,
                dim3525Kuo3Init,
                dim3526Kuo3Init,
                dim3527Kuo3Init,
                dim3528Kuo3Init,
                dim3529Kuo3Init,
                dim3530Kuo3Init,
                dim3531Kuo3Init,
                dim3532Kuo3Init,
                dim3533Kuo3Init,
                dim3534Kuo3Init,
                dim3535Kuo3Init,
                dim3536Kuo3Init,
                dim3537Kuo3Init,
                dim3538Kuo3Init,
                dim3539Kuo3Init,
                dim3540Kuo3Init,
                dim3541Kuo3Init,
                dim3542Kuo3Init,
                dim3543Kuo3Init,
                dim3544Kuo3Init,
                dim3545Kuo3Init,
                dim3546Kuo3Init,
                dim3547Kuo3Init,
                dim3548Kuo3Init,
                dim3549Kuo3Init,
                dim3550Kuo3Init,
                dim3551Kuo3Init,
                dim3552Kuo3Init,
                dim3553Kuo3Init,
                dim3554Kuo3Init,
                dim3555Kuo3Init,
                dim3556Kuo3Init,
                dim3557Kuo3Init,
                dim3558Kuo3Init,
                dim3559Kuo3Init,
                dim3560Kuo3Init,
                dim3561Kuo3Init,
                dim3562Kuo3Init,
                dim3563Kuo3Init,
                dim3564Kuo3Init,
                dim3565Kuo3Init,
                dim3566Kuo3Init,
                dim3567Kuo3Init,
                dim3568Kuo3Init,
                dim3569Kuo3Init,
                dim3570Kuo3Init,
                dim3571Kuo3Init,
                dim3572Kuo3Init,
                dim3573Kuo3Init,
                dim3574Kuo3Init,
                dim3575Kuo3Init,
                dim3576Kuo3Init,
                dim3577Kuo3Init,
                dim3578Kuo3Init,
                dim3579Kuo3Init,
                dim3580Kuo3Init,
                dim3581Kuo3Init,
                dim3582Kuo3Init,
                dim3583Kuo3Init,
                dim3584Kuo3Init,
                dim3585Kuo3Init,
                dim3586Kuo3Init,
                dim3587Kuo3Init,
                dim3588Kuo3Init,
                dim3589Kuo3Init,
                dim3590Kuo3Init,
                dim3591Kuo3Init,
                dim3592Kuo3Init,
                dim3593Kuo3Init,
                dim3594Kuo3Init,
                dim3595Kuo3Init,
                dim3596Kuo3Init,
                dim3597Kuo3Init,
                dim3598Kuo3Init,
                dim3599Kuo3Init,
                dim3600Kuo3Init,
                dim3601Kuo3Init,
                dim3602Kuo3Init,
                dim3603Kuo3Init,
                dim3604Kuo3Init,
                dim3605Kuo3Init,
                dim3606Kuo3Init,
                dim3607Kuo3Init,
                dim3608Kuo3Init,
                dim3609Kuo3Init,
                dim3610Kuo3Init,
                dim3611Kuo3Init,
                dim3612Kuo3Init,
                dim3613Kuo3Init,
                dim3614Kuo3Init,
                dim3615Kuo3Init,
                dim3616Kuo3Init,
                dim3617Kuo3Init,
                dim3618Kuo3Init,
                dim3619Kuo3Init,
                dim3620Kuo3Init,
                dim3621Kuo3Init,
                dim3622Kuo3Init,
                dim3623Kuo3Init,
                dim3624Kuo3Init,
                dim3625Kuo3Init,
                dim3626Kuo3Init,
                dim3627Kuo3Init,
                dim3628Kuo3Init,
                dim3629Kuo3Init,
                dim3630Kuo3Init,
                dim3631Kuo3Init,
                dim3632Kuo3Init,
                dim3633Kuo3Init,
                dim3634Kuo3Init,
                dim3635Kuo3Init,
                dim3636Kuo3Init,
                dim3637Kuo3Init,
                dim3638Kuo3Init,
                dim3639Kuo3Init,
                dim3640Kuo3Init,
                dim3641Kuo3Init,
                dim3642Kuo3Init,
                dim3643Kuo3Init,
                dim3644Kuo3Init,
                dim3645Kuo3Init,
                dim3646Kuo3Init,
                dim3647Kuo3Init,
                dim3648Kuo3Init,
                dim3649Kuo3Init,
                dim3650Kuo3Init,
                dim3651Kuo3Init,
                dim3652Kuo3Init,
                dim3653Kuo3Init,
                dim3654Kuo3Init,
                dim3655Kuo3Init,
                dim3656Kuo3Init,
                dim3657Kuo3Init,
                dim3658Kuo3Init,
                dim3659Kuo3Init,
                dim3660Kuo3Init,
                dim3661Kuo3Init,
                dim3662Kuo3Init,
                dim3663Kuo3Init,
                dim3664Kuo3Init,
                dim3665Kuo3Init,
                dim3666Kuo3Init,
                dim3667Kuo3Init,
                dim3668Kuo3Init,
                dim3669Kuo3Init,
                dim3670Kuo3Init,
                dim3671Kuo3Init,
                dim3672Kuo3Init,
                dim3673Kuo3Init,
                dim3674Kuo3Init,
                dim3675Kuo3Init,
                dim3676Kuo3Init,
                dim3677Kuo3Init,
                dim3678Kuo3Init,
                dim3679Kuo3Init,
                dim3680Kuo3Init,
                dim3681Kuo3Init,
                dim3682Kuo3Init,
                dim3683Kuo3Init,
                dim3684Kuo3Init,
                dim3685Kuo3Init,
                dim3686Kuo3Init,
                dim3687Kuo3Init,
                dim3688Kuo3Init,
                dim3689Kuo3Init,
                dim3690Kuo3Init,
                dim3691Kuo3Init,
                dim3692Kuo3Init,
                dim3693Kuo3Init,
                dim3694Kuo3Init,
                dim3695Kuo3Init,
                dim3696Kuo3Init,
                dim3697Kuo3Init,
                dim3698Kuo3Init,
                dim3699Kuo3Init,
                dim3700Kuo3Init,
                dim3701Kuo3Init,
                dim3702Kuo3Init,
                dim3703Kuo3Init,
                dim3704Kuo3Init,
                dim3705Kuo3Init,
                dim3706Kuo3Init,
                dim3707Kuo3Init,
                dim3708Kuo3Init,
                dim3709Kuo3Init,
                dim3710Kuo3Init,
                dim3711Kuo3Init,
                dim3712Kuo3Init,
                dim3713Kuo3Init,
                dim3714Kuo3Init,
                dim3715Kuo3Init,
                dim3716Kuo3Init,
                dim3717Kuo3Init,
                dim3718Kuo3Init,
                dim3719Kuo3Init,
                dim3720Kuo3Init,
                dim3721Kuo3Init,
                dim3722Kuo3Init,
                dim3723Kuo3Init,
                dim3724Kuo3Init,
                dim3725Kuo3Init,
                dim3726Kuo3Init,
                dim3727Kuo3Init,
                dim3728Kuo3Init,
                dim3729Kuo3Init,
                dim3730Kuo3Init,
                dim3731Kuo3Init,
                dim3732Kuo3Init,
                dim3733Kuo3Init,
                dim3734Kuo3Init,
                dim3735Kuo3Init,
                dim3736Kuo3Init,
                dim3737Kuo3Init,
                dim3738Kuo3Init,
                dim3739Kuo3Init,
                dim3740Kuo3Init,
                dim3741Kuo3Init,
                dim3742Kuo3Init,
                dim3743Kuo3Init,
                dim3744Kuo3Init,
                dim3745Kuo3Init,
                dim3746Kuo3Init,
                dim3747Kuo3Init,
                dim3748Kuo3Init,
                dim3749Kuo3Init,
                dim3750Kuo3Init,
                dim3751Kuo3Init,
                dim3752Kuo3Init,
                dim3753Kuo3Init,
                dim3754Kuo3Init,
                dim3755Kuo3Init,
                dim3756Kuo3Init,
                dim3757Kuo3Init,
                dim3758Kuo3Init,
                dim3759Kuo3Init,
                dim3760Kuo3Init,
                dim3761Kuo3Init,
                dim3762Kuo3Init,
                dim3763Kuo3Init,
                dim3764Kuo3Init,
                dim3765Kuo3Init,
                dim3766Kuo3Init,
                dim3767Kuo3Init,
                dim3768Kuo3Init,
                dim3769Kuo3Init,
                dim3770Kuo3Init,
                dim3771Kuo3Init,
                dim3772Kuo3Init,
                dim3773Kuo3Init,
                dim3774Kuo3Init,
                dim3775Kuo3Init,
                dim3776Kuo3Init,
                dim3777Kuo3Init,
                dim3778Kuo3Init,
                dim3779Kuo3Init,
                dim3780Kuo3Init,
                dim3781Kuo3Init,
                dim3782Kuo3Init,
                dim3783Kuo3Init,
                dim3784Kuo3Init,
                dim3785Kuo3Init,
                dim3786Kuo3Init,
                dim3787Kuo3Init,
                dim3788Kuo3Init,
                dim3789Kuo3Init,
                dim3790Kuo3Init,
                dim3791Kuo3Init,
                dim3792Kuo3Init,
                dim3793Kuo3Init,
                dim3794Kuo3Init,
                dim3795Kuo3Init,
                dim3796Kuo3Init,
                dim3797Kuo3Init,
                dim3798Kuo3Init,
                dim3799Kuo3Init,
                dim3800Kuo3Init,
                dim3801Kuo3Init,
                dim3802Kuo3Init,
                dim3803Kuo3Init,
                dim3804Kuo3Init,
                dim3805Kuo3Init,
                dim3806Kuo3Init,
                dim3807Kuo3Init,
                dim3808Kuo3Init,
                dim3809Kuo3Init,
                dim3810Kuo3Init,
                dim3811Kuo3Init,
                dim3812Kuo3Init,
                dim3813Kuo3Init,
                dim3814Kuo3Init,
                dim3815Kuo3Init,
                dim3816Kuo3Init,
                dim3817Kuo3Init,
                dim3818Kuo3Init,
                dim3819Kuo3Init,
                dim3820Kuo3Init,
                dim3821Kuo3Init,
                dim3822Kuo3Init,
                dim3823Kuo3Init,
                dim3824Kuo3Init,
                dim3825Kuo3Init,
                dim3826Kuo3Init,
                dim3827Kuo3Init,
                dim3828Kuo3Init,
                dim3829Kuo3Init,
                dim3830Kuo3Init,
                dim3831Kuo3Init,
                dim3832Kuo3Init,
                dim3833Kuo3Init,
                dim3834Kuo3Init,
                dim3835Kuo3Init,
                dim3836Kuo3Init,
                dim3837Kuo3Init,
                dim3838Kuo3Init,
                dim3839Kuo3Init,
                dim3840Kuo3Init,
                dim3841Kuo3Init,
                dim3842Kuo3Init,
                dim3843Kuo3Init,
                dim3844Kuo3Init,
                dim3845Kuo3Init,
                dim3846Kuo3Init,
                dim3847Kuo3Init,
                dim3848Kuo3Init,
                dim3849Kuo3Init,
                dim3850Kuo3Init,
                dim3851Kuo3Init,
                dim3852Kuo3Init,
                dim3853Kuo3Init,
                dim3854Kuo3Init,
                dim3855Kuo3Init,
                dim3856Kuo3Init,
                dim3857Kuo3Init,
                dim3858Kuo3Init,
                dim3859Kuo3Init,
                dim3860Kuo3Init,
                dim3861Kuo3Init,
                dim3862Kuo3Init,
                dim3863Kuo3Init,
                dim3864Kuo3Init,
                dim3865Kuo3Init,
                dim3866Kuo3Init,
                dim3867Kuo3Init,
                dim3868Kuo3Init,
                dim3869Kuo3Init,
                dim3870Kuo3Init,
                dim3871Kuo3Init,
                dim3872Kuo3Init,
                dim3873Kuo3Init,
                dim3874Kuo3Init,
                dim3875Kuo3Init,
                dim3876Kuo3Init,
                dim3877Kuo3Init,
                dim3878Kuo3Init,
                dim3879Kuo3Init,
                dim3880Kuo3Init,
                dim3881Kuo3Init,
                dim3882Kuo3Init,
                dim3883Kuo3Init,
                dim3884Kuo3Init,
                dim3885Kuo3Init,
                dim3886Kuo3Init,
                dim3887Kuo3Init,
                dim3888Kuo3Init,
                dim3889Kuo3Init,
                dim3890Kuo3Init,
                dim3891Kuo3Init,
                dim3892Kuo3Init,
                dim3893Kuo3Init,
                dim3894Kuo3Init,
                dim3895Kuo3Init,
                dim3896Kuo3Init,
                dim3897Kuo3Init,
                dim3898Kuo3Init,
                dim3899Kuo3Init,
                dim3900Kuo3Init,
                dim3901Kuo3Init,
                dim3902Kuo3Init,
                dim3903Kuo3Init,
                dim3904Kuo3Init,
                dim3905Kuo3Init,
                dim3906Kuo3Init,
                dim3907Kuo3Init,
                dim3908Kuo3Init,
                dim3909Kuo3Init,
                dim3910Kuo3Init,
                dim3911Kuo3Init,
                dim3912Kuo3Init,
                dim3913Kuo3Init,
                dim3914Kuo3Init,
                dim3915Kuo3Init,
                dim3916Kuo3Init,
                dim3917Kuo3Init,
                dim3918Kuo3Init,
                dim3919Kuo3Init,
                dim3920Kuo3Init,
                dim3921Kuo3Init,
                dim3922Kuo3Init,
                dim3923Kuo3Init,
                dim3924Kuo3Init,
                dim3925Kuo3Init,
                dim3926Kuo3Init,
                dim3927Kuo3Init,
                dim3928Kuo3Init,
                dim3929Kuo3Init,
                dim3930Kuo3Init,
                dim3931Kuo3Init,
                dim3932Kuo3Init,
                dim3933Kuo3Init,
                dim3934Kuo3Init,
                dim3935Kuo3Init,
                dim3936Kuo3Init,
                dim3937Kuo3Init,
                dim3938Kuo3Init,
                dim3939Kuo3Init,
                dim3940Kuo3Init,
                dim3941Kuo3Init,
                dim3942Kuo3Init,
                dim3943Kuo3Init,
                dim3944Kuo3Init,
                dim3945Kuo3Init,
                dim3946Kuo3Init,
                dim3947Kuo3Init,
                dim3948Kuo3Init,
                dim3949Kuo3Init,
                dim3950Kuo3Init,
                dim3951Kuo3Init,
                dim3952Kuo3Init,
                dim3953Kuo3Init,
                dim3954Kuo3Init,
                dim3955Kuo3Init,
                dim3956Kuo3Init,
                dim3957Kuo3Init,
                dim3958Kuo3Init,
                dim3959Kuo3Init,
                dim3960Kuo3Init,
                dim3961Kuo3Init,
                dim3962Kuo3Init,
                dim3963Kuo3Init,
                dim3964Kuo3Init,
                dim3965Kuo3Init,
                dim3966Kuo3Init,
                dim3967Kuo3Init,
                dim3968Kuo3Init,
                dim3969Kuo3Init,
                dim3970Kuo3Init,
                dim3971Kuo3Init,
                dim3972Kuo3Init,
                dim3973Kuo3Init,
                dim3974Kuo3Init,
                dim3975Kuo3Init,
                dim3976Kuo3Init,
                dim3977Kuo3Init,
                dim3978Kuo3Init,
                dim3979Kuo3Init,
                dim3980Kuo3Init,
                dim3981Kuo3Init,
                dim3982Kuo3Init,
                dim3983Kuo3Init,
                dim3984Kuo3Init,
                dim3985Kuo3Init,
                dim3986Kuo3Init,
                dim3987Kuo3Init,
                dim3988Kuo3Init,
                dim3989Kuo3Init,
                dim3990Kuo3Init,
                dim3991Kuo3Init,
                dim3992Kuo3Init,
                dim3993Kuo3Init,
                dim3994Kuo3Init,
                dim3995Kuo3Init,
                dim3996Kuo3Init,
                dim3997Kuo3Init,
                dim3998Kuo3Init,
                dim3999Kuo3Init,
                dim4000Kuo3Init,
                dim4001Kuo3Init,
                dim4002Kuo3Init,
                dim4003Kuo3Init,
                dim4004Kuo3Init,
                dim4005Kuo3Init,
                dim4006Kuo3Init,
                dim4007Kuo3Init,
                dim4008Kuo3Init,
                dim4009Kuo3Init,
                dim4010Kuo3Init,
                dim4011Kuo3Init,
                dim4012Kuo3Init,
                dim4013Kuo3Init,
                dim4014Kuo3Init,
                dim4015Kuo3Init,
                dim4016Kuo3Init,
                dim4017Kuo3Init,
                dim4018Kuo3Init,
                dim4019Kuo3Init,
                dim4020Kuo3Init,
                dim4021Kuo3Init,
                dim4022Kuo3Init,
                dim4023Kuo3Init,
                dim4024Kuo3Init,
                dim4025Kuo3Init,
                dim4026Kuo3Init,
                dim4027Kuo3Init,
                dim4028Kuo3Init,
                dim4029Kuo3Init,
                dim4030Kuo3Init,
                dim4031Kuo3Init,
                dim4032Kuo3Init,
                dim4033Kuo3Init,
                dim4034Kuo3Init,
                dim4035Kuo3Init,
                dim4036Kuo3Init,
                dim4037Kuo3Init,
                dim4038Kuo3Init,
                dim4039Kuo3Init,
                dim4040Kuo3Init,
                dim4041Kuo3Init,
                dim4042Kuo3Init,
                dim4043Kuo3Init,
                dim4044Kuo3Init,
                dim4045Kuo3Init,
                dim4046Kuo3Init,
                dim4047Kuo3Init,
                dim4048Kuo3Init,
                dim4049Kuo3Init,
                dim4050Kuo3Init,
                dim4051Kuo3Init,
                dim4052Kuo3Init,
                dim4053Kuo3Init,
                dim4054Kuo3Init,
                dim4055Kuo3Init,
                dim4056Kuo3Init,
                dim4057Kuo3Init,
                dim4058Kuo3Init,
                dim4059Kuo3Init,
                dim4060Kuo3Init,
                dim4061Kuo3Init,
                dim4062Kuo3Init,
                dim4063Kuo3Init,
                dim4064Kuo3Init,
                dim4065Kuo3Init,
                dim4066Kuo3Init,
                dim4067Kuo3Init,
                dim4068Kuo3Init,
                dim4069Kuo3Init,
                dim4070Kuo3Init,
                dim4071Kuo3Init,
                dim4072Kuo3Init,
                dim4073Kuo3Init,
                dim4074Kuo3Init,
                dim4075Kuo3Init,
                dim4076Kuo3Init,
                dim4077Kuo3Init,
                dim4078Kuo3Init,
                dim4079Kuo3Init,
                dim4080Kuo3Init,
                dim4081Kuo3Init,
                dim4082Kuo3Init,
                dim4083Kuo3Init,
                dim4084Kuo3Init,
                dim4085Kuo3Init,
                dim4086Kuo3Init,
                dim4087Kuo3Init,
                dim4088Kuo3Init,
                dim4089Kuo3Init,
                dim4090Kuo3Init,
                dim4091Kuo3Init,
                dim4092Kuo3Init,
                dim4093Kuo3Init,
                dim4094Kuo3Init,
                dim4095Kuo3Init,
                dim4096Kuo3Init,
                dim4097Kuo3Init,
                dim4098Kuo3Init,
                dim4099Kuo3Init,
                dim4100Kuo3Init,
                dim4101Kuo3Init,
                dim4102Kuo3Init,
                dim4103Kuo3Init,
                dim4104Kuo3Init,
                dim4105Kuo3Init,
                dim4106Kuo3Init,
                dim4107Kuo3Init,
                dim4108Kuo3Init,
                dim4109Kuo3Init,
                dim4110Kuo3Init,
                dim4111Kuo3Init,
                dim4112Kuo3Init,
                dim4113Kuo3Init,
                dim4114Kuo3Init,
                dim4115Kuo3Init,
                dim4116Kuo3Init,
                dim4117Kuo3Init,
                dim4118Kuo3Init,
                dim4119Kuo3Init,
                dim4120Kuo3Init,
                dim4121Kuo3Init,
                dim4122Kuo3Init,
                dim4123Kuo3Init,
                dim4124Kuo3Init,
                dim4125Kuo3Init,
                dim4126Kuo3Init,
                dim4127Kuo3Init,
                dim4128Kuo3Init,
                dim4129Kuo3Init,
                dim4130Kuo3Init,
                dim4131Kuo3Init,
                dim4132Kuo3Init,
                dim4133Kuo3Init,
                dim4134Kuo3Init,
                dim4135Kuo3Init,
                dim4136Kuo3Init,
                dim4137Kuo3Init,
                dim4138Kuo3Init,
                dim4139Kuo3Init,
                dim4140Kuo3Init,
                dim4141Kuo3Init,
                dim4142Kuo3Init,
                dim4143Kuo3Init,
                dim4144Kuo3Init,
                dim4145Kuo3Init,
                dim4146Kuo3Init,
                dim4147Kuo3Init,
                dim4148Kuo3Init,
                dim4149Kuo3Init,
                dim4150Kuo3Init,
                dim4151Kuo3Init,
                dim4152Kuo3Init,
                dim4153Kuo3Init,
                dim4154Kuo3Init,
                dim4155Kuo3Init,
                dim4156Kuo3Init,
                dim4157Kuo3Init,
                dim4158Kuo3Init,
                dim4159Kuo3Init,
                dim4160Kuo3Init,
                dim4161Kuo3Init,
                dim4162Kuo3Init,
                dim4163Kuo3Init,
                dim4164Kuo3Init,
                dim4165Kuo3Init,
                dim4166Kuo3Init,
                dim4167Kuo3Init,
                dim4168Kuo3Init,
                dim4169Kuo3Init,
                dim4170Kuo3Init,
                dim4171Kuo3Init,
                dim4172Kuo3Init,
                dim4173Kuo3Init,
                dim4174Kuo3Init,
                dim4175Kuo3Init,
                dim4176Kuo3Init,
                dim4177Kuo3Init,
                dim4178Kuo3Init,
                dim4179Kuo3Init,
                dim4180Kuo3Init,
                dim4181Kuo3Init,
                dim4182Kuo3Init,
                dim4183Kuo3Init,
                dim4184Kuo3Init,
                dim4185Kuo3Init,
                dim4186Kuo3Init,
                dim4187Kuo3Init,
                dim4188Kuo3Init,
                dim4189Kuo3Init,
                dim4190Kuo3Init,
                dim4191Kuo3Init,
                dim4192Kuo3Init,
                dim4193Kuo3Init,
                dim4194Kuo3Init,
                dim4195Kuo3Init,
                dim4196Kuo3Init,
                dim4197Kuo3Init,
                dim4198Kuo3Init,
                dim4199Kuo3Init,
                dim4200Kuo3Init,
                dim4201Kuo3Init,
                dim4202Kuo3Init,
                dim4203Kuo3Init,
                dim4204Kuo3Init,
                dim4205Kuo3Init,
                dim4206Kuo3Init,
                dim4207Kuo3Init,
                dim4208Kuo3Init,
                dim4209Kuo3Init,
                dim4210Kuo3Init,
                dim4211Kuo3Init,
                dim4212Kuo3Init,
                dim4213Kuo3Init,
                dim4214Kuo3Init,
                dim4215Kuo3Init,
                dim4216Kuo3Init,
                dim4217Kuo3Init,
                dim4218Kuo3Init,
                dim4219Kuo3Init,
                dim4220Kuo3Init,
                dim4221Kuo3Init,
                dim4222Kuo3Init,
                dim4223Kuo3Init,
                dim4224Kuo3Init,
                dim4225Kuo3Init,
                dim4226Kuo3Init,
                dim4227Kuo3Init,
                dim4228Kuo3Init,
                dim4229Kuo3Init,
                dim4230Kuo3Init,
                dim4231Kuo3Init,
                dim4232Kuo3Init,
                dim4233Kuo3Init,
                dim4234Kuo3Init,
                dim4235Kuo3Init,
                dim4236Kuo3Init,
                dim4237Kuo3Init,
                dim4238Kuo3Init,
                dim4239Kuo3Init,
                dim4240Kuo3Init,
                dim4241Kuo3Init,
                dim4242Kuo3Init,
                dim4243Kuo3Init,
                dim4244Kuo3Init,
                dim4245Kuo3Init,
                dim4246Kuo3Init,
                dim4247Kuo3Init,
                dim4248Kuo3Init,
                dim4249Kuo3Init,
                dim4250Kuo3Init,
                dim4251Kuo3Init,
                dim4252Kuo3Init,
                dim4253Kuo3Init,
                dim4254Kuo3Init,
                dim4255Kuo3Init,
                dim4256Kuo3Init,
                dim4257Kuo3Init,
                dim4258Kuo3Init,
                dim4259Kuo3Init,
                dim4260Kuo3Init,
                dim4261Kuo3Init,
                dim4262Kuo3Init,
                dim4263Kuo3Init,
                dim4264Kuo3Init,
                dim4265Kuo3Init,
                dim4266Kuo3Init,
                dim4267Kuo3Init,
                dim4268Kuo3Init,
                dim4269Kuo3Init,
                dim4270Kuo3Init,
                dim4271Kuo3Init,
                dim4272Kuo3Init,
                dim4273Kuo3Init,
                dim4274Kuo3Init,
                dim4275Kuo3Init,
                dim4276Kuo3Init,
                dim4277Kuo3Init,
                dim4278Kuo3Init,
                dim4279Kuo3Init,
                dim4280Kuo3Init,
                dim4281Kuo3Init,
                dim4282Kuo3Init,
                dim4283Kuo3Init,
                dim4284Kuo3Init,
                dim4285Kuo3Init,
                dim4286Kuo3Init,
                dim4287Kuo3Init,
                dim4288Kuo3Init,
                dim4289Kuo3Init,
                dim4290Kuo3Init,
                dim4291Kuo3Init,
                dim4292Kuo3Init,
                dim4293Kuo3Init,
                dim4294Kuo3Init,
                dim4295Kuo3Init,
                dim4296Kuo3Init,
                dim4297Kuo3Init,
                dim4298Kuo3Init,
                dim4299Kuo3Init,
                dim4300Kuo3Init,
                dim4301Kuo3Init,
                dim4302Kuo3Init,
                dim4303Kuo3Init,
                dim4304Kuo3Init,
                dim4305Kuo3Init,
                dim4306Kuo3Init,
                dim4307Kuo3Init,
                dim4308Kuo3Init,
                dim4309Kuo3Init,
                dim4310Kuo3Init,
                dim4311Kuo3Init,
                dim4312Kuo3Init,
                dim4313Kuo3Init,
                dim4314Kuo3Init,
                dim4315Kuo3Init,
                dim4316Kuo3Init,
                dim4317Kuo3Init,
                dim4318Kuo3Init,
                dim4319Kuo3Init,
                dim4320Kuo3Init,
                dim4321Kuo3Init,
                dim4322Kuo3Init,
                dim4323Kuo3Init,
                dim4324Kuo3Init,
                dim4325Kuo3Init,
                dim4326Kuo3Init,
                dim4327Kuo3Init,
                dim4328Kuo3Init,
                dim4329Kuo3Init,
                dim4330Kuo3Init,
                dim4331Kuo3Init,
                dim4332Kuo3Init,
                dim4333Kuo3Init,
                dim4334Kuo3Init,
                dim4335Kuo3Init,
                dim4336Kuo3Init,
                dim4337Kuo3Init,
                dim4338Kuo3Init,
                dim4339Kuo3Init,
                dim4340Kuo3Init,
                dim4341Kuo3Init,
                dim4342Kuo3Init,
                dim4343Kuo3Init,
                dim4344Kuo3Init,
                dim4345Kuo3Init,
                dim4346Kuo3Init,
                dim4347Kuo3Init,
                dim4348Kuo3Init,
                dim4349Kuo3Init,
                dim4350Kuo3Init,
                dim4351Kuo3Init,
                dim4352Kuo3Init,
                dim4353Kuo3Init,
                dim4354Kuo3Init,
                dim4355Kuo3Init,
                dim4356Kuo3Init,
                dim4357Kuo3Init,
                dim4358Kuo3Init,
                dim4359Kuo3Init,
                dim4360Kuo3Init,
                dim4361Kuo3Init,
                dim4362Kuo3Init,
                dim4363Kuo3Init,
                dim4364Kuo3Init,
                dim4365Kuo3Init,
                dim4366Kuo3Init,
                dim4367Kuo3Init,
                dim4368Kuo3Init,
                dim4369Kuo3Init,
                dim4370Kuo3Init,
                dim4371Kuo3Init,
                dim4372Kuo3Init,
                dim4373Kuo3Init,
                dim4374Kuo3Init,
                dim4375Kuo3Init,
                dim4376Kuo3Init,
                dim4377Kuo3Init,
                dim4378Kuo3Init,
                dim4379Kuo3Init,
                dim4380Kuo3Init,
                dim4381Kuo3Init,
                dim4382Kuo3Init,
                dim4383Kuo3Init,
                dim4384Kuo3Init,
                dim4385Kuo3Init,
                dim4386Kuo3Init,
                dim4387Kuo3Init,
                dim4388Kuo3Init,
                dim4389Kuo3Init,
                dim4390Kuo3Init,
                dim4391Kuo3Init,
                dim4392Kuo3Init,
                dim4393Kuo3Init,
                dim4394Kuo3Init,
                dim4395Kuo3Init,
                dim4396Kuo3Init,
                dim4397Kuo3Init,
                dim4398Kuo3Init,
                dim4399Kuo3Init,
                dim4400Kuo3Init,
                dim4401Kuo3Init,
                dim4402Kuo3Init,
                dim4403Kuo3Init,
                dim4404Kuo3Init,
                dim4405Kuo3Init,
                dim4406Kuo3Init,
                dim4407Kuo3Init,
                dim4408Kuo3Init,
                dim4409Kuo3Init,
                dim4410Kuo3Init,
                dim4411Kuo3Init,
                dim4412Kuo3Init,
                dim4413Kuo3Init,
                dim4414Kuo3Init,
                dim4415Kuo3Init,
                dim4416Kuo3Init,
                dim4417Kuo3Init,
                dim4418Kuo3Init,
                dim4419Kuo3Init,
                dim4420Kuo3Init,
                dim4421Kuo3Init,
                dim4422Kuo3Init,
                dim4423Kuo3Init,
                dim4424Kuo3Init,
                dim4425Kuo3Init,
                dim4426Kuo3Init,
                dim4427Kuo3Init,
                dim4428Kuo3Init,
                dim4429Kuo3Init,
                dim4430Kuo3Init,
                dim4431Kuo3Init,
                dim4432Kuo3Init,
                dim4433Kuo3Init,
                dim4434Kuo3Init,
                dim4435Kuo3Init,
                dim4436Kuo3Init,
                dim4437Kuo3Init,
                dim4438Kuo3Init,
                dim4439Kuo3Init,
                dim4440Kuo3Init,
                dim4441Kuo3Init,
                dim4442Kuo3Init,
                dim4443Kuo3Init,
                dim4444Kuo3Init,
                dim4445Kuo3Init,
                dim4446Kuo3Init,
                dim4447Kuo3Init,
                dim4448Kuo3Init,
                dim4449Kuo3Init,
                dim4450Kuo3Init,
                dim4451Kuo3Init,
                dim4452Kuo3Init,
                dim4453Kuo3Init,
                dim4454Kuo3Init,
                dim4455Kuo3Init,
                dim4456Kuo3Init,
                dim4457Kuo3Init,
                dim4458Kuo3Init,
                dim4459Kuo3Init,
                dim4460Kuo3Init,
                dim4461Kuo3Init,
                dim4462Kuo3Init,
                dim4463Kuo3Init,
                dim4464Kuo3Init,
                dim4465Kuo3Init,
                dim4466Kuo3Init,
                dim4467Kuo3Init,
                dim4468Kuo3Init,
                dim4469Kuo3Init,
                dim4470Kuo3Init,
                dim4471Kuo3Init,
                dim4472Kuo3Init,
                dim4473Kuo3Init,
                dim4474Kuo3Init,
                dim4475Kuo3Init,
                dim4476Kuo3Init,
                dim4477Kuo3Init,
                dim4478Kuo3Init,
                dim4479Kuo3Init,
                dim4480Kuo3Init,
                dim4481Kuo3Init,
                dim4482Kuo3Init,
                dim4483Kuo3Init,
                dim4484Kuo3Init,
                dim4485Kuo3Init,
                dim4486Kuo3Init,
                dim4487Kuo3Init,
                dim4488Kuo3Init,
                dim4489Kuo3Init,
                dim4490Kuo3Init,
                dim4491Kuo3Init,
                dim4492Kuo3Init,
                dim4493Kuo3Init,
                dim4494Kuo3Init,
                dim4495Kuo3Init,
                dim4496Kuo3Init,
                dim4497Kuo3Init,
                dim4498Kuo3Init,
                dim4499Kuo3Init,
                dim4500Kuo3Init,
                dim4501Kuo3Init,
                dim4502Kuo3Init,
                dim4503Kuo3Init,
                dim4504Kuo3Init,
                dim4505Kuo3Init,
                dim4506Kuo3Init,
                dim4507Kuo3Init,
                dim4508Kuo3Init,
                dim4509Kuo3Init,
                dim4510Kuo3Init,
                dim4511Kuo3Init,
                dim4512Kuo3Init,
                dim4513Kuo3Init,
                dim4514Kuo3Init,
                dim4515Kuo3Init,
                dim4516Kuo3Init,
                dim4517Kuo3Init,
                dim4518Kuo3Init,
                dim4519Kuo3Init,
                dim4520Kuo3Init,
                dim4521Kuo3Init,
                dim4522Kuo3Init,
                dim4523Kuo3Init,
                dim4524Kuo3Init,
                dim4525Kuo3Init,
                dim4526Kuo3Init,
                dim4527Kuo3Init,
                dim4528Kuo3Init,
                dim4529Kuo3Init,
                dim4530Kuo3Init,
                dim4531Kuo3Init,
                dim4532Kuo3Init,
                dim4533Kuo3Init,
                dim4534Kuo3Init,
                dim4535Kuo3Init,
                dim4536Kuo3Init,
                dim4537Kuo3Init,
                dim4538Kuo3Init,
                dim4539Kuo3Init,
                dim4540Kuo3Init,
                dim4541Kuo3Init,
                dim4542Kuo3Init,
                dim4543Kuo3Init,
                dim4544Kuo3Init,
                dim4545Kuo3Init,
                dim4546Kuo3Init,
                dim4547Kuo3Init,
                dim4548Kuo3Init,
                dim4549Kuo3Init,
                dim4550Kuo3Init,
                dim4551Kuo3Init,
                dim4552Kuo3Init,
                dim4553Kuo3Init,
                dim4554Kuo3Init,
                dim4555Kuo3Init,
                dim4556Kuo3Init,
                dim4557Kuo3Init,
                dim4558Kuo3Init,
                dim4559Kuo3Init,
                dim4560Kuo3Init,
                dim4561Kuo3Init,
                dim4562Kuo3Init,
                dim4563Kuo3Init,
                dim4564Kuo3Init,
                dim4565Kuo3Init,
                dim4566Kuo3Init,
                dim4567Kuo3Init,
                dim4568Kuo3Init,
                dim4569Kuo3Init,
                dim4570Kuo3Init,
                dim4571Kuo3Init,
                dim4572Kuo3Init,
                dim4573Kuo3Init,
                dim4574Kuo3Init,
                dim4575Kuo3Init,
                dim4576Kuo3Init,
                dim4577Kuo3Init,
                dim4578Kuo3Init,
                dim4579Kuo3Init,
                dim4580Kuo3Init,
                dim4581Kuo3Init,
                dim4582Kuo3Init,
                dim4583Kuo3Init,
                dim4584Kuo3Init,
                dim4585Kuo3Init,
                dim4586Kuo3Init
            };

            const std::uint32_t dim1JoeKuoD6Init[]   =   { 1, 0 };
            const std::uint32_t dim2JoeKuoD6Init[]   =   { 1, 3, 0 };
            const std::uint32_t dim3JoeKuoD6Init[]   =   { 1, 3, 1, 0 };
            const std::uint32_t dim4JoeKuoD6Init[]   =   { 1, 1, 1, 0 };
            const std::uint32_t dim5JoeKuoD6Init[]   =   { 1, 1, 3, 3, 0 };
            const std::uint32_t dim6JoeKuoD6Init[]   =   { 1, 3, 5, 13, 0 };
            const std::uint32_t dim7JoeKuoD6Init[]   =   { 1, 1, 5, 5, 17, 0 };
            const std::uint32_t dim8JoeKuoD6Init[]   =   { 1, 1, 5, 5, 5, 0 };
            const std::uint32_t dim9JoeKuoD6Init[]   =   { 1, 1, 7, 11, 19, 0 };
            const std::uint32_t dim10JoeKuoD6Init[]   =   { 1, 1, 5, 1, 1, 0 };
            const std::uint32_t dim11JoeKuoD6Init[]   =   { 1, 1, 1, 3, 11, 0 };
            const std::uint32_t dim12JoeKuoD6Init[]   =   { 1, 3, 5, 5, 31, 0 };
            const std::uint32_t dim13JoeKuoD6Init[]   =   { 1, 3, 3, 9, 7, 49, 0 };
            const std::uint32_t dim14JoeKuoD6Init[]   =   { 1, 1, 1, 15, 21, 21, 0 };
            const std::uint32_t dim15JoeKuoD6Init[]   =   { 1, 3, 1, 13, 27, 49, 0 };
            const std::uint32_t dim16JoeKuoD6Init[]   =   { 1, 1, 1, 15, 7, 5, 0 };
            const std::uint32_t dim17JoeKuoD6Init[]   =   { 1, 3, 1, 15, 13, 25, 0 };
            const std::uint32_t dim18JoeKuoD6Init[]   =   { 1, 1, 5, 5, 19, 61, 0 };
            const std::uint32_t dim19JoeKuoD6Init[]   =   { 1, 3, 7, 11, 23, 15, 103, 0 };
            const std::uint32_t dim20JoeKuoD6Init[]   =   { 1, 3, 7, 13, 13, 15, 69, 0 };
            const std::uint32_t dim21JoeKuoD6Init[]   =   { 1, 1, 3, 13, 7, 35, 63, 0 };
            const std::uint32_t dim22JoeKuoD6Init[]   =   { 1, 3, 5, 9, 1, 25, 53, 0 };
            const std::uint32_t dim23JoeKuoD6Init[]   =   { 1, 3, 1, 13, 9, 35, 107, 0 };
            const std::uint32_t dim24JoeKuoD6Init[]   =   { 1, 3, 1, 5, 27, 61, 31, 0 };
            const std::uint32_t dim25JoeKuoD6Init[]   =   { 1, 1, 5, 11, 19, 41, 61, 0 };
            const std::uint32_t dim26JoeKuoD6Init[]   =   { 1, 3, 5, 3, 3, 13, 69, 0 };
            const std::uint32_t dim27JoeKuoD6Init[]   =   { 1, 1, 7, 13, 1, 19, 1, 0 };
            const std::uint32_t dim28JoeKuoD6Init[]   =   { 1, 3, 7, 5, 13, 19, 59, 0 };
            const std::uint32_t dim29JoeKuoD6Init[]   =   { 1, 1, 3, 9, 25, 29, 41, 0 };
            const std::uint32_t dim30JoeKuoD6Init[]   =   { 1, 3, 5, 13, 23, 1, 55, 0 };
            const std::uint32_t dim31JoeKuoD6Init[]   =   { 1, 3, 7, 3, 13, 59, 17, 0 };
            const std::uint32_t dim32JoeKuoD6Init[]   =   { 1, 3, 1, 3, 5, 53, 69, 0 };
            const std::uint32_t dim33JoeKuoD6Init[]   =   { 1, 1, 5, 5, 23, 33, 13, 0 };
            const std::uint32_t dim34JoeKuoD6Init[]   =   { 1, 1, 7, 7, 1, 61, 123, 0 };
            const std::uint32_t dim35JoeKuoD6Init[]   =   { 1, 1, 7, 9, 13, 61, 49, 0 };
            const std::uint32_t dim36JoeKuoD6Init[]   =   { 1, 3, 3, 5, 3, 55, 33, 0 };
            const std::uint32_t dim37JoeKuoD6Init[]   =   { 1, 3, 1, 15, 31, 13, 49, 245, 0 };
            const std::uint32_t dim38JoeKuoD6Init[]   =   { 1, 3, 5, 15, 31, 59, 63, 97, 0 };
            const std::uint32_t dim39JoeKuoD6Init[]   =   { 1, 3, 1, 11, 11, 11, 77, 249, 0 };
            const std::uint32_t dim40JoeKuoD6Init[]   =   { 1, 3, 1, 11, 27, 43, 71, 9, 0 };
            const std::uint32_t dim41JoeKuoD6Init[]   =   { 1, 1, 7, 15, 21, 11, 81, 45, 0 };
            const std::uint32_t dim42JoeKuoD6Init[]   =   { 1, 3, 7, 3, 25, 31, 65, 79, 0 };
            const std::uint32_t dim43JoeKuoD6Init[]   =   { 1, 3, 1, 1, 19, 11, 3, 205, 0 };
            const std::uint32_t dim44JoeKuoD6Init[]   =   { 1, 1, 5, 9, 19, 21, 29, 157, 0 };
            const std::uint32_t dim45JoeKuoD6Init[]   =   { 1, 3, 7, 11, 1, 33, 89, 185, 0 };
            const std::uint32_t dim46JoeKuoD6Init[]   =   { 1, 3, 3, 3, 15, 9, 79, 71, 0 };
            const std::uint32_t dim47JoeKuoD6Init[]   =   { 1, 3, 7, 11, 15, 39, 119, 27, 0 };
            const std::uint32_t dim48JoeKuoD6Init[]   =   { 1, 1, 3, 1, 11, 31, 97, 225, 0 };
            const std::uint32_t dim49JoeKuoD6Init[]   =   { 1, 1, 1, 3, 23, 43, 57, 177, 0 };
            const std::uint32_t dim50JoeKuoD6Init[]   =   { 1, 3, 7, 7, 17, 17, 37, 71, 0 };
            const std::uint32_t dim51JoeKuoD6Init[]   =   { 1, 3, 1, 5, 27, 63, 123, 213, 0 };
            const std::uint32_t dim52JoeKuoD6Init[]   =   { 1, 1, 3, 5, 11, 43, 53, 133, 0 };
            const std::uint32_t dim53JoeKuoD6Init[]   =   { 1, 3, 5, 5, 29, 17, 47, 173, 479, 0 };
            const std::uint32_t dim54JoeKuoD6Init[]   =   { 1, 3, 3, 11, 3, 1, 109, 9, 69, 0 };
            const std::uint32_t dim55JoeKuoD6Init[]   =   { 1, 1, 1, 5, 17, 39, 23, 5, 343, 0 };
            const std::uint32_t dim56JoeKuoD6Init[]   =   { 1, 3, 1, 5, 25, 15, 31, 103, 499, 0 };
            const std::uint32_t dim57JoeKuoD6Init[]   =   { 1, 1, 1, 11, 11, 17, 63, 105, 183, 0 };
            const std::uint32_t dim58JoeKuoD6Init[]   =   { 1, 1, 5, 11, 9, 29, 97, 231, 363, 0 };
            const std::uint32_t dim59JoeKuoD6Init[]   =   { 1, 1, 5, 15, 19, 45, 41, 7, 383, 0 };
            const std::uint32_t dim60JoeKuoD6Init[]   =   { 1, 3, 7, 7, 31, 19, 83, 137, 221, 0 };
            const std::uint32_t dim61JoeKuoD6Init[]   =   { 1, 1, 1, 3, 23, 15, 111, 223, 83, 0 };
            const std::uint32_t dim62JoeKuoD6Init[]   =   { 1, 1, 5, 13, 31, 15, 55, 25, 161, 0 };
            const std::uint32_t dim63JoeKuoD6Init[]   =   { 1, 1, 3, 13, 25, 47, 39, 87, 257, 0 };
            const std::uint32_t dim64JoeKuoD6Init[]   =   { 1, 1, 1, 11, 21, 53, 125, 249, 293, 0 };
            const std::uint32_t dim65JoeKuoD6Init[]   =   { 1, 1, 7, 11, 11, 7, 57, 79, 323, 0 };
            const std::uint32_t dim66JoeKuoD6Init[]   =   { 1, 1, 5, 5, 17, 13, 81, 3, 131, 0 };
            const std::uint32_t dim67JoeKuoD6Init[]   =   { 1, 1, 7, 13, 23, 7, 65, 251, 475, 0 };
            const std::uint32_t dim68JoeKuoD6Init[]   =   { 1, 3, 5, 1, 9, 43, 3, 149, 11, 0 };
            const std::uint32_t dim69JoeKuoD6Init[]   =   { 1, 1, 3, 13, 31, 13, 13, 255, 487, 0 };
            const std::uint32_t dim70JoeKuoD6Init[]   =   { 1, 3, 3, 1, 5, 63, 89, 91, 127, 0 };
            const std::uint32_t dim71JoeKuoD6Init[]   =   { 1, 1, 3, 3, 1, 19, 123, 127, 237, 0 };
            const std::uint32_t dim72JoeKuoD6Init[]   =   { 1, 1, 5, 7, 23, 31, 37, 243, 289, 0 };
            const std::uint32_t dim73JoeKuoD6Init[]   =   { 1, 1, 5, 11, 17, 53, 117, 183, 491, 0 };
            const std::uint32_t dim74JoeKuoD6Init[]   =   { 1, 1, 1, 5, 1, 13, 13, 209, 345, 0 };
            const std::uint32_t dim75JoeKuoD6Init[]   =   { 1, 1, 3, 15, 1, 57, 115, 7, 33, 0 };
            const std::uint32_t dim76JoeKuoD6Init[]   =   { 1, 3, 1, 11, 7, 43, 81, 207, 175, 0 };
            const std::uint32_t dim77JoeKuoD6Init[]   =   { 1, 3, 1, 1, 15, 27, 63, 255, 49, 0 };
            const std::uint32_t dim78JoeKuoD6Init[]   =   { 1, 3, 5, 3, 27, 61, 105, 171, 305, 0 };
            const std::uint32_t dim79JoeKuoD6Init[]   =   { 1, 1, 5, 3, 1, 3, 57, 249, 149, 0 };
            const std::uint32_t dim80JoeKuoD6Init[]   =   { 1, 1, 3, 5, 5, 57, 15, 13, 159, 0 };
            const std::uint32_t dim81JoeKuoD6Init[]   =   { 1, 1, 1, 11, 7, 11, 105, 141, 225, 0 };
            const std::uint32_t dim82JoeKuoD6Init[]   =   { 1, 3, 3, 5, 27, 59, 121, 101, 271, 0 };
            const std::uint32_t dim83JoeKuoD6Init[]   =   { 1, 3, 5, 9, 11, 49, 51, 59, 115, 0 };
            const std::uint32_t dim84JoeKuoD6Init[]   =   { 1, 1, 7, 1, 23, 45, 125, 71, 419, 0 };
            const std::uint32_t dim85JoeKuoD6Init[]   =   { 1, 1, 3, 5, 23, 5, 105, 109, 75, 0 };
            const std::uint32_t dim86JoeKuoD6Init[]   =   { 1, 1, 7, 15, 7, 11, 67, 121, 453, 0 };
            const std::uint32_t dim87JoeKuoD6Init[]   =   { 1, 3, 7, 3, 9, 13, 31, 27, 449, 0 };
            const std::uint32_t dim88JoeKuoD6Init[]   =   { 1, 3, 1, 15, 19, 39, 39, 89, 15, 0 };
            const std::uint32_t dim89JoeKuoD6Init[]   =   { 1, 1, 1, 1, 1, 33, 73, 145, 379, 0 };
            const std::uint32_t dim90JoeKuoD6Init[]   =   { 1, 3, 1, 15, 15, 43, 29, 13, 483, 0 };
            const std::uint32_t dim91JoeKuoD6Init[]   =   { 1, 1, 7, 3, 19, 27, 85, 131, 431, 0 };
            const std::uint32_t dim92JoeKuoD6Init[]   =   { 1, 3, 3, 3, 5, 35, 23, 195, 349, 0 };
            const std::uint32_t dim93JoeKuoD6Init[]   =   { 1, 3, 3, 7, 9, 27, 39, 59, 297, 0 };
            const std::uint32_t dim94JoeKuoD6Init[]   =   { 1, 1, 3, 9, 11, 17, 13, 241, 157, 0 };
            const std::uint32_t dim95JoeKuoD6Init[]   =   { 1, 3, 7, 15, 25, 57, 33, 189, 213, 0 };
            const std::uint32_t dim96JoeKuoD6Init[]   =   { 1, 1, 7, 1, 9, 55, 73, 83, 217, 0 };
            const std::uint32_t dim97JoeKuoD6Init[]   =   { 1, 3, 3, 13, 19, 27, 23, 113, 249, 0 };
            const std::uint32_t dim98JoeKuoD6Init[]   =   { 1, 3, 5, 3, 23, 43, 3, 253, 479, 0 };
            const std::uint32_t dim99JoeKuoD6Init[]   =   { 1, 1, 5, 5, 11, 5, 45, 117, 217, 0 };
            const std::uint32_t dim100JoeKuoD6Init[]   =   { 1, 3, 3, 7, 29, 37, 33, 123, 147, 0 };
            const std::uint32_t dim101JoeKuoD6Init[]   =   { 1, 3, 1, 15, 5, 5, 37, 227, 223, 459, 0 };
            const std::uint32_t dim102JoeKuoD6Init[]   =   { 1, 1, 7, 5, 5, 39, 63, 255, 135, 487, 0 };
            const std::uint32_t dim103JoeKuoD6Init[]   =   { 1, 3, 1, 7, 9, 7, 87, 249, 217, 599, 0 };
            const std::uint32_t dim104JoeKuoD6Init[]   =   { 1, 1, 3, 13, 9, 47, 7, 225, 363, 247, 0 };
            const std::uint32_t dim105JoeKuoD6Init[]   =   { 1, 3, 7, 13, 19, 13, 9, 67, 9, 737, 0 };
            const std::uint32_t dim106JoeKuoD6Init[]   =   { 1, 3, 5, 5, 19, 59, 7, 41, 319, 677, 0 };
            const std::uint32_t dim107JoeKuoD6Init[]   =   { 1, 1, 5, 3, 31, 63, 15, 43, 207, 789, 0 };
            const std::uint32_t dim108JoeKuoD6Init[]   =   { 1, 1, 7, 9, 13, 39, 3, 47, 497, 169, 0 };
            const std::uint32_t dim109JoeKuoD6Init[]   =   { 1, 3, 1, 7, 21, 17, 97, 19, 415, 905, 0 };
            const std::uint32_t dim110JoeKuoD6Init[]   =   { 1, 3, 7, 1, 3, 31, 71, 111, 165, 127, 0 };
            const std::uint32_t dim111JoeKuoD6Init[]   =   { 1, 1, 5, 11, 1, 61, 83, 119, 203, 847, 0 };
            const std::uint32_t dim112JoeKuoD6Init[]   =   { 1, 3, 3, 13, 9, 61, 19, 97, 47, 35, 0 };
            const std::uint32_t dim113JoeKuoD6Init[]   =   { 1, 1, 7, 7, 15, 29, 63, 95, 417, 469, 0 };
            const std::uint32_t dim114JoeKuoD6Init[]   =   { 1, 3, 1, 9, 25, 9, 71, 57, 213, 385, 0 };
            const std::uint32_t dim115JoeKuoD6Init[]   =   { 1, 3, 5, 13, 31, 47, 101, 57, 39, 341, 0 };
            const std::uint32_t dim116JoeKuoD6Init[]   =   { 1, 1, 3, 3, 31, 57, 125, 173, 365, 551, 0 };
            const std::uint32_t dim117JoeKuoD6Init[]   =   { 1, 3, 7, 1, 13, 57, 67, 157, 451, 707, 0 };
            const std::uint32_t dim118JoeKuoD6Init[]   =   { 1, 1, 1, 7, 21, 13, 105, 89, 429, 965, 0 };
            const std::uint32_t dim119JoeKuoD6Init[]   =   { 1, 1, 5, 9, 17, 51, 45, 119, 157, 141, 0 };
            const std::uint32_t dim120JoeKuoD6Init[]   =   { 1, 3, 7, 7, 13, 45, 91, 9, 129, 741, 0 };
            const std::uint32_t dim121JoeKuoD6Init[]   =   { 1, 3, 7, 1, 23, 57, 67, 141, 151, 571, 0 };
            const std::uint32_t dim122JoeKuoD6Init[]   =   { 1, 1, 3, 11, 17, 47, 93, 107, 375, 157, 0 };
            const std::uint32_t dim123JoeKuoD6Init[]   =   { 1, 3, 3, 5, 11, 21, 43, 51, 169, 915, 0 };
            const std::uint32_t dim124JoeKuoD6Init[]   =   { 1, 1, 5, 3, 15, 55, 101, 67, 455, 625, 0 };
            const std::uint32_t dim125JoeKuoD6Init[]   =   { 1, 3, 5, 9, 1, 23, 29, 47, 345, 595, 0 };
            const std::uint32_t dim126JoeKuoD6Init[]   =   { 1, 3, 7, 7, 5, 49, 29, 155, 323, 589, 0 };
            const std::uint32_t dim127JoeKuoD6Init[]   =   { 1, 3, 3, 7, 5, 41, 127, 61, 261, 717, 0 };
            const std::uint32_t dim128JoeKuoD6Init[]   =   { 1, 3, 7, 7, 17, 23, 117, 67, 129, 1009, 0 };
            const std::uint32_t dim129JoeKuoD6Init[]   =   { 1, 1, 3, 13, 11, 39, 21, 207, 123, 305, 0 };
            const std::uint32_t dim130JoeKuoD6Init[]   =   { 1, 1, 3, 9, 29, 3, 95, 47, 231, 73, 0 };
            const std::uint32_t dim131JoeKuoD6Init[]   =   { 1, 3, 1, 9, 1, 29, 117, 21, 441, 259, 0 };
            const std::uint32_t dim132JoeKuoD6Init[]   =   { 1, 3, 1, 13, 21, 39, 125, 211, 439, 723, 0 };
            const std::uint32_t dim133JoeKuoD6Init[]   =   { 1, 1, 7, 3, 17, 63, 115, 89, 49, 773, 0 };
            const std::uint32_t dim134JoeKuoD6Init[]   =   { 1, 3, 7, 13, 11, 33, 101, 107, 63, 73, 0 };
            const std::uint32_t dim135JoeKuoD6Init[]   =   { 1, 1, 5, 5, 13, 57, 63, 135, 437, 177, 0 };
            const std::uint32_t dim136JoeKuoD6Init[]   =   { 1, 1, 3, 7, 27, 63, 93, 47, 417, 483, 0 };
            const std::uint32_t dim137JoeKuoD6Init[]   =   { 1, 1, 3, 1, 23, 29, 1, 191, 49, 23, 0 };
            const std::uint32_t dim138JoeKuoD6Init[]   =   { 1, 1, 3, 15, 25, 55, 9, 101, 219, 607, 0 };
            const std::uint32_t dim139JoeKuoD6Init[]   =   { 1, 3, 1, 7, 7, 19, 51, 251, 393, 307, 0 };
            const std::uint32_t dim140JoeKuoD6Init[]   =   { 1, 3, 3, 3, 25, 55, 17, 75, 337, 3, 0 };
            const std::uint32_t dim141JoeKuoD6Init[]   =   { 1, 1, 1, 13, 25, 17, 65, 45, 479, 413, 0 };
            const std::uint32_t dim142JoeKuoD6Init[]   =   { 1, 1, 7, 7, 27, 49, 99, 161, 213, 727, 0 };
            const std::uint32_t dim143JoeKuoD6Init[]   =   { 1, 3, 5, 1, 23, 5, 43, 41, 251, 857, 0 };
            const std::uint32_t dim144JoeKuoD6Init[]   =   { 1, 3, 3, 7, 11, 61, 39, 87, 383, 835, 0 };
            const std::uint32_t dim145JoeKuoD6Init[]   =   { 1, 1, 3, 15, 13, 7, 29, 7, 505, 923, 0 };
            const std::uint32_t dim146JoeKuoD6Init[]   =   { 1, 3, 7, 1, 5, 31, 47, 157, 445, 501, 0 };
            const std::uint32_t dim147JoeKuoD6Init[]   =   { 1, 1, 3, 7, 1, 43, 9, 147, 115, 605, 0 };
            const std::uint32_t dim148JoeKuoD6Init[]   =   { 1, 3, 3, 13, 5, 1, 119, 211, 455, 1001, 0 };
            const std::uint32_t dim149JoeKuoD6Init[]   =   { 1, 1, 3, 5, 13, 19, 3, 243, 75, 843, 0 };
            const std::uint32_t dim150JoeKuoD6Init[]   =   { 1, 3, 7, 7, 1, 19, 91, 249, 357, 589, 0 };
            const std::uint32_t dim151JoeKuoD6Init[]   =   { 1, 1, 1, 9, 1, 25, 109, 197, 279, 411, 0 };
            const std::uint32_t dim152JoeKuoD6Init[]   =   { 1, 3, 1, 15, 23, 57, 59, 135, 191, 75, 0 };
            const std::uint32_t dim153JoeKuoD6Init[]   =   { 1, 1, 5, 15, 29, 21, 39, 253, 383, 349, 0 };
            const std::uint32_t dim154JoeKuoD6Init[]   =   { 1, 3, 3, 5, 19, 45, 61, 151, 199, 981, 0 };
            const std::uint32_t dim155JoeKuoD6Init[]   =   { 1, 3, 5, 13, 9, 61, 107, 141, 141, 1, 0 };
            const std::uint32_t dim156JoeKuoD6Init[]   =   { 1, 3, 1, 11, 27, 25, 85, 105, 309, 979, 0 };
            const std::uint32_t dim157JoeKuoD6Init[]   =   { 1, 3, 3, 11, 19, 7, 115, 223, 349, 43, 0 };
            const std::uint32_t dim158JoeKuoD6Init[]   =   { 1, 1, 7, 9, 21, 39, 123, 21, 275, 927, 0 };
            const std::uint32_t dim159JoeKuoD6Init[]   =   { 1, 1, 7, 13, 15, 41, 47, 243, 303, 437, 0 };
            const std::uint32_t dim160JoeKuoD6Init[]   =   { 1, 1, 1, 7, 7, 3, 15, 99, 409, 719, 0 };
            const std::uint32_t dim161JoeKuoD6Init[]   =   { 1, 3, 3, 15, 27, 49, 113, 123, 113, 67, 469, 0 };
            const std::uint32_t dim162JoeKuoD6Init[]   =   { 1, 3, 7, 11, 3, 23, 87, 169, 119, 483, 199, 0 };
            const std::uint32_t dim163JoeKuoD6Init[]   =   { 1, 1, 5, 15, 7, 17, 109, 229, 179, 213, 741, 0 };
            const std::uint32_t dim164JoeKuoD6Init[]   =   { 1, 1, 5, 13, 11, 17, 25, 135, 403, 557, 1433, 0 };
            const std::uint32_t dim165JoeKuoD6Init[]   =   { 1, 3, 1, 1, 1, 61, 67, 215, 189, 945, 1243, 0 };
            const std::uint32_t dim166JoeKuoD6Init[]   =   { 1, 1, 7, 13, 17, 33, 9, 221, 429, 217, 1679, 0 };
            const std::uint32_t dim167JoeKuoD6Init[]   =   { 1, 1, 3, 11, 27, 3, 15, 93, 93, 865, 1049, 0 };
            const std::uint32_t dim168JoeKuoD6Init[]   =   { 1, 3, 7, 7, 25, 41, 121, 35, 373, 379, 1547, 0 };
            const std::uint32_t dim169JoeKuoD6Init[]   =   { 1, 3, 3, 9, 11, 35, 45, 205, 241, 9, 59, 0 };
            const std::uint32_t dim170JoeKuoD6Init[]   =   { 1, 3, 1, 7, 3, 51, 7, 177, 53, 975, 89, 0 };
            const std::uint32_t dim171JoeKuoD6Init[]   =   { 1, 1, 3, 5, 27, 1, 113, 231, 299, 759, 861, 0 };
            const std::uint32_t dim172JoeKuoD6Init[]   =   { 1, 3, 3, 15, 25, 29, 5, 255, 139, 891, 2031, 0 };
            const std::uint32_t dim173JoeKuoD6Init[]   =   { 1, 3, 1, 1, 13, 9, 109, 193, 419, 95, 17, 0 };
            const std::uint32_t dim174JoeKuoD6Init[]   =   { 1, 1, 7, 9, 3, 7, 29, 41, 135, 839, 867, 0 };
            const std::uint32_t dim175JoeKuoD6Init[]   =   { 1, 1, 7, 9, 25, 49, 123, 217, 113, 909, 215, 0 };
            const std::uint32_t dim176JoeKuoD6Init[]   =   { 1, 1, 7, 3, 23, 15, 43, 133, 217, 327, 901, 0 };
            const std::uint32_t dim177JoeKuoD6Init[]   =   { 1, 1, 3, 3, 13, 53, 63, 123, 477, 711, 1387, 0 };
            const std::uint32_t dim178JoeKuoD6Init[]   =   { 1, 1, 3, 15, 7, 29, 75, 119, 181, 957, 247, 0 };
            const std::uint32_t dim179JoeKuoD6Init[]   =   { 1, 1, 1, 11, 27, 25, 109, 151, 267, 99, 1461, 0 };
            const std::uint32_t dim180JoeKuoD6Init[]   =   { 1, 3, 7, 15, 5, 5, 53, 145, 11, 725, 1501, 0 };
            const std::uint32_t dim181JoeKuoD6Init[]   =   { 1, 3, 7, 1, 9, 43, 71, 229, 157, 607, 1835, 0 };
            const std::uint32_t dim182JoeKuoD6Init[]   =   { 1, 3, 3, 13, 25, 1, 5, 27, 471, 349, 127, 0 };
            const std::uint32_t dim183JoeKuoD6Init[]   =   { 1, 1, 1, 1, 23, 37, 9, 221, 269, 897, 1685, 0 };
            const std::uint32_t dim184JoeKuoD6Init[]   =   { 1, 1, 3, 3, 31, 29, 51, 19, 311, 553, 1969, 0 };
            const std::uint32_t dim185JoeKuoD6Init[]   =   { 1, 3, 7, 5, 5, 55, 17, 39, 475, 671, 1529, 0 };
            const std::uint32_t dim186JoeKuoD6Init[]   =   { 1, 1, 7, 1, 1, 35, 47, 27, 437, 395, 1635, 0 };
            const std::uint32_t dim187JoeKuoD6Init[]   =   { 1, 1, 7, 3, 13, 23, 43, 135, 327, 139, 389, 0 };
            const std::uint32_t dim188JoeKuoD6Init[]   =   { 1, 3, 7, 3, 9, 25, 91, 25, 429, 219, 513, 0 };
            const std::uint32_t dim189JoeKuoD6Init[]   =   { 1, 1, 3, 5, 13, 29, 119, 201, 277, 157, 2043, 0 };
            const std::uint32_t dim190JoeKuoD6Init[]   =   { 1, 3, 5, 3, 29, 57, 13, 17, 167, 739, 1031, 0 };
            const std::uint32_t dim191JoeKuoD6Init[]   =   { 1, 3, 3, 5, 29, 21, 95, 27, 255, 679, 1531, 0 };
            const std::uint32_t dim192JoeKuoD6Init[]   =   { 1, 3, 7, 15, 9, 5, 21, 71, 61, 961, 1201, 0 };
            const std::uint32_t dim193JoeKuoD6Init[]   =   { 1, 3, 5, 13, 15, 57, 33, 93, 459, 867, 223, 0 };
            const std::uint32_t dim194JoeKuoD6Init[]   =   { 1, 1, 1, 15, 17, 43, 127, 191, 67, 177, 1073, 0 };
            const std::uint32_t dim195JoeKuoD6Init[]   =   { 1, 1, 1, 15, 23, 7, 21, 199, 75, 293, 1611, 0 };
            const std::uint32_t dim196JoeKuoD6Init[]   =   { 1, 3, 7, 13, 15, 39, 21, 149, 65, 741, 319, 0 };
            const std::uint32_t dim197JoeKuoD6Init[]   =   { 1, 3, 7, 11, 23, 13, 101, 89, 277, 519, 711, 0 };
            const std::uint32_t dim198JoeKuoD6Init[]   =   { 1, 3, 7, 15, 19, 27, 85, 203, 441, 97, 1895, 0 };
            const std::uint32_t dim199JoeKuoD6Init[]   =   { 1, 3, 1, 3, 29, 25, 21, 155, 11, 191, 197, 0 };
            const std::uint32_t dim200JoeKuoD6Init[]   =   { 1, 1, 7, 5, 27, 11, 81, 101, 457, 675, 1687, 0 };
            const std::uint32_t dim201JoeKuoD6Init[]   =   { 1, 3, 1, 5, 25, 5, 65, 193, 41, 567, 781, 0 };
            const std::uint32_t dim202JoeKuoD6Init[]   =   { 1, 3, 1, 5, 11, 15, 113, 77, 411, 695, 1111, 0 };
            const std::uint32_t dim203JoeKuoD6Init[]   =   { 1, 1, 3, 9, 11, 53, 119, 171, 55, 297, 509, 0 };
            const std::uint32_t dim204JoeKuoD6Init[]   =   { 1, 1, 1, 1, 11, 39, 113, 139, 165, 347, 595, 0 };
            const std::uint32_t dim205JoeKuoD6Init[]   =   { 1, 3, 7, 11, 9, 17, 101, 13, 81, 325, 1733, 0 };
            const std::uint32_t dim206JoeKuoD6Init[]   =   { 1, 3, 1, 1, 21, 43, 115, 9, 113, 907, 645, 0 };
            const std::uint32_t dim207JoeKuoD6Init[]   =   { 1, 1, 7, 3, 9, 25, 117, 197, 159, 471, 475, 0 };
            const std::uint32_t dim208JoeKuoD6Init[]   =   { 1, 3, 1, 9, 11, 21, 57, 207, 485, 613, 1661, 0 };
            const std::uint32_t dim209JoeKuoD6Init[]   =   { 1, 1, 7, 7, 27, 55, 49, 223, 89, 85, 1523, 0 };
            const std::uint32_t dim210JoeKuoD6Init[]   =   { 1, 1, 5, 3, 19, 41, 45, 51, 447, 299, 1355, 0 };
            const std::uint32_t dim211JoeKuoD6Init[]   =   { 1, 3, 1, 13, 1, 33, 117, 143, 313, 187, 1073, 0 };
            const std::uint32_t dim212JoeKuoD6Init[]   =   { 1, 1, 7, 7, 5, 11, 65, 97, 377, 377, 1501, 0 };
            const std::uint32_t dim213JoeKuoD6Init[]   =   { 1, 3, 1, 1, 21, 35, 95, 65, 99, 23, 1239, 0 };
            const std::uint32_t dim214JoeKuoD6Init[]   =   { 1, 1, 5, 9, 3, 37, 95, 167, 115, 425, 867, 0 };
            const std::uint32_t dim215JoeKuoD6Init[]   =   { 1, 3, 3, 13, 1, 37, 27, 189, 81, 679, 773, 0 };
            const std::uint32_t dim216JoeKuoD6Init[]   =   { 1, 1, 3, 11, 1, 61, 99, 233, 429, 969, 49, 0 };
            const std::uint32_t dim217JoeKuoD6Init[]   =   { 1, 1, 1, 7, 25, 63, 99, 165, 245, 793, 1143, 0 };
            const std::uint32_t dim218JoeKuoD6Init[]   =   { 1, 1, 5, 11, 11, 43, 55, 65, 71, 283, 273, 0 };
            const std::uint32_t dim219JoeKuoD6Init[]   =   { 1, 1, 5, 5, 9, 3, 101, 251, 355, 379, 1611, 0 };
            const std::uint32_t dim220JoeKuoD6Init[]   =   { 1, 1, 1, 15, 21, 63, 85, 99, 49, 749, 1335, 0 };
            const std::uint32_t dim221JoeKuoD6Init[]   =   { 1, 1, 5, 13, 27, 9, 121, 43, 255, 715, 289, 0 };
            const std::uint32_t dim222JoeKuoD6Init[]   =   { 1, 3, 1, 5, 27, 19, 17, 223, 77, 571, 1415, 0 };
            const std::uint32_t dim223JoeKuoD6Init[]   =   { 1, 1, 5, 3, 13, 59, 125, 251, 195, 551, 1737, 0 };
            const std::uint32_t dim224JoeKuoD6Init[]   =   { 1, 3, 3, 15, 13, 27, 49, 105, 389, 971, 755, 0 };
            const std::uint32_t dim225JoeKuoD6Init[]   =   { 1, 3, 5, 15, 23, 43, 35, 107, 447, 763, 253, 0 };
            const std::uint32_t dim226JoeKuoD6Init[]   =   { 1, 3, 5, 11, 21, 3, 17, 39, 497, 407, 611, 0 };
            const std::uint32_t dim227JoeKuoD6Init[]   =   { 1, 1, 7, 13, 15, 31, 113, 17, 23, 507, 1995, 0 };
            const std::uint32_t dim228JoeKuoD6Init[]   =   { 1, 1, 7, 15, 3, 15, 31, 153, 423, 79, 503, 0 };
            const std::uint32_t dim229JoeKuoD6Init[]   =   { 1, 1, 7, 9, 19, 25, 23, 171, 505, 923, 1989, 0 };
            const std::uint32_t dim230JoeKuoD6Init[]   =   { 1, 1, 5, 9, 21, 27, 121, 223, 133, 87, 697, 0 };
            const std::uint32_t dim231JoeKuoD6Init[]   =   { 1, 1, 5, 5, 9, 19, 107, 99, 319, 765, 1461, 0 };
            const std::uint32_t dim232JoeKuoD6Init[]   =   { 1, 1, 3, 3, 19, 25, 3, 101, 171, 729, 187, 0 };
            const std::uint32_t dim233JoeKuoD6Init[]   =   { 1, 1, 3, 1, 13, 23, 85, 93, 291, 209, 37, 0 };
            const std::uint32_t dim234JoeKuoD6Init[]   =   { 1, 1, 1, 15, 25, 25, 77, 253, 333, 947, 1073, 0 };
            const std::uint32_t dim235JoeKuoD6Init[]   =   { 1, 1, 3, 9, 17, 29, 55, 47, 255, 305, 2037, 0 };
            const std::uint32_t dim236JoeKuoD6Init[]   =   { 1, 3, 3, 9, 29, 63, 9, 103, 489, 939, 1523, 0 };
            const std::uint32_t dim237JoeKuoD6Init[]   =   { 1, 3, 7, 15, 7, 31, 89, 175, 369, 339, 595, 0 };
            const std::uint32_t dim238JoeKuoD6Init[]   =   { 1, 3, 7, 13, 25, 5, 71, 207, 251, 367, 665, 0 };
            const std::uint32_t dim239JoeKuoD6Init[]   =   { 1, 3, 3, 3, 21, 25, 75, 35, 31, 321, 1603, 0 };
            const std::uint32_t dim240JoeKuoD6Init[]   =   { 1, 1, 1, 9, 11, 1, 65, 5, 11, 329, 535, 0 };
            const std::uint32_t dim241JoeKuoD6Init[]   =   { 1, 1, 5, 3, 19, 13, 17, 43, 379, 485, 383, 0 };
            const std::uint32_t dim242JoeKuoD6Init[]   =   { 1, 3, 5, 13, 13, 9, 85, 147, 489, 787, 1133, 0 };
            const std::uint32_t dim243JoeKuoD6Init[]   =   { 1, 3, 1, 1, 5, 51, 37, 129, 195, 297, 1783, 0 };
            const std::uint32_t dim244JoeKuoD6Init[]   =   { 1, 1, 3, 15, 19, 57, 59, 181, 455, 697, 2033, 0 };
            const std::uint32_t dim245JoeKuoD6Init[]   =   { 1, 3, 7, 1, 27, 9, 65, 145, 325, 189, 201, 0 };
            const std::uint32_t dim246JoeKuoD6Init[]   =   { 1, 3, 1, 15, 31, 23, 19, 5, 485, 581, 539, 0 };
            const std::uint32_t dim247JoeKuoD6Init[]   =   { 1, 1, 7, 13, 11, 15, 65, 83, 185, 847, 831, 0 };
            const std::uint32_t dim248JoeKuoD6Init[]   =   { 1, 3, 5, 7, 7, 55, 73, 15, 303, 511, 1905, 0 };
            const std::uint32_t dim249JoeKuoD6Init[]   =   { 1, 3, 5, 9, 7, 21, 45, 15, 397, 385, 597, 0 };
            const std::uint32_t dim250JoeKuoD6Init[]   =   { 1, 3, 7, 3, 23, 13, 73, 221, 511, 883, 1265, 0 };
            const std::uint32_t dim251JoeKuoD6Init[]   =   { 1, 1, 3, 11, 1, 51, 73, 185, 33, 975, 1441, 0 };
            const std::uint32_t dim252JoeKuoD6Init[]   =   { 1, 3, 3, 9, 19, 59, 21, 39, 339, 37, 143, 0 };
            const std::uint32_t dim253JoeKuoD6Init[]   =   { 1, 1, 7, 1, 31, 33, 19, 167, 117, 635, 639, 0 };
            const std::uint32_t dim254JoeKuoD6Init[]   =   { 1, 1, 1, 3, 5, 13, 59, 83, 355, 349, 1967, 0 };
            const std::uint32_t dim255JoeKuoD6Init[]   =   { 1, 1, 1, 5, 19, 3, 53, 133, 97, 863, 983, 0 };
            const std::uint32_t dim256JoeKuoD6Init[]   =   { 1, 3, 1, 13, 9, 41, 91, 105, 173, 97, 625, 0 };
            const std::uint32_t dim257JoeKuoD6Init[]   =   { 1, 1, 5, 3, 7, 49, 115, 133, 71, 231, 1063, 0 };
            const std::uint32_t dim258JoeKuoD6Init[]   =   { 1, 1, 7, 5, 17, 43, 47, 45, 497, 547, 757, 0 };
            const std::uint32_t dim259JoeKuoD6Init[]   =   { 1, 3, 5, 15, 21, 61, 123, 191, 249, 31, 631, 0 };
            const std::uint32_t dim260JoeKuoD6Init[]   =   { 1, 3, 7, 9, 17, 7, 11, 185, 127, 169, 1951, 0 };
            const std::uint32_t dim261JoeKuoD6Init[]   =   { 1, 1, 5, 13, 11, 11, 9, 49, 29, 125, 791, 0 };
            const std::uint32_t dim262JoeKuoD6Init[]   =   { 1, 1, 1, 15, 31, 41, 13, 167, 273, 429, 57, 0 };
            const std::uint32_t dim263JoeKuoD6Init[]   =   { 1, 3, 5, 3, 27, 7, 35, 209, 65, 265, 1393, 0 };
            const std::uint32_t dim264JoeKuoD6Init[]   =   { 1, 3, 1, 13, 31, 19, 53, 143, 135, 9, 1021, 0 };
            const std::uint32_t dim265JoeKuoD6Init[]   =   { 1, 1, 7, 13, 31, 5, 115, 153, 143, 957, 623, 0 };
            const std::uint32_t dim266JoeKuoD6Init[]   =   { 1, 1, 5, 11, 25, 19, 29, 31, 297, 943, 443, 0 };
            const std::uint32_t dim267JoeKuoD6Init[]   =   { 1, 3, 3, 5, 21, 11, 127, 81, 479, 25, 699, 0 };
            const std::uint32_t dim268JoeKuoD6Init[]   =   { 1, 1, 3, 11, 25, 31, 97, 19, 195, 781, 705, 0 };
            const std::uint32_t dim269JoeKuoD6Init[]   =   { 1, 1, 5, 5, 31, 11, 75, 207, 197, 885, 2037, 0 };
            const std::uint32_t dim270JoeKuoD6Init[]   =   { 1, 1, 1, 11, 9, 23, 29, 231, 307, 17, 1497, 0 };
            const std::uint32_t dim271JoeKuoD6Init[]   =   { 1, 1, 5, 11, 11, 43, 111, 233, 307, 523, 1259, 0 };
            const std::uint32_t dim272JoeKuoD6Init[]   =   { 1, 1, 7, 5, 1, 21, 107, 229, 343, 933, 217, 0 };
            const std::uint32_t dim273JoeKuoD6Init[]   =   { 1, 1, 1, 11, 3, 21, 125, 131, 405, 599, 1469, 0 };
            const std::uint32_t dim274JoeKuoD6Init[]   =   { 1, 3, 5, 5, 9, 39, 33, 81, 389, 151, 811, 0 };
            const std::uint32_t dim275JoeKuoD6Init[]   =   { 1, 1, 7, 7, 7, 1, 59, 223, 265, 529, 2021, 0 };
            const std::uint32_t dim276JoeKuoD6Init[]   =   { 1, 3, 1, 3, 9, 23, 85, 181, 47, 265, 49, 0 };
            const std::uint32_t dim277JoeKuoD6Init[]   =   { 1, 3, 5, 11, 19, 23, 9, 7, 157, 299, 1983, 0 };
            const std::uint32_t dim278JoeKuoD6Init[]   =   { 1, 3, 1, 5, 15, 5, 21, 105, 29, 339, 1041, 0 };
            const std::uint32_t dim279JoeKuoD6Init[]   =   { 1, 1, 1, 1, 5, 33, 65, 85, 111, 705, 479, 0 };
            const std::uint32_t dim280JoeKuoD6Init[]   =   { 1, 1, 1, 7, 9, 35, 77, 87, 151, 321, 101, 0 };
            const std::uint32_t dim281JoeKuoD6Init[]   =   { 1, 1, 5, 7, 17, 1, 51, 197, 175, 811, 1229, 0 };
            const std::uint32_t dim282JoeKuoD6Init[]   =   { 1, 3, 3, 15, 23, 37, 85, 185, 239, 543, 731, 0 };
            const std::uint32_t dim283JoeKuoD6Init[]   =   { 1, 3, 1, 7, 7, 55, 111, 109, 289, 439, 243, 0 };
            const std::uint32_t dim284JoeKuoD6Init[]   =   { 1, 1, 7, 11, 17, 53, 35, 217, 259, 853, 1667, 0 };
            const std::uint32_t dim285JoeKuoD6Init[]   =   { 1, 3, 1, 9, 1, 63, 87, 17, 73, 565, 1091, 0 };
            const std::uint32_t dim286JoeKuoD6Init[]   =   { 1, 1, 3, 3, 11, 41, 1, 57, 295, 263, 1029, 0 };
            const std::uint32_t dim287JoeKuoD6Init[]   =   { 1, 1, 5, 1, 27, 45, 109, 161, 411, 421, 1395, 0 };
            const std::uint32_t dim288JoeKuoD6Init[]   =   { 1, 3, 5, 11, 25, 35, 47, 191, 339, 417, 1727, 0 };
            const std::uint32_t dim289JoeKuoD6Init[]   =   { 1, 1, 5, 15, 21, 1, 93, 251, 351, 217, 1767, 0 };
            const std::uint32_t dim290JoeKuoD6Init[]   =   { 1, 3, 3, 11, 3, 7, 75, 155, 313, 211, 491, 0 };
            const std::uint32_t dim291JoeKuoD6Init[]   =   { 1, 3, 3, 5, 11, 9, 101, 161, 453, 913, 1067, 0 };
            const std::uint32_t dim292JoeKuoD6Init[]   =   { 1, 1, 3, 1, 15, 45, 127, 141, 163, 727, 1597, 0 };
            const std::uint32_t dim293JoeKuoD6Init[]   =   { 1, 3, 3, 7, 1, 33, 63, 73, 73, 341, 1691, 0 };
            const std::uint32_t dim294JoeKuoD6Init[]   =   { 1, 3, 5, 13, 15, 39, 53, 235, 77, 99, 949, 0 };
            const std::uint32_t dim295JoeKuoD6Init[]   =   { 1, 1, 5, 13, 31, 17, 97, 13, 215, 301, 1927, 0 };
            const std::uint32_t dim296JoeKuoD6Init[]   =   { 1, 1, 7, 1, 1, 37, 91, 93, 441, 251, 1131, 0 };
            const std::uint32_t dim297JoeKuoD6Init[]   =   { 1, 3, 7, 9, 25, 5, 105, 69, 81, 943, 1459, 0 };
            const std::uint32_t dim298JoeKuoD6Init[]   =   { 1, 3, 7, 11, 31, 43, 13, 209, 27, 1017, 501, 0 };
            const std::uint32_t dim299JoeKuoD6Init[]   =   { 1, 1, 7, 15, 1, 33, 31, 233, 161, 507, 387, 0 };
            const std::uint32_t dim300JoeKuoD6Init[]   =   { 1, 3, 3, 5, 5, 53, 33, 177, 503, 627, 1927, 0 };
            const std::uint32_t dim301JoeKuoD6Init[]   =   { 1, 1, 7, 11, 7, 61, 119, 31, 457, 229, 1875, 0 };
            const std::uint32_t dim302JoeKuoD6Init[]   =   { 1, 1, 5, 15, 19, 5, 53, 201, 157, 885, 1057, 0 };
            const std::uint32_t dim303JoeKuoD6Init[]   =   { 1, 3, 7, 9, 1, 35, 51, 113, 249, 425, 1009, 0 };
            const std::uint32_t dim304JoeKuoD6Init[]   =   { 1, 3, 5, 7, 21, 53, 37, 155, 119, 345, 631, 0 };
            const std::uint32_t dim305JoeKuoD6Init[]   =   { 1, 3, 5, 7, 15, 31, 109, 69, 503, 595, 1879, 0 };
            const std::uint32_t dim306JoeKuoD6Init[]   =   { 1, 3, 3, 1, 25, 35, 65, 131, 403, 705, 503, 0 };
            const std::uint32_t dim307JoeKuoD6Init[]   =   { 1, 3, 7, 7, 19, 33, 11, 153, 45, 633, 499, 0 };
            const std::uint32_t dim308JoeKuoD6Init[]   =   { 1, 3, 3, 5, 11, 3, 29, 93, 487, 33, 703, 0 };
            const std::uint32_t dim309JoeKuoD6Init[]   =   { 1, 1, 3, 15, 21, 53, 107, 179, 387, 927, 1757, 0 };
            const std::uint32_t dim310JoeKuoD6Init[]   =   { 1, 1, 3, 7, 21, 45, 51, 147, 175, 317, 361, 0 };
            const std::uint32_t dim311JoeKuoD6Init[]   =   { 1, 1, 1, 7, 7, 13, 15, 243, 269, 795, 1965, 0 };
            const std::uint32_t dim312JoeKuoD6Init[]   =   { 1, 1, 3, 5, 19, 33, 57, 115, 443, 537, 627, 0 };
            const std::uint32_t dim313JoeKuoD6Init[]   =   { 1, 3, 3, 9, 3, 39, 25, 61, 185, 717, 1049, 0 };
            const std::uint32_t dim314JoeKuoD6Init[]   =   { 1, 3, 7, 3, 7, 37, 107, 153, 7, 269, 1581, 0 };
            const std::uint32_t dim315JoeKuoD6Init[]   =   { 1, 1, 7, 3, 7, 41, 91, 41, 145, 489, 1245, 0 };
            const std::uint32_t dim316JoeKuoD6Init[]   =   { 1, 1, 5, 9, 7, 7, 105, 81, 403, 407, 283, 0 };
            const std::uint32_t dim317JoeKuoD6Init[]   =   { 1, 1, 7, 9, 27, 55, 29, 77, 193, 963, 949, 0 };
            const std::uint32_t dim318JoeKuoD6Init[]   =   { 1, 1, 5, 3, 25, 51, 107, 63, 403, 917, 815, 0 };
            const std::uint32_t dim319JoeKuoD6Init[]   =   { 1, 1, 7, 3, 7, 61, 19, 51, 457, 599, 535, 0 };
            const std::uint32_t dim320JoeKuoD6Init[]   =   { 1, 3, 7, 1, 23, 51, 105, 153, 239, 215, 1847, 0 };
            const std::uint32_t dim321JoeKuoD6Init[]   =   { 1, 1, 3, 5, 27, 23, 79, 49, 495, 45, 1935, 0 };
            const std::uint32_t dim322JoeKuoD6Init[]   =   { 1, 1, 1, 11, 11, 47, 55, 133, 495, 999, 1461, 0 };
            const std::uint32_t dim323JoeKuoD6Init[]   =   { 1, 1, 3, 15, 27, 51, 93, 17, 355, 763, 1675, 0 };
            const std::uint32_t dim324JoeKuoD6Init[]   =   { 1, 3, 1, 3, 1, 3, 79, 119, 499, 17, 995, 0 };
            const std::uint32_t dim325JoeKuoD6Init[]   =   { 1, 1, 1, 1, 15, 43, 45, 17, 167, 973, 799, 0 };
            const std::uint32_t dim326JoeKuoD6Init[]   =   { 1, 1, 1, 3, 27, 49, 89, 29, 483, 913, 2023, 0 };
            const std::uint32_t dim327JoeKuoD6Init[]   =   { 1, 1, 3, 3, 5, 11, 75, 7, 41, 851, 611, 0 };
            const std::uint32_t dim328JoeKuoD6Init[]   =   { 1, 3, 1, 3, 7, 57, 39, 123, 257, 283, 507, 0 };
            const std::uint32_t dim329JoeKuoD6Init[]   =   { 1, 3, 3, 11, 27, 23, 113, 229, 187, 299, 133, 0 };
            const std::uint32_t dim330JoeKuoD6Init[]   =   { 1, 1, 3, 13, 9, 63, 101, 77, 451, 169, 337, 0 };
            const std::uint32_t dim331JoeKuoD6Init[]   =   { 1, 3, 7, 3, 3, 59, 45, 195, 229, 415, 409, 0 };
            const std::uint32_t dim332JoeKuoD6Init[]   =   { 1, 3, 5, 3, 11, 19, 71, 93, 43, 857, 369, 0 };
            const std::uint32_t dim333JoeKuoD6Init[]   =   { 1, 3, 7, 9, 19, 33, 115, 19, 241, 703, 247, 0 };
            const std::uint32_t dim334JoeKuoD6Init[]   =   { 1, 3, 5, 11, 5, 35, 21, 155, 463, 1005, 1073, 0 };
            const std::uint32_t dim335JoeKuoD6Init[]   =   { 1, 3, 7, 3, 25, 15, 109, 83, 93, 69, 1189, 0 };
            const std::uint32_t dim336JoeKuoD6Init[]   =   { 1, 3, 5, 7, 5, 21, 93, 133, 135, 167, 903, 0 };
            const std::uint32_t dim337JoeKuoD6Init[]   =   { 1, 1, 7, 7, 3, 59, 121, 161, 285, 815, 1769, 3705, 0 };
            const std::uint32_t dim338JoeKuoD6Init[]   =   { 1, 3, 1, 1, 3, 47, 103, 171, 381, 609, 185, 373, 0 };
            const std::uint32_t dim339JoeKuoD6Init[]   =   { 1, 3, 3, 15, 23, 33, 107, 131, 441, 445, 689, 2059, 0 };
            const std::uint32_t dim340JoeKuoD6Init[]   =   { 1, 3, 3, 11, 7, 53, 101, 167, 435, 803, 1255, 3781, 0 };
            const std::uint32_t dim341JoeKuoD6Init[]   =   { 1, 1, 5, 11, 15, 59, 41, 19, 135, 835, 1263, 505, 0 };
            const std::uint32_t dim342JoeKuoD6Init[]   =   { 1, 1, 7, 11, 21, 49, 23, 219, 127, 961, 1065, 385, 0 };
            const std::uint32_t dim343JoeKuoD6Init[]   =   { 1, 3, 5, 15, 7, 47, 117, 217, 45, 731, 1639, 733, 0 };
            const std::uint32_t dim344JoeKuoD6Init[]   =   { 1, 1, 7, 11, 27, 57, 91, 87, 81, 35, 1269, 1007, 0 };
            const std::uint32_t dim345JoeKuoD6Init[]   =   { 1, 1, 3, 11, 15, 37, 53, 219, 193, 937, 1899, 3733, 0 };
            const std::uint32_t dim346JoeKuoD6Init[]   =   { 1, 3, 5, 3, 13, 11, 27, 19, 199, 393, 965, 2195, 0 };
            const std::uint32_t dim347JoeKuoD6Init[]   =   { 1, 3, 1, 3, 5, 1, 37, 173, 413, 1023, 553, 409, 0 };
            const std::uint32_t dim348JoeKuoD6Init[]   =   { 1, 3, 1, 7, 15, 29, 123, 95, 255, 373, 1799, 3841, 0 };
            const std::uint32_t dim349JoeKuoD6Init[]   =   { 1, 3, 5, 13, 21, 57, 51, 17, 511, 195, 1157, 1831, 0 };
            const std::uint32_t dim350JoeKuoD6Init[]   =   { 1, 1, 1, 15, 29, 19, 7, 73, 295, 519, 587, 3523, 0 };
            const std::uint32_t dim351JoeKuoD6Init[]   =   { 1, 1, 5, 13, 13, 35, 115, 191, 123, 535, 717, 1661, 0 };
            const std::uint32_t dim352JoeKuoD6Init[]   =   { 1, 3, 3, 5, 23, 21, 47, 251, 379, 921, 1119, 297, 0 };
            const std::uint32_t dim353JoeKuoD6Init[]   =   { 1, 3, 3, 9, 29, 53, 121, 201, 135, 193, 523, 2943, 0 };
            const std::uint32_t dim354JoeKuoD6Init[]   =   { 1, 1, 1, 7, 29, 45, 125, 9, 99, 867, 425, 601, 0 };
            const std::uint32_t dim355JoeKuoD6Init[]   =   { 1, 3, 1, 9, 13, 15, 67, 181, 109, 293, 1305, 3079, 0 };
            const std::uint32_t dim356JoeKuoD6Init[]   =   { 1, 3, 3, 9, 5, 35, 15, 209, 305, 87, 767, 2795, 0 };
            const std::uint32_t dim357JoeKuoD6Init[]   =   { 1, 3, 3, 11, 27, 57, 113, 123, 179, 643, 149, 523, 0 };
            const std::uint32_t dim358JoeKuoD6Init[]   =   { 1, 1, 3, 15, 11, 17, 67, 223, 63, 657, 335, 3309, 0 };
            const std::uint32_t dim359JoeKuoD6Init[]   =   { 1, 1, 1, 9, 25, 29, 109, 159, 39, 513, 571, 1761, 0 };
            const std::uint32_t dim360JoeKuoD6Init[]   =   { 1, 1, 3, 1, 5, 63, 75, 19, 455, 601, 123, 691, 0 };
            const std::uint32_t dim361JoeKuoD6Init[]   =   { 1, 1, 1, 3, 21, 5, 45, 169, 377, 513, 1951, 2565, 0 };
            const std::uint32_t dim362JoeKuoD6Init[]   =   { 1, 1, 3, 11, 3, 33, 119, 69, 253, 907, 805, 1449, 0 };
            const std::uint32_t dim363JoeKuoD6Init[]   =   { 1, 1, 5, 13, 31, 15, 17, 7, 499, 61, 687, 1867, 0 };
            const std::uint32_t dim364JoeKuoD6Init[]   =   { 1, 3, 7, 11, 17, 33, 73, 77, 299, 243, 641, 2345, 0 };
            const std::uint32_t dim365JoeKuoD6Init[]   =   { 1, 1, 7, 11, 9, 35, 31, 235, 359, 647, 379, 1161, 0 };
            const std::uint32_t dim366JoeKuoD6Init[]   =   { 1, 3, 3, 15, 31, 25, 5, 67, 33, 45, 437, 4067, 0 };
            const std::uint32_t dim367JoeKuoD6Init[]   =   { 1, 1, 3, 11, 7, 17, 37, 87, 333, 253, 1517, 2921, 0 };
            const std::uint32_t dim368JoeKuoD6Init[]   =   { 1, 1, 7, 15, 7, 15, 107, 189, 153, 769, 1521, 3427, 0 };
            const std::uint32_t dim369JoeKuoD6Init[]   =   { 1, 3, 5, 13, 5, 61, 113, 37, 293, 393, 113, 43, 0 };
            const std::uint32_t dim370JoeKuoD6Init[]   =   { 1, 1, 1, 15, 29, 43, 107, 31, 167, 147, 301, 1021, 0 };
            const std::uint32_t dim371JoeKuoD6Init[]   =   { 1, 1, 1, 13, 3, 1, 35, 93, 195, 181, 2027, 1491, 0 };
            const std::uint32_t dim372JoeKuoD6Init[]   =   { 1, 3, 3, 3, 13, 33, 77, 199, 153, 221, 1699, 3671, 0 };
            const std::uint32_t dim373JoeKuoD6Init[]   =   { 1, 3, 5, 13, 7, 49, 123, 155, 495, 681, 819, 809, 0 };
            const std::uint32_t dim374JoeKuoD6Init[]   =   { 1, 3, 5, 15, 27, 61, 117, 189, 183, 887, 617, 4053, 0 };
            const std::uint32_t dim375JoeKuoD6Init[]   =   { 1, 1, 1, 7, 31, 59, 125, 235, 389, 369, 447, 1039, 0 };
            const std::uint32_t dim376JoeKuoD6Init[]   =   { 1, 3, 5, 1, 5, 39, 115, 89, 249, 377, 431, 3747, 0 };
            const std::uint32_t dim377JoeKuoD6Init[]   =   { 1, 1, 1, 5, 7, 47, 59, 157, 77, 445, 699, 3439, 0 };
            const std::uint32_t dim378JoeKuoD6Init[]   =   { 1, 1, 3, 5, 11, 21, 19, 75, 11, 599, 1575, 735, 0 };
            const std::uint32_t dim379JoeKuoD6Init[]   =   { 1, 3, 5, 3, 19, 13, 41, 69, 199, 143, 1761, 3215, 0 };
            const std::uint32_t dim380JoeKuoD6Init[]   =   { 1, 3, 5, 7, 19, 43, 25, 41, 41, 11, 1647, 2783, 0 };
            const std::uint32_t dim381JoeKuoD6Init[]   =   { 1, 3, 1, 9, 19, 45, 111, 97, 405, 399, 457, 3219, 0 };
            const std::uint32_t dim382JoeKuoD6Init[]   =   { 1, 1, 3, 1, 23, 15, 65, 121, 59, 985, 829, 2259, 0 };
            const std::uint32_t dim383JoeKuoD6Init[]   =   { 1, 1, 3, 7, 17, 13, 107, 229, 75, 551, 1299, 2363, 0 };
            const std::uint32_t dim384JoeKuoD6Init[]   =   { 1, 1, 5, 5, 21, 57, 23, 199, 509, 139, 2007, 3875, 0 };
            const std::uint32_t dim385JoeKuoD6Init[]   =   { 1, 3, 1, 11, 19, 53, 15, 229, 215, 741, 695, 823, 0 };
            const std::uint32_t dim386JoeKuoD6Init[]   =   { 1, 3, 7, 1, 29, 3, 17, 163, 417, 559, 549, 319, 0 };
            const std::uint32_t dim387JoeKuoD6Init[]   =   { 1, 3, 1, 13, 17, 9, 47, 133, 365, 7, 1937, 1071, 0 };
            const std::uint32_t dim388JoeKuoD6Init[]   =   { 1, 3, 5, 7, 19, 37, 55, 163, 301, 249, 689, 2327, 0 };
            const std::uint32_t dim389JoeKuoD6Init[]   =   { 1, 3, 5, 13, 11, 23, 61, 205, 257, 377, 615, 1457, 0 };
            const std::uint32_t dim390JoeKuoD6Init[]   =   { 1, 3, 5, 1, 23, 37, 13, 75, 331, 495, 579, 3367, 0 };
            const std::uint32_t dim391JoeKuoD6Init[]   =   { 1, 1, 1, 9, 1, 23, 49, 129, 475, 543, 883, 2531, 0 };
            const std::uint32_t dim392JoeKuoD6Init[]   =   { 1, 3, 1, 5, 23, 59, 51, 35, 343, 695, 219, 369, 0 };
            const std::uint32_t dim393JoeKuoD6Init[]   =   { 1, 3, 3, 1, 27, 17, 63, 97, 71, 507, 1929, 613, 0 };
            const std::uint32_t dim394JoeKuoD6Init[]   =   { 1, 1, 5, 1, 21, 31, 11, 109, 247, 409, 1817, 2173, 0 };
            const std::uint32_t dim395JoeKuoD6Init[]   =   { 1, 1, 3, 15, 23, 9, 7, 209, 301, 23, 147, 1691, 0 };
            const std::uint32_t dim396JoeKuoD6Init[]   =   { 1, 1, 7, 5, 5, 19, 37, 229, 249, 277, 1115, 2309, 0 };
            const std::uint32_t dim397JoeKuoD6Init[]   =   { 1, 1, 1, 5, 5, 63, 5, 249, 285, 431, 343, 2467, 0 };
            const std::uint32_t dim398JoeKuoD6Init[]   =   { 1, 1, 1, 11, 7, 45, 35, 75, 505, 537, 29, 2919, 0 };
            const std::uint32_t dim399JoeKuoD6Init[]   =   { 1, 3, 5, 15, 11, 39, 15, 63, 263, 9, 199, 445, 0 };
            const std::uint32_t dim400JoeKuoD6Init[]   =   { 1, 3, 3, 3, 27, 63, 53, 171, 227, 63, 1049, 827, 0 };
            const std::uint32_t dim401JoeKuoD6Init[]   =   { 1, 1, 3, 13, 7, 11, 115, 183, 179, 937, 1785, 381, 0 };
            const std::uint32_t dim402JoeKuoD6Init[]   =   { 1, 3, 1, 11, 13, 15, 107, 81, 53, 295, 1785, 3757, 0 };
            const std::uint32_t dim403JoeKuoD6Init[]   =   { 1, 3, 3, 13, 11, 5, 109, 243, 3, 505, 323, 1373, 0 };
            const std::uint32_t dim404JoeKuoD6Init[]   =   { 1, 3, 3, 11, 21, 51, 17, 177, 381, 937, 1263, 3889, 0 };
            const std::uint32_t dim405JoeKuoD6Init[]   =   { 1, 3, 5, 9, 27, 25, 85, 193, 143, 573, 1189, 2995, 0 };
            const std::uint32_t dim406JoeKuoD6Init[]   =   { 1, 3, 5, 11, 13, 9, 81, 21, 159, 953, 91, 1751, 0 };
            const std::uint32_t dim407JoeKuoD6Init[]   =   { 1, 1, 3, 3, 27, 61, 11, 253, 391, 333, 1105, 635, 0 };
            const std::uint32_t dim408JoeKuoD6Init[]   =   { 1, 3, 3, 15, 9, 57, 95, 81, 419, 735, 251, 1141, 0 };
            const std::uint32_t dim409JoeKuoD6Init[]   =   { 1, 1, 5, 9, 31, 39, 59, 13, 319, 807, 1241, 2433, 0 };
            const std::uint32_t dim410JoeKuoD6Init[]   =   { 1, 3, 3, 5, 27, 13, 107, 141, 423, 937, 2027, 3233, 0 };
            const std::uint32_t dim411JoeKuoD6Init[]   =   { 1, 3, 3, 9, 9, 25, 125, 23, 443, 835, 1245, 847, 0 };
            const std::uint32_t dim412JoeKuoD6Init[]   =   { 1, 1, 7, 15, 17, 17, 83, 107, 411, 285, 847, 1571, 0 };
            const std::uint32_t dim413JoeKuoD6Init[]   =   { 1, 1, 3, 13, 29, 61, 37, 81, 349, 727, 1453, 1957, 0 };
            const std::uint32_t dim414JoeKuoD6Init[]   =   { 1, 3, 7, 11, 31, 13, 59, 77, 273, 591, 1265, 1533, 0 };
            const std::uint32_t dim415JoeKuoD6Init[]   =   { 1, 1, 7, 7, 13, 17, 25, 25, 187, 329, 347, 1473, 0 };
            const std::uint32_t dim416JoeKuoD6Init[]   =   { 1, 3, 7, 7, 5, 51, 37, 99, 221, 153, 503, 2583, 0 };
            const std::uint32_t dim417JoeKuoD6Init[]   =   { 1, 3, 1, 13, 19, 27, 11, 69, 181, 479, 1183, 3229, 0 };
            const std::uint32_t dim418JoeKuoD6Init[]   =   { 1, 3, 3, 13, 23, 21, 103, 147, 323, 909, 947, 315, 0 };
            const std::uint32_t dim419JoeKuoD6Init[]   =   { 1, 3, 1, 3, 23, 1, 31, 59, 93, 513, 45, 2271, 0 };
            const std::uint32_t dim420JoeKuoD6Init[]   =   { 1, 3, 5, 1, 7, 43, 109, 59, 231, 41, 1515, 2385, 0 };
            const std::uint32_t dim421JoeKuoD6Init[]   =   { 1, 3, 1, 5, 31, 57, 49, 223, 283, 1013, 11, 701, 0 };
            const std::uint32_t dim422JoeKuoD6Init[]   =   { 1, 1, 5, 1, 19, 53, 55, 31, 31, 299, 495, 693, 0 };
            const std::uint32_t dim423JoeKuoD6Init[]   =   { 1, 3, 3, 9, 5, 33, 77, 253, 427, 791, 731, 1019, 0 };
            const std::uint32_t dim424JoeKuoD6Init[]   =   { 1, 3, 7, 11, 1, 9, 119, 203, 53, 877, 1707, 3499, 0 };
            const std::uint32_t dim425JoeKuoD6Init[]   =   { 1, 1, 3, 7, 13, 39, 55, 159, 423, 113, 1653, 3455, 0 };
            const std::uint32_t dim426JoeKuoD6Init[]   =   { 1, 1, 3, 5, 21, 47, 51, 59, 55, 411, 931, 251, 0 };
            const std::uint32_t dim427JoeKuoD6Init[]   =   { 1, 3, 7, 3, 31, 25, 81, 115, 405, 239, 741, 455, 0 };
            const std::uint32_t dim428JoeKuoD6Init[]   =   { 1, 1, 5, 1, 31, 3, 101, 83, 479, 491, 1779, 2225, 0 };
            const std::uint32_t dim429JoeKuoD6Init[]   =   { 1, 3, 3, 3, 9, 37, 107, 161, 203, 503, 767, 3435, 0 };
            const std::uint32_t dim430JoeKuoD6Init[]   =   { 1, 3, 7, 9, 1, 27, 61, 119, 233, 39, 1375, 4089, 0 };
            const std::uint32_t dim431JoeKuoD6Init[]   =   { 1, 1, 5, 9, 1, 31, 45, 51, 369, 587, 383, 2813, 0 };
            const std::uint32_t dim432JoeKuoD6Init[]   =   { 1, 3, 7, 5, 31, 7, 49, 119, 487, 591, 1627, 53, 0 };
            const std::uint32_t dim433JoeKuoD6Init[]   =   { 1, 1, 7, 1, 9, 47, 1, 223, 369, 711, 1603, 1917, 0 };
            const std::uint32_t dim434JoeKuoD6Init[]   =   { 1, 3, 5, 3, 21, 37, 111, 17, 483, 739, 1193, 2775, 0 };
            const std::uint32_t dim435JoeKuoD6Init[]   =   { 1, 3, 3, 7, 17, 11, 51, 117, 455, 191, 1493, 3821, 0 };
            const std::uint32_t dim436JoeKuoD6Init[]   =   { 1, 1, 5, 9, 23, 39, 99, 181, 343, 485, 99, 1931, 0 };
            const std::uint32_t dim437JoeKuoD6Init[]   =   { 1, 3, 1, 7, 29, 49, 31, 71, 489, 527, 1763, 2909, 0 };
            const std::uint32_t dim438JoeKuoD6Init[]   =   { 1, 1, 5, 11, 5, 5, 73, 189, 321, 57, 1191, 3685, 0 };
            const std::uint32_t dim439JoeKuoD6Init[]   =   { 1, 1, 5, 15, 13, 45, 125, 207, 371, 415, 315, 983, 0 };
            const std::uint32_t dim440JoeKuoD6Init[]   =   { 1, 3, 3, 5, 25, 59, 33, 31, 239, 919, 1859, 2709, 0 };
            const std::uint32_t dim441JoeKuoD6Init[]   =   { 1, 3, 5, 13, 27, 61, 23, 115, 61, 413, 1275, 3559, 0 };
            const std::uint32_t dim442JoeKuoD6Init[]   =   { 1, 3, 7, 15, 5, 59, 101, 81, 47, 967, 809, 3189, 0 };
            const std::uint32_t dim443JoeKuoD6Init[]   =   { 1, 1, 5, 11, 31, 15, 39, 25, 173, 505, 809, 2677, 0 };
            const std::uint32_t dim444JoeKuoD6Init[]   =   { 1, 1, 5, 9, 19, 13, 95, 89, 511, 127, 1395, 2935, 0 };
            const std::uint32_t dim445JoeKuoD6Init[]   =   { 1, 1, 5, 5, 31, 45, 9, 57, 91, 303, 1295, 3215, 0 };
            const std::uint32_t dim446JoeKuoD6Init[]   =   { 1, 3, 3, 3, 19, 15, 113, 187, 217, 489, 1285, 1803, 0 };
            const std::uint32_t dim447JoeKuoD6Init[]   =   { 1, 1, 3, 1, 13, 29, 57, 139, 255, 197, 537, 2183, 0 };
            const std::uint32_t dim448JoeKuoD6Init[]   =   { 1, 3, 1, 15, 11, 7, 53, 255, 467, 9, 757, 3167, 0 };
            const std::uint32_t dim449JoeKuoD6Init[]   =   { 1, 3, 3, 15, 21, 13, 9, 189, 359, 323, 49, 333, 0 };
            const std::uint32_t dim450JoeKuoD6Init[]   =   { 1, 3, 7, 11, 7, 37, 21, 119, 401, 157, 1659, 1069, 0 };
            const std::uint32_t dim451JoeKuoD6Init[]   =   { 1, 1, 5, 7, 17, 33, 115, 229, 149, 151, 2027, 279, 0 };
            const std::uint32_t dim452JoeKuoD6Init[]   =   { 1, 1, 5, 15, 5, 49, 77, 155, 383, 385, 1985, 945, 0 };
            const std::uint32_t dim453JoeKuoD6Init[]   =   { 1, 3, 7, 3, 7, 55, 85, 41, 357, 527, 1715, 1619, 0 };
            const std::uint32_t dim454JoeKuoD6Init[]   =   { 1, 1, 3, 1, 21, 45, 115, 21, 199, 967, 1581, 3807, 0 };
            const std::uint32_t dim455JoeKuoD6Init[]   =   { 1, 1, 3, 7, 21, 39, 117, 191, 169, 73, 413, 3417, 0 };
            const std::uint32_t dim456JoeKuoD6Init[]   =   { 1, 1, 1, 13, 1, 31, 57, 195, 231, 321, 367, 1027, 0 };
            const std::uint32_t dim457JoeKuoD6Init[]   =   { 1, 3, 7, 3, 11, 29, 47, 161, 71, 419, 1721, 437, 0 };
            const std::uint32_t dim458JoeKuoD6Init[]   =   { 1, 1, 7, 3, 11, 9, 43, 65, 157, 1, 1851, 823, 0 };
            const std::uint32_t dim459JoeKuoD6Init[]   =   { 1, 1, 1, 5, 21, 15, 31, 101, 293, 299, 127, 1321, 0 };
            const std::uint32_t dim460JoeKuoD6Init[]   =   { 1, 1, 7, 1, 27, 1, 11, 229, 241, 705, 43, 1475, 0 };
            const std::uint32_t dim461JoeKuoD6Init[]   =   { 1, 3, 7, 1, 5, 15, 73, 183, 193, 55, 1345, 49, 0 };
            const std::uint32_t dim462JoeKuoD6Init[]   =   { 1, 3, 3, 3, 19, 3, 55, 21, 169, 663, 1675, 137, 0 };
            const std::uint32_t dim463JoeKuoD6Init[]   =   { 1, 1, 1, 13, 7, 21, 69, 67, 373, 965, 1273, 2279, 0 };
            const std::uint32_t dim464JoeKuoD6Init[]   =   { 1, 1, 7, 7, 21, 23, 17, 43, 341, 845, 465, 3355, 0 };
            const std::uint32_t dim465JoeKuoD6Init[]   =   { 1, 3, 5, 5, 25, 5, 81, 101, 233, 139, 359, 2057, 0 };
            const std::uint32_t dim466JoeKuoD6Init[]   =   { 1, 1, 3, 11, 15, 39, 55, 3, 471, 765, 1143, 3941, 0 };
            const std::uint32_t dim467JoeKuoD6Init[]   =   { 1, 1, 7, 15, 9, 57, 81, 79, 215, 433, 333, 3855, 0 };
            const std::uint32_t dim468JoeKuoD6Init[]   =   { 1, 1, 5, 5, 19, 45, 83, 31, 209, 363, 701, 1303, 0 };
            const std::uint32_t dim469JoeKuoD6Init[]   =   { 1, 3, 7, 5, 1, 13, 55, 163, 435, 807, 287, 2031, 0 };
            const std::uint32_t dim470JoeKuoD6Init[]   =   { 1, 3, 3, 7, 3, 3, 17, 197, 39, 169, 489, 1769, 0 };
            const std::uint32_t dim471JoeKuoD6Init[]   =   { 1, 1, 3, 5, 29, 43, 87, 161, 289, 339, 1233, 2353, 0 };
            const std::uint32_t dim472JoeKuoD6Init[]   =   { 1, 3, 3, 9, 21, 9, 77, 1, 453, 167, 1643, 2227, 0 };
            const std::uint32_t dim473JoeKuoD6Init[]   =   { 1, 1, 7, 1, 15, 7, 67, 33, 193, 241, 1031, 2339, 0 };
            const std::uint32_t dim474JoeKuoD6Init[]   =   { 1, 3, 1, 11, 1, 63, 45, 65, 265, 661, 849, 1979, 0 };
            const std::uint32_t dim475JoeKuoD6Init[]   =   { 1, 3, 1, 13, 19, 49, 3, 11, 159, 213, 659, 2839, 0 };
            const std::uint32_t dim476JoeKuoD6Init[]   =   { 1, 3, 5, 11, 9, 29, 27, 227, 253, 449, 1403, 3427, 0 };
            const std::uint32_t dim477JoeKuoD6Init[]   =   { 1, 1, 3, 1, 7, 3, 77, 143, 277, 779, 1499, 475, 0 };
            const std::uint32_t dim478JoeKuoD6Init[]   =   { 1, 1, 1, 5, 11, 23, 87, 131, 393, 849, 193, 3189, 0 };
            const std::uint32_t dim479JoeKuoD6Init[]   =   { 1, 3, 5, 11, 3, 3, 89, 9, 449, 243, 1501, 1739, 0 };
            const std::uint32_t dim480JoeKuoD6Init[]   =   { 1, 3, 1, 9, 29, 29, 113, 15, 65, 611, 135, 3687, 0 };
            const std::uint32_t dim481JoeKuoD6Init[]   =   { 1, 1, 1, 9, 21, 19, 39, 151, 395, 501, 1339, 959, 2725, 0 };
            const std::uint32_t dim482JoeKuoD6Init[]   =   { 1, 3, 7, 1, 7, 35, 45, 33, 119, 225, 1631, 1695, 1459, 0 };
            const std::uint32_t dim483JoeKuoD6Init[]   =   { 1, 1, 1, 3, 25, 55, 37, 79, 167, 907, 1075, 271, 4059, 0 };
            const std::uint32_t dim484JoeKuoD6Init[]   =   { 1, 3, 5, 13, 5, 13, 53, 165, 437, 67, 1705, 3177, 8095, 0 };
            const std::uint32_t dim485JoeKuoD6Init[]   =   { 1, 3, 3, 13, 27, 57, 95, 55, 443, 245, 1945, 1725, 1929, 0 };
            const std::uint32_t dim486JoeKuoD6Init[]   =   { 1, 3, 1, 9, 5, 33, 109, 35, 99, 827, 341, 2401, 2411, 0 };
            const std::uint32_t dim487JoeKuoD6Init[]   =   { 1, 1, 5, 9, 7, 33, 43, 39, 87, 799, 635, 3481, 7159, 0 };
            const std::uint32_t dim488JoeKuoD6Init[]   =   { 1, 3, 1, 1, 31, 15, 45, 27, 337, 113, 987, 2065, 2529, 0 };
            const std::uint32_t dim489JoeKuoD6Init[]   =   { 1, 1, 5, 9, 5, 15, 105, 123, 479, 289, 1609, 2177, 4629, 0 };
            const std::uint32_t dim490JoeKuoD6Init[]   =   { 1, 3, 5, 11, 31, 47, 97, 87, 385, 195, 1041, 651, 3271, 0 };
            const std::uint32_t dim491JoeKuoD6Init[]   =   { 1, 1, 3, 7, 17, 3, 101, 55, 87, 629, 1687, 1387, 2745, 0 };
            const std::uint32_t dim492JoeKuoD6Init[]   =   { 1, 3, 5, 5, 7, 21, 9, 237, 313, 549, 1107, 117, 6183, 0 };
            const std::uint32_t dim493JoeKuoD6Init[]   =   { 1, 1, 3, 9, 9, 5, 55, 201, 487, 851, 1103, 2993, 4055, 0 };
            const std::uint32_t dim494JoeKuoD6Init[]   =   { 1, 1, 5, 9, 31, 19, 59, 7, 363, 381, 1167, 2057, 5715, 0 };
            const std::uint32_t dim495JoeKuoD6Init[]   =   { 1, 3, 3, 15, 23, 63, 19, 227, 387, 827, 487, 1049, 7471, 0 };
            const std::uint32_t dim496JoeKuoD6Init[]   =   { 1, 3, 1, 5, 23, 25, 61, 245, 363, 863, 963, 3583, 6475, 0 };
            const std::uint32_t dim497JoeKuoD6Init[]   =   { 1, 1, 5, 1, 5, 27, 81, 85, 275, 49, 235, 3291, 1195, 0 };
            const std::uint32_t dim498JoeKuoD6Init[]   =   { 1, 1, 5, 7, 23, 53, 85, 107, 511, 779, 1265, 1093, 7859, 0 };
            const std::uint32_t dim499JoeKuoD6Init[]   =   { 1, 3, 3, 1, 9, 21, 75, 219, 59, 485, 1739, 3845, 1109, 0 };
            const std::uint32_t dim500JoeKuoD6Init[]   =   { 1, 3, 5, 1, 13, 41, 19, 143, 293, 391, 2023, 1791, 4399, 0 };
            const std::uint32_t dim501JoeKuoD6Init[]   =   { 1, 3, 7, 15, 21, 13, 21, 195, 215, 413, 523, 2099, 2341, 0 };
            const std::uint32_t dim502JoeKuoD6Init[]   =   { 1, 1, 1, 3, 29, 51, 47, 57, 135, 575, 943, 1673, 541, 0 };
            const std::uint32_t dim503JoeKuoD6Init[]   =   { 1, 3, 5, 1, 9, 13, 113, 175, 447, 115, 657, 4077, 5973, 0 };
            const std::uint32_t dim504JoeKuoD6Init[]   =   { 1, 1, 1, 11, 17, 41, 37, 95, 297, 579, 911, 2207, 2387, 0 };
            const std::uint32_t dim505JoeKuoD6Init[]   =   { 1, 3, 5, 3, 23, 11, 23, 231, 93, 667, 711, 1563, 7961, 0 };
            const std::uint32_t dim506JoeKuoD6Init[]   =   { 1, 1, 7, 3, 17, 59, 13, 181, 141, 991, 1817, 457, 1711, 0 };
            const std::uint32_t dim507JoeKuoD6Init[]   =   { 1, 3, 3, 5, 31, 59, 81, 205, 245, 537, 1049, 997, 1815, 0 };
            const std::uint32_t dim508JoeKuoD6Init[]   =   { 1, 3, 7, 5, 17, 13, 9, 79, 17, 185, 5, 2211, 6263, 0 };
            const std::uint32_t dim509JoeKuoD6Init[]   =   { 1, 3, 7, 13, 7, 53, 61, 145, 13, 285, 1203, 947, 2933, 0 };
            const std::uint32_t dim510JoeKuoD6Init[]   =   { 1, 1, 7, 3, 31, 19, 69, 217, 47, 441, 1893, 673, 4451, 0 };
            const std::uint32_t dim511JoeKuoD6Init[]   =   { 1, 1, 1, 1, 25, 9, 23, 225, 385, 629, 603, 3747, 4241, 0 };
            const std::uint32_t dim512JoeKuoD6Init[]   =   { 1, 3, 1, 9, 5, 37, 31, 237, 431, 79, 1521, 459, 2523, 0 };
            const std::uint32_t dim513JoeKuoD6Init[]   =   { 1, 3, 7, 3, 9, 43, 105, 179, 5, 225, 799, 1777, 4893, 0 };
            const std::uint32_t dim514JoeKuoD6Init[]   =   { 1, 1, 3, 1, 29, 45, 29, 159, 267, 247, 455, 847, 3909, 0 };
            const std::uint32_t dim515JoeKuoD6Init[]   =   { 1, 1, 3, 7, 25, 21, 121, 57, 467, 275, 719, 1521, 7319, 0 };
            const std::uint32_t dim516JoeKuoD6Init[]   =   { 1, 3, 1, 3, 11, 35, 119, 123, 81, 979, 1187, 3623, 4293, 0 };
            const std::uint32_t dim517JoeKuoD6Init[]   =   { 1, 1, 1, 7, 15, 25, 121, 235, 25, 487, 873, 1787, 1977, 0 };
            const std::uint32_t dim518JoeKuoD6Init[]   =   { 1, 1, 1, 11, 3, 7, 17, 135, 345, 353, 383, 4011, 2573, 0 };
            const std::uint32_t dim519JoeKuoD6Init[]   =   { 1, 3, 7, 15, 27, 13, 97, 123, 65, 675, 951, 1285, 6559, 0 };
            const std::uint32_t dim520JoeKuoD6Init[]   =   { 1, 3, 7, 3, 7, 1, 71, 19, 325, 765, 337, 1197, 2697, 0 };
            const std::uint32_t dim521JoeKuoD6Init[]   =   { 1, 3, 5, 1, 31, 37, 11, 71, 169, 283, 83, 3801, 7083, 0 };
            const std::uint32_t dim522JoeKuoD6Init[]   =   { 1, 1, 3, 15, 17, 29, 83, 65, 275, 679, 1749, 4007, 7749, 0 };
            const std::uint32_t dim523JoeKuoD6Init[]   =   { 1, 1, 3, 1, 21, 11, 41, 95, 237, 361, 1819, 2783, 2383, 0 };
            const std::uint32_t dim524JoeKuoD6Init[]   =   { 1, 3, 7, 11, 29, 57, 111, 187, 465, 145, 605, 1987, 8109, 0 };
            const std::uint32_t dim525JoeKuoD6Init[]   =   { 1, 1, 3, 3, 19, 15, 55, 83, 357, 1001, 643, 1517, 6529, 0 };
            const std::uint32_t dim526JoeKuoD6Init[]   =   { 1, 3, 1, 5, 29, 35, 73, 23, 77, 619, 1523, 1725, 8145, 0 };
            const std::uint32_t dim527JoeKuoD6Init[]   =   { 1, 1, 5, 5, 19, 23, 7, 197, 449, 337, 717, 2921, 315, 0 };
            const std::uint32_t dim528JoeKuoD6Init[]   =   { 1, 3, 5, 9, 7, 63, 117, 97, 97, 813, 1925, 2817, 1579, 0 };
            const std::uint32_t dim529JoeKuoD6Init[]   =   { 1, 1, 1, 11, 31, 7, 25, 235, 231, 133, 1007, 1371, 1553, 0 };
            const std::uint32_t dim530JoeKuoD6Init[]   =   { 1, 1, 7, 5, 19, 7, 47, 171, 267, 243, 1331, 567, 6033, 0 };
            const std::uint32_t dim531JoeKuoD6Init[]   =   { 1, 1, 5, 1, 7, 49, 55, 89, 109, 735, 1455, 3193, 6239, 0 };
            const std::uint32_t dim532JoeKuoD6Init[]   =   { 1, 1, 1, 7, 1, 61, 9, 103, 3, 929, 1481, 2927, 2957, 0 };
            const std::uint32_t dim533JoeKuoD6Init[]   =   { 1, 1, 5, 13, 17, 21, 75, 49, 255, 1019, 1161, 2133, 1177, 0 };
            const std::uint32_t dim534JoeKuoD6Init[]   =   { 1, 3, 1, 3, 13, 15, 41, 247, 211, 409, 1163, 523, 2635, 0 };
            const std::uint32_t dim535JoeKuoD6Init[]   =   { 1, 3, 7, 7, 21, 59, 91, 149, 479, 391, 681, 2311, 6249, 0 };
            const std::uint32_t dim536JoeKuoD6Init[]   =   { 1, 1, 5, 11, 27, 53, 21, 211, 197, 815, 719, 1605, 255, 0 };
            const std::uint32_t dim537JoeKuoD6Init[]   =   { 1, 1, 3, 3, 9, 33, 59, 3, 323, 1, 101, 1135, 8105, 0 };
            const std::uint32_t dim538JoeKuoD6Init[]   =   { 1, 3, 3, 1, 29, 5, 17, 141, 51, 991, 841, 327, 3859, 0 };
            const std::uint32_t dim539JoeKuoD6Init[]   =   { 1, 3, 1, 5, 11, 19, 23, 89, 175, 173, 165, 2881, 1881, 0 };
            const std::uint32_t dim540JoeKuoD6Init[]   =   { 1, 1, 1, 15, 13, 51, 87, 39, 495, 611, 1341, 1531, 7029, 0 };
            const std::uint32_t dim541JoeKuoD6Init[]   =   { 1, 1, 3, 11, 13, 55, 75, 185, 57, 61, 1917, 2051, 5965, 0 };
            const std::uint32_t dim542JoeKuoD6Init[]   =   { 1, 1, 5, 5, 7, 53, 11, 217, 213, 933, 921, 3607, 5175, 0 };
            const std::uint32_t dim543JoeKuoD6Init[]   =   { 1, 3, 3, 5, 17, 53, 103, 251, 369, 781, 1319, 3717, 4439, 0 };
            const std::uint32_t dim544JoeKuoD6Init[]   =   { 1, 3, 5, 13, 1, 39, 25, 235, 321, 773, 251, 3111, 6397, 0 };
            const std::uint32_t dim545JoeKuoD6Init[]   =   { 1, 1, 7, 3, 31, 5, 25, 29, 325, 385, 1313, 127, 4705, 0 };
            const std::uint32_t dim546JoeKuoD6Init[]   =   { 1, 1, 5, 15, 15, 27, 15, 85, 239, 243, 1633, 3473, 2621, 0 };
            const std::uint32_t dim547JoeKuoD6Init[]   =   { 1, 3, 3, 3, 9, 19, 113, 13, 137, 165, 25, 2957, 7549, 0 };
            const std::uint32_t dim548JoeKuoD6Init[]   =   { 1, 3, 1, 3, 11, 21, 3, 97, 417, 183, 1205, 1437, 247, 0 };
            const std::uint32_t dim549JoeKuoD6Init[]   =   { 1, 1, 7, 3, 17, 21, 125, 55, 67, 387, 385, 2323, 887, 0 };
            const std::uint32_t dim550JoeKuoD6Init[]   =   { 1, 3, 5, 5, 29, 11, 103, 223, 233, 641, 133, 415, 1297, 0 };
            const std::uint32_t dim551JoeKuoD6Init[]   =   { 1, 3, 3, 11, 1, 9, 5, 189, 235, 1007, 1363, 3985, 889, 0 };
            const std::uint32_t dim552JoeKuoD6Init[]   =   { 1, 3, 7, 9, 23, 19, 19, 183, 269, 403, 1643, 3559, 5189, 0 };
            const std::uint32_t dim553JoeKuoD6Init[]   =   { 1, 3, 7, 3, 29, 45, 17, 69, 475, 149, 1291, 2689, 7625, 0 };
            const std::uint32_t dim554JoeKuoD6Init[]   =   { 1, 3, 7, 3, 27, 37, 41, 73, 253, 1001, 431, 1111, 7887, 0 };
            const std::uint32_t dim555JoeKuoD6Init[]   =   { 1, 1, 7, 5, 3, 7, 87, 143, 289, 495, 631, 3011, 6151, 0 };
            const std::uint32_t dim556JoeKuoD6Init[]   =   { 1, 1, 1, 13, 5, 45, 17, 167, 23, 975, 801, 1975, 6833, 0 };
            const std::uint32_t dim557JoeKuoD6Init[]   =   { 1, 3, 1, 11, 7, 21, 39, 23, 213, 429, 1301, 2059, 197, 0 };
            const std::uint32_t dim558JoeKuoD6Init[]   =   { 1, 3, 3, 15, 3, 57, 121, 133, 29, 711, 1961, 2497, 189, 0 };
            const std::uint32_t dim559JoeKuoD6Init[]   =   { 1, 1, 3, 5, 11, 55, 115, 137, 233, 673, 985, 2849, 5911, 0 };
            const std::uint32_t dim560JoeKuoD6Init[]   =   { 1, 1, 7, 15, 29, 45, 1, 241, 329, 323, 925, 2821, 3331, 0 };
            const std::uint32_t dim561JoeKuoD6Init[]   =   { 1, 1, 5, 7, 13, 31, 81, 105, 199, 145, 195, 1365, 5119, 0 };
            const std::uint32_t dim562JoeKuoD6Init[]   =   { 1, 3, 7, 11, 3, 55, 11, 31, 117, 343, 1265, 1837, 2451, 0 };
            const std::uint32_t dim563JoeKuoD6Init[]   =   { 1, 1, 3, 7, 29, 57, 61, 179, 429, 591, 177, 1945, 2159, 0 };
            const std::uint32_t dim564JoeKuoD6Init[]   =   { 1, 3, 5, 11, 23, 49, 101, 137, 339, 323, 1035, 1749, 7737, 0 };
            const std::uint32_t dim565JoeKuoD6Init[]   =   { 1, 3, 1, 13, 21, 35, 55, 79, 19, 269, 1055, 2651, 7083, 0 };
            const std::uint32_t dim566JoeKuoD6Init[]   =   { 1, 3, 3, 11, 9, 9, 95, 167, 437, 361, 1185, 4083, 603, 0 };
            const std::uint32_t dim567JoeKuoD6Init[]   =   { 1, 1, 1, 7, 31, 61, 77, 65, 489, 657, 691, 2423, 4147, 0 };
            const std::uint32_t dim568JoeKuoD6Init[]   =   { 1, 3, 5, 7, 21, 37, 87, 191, 311, 453, 2013, 829, 2619, 0 };
            const std::uint32_t dim569JoeKuoD6Init[]   =   { 1, 1, 5, 9, 17, 47, 35, 101, 5, 813, 1157, 1279, 7365, 0 };
            const std::uint32_t dim570JoeKuoD6Init[]   =   { 1, 1, 5, 3, 11, 35, 113, 199, 369, 721, 901, 1471, 7801, 0 };
            const std::uint32_t dim571JoeKuoD6Init[]   =   { 1, 3, 1, 5, 9, 61, 83, 157, 391, 739, 1957, 2123, 4341, 0 };
            const std::uint32_t dim572JoeKuoD6Init[]   =   { 1, 3, 5, 11, 19, 19, 111, 225, 383, 219, 997, 717, 7505, 0 };
            const std::uint32_t dim573JoeKuoD6Init[]   =   { 1, 3, 1, 11, 13, 63, 35, 127, 209, 831, 501, 3017, 3507, 0 };
            const std::uint32_t dim574JoeKuoD6Init[]   =   { 1, 3, 7, 9, 29, 7, 11, 163, 81, 563, 1445, 3215, 6377, 0 };
            const std::uint32_t dim575JoeKuoD6Init[]   =   { 1, 3, 7, 11, 25, 3, 39, 195, 491, 45, 839, 4021, 4899, 0 };
            const std::uint32_t dim576JoeKuoD6Init[]   =   { 1, 3, 7, 15, 13, 5, 67, 143, 117, 505, 1281, 3679, 5695, 0 };
            const std::uint32_t dim577JoeKuoD6Init[]   =   { 1, 3, 7, 9, 9, 19, 21, 221, 147, 763, 683, 2211, 589, 0 };
            const std::uint32_t dim578JoeKuoD6Init[]   =   { 1, 1, 3, 5, 21, 47, 53, 109, 299, 807, 1153, 1209, 7961, 0 };
            const std::uint32_t dim579JoeKuoD6Init[]   =   { 1, 3, 7, 11, 9, 31, 45, 43, 505, 647, 1127, 2681, 4917, 0 };
            const std::uint32_t dim580JoeKuoD6Init[]   =   { 1, 1, 5, 15, 31, 41, 63, 113, 399, 727, 673, 2587, 5259, 0 };
            const std::uint32_t dim581JoeKuoD6Init[]   =   { 1, 1, 1, 13, 17, 53, 35, 99, 57, 243, 1447, 1919, 2831, 0 };
            const std::uint32_t dim582JoeKuoD6Init[]   =   { 1, 3, 7, 11, 23, 51, 13, 9, 49, 449, 997, 3073, 4407, 0 };
            const std::uint32_t dim583JoeKuoD6Init[]   =   { 1, 3, 5, 7, 23, 33, 89, 41, 415, 53, 697, 1113, 1489, 0 };
            const std::uint32_t dim584JoeKuoD6Init[]   =   { 1, 1, 3, 7, 1, 13, 29, 13, 255, 749, 77, 3463, 1761, 0 };
            const std::uint32_t dim585JoeKuoD6Init[]   =   { 1, 3, 3, 7, 13, 15, 93, 191, 309, 869, 739, 1041, 3053, 0 };
            const std::uint32_t dim586JoeKuoD6Init[]   =   { 1, 3, 5, 13, 5, 19, 109, 211, 347, 839, 893, 2947, 7735, 0 };
            const std::uint32_t dim587JoeKuoD6Init[]   =   { 1, 3, 1, 13, 27, 3, 119, 157, 485, 99, 1703, 3895, 573, 0 };
            const std::uint32_t dim588JoeKuoD6Init[]   =   { 1, 3, 7, 11, 1, 23, 123, 105, 31, 359, 275, 1775, 3685, 0 };
            const std::uint32_t dim589JoeKuoD6Init[]   =   { 1, 3, 3, 5, 27, 11, 125, 3, 413, 199, 2043, 2895, 2945, 0 };
            const std::uint32_t dim590JoeKuoD6Init[]   =   { 1, 3, 3, 3, 15, 49, 121, 159, 233, 543, 193, 4007, 321, 0 };
            const std::uint32_t dim591JoeKuoD6Init[]   =   { 1, 1, 3, 5, 9, 47, 87, 1, 51, 1011, 1595, 2239, 6467, 0 };
            const std::uint32_t dim592JoeKuoD6Init[]   =   { 1, 3, 7, 9, 1, 33, 87, 137, 469, 749, 1413, 805, 6817, 0 };
            const std::uint32_t dim593JoeKuoD6Init[]   =   { 1, 3, 1, 13, 19, 45, 95, 227, 29, 677, 1275, 3395, 4451, 0 };
            const std::uint32_t dim594JoeKuoD6Init[]   =   { 1, 1, 7, 5, 7, 63, 33, 71, 443, 561, 1311, 3069, 6943, 0 };
            const std::uint32_t dim595JoeKuoD6Init[]   =   { 1, 1, 1, 13, 9, 37, 23, 69, 13, 415, 1479, 1197, 861, 0 };
            const std::uint32_t dim596JoeKuoD6Init[]   =   { 1, 3, 3, 13, 27, 21, 13, 233, 105, 777, 345, 2443, 1105, 0 };
            const std::uint32_t dim597JoeKuoD6Init[]   =   { 1, 1, 7, 11, 23, 13, 21, 147, 221, 549, 73, 2729, 6279, 0 };
            const std::uint32_t dim598JoeKuoD6Init[]   =   { 1, 1, 7, 7, 25, 27, 15, 45, 227, 39, 75, 1191, 3563, 0 };
            const std::uint32_t dim599JoeKuoD6Init[]   =   { 1, 1, 5, 7, 13, 49, 99, 167, 227, 13, 353, 1047, 8075, 0 };
            const std::uint32_t dim600JoeKuoD6Init[]   =   { 1, 1, 3, 13, 31, 9, 27, 7, 461, 737, 1559, 3243, 53, 0 };
            const std::uint32_t dim601JoeKuoD6Init[]   =   { 1, 3, 1, 1, 21, 41, 97, 165, 171, 821, 587, 2137, 2293, 0 };
            const std::uint32_t dim602JoeKuoD6Init[]   =   { 1, 3, 1, 11, 17, 41, 29, 187, 87, 599, 1467, 1395, 5931, 0 };
            const std::uint32_t dim603JoeKuoD6Init[]   =   { 1, 1, 1, 9, 9, 49, 89, 205, 409, 453, 61, 1923, 1257, 0 };
            const std::uint32_t dim604JoeKuoD6Init[]   =   { 1, 3, 7, 3, 9, 43, 89, 143, 431, 83, 1243, 1795, 3599, 0 };
            const std::uint32_t dim605JoeKuoD6Init[]   =   { 1, 3, 5, 13, 3, 25, 59, 219, 43, 223, 797, 2651, 6015, 0 };
            const std::uint32_t dim606JoeKuoD6Init[]   =   { 1, 1, 5, 15, 7, 55, 65, 207, 213, 311, 1287, 1269, 6467, 0 };
            const std::uint32_t dim607JoeKuoD6Init[]   =   { 1, 3, 7, 11, 21, 57, 31, 183, 351, 857, 911, 1683, 7155, 0 };
            const std::uint32_t dim608JoeKuoD6Init[]   =   { 1, 3, 5, 11, 27, 1, 21, 47, 387, 383, 1593, 115, 3805, 0 };
            const std::uint32_t dim609JoeKuoD6Init[]   =   { 1, 3, 1, 1, 13, 23, 87, 173, 181, 619, 1653, 3931, 6073, 0 };
            const std::uint32_t dim610JoeKuoD6Init[]   =   { 1, 1, 7, 5, 17, 43, 37, 61, 307, 621, 1785, 55, 115, 0 };
            const std::uint32_t dim611JoeKuoD6Init[]   =   { 1, 3, 7, 15, 25, 61, 123, 15, 237, 671, 1473, 467, 1907, 0 };
            const std::uint32_t dim612JoeKuoD6Init[]   =   { 1, 1, 7, 5, 29, 57, 75, 237, 85, 699, 159, 3577, 4771, 0 };
            const std::uint32_t dim613JoeKuoD6Init[]   =   { 1, 1, 1, 11, 25, 19, 51, 1, 147, 31, 895, 2617, 625, 0 };
            const std::uint32_t dim614JoeKuoD6Init[]   =   { 1, 3, 7, 5, 29, 15, 115, 175, 395, 391, 1141, 1827, 1181, 0 };
            const std::uint32_t dim615JoeKuoD6Init[]   =   { 1, 3, 5, 7, 17, 7, 11, 193, 89, 243, 561, 3787, 4551, 0 };
            const std::uint32_t dim616JoeKuoD6Init[]   =   { 1, 3, 1, 11, 7, 57, 7, 125, 403, 947, 1261, 409, 8083, 0 };
            const std::uint32_t dim617JoeKuoD6Init[]   =   { 1, 1, 5, 13, 21, 63, 115, 233, 231, 921, 1747, 3635, 2519, 0 };
            const std::uint32_t dim618JoeKuoD6Init[]   =   { 1, 1, 5, 11, 3, 27, 15, 91, 505, 591, 1451, 3881, 2997, 0 };
            const std::uint32_t dim619JoeKuoD6Init[]   =   { 1, 1, 3, 11, 21, 9, 109, 153, 317, 533, 593, 3967, 2797, 0 };
            const std::uint32_t dim620JoeKuoD6Init[]   =   { 1, 3, 3, 13, 9, 57, 121, 245, 219, 867, 967, 791, 7095, 0 };
            const std::uint32_t dim621JoeKuoD6Init[]   =   { 1, 1, 1, 9, 29, 21, 99, 35, 375, 959, 329, 4087, 7171, 0 };
            const std::uint32_t dim622JoeKuoD6Init[]   =   { 1, 1, 1, 9, 11, 17, 17, 97, 89, 135, 631, 3809, 3253, 0 };
            const std::uint32_t dim623JoeKuoD6Init[]   =   { 1, 1, 1, 15, 21, 51, 91, 249, 459, 801, 757, 2353, 2033, 0 };
            const std::uint32_t dim624JoeKuoD6Init[]   =   { 1, 3, 5, 9, 23, 29, 77, 53, 399, 767, 1817, 2171, 1629, 0 };
            const std::uint32_t dim625JoeKuoD6Init[]   =   { 1, 1, 3, 5, 29, 5, 43, 121, 17, 859, 1479, 3785, 6641, 0 };
            const std::uint32_t dim626JoeKuoD6Init[]   =   { 1, 1, 3, 7, 7, 61, 45, 109, 371, 833, 91, 153, 4553, 0 };
            const std::uint32_t dim627JoeKuoD6Init[]   =   { 1, 1, 3, 11, 7, 55, 81, 123, 389, 139, 1933, 891, 1789, 0 };
            const std::uint32_t dim628JoeKuoD6Init[]   =   { 1, 3, 7, 15, 25, 17, 93, 165, 503, 717, 1553, 1475, 1627, 0 };
            const std::uint32_t dim629JoeKuoD6Init[]   =   { 1, 1, 1, 13, 13, 63, 13, 225, 357, 571, 33, 4073, 3795, 0 };
            const std::uint32_t dim630JoeKuoD6Init[]   =   { 1, 1, 3, 11, 1, 31, 107, 145, 407, 961, 501, 2987, 103, 0 };
            const std::uint32_t dim631JoeKuoD6Init[]   =   { 1, 1, 7, 1, 23, 63, 49, 193, 173, 281, 25, 2465, 5927, 0 };
            const std::uint32_t dim632JoeKuoD6Init[]   =   { 1, 1, 7, 1, 1, 1, 85, 77, 273, 693, 349, 1239, 4503, 0 };
            const std::uint32_t dim633JoeKuoD6Init[]   =   { 1, 1, 5, 11, 7, 61, 9, 121, 25, 357, 1443, 405, 7827, 0 };
            const std::uint32_t dim634JoeKuoD6Init[]   =   { 1, 1, 7, 13, 11, 53, 11, 207, 145, 211, 1703, 1081, 2117, 0 };
            const std::uint32_t dim635JoeKuoD6Init[]   =   { 1, 1, 3, 11, 27, 23, 19, 9, 297, 279, 1481, 2273, 6387, 0 };
            const std::uint32_t dim636JoeKuoD6Init[]   =   { 1, 3, 3, 5, 15, 45, 3, 41, 305, 87, 1815, 3461, 5349, 0 };
            const std::uint32_t dim637JoeKuoD6Init[]   =   { 1, 3, 3, 13, 9, 37, 79, 125, 259, 561, 1087, 4091, 793, 0 };
            const std::uint32_t dim638JoeKuoD6Init[]   =   { 1, 3, 5, 7, 31, 55, 7, 145, 347, 929, 589, 2783, 5905, 0 };
            const std::uint32_t dim639JoeKuoD6Init[]   =   { 1, 1, 7, 15, 3, 25, 1, 181, 13, 243, 653, 2235, 7445, 0 };
            const std::uint32_t dim640JoeKuoD6Init[]   =   { 1, 3, 5, 5, 17, 53, 65, 7, 33, 583, 1363, 1313, 2319, 0 };
            const std::uint32_t dim641JoeKuoD6Init[]   =   { 1, 3, 3, 7, 27, 47, 97, 201, 187, 321, 63, 1515, 7917, 0 };
            const std::uint32_t dim642JoeKuoD6Init[]   =   { 1, 1, 3, 5, 23, 9, 3, 165, 61, 19, 1789, 3783, 3037, 0 };
            const std::uint32_t dim643JoeKuoD6Init[]   =   { 1, 3, 1, 13, 15, 43, 125, 191, 67, 273, 1551, 2227, 5253, 0 };
            const std::uint32_t dim644JoeKuoD6Init[]   =   { 1, 1, 1, 13, 25, 53, 107, 33, 299, 249, 1475, 2233, 907, 0 };
            const std::uint32_t dim645JoeKuoD6Init[]   =   { 1, 3, 5, 1, 23, 37, 85, 17, 207, 643, 665, 2933, 5199, 0 };
            const std::uint32_t dim646JoeKuoD6Init[]   =   { 1, 1, 7, 7, 25, 57, 59, 41, 15, 751, 751, 1749, 7053, 0 };
            const std::uint32_t dim647JoeKuoD6Init[]   =   { 1, 3, 3, 1, 13, 25, 127, 93, 281, 613, 875, 2223, 6345, 0 };
            const std::uint32_t dim648JoeKuoD6Init[]   =   { 1, 1, 5, 3, 29, 55, 79, 249, 43, 317, 533, 995, 1991, 0 };
            const std::uint32_t dim649JoeKuoD6Init[]   =   { 1, 3, 3, 15, 17, 49, 79, 31, 193, 233, 1437, 2615, 819, 0 };
            const std::uint32_t dim650JoeKuoD6Init[]   =   { 1, 1, 5, 15, 25, 3, 123, 145, 377, 9, 455, 1191, 3953, 0 };
            const std::uint32_t dim651JoeKuoD6Init[]   =   { 1, 3, 5, 3, 15, 19, 41, 231, 81, 393, 3, 19, 2409, 0 };
            const std::uint32_t dim652JoeKuoD6Init[]   =   { 1, 1, 3, 1, 27, 43, 113, 179, 7, 853, 947, 2731, 297, 0 };
            const std::uint32_t dim653JoeKuoD6Init[]   =   { 1, 1, 1, 11, 29, 39, 53, 191, 443, 689, 529, 3329, 7431, 0 };
            const std::uint32_t dim654JoeKuoD6Init[]   =   { 1, 3, 7, 5, 3, 29, 19, 67, 441, 113, 949, 2769, 4169, 0 };
            const std::uint32_t dim655JoeKuoD6Init[]   =   { 1, 3, 5, 11, 11, 55, 85, 169, 215, 815, 803, 2345, 3967, 0 };
            const std::uint32_t dim656JoeKuoD6Init[]   =   { 1, 1, 7, 9, 5, 45, 111, 5, 419, 375, 303, 1725, 4489, 0 };
            const std::uint32_t dim657JoeKuoD6Init[]   =   { 1, 3, 5, 15, 29, 43, 79, 19, 23, 417, 381, 541, 4923, 0 };
            const std::uint32_t dim658JoeKuoD6Init[]   =   { 1, 1, 3, 15, 3, 31, 117, 39, 117, 305, 1227, 1223, 143, 0 };
            const std::uint32_t dim659JoeKuoD6Init[]   =   { 1, 1, 5, 9, 5, 47, 87, 239, 181, 353, 1561, 3313, 1921, 0 };
            const std::uint32_t dim660JoeKuoD6Init[]   =   { 1, 3, 3, 1, 3, 15, 53, 221, 441, 987, 1997, 2529, 8059, 0 };
            const std::uint32_t dim661JoeKuoD6Init[]   =   { 1, 1, 7, 11, 15, 57, 111, 139, 137, 883, 1881, 2823, 5661, 0 };
            const std::uint32_t dim662JoeKuoD6Init[]   =   { 1, 3, 5, 5, 21, 11, 5, 13, 27, 973, 587, 1331, 1373, 0 };
            const std::uint32_t dim663JoeKuoD6Init[]   =   { 1, 1, 7, 11, 29, 51, 93, 29, 217, 221, 55, 2477, 1979, 0 };
            const std::uint32_t dim664JoeKuoD6Init[]   =   { 1, 3, 3, 13, 3, 11, 49, 75, 379, 371, 1441, 793, 7633, 0 };
            const std::uint32_t dim665JoeKuoD6Init[]   =   { 1, 1, 1, 13, 19, 45, 89, 249, 91, 649, 1695, 915, 5619, 0 };
            const std::uint32_t dim666JoeKuoD6Init[]   =   { 1, 3, 1, 7, 7, 29, 1, 77, 313, 895, 519, 771, 295, 0 };
            const std::uint32_t dim667JoeKuoD6Init[]   =   { 1, 3, 1, 15, 5, 3, 1, 57, 331, 109, 485, 2853, 6831, 0 };
            const std::uint32_t dim668JoeKuoD6Init[]   =   { 1, 1, 1, 15, 17, 3, 35, 99, 245, 971, 839, 2509, 2803, 0 };
            const std::uint32_t dim669JoeKuoD6Init[]   =   { 1, 3, 3, 3, 9, 37, 57, 251, 325, 317, 529, 1313, 6379, 0 };
            const std::uint32_t dim670JoeKuoD6Init[]   =   { 1, 1, 1, 15, 25, 59, 1, 119, 95, 15, 795, 2375, 6463, 0 };
            const std::uint32_t dim671JoeKuoD6Init[]   =   { 1, 3, 1, 5, 1, 49, 117, 21, 47, 179, 863, 85, 1669, 0 };
            const std::uint32_t dim672JoeKuoD6Init[]   =   { 1, 3, 7, 3, 9, 37, 19, 221, 455, 973, 571, 1427, 817, 0 };
            const std::uint32_t dim673JoeKuoD6Init[]   =   { 1, 1, 1, 15, 17, 9, 67, 213, 127, 887, 1299, 2913, 7451, 0 };
            const std::uint32_t dim674JoeKuoD6Init[]   =   { 1, 3, 1, 13, 27, 27, 41, 43, 171, 623, 691, 391, 4885, 0 };
            const std::uint32_t dim675JoeKuoD6Init[]   =   { 1, 3, 1, 13, 17, 17, 123, 239, 143, 227, 1151, 519, 6543, 0 };
            const std::uint32_t dim676JoeKuoD6Init[]   =   { 1, 3, 7, 5, 7, 63, 97, 39, 101, 555, 1057, 381, 7891, 0 };
            const std::uint32_t dim677JoeKuoD6Init[]   =   { 1, 3, 5, 1, 3, 27, 85, 129, 161, 875, 1945, 3541, 695, 0 };
            const std::uint32_t dim678JoeKuoD6Init[]   =   { 1, 3, 3, 5, 21, 59, 25, 183, 35, 25, 987, 1459, 181, 0 };
            const std::uint32_t dim679JoeKuoD6Init[]   =   { 1, 3, 5, 13, 1, 15, 127, 237, 349, 337, 1491, 2383, 7811, 0 };
            const std::uint32_t dim680JoeKuoD6Init[]   =   { 1, 3, 5, 5, 31, 5, 109, 51, 409, 733, 1395, 3207, 6049, 0 };
            const std::uint32_t dim681JoeKuoD6Init[]   =   { 1, 1, 5, 7, 13, 35, 113, 25, 263, 389, 299, 2521, 1783, 0 };
            const std::uint32_t dim682JoeKuoD6Init[]   =   { 1, 3, 7, 11, 15, 47, 97, 73, 55, 75, 113, 2695, 1023, 0 };
            const std::uint32_t dim683JoeKuoD6Init[]   =   { 1, 3, 1, 1, 3, 13, 69, 211, 289, 483, 1335, 787, 677, 0 };
            const std::uint32_t dim684JoeKuoD6Init[]   =   { 1, 1, 3, 3, 17, 7, 37, 77, 505, 137, 1113, 345, 2975, 0 };
            const std::uint32_t dim685JoeKuoD6Init[]   =   { 1, 1, 1, 13, 3, 11, 95, 199, 453, 109, 479, 3725, 239, 0 };
            const std::uint32_t dim686JoeKuoD6Init[]   =   { 1, 1, 7, 15, 19, 53, 3, 145, 359, 863, 347, 3833, 3043, 0 };
            const std::uint32_t dim687JoeKuoD6Init[]   =   { 1, 1, 7, 15, 25, 63, 127, 129, 125, 195, 155, 2211, 8153, 0 };
            const std::uint32_t dim688JoeKuoD6Init[]   =   { 1, 1, 7, 13, 9, 49, 121, 115, 73, 119, 1851, 727, 47, 0 };
            const std::uint32_t dim689JoeKuoD6Init[]   =   { 1, 3, 3, 13, 13, 11, 71, 7, 45, 591, 133, 2407, 5563, 0 };
            const std::uint32_t dim690JoeKuoD6Init[]   =   { 1, 1, 1, 13, 23, 29, 87, 89, 501, 71, 1759, 1119, 687, 0 };
            const std::uint32_t dim691JoeKuoD6Init[]   =   { 1, 1, 7, 7, 13, 7, 13, 183, 53, 951, 1877, 3991, 6771, 0 };
            const std::uint32_t dim692JoeKuoD6Init[]   =   { 1, 3, 7, 11, 7, 1, 27, 47, 61, 21, 919, 961, 1091, 0 };
            const std::uint32_t dim693JoeKuoD6Init[]   =   { 1, 3, 5, 5, 1, 27, 1, 5, 63, 157, 1297, 1049, 5893, 0 };
            const std::uint32_t dim694JoeKuoD6Init[]   =   { 1, 3, 7, 9, 19, 33, 17, 133, 425, 797, 1721, 153, 119, 0 };
            const std::uint32_t dim695JoeKuoD6Init[]   =   { 1, 3, 3, 7, 13, 37, 1, 215, 509, 1003, 61, 2353, 7511, 0 };
            const std::uint32_t dim696JoeKuoD6Init[]   =   { 1, 1, 7, 1, 29, 19, 31, 79, 199, 555, 1209, 1603, 6089, 0 };
            const std::uint32_t dim697JoeKuoD6Init[]   =   { 1, 3, 1, 1, 5, 31, 111, 127, 333, 429, 1863, 3925, 5411, 0 };
            const std::uint32_t dim698JoeKuoD6Init[]   =   { 1, 1, 7, 5, 5, 5, 123, 191, 47, 993, 269, 4051, 2111, 0 };
            const std::uint32_t dim699JoeKuoD6Init[]   =   { 1, 1, 5, 15, 1, 9, 87, 5, 47, 463, 865, 1813, 7357, 0 };
            const std::uint32_t dim700JoeKuoD6Init[]   =   { 1, 3, 1, 3, 23, 63, 123, 83, 511, 777, 63, 1285, 4537, 0 };
            const std::uint32_t dim701JoeKuoD6Init[]   =   { 1, 3, 3, 7, 27, 25, 31, 65, 441, 529, 1815, 1893, 323, 0 };
            const std::uint32_t dim702JoeKuoD6Init[]   =   { 1, 3, 7, 5, 11, 19, 7, 5, 397, 811, 755, 2883, 4217, 0 };
            const std::uint32_t dim703JoeKuoD6Init[]   =   { 1, 3, 1, 13, 9, 21, 13, 7, 271, 539, 1769, 3243, 5325, 0 };
            const std::uint32_t dim704JoeKuoD6Init[]   =   { 1, 1, 7, 1, 31, 13, 47, 131, 181, 457, 1559, 2663, 6653, 0 };
            const std::uint32_t dim705JoeKuoD6Init[]   =   { 1, 3, 3, 7, 29, 55, 25, 203, 419, 91, 437, 1159, 5691, 0 };
            const std::uint32_t dim706JoeKuoD6Init[]   =   { 1, 1, 3, 13, 29, 19, 71, 217, 337, 329, 501, 939, 2205, 0 };
            const std::uint32_t dim707JoeKuoD6Init[]   =   { 1, 1, 3, 1, 1, 27, 17, 201, 97, 285, 1269, 4043, 2207, 0 };
            const std::uint32_t dim708JoeKuoD6Init[]   =   { 1, 1, 1, 1, 3, 41, 13, 199, 141, 129, 1515, 3129, 5969, 0 };
            const std::uint32_t dim709JoeKuoD6Init[]   =   { 1, 3, 3, 9, 3, 17, 119, 41, 271, 933, 877, 701, 2197, 0 };
            const std::uint32_t dim710JoeKuoD6Init[]   =   { 1, 1, 1, 7, 15, 47, 3, 195, 115, 821, 725, 843, 6071, 0 };
            const std::uint32_t dim711JoeKuoD6Init[]   =   { 1, 3, 5, 15, 17, 33, 85, 65, 297, 571, 1123, 2743, 5727, 0 };
            const std::uint32_t dim712JoeKuoD6Init[]   =   { 1, 1, 5, 11, 27, 15, 37, 235, 415, 293, 1439, 2739, 4171, 0 };
            const std::uint32_t dim713JoeKuoD6Init[]   =   { 1, 3, 7, 7, 1, 55, 71, 35, 307, 11, 401, 1881, 933, 0 };
            const std::uint32_t dim714JoeKuoD6Init[]   =   { 1, 3, 1, 11, 21, 37, 3, 177, 119, 339, 559, 3991, 3437, 0 };
            const std::uint32_t dim715JoeKuoD6Init[]   =   { 1, 3, 3, 9, 17, 17, 97, 119, 301, 169, 157, 3267, 2261, 0 };
            const std::uint32_t dim716JoeKuoD6Init[]   =   { 1, 3, 3, 9, 29, 3, 111, 101, 355, 869, 375, 2609, 7377, 0 };
            const std::uint32_t dim717JoeKuoD6Init[]   =   { 1, 3, 5, 9, 7, 21, 123, 99, 343, 693, 1927, 1605, 4923, 0 };
            const std::uint32_t dim718JoeKuoD6Init[]   =   { 1, 1, 3, 5, 13, 31, 99, 17, 75, 385, 1539, 1553, 7077, 0 };
            const std::uint32_t dim719JoeKuoD6Init[]   =   { 1, 3, 3, 5, 31, 35, 107, 11, 407, 1019, 1317, 3593, 7203, 0 };
            const std::uint32_t dim720JoeKuoD6Init[]   =   { 1, 3, 3, 13, 17, 33, 99, 245, 401, 957, 157, 1949, 1571, 0 };
            const std::uint32_t dim721JoeKuoD6Init[]   =   { 1, 3, 1, 11, 27, 15, 11, 109, 429, 307, 1911, 2701, 861, 0 };
            const std::uint32_t dim722JoeKuoD6Init[]   =   { 1, 1, 5, 13, 13, 35, 55, 255, 311, 957, 1803, 2673, 5195, 0 };
            const std::uint32_t dim723JoeKuoD6Init[]   =   { 1, 1, 1, 11, 19, 3, 89, 37, 211, 783, 1355, 3567, 7135, 0 };
            const std::uint32_t dim724JoeKuoD6Init[]   =   { 1, 1, 5, 5, 21, 49, 79, 17, 509, 331, 183, 3831, 855, 0 };
            const std::uint32_t dim725JoeKuoD6Init[]   =   { 1, 3, 7, 5, 29, 19, 85, 109, 105, 523, 845, 3385, 7477, 0 };
            const std::uint32_t dim726JoeKuoD6Init[]   =   { 1, 1, 1, 7, 25, 17, 125, 131, 53, 757, 253, 2989, 2939, 0 };
            const std::uint32_t dim727JoeKuoD6Init[]   =   { 1, 3, 3, 9, 19, 23, 105, 39, 351, 677, 211, 401, 8103, 0 };
            const std::uint32_t dim728JoeKuoD6Init[]   =   { 1, 3, 5, 1, 5, 11, 17, 3, 405, 469, 1569, 2865, 3133, 0 };
            const std::uint32_t dim729JoeKuoD6Init[]   =   { 1, 1, 3, 13, 15, 5, 117, 179, 139, 145, 477, 1137, 2537, 0 };
            const std::uint32_t dim730JoeKuoD6Init[]   =   { 1, 1, 7, 9, 5, 21, 9, 93, 211, 963, 1207, 3343, 4911, 0 };
            const std::uint32_t dim731JoeKuoD6Init[]   =   { 1, 1, 1, 9, 13, 43, 17, 53, 81, 793, 1571, 2523, 3683, 0 };
            const std::uint32_t dim732JoeKuoD6Init[]   =   { 1, 3, 3, 13, 25, 21, 5, 59, 489, 987, 1941, 171, 6009, 0 };
            const std::uint32_t dim733JoeKuoD6Init[]   =   { 1, 3, 3, 7, 1, 39, 89, 171, 403, 467, 1767, 3423, 2791, 0 };
            const std::uint32_t dim734JoeKuoD6Init[]   =   { 1, 1, 3, 9, 19, 49, 91, 125, 163, 1013, 89, 2849, 6785, 0 };
            const std::uint32_t dim735JoeKuoD6Init[]   =   { 1, 1, 5, 9, 9, 11, 15, 241, 43, 297, 1719, 1541, 1821, 0 };
            const std::uint32_t dim736JoeKuoD6Init[]   =   { 1, 3, 7, 15, 29, 23, 103, 239, 191, 33, 1043, 3649, 6579, 0 };
            const std::uint32_t dim737JoeKuoD6Init[]   =   { 1, 3, 3, 9, 21, 51, 123, 55, 223, 645, 1463, 4021, 5891, 0 };
            const std::uint32_t dim738JoeKuoD6Init[]   =   { 1, 1, 5, 7, 3, 41, 27, 235, 391, 303, 2021, 3187, 7607, 0 };
            const std::uint32_t dim739JoeKuoD6Init[]   =   { 1, 1, 1, 9, 5, 49, 49, 29, 377, 251, 1887, 1017, 1301, 0 };
            const std::uint32_t dim740JoeKuoD6Init[]   =   { 1, 1, 3, 3, 13, 41, 27, 47, 223, 23, 517, 3227, 6731, 0 };
            const std::uint32_t dim741JoeKuoD6Init[]   =   { 1, 1, 7, 1, 31, 25, 47, 9, 511, 623, 2047, 1263, 1511, 0 };
            const std::uint32_t dim742JoeKuoD6Init[]   =   { 1, 1, 3, 15, 15, 23, 53, 1, 261, 595, 85, 241, 7047, 0 };
            const std::uint32_t dim743JoeKuoD6Init[]   =   { 1, 3, 3, 11, 17, 5, 81, 73, 149, 781, 2035, 3163, 4247, 0 };
            const std::uint32_t dim744JoeKuoD6Init[]   =   { 1, 3, 7, 7, 29, 59, 49, 79, 397, 901, 1105, 2191, 6277, 0 };
            const std::uint32_t dim745JoeKuoD6Init[]   =   { 1, 3, 3, 11, 13, 27, 25, 173, 107, 73, 1265, 585, 5251, 0 };
            const std::uint32_t dim746JoeKuoD6Init[]   =   { 1, 1, 7, 15, 29, 23, 73, 229, 235, 887, 1469, 4073, 2591, 0 };
            const std::uint32_t dim747JoeKuoD6Init[]   =   { 1, 1, 3, 9, 17, 15, 83, 173, 207, 879, 1701, 1509, 11, 0 };
            const std::uint32_t dim748JoeKuoD6Init[]   =   { 1, 1, 3, 5, 5, 37, 65, 161, 39, 421, 1153, 2007, 5355, 0 };
            const std::uint32_t dim749JoeKuoD6Init[]   =   { 1, 1, 7, 11, 23, 37, 5, 11, 9, 499, 17, 157, 5747, 0 };
            const std::uint32_t dim750JoeKuoD6Init[]   =   { 1, 3, 7, 13, 25, 9, 49, 7, 39, 945, 1349, 1759, 1441, 0 };
            const std::uint32_t dim751JoeKuoD6Init[]   =   { 1, 1, 5, 3, 21, 15, 113, 81, 265, 837, 333, 3625, 6133, 0 };
            const std::uint32_t dim752JoeKuoD6Init[]   =   { 1, 3, 1, 11, 13, 27, 73, 109, 297, 327, 299, 3253, 6957, 0 };
            const std::uint32_t dim753JoeKuoD6Init[]   =   { 1, 1, 3, 13, 19, 39, 123, 73, 65, 5, 1061, 2187, 5055, 0 };
            const std::uint32_t dim754JoeKuoD6Init[]   =   { 1, 1, 3, 1, 11, 31, 21, 115, 453, 857, 711, 495, 549, 0 };
            const std::uint32_t dim755JoeKuoD6Init[]   =   { 1, 3, 7, 7, 15, 29, 79, 103, 47, 713, 1735, 3121, 6321, 0 };
            const std::uint32_t dim756JoeKuoD6Init[]   =   { 1, 1, 5, 5, 29, 9, 97, 33, 471, 705, 329, 1501, 1349, 0 };
            const std::uint32_t dim757JoeKuoD6Init[]   =   { 1, 3, 3, 1, 21, 9, 111, 209, 71, 47, 491, 2143, 1797, 0 };
            const std::uint32_t dim758JoeKuoD6Init[]   =   { 1, 3, 3, 3, 11, 39, 21, 135, 445, 259, 607, 3811, 5449, 0 };
            const std::uint32_t dim759JoeKuoD6Init[]   =   { 1, 1, 7, 9, 11, 25, 113, 251, 395, 317, 317, 91, 1979, 0 };
            const std::uint32_t dim760JoeKuoD6Init[]   =   { 1, 3, 1, 9, 3, 21, 103, 133, 389, 943, 1235, 1749, 7063, 0 };
            const std::uint32_t dim761JoeKuoD6Init[]   =   { 1, 1, 3, 7, 1, 11, 5, 15, 497, 477, 479, 3079, 6969, 0 };
            const std::uint32_t dim762JoeKuoD6Init[]   =   { 1, 1, 3, 3, 15, 39, 105, 131, 475, 465, 181, 865, 3813, 0 };
            const std::uint32_t dim763JoeKuoD6Init[]   =   { 1, 1, 7, 9, 19, 63, 123, 131, 415, 525, 457, 2471, 3135, 0 };
            const std::uint32_t dim764JoeKuoD6Init[]   =   { 1, 3, 7, 15, 25, 35, 123, 45, 341, 805, 485, 4049, 7065, 0 };
            const std::uint32_t dim765JoeKuoD6Init[]   =   { 1, 1, 1, 5, 29, 9, 47, 227, 51, 867, 1873, 1593, 2271, 0 };
            const std::uint32_t dim766JoeKuoD6Init[]   =   { 1, 1, 7, 15, 31, 9, 71, 117, 285, 711, 837, 1435, 6275, 0 };
            const std::uint32_t dim767JoeKuoD6Init[]   =   { 1, 3, 1, 1, 5, 19, 79, 25, 301, 415, 1871, 645, 3251, 0 };
            const std::uint32_t dim768JoeKuoD6Init[]   =   { 1, 3, 1, 3, 17, 51, 99, 185, 447, 43, 523, 219, 429, 0 };
            const std::uint32_t dim769JoeKuoD6Init[]   =   { 1, 3, 1, 13, 29, 13, 51, 93, 7, 995, 757, 3017, 6865, 0 };
            const std::uint32_t dim770JoeKuoD6Init[]   =   { 1, 1, 3, 15, 7, 25, 75, 17, 155, 981, 1231, 1229, 1995, 0 };
            const std::uint32_t dim771JoeKuoD6Init[]   =   { 1, 3, 5, 3, 27, 45, 71, 73, 225, 763, 377, 1139, 2863, 0 };
            const std::uint32_t dim772JoeKuoD6Init[]   =   { 1, 1, 3, 1, 1, 39, 69, 113, 29, 371, 1051, 793, 3749, 0 };
            const std::uint32_t dim773JoeKuoD6Init[]   =   { 1, 1, 3, 13, 23, 61, 27, 183, 307, 431, 1345, 2757, 4031, 0 };
            const std::uint32_t dim774JoeKuoD6Init[]   =   { 1, 3, 7, 5, 5, 59, 117, 197, 303, 721, 877, 723, 1601, 0 };
            const std::uint32_t dim775JoeKuoD6Init[]   =   { 1, 3, 5, 1, 27, 33, 99, 237, 485, 711, 665, 3077, 5105, 0 };
            const std::uint32_t dim776JoeKuoD6Init[]   =   { 1, 1, 3, 1, 13, 9, 103, 201, 23, 951, 2029, 165, 2093, 0 };
            const std::uint32_t dim777JoeKuoD6Init[]   =   { 1, 3, 5, 13, 5, 29, 55, 85, 221, 677, 611, 3613, 4567, 0 };
            const std::uint32_t dim778JoeKuoD6Init[]   =   { 1, 1, 1, 1, 7, 61, 9, 233, 261, 561, 953, 4023, 2443, 0 };
            const std::uint32_t dim779JoeKuoD6Init[]   =   { 1, 3, 3, 13, 1, 17, 103, 71, 223, 213, 833, 1747, 6999, 0 };
            const std::uint32_t dim780JoeKuoD6Init[]   =   { 1, 3, 5, 15, 25, 53, 57, 187, 25, 695, 1207, 4089, 2877, 0 };
            const std::uint32_t dim781JoeKuoD6Init[]   =   { 1, 1, 7, 1, 7, 31, 87, 129, 493, 519, 1555, 1155, 4637, 0 };
            const std::uint32_t dim782JoeKuoD6Init[]   =   { 1, 1, 1, 15, 21, 17, 23, 29, 19, 255, 927, 1791, 3093, 0 };
            const std::uint32_t dim783JoeKuoD6Init[]   =   { 1, 1, 3, 9, 17, 33, 95, 129, 175, 461, 287, 2633, 2325, 0 };
            const std::uint32_t dim784JoeKuoD6Init[]   =   { 1, 3, 5, 7, 23, 19, 63, 209, 249, 583, 1373, 2039, 2225, 0 };
            const std::uint32_t dim785JoeKuoD6Init[]   =   { 1, 3, 3, 5, 5, 19, 79, 241, 459, 355, 1455, 3313, 3639, 0 };
            const std::uint32_t dim786JoeKuoD6Init[]   =   { 1, 1, 7, 9, 21, 41, 97, 119, 129, 769, 1541, 3495, 7741, 0 };
            const std::uint32_t dim787JoeKuoD6Init[]   =   { 1, 1, 7, 11, 9, 29, 35, 255, 141, 937, 1763, 41, 1393, 0 };
            const std::uint32_t dim788JoeKuoD6Init[]   =   { 1, 3, 7, 1, 13, 51, 61, 157, 177, 847, 1829, 3539, 285, 0 };
            const std::uint32_t dim789JoeKuoD6Init[]   =   { 1, 1, 1, 15, 21, 13, 9, 55, 397, 19, 1495, 1255, 7235, 0 };
            const std::uint32_t dim790JoeKuoD6Init[]   =   { 1, 1, 7, 7, 25, 37, 53, 237, 319, 197, 269, 1205, 1485, 0 };
            const std::uint32_t dim791JoeKuoD6Init[]   =   { 1, 1, 5, 15, 23, 17, 35, 247, 323, 807, 233, 3681, 4407, 0 };
            const std::uint32_t dim792JoeKuoD6Init[]   =   { 1, 1, 3, 7, 9, 59, 85, 105, 493, 763, 1639, 391, 1451, 0 };
            const std::uint32_t dim793JoeKuoD6Init[]   =   { 1, 3, 3, 9, 15, 33, 5, 253, 129, 625, 1527, 2793, 6057, 0 };
            const std::uint32_t dim794JoeKuoD6Init[]   =   { 1, 3, 1, 1, 7, 47, 21, 161, 235, 83, 397, 3563, 5953, 0 };
            const std::uint32_t dim795JoeKuoD6Init[]   =   { 1, 3, 7, 11, 3, 41, 25, 117, 375, 779, 1297, 3715, 8117, 0 };
            const std::uint32_t dim796JoeKuoD6Init[]   =   { 1, 1, 3, 7, 31, 19, 103, 173, 475, 189, 2035, 2921, 1107, 0 };
            const std::uint32_t dim797JoeKuoD6Init[]   =   { 1, 1, 7, 3, 25, 7, 93, 255, 307, 113, 1893, 2233, 6919, 0 };
            const std::uint32_t dim798JoeKuoD6Init[]   =   { 1, 3, 5, 15, 9, 57, 79, 143, 165, 5, 1389, 193, 693, 0 };
            const std::uint32_t dim799JoeKuoD6Init[]   =   { 1, 3, 5, 1, 29, 45, 91, 49, 189, 461, 439, 1283, 7835, 0 };
            const std::uint32_t dim800JoeKuoD6Init[]   =   { 1, 1, 3, 13, 11, 61, 41, 231, 373, 695, 395, 915, 5393, 0 };
            const std::uint32_t dim801JoeKuoD6Init[]   =   { 1, 3, 7, 11, 5, 51, 67, 53, 483, 95, 1943, 247, 5653, 0 };
            const std::uint32_t dim802JoeKuoD6Init[]   =   { 1, 3, 7, 5, 5, 57, 45, 235, 137, 793, 1069, 1661, 1557, 0 };
            const std::uint32_t dim803JoeKuoD6Init[]   =   { 1, 3, 5, 3, 25, 55, 103, 177, 81, 861, 1151, 143, 7655, 0 };
            const std::uint32_t dim804JoeKuoD6Init[]   =   { 1, 1, 3, 1, 21, 41, 67, 131, 253, 431, 1269, 3181, 3429, 0 };
            const std::uint32_t dim805JoeKuoD6Init[]   =   { 1, 3, 1, 1, 21, 7, 77, 221, 257, 663, 71, 2949, 2481, 0 };
            const std::uint32_t dim806JoeKuoD6Init[]   =   { 1, 3, 5, 3, 3, 23, 45, 107, 299, 739, 1013, 3, 3165, 0 };
            const std::uint32_t dim807JoeKuoD6Init[]   =   { 1, 1, 5, 1, 3, 37, 109, 37, 243, 983, 1221, 1691, 3869, 0 };
            const std::uint32_t dim808JoeKuoD6Init[]   =   { 1, 1, 5, 5, 31, 7, 5, 193, 397, 867, 1495, 3435, 7441, 0 };
            const std::uint32_t dim809JoeKuoD6Init[]   =   { 1, 1, 1, 1, 17, 59, 97, 233, 389, 597, 1013, 1631, 483, 0 };
            const std::uint32_t dim810JoeKuoD6Init[]   =   { 1, 1, 1, 11, 7, 41, 107, 53, 111, 125, 1513, 1921, 7647, 0 };
            const std::uint32_t dim811JoeKuoD6Init[]   =   { 1, 3, 3, 3, 31, 29, 117, 3, 365, 971, 1139, 2123, 5913, 0 };
            const std::uint32_t dim812JoeKuoD6Init[]   =   { 1, 1, 1, 13, 23, 3, 1, 167, 475, 639, 1811, 3841, 3081, 0 };
            const std::uint32_t dim813JoeKuoD6Init[]   =   { 1, 1, 5, 3, 5, 47, 65, 123, 275, 783, 95, 119, 7591, 0 };
            const std::uint32_t dim814JoeKuoD6Init[]   =   { 1, 3, 1, 15, 13, 33, 93, 237, 467, 431, 705, 4013, 4035, 0 };
            const std::uint32_t dim815JoeKuoD6Init[]   =   { 1, 3, 5, 1, 19, 7, 101, 231, 155, 737, 1381, 3343, 2051, 0 };
            const std::uint32_t dim816JoeKuoD6Init[]   =   { 1, 1, 5, 9, 15, 49, 45, 163, 433, 765, 2031, 201, 2589, 0 };
            const std::uint32_t dim817JoeKuoD6Init[]   =   { 1, 3, 7, 9, 19, 41, 31, 89, 93, 623, 105, 745, 4409, 0 };
            const std::uint32_t dim818JoeKuoD6Init[]   =   { 1, 1, 5, 1, 11, 45, 127, 85, 389, 439, 829, 477, 7965, 0 };
            const std::uint32_t dim819JoeKuoD6Init[]   =   { 1, 3, 3, 15, 13, 41, 1, 207, 435, 585, 311, 1725, 2737, 0 };
            const std::uint32_t dim820JoeKuoD6Init[]   =   { 1, 3, 3, 3, 13, 49, 21, 31, 197, 799, 1411, 2959, 7133, 0 };
            const std::uint32_t dim821JoeKuoD6Init[]   =   { 1, 3, 1, 3, 7, 43, 9, 141, 133, 579, 1059, 93, 957, 0 };
            const std::uint32_t dim822JoeKuoD6Init[]   =   { 1, 3, 7, 1, 15, 51, 23, 213, 381, 851, 699, 2261, 3419, 0 };
            const std::uint32_t dim823JoeKuoD6Init[]   =   { 1, 3, 5, 9, 25, 35, 67, 141, 35, 409, 1423, 365, 1645, 0 };
            const std::uint32_t dim824JoeKuoD6Init[]   =   { 1, 3, 3, 11, 15, 33, 27, 181, 93, 87, 1761, 3511, 1353, 0 };
            const std::uint32_t dim825JoeKuoD6Init[]   =   { 1, 3, 5, 3, 25, 63, 111, 137, 321, 819, 705, 1547, 7271, 0 };
            const std::uint32_t dim826JoeKuoD6Init[]   =   { 1, 3, 1, 1, 5, 57, 99, 59, 411, 757, 1371, 3953, 3695, 0 };
            const std::uint32_t dim827JoeKuoD6Init[]   =   { 1, 3, 5, 11, 11, 21, 25, 147, 239, 455, 709, 953, 7175, 0 };
            const std::uint32_t dim828JoeKuoD6Init[]   =   { 1, 3, 3, 15, 5, 53, 91, 205, 341, 63, 723, 1565, 7135, 0 };
            const std::uint32_t dim829JoeKuoD6Init[]   =   { 1, 1, 7, 15, 11, 21, 99, 79, 63, 593, 2007, 3629, 5271, 0 };
            const std::uint32_t dim830JoeKuoD6Init[]   =   { 1, 3, 3, 1, 9, 21, 45, 175, 453, 435, 1855, 2649, 6959, 0 };
            const std::uint32_t dim831JoeKuoD6Init[]   =   { 1, 1, 3, 15, 15, 33, 121, 121, 251, 431, 1127, 3305, 4199, 0 };
            const std::uint32_t dim832JoeKuoD6Init[]   =   { 1, 1, 1, 9, 31, 15, 71, 29, 345, 391, 1159, 2809, 345, 0 };
            const std::uint32_t dim833JoeKuoD6Init[]   =   { 1, 3, 7, 1, 23, 29, 95, 151, 327, 727, 647, 1623, 2971, 0 };
            const std::uint32_t dim834JoeKuoD6Init[]   =   { 1, 1, 7, 7, 9, 29, 79, 91, 127, 909, 1293, 1315, 5315, 0 };
            const std::uint32_t dim835JoeKuoD6Init[]   =   { 1, 1, 5, 11, 13, 37, 89, 73, 149, 477, 1909, 3343, 525, 0 };
            const std::uint32_t dim836JoeKuoD6Init[]   =   { 1, 3, 5, 7, 5, 59, 55, 255, 223, 459, 2027, 237, 4205, 0 };
            const std::uint32_t dim837JoeKuoD6Init[]   =   { 1, 1, 1, 7, 27, 11, 95, 65, 325, 835, 907, 3801, 3787, 0 };
            const std::uint32_t dim838JoeKuoD6Init[]   =   { 1, 1, 1, 11, 27, 33, 99, 175, 51, 913, 331, 1851, 4133, 0 };
            const std::uint32_t dim839JoeKuoD6Init[]   =   { 1, 3, 5, 5, 13, 37, 31, 99, 273, 409, 1827, 3845, 5491, 0 };
            const std::uint32_t dim840JoeKuoD6Init[]   =   { 1, 1, 3, 7, 23, 19, 107, 85, 283, 523, 509, 451, 421, 0 };
            const std::uint32_t dim841JoeKuoD6Init[]   =   { 1, 3, 5, 7, 13, 9, 51, 81, 87, 619, 61, 2803, 5271, 0 };
            const std::uint32_t dim842JoeKuoD6Init[]   =   { 1, 1, 1, 15, 9, 45, 35, 219, 401, 271, 953, 649, 6847, 0 };
            const std::uint32_t dim843JoeKuoD6Init[]   =   { 1, 1, 7, 11, 9, 45, 17, 219, 169, 837, 1483, 1605, 2901, 0 };
            const std::uint32_t dim844JoeKuoD6Init[]   =   { 1, 1, 7, 7, 21, 43, 37, 33, 291, 359, 71, 2899, 7037, 0 };
            const std::uint32_t dim845JoeKuoD6Init[]   =   { 1, 3, 3, 13, 31, 53, 37, 15, 149, 949, 551, 3445, 5455, 0 };
            const std::uint32_t dim846JoeKuoD6Init[]   =   { 1, 3, 1, 5, 19, 45, 81, 223, 193, 439, 2047, 3879, 789, 0 };
            const std::uint32_t dim847JoeKuoD6Init[]   =   { 1, 1, 7, 3, 11, 63, 35, 61, 255, 563, 459, 2991, 3359, 0 };
            const std::uint32_t dim848JoeKuoD6Init[]   =   { 1, 1, 5, 9, 13, 49, 47, 185, 239, 221, 1533, 3635, 2045, 0 };
            const std::uint32_t dim849JoeKuoD6Init[]   =   { 1, 3, 7, 3, 25, 37, 127, 223, 51, 357, 483, 3837, 6873, 0 };
            const std::uint32_t dim850JoeKuoD6Init[]   =   { 1, 1, 7, 9, 31, 37, 113, 31, 387, 833, 1243, 1543, 5535, 0 };
            const std::uint32_t dim851JoeKuoD6Init[]   =   { 1, 3, 1, 9, 23, 59, 119, 221, 73, 185, 2007, 2885, 2563, 0 };
            const std::uint32_t dim852JoeKuoD6Init[]   =   { 1, 1, 1, 13, 7, 33, 53, 179, 67, 185, 1541, 1807, 4659, 0 };
            const std::uint32_t dim853JoeKuoD6Init[]   =   { 1, 3, 1, 11, 31, 37, 23, 215, 269, 357, 207, 645, 4219, 0 };
            const std::uint32_t dim854JoeKuoD6Init[]   =   { 1, 3, 3, 13, 19, 27, 107, 55, 91, 71, 1695, 1815, 89, 0 };
            const std::uint32_t dim855JoeKuoD6Init[]   =   { 1, 1, 3, 15, 3, 19, 35, 247, 49, 529, 1523, 3317, 6151, 0 };
            const std::uint32_t dim856JoeKuoD6Init[]   =   { 1, 1, 7, 7, 23, 25, 107, 139, 483, 503, 1277, 243, 7879, 0 };
            const std::uint32_t dim857JoeKuoD6Init[]   =   { 1, 3, 3, 13, 3, 15, 11, 197, 135, 839, 985, 275, 5527, 0 };
            const std::uint32_t dim858JoeKuoD6Init[]   =   { 1, 3, 5, 3, 25, 47, 95, 21, 113, 307, 1001, 3065, 295, 0 };
            const std::uint32_t dim859JoeKuoD6Init[]   =   { 1, 1, 3, 9, 19, 19, 99, 213, 363, 449, 735, 2851, 2521, 0 };
            const std::uint32_t dim860JoeKuoD6Init[]   =   { 1, 1, 3, 9, 5, 49, 63, 61, 157, 857, 497, 2801, 6987, 0 };
            const std::uint32_t dim861JoeKuoD6Init[]   =   { 1, 1, 1, 9, 1, 41, 109, 119, 499, 939, 867, 3675, 8023, 0 };
            const std::uint32_t dim862JoeKuoD6Init[]   =   { 1, 3, 1, 1, 13, 33, 109, 123, 289, 3, 1271, 2773, 4265, 0 };
            const std::uint32_t dim863JoeKuoD6Init[]   =   { 1, 3, 1, 11, 9, 57, 83, 221, 95, 43, 1189, 457, 7133, 0 };
            const std::uint32_t dim864JoeKuoD6Init[]   =   { 1, 1, 7, 3, 11, 49, 33, 219, 229, 289, 685, 3359, 4495, 0 };
            const std::uint32_t dim865JoeKuoD6Init[]   =   { 1, 3, 1, 3, 19, 43, 67, 193, 41, 771, 407, 81, 3891, 0 };
            const std::uint32_t dim866JoeKuoD6Init[]   =   { 1, 1, 7, 11, 5, 29, 51, 175, 297, 539, 1, 2245, 6439, 0 };
            const std::uint32_t dim867JoeKuoD6Init[]   =   { 1, 3, 7, 15, 21, 33, 117, 183, 511, 489, 1283, 3281, 5979, 0 };
            const std::uint32_t dim868JoeKuoD6Init[]   =   { 1, 3, 7, 5, 9, 3, 125, 147, 359, 549, 369, 3049, 2405, 0 };
            const std::uint32_t dim869JoeKuoD6Init[]   =   { 1, 3, 5, 7, 19, 5, 65, 97, 483, 377, 1523, 1457, 2995, 0 };
            const std::uint32_t dim870JoeKuoD6Init[]   =   { 1, 1, 5, 1, 11, 21, 41, 113, 277, 131, 1475, 1043, 2367, 0 };
            const std::uint32_t dim871JoeKuoD6Init[]   =   { 1, 3, 3, 1, 15, 17, 101, 69, 443, 865, 817, 1421, 5231, 0 };
            const std::uint32_t dim872JoeKuoD6Init[]   =   { 1, 1, 3, 3, 3, 55, 95, 99, 75, 195, 1929, 3931, 5855, 0 };
            const std::uint32_t dim873JoeKuoD6Init[]   =   { 1, 3, 1, 3, 19, 23, 93, 213, 241, 551, 1307, 585, 7729, 0 };
            const std::uint32_t dim874JoeKuoD6Init[]   =   { 1, 3, 1, 11, 23, 15, 53, 249, 467, 519, 95, 741, 409, 0 };
            const std::uint32_t dim875JoeKuoD6Init[]   =   { 1, 1, 1, 15, 29, 37, 43, 203, 233, 877, 77, 1933, 2729, 0 };
            const std::uint32_t dim876JoeKuoD6Init[]   =   { 1, 3, 7, 11, 27, 39, 43, 161, 255, 15, 1463, 833, 495, 0 };
            const std::uint32_t dim877JoeKuoD6Init[]   =   { 1, 1, 7, 11, 3, 53, 81, 67, 375, 823, 1903, 3061, 395, 0 };
            const std::uint32_t dim878JoeKuoD6Init[]   =   { 1, 1, 1, 1, 15, 37, 93, 233, 247, 501, 1321, 3275, 5409, 0 };
            const std::uint32_t dim879JoeKuoD6Init[]   =   { 1, 3, 3, 7, 7, 11, 5, 105, 139, 983, 1239, 531, 3881, 0 };
            const std::uint32_t dim880JoeKuoD6Init[]   =   { 1, 1, 5, 3, 19, 49, 107, 227, 361, 101, 355, 2649, 7383, 0 };
            const std::uint32_t dim881JoeKuoD6Init[]   =   { 1, 1, 7, 5, 25, 41, 101, 121, 209, 293, 1937, 2259, 5557, 0 };
            const std::uint32_t dim882JoeKuoD6Init[]   =   { 1, 1, 3, 7, 7, 1, 9, 13, 463, 1019, 995, 3159, 107, 0 };
            const std::uint32_t dim883JoeKuoD6Init[]   =   { 1, 3, 5, 11, 5, 35, 127, 97, 261, 789, 807, 807, 6257, 0 };
            const std::uint32_t dim884JoeKuoD6Init[]   =   { 1, 1, 7, 5, 11, 13, 45, 91, 417, 101, 1973, 3645, 2107, 0 };
            const std::uint32_t dim885JoeKuoD6Init[]   =   { 1, 1, 3, 7, 5, 63, 57, 49, 203, 157, 115, 1393, 8117, 0 };
            const std::uint32_t dim886JoeKuoD6Init[]   =   { 1, 3, 5, 5, 3, 43, 15, 155, 127, 489, 1165, 3701, 4867, 0 };
            const std::uint32_t dim887JoeKuoD6Init[]   =   { 1, 1, 7, 7, 29, 29, 69, 215, 415, 367, 371, 1901, 6075, 0 };
            const std::uint32_t dim888JoeKuoD6Init[]   =   { 1, 1, 1, 3, 11, 33, 89, 149, 433, 705, 1437, 1597, 505, 0 };
            const std::uint32_t dim889JoeKuoD6Init[]   =   { 1, 3, 5, 1, 13, 37, 19, 119, 5, 581, 2037, 1633, 2099, 0 };
            const std::uint32_t dim890JoeKuoD6Init[]   =   { 1, 3, 7, 13, 5, 49, 103, 245, 215, 515, 133, 2007, 1933, 0 };
            const std::uint32_t dim891JoeKuoD6Init[]   =   { 1, 3, 1, 9, 1, 3, 25, 197, 253, 387, 1683, 2267, 221, 0 };
            const std::uint32_t dim892JoeKuoD6Init[]   =   { 1, 3, 5, 15, 21, 9, 73, 201, 405, 999, 437, 3877, 6045, 0 };
            const std::uint32_t dim893JoeKuoD6Init[]   =   { 1, 1, 3, 1, 31, 55, 25, 83, 421, 395, 1807, 2129, 7797, 0 };
            const std::uint32_t dim894JoeKuoD6Init[]   =   { 1, 1, 3, 1, 23, 21, 121, 183, 125, 347, 143, 3685, 4317, 0 };
            const std::uint32_t dim895JoeKuoD6Init[]   =   { 1, 3, 3, 3, 17, 45, 17, 223, 267, 795, 1815, 1309, 155, 0 };
            const std::uint32_t dim896JoeKuoD6Init[]   =   { 1, 1, 1, 15, 17, 59, 5, 133, 15, 715, 1503, 153, 2887, 0 };
            const std::uint32_t dim897JoeKuoD6Init[]   =   { 1, 1, 1, 1, 27, 13, 119, 77, 243, 995, 1851, 3719, 4695, 0 };
            const std::uint32_t dim898JoeKuoD6Init[]   =   { 1, 3, 1, 5, 31, 49, 43, 165, 49, 609, 1265, 1141, 505, 0 };
            const std::uint32_t dim899JoeKuoD6Init[]   =   { 1, 1, 7, 13, 11, 63, 21, 253, 229, 585, 1543, 3719, 4141, 0 };
            const std::uint32_t dim900JoeKuoD6Init[]   =   { 1, 3, 7, 11, 23, 27, 17, 131, 295, 895, 1493, 1411, 3247, 0 };
            const std::uint32_t dim901JoeKuoD6Init[]   =   { 1, 1, 5, 9, 29, 7, 97, 15, 113, 445, 859, 1483, 1121, 0 };
            const std::uint32_t dim902JoeKuoD6Init[]   =   { 1, 3, 1, 9, 13, 49, 99, 107, 323, 201, 681, 3071, 5281, 0 };
            const std::uint32_t dim903JoeKuoD6Init[]   =   { 1, 1, 1, 15, 9, 19, 61, 161, 7, 87, 587, 2199, 2811, 0 };
            const std::uint32_t dim904JoeKuoD6Init[]   =   { 1, 3, 3, 15, 15, 19, 95, 45, 299, 829, 981, 3479, 487, 0 };
            const std::uint32_t dim905JoeKuoD6Init[]   =   { 1, 1, 1, 9, 3, 37, 7, 19, 227, 13, 397, 513, 1257, 0 };
            const std::uint32_t dim906JoeKuoD6Init[]   =   { 1, 1, 5, 15, 15, 13, 17, 111, 135, 929, 1145, 811, 1801, 0 };
            const std::uint32_t dim907JoeKuoD6Init[]   =   { 1, 3, 1, 3, 27, 57, 31, 19, 279, 103, 693, 631, 3409, 0 };
            const std::uint32_t dim908JoeKuoD6Init[]   =   { 1, 1, 1, 1, 15, 13, 67, 83, 23, 799, 1735, 2063, 3363, 0 };
            const std::uint32_t dim909JoeKuoD6Init[]   =   { 1, 3, 3, 7, 3, 1, 61, 31, 41, 533, 2025, 4067, 6963, 0 };
            const std::uint32_t dim910JoeKuoD6Init[]   =   { 1, 1, 5, 7, 17, 27, 81, 79, 107, 205, 29, 97, 4883, 0 };
            const std::uint32_t dim911JoeKuoD6Init[]   =   { 1, 1, 1, 5, 19, 49, 91, 201, 283, 949, 651, 3819, 5073, 0 };
            const std::uint32_t dim912JoeKuoD6Init[]   =   { 1, 1, 7, 9, 11, 13, 73, 197, 37, 219, 1931, 3369, 6017, 0 };
            const std::uint32_t dim913JoeKuoD6Init[]   =   { 1, 1, 7, 15, 11, 7, 75, 205, 7, 819, 399, 661, 6487, 0 };
            const std::uint32_t dim914JoeKuoD6Init[]   =   { 1, 3, 3, 3, 27, 37, 95, 41, 307, 165, 1077, 3485, 563, 0 };
            const std::uint32_t dim915JoeKuoD6Init[]   =   { 1, 3, 5, 3, 21, 49, 57, 179, 109, 627, 1789, 431, 2941, 0 };
            const std::uint32_t dim916JoeKuoD6Init[]   =   { 1, 1, 7, 5, 11, 19, 43, 137, 149, 679, 1543, 245, 1381, 0 };
            const std::uint32_t dim917JoeKuoD6Init[]   =   { 1, 3, 5, 5, 15, 3, 69, 81, 135, 159, 1363, 3401, 6355, 0 };
            const std::uint32_t dim918JoeKuoD6Init[]   =   { 1, 3, 5, 1, 9, 61, 49, 53, 319, 25, 1647, 1297, 615, 0 };
            const std::uint32_t dim919JoeKuoD6Init[]   =   { 1, 3, 5, 11, 31, 43, 9, 101, 71, 919, 335, 3147, 5823, 0 };
            const std::uint32_t dim920JoeKuoD6Init[]   =   { 1, 3, 1, 1, 15, 5, 29, 109, 511, 945, 867, 3677, 6915, 0 };
            const std::uint32_t dim921JoeKuoD6Init[]   =   { 1, 3, 3, 15, 17, 49, 91, 111, 215, 29, 1879, 97, 2505, 0 };
            const std::uint32_t dim922JoeKuoD6Init[]   =   { 1, 3, 1, 13, 19, 61, 11, 111, 163, 777, 533, 1113, 5339, 0 };
            const std::uint32_t dim923JoeKuoD6Init[]   =   { 1, 1, 7, 9, 17, 55, 117, 91, 455, 289, 557, 913, 4455, 0 };
            const std::uint32_t dim924JoeKuoD6Init[]   =   { 1, 3, 1, 7, 25, 19, 123, 37, 1, 277, 717, 2965, 4469, 0 };
            const std::uint32_t dim925JoeKuoD6Init[]   =   { 1, 3, 7, 3, 19, 23, 87, 235, 209, 457, 2041, 2893, 1805, 0 };
            const std::uint32_t dim926JoeKuoD6Init[]   =   { 1, 3, 3, 5, 5, 43, 23, 61, 351, 791, 59, 2009, 2909, 0 };
            const std::uint32_t dim927JoeKuoD6Init[]   =   { 1, 1, 3, 7, 5, 1, 27, 231, 385, 257, 1261, 2701, 1807, 0 };
            const std::uint32_t dim928JoeKuoD6Init[]   =   { 1, 3, 1, 1, 27, 19, 87, 253, 131, 685, 1743, 3983, 2651, 0 };
            const std::uint32_t dim929JoeKuoD6Init[]   =   { 1, 3, 7, 11, 21, 17, 11, 81, 191, 641, 1821, 3005, 7251, 0 };
            const std::uint32_t dim930JoeKuoD6Init[]   =   { 1, 3, 3, 5, 15, 31, 41, 213, 55, 931, 1953, 49, 6037, 0 };
            const std::uint32_t dim931JoeKuoD6Init[]   =   { 1, 1, 7, 15, 7, 27, 65, 223, 113, 79, 1875, 911, 5445, 0 };
            const std::uint32_t dim932JoeKuoD6Init[]   =   { 1, 3, 7, 7, 23, 55, 51, 167, 495, 25, 1585, 3447, 799, 0 };
            const std::uint32_t dim933JoeKuoD6Init[]   =   { 1, 1, 3, 7, 27, 15, 95, 193, 337, 415, 975, 3085, 967, 0 };
            const std::uint32_t dim934JoeKuoD6Init[]   =   { 1, 1, 7, 15, 19, 7, 93, 41, 433, 551, 401, 3169, 3971, 0 };
            const std::uint32_t dim935JoeKuoD6Init[]   =   { 1, 1, 7, 11, 13, 15, 53, 69, 433, 59, 1117, 3359, 6231, 0 };
            const std::uint32_t dim936JoeKuoD6Init[]   =   { 1, 1, 7, 3, 23, 5, 115, 201, 225, 109, 1903, 3897, 6265, 0 };
            const std::uint32_t dim937JoeKuoD6Init[]   =   { 1, 1, 1, 11, 17, 1, 39, 143, 361, 659, 1105, 23, 4923, 0 };
            const std::uint32_t dim938JoeKuoD6Init[]   =   { 1, 1, 1, 9, 27, 57, 85, 227, 261, 119, 1881, 3965, 6999, 0 };
            const std::uint32_t dim939JoeKuoD6Init[]   =   { 1, 3, 7, 7, 15, 7, 107, 17, 315, 49, 1591, 905, 7789, 0 };
            const std::uint32_t dim940JoeKuoD6Init[]   =   { 1, 3, 1, 7, 29, 3, 47, 237, 157, 769, 839, 3199, 3195, 0 };
            const std::uint32_t dim941JoeKuoD6Init[]   =   { 1, 1, 3, 15, 25, 39, 63, 15, 111, 857, 881, 1505, 7671, 0 };
            const std::uint32_t dim942JoeKuoD6Init[]   =   { 1, 1, 7, 1, 3, 35, 41, 215, 99, 895, 1025, 1483, 4707, 0 };
            const std::uint32_t dim943JoeKuoD6Init[]   =   { 1, 3, 5, 1, 1, 31, 25, 247, 113, 841, 397, 1825, 6969, 0 };
            const std::uint32_t dim944JoeKuoD6Init[]   =   { 1, 1, 3, 5, 19, 41, 49, 243, 225, 973, 241, 175, 1041, 0 };
            const std::uint32_t dim945JoeKuoD6Init[]   =   { 1, 1, 1, 7, 15, 15, 105, 141, 83, 75, 1675, 3523, 5219, 0 };
            const std::uint32_t dim946JoeKuoD6Init[]   =   { 1, 1, 7, 5, 13, 27, 47, 199, 445, 841, 959, 1157, 2209, 0 };
            const std::uint32_t dim947JoeKuoD6Init[]   =   { 1, 3, 5, 15, 23, 31, 31, 81, 85, 33, 785, 2639, 7799, 0 };
            const std::uint32_t dim948JoeKuoD6Init[]   =   { 1, 1, 5, 13, 21, 3, 47, 99, 235, 943, 1731, 2467, 7891, 0 };
            const std::uint32_t dim949JoeKuoD6Init[]   =   { 1, 1, 1, 3, 17, 53, 85, 219, 73, 131, 1339, 875, 1191, 0 };
            const std::uint32_t dim950JoeKuoD6Init[]   =   { 1, 1, 5, 7, 17, 63, 113, 7, 185, 557, 749, 3563, 4973, 0 };
            const std::uint32_t dim951JoeKuoD6Init[]   =   { 1, 3, 3, 15, 15, 21, 43, 111, 155, 689, 345, 423, 3597, 0 };
            const std::uint32_t dim952JoeKuoD6Init[]   =   { 1, 1, 5, 1, 15, 29, 93, 5, 361, 713, 695, 3937, 425, 0 };
            const std::uint32_t dim953JoeKuoD6Init[]   =   { 1, 3, 7, 7, 13, 41, 115, 175, 315, 937, 123, 2841, 4457, 0 };
            const std::uint32_t dim954JoeKuoD6Init[]   =   { 1, 1, 3, 11, 25, 5, 103, 53, 423, 811, 657, 399, 7257, 0 };
            const std::uint32_t dim955JoeKuoD6Init[]   =   { 1, 1, 1, 1, 1, 13, 101, 211, 383, 325, 97, 1703, 4429, 0 };
            const std::uint32_t dim956JoeKuoD6Init[]   =   { 1, 3, 7, 9, 31, 45, 83, 157, 509, 701, 841, 1105, 3643, 0 };
            const std::uint32_t dim957JoeKuoD6Init[]   =   { 1, 1, 1, 7, 1, 9, 69, 17, 129, 281, 1161, 2945, 7693, 0 };
            const std::uint32_t dim958JoeKuoD6Init[]   =   { 1, 3, 7, 1, 11, 29, 51, 143, 77, 433, 1723, 2317, 5641, 0 };
            const std::uint32_t dim959JoeKuoD6Init[]   =   { 1, 1, 1, 1, 21, 43, 13, 67, 177, 505, 1629, 1267, 4885, 0 };
            const std::uint32_t dim960JoeKuoD6Init[]   =   { 1, 1, 3, 11, 27, 63, 111, 47, 233, 781, 453, 1679, 3209, 0 };
            const std::uint32_t dim961JoeKuoD6Init[]   =   { 1, 1, 3, 13, 29, 27, 119, 141, 493, 971, 461, 1159, 633, 0 };
            const std::uint32_t dim962JoeKuoD6Init[]   =   { 1, 1, 3, 15, 23, 5, 79, 215, 163, 149, 1805, 2399, 61, 0 };
            const std::uint32_t dim963JoeKuoD6Init[]   =   { 1, 3, 5, 13, 19, 5, 1, 39, 409, 561, 709, 829, 1357, 0 };
            const std::uint32_t dim964JoeKuoD6Init[]   =   { 1, 3, 3, 13, 19, 43, 9, 177, 449, 447, 73, 2107, 5669, 0 };
            const std::uint32_t dim965JoeKuoD6Init[]   =   { 1, 3, 5, 1, 23, 13, 63, 109, 203, 593, 829, 4017, 6881, 0 };
            const std::uint32_t dim966JoeKuoD6Init[]   =   { 1, 1, 5, 7, 3, 9, 53, 175, 391, 169, 1283, 3793, 4451, 0 };
            const std::uint32_t dim967JoeKuoD6Init[]   =   { 1, 1, 5, 7, 29, 43, 9, 5, 209, 77, 927, 2941, 8145, 0 };
            const std::uint32_t dim968JoeKuoD6Init[]   =   { 1, 3, 5, 15, 17, 49, 5, 143, 131, 771, 1685, 925, 2175, 0 };
            const std::uint32_t dim969JoeKuoD6Init[]   =   { 1, 1, 3, 11, 27, 27, 27, 159, 161, 1015, 1587, 4049, 1983, 0 };
            const std::uint32_t dim970JoeKuoD6Init[]   =   { 1, 3, 1, 3, 23, 57, 119, 67, 481, 577, 389, 3319, 5325, 0 };
            const std::uint32_t dim971JoeKuoD6Init[]   =   { 1, 3, 5, 1, 19, 39, 87, 61, 329, 657, 1773, 31, 1707, 0 };
            const std::uint32_t dim972JoeKuoD6Init[]   =   { 1, 1, 3, 1, 5, 25, 15, 241, 131, 815, 1751, 3029, 8039, 0 };
            const std::uint32_t dim973JoeKuoD6Init[]   =   { 1, 3, 3, 13, 27, 13, 77, 87, 437, 57, 621, 1031, 7891, 0 };
            const std::uint32_t dim974JoeKuoD6Init[]   =   { 1, 3, 1, 13, 23, 51, 117, 37, 331, 745, 605, 3179, 4713, 0 };
            const std::uint32_t dim975JoeKuoD6Init[]   =   { 1, 1, 5, 5, 19, 17, 99, 167, 87, 721, 737, 789, 2165, 0 };
            const std::uint32_t dim976JoeKuoD6Init[]   =   { 1, 3, 5, 13, 1, 51, 119, 211, 165, 299, 1327, 3053, 3343, 0 };
            const std::uint32_t dim977JoeKuoD6Init[]   =   { 1, 1, 5, 15, 29, 45, 17, 129, 67, 345, 1553, 2705, 7369, 0 };
            const std::uint32_t dim978JoeKuoD6Init[]   =   { 1, 1, 1, 9, 23, 7, 13, 209, 7, 407, 317, 3077, 7287, 0 };
            const std::uint32_t dim979JoeKuoD6Init[]   =   { 1, 1, 1, 5, 9, 59, 89, 3, 487, 451, 505, 2499, 7563, 0 };
            const std::uint32_t dim980JoeKuoD6Init[]   =   { 1, 3, 1, 7, 21, 1, 21, 203, 101, 417, 1389, 2751, 1397, 0 };
            const std::uint32_t dim981JoeKuoD6Init[]   =   { 1, 3, 7, 13, 7, 31, 3, 247, 349, 485, 1259, 549, 6321, 0 };
            const std::uint32_t dim982JoeKuoD6Init[]   =   { 1, 1, 7, 7, 27, 33, 107, 197, 293, 729, 1753, 2571, 103, 0 };
            const std::uint32_t dim983JoeKuoD6Init[]   =   { 1, 3, 5, 9, 25, 35, 5, 253, 137, 213, 2041, 3387, 1809, 0 };
            const std::uint32_t dim984JoeKuoD6Init[]   =   { 1, 1, 7, 13, 15, 35, 67, 83, 295, 175, 839, 2831, 839, 0 };
            const std::uint32_t dim985JoeKuoD6Init[]   =   { 1, 3, 3, 11, 3, 17, 55, 141, 247, 991, 117, 3799, 1221, 0 };
            const std::uint32_t dim986JoeKuoD6Init[]   =   { 1, 1, 5, 1, 11, 37, 87, 233, 457, 653, 899, 2933, 3105, 0 };
            const std::uint32_t dim987JoeKuoD6Init[]   =   { 1, 1, 3, 15, 3, 31, 67, 167, 437, 9, 651, 1109, 1139, 0 };
            const std::uint32_t dim988JoeKuoD6Init[]   =   { 1, 1, 3, 1, 7, 63, 67, 17, 11, 883, 1855, 1941, 4751, 0 };
            const std::uint32_t dim989JoeKuoD6Init[]   =   { 1, 3, 7, 9, 19, 33, 113, 117, 495, 39, 1795, 2561, 5519, 0 };
            const std::uint32_t dim990JoeKuoD6Init[]   =   { 1, 1, 7, 5, 1, 3, 103, 37, 201, 223, 1101, 877, 6483, 0 };
            const std::uint32_t dim991JoeKuoD6Init[]   =   { 1, 1, 5, 9, 29, 49, 51, 33, 439, 917, 861, 1321, 2135, 0 };
            const std::uint32_t dim992JoeKuoD6Init[]   =   { 1, 1, 3, 3, 1, 5, 17, 93, 217, 619, 613, 1357, 6095, 0 };
            const std::uint32_t dim993JoeKuoD6Init[]   =   { 1, 3, 1, 11, 3, 21, 5, 41, 15, 175, 843, 2937, 6849, 0 };
            const std::uint32_t dim994JoeKuoD6Init[]   =   { 1, 3, 3, 7, 9, 57, 55, 127, 79, 287, 445, 2205, 7989, 0 };
            const std::uint32_t dim995JoeKuoD6Init[]   =   { 1, 1, 7, 13, 23, 17, 93, 129, 157, 135, 1747, 1813, 4183, 0 };
            const std::uint32_t dim996JoeKuoD6Init[]   =   { 1, 1, 1, 5, 31, 59, 99, 33, 425, 329, 887, 367, 1761, 0 };
            const std::uint32_t dim997JoeKuoD6Init[]   =   { 1, 1, 7, 9, 17, 53, 77, 139, 435, 387, 49, 3649, 1773, 0 };
            const std::uint32_t dim998JoeKuoD6Init[]   =   { 1, 3, 3, 15, 21, 57, 45, 161, 331, 719, 273, 3479, 4173, 0 };
            const std::uint32_t dim999JoeKuoD6Init[]   =   { 1, 1, 3, 9, 3, 3, 105, 201, 373, 877, 919, 1263, 6649, 0 };
            const std::uint32_t dim1000JoeKuoD6Init[]   =   { 1, 3, 1, 15, 13, 43, 13, 99, 73, 163, 353, 3569, 5601, 0 };
            const std::uint32_t dim1001JoeKuoD6Init[]   =   { 1, 3, 7, 3, 5, 9, 69, 177, 449, 47, 781, 1125, 4245, 0 };
            const std::uint32_t dim1002JoeKuoD6Init[]   =   { 1, 1, 1, 5, 3, 45, 1, 123, 409, 903, 205, 2057, 7637, 0 };
            const std::uint32_t dim1003JoeKuoD6Init[]   =   { 1, 3, 5, 9, 19, 47, 87, 135, 481, 799, 101, 3409, 2241, 0 };
            const std::uint32_t dim1004JoeKuoD6Init[]   =   { 1, 3, 1, 13, 3, 25, 15, 27, 181, 967, 669, 2577, 7249, 0 };
            const std::uint32_t dim1005JoeKuoD6Init[]   =   { 1, 1, 7, 3, 31, 5, 103, 53, 1, 911, 1209, 3697, 6685, 0 };
            const std::uint32_t dim1006JoeKuoD6Init[]   =   { 1, 1, 3, 1, 5, 5, 49, 135, 281, 747, 761, 2973, 7963, 0 };
            const std::uint32_t dim1007JoeKuoD6Init[]   =   { 1, 3, 3, 5, 19, 61, 125, 199, 299, 515, 1365, 369, 7027, 0 };
            const std::uint32_t dim1008JoeKuoD6Init[]   =   { 1, 3, 1, 7, 5, 41, 63, 229, 283, 571, 147, 447, 657, 0 };
            const std::uint32_t dim1009JoeKuoD6Init[]   =   { 1, 3, 1, 11, 5, 15, 55, 7, 259, 61, 27, 1429, 5631, 0 };
            const std::uint32_t dim1010JoeKuoD6Init[]   =   { 1, 1, 5, 1, 3, 53, 51, 253, 155, 553, 1293, 3735, 6567, 0 };
            const std::uint32_t dim1011JoeKuoD6Init[]   =   { 1, 3, 5, 9, 5, 41, 21, 159, 101, 785, 1981, 3799, 7693, 0 };
            const std::uint32_t dim1012JoeKuoD6Init[]   =   { 1, 3, 7, 7, 9, 3, 95, 105, 129, 213, 1215, 1027, 5699, 0 };
            const std::uint32_t dim1013JoeKuoD6Init[]   =   { 1, 1, 3, 3, 29, 13, 9, 253, 449, 321, 341, 2879, 171, 0 };
            const std::uint32_t dim1014JoeKuoD6Init[]   =   { 1, 3, 7, 11, 21, 11, 75, 35, 43, 965, 675, 2217, 7175, 0 };
            const std::uint32_t dim1015JoeKuoD6Init[]   =   { 1, 1, 5, 15, 31, 5, 29, 137, 311, 751, 47, 1367, 5921, 0 };
            const std::uint32_t dim1016JoeKuoD6Init[]   =   { 1, 1, 3, 15, 17, 1, 45, 69, 55, 649, 835, 569, 7615, 0 };
            const std::uint32_t dim1017JoeKuoD6Init[]   =   { 1, 3, 1, 13, 31, 7, 23, 15, 391, 145, 1845, 1825, 1403, 0 };
            const std::uint32_t dim1018JoeKuoD6Init[]   =   { 1, 1, 3, 15, 5, 9, 79, 77, 105, 399, 1933, 2503, 4781, 0 };
            const std::uint32_t dim1019JoeKuoD6Init[]   =   { 1, 3, 1, 3, 17, 47, 19, 13, 107, 475, 759, 2933, 3761, 0 };
            const std::uint32_t dim1020JoeKuoD6Init[]   =   { 1, 1, 7, 11, 3, 7, 121, 209, 397, 877, 293, 847, 7039, 0 };
            const std::uint32_t dim1021JoeKuoD6Init[]   =   { 1, 1, 1, 15, 29, 45, 5, 109, 335, 461, 143, 931, 4045, 0 };
            const std::uint32_t dim1022JoeKuoD6Init[]   =   { 1, 3, 1, 7, 11, 57, 73, 89, 201, 173, 803, 3953, 5205, 0 };
            const std::uint32_t dim1023JoeKuoD6Init[]   =   { 1, 1, 5, 11, 11, 33, 37, 29, 263, 1019, 657, 1453, 7807, 0 };
            const std::uint32_t dim1024JoeKuoD6Init[]   =   { 1, 3, 3, 13, 31, 25, 37, 47, 261, 607, 1703, 2603, 417, 0 };
            const std::uint32_t dim1025JoeKuoD6Init[]   =   { 1, 1, 1, 1, 31, 61, 45, 115, 275, 239, 1989, 1897, 4329, 0 };
            const std::uint32_t dim1026JoeKuoD6Init[]   =   { 1, 3, 5, 3, 31, 3, 11, 173, 335, 579, 1193, 2219, 7875, 0 };
            const std::uint32_t dim1027JoeKuoD6Init[]   =   { 1, 1, 7, 9, 29, 45, 13, 67, 399, 177, 1293, 3865, 2225, 0 };
            const std::uint32_t dim1028JoeKuoD6Init[]   =   { 1, 1, 7, 11, 11, 51, 121, 227, 469, 905, 929, 2635, 4165, 0 };
            const std::uint32_t dim1029JoeKuoD6Init[]   =   { 1, 3, 7, 9, 13, 39, 55, 167, 23, 147, 1603, 2083, 4645, 0 };
            const std::uint32_t dim1030JoeKuoD6Init[]   =   { 1, 1, 3, 15, 27, 53, 11, 155, 157, 629, 259, 3009, 4605, 0 };
            const std::uint32_t dim1031JoeKuoD6Init[]   =   { 1, 3, 1, 7, 15, 47, 51, 1, 259, 603, 887, 2833, 6581, 0 };
            const std::uint32_t dim1032JoeKuoD6Init[]   =   { 1, 3, 5, 3, 1, 47, 91, 43, 361, 571, 29, 1453, 4269, 0 };
            const std::uint32_t dim1033JoeKuoD6Init[]   =   { 1, 1, 3, 9, 11, 51, 55, 23, 415, 277, 1423, 3475, 1527, 0 };
            const std::uint32_t dim1034JoeKuoD6Init[]   =   { 1, 1, 3, 11, 29, 49, 101, 75, 299, 709, 805, 4037, 4389, 0 };
            const std::uint32_t dim1035JoeKuoD6Init[]   =   { 1, 1, 7, 3, 23, 1, 37, 51, 379, 771, 1301, 3717, 6673, 0 };
            const std::uint32_t dim1036JoeKuoD6Init[]   =   { 1, 1, 5, 3, 23, 11, 125, 177, 375, 665, 951, 1577, 2603, 0 };
            const std::uint32_t dim1037JoeKuoD6Init[]   =   { 1, 1, 1, 1, 1, 5, 71, 255, 21, 459, 467, 2083, 5415, 0 };
            const std::uint32_t dim1038JoeKuoD6Init[]   =   { 1, 1, 5, 13, 23, 29, 109, 157, 363, 971, 549, 647, 1177, 0 };
            const std::uint32_t dim1039JoeKuoD6Init[]   =   { 1, 1, 3, 9, 7, 15, 101, 3, 365, 213, 745, 1155, 6099, 0 };
            const std::uint32_t dim1040JoeKuoD6Init[]   =   { 1, 3, 5, 15, 15, 19, 47, 179, 303, 521, 1279, 219, 2415, 0 };
            const std::uint32_t dim1041JoeKuoD6Init[]   =   { 1, 3, 3, 13, 27, 11, 83, 165, 369, 989, 261, 3933, 4809, 0 };
            const std::uint32_t dim1042JoeKuoD6Init[]   =   { 1, 1, 3, 11, 31, 59, 1, 185, 53, 703, 1471, 2935, 1107, 0 };
            const std::uint32_t dim1043JoeKuoD6Init[]   =   { 1, 3, 3, 7, 25, 3, 81, 27, 93, 521, 433, 2859, 5861, 0 };
            const std::uint32_t dim1044JoeKuoD6Init[]   =   { 1, 3, 3, 11, 29, 15, 49, 167, 315, 927, 543, 3473, 4307, 0 };
            const std::uint32_t dim1045JoeKuoD6Init[]   =   { 1, 3, 1, 3, 29, 33, 53, 15, 183, 691, 703, 1311, 3393, 0 };
            const std::uint32_t dim1046JoeKuoD6Init[]   =   { 1, 3, 5, 13, 23, 49, 3, 11, 1, 357, 1407, 415, 7211, 0 };
            const std::uint32_t dim1047JoeKuoD6Init[]   =   { 1, 3, 7, 15, 1, 25, 91, 113, 323, 371, 189, 925, 1181, 0 };
            const std::uint32_t dim1048JoeKuoD6Init[]   =   { 1, 3, 3, 3, 17, 59, 119, 199, 115, 223, 877, 2193, 193, 0 };
            const std::uint32_t dim1049JoeKuoD6Init[]   =   { 1, 1, 1, 5, 5, 35, 31, 59, 437, 411, 37, 2405, 3797, 0 };
            const std::uint32_t dim1050JoeKuoD6Init[]   =   { 1, 3, 1, 13, 9, 37, 1, 241, 59, 157, 1785, 1223, 563, 0 };
            const std::uint32_t dim1051JoeKuoD6Init[]   =   { 1, 3, 5, 13, 3, 21, 25, 95, 15, 745, 85, 701, 5361, 0 };
            const std::uint32_t dim1052JoeKuoD6Init[]   =   { 1, 3, 7, 1, 31, 33, 111, 195, 35, 913, 2013, 2951, 6611, 0 };
            const std::uint32_t dim1053JoeKuoD6Init[]   =   { 1, 3, 5, 1, 19, 3, 75, 119, 111, 409, 951, 1457, 4957, 0 };
            const std::uint32_t dim1054JoeKuoD6Init[]   =   { 1, 3, 1, 15, 19, 59, 3, 155, 237, 657, 1967, 3323, 6235, 0 };
            const std::uint32_t dim1055JoeKuoD6Init[]   =   { 1, 1, 5, 1, 3, 19, 45, 105, 377, 881, 167, 2255, 4483, 0 };
            const std::uint32_t dim1056JoeKuoD6Init[]   =   { 1, 1, 7, 7, 13, 13, 99, 89, 201, 279, 161, 2483, 6001, 0 };
            const std::uint32_t dim1057JoeKuoD6Init[]   =   { 1, 1, 7, 3, 13, 17, 97, 129, 137, 377, 1519, 183, 3725, 0 };
            const std::uint32_t dim1058JoeKuoD6Init[]   =   { 1, 1, 7, 9, 9, 5, 45, 135, 115, 181, 1685, 3505, 4387, 0 };
            const std::uint32_t dim1059JoeKuoD6Init[]   =   { 1, 1, 1, 1, 19, 35, 69, 113, 305, 419, 949, 2969, 247, 0 };
            const std::uint32_t dim1060JoeKuoD6Init[]   =   { 1, 1, 5, 13, 23, 61, 13, 139, 501, 811, 67, 1501, 6493, 0 };
            const std::uint32_t dim1061JoeKuoD6Init[]   =   { 1, 1, 3, 13, 15, 41, 27, 217, 293, 13, 145, 2631, 6991, 0 };
            const std::uint32_t dim1062JoeKuoD6Init[]   =   { 1, 3, 3, 13, 15, 37, 71, 123, 285, 49, 627, 1283, 5993, 0 };
            const std::uint32_t dim1063JoeKuoD6Init[]   =   { 1, 3, 3, 11, 9, 25, 11, 1, 203, 353, 1347, 1999, 2799, 0 };
            const std::uint32_t dim1064JoeKuoD6Init[]   =   { 1, 3, 5, 1, 7, 49, 101, 231, 499, 63, 1977, 2207, 7829, 0 };
            const std::uint32_t dim1065JoeKuoD6Init[]   =   { 1, 1, 7, 1, 17, 15, 115, 139, 381, 943, 623, 4037, 2971, 0 };
            const std::uint32_t dim1066JoeKuoD6Init[]   =   { 1, 1, 3, 5, 13, 55, 23, 87, 139, 795, 1669, 1375, 1185, 0 };
            const std::uint32_t dim1067JoeKuoD6Init[]   =   { 1, 3, 3, 5, 5, 45, 97, 253, 241, 333, 645, 555, 7867, 0 };
            const std::uint32_t dim1068JoeKuoD6Init[]   =   { 1, 3, 5, 1, 1, 1, 89, 27, 407, 509, 1433, 609, 2355, 0 };
            const std::uint32_t dim1069JoeKuoD6Init[]   =   { 1, 3, 7, 1, 27, 29, 5, 157, 495, 811, 1293, 1143, 827, 0 };
            const std::uint32_t dim1070JoeKuoD6Init[]   =   { 1, 1, 3, 3, 25, 49, 127, 111, 191, 3, 845, 1383, 2521, 0 };
            const std::uint32_t dim1071JoeKuoD6Init[]   =   { 1, 1, 5, 7, 5, 51, 101, 155, 237, 461, 831, 3091, 3851, 0 };
            const std::uint32_t dim1072JoeKuoD6Init[]   =   { 1, 3, 7, 1, 29, 35, 105, 91, 285, 705, 131, 395, 6011, 0 };
            const std::uint32_t dim1073JoeKuoD6Init[]   =   { 1, 3, 5, 3, 13, 21, 83, 173, 221, 827, 1775, 1931, 6727, 0 };
            const std::uint32_t dim1074JoeKuoD6Init[]   =   { 1, 1, 3, 5, 3, 25, 95, 115, 205, 569, 1447, 933, 6425, 0 };
            const std::uint32_t dim1075JoeKuoD6Init[]   =   { 1, 1, 7, 9, 31, 3, 17, 175, 145, 447, 1321, 1069, 6527, 0 };
            const std::uint32_t dim1076JoeKuoD6Init[]   =   { 1, 1, 3, 3, 23, 1, 79, 51, 421, 419, 873, 3939, 1801, 0 };
            const std::uint32_t dim1077JoeKuoD6Init[]   =   { 1, 1, 5, 1, 3, 39, 15, 85, 169, 669, 919, 397, 5579, 0 };
            const std::uint32_t dim1078JoeKuoD6Init[]   =   { 1, 3, 5, 1, 21, 61, 87, 217, 251, 619, 1091, 4009, 229, 0 };
            const std::uint32_t dim1079JoeKuoD6Init[]   =   { 1, 1, 1, 11, 23, 55, 85, 121, 363, 867, 315, 447, 3373, 0 };
            const std::uint32_t dim1080JoeKuoD6Init[]   =   { 1, 3, 3, 13, 29, 19, 89, 85, 137, 469, 1873, 2765, 3975, 0 };
            const std::uint32_t dim1081JoeKuoD6Init[]   =   { 1, 3, 7, 13, 19, 63, 61, 77, 67, 361, 11, 1787, 4703, 0 };
            const std::uint32_t dim1082JoeKuoD6Init[]   =   { 1, 1, 3, 11, 7, 15, 127, 105, 179, 857, 1671, 3647, 3389, 0 };
            const std::uint32_t dim1083JoeKuoD6Init[]   =   { 1, 1, 1, 7, 19, 21, 99, 161, 499, 519, 1287, 2973, 479, 0 };
            const std::uint32_t dim1084JoeKuoD6Init[]   =   { 1, 1, 3, 13, 29, 51, 95, 251, 55, 519, 1955, 2881, 5951, 0 };
            const std::uint32_t dim1085JoeKuoD6Init[]   =   { 1, 1, 3, 11, 23, 63, 121, 237, 175, 311, 701, 1539, 2383, 0 };
            const std::uint32_t dim1086JoeKuoD6Init[]   =   { 1, 1, 7, 5, 5, 45, 73, 97, 5, 153, 715, 2037, 3353, 0 };
            const std::uint32_t dim1087JoeKuoD6Init[]   =   { 1, 1, 1, 3, 13, 7, 67, 173, 425, 843, 1497, 2729, 5193, 0 };
            const std::uint32_t dim1088JoeKuoD6Init[]   =   { 1, 1, 7, 1, 23, 3, 119, 11, 77, 141, 1905, 2269, 4269, 0 };
            const std::uint32_t dim1089JoeKuoD6Init[]   =   { 1, 1, 7, 15, 1, 23, 79, 251, 439, 603, 405, 2449, 6383, 0 };
            const std::uint32_t dim1090JoeKuoD6Init[]   =   { 1, 3, 7, 11, 29, 27, 47, 255, 47, 661, 1967, 1007, 3689, 0 };
            const std::uint32_t dim1091JoeKuoD6Init[]   =   { 1, 3, 7, 5, 19, 39, 35, 115, 417, 373, 291, 329, 603, 0 };
            const std::uint32_t dim1092JoeKuoD6Init[]   =   { 1, 3, 1, 9, 11, 33, 27, 193, 207, 423, 1311, 1369, 7307, 0 };
            const std::uint32_t dim1093JoeKuoD6Init[]   =   { 1, 1, 3, 11, 9, 29, 83, 17, 497, 493, 329, 3141, 5935, 0 };
            const std::uint32_t dim1094JoeKuoD6Init[]   =   { 1, 3, 1, 5, 31, 51, 29, 171, 51, 493, 1621, 3501, 4091, 0 };
            const std::uint32_t dim1095JoeKuoD6Init[]   =   { 1, 1, 5, 9, 21, 43, 105, 207, 245, 363, 1191, 699, 1139, 0 };
            const std::uint32_t dim1096JoeKuoD6Init[]   =   { 1, 1, 3, 11, 19, 5, 81, 119, 247, 169, 1337, 45, 6565, 0 };
            const std::uint32_t dim1097JoeKuoD6Init[]   =   { 1, 3, 1, 11, 3, 51, 3, 101, 159, 11, 253, 299, 5043, 0 };
            const std::uint32_t dim1098JoeKuoD6Init[]   =   { 1, 3, 1, 5, 11, 53, 85, 39, 57, 645, 2007, 1039, 3627, 0 };
            const std::uint32_t dim1099JoeKuoD6Init[]   =   { 1, 3, 5, 3, 17, 61, 97, 165, 415, 357, 283, 601, 5505, 0 };
            const std::uint32_t dim1100JoeKuoD6Init[]   =   { 1, 3, 7, 3, 9, 51, 49, 85, 3, 227, 137, 309, 243, 0 };
            const std::uint32_t dim1101JoeKuoD6Init[]   =   { 1, 1, 5, 3, 11, 59, 11, 131, 409, 703, 455, 123, 6727, 0 };
            const std::uint32_t dim1102JoeKuoD6Init[]   =   { 1, 3, 7, 9, 25, 49, 21, 171, 287, 379, 667, 313, 713, 0 };
            const std::uint32_t dim1103JoeKuoD6Init[]   =   { 1, 1, 3, 9, 7, 35, 47, 3, 367, 581, 1627, 1665, 3905, 0 };
            const std::uint32_t dim1104JoeKuoD6Init[]   =   { 1, 3, 1, 1, 29, 57, 35, 55, 255, 653, 823, 2197, 6179, 0 };
            const std::uint32_t dim1105JoeKuoD6Init[]   =   { 1, 3, 7, 15, 17, 15, 117, 83, 359, 163, 115, 2999, 5373, 0 };
            const std::uint32_t dim1106JoeKuoD6Init[]   =   { 1, 1, 5, 3, 21, 61, 35, 97, 71, 687, 207, 2917, 1049, 0 };
            const std::uint32_t dim1107JoeKuoD6Init[]   =   { 1, 1, 1, 15, 13, 15, 125, 81, 263, 661, 417, 3243, 1669, 0 };
            const std::uint32_t dim1108JoeKuoD6Init[]   =   { 1, 1, 7, 3, 3, 19, 111, 193, 443, 339, 659, 1211, 1557, 0 };
            const std::uint32_t dim1109JoeKuoD6Init[]   =   { 1, 3, 1, 3, 27, 3, 3, 173, 391, 213, 803, 3281, 3207, 0 };
            const std::uint32_t dim1110JoeKuoD6Init[]   =   { 1, 1, 5, 15, 19, 1, 7, 211, 157, 603, 403, 1387, 1583, 0 };
            const std::uint32_t dim1111JoeKuoD6Init[]   =   { 1, 3, 5, 13, 17, 53, 125, 13, 339, 723, 521, 413, 5801, 10451, 0 };
            const std::uint32_t dim1112JoeKuoD6Init[]   =   { 1, 1, 3, 13, 29, 9, 99, 77, 141, 609, 1533, 983, 2039, 51, 0 };
            const std::uint32_t dim1113JoeKuoD6Init[]   =   { 1, 1, 3, 11, 21, 55, 5, 51, 423, 309, 525, 3715, 3025, 15055, 0 };
            const std::uint32_t dim1114JoeKuoD6Init[]   =   { 1, 1, 3, 7, 9, 21, 77, 171, 239, 341, 1653, 1093, 2273, 10723, 0 };
            const std::uint32_t dim1115JoeKuoD6Init[]   =   { 1, 1, 1, 15, 31, 15, 23, 35, 317, 869, 1917, 1415, 4313, 3687, 0 };
            const std::uint32_t dim1116JoeKuoD6Init[]   =   { 1, 1, 1, 5, 21, 25, 99, 167, 439, 453, 473, 431, 6665, 4989, 0 };
            const std::uint32_t dim1117JoeKuoD6Init[]   =   { 1, 1, 7, 9, 31, 47, 81, 83, 345, 43, 1363, 1885, 3155, 3185, 0 };
            const std::uint32_t dim1118JoeKuoD6Init[]   =   { 1, 3, 7, 1, 31, 17, 61, 185, 341, 129, 547, 717, 2071, 9991, 0 };
            const std::uint32_t dim1119JoeKuoD6Init[]   =   { 1, 3, 1, 13, 23, 61, 77, 217, 455, 77, 1263, 1601, 3501, 14953, 0 };
            const std::uint32_t dim1120JoeKuoD6Init[]   =   { 1, 1, 7, 7, 19, 19, 1, 229, 431, 943, 1069, 1949, 1289, 15729, 0 };
            const std::uint32_t dim1121JoeKuoD6Init[]   =   { 1, 1, 3, 5, 1, 35, 97, 251, 487, 459, 1265, 1739, 165, 10365, 0 };
            const std::uint32_t dim1122JoeKuoD6Init[]   =   { 1, 3, 5, 3, 11, 25, 79, 175, 383, 545, 187, 197, 4329, 3363, 0 };
            const std::uint32_t dim1123JoeKuoD6Init[]   =   { 1, 1, 3, 3, 29, 9, 63, 55, 175, 277, 431, 2549, 2629, 6409, 0 };
            const std::uint32_t dim1124JoeKuoD6Init[]   =   { 1, 1, 3, 15, 17, 21, 79, 139, 99, 135, 1763, 1805, 3471, 5439, 0 };
            const std::uint32_t dim1125JoeKuoD6Init[]   =   { 1, 1, 3, 9, 9, 15, 35, 119, 289, 835, 769, 3843, 4119, 4421, 0 };
            const std::uint32_t dim1126JoeKuoD6Init[]   =   { 1, 1, 1, 5, 19, 19, 67, 199, 307, 815, 1367, 1231, 3927, 6593, 0 };
            const std::uint32_t dim1127JoeKuoD6Init[]   =   { 1, 1, 3, 1, 29, 51, 121, 209, 431, 47, 1115, 907, 2535, 9755, 0 };
            const std::uint32_t dim1128JoeKuoD6Init[]   =   { 1, 1, 3, 5, 17, 1, 5, 119, 121, 223, 1719, 1291, 3947, 15891, 0 };
            const std::uint32_t dim1129JoeKuoD6Init[]   =   { 1, 3, 1, 15, 29, 25, 3, 131, 373, 307, 645, 3513, 1289, 1987, 0 };
            const std::uint32_t dim1130JoeKuoD6Init[]   =   { 1, 3, 3, 11, 29, 45, 105, 179, 331, 465, 891, 1315, 403, 3057, 0 };
            const std::uint32_t dim1131JoeKuoD6Init[]   =   { 1, 1, 5, 13, 17, 59, 77, 127, 485, 855, 1147, 3093, 891, 9869, 0 };
            const std::uint32_t dim1132JoeKuoD6Init[]   =   { 1, 1, 1, 7, 23, 27, 31, 203, 285, 463, 827, 685, 1349, 15051, 0 };
            const std::uint32_t dim1133JoeKuoD6Init[]   =   { 1, 1, 1, 5, 29, 5, 107, 195, 31, 425, 19, 2865, 3869, 11153, 0 };
            const std::uint32_t dim1134JoeKuoD6Init[]   =   { 1, 1, 7, 5, 7, 47, 1, 73, 307, 347, 393, 2205, 7709, 15121, 0 };
            const std::uint32_t dim1135JoeKuoD6Init[]   =   { 1, 1, 1, 13, 15, 61, 25, 131, 113, 369, 1995, 2527, 4475, 1745, 0 };
            const std::uint32_t dim1136JoeKuoD6Init[]   =   { 1, 1, 1, 1, 31, 63, 21, 253, 307, 281, 859, 3319, 6721, 2891, 0 };
            const std::uint32_t dim1137JoeKuoD6Init[]   =   { 1, 1, 3, 11, 1, 17, 5, 183, 301, 979, 651, 1685, 6343, 10067, 0 };
            const std::uint32_t dim1138JoeKuoD6Init[]   =   { 1, 1, 5, 15, 23, 45, 99, 145, 263, 507, 1381, 3425, 2215, 1815, 0 };
            const std::uint32_t dim1139JoeKuoD6Init[]   =   { 1, 3, 1, 5, 11, 63, 85, 203, 411, 881, 1369, 1237, 4657, 6541, 0 };
            const std::uint32_t dim1140JoeKuoD6Init[]   =   { 1, 3, 3, 13, 17, 53, 121, 201, 269, 983, 215, 3187, 7121, 6111, 0 };
            const std::uint32_t dim1141JoeKuoD6Init[]   =   { 1, 3, 5, 15, 15, 5, 13, 143, 3, 313, 1677, 1093, 3295, 3387, 0 };
            const std::uint32_t dim1142JoeKuoD6Init[]   =   { 1, 1, 3, 13, 3, 23, 73, 17, 257, 965, 239, 1271, 2803, 7327, 0 };
            const std::uint32_t dim1143JoeKuoD6Init[]   =   { 1, 3, 5, 13, 9, 57, 115, 37, 41, 467, 135, 1403, 3811, 4741, 0 };
            const std::uint32_t dim1144JoeKuoD6Init[]   =   { 1, 3, 7, 15, 9, 33, 39, 203, 351, 367, 1355, 1403, 3685, 4757, 0 };
            const std::uint32_t dim1145JoeKuoD6Init[]   =   { 1, 3, 5, 11, 31, 3, 113, 123, 203, 421, 1821, 3151, 2375, 4419, 0 };
            const std::uint32_t dim1146JoeKuoD6Init[]   =   { 1, 1, 1, 7, 21, 63, 99, 23, 133, 79, 991, 1755, 4989, 4709, 0 };
            const std::uint32_t dim1147JoeKuoD6Init[]   =   { 1, 3, 5, 1, 25, 63, 113, 239, 49, 443, 173, 1261, 3201, 10599, 0 };
            const std::uint32_t dim1148JoeKuoD6Init[]   =   { 1, 3, 3, 13, 3, 25, 101, 169, 23, 585, 327, 1327, 111, 10059, 0 };
            const std::uint32_t dim1149JoeKuoD6Init[]   =   { 1, 3, 3, 5, 19, 1, 33, 89, 437, 213, 1933, 1741, 2603, 5625, 0 };
            const std::uint32_t dim1150JoeKuoD6Init[]   =   { 1, 3, 1, 3, 15, 15, 25, 139, 73, 335, 237, 2461, 3101, 14951, 0 };
            const std::uint32_t dim1151JoeKuoD6Init[]   =   { 1, 3, 5, 1, 31, 15, 31, 187, 177, 659, 1339, 3767, 4975, 7123, 0 };
            const std::uint32_t dim1152JoeKuoD6Init[]   =   { 1, 3, 1, 3, 25, 19, 47, 89, 107, 107, 649, 683, 3123, 11085, 0 };
            const std::uint32_t dim1153JoeKuoD6Init[]   =   { 1, 3, 7, 9, 15, 21, 101, 25, 11, 625, 1555, 675, 3893, 5805, 0 };
            const std::uint32_t dim1154JoeKuoD6Init[]   =   { 1, 1, 1, 5, 7, 49, 123, 21, 439, 369, 207, 535, 4619, 14665, 0 };
            const std::uint32_t dim1155JoeKuoD6Init[]   =   { 1, 1, 5, 7, 1, 25, 103, 185, 99, 239, 1093, 1561, 6177, 4039, 0 };
            const std::uint32_t dim1156JoeKuoD6Init[]   =   { 1, 3, 7, 5, 29, 21, 43, 103, 343, 973, 1561, 2975, 7467, 7947, 0 };
            const std::uint32_t dim1157JoeKuoD6Init[]   =   { 1, 1, 7, 9, 19, 3, 13, 23, 461, 813, 1191, 985, 559, 3317, 0 };
            const std::uint32_t dim1158JoeKuoD6Init[]   =   { 1, 3, 5, 5, 27, 31, 79, 15, 365, 901, 1949, 117, 3619, 13311, 0 };
            const std::uint32_t dim1159JoeKuoD6Init[]   =   { 1, 3, 5, 7, 5, 33, 67, 199, 425, 189, 1691, 3099, 815, 1677, 0 };
            const std::uint32_t dim1160JoeKuoD6Init[]   =   { 1, 1, 7, 11, 13, 29, 73, 137, 265, 601, 445, 3893, 2511, 8047, 0 };
            const std::uint32_t dim1161JoeKuoD6Init[]   =   { 1, 1, 3, 1, 13, 5, 57, 101, 357, 391, 335, 601, 1359, 1065, 0 };
            const std::uint32_t dim1162JoeKuoD6Init[]   =   { 1, 1, 1, 1, 25, 57, 27, 115, 31, 873, 611, 2125, 447, 13585, 0 };
            const std::uint32_t dim1163JoeKuoD6Init[]   =   { 1, 3, 3, 13, 27, 17, 73, 11, 359, 33, 1153, 271, 4537, 15141, 0 };
            const std::uint32_t dim1164JoeKuoD6Init[]   =   { 1, 3, 7, 3, 11, 63, 103, 61, 59, 629, 1629, 3279, 3919, 3177, 0 };
            const std::uint32_t dim1165JoeKuoD6Init[]   =   { 1, 1, 5, 15, 3, 63, 85, 193, 381, 165, 175, 3247, 2501, 4209, 0 };
            const std::uint32_t dim1166JoeKuoD6Init[]   =   { 1, 1, 5, 15, 1, 33, 59, 219, 487, 193, 1557, 703, 2907, 7953, 0 };
            const std::uint32_t dim1167JoeKuoD6Init[]   =   { 1, 1, 7, 3, 9, 3, 105, 95, 389, 991, 21, 3841, 6983, 285, 0 };
            const std::uint32_t dim1168JoeKuoD6Init[]   =   { 1, 1, 1, 1, 1, 31, 25, 137, 117, 67, 1283, 1963, 6591, 15541, 0 };
            const std::uint32_t dim1169JoeKuoD6Init[]   =   { 1, 3, 5, 11, 7, 15, 127, 89, 453, 777, 1827, 2311, 7661, 11833, 0 };
            const std::uint32_t dim1170JoeKuoD6Init[]   =   { 1, 1, 7, 13, 19, 29, 79, 165, 223, 453, 2039, 3961, 6467, 5481, 0 };
            const std::uint32_t dim1171JoeKuoD6Init[]   =   { 1, 3, 3, 7, 17, 41, 43, 157, 323, 3, 1001, 2109, 4513, 12127, 0 };
            const std::uint32_t dim1172JoeKuoD6Init[]   =   { 1, 1, 5, 9, 31, 57, 3, 217, 113, 271, 1663, 1367, 6949, 8165, 0 };
            const std::uint32_t dim1173JoeKuoD6Init[]   =   { 1, 1, 7, 15, 27, 35, 81, 235, 61, 205, 525, 311, 6357, 2527, 0 };
            const std::uint32_t dim1174JoeKuoD6Init[]   =   { 1, 3, 1, 9, 19, 29, 71, 207, 321, 1011, 1615, 1333, 3459, 6681, 0 };
            const std::uint32_t dim1175JoeKuoD6Init[]   =   { 1, 3, 7, 7, 3, 57, 41, 19, 25, 397, 565, 1837, 7625, 11813, 0 };
            const std::uint32_t dim1176JoeKuoD6Init[]   =   { 1, 3, 3, 1, 27, 47, 31, 79, 441, 961, 1255, 423, 2405, 913, 0 };
            const std::uint32_t dim1177JoeKuoD6Init[]   =   { 1, 3, 3, 13, 3, 29, 69, 227, 85, 201, 395, 3199, 3869, 13099, 0 };
            const std::uint32_t dim1178JoeKuoD6Init[]   =   { 1, 3, 3, 7, 29, 61, 99, 7, 27, 227, 945, 873, 475, 4363, 0 };
            const std::uint32_t dim1179JoeKuoD6Init[]   =   { 1, 3, 5, 13, 19, 21, 57, 149, 217, 443, 565, 453, 5487, 10981, 0 };
            const std::uint32_t dim1180JoeKuoD6Init[]   =   { 1, 3, 3, 1, 9, 27, 47, 191, 35, 395, 1429, 4079, 6871, 8013, 0 };
            const std::uint32_t dim1181JoeKuoD6Init[]   =   { 1, 3, 5, 15, 5, 43, 9, 79, 279, 563, 1125, 985, 8117, 4099, 0 };
            const std::uint32_t dim1182JoeKuoD6Init[]   =   { 1, 3, 5, 1, 13, 41, 21, 117, 287, 667, 701, 1483, 8167, 13283, 0 };
            const std::uint32_t dim1183JoeKuoD6Init[]   =   { 1, 3, 1, 3, 15, 15, 59, 5, 383, 509, 1657, 3977, 7697, 10941, 0 };
            const std::uint32_t dim1184JoeKuoD6Init[]   =   { 1, 3, 1, 1, 17, 29, 19, 23, 377, 45, 981, 1631, 3557, 6749, 0 };
            const std::uint32_t dim1185JoeKuoD6Init[]   =   { 1, 3, 3, 9, 9, 51, 9, 193, 345, 361, 1679, 3333, 713, 5387, 0 };
            const std::uint32_t dim1186JoeKuoD6Init[]   =   { 1, 3, 5, 5, 17, 45, 97, 17, 385, 349, 105, 2245, 7295, 14393, 0 };
            const std::uint32_t dim1187JoeKuoD6Init[]   =   { 1, 3, 7, 3, 19, 51, 35, 99, 79, 301, 1563, 399, 5879, 14675, 0 };
            const std::uint32_t dim1188JoeKuoD6Init[]   =   { 1, 1, 7, 15, 13, 53, 55, 203, 417, 161, 2033, 1845, 6763, 3585, 0 };
            const std::uint32_t dim1189JoeKuoD6Init[]   =   { 1, 1, 3, 3, 7, 23, 11, 43, 241, 309, 1453, 3147, 2619, 3163, 0 };
            const std::uint32_t dim1190JoeKuoD6Init[]   =   { 1, 1, 1, 11, 17, 1, 17, 137, 443, 465, 993, 3217, 7879, 14607, 0 };
            const std::uint32_t dim1191JoeKuoD6Init[]   =   { 1, 1, 7, 13, 29, 49, 71, 217, 291, 793, 135, 21, 2503, 11091, 0 };
            const std::uint32_t dim1192JoeKuoD6Init[]   =   { 1, 3, 1, 11, 31, 51, 121, 227, 377, 157, 1457, 1317, 5625, 6217, 0 };
            const std::uint32_t dim1193JoeKuoD6Init[]   =   { 1, 1, 3, 7, 23, 61, 47, 93, 79, 617, 1805, 2403, 5513, 16335, 0 };
            const std::uint32_t dim1194JoeKuoD6Init[]   =   { 1, 3, 5, 11, 23, 25, 41, 11, 495, 587, 1223, 3107, 1469, 15223, 0 };
            const std::uint32_t dim1195JoeKuoD6Init[]   =   { 1, 3, 7, 7, 9, 1, 1, 49, 23, 723, 1761, 3717, 7375, 10875, 0 };
            const std::uint32_t dim1196JoeKuoD6Init[]   =   { 1, 3, 3, 11, 25, 37, 57, 63, 309, 603, 183, 285, 1663, 5627, 0 };
            const std::uint32_t dim1197JoeKuoD6Init[]   =   { 1, 3, 7, 11, 19, 25, 25, 201, 391, 257, 529, 1645, 1, 15111, 0 };
            const std::uint32_t dim1198JoeKuoD6Init[]   =   { 1, 3, 3, 9, 11, 43, 91, 65, 5, 959, 301, 1015, 6343, 3453, 0 };
            const std::uint32_t dim1199JoeKuoD6Init[]   =   { 1, 3, 3, 11, 17, 17, 103, 37, 77, 973, 575, 439, 49, 3639, 0 };
            const std::uint32_t dim1200JoeKuoD6Init[]   =   { 1, 1, 5, 7, 1, 15, 107, 237, 231, 967, 923, 1101, 6715, 1713, 0 };
            const std::uint32_t dim1201JoeKuoD6Init[]   =   { 1, 3, 1, 15, 9, 33, 29, 211, 245, 601, 1783, 887, 1209, 11785, 0 };
            const std::uint32_t dim1202JoeKuoD6Init[]   =   { 1, 3, 3, 7, 21, 43, 27, 89, 27, 141, 865, 367, 1379, 4063, 0 };
            const std::uint32_t dim1203JoeKuoD6Init[]   =   { 1, 3, 7, 7, 15, 17, 15, 15, 131, 649, 1955, 3289, 3983, 10689, 0 };
            const std::uint32_t dim1204JoeKuoD6Init[]   =   { 1, 3, 1, 5, 17, 7, 125, 69, 359, 981, 1345, 933, 5281, 7113, 0 };
            const std::uint32_t dim1205JoeKuoD6Init[]   =   { 1, 1, 5, 9, 17, 7, 41, 207, 497, 1015, 493, 891, 3563, 3541, 0 };
            const std::uint32_t dim1206JoeKuoD6Init[]   =   { 1, 3, 5, 11, 27, 3, 47, 31, 303, 1007, 2047, 2203, 6257, 8369, 0 };
            const std::uint32_t dim1207JoeKuoD6Init[]   =   { 1, 1, 1, 15, 25, 15, 89, 51, 217, 357, 1133, 1917, 213, 3365, 0 };
            const std::uint32_t dim1208JoeKuoD6Init[]   =   { 1, 1, 5, 13, 29, 23, 123, 207, 429, 805, 819, 2357, 6313, 11019, 0 };
            const std::uint32_t dim1209JoeKuoD6Init[]   =   { 1, 1, 3, 7, 19, 15, 41, 73, 279, 11, 1089, 3107, 7737, 15953, 0 };
            const std::uint32_t dim1210JoeKuoD6Init[]   =   { 1, 3, 5, 7, 7, 15, 41, 73, 493, 457, 1731, 1139, 2513, 12373, 0 };
            const std::uint32_t dim1211JoeKuoD6Init[]   =   { 1, 3, 5, 9, 17, 5, 55, 155, 173, 1005, 529, 3175, 7667, 4747, 0 };
            const std::uint32_t dim1212JoeKuoD6Init[]   =   { 1, 1, 7, 7, 5, 21, 105, 31, 205, 847, 1033, 3167, 2347, 8499, 0 };
            const std::uint32_t dim1213JoeKuoD6Init[]   =   { 1, 3, 5, 3, 11, 17, 59, 189, 179, 1007, 33, 3287, 4813, 8177, 0 };
            const std::uint32_t dim1214JoeKuoD6Init[]   =   { 1, 3, 3, 13, 27, 47, 47, 171, 413, 875, 1081, 1259, 7139, 8645, 0 };
            const std::uint32_t dim1215JoeKuoD6Init[]   =   { 1, 3, 5, 7, 25, 21, 51, 29, 361, 293, 51, 1119, 1453, 5283, 0 };
            const std::uint32_t dim1216JoeKuoD6Init[]   =   { 1, 3, 7, 7, 29, 55, 103, 199, 511, 341, 1957, 3987, 2855, 1279, 0 };
            const std::uint32_t dim1217JoeKuoD6Init[]   =   { 1, 1, 1, 9, 23, 51, 61, 63, 391, 37, 55, 3771, 6517, 15913, 0 };
            const std::uint32_t dim1218JoeKuoD6Init[]   =   { 1, 1, 1, 9, 3, 19, 13, 147, 453, 855, 1321, 189, 5043, 11215, 0 };
            const std::uint32_t dim1219JoeKuoD6Init[]   =   { 1, 3, 3, 13, 23, 3, 87, 155, 401, 981, 607, 3413, 995, 6473, 0 };
            const std::uint32_t dim1220JoeKuoD6Init[]   =   { 1, 3, 1, 9, 29, 47, 95, 123, 421, 353, 1867, 2609, 2569, 14083, 0 };
            const std::uint32_t dim1221JoeKuoD6Init[]   =   { 1, 1, 5, 13, 25, 39, 29, 111, 125, 545, 1493, 2371, 6361, 6307, 0 };
            const std::uint32_t dim1222JoeKuoD6Init[]   =   { 1, 3, 3, 11, 13, 31, 87, 75, 27, 393, 921, 3655, 3343, 16349, 0 };
            const std::uint32_t dim1223JoeKuoD6Init[]   =   { 1, 1, 5, 9, 19, 19, 7, 129, 223, 715, 433, 1627, 4463, 2951, 0 };
            const std::uint32_t dim1224JoeKuoD6Init[]   =   { 1, 1, 7, 1, 31, 13, 49, 33, 89, 43, 1529, 725, 3809, 3427, 0 };
            const std::uint32_t dim1225JoeKuoD6Init[]   =   { 1, 1, 7, 3, 1, 27, 45, 9, 309, 875, 659, 2661, 553, 7069, 0 };
            const std::uint32_t dim1226JoeKuoD6Init[]   =   { 1, 1, 7, 15, 13, 37, 61, 19, 125, 683, 1227, 2255, 1455, 9339, 0 };
            const std::uint32_t dim1227JoeKuoD6Init[]   =   { 1, 3, 5, 7, 19, 7, 71, 21, 465, 645, 1885, 873, 7405, 1913, 0 };
            const std::uint32_t dim1228JoeKuoD6Init[]   =   { 1, 3, 1, 11, 11, 35, 79, 61, 79, 57, 1603, 3719, 6323, 16371, 0 };
            const std::uint32_t dim1229JoeKuoD6Init[]   =   { 1, 1, 7, 1, 29, 57, 85, 21, 205, 37, 2045, 683, 4901, 8223, 0 };
            const std::uint32_t dim1230JoeKuoD6Init[]   =   { 1, 1, 5, 13, 31, 31, 65, 131, 259, 535, 967, 3943, 2605, 2089, 0 };
            const std::uint32_t dim1231JoeKuoD6Init[]   =   { 1, 1, 7, 9, 27, 61, 39, 243, 207, 41, 1909, 3279, 1331, 4635, 0 };
            const std::uint32_t dim1232JoeKuoD6Init[]   =   { 1, 3, 3, 5, 11, 63, 105, 19, 169, 95, 773, 3175, 1869, 1797, 0 };
            const std::uint32_t dim1233JoeKuoD6Init[]   =   { 1, 3, 3, 15, 13, 33, 107, 197, 153, 795, 1477, 105, 4965, 991, 0 };
            const std::uint32_t dim1234JoeKuoD6Init[]   =   { 1, 3, 7, 11, 11, 37, 23, 149, 197, 3, 1035, 3857, 553, 1059, 0 };
            const std::uint32_t dim1235JoeKuoD6Init[]   =   { 1, 3, 1, 3, 17, 29, 89, 189, 193, 59, 1477, 3517, 2565, 7739, 0 };
            const std::uint32_t dim1236JoeKuoD6Init[]   =   { 1, 1, 1, 9, 23, 3, 25, 163, 469, 305, 1791, 3393, 6141, 8119, 0 };
            const std::uint32_t dim1237JoeKuoD6Init[]   =   { 1, 3, 5, 7, 7, 41, 19, 101, 179, 487, 1071, 2761, 8043, 5103, 0 };
            const std::uint32_t dim1238JoeKuoD6Init[]   =   { 1, 1, 7, 9, 1, 21, 101, 103, 349, 85, 1841, 1033, 4473, 3563, 0 };
            const std::uint32_t dim1239JoeKuoD6Init[]   =   { 1, 1, 3, 13, 23, 61, 39, 27, 479, 13, 45, 1371, 7897, 10637, 0 };
            const std::uint32_t dim1240JoeKuoD6Init[]   =   { 1, 1, 5, 9, 17, 61, 71, 55, 355, 99, 1695, 3053, 839, 959, 0 };
            const std::uint32_t dim1241JoeKuoD6Init[]   =   { 1, 1, 3, 1, 7, 27, 87, 221, 327, 241, 461, 3177, 5933, 8299, 0 };
            const std::uint32_t dim1242JoeKuoD6Init[]   =   { 1, 3, 7, 9, 5, 41, 111, 245, 447, 263, 1363, 1767, 6331, 3355, 0 };
            const std::uint32_t dim1243JoeKuoD6Init[]   =   { 1, 3, 3, 13, 15, 11, 15, 169, 429, 149, 1965, 2477, 7733, 2499, 0 };
            const std::uint32_t dim1244JoeKuoD6Init[]   =   { 1, 1, 5, 15, 15, 47, 25, 33, 469, 701, 773, 2747, 1533, 14633, 0 };
            const std::uint32_t dim1245JoeKuoD6Init[]   =   { 1, 3, 1, 5, 19, 57, 37, 75, 423, 11, 685, 2487, 1779, 8797, 0 };
            const std::uint32_t dim1246JoeKuoD6Init[]   =   { 1, 3, 1, 5, 19, 41, 67, 99, 333, 991, 953, 3221, 939, 4197, 0 };
            const std::uint32_t dim1247JoeKuoD6Init[]   =   { 1, 3, 1, 15, 11, 39, 25, 1, 159, 679, 465, 1611, 5799, 2537, 0 };
            const std::uint32_t dim1248JoeKuoD6Init[]   =   { 1, 1, 5, 11, 5, 37, 37, 7, 101, 703, 235, 23, 2209, 12799, 0 };
            const std::uint32_t dim1249JoeKuoD6Init[]   =   { 1, 1, 7, 3, 11, 23, 71, 215, 45, 269, 1539, 3625, 5773, 6889, 0 };
            const std::uint32_t dim1250JoeKuoD6Init[]   =   { 1, 3, 5, 15, 27, 33, 105, 109, 205, 653, 821, 435, 1087, 2495, 0 };
            const std::uint32_t dim1251JoeKuoD6Init[]   =   { 1, 1, 3, 5, 11, 39, 53, 213, 41, 385, 1425, 25, 5553, 12523, 0 };
            const std::uint32_t dim1252JoeKuoD6Init[]   =   { 1, 3, 5, 15, 29, 49, 13, 253, 505, 407, 985, 2569, 6727, 4761, 0 };
            const std::uint32_t dim1253JoeKuoD6Init[]   =   { 1, 1, 1, 3, 29, 17, 69, 47, 25, 819, 1145, 2479, 1183, 3343, 0 };
            const std::uint32_t dim1254JoeKuoD6Init[]   =   { 1, 3, 1, 15, 25, 61, 43, 55, 279, 579, 361, 355, 6101, 3143, 0 };
            const std::uint32_t dim1255JoeKuoD6Init[]   =   { 1, 3, 5, 11, 3, 59, 125, 101, 451, 495, 1711, 3443, 3625, 15579, 0 };
            const std::uint32_t dim1256JoeKuoD6Init[]   =   { 1, 3, 1, 11, 25, 61, 49, 219, 23, 795, 481, 3609, 3691, 15419, 0 };
            const std::uint32_t dim1257JoeKuoD6Init[]   =   { 1, 3, 7, 5, 9, 59, 49, 233, 345, 143, 181, 3587, 3041, 1219, 0 };
            const std::uint32_t dim1258JoeKuoD6Init[]   =   { 1, 3, 7, 13, 9, 31, 39, 137, 261, 919, 1367, 3145, 4659, 5875, 0 };
            const std::uint32_t dim1259JoeKuoD6Init[]   =   { 1, 1, 3, 3, 27, 43, 95, 65, 301, 915, 31, 451, 7743, 7277, 0 };
            const std::uint32_t dim1260JoeKuoD6Init[]   =   { 1, 3, 1, 5, 23, 37, 53, 31, 203, 453, 71, 1585, 6011, 16369, 0 };
            const std::uint32_t dim1261JoeKuoD6Init[]   =   { 1, 1, 5, 1, 15, 47, 91, 227, 297, 45, 1415, 3647, 7811, 14015, 0 };
            const std::uint32_t dim1262JoeKuoD6Init[]   =   { 1, 1, 1, 1, 29, 27, 93, 121, 169, 69, 1361, 2907, 1867, 7017, 0 };
            const std::uint32_t dim1263JoeKuoD6Init[]   =   { 1, 3, 1, 7, 23, 53, 77, 41, 25, 873, 1333, 3889, 3239, 1771, 0 };
            const std::uint32_t dim1264JoeKuoD6Init[]   =   { 1, 1, 1, 7, 31, 27, 87, 81, 167, 343, 1981, 2499, 7749, 15747, 0 };
            const std::uint32_t dim1265JoeKuoD6Init[]   =   { 1, 3, 5, 13, 1, 17, 97, 37, 81, 645, 1167, 3547, 7769, 10731, 0 };
            const std::uint32_t dim1266JoeKuoD6Init[]   =   { 1, 1, 7, 5, 9, 17, 31, 55, 151, 463, 1041, 2303, 4015, 3737, 0 };
            const std::uint32_t dim1267JoeKuoD6Init[]   =   { 1, 1, 3, 11, 31, 9, 81, 213, 95, 215, 2031, 2129, 4299, 3021, 0 };
            const std::uint32_t dim1268JoeKuoD6Init[]   =   { 1, 1, 1, 3, 25, 25, 115, 229, 101, 441, 783, 1729, 7905, 2375, 0 };
            const std::uint32_t dim1269JoeKuoD6Init[]   =   { 1, 1, 5, 9, 3, 19, 73, 35, 379, 493, 1333, 1647, 13, 197, 0 };
            const std::uint32_t dim1270JoeKuoD6Init[]   =   { 1, 1, 7, 9, 3, 55, 99, 43, 281, 9, 73, 2477, 8183, 11055, 0 };
            const std::uint32_t dim1271JoeKuoD6Init[]   =   { 1, 3, 7, 13, 25, 19, 27, 195, 469, 175, 355, 1861, 7255, 15377, 0 };
            const std::uint32_t dim1272JoeKuoD6Init[]   =   { 1, 1, 3, 11, 15, 19, 115, 31, 413, 835, 697, 879, 6515, 13465, 0 };
            const std::uint32_t dim1273JoeKuoD6Init[]   =   { 1, 3, 3, 15, 3, 61, 105, 201, 151, 739, 49, 3963, 2573, 3303, 0 };
            const std::uint32_t dim1274JoeKuoD6Init[]   =   { 1, 3, 5, 7, 23, 5, 11, 215, 19, 591, 509, 2887, 1631, 4391, 0 };
            const std::uint32_t dim1275JoeKuoD6Init[]   =   { 1, 3, 3, 3, 25, 1, 109, 5, 363, 545, 1745, 503, 827, 4677, 0 };
            const std::uint32_t dim1276JoeKuoD6Init[]   =   { 1, 1, 3, 15, 1, 45, 121, 141, 497, 745, 1825, 2041, 2561, 8153, 0 };
            const std::uint32_t dim1277JoeKuoD6Init[]   =   { 1, 3, 1, 11, 29, 7, 71, 241, 7, 39, 1379, 2479, 7483, 7195, 0 };
            const std::uint32_t dim1278JoeKuoD6Init[]   =   { 1, 1, 7, 11, 3, 27, 39, 97, 339, 217, 1409, 1569, 4761, 1567, 0 };
            const std::uint32_t dim1279JoeKuoD6Init[]   =   { 1, 1, 5, 15, 11, 53, 87, 213, 297, 923, 393, 717, 3297, 16123, 0 };
            const std::uint32_t dim1280JoeKuoD6Init[]   =   { 1, 1, 1, 11, 27, 41, 121, 49, 225, 379, 1305, 319, 2461, 5445, 0 };
            const std::uint32_t dim1281JoeKuoD6Init[]   =   { 1, 1, 5, 5, 25, 3, 121, 23, 47, 843, 1679, 1427, 6393, 4199, 0 };
            const std::uint32_t dim1282JoeKuoD6Init[]   =   { 1, 1, 5, 13, 17, 3, 17, 25, 161, 487, 121, 361, 1375, 10745, 0 };
            const std::uint32_t dim1283JoeKuoD6Init[]   =   { 1, 1, 7, 3, 3, 37, 7, 245, 107, 107, 745, 2415, 2131, 11419, 0 };
            const std::uint32_t dim1284JoeKuoD6Init[]   =   { 1, 1, 5, 3, 3, 23, 67, 91, 281, 387, 465, 905, 883, 9775, 0 };
            const std::uint32_t dim1285JoeKuoD6Init[]   =   { 1, 3, 7, 15, 25, 55, 123, 49, 23, 983, 1903, 2589, 2073, 7823, 0 };
            const std::uint32_t dim1286JoeKuoD6Init[]   =   { 1, 1, 5, 11, 25, 17, 63, 229, 267, 175, 1759, 1947, 479, 11089, 0 };
            const std::uint32_t dim1287JoeKuoD6Init[]   =   { 1, 3, 7, 3, 11, 37, 83, 95, 415, 1003, 1175, 2361, 2117, 9809, 0 };
            const std::uint32_t dim1288JoeKuoD6Init[]   =   { 1, 3, 1, 9, 5, 39, 51, 129, 249, 161, 1981, 2755, 8057, 13641, 0 };
            const std::uint32_t dim1289JoeKuoD6Init[]   =   { 1, 1, 7, 1, 15, 47, 9, 197, 199, 549, 1091, 2853, 2331, 4535, 0 };
            const std::uint32_t dim1290JoeKuoD6Init[]   =   { 1, 3, 3, 13, 15, 21, 23, 111, 463, 719, 1667, 377, 5039, 10723, 0 };
            const std::uint32_t dim1291JoeKuoD6Init[]   =   { 1, 1, 3, 7, 23, 47, 39, 47, 307, 949, 1651, 2525, 5835, 1425, 0 };
            const std::uint32_t dim1292JoeKuoD6Init[]   =   { 1, 3, 3, 9, 23, 47, 111, 39, 251, 1001, 179, 3985, 535, 15435, 0 };
            const std::uint32_t dim1293JoeKuoD6Init[]   =   { 1, 1, 3, 13, 5, 45, 51, 123, 205, 651, 1583, 1691, 1631, 11975, 0 };
            const std::uint32_t dim1294JoeKuoD6Init[]   =   { 1, 1, 7, 9, 1, 29, 59, 27, 389, 497, 1459, 1633, 521, 14037, 0 };
            const std::uint32_t dim1295JoeKuoD6Init[]   =   { 1, 1, 3, 3, 3, 23, 35, 247, 371, 729, 931, 681, 1777, 8353, 0 };
            const std::uint32_t dim1296JoeKuoD6Init[]   =   { 1, 3, 3, 1, 19, 15, 17, 191, 495, 643, 319, 37, 5691, 7049, 0 };
            const std::uint32_t dim1297JoeKuoD6Init[]   =   { 1, 3, 5, 11, 5, 31, 123, 243, 335, 573, 113, 209, 4825, 7783, 0 };
            const std::uint32_t dim1298JoeKuoD6Init[]   =   { 1, 3, 7, 7, 29, 19, 25, 191, 89, 515, 55, 3013, 4523, 12913, 0 };
            const std::uint32_t dim1299JoeKuoD6Init[]   =   { 1, 1, 3, 3, 15, 3, 35, 37, 339, 7, 697, 359, 4553, 1431, 0 };
            const std::uint32_t dim1300JoeKuoD6Init[]   =   { 1, 3, 1, 1, 9, 15, 33, 77, 161, 13, 255, 1187, 6587, 11715, 0 };
            const std::uint32_t dim1301JoeKuoD6Init[]   =   { 1, 3, 7, 7, 25, 57, 61, 171, 231, 43, 1219, 903, 5623, 4781, 0 };
            const std::uint32_t dim1302JoeKuoD6Init[]   =   { 1, 1, 5, 15, 29, 47, 117, 23, 213, 907, 1423, 369, 4529, 9651, 0 };
            const std::uint32_t dim1303JoeKuoD6Init[]   =   { 1, 1, 5, 7, 15, 55, 105, 249, 401, 37, 1885, 3779, 3441, 9057, 0 };
            const std::uint32_t dim1304JoeKuoD6Init[]   =   { 1, 1, 5, 3, 3, 27, 49, 89, 335, 561, 1235, 3251, 2731, 12711, 0 };
            const std::uint32_t dim1305JoeKuoD6Init[]   =   { 1, 1, 1, 15, 29, 49, 37, 173, 25, 743, 1321, 821, 5899, 9213, 0 };
            const std::uint32_t dim1306JoeKuoD6Init[]   =   { 1, 1, 7, 3, 1, 41, 61, 209, 275, 925, 521, 3029, 1569, 9277, 0 };
            const std::uint32_t dim1307JoeKuoD6Init[]   =   { 1, 3, 5, 13, 17, 1, 11, 171, 441, 119, 1589, 299, 157, 11439, 0 };
            const std::uint32_t dim1308JoeKuoD6Init[]   =   { 1, 1, 5, 9, 13, 33, 27, 77, 363, 939, 1103, 2135, 1759, 5429, 0 };
            const std::uint32_t dim1309JoeKuoD6Init[]   =   { 1, 3, 7, 1, 17, 39, 49, 201, 49, 803, 2003, 1193, 7415, 13847, 0 };
            const std::uint32_t dim1310JoeKuoD6Init[]   =   { 1, 1, 5, 5, 17, 49, 39, 19, 311, 801, 1441, 3263, 7973, 14181, 0 };
            const std::uint32_t dim1311JoeKuoD6Init[]   =   { 1, 1, 3, 9, 9, 27, 59, 89, 81, 473, 1369, 3121, 7929, 10905, 0 };
            const std::uint32_t dim1312JoeKuoD6Init[]   =   { 1, 3, 3, 5, 17, 35, 35, 239, 379, 431, 501, 3561, 2059, 9679, 0 };
            const std::uint32_t dim1313JoeKuoD6Init[]   =   { 1, 3, 5, 15, 25, 29, 113, 179, 269, 891, 301, 2017, 7513, 9379, 0 };
            const std::uint32_t dim1314JoeKuoD6Init[]   =   { 1, 3, 1, 11, 17, 35, 49, 149, 135, 661, 1691, 3169, 3765, 9003, 0 };
            const std::uint32_t dim1315JoeKuoD6Init[]   =   { 1, 3, 7, 15, 5, 21, 53, 241, 475, 271, 683, 2351, 2181, 6333, 0 };
            const std::uint32_t dim1316JoeKuoD6Init[]   =   { 1, 1, 7, 13, 25, 33, 71, 153, 221, 507, 2017, 2401, 7545, 8489, 0 };
            const std::uint32_t dim1317JoeKuoD6Init[]   =   { 1, 1, 7, 5, 1, 49, 87, 1, 179, 331, 1597, 3713, 809, 11109, 0 };
            const std::uint32_t dim1318JoeKuoD6Init[]   =   { 1, 3, 1, 5, 5, 61, 93, 39, 479, 977, 1099, 1291, 7049, 2797, 0 };
            const std::uint32_t dim1319JoeKuoD6Init[]   =   { 1, 3, 1, 13, 19, 41, 57, 77, 5, 117, 125, 115, 3969, 1345, 0 };
            const std::uint32_t dim1320JoeKuoD6Init[]   =   { 1, 1, 1, 9, 15, 9, 57, 7, 219, 41, 767, 23, 5771, 14175, 0 };
            const std::uint32_t dim1321JoeKuoD6Init[]   =   { 1, 3, 7, 9, 17, 61, 1, 59, 227, 349, 63, 189, 3871, 7919, 0 };
            const std::uint32_t dim1322JoeKuoD6Init[]   =   { 1, 3, 5, 5, 9, 29, 33, 203, 413, 701, 1129, 2103, 1889, 8377, 0 };
            const std::uint32_t dim1323JoeKuoD6Init[]   =   { 1, 1, 3, 1, 9, 17, 69, 115, 123, 1001, 1, 2893, 3957, 8593, 0 };
            const std::uint32_t dim1324JoeKuoD6Init[]   =   { 1, 1, 3, 1, 31, 41, 83, 91, 113, 195, 1121, 2665, 6815, 1189, 0 };
            const std::uint32_t dim1325JoeKuoD6Init[]   =   { 1, 1, 1, 13, 3, 59, 13, 123, 95, 103, 1689, 2809, 5049, 4055, 0 };
            const std::uint32_t dim1326JoeKuoD6Init[]   =   { 1, 1, 1, 15, 21, 41, 11, 167, 375, 589, 207, 1631, 1597, 8091, 0 };
            const std::uint32_t dim1327JoeKuoD6Init[]   =   { 1, 3, 5, 5, 1, 33, 57, 89, 157, 921, 1353, 2777, 461, 14567, 0 };
            const std::uint32_t dim1328JoeKuoD6Init[]   =   { 1, 1, 5, 1, 25, 5, 51, 247, 1, 577, 463, 3741, 303, 16059, 0 };
            const std::uint32_t dim1329JoeKuoD6Init[]   =   { 1, 1, 7, 5, 13, 7, 17, 87, 51, 987, 835, 93, 5203, 3973, 0 };
            const std::uint32_t dim1330JoeKuoD6Init[]   =   { 1, 1, 7, 7, 3, 27, 7, 1, 135, 171, 231, 3349, 4459, 2925, 0 };
            const std::uint32_t dim1331JoeKuoD6Init[]   =   { 1, 1, 5, 5, 9, 51, 71, 153, 115, 315, 265, 2207, 4127, 12631, 0 };
            const std::uint32_t dim1332JoeKuoD6Init[]   =   { 1, 1, 3, 15, 23, 59, 35, 121, 425, 921, 1255, 2123, 5811, 15937, 0 };
            const std::uint32_t dim1333JoeKuoD6Init[]   =   { 1, 3, 7, 7, 11, 21, 45, 57, 269, 395, 555, 783, 6677, 2889, 0 };
            const std::uint32_t dim1334JoeKuoD6Init[]   =   { 1, 3, 5, 7, 31, 19, 73, 35, 465, 349, 1429, 863, 4707, 6121, 0 };
            const std::uint32_t dim1335JoeKuoD6Init[]   =   { 1, 3, 3, 9, 25, 27, 119, 159, 195, 949, 19, 73, 4511, 15711, 0 };
            const std::uint32_t dim1336JoeKuoD6Init[]   =   { 1, 3, 3, 7, 9, 59, 47, 57, 91, 749, 1579, 1297, 2445, 5167, 0 };
            const std::uint32_t dim1337JoeKuoD6Init[]   =   { 1, 3, 3, 3, 31, 57, 19, 203, 61, 927, 1477, 2863, 1305, 11673, 0 };
            const std::uint32_t dim1338JoeKuoD6Init[]   =   { 1, 3, 7, 11, 29, 13, 3, 111, 351, 79, 1863, 2213, 3273, 7049, 0 };
            const std::uint32_t dim1339JoeKuoD6Init[]   =   { 1, 3, 3, 9, 7, 23, 47, 237, 121, 877, 441, 119, 2723, 3989, 0 };
            const std::uint32_t dim1340JoeKuoD6Init[]   =   { 1, 3, 3, 11, 17, 23, 63, 177, 231, 363, 1451, 33, 2169, 7251, 0 };
            const std::uint32_t dim1341JoeKuoD6Init[]   =   { 1, 1, 5, 11, 31, 41, 93, 229, 39, 1009, 1061, 433, 2393, 15401, 0 };
            const std::uint32_t dim1342JoeKuoD6Init[]   =   { 1, 1, 5, 15, 31, 37, 25, 135, 135, 897, 33, 3713, 7663, 8079, 0 };
            const std::uint32_t dim1343JoeKuoD6Init[]   =   { 1, 1, 5, 7, 17, 49, 43, 89, 411, 731, 1431, 3893, 1635, 7063, 0 };
            const std::uint32_t dim1344JoeKuoD6Init[]   =   { 1, 1, 1, 13, 29, 27, 5, 77, 283, 913, 789, 817, 3309, 475, 0 };
            const std::uint32_t dim1345JoeKuoD6Init[]   =   { 1, 1, 3, 1, 19, 21, 67, 77, 423, 551, 5, 1057, 5469, 7859, 0 };
            const std::uint32_t dim1346JoeKuoD6Init[]   =   { 1, 1, 5, 1, 1, 21, 99, 237, 215, 759, 1505, 1983, 1517, 8923, 0 };
            const std::uint32_t dim1347JoeKuoD6Init[]   =   { 1, 3, 5, 7, 19, 61, 73, 215, 165, 127, 205, 259, 7755, 15395, 0 };
            const std::uint32_t dim1348JoeKuoD6Init[]   =   { 1, 1, 5, 9, 15, 23, 17, 111, 471, 751, 1923, 775, 6901, 13095, 0 };
            const std::uint32_t dim1349JoeKuoD6Init[]   =   { 1, 1, 7, 1, 25, 5, 63, 141, 461, 687, 1589, 1559, 7719, 11349, 0 };
            const std::uint32_t dim1350JoeKuoD6Init[]   =   { 1, 1, 1, 3, 11, 63, 11, 27, 253, 439, 297, 1315, 829, 3765, 0 };
            const std::uint32_t dim1351JoeKuoD6Init[]   =   { 1, 3, 1, 1, 9, 47, 127, 179, 173, 809, 241, 35, 7355, 5049, 0 };
            const std::uint32_t dim1352JoeKuoD6Init[]   =   { 1, 3, 1, 11, 19, 63, 93, 1, 205, 977, 303, 3409, 6529, 10927, 0 };
            const std::uint32_t dim1353JoeKuoD6Init[]   =   { 1, 3, 7, 9, 31, 63, 41, 79, 477, 91, 1801, 3487, 6885, 13341, 0 };
            const std::uint32_t dim1354JoeKuoD6Init[]   =   { 1, 1, 3, 7, 15, 59, 9, 101, 459, 247, 549, 2855, 5765, 7785, 0 };
            const std::uint32_t dim1355JoeKuoD6Init[]   =   { 1, 1, 7, 3, 13, 59, 71, 123, 93, 517, 1453, 2389, 4429, 5053, 0 };
            const std::uint32_t dim1356JoeKuoD6Init[]   =   { 1, 1, 5, 3, 19, 21, 77, 53, 81, 879, 1653, 1637, 3667, 2623, 0 };
            const std::uint32_t dim1357JoeKuoD6Init[]   =   { 1, 1, 1, 15, 17, 57, 65, 53, 407, 765, 417, 497, 5009, 2175, 0 };
            const std::uint32_t dim1358JoeKuoD6Init[]   =   { 1, 3, 3, 7, 31, 13, 5, 203, 263, 17, 119, 1607, 6773, 11195, 0 };
            const std::uint32_t dim1359JoeKuoD6Init[]   =   { 1, 3, 3, 13, 19, 13, 13, 147, 93, 735, 689, 781, 655, 6853, 0 };
            const std::uint32_t dim1360JoeKuoD6Init[]   =   { 1, 1, 1, 1, 1, 25, 63, 159, 493, 987, 71, 1249, 5859, 11717, 0 };
            const std::uint32_t dim1361JoeKuoD6Init[]   =   { 1, 1, 1, 15, 13, 23, 61, 61, 5, 947, 1853, 3331, 467, 8081, 0 };
            const std::uint32_t dim1362JoeKuoD6Init[]   =   { 1, 1, 3, 9, 19, 61, 65, 189, 95, 309, 283, 1725, 5683, 15463, 0 };
            const std::uint32_t dim1363JoeKuoD6Init[]   =   { 1, 1, 7, 5, 9, 33, 35, 75, 475, 831, 1445, 1485, 5047, 9631, 0 };
            const std::uint32_t dim1364JoeKuoD6Init[]   =   { 1, 1, 3, 15, 11, 23, 59, 87, 433, 221, 685, 3113, 4095, 13819, 0 };
            const std::uint32_t dim1365JoeKuoD6Init[]   =   { 1, 1, 7, 15, 25, 29, 67, 17, 349, 353, 1321, 563, 57, 533, 0 };
            const std::uint32_t dim1366JoeKuoD6Init[]   =   { 1, 3, 3, 3, 5, 43, 109, 217, 15, 185, 1895, 1015, 1831, 10623, 0 };
            const std::uint32_t dim1367JoeKuoD6Init[]   =   { 1, 1, 7, 1, 1, 47, 81, 185, 59, 691, 191, 3709, 1535, 13347, 0 };
            const std::uint32_t dim1368JoeKuoD6Init[]   =   { 1, 1, 5, 1, 23, 57, 83, 217, 457, 771, 1877, 2789, 8143, 4797, 0 };
            const std::uint32_t dim1369JoeKuoD6Init[]   =   { 1, 1, 3, 7, 23, 35, 79, 49, 227, 205, 1523, 3873, 4843, 10505, 0 };
            const std::uint32_t dim1370JoeKuoD6Init[]   =   { 1, 1, 1, 1, 17, 43, 121, 95, 205, 35, 189, 2061, 1693, 13273, 0 };
            const std::uint32_t dim1371JoeKuoD6Init[]   =   { 1, 1, 1, 15, 31, 49, 83, 249, 433, 497, 1949, 1845, 5215, 5971, 0 };
            const std::uint32_t dim1372JoeKuoD6Init[]   =   { 1, 3, 1, 1, 21, 53, 73, 211, 265, 929, 923, 279, 3621, 9469, 0 };
            const std::uint32_t dim1373JoeKuoD6Init[]   =   { 1, 3, 7, 7, 1, 57, 13, 45, 467, 705, 371, 1345, 1647, 3411, 0 };
            const std::uint32_t dim1374JoeKuoD6Init[]   =   { 1, 3, 1, 11, 27, 29, 117, 163, 143, 669, 489, 3913, 7891, 9031, 0 };
            const std::uint32_t dim1375JoeKuoD6Init[]   =   { 1, 3, 7, 15, 27, 15, 77, 217, 107, 839, 1517, 1543, 357, 10365, 0 };
            const std::uint32_t dim1376JoeKuoD6Init[]   =   { 1, 1, 1, 5, 31, 17, 107, 245, 345, 939, 1453, 3645, 6865, 16173, 0 };
            const std::uint32_t dim1377JoeKuoD6Init[]   =   { 1, 3, 5, 5, 9, 61, 43, 97, 453, 917, 945, 2143, 5473, 5611, 0 };
            const std::uint32_t dim1378JoeKuoD6Init[]   =   { 1, 1, 5, 11, 3, 33, 71, 97, 137, 549, 1605, 3839, 4883, 2677, 0 };
            const std::uint32_t dim1379JoeKuoD6Init[]   =   { 1, 3, 1, 11, 29, 23, 85, 47, 225, 633, 1613, 1297, 1415, 15813, 0 };
            const std::uint32_t dim1380JoeKuoD6Init[]   =   { 1, 1, 3, 3, 9, 19, 57, 107, 79, 449, 1951, 753, 6317, 10377, 0 };
            const std::uint32_t dim1381JoeKuoD6Init[]   =   { 1, 1, 1, 5, 21, 3, 39, 187, 299, 517, 1313, 741, 7259, 4197, 0 };
            const std::uint32_t dim1382JoeKuoD6Init[]   =   { 1, 1, 5, 13, 1, 39, 39, 41, 381, 123, 1257, 3185, 493, 3723, 0 };
            const std::uint32_t dim1383JoeKuoD6Init[]   =   { 1, 3, 7, 7, 3, 37, 15, 161, 129, 169, 555, 3605, 4287, 15831, 0 };
            const std::uint32_t dim1384JoeKuoD6Init[]   =   { 1, 3, 7, 15, 15, 23, 81, 163, 257, 791, 505, 1903, 2703, 11919, 0 };
            const std::uint32_t dim1385JoeKuoD6Init[]   =   { 1, 3, 7, 7, 27, 63, 17, 147, 111, 851, 1533, 1365, 5359, 3315, 0 };
            const std::uint32_t dim1386JoeKuoD6Init[]   =   { 1, 3, 7, 1, 15, 5, 61, 143, 385, 261, 1019, 1705, 1737, 14485, 0 };
            const std::uint32_t dim1387JoeKuoD6Init[]   =   { 1, 3, 5, 5, 25, 17, 49, 229, 431, 567, 1613, 3431, 2139, 2981, 0 };
            const std::uint32_t dim1388JoeKuoD6Init[]   =   { 1, 3, 5, 11, 17, 57, 71, 241, 31, 1007, 1695, 2965, 149, 14125, 0 };
            const std::uint32_t dim1389JoeKuoD6Init[]   =   { 1, 1, 3, 11, 7, 49, 39, 101, 5, 501, 1491, 3061, 225, 12255, 0 };
            const std::uint32_t dim1390JoeKuoD6Init[]   =   { 1, 3, 5, 7, 17, 35, 37, 97, 415, 15, 1349, 997, 2949, 4511, 0 };
            const std::uint32_t dim1391JoeKuoD6Init[]   =   { 1, 3, 1, 5, 25, 35, 99, 183, 161, 59, 1363, 515, 3767, 3641, 0 };
            const std::uint32_t dim1392JoeKuoD6Init[]   =   { 1, 1, 7, 15, 7, 15, 127, 137, 281, 67, 139, 2315, 3517, 13371, 0 };
            const std::uint32_t dim1393JoeKuoD6Init[]   =   { 1, 1, 5, 15, 23, 49, 19, 79, 425, 805, 1035, 429, 7707, 14195, 0 };
            const std::uint32_t dim1394JoeKuoD6Init[]   =   { 1, 3, 5, 3, 21, 25, 123, 11, 425, 475, 961, 2995, 7405, 5449, 0 };
            const std::uint32_t dim1395JoeKuoD6Init[]   =   { 1, 1, 7, 1, 21, 1, 75, 231, 451, 595, 719, 2369, 5907, 1227, 0 };
            const std::uint32_t dim1396JoeKuoD6Init[]   =   { 1, 1, 1, 9, 21, 57, 45, 255, 19, 79, 481, 3363, 3451, 8399, 0 };
            const std::uint32_t dim1397JoeKuoD6Init[]   =   { 1, 1, 7, 13, 31, 49, 95, 69, 483, 427, 37, 4047, 7057, 9111, 0 };
            const std::uint32_t dim1398JoeKuoD6Init[]   =   { 1, 3, 3, 11, 3, 61, 87, 79, 499, 91, 771, 1987, 2017, 3381, 0 };
            const std::uint32_t dim1399JoeKuoD6Init[]   =   { 1, 3, 1, 7, 5, 57, 1, 121, 155, 225, 501, 477, 6555, 9863, 0 };
            const std::uint32_t dim1400JoeKuoD6Init[]   =   { 1, 3, 7, 11, 27, 49, 83, 213, 61, 283, 1599, 3205, 2525, 8553, 0 };
            const std::uint32_t dim1401JoeKuoD6Init[]   =   { 1, 1, 1, 9, 9, 49, 3, 51, 141, 33, 301, 2167, 587, 15067, 0 };
            const std::uint32_t dim1402JoeKuoD6Init[]   =   { 1, 1, 1, 11, 7, 55, 99, 81, 191, 553, 953, 3753, 6731, 1093, 0 };
            const std::uint32_t dim1403JoeKuoD6Init[]   =   { 1, 1, 3, 3, 11, 59, 57, 235, 297, 197, 853, 1411, 3799, 7527, 0 };
            const std::uint32_t dim1404JoeKuoD6Init[]   =   { 1, 3, 5, 3, 7, 7, 5, 201, 393, 95, 91, 3273, 6285, 10661, 0 };
            const std::uint32_t dim1405JoeKuoD6Init[]   =   { 1, 1, 5, 7, 17, 57, 87, 3, 413, 915, 659, 369, 3593, 14429, 0 };
            const std::uint32_t dim1406JoeKuoD6Init[]   =   { 1, 3, 7, 1, 31, 31, 45, 115, 417, 427, 745, 4087, 953, 1119, 0 };
            const std::uint32_t dim1407JoeKuoD6Init[]   =   { 1, 3, 7, 3, 29, 43, 45, 221, 41, 641, 451, 173, 2999, 12103, 0 };
            const std::uint32_t dim1408JoeKuoD6Init[]   =   { 1, 1, 3, 11, 25, 57, 117, 201, 135, 787, 1525, 3879, 3247, 8907, 0 };
            const std::uint32_t dim1409JoeKuoD6Init[]   =   { 1, 1, 7, 11, 3, 35, 69, 157, 331, 615, 573, 2169, 3575, 289, 0 };
            const std::uint32_t dim1410JoeKuoD6Init[]   =   { 1, 3, 3, 13, 15, 51, 67, 127, 265, 495, 103, 3145, 2685, 15919, 0 };
            const std::uint32_t dim1411JoeKuoD6Init[]   =   { 1, 3, 5, 11, 31, 27, 65, 57, 153, 465, 1163, 467, 4103, 4713, 0 };
            const std::uint32_t dim1412JoeKuoD6Init[]   =   { 1, 3, 7, 3, 23, 31, 9, 51, 239, 417, 1597, 229, 2865, 15199, 0 };
            const std::uint32_t dim1413JoeKuoD6Init[]   =   { 1, 3, 5, 3, 11, 45, 123, 217, 31, 765, 1009, 2001, 3645, 9407, 0 };
            const std::uint32_t dim1414JoeKuoD6Init[]   =   { 1, 3, 3, 9, 5, 23, 117, 83, 237, 1017, 251, 1187, 2631, 5151, 0 };
            const std::uint32_t dim1415JoeKuoD6Init[]   =   { 1, 1, 1, 7, 23, 55, 97, 141, 501, 305, 467, 4061, 2369, 15973, 0 };
            const std::uint32_t dim1416JoeKuoD6Init[]   =   { 1, 1, 7, 5, 31, 51, 125, 191, 219, 495, 37, 3337, 813, 241, 0 };
            const std::uint32_t dim1417JoeKuoD6Init[]   =   { 1, 3, 1, 1, 11, 39, 93, 109, 285, 147, 1297, 737, 4051, 7223, 0 };
            const std::uint32_t dim1418JoeKuoD6Init[]   =   { 1, 3, 1, 15, 13, 17, 57, 171, 463, 163, 609, 1681, 7583, 9231, 0 };
            const std::uint32_t dim1419JoeKuoD6Init[]   =   { 1, 3, 1, 1, 23, 5, 51, 5, 205, 415, 419, 989, 4239, 10943, 0 };
            const std::uint32_t dim1420JoeKuoD6Init[]   =   { 1, 1, 3, 15, 3, 13, 65, 145, 387, 59, 395, 1067, 4143, 5649, 0 };
            const std::uint32_t dim1421JoeKuoD6Init[]   =   { 1, 3, 1, 13, 9, 59, 121, 127, 95, 71, 1541, 1423, 1753, 8041, 0 };
            const std::uint32_t dim1422JoeKuoD6Init[]   =   { 1, 1, 3, 15, 7, 5, 69, 167, 181, 991, 1189, 4017, 5935, 6669, 0 };
            const std::uint32_t dim1423JoeKuoD6Init[]   =   { 1, 3, 5, 7, 23, 41, 53, 21, 47, 261, 1231, 2011, 133, 2247, 0 };
            const std::uint32_t dim1424JoeKuoD6Init[]   =   { 1, 1, 1, 5, 17, 47, 77, 19, 331, 609, 1893, 3965, 3123, 9093, 0 };
            const std::uint32_t dim1425JoeKuoD6Init[]   =   { 1, 3, 1, 3, 9, 39, 103, 231, 249, 75, 373, 107, 1823, 10801, 0 };
            const std::uint32_t dim1426JoeKuoD6Init[]   =   { 1, 3, 3, 7, 1, 51, 35, 111, 137, 879, 1221, 225, 4285, 2287, 0 };
            const std::uint32_t dim1427JoeKuoD6Init[]   =   { 1, 1, 7, 9, 23, 17, 75, 245, 409, 163, 395, 3731, 7111, 6845, 0 };
            const std::uint32_t dim1428JoeKuoD6Init[]   =   { 1, 1, 3, 13, 29, 47, 75, 153, 497, 621, 1691, 3187, 2125, 10533, 0 };
            const std::uint32_t dim1429JoeKuoD6Init[]   =   { 1, 1, 7, 7, 9, 7, 55, 159, 255, 417, 1335, 643, 3843, 3733, 0 };
            const std::uint32_t dim1430JoeKuoD6Init[]   =   { 1, 3, 3, 1, 21, 41, 7, 21, 5, 679, 1655, 95, 5699, 5785, 0 };
            const std::uint32_t dim1431JoeKuoD6Init[]   =   { 1, 1, 1, 13, 19, 7, 85, 7, 195, 357, 1097, 2893, 2913, 9635, 0 };
            const std::uint32_t dim1432JoeKuoD6Init[]   =   { 1, 1, 5, 9, 25, 33, 41, 155, 39, 655, 1993, 3117, 3639, 7977, 0 };
            const std::uint32_t dim1433JoeKuoD6Init[]   =   { 1, 1, 1, 13, 3, 63, 121, 247, 151, 673, 609, 285, 2299, 7663, 0 };
            const std::uint32_t dim1434JoeKuoD6Init[]   =   { 1, 3, 7, 11, 17, 13, 49, 253, 245, 21, 273, 993, 911, 863, 0 };
            const std::uint32_t dim1435JoeKuoD6Init[]   =   { 1, 1, 5, 5, 23, 1, 121, 95, 225, 9, 1237, 1183, 6461, 559, 0 };
            const std::uint32_t dim1436JoeKuoD6Init[]   =   { 1, 3, 7, 13, 3, 7, 121, 151, 233, 561, 281, 3583, 897, 1767, 0 };
            const std::uint32_t dim1437JoeKuoD6Init[]   =   { 1, 1, 7, 7, 9, 47, 107, 41, 25, 569, 1697, 2299, 6231, 12209, 0 };
            const std::uint32_t dim1438JoeKuoD6Init[]   =   { 1, 3, 7, 7, 27, 43, 59, 37, 31, 51, 503, 149, 4043, 11847, 0 };
            const std::uint32_t dim1439JoeKuoD6Init[]   =   { 1, 3, 3, 11, 5, 1, 119, 181, 47, 641, 685, 4017, 637, 16251, 0 };
            const std::uint32_t dim1440JoeKuoD6Init[]   =   { 1, 3, 3, 7, 11, 1, 101, 7, 239, 747, 307, 1721, 5979, 4367, 0 };
            const std::uint32_t dim1441JoeKuoD6Init[]   =   { 1, 3, 5, 7, 1, 63, 19, 151, 469, 333, 1587, 2453, 897, 4711, 0 };
            const std::uint32_t dim1442JoeKuoD6Init[]   =   { 1, 3, 1, 5, 11, 61, 21, 253, 91, 993, 1347, 1993, 5607, 13031, 0 };
            const std::uint32_t dim1443JoeKuoD6Init[]   =   { 1, 3, 5, 5, 1, 39, 65, 71, 189, 389, 1437, 1055, 6439, 3989, 0 };
            const std::uint32_t dim1444JoeKuoD6Init[]   =   { 1, 1, 3, 3, 19, 15, 93, 3, 339, 165, 1675, 3953, 2145, 12113, 0 };
            const std::uint32_t dim1445JoeKuoD6Init[]   =   { 1, 1, 3, 13, 13, 45, 5, 175, 211, 993, 705, 2761, 3023, 13633, 0 };
            const std::uint32_t dim1446JoeKuoD6Init[]   =   { 1, 1, 3, 1, 19, 39, 121, 29, 287, 87, 281, 3491, 7107, 13007, 0 };
            const std::uint32_t dim1447JoeKuoD6Init[]   =   { 1, 1, 7, 1, 29, 49, 103, 187, 39, 923, 51, 1533, 3249, 4399, 0 };
            const std::uint32_t dim1448JoeKuoD6Init[]   =   { 1, 1, 5, 5, 5, 43, 25, 107, 453, 955, 115, 57, 4589, 14573, 0 };
            const std::uint32_t dim1449JoeKuoD6Init[]   =   { 1, 1, 3, 5, 21, 45, 103, 99, 183, 987, 1207, 1697, 8033, 13703, 0 };
            const std::uint32_t dim1450JoeKuoD6Init[]   =   { 1, 1, 5, 7, 11, 23, 9, 17, 261, 749, 1957, 935, 6283, 8625, 0 };
            const std::uint32_t dim1451JoeKuoD6Init[]   =   { 1, 1, 1, 9, 9, 51, 69, 225, 265, 323, 1161, 2993, 7305, 2249, 0 };
            const std::uint32_t dim1452JoeKuoD6Init[]   =   { 1, 3, 1, 9, 23, 19, 57, 205, 503, 489, 1499, 3277, 817, 11931, 0 };
            const std::uint32_t dim1453JoeKuoD6Init[]   =   { 1, 3, 3, 5, 1, 7, 49, 1, 313, 123, 643, 2027, 1469, 3585, 0 };
            const std::uint32_t dim1454JoeKuoD6Init[]   =   { 1, 3, 7, 11, 27, 47, 95, 111, 27, 213, 465, 3693, 3661, 7531, 0 };
            const std::uint32_t dim1455JoeKuoD6Init[]   =   { 1, 1, 7, 9, 3, 37, 115, 189, 31, 613, 1393, 1229, 4767, 12425, 0 };
            const std::uint32_t dim1456JoeKuoD6Init[]   =   { 1, 1, 3, 3, 25, 17, 99, 47, 161, 931, 959, 1293, 7095, 8325, 0 };
            const std::uint32_t dim1457JoeKuoD6Init[]   =   { 1, 1, 1, 7, 23, 9, 11, 51, 205, 419, 479, 1497, 2493, 13921, 0 };
            const std::uint32_t dim1458JoeKuoD6Init[]   =   { 1, 3, 1, 9, 17, 29, 51, 79, 159, 435, 477, 413, 3815, 5589, 0 };
            const std::uint32_t dim1459JoeKuoD6Init[]   =   { 1, 3, 7, 5, 7, 23, 99, 43, 169, 665, 403, 1163, 4337, 1335, 0 };
            const std::uint32_t dim1460JoeKuoD6Init[]   =   { 1, 3, 1, 5, 25, 27, 125, 249, 421, 267, 1259, 4089, 59, 9377, 0 };
            const std::uint32_t dim1461JoeKuoD6Init[]   =   { 1, 3, 3, 1, 27, 37, 91, 17, 123, 597, 1749, 3449, 6503, 11043, 0 };
            const std::uint32_t dim1462JoeKuoD6Init[]   =   { 1, 3, 7, 7, 23, 41, 19, 245, 109, 569, 547, 1917, 7943, 2697, 0 };
            const std::uint32_t dim1463JoeKuoD6Init[]   =   { 1, 3, 7, 7, 9, 1, 123, 105, 329, 435, 2013, 2745, 347, 11045, 0 };
            const std::uint32_t dim1464JoeKuoD6Init[]   =   { 1, 1, 1, 13, 29, 53, 51, 67, 105, 89, 1887, 3543, 963, 8159, 0 };
            const std::uint32_t dim1465JoeKuoD6Init[]   =   { 1, 1, 5, 3, 5, 27, 41, 67, 67, 883, 973, 1785, 901, 14969, 0 };
            const std::uint32_t dim1466JoeKuoD6Init[]   =   { 1, 3, 3, 13, 17, 11, 117, 115, 163, 939, 79, 641, 4365, 2267, 0 };
            const std::uint32_t dim1467JoeKuoD6Init[]   =   { 1, 1, 3, 3, 9, 5, 41, 123, 149, 9, 1533, 3939, 5995, 12701, 0 };
            const std::uint32_t dim1468JoeKuoD6Init[]   =   { 1, 1, 1, 15, 31, 1, 101, 229, 191, 965, 61, 2671, 4177, 15779, 0 };
            const std::uint32_t dim1469JoeKuoD6Init[]   =   { 1, 1, 5, 15, 1, 25, 49, 185, 33, 697, 1043, 2639, 7819, 3171, 0 };
            const std::uint32_t dim1470JoeKuoD6Init[]   =   { 1, 3, 5, 13, 19, 9, 111, 49, 47, 847, 1865, 717, 5287, 13417, 0 };
            const std::uint32_t dim1471JoeKuoD6Init[]   =   { 1, 3, 7, 11, 5, 61, 63, 111, 171, 735, 2003, 73, 5701, 647, 0 };
            const std::uint32_t dim1472JoeKuoD6Init[]   =   { 1, 3, 1, 11, 1, 49, 121, 79, 431, 671, 1241, 1161, 2057, 263, 0 };
            const std::uint32_t dim1473JoeKuoD6Init[]   =   { 1, 3, 3, 1, 1, 23, 75, 15, 117, 641, 313, 1525, 2041, 1409, 0 };
            const std::uint32_t dim1474JoeKuoD6Init[]   =   { 1, 3, 5, 11, 15, 57, 13, 67, 139, 131, 1339, 2419, 7945, 11877, 0 };
            const std::uint32_t dim1475JoeKuoD6Init[]   =   { 1, 3, 1, 1, 19, 39, 97, 83, 297, 595, 1611, 5, 4753, 3435, 0 };
            const std::uint32_t dim1476JoeKuoD6Init[]   =   { 1, 3, 1, 9, 7, 49, 125, 101, 383, 717, 63, 2295, 3873, 13461, 0 };
            const std::uint32_t dim1477JoeKuoD6Init[]   =   { 1, 1, 3, 3, 15, 29, 89, 77, 269, 689, 229, 1207, 7311, 8663, 0 };
            const std::uint32_t dim1478JoeKuoD6Init[]   =   { 1, 1, 1, 1, 1, 61, 25, 255, 203, 233, 271, 987, 2277, 8735, 0 };
            const std::uint32_t dim1479JoeKuoD6Init[]   =   { 1, 1, 5, 7, 21, 27, 63, 79, 337, 133, 1453, 3633, 6157, 15875, 0 };
            const std::uint32_t dim1480JoeKuoD6Init[]   =   { 1, 3, 1, 7, 7, 55, 31, 81, 203, 709, 1743, 1677, 4247, 11411, 0 };
            const std::uint32_t dim1481JoeKuoD6Init[]   =   { 1, 1, 3, 3, 29, 51, 37, 17, 487, 325, 1393, 1433, 3467, 2851, 0 };
            const std::uint32_t dim1482JoeKuoD6Init[]   =   { 1, 1, 7, 9, 3, 41, 99, 177, 241, 869, 739, 2729, 4585, 14801, 0 };
            const std::uint32_t dim1483JoeKuoD6Init[]   =   { 1, 1, 3, 1, 9, 43, 97, 65, 99, 295, 1693, 2083, 3241, 4073, 0 };
            const std::uint32_t dim1484JoeKuoD6Init[]   =   { 1, 1, 1, 9, 5, 39, 67, 119, 235, 543, 795, 2773, 3195, 6273, 0 };
            const std::uint32_t dim1485JoeKuoD6Init[]   =   { 1, 1, 5, 5, 21, 41, 89, 1, 85, 81, 57, 2951, 1531, 10101, 0 };
            const std::uint32_t dim1486JoeKuoD6Init[]   =   { 1, 1, 1, 7, 3, 35, 127, 69, 39, 265, 1643, 2973, 267, 12365, 0 };
            const std::uint32_t dim1487JoeKuoD6Init[]   =   { 1, 3, 1, 1, 21, 57, 99, 205, 119, 477, 1771, 1989, 2761, 12573, 0 };
            const std::uint32_t dim1488JoeKuoD6Init[]   =   { 1, 1, 3, 13, 1, 59, 93, 125, 279, 935, 1877, 2061, 4845, 7835, 0 };
            const std::uint32_t dim1489JoeKuoD6Init[]   =   { 1, 1, 7, 9, 7, 45, 69, 99, 273, 35, 1579, 2137, 7175, 6999, 0 };
            const std::uint32_t dim1490JoeKuoD6Init[]   =   { 1, 1, 7, 7, 29, 21, 127, 91, 9, 383, 787, 1783, 601, 5047, 0 };
            const std::uint32_t dim1491JoeKuoD6Init[]   =   { 1, 1, 7, 13, 7, 29, 35, 219, 43, 581, 2043, 2211, 6169, 12173, 0 };
            const std::uint32_t dim1492JoeKuoD6Init[]   =   { 1, 3, 5, 13, 29, 29, 39, 63, 411, 645, 415, 2383, 1989, 11411, 0 };
            const std::uint32_t dim1493JoeKuoD6Init[]   =   { 1, 1, 7, 9, 15, 9, 87, 95, 321, 709, 543, 3831, 2453, 4167, 0 };
            const std::uint32_t dim1494JoeKuoD6Init[]   =   { 1, 3, 1, 5, 31, 25, 5, 85, 239, 487, 1613, 3937, 4661, 3535, 0 };
            const std::uint32_t dim1495JoeKuoD6Init[]   =   { 1, 3, 5, 11, 27, 41, 3, 201, 39, 91, 1997, 237, 5639, 14703, 0 };
            const std::uint32_t dim1496JoeKuoD6Init[]   =   { 1, 1, 7, 3, 27, 49, 87, 71, 473, 247, 1007, 47, 475, 5413, 0 };
            const std::uint32_t dim1497JoeKuoD6Init[]   =   { 1, 3, 7, 15, 9, 57, 81, 149, 287, 333, 1911, 3417, 1081, 8995, 0 };
            const std::uint32_t dim1498JoeKuoD6Init[]   =   { 1, 1, 5, 1, 3, 63, 43, 151, 97, 431, 961, 1019, 5153, 2407, 0 };
            const std::uint32_t dim1499JoeKuoD6Init[]   =   { 1, 1, 5, 5, 27, 21, 127, 161, 507, 311, 129, 3489, 1133, 3241, 0 };
            const std::uint32_t dim1500JoeKuoD6Init[]   =   { 1, 3, 7, 15, 21, 33, 117, 83, 497, 667, 1399, 931, 1695, 8171, 0 };
            const std::uint32_t dim1501JoeKuoD6Init[]   =   { 1, 1, 1, 13, 3, 39, 53, 27, 193, 993, 671, 1871, 7579, 11457, 0 };
            const std::uint32_t dim1502JoeKuoD6Init[]   =   { 1, 1, 5, 11, 7, 39, 81, 107, 195, 387, 849, 395, 1317, 6487, 0 };
            const std::uint32_t dim1503JoeKuoD6Init[]   =   { 1, 3, 3, 3, 3, 15, 45, 127, 279, 111, 331, 357, 4637, 4697, 0 };
            const std::uint32_t dim1504JoeKuoD6Init[]   =   { 1, 1, 3, 9, 21, 49, 47, 97, 61, 101, 181, 1867, 1201, 14099, 0 };
            const std::uint32_t dim1505JoeKuoD6Init[]   =   { 1, 1, 5, 11, 25, 19, 51, 51, 101, 451, 545, 101, 7497, 9141, 0 };
            const std::uint32_t dim1506JoeKuoD6Init[]   =   { 1, 1, 1, 3, 13, 53, 119, 81, 377, 245, 765, 251, 3757, 16045, 0 };
            const std::uint32_t dim1507JoeKuoD6Init[]   =   { 1, 1, 1, 3, 5, 61, 65, 37, 331, 925, 1439, 3219, 2843, 11397, 0 };
            const std::uint32_t dim1508JoeKuoD6Init[]   =   { 1, 3, 5, 9, 23, 31, 95, 155, 83, 641, 1129, 135, 477, 1623, 0 };
            const std::uint32_t dim1509JoeKuoD6Init[]   =   { 1, 1, 3, 9, 9, 61, 93, 11, 331, 585, 799, 1417, 1533, 463, 0 };
            const std::uint32_t dim1510JoeKuoD6Init[]   =   { 1, 1, 7, 7, 21, 51, 61, 29, 467, 935, 11, 3357, 1087, 12337, 0 };
            const std::uint32_t dim1511JoeKuoD6Init[]   =   { 1, 3, 3, 11, 1, 39, 103, 153, 351, 893, 1823, 835, 2149, 4203, 0 };
            const std::uint32_t dim1512JoeKuoD6Init[]   =   { 1, 1, 1, 9, 31, 13, 61, 235, 369, 359, 835, 2067, 2697, 15289, 0 };
            const std::uint32_t dim1513JoeKuoD6Init[]   =   { 1, 1, 7, 1, 15, 1, 107, 27, 201, 451, 1521, 313, 3195, 3847, 0 };
            const std::uint32_t dim1514JoeKuoD6Init[]   =   { 1, 1, 5, 13, 1, 27, 63, 137, 355, 489, 2039, 1015, 2519, 13797, 0 };
            const std::uint32_t dim1515JoeKuoD6Init[]   =   { 1, 1, 7, 9, 29, 33, 23, 197, 49, 555, 1087, 3447, 7299, 15513, 0 };
            const std::uint32_t dim1516JoeKuoD6Init[]   =   { 1, 3, 5, 11, 7, 37, 55, 63, 443, 573, 1715, 631, 3405, 6155, 0 };
            const std::uint32_t dim1517JoeKuoD6Init[]   =   { 1, 3, 3, 3, 31, 35, 51, 167, 225, 617, 2007, 2555, 6819, 12709, 0 };
            const std::uint32_t dim1518JoeKuoD6Init[]   =   { 1, 1, 1, 13, 15, 5, 73, 85, 109, 43, 1067, 3941, 1125, 10269, 0 };
            const std::uint32_t dim1519JoeKuoD6Init[]   =   { 1, 1, 7, 11, 17, 3, 127, 145, 279, 19, 1007, 3287, 4751, 12507, 0 };
            const std::uint32_t dim1520JoeKuoD6Init[]   =   { 1, 3, 7, 3, 19, 1, 117, 111, 193, 435, 47, 1801, 529, 8547, 0 };
            const std::uint32_t dim1521JoeKuoD6Init[]   =   { 1, 3, 3, 13, 1, 19, 101, 19, 469, 187, 207, 1243, 8153, 3273, 0 };
            const std::uint32_t dim1522JoeKuoD6Init[]   =   { 1, 3, 1, 5, 11, 51, 69, 189, 453, 775, 241, 3331, 4067, 14759, 0 };
            const std::uint32_t dim1523JoeKuoD6Init[]   =   { 1, 1, 1, 1, 23, 55, 113, 133, 497, 731, 391, 2777, 3529, 955, 0 };
            const std::uint32_t dim1524JoeKuoD6Init[]   =   { 1, 3, 1, 11, 5, 49, 59, 35, 261, 949, 325, 3595, 7433, 11099, 0 };
            const std::uint32_t dim1525JoeKuoD6Init[]   =   { 1, 3, 5, 9, 13, 37, 103, 219, 329, 865, 1787, 2497, 7249, 9877, 0 };
            const std::uint32_t dim1526JoeKuoD6Init[]   =   { 1, 3, 7, 9, 11, 33, 19, 255, 191, 935, 1115, 1901, 1577, 9623, 0 };
            const std::uint32_t dim1527JoeKuoD6Init[]   =   { 1, 1, 5, 7, 29, 23, 77, 43, 283, 143, 1211, 73, 2835, 10235, 0 };
            const std::uint32_t dim1528JoeKuoD6Init[]   =   { 1, 1, 7, 3, 3, 27, 35, 173, 453, 425, 1225, 3023, 2159, 8433, 0 };
            const std::uint32_t dim1529JoeKuoD6Init[]   =   { 1, 1, 1, 5, 27, 21, 35, 25, 71, 145, 1545, 523, 4527, 7655, 0 };
            const std::uint32_t dim1530JoeKuoD6Init[]   =   { 1, 1, 5, 3, 13, 49, 61, 157, 113, 775, 763, 1785, 225, 11851, 0 };
            const std::uint32_t dim1531JoeKuoD6Init[]   =   { 1, 1, 3, 1, 31, 57, 97, 229, 291, 777, 213, 4067, 921, 8203, 0 };
            const std::uint32_t dim1532JoeKuoD6Init[]   =   { 1, 1, 5, 1, 25, 13, 125, 123, 263, 207, 119, 3111, 3841, 843, 0 };
            const std::uint32_t dim1533JoeKuoD6Init[]   =   { 1, 1, 7, 7, 25, 57, 81, 129, 31, 133, 1869, 2949, 5563, 14965, 0 };
            const std::uint32_t dim1534JoeKuoD6Init[]   =   { 1, 3, 3, 7, 3, 51, 33, 127, 281, 425, 1253, 405, 7941, 8799, 0 };
            const std::uint32_t dim1535JoeKuoD6Init[]   =   { 1, 1, 3, 9, 3, 63, 93, 173, 255, 609, 49, 111, 7785, 15865, 0 };
            const std::uint32_t dim1536JoeKuoD6Init[]   =   { 1, 1, 1, 3, 17, 59, 113, 55, 155, 789, 1335, 177, 3071, 1851, 0 };
            const std::uint32_t dim1537JoeKuoD6Init[]   =   { 1, 3, 7, 15, 15, 23, 35, 35, 131, 623, 47, 437, 1337, 9891, 0 };
            const std::uint32_t dim1538JoeKuoD6Init[]   =   { 1, 3, 7, 5, 29, 57, 39, 31, 111, 271, 59, 1473, 949, 3899, 0 };
            const std::uint32_t dim1539JoeKuoD6Init[]   =   { 1, 1, 3, 11, 17, 19, 41, 229, 259, 691, 1455, 3023, 7455, 9711, 0 };
            const std::uint32_t dim1540JoeKuoD6Init[]   =   { 1, 3, 5, 11, 29, 13, 9, 165, 499, 355, 1415, 1395, 7595, 15571, 0 };
            const std::uint32_t dim1541JoeKuoD6Init[]   =   { 1, 3, 1, 9, 5, 5, 25, 247, 185, 241, 1325, 3133, 7471, 2649, 0 };
            const std::uint32_t dim1542JoeKuoD6Init[]   =   { 1, 3, 3, 11, 17, 29, 57, 61, 51, 203, 993, 1837, 3785, 15163, 0 };
            const std::uint32_t dim1543JoeKuoD6Init[]   =   { 1, 1, 7, 7, 21, 57, 79, 165, 277, 133, 93, 1055, 7169, 15685, 0 };
            const std::uint32_t dim1544JoeKuoD6Init[]   =   { 1, 1, 5, 3, 5, 17, 25, 177, 95, 323, 367, 1359, 4915, 6409, 0 };
            const std::uint32_t dim1545JoeKuoD6Init[]   =   { 1, 1, 1, 1, 11, 25, 115, 45, 373, 221, 1483, 591, 6561, 4527, 0 };
            const std::uint32_t dim1546JoeKuoD6Init[]   =   { 1, 3, 5, 3, 5, 23, 69, 77, 313, 473, 1037, 4045, 3969, 5445, 0 };
            const std::uint32_t dim1547JoeKuoD6Init[]   =   { 1, 3, 1, 5, 1, 15, 73, 83, 439, 463, 203, 361, 6835, 1061, 0 };
            const std::uint32_t dim1548JoeKuoD6Init[]   =   { 1, 1, 3, 11, 21, 5, 89, 233, 405, 253, 773, 3901, 6085, 5677, 0 };
            const std::uint32_t dim1549JoeKuoD6Init[]   =   { 1, 1, 3, 9, 15, 53, 71, 29, 101, 599, 1073, 705, 4507, 12779, 0 };
            const std::uint32_t dim1550JoeKuoD6Init[]   =   { 1, 1, 3, 1, 3, 9, 27, 97, 207, 859, 417, 735, 2179, 5071, 0 };
            const std::uint32_t dim1551JoeKuoD6Init[]   =   { 1, 1, 1, 3, 13, 63, 65, 125, 195, 611, 649, 2221, 3143, 143, 0 };
            const std::uint32_t dim1552JoeKuoD6Init[]   =   { 1, 3, 3, 15, 17, 57, 99, 119, 243, 407, 1229, 813, 5245, 1893, 0 };
            const std::uint32_t dim1553JoeKuoD6Init[]   =   { 1, 1, 1, 5, 27, 27, 49, 13, 313, 287, 473, 2629, 3509, 11371, 0 };
            const std::uint32_t dim1554JoeKuoD6Init[]   =   { 1, 1, 7, 7, 23, 3, 75, 59, 245, 689, 1215, 2375, 3325, 1593, 0 };
            const std::uint32_t dim1555JoeKuoD6Init[]   =   { 1, 3, 1, 5, 21, 51, 43, 107, 91, 611, 1405, 677, 2087, 9565, 0 };
            const std::uint32_t dim1556JoeKuoD6Init[]   =   { 1, 3, 7, 11, 9, 27, 81, 101, 449, 201, 1507, 2217, 6767, 8059, 0 };
            const std::uint32_t dim1557JoeKuoD6Init[]   =   { 1, 1, 3, 9, 13, 41, 21, 195, 421, 315, 347, 2621, 2359, 9247, 0 };
            const std::uint32_t dim1558JoeKuoD6Init[]   =   { 1, 1, 5, 7, 31, 45, 77, 229, 455, 575, 1087, 1147, 2273, 13773, 0 };
            const std::uint32_t dim1559JoeKuoD6Init[]   =   { 1, 1, 1, 1, 9, 5, 87, 19, 207, 545, 1435, 495, 1299, 4947, 0 };
            const std::uint32_t dim1560JoeKuoD6Init[]   =   { 1, 1, 3, 3, 15, 9, 63, 67, 219, 735, 1911, 2361, 6503, 11977, 0 };
            const std::uint32_t dim1561JoeKuoD6Init[]   =   { 1, 3, 1, 9, 31, 27, 103, 153, 81, 939, 461, 2753, 697, 537, 0 };
            const std::uint32_t dim1562JoeKuoD6Init[]   =   { 1, 3, 3, 9, 21, 53, 49, 211, 415, 817, 321, 3775, 2921, 9473, 0 };
            const std::uint32_t dim1563JoeKuoD6Init[]   =   { 1, 1, 7, 3, 23, 55, 15, 51, 435, 1013, 73, 3967, 4575, 13099, 0 };
            const std::uint32_t dim1564JoeKuoD6Init[]   =   { 1, 1, 3, 7, 5, 27, 43, 225, 267, 21, 1261, 603, 6913, 4421, 0 };
            const std::uint32_t dim1565JoeKuoD6Init[]   =   { 1, 1, 7, 13, 25, 31, 101, 109, 237, 91, 1587, 1987, 2795, 6991, 0 };
            const std::uint32_t dim1566JoeKuoD6Init[]   =   { 1, 1, 3, 13, 23, 51, 91, 89, 287, 39, 1513, 463, 6135, 10469, 0 };
            const std::uint32_t dim1567JoeKuoD6Init[]   =   { 1, 3, 3, 1, 9, 43, 125, 157, 369, 495, 1849, 785, 6357, 6557, 0 };
            const std::uint32_t dim1568JoeKuoD6Init[]   =   { 1, 3, 1, 13, 5, 25, 107, 139, 367, 239, 1671, 1239, 7027, 5291, 0 };
            const std::uint32_t dim1569JoeKuoD6Init[]   =   { 1, 3, 5, 13, 11, 13, 35, 177, 45, 939, 251, 59, 333, 13105, 0 };
            const std::uint32_t dim1570JoeKuoD6Init[]   =   { 1, 3, 5, 7, 29, 57, 109, 227, 435, 739, 423, 1941, 3345, 12731, 0 };
            const std::uint32_t dim1571JoeKuoD6Init[]   =   { 1, 3, 3, 9, 23, 51, 19, 207, 69, 99, 955, 519, 7305, 2415, 0 };
            const std::uint32_t dim1572JoeKuoD6Init[]   =   { 1, 1, 5, 13, 17, 1, 67, 201, 61, 403, 1059, 2915, 2419, 12773, 0 };
            const std::uint32_t dim1573JoeKuoD6Init[]   =   { 1, 3, 1, 11, 17, 19, 25, 27, 207, 299, 143, 1955, 5669, 2301, 0 };
            const std::uint32_t dim1574JoeKuoD6Init[]   =   { 1, 1, 5, 3, 25, 57, 45, 255, 489, 1011, 1699, 2637, 5279, 12211, 0 };
            const std::uint32_t dim1575JoeKuoD6Init[]   =   { 1, 3, 3, 15, 7, 47, 113, 33, 511, 907, 1815, 1741, 2091, 13857, 0 };
            const std::uint32_t dim1576JoeKuoD6Init[]   =   { 1, 3, 3, 5, 5, 27, 95, 3, 353, 253, 947, 393, 1815, 14551, 0 };
            const std::uint32_t dim1577JoeKuoD6Init[]   =   { 1, 1, 5, 11, 29, 19, 63, 117, 293, 861, 2039, 9, 5999, 6909, 0 };
            const std::uint32_t dim1578JoeKuoD6Init[]   =   { 1, 3, 7, 3, 15, 63, 107, 173, 509, 817, 99, 2825, 131, 7917, 0 };
            const std::uint32_t dim1579JoeKuoD6Init[]   =   { 1, 3, 1, 1, 29, 49, 33, 153, 119, 777, 1315, 3581, 5675, 4043, 0 };
            const std::uint32_t dim1580JoeKuoD6Init[]   =   { 1, 3, 5, 15, 13, 11, 17, 147, 327, 305, 367, 3237, 5423, 13757, 0 };
            const std::uint32_t dim1581JoeKuoD6Init[]   =   { 1, 1, 5, 13, 1, 39, 35, 29, 25, 751, 1365, 2243, 8181, 7063, 0 };
            const std::uint32_t dim1582JoeKuoD6Init[]   =   { 1, 3, 7, 11, 25, 53, 11, 111, 289, 755, 1201, 691, 3679, 3725, 0 };
            const std::uint32_t dim1583JoeKuoD6Init[]   =   { 1, 1, 1, 11, 11, 37, 33, 211, 395, 691, 1817, 861, 6485, 12077, 0 };
            const std::uint32_t dim1584JoeKuoD6Init[]   =   { 1, 3, 3, 11, 21, 3, 111, 171, 305, 561, 1501, 2011, 7841, 10931, 0 };
            const std::uint32_t dim1585JoeKuoD6Init[]   =   { 1, 3, 7, 9, 9, 59, 109, 113, 31, 915, 103, 1861, 2779, 10619, 0 };
            const std::uint32_t dim1586JoeKuoD6Init[]   =   { 1, 1, 1, 1, 7, 25, 61, 97, 103, 723, 1145, 3105, 371, 339, 0 };
            const std::uint32_t dim1587JoeKuoD6Init[]   =   { 1, 1, 7, 13, 17, 9, 113, 51, 233, 209, 1117, 211, 6969, 2347, 0 };
            const std::uint32_t dim1588JoeKuoD6Init[]   =   { 1, 1, 5, 9, 25, 43, 21, 217, 327, 735, 197, 1063, 799, 801, 0 };
            const std::uint32_t dim1589JoeKuoD6Init[]   =   { 1, 1, 7, 13, 9, 13, 73, 33, 415, 923, 863, 1999, 5383, 8119, 0 };
            const std::uint32_t dim1590JoeKuoD6Init[]   =   { 1, 3, 1, 5, 7, 33, 51, 185, 289, 967, 1277, 1011, 767, 15505, 0 };
            const std::uint32_t dim1591JoeKuoD6Init[]   =   { 1, 3, 3, 13, 21, 11, 105, 235, 343, 1021, 2009, 2251, 3865, 6923, 0 };
            const std::uint32_t dim1592JoeKuoD6Init[]   =   { 1, 3, 5, 9, 29, 11, 33, 17, 149, 155, 1739, 3039, 7015, 2401, 0 };
            const std::uint32_t dim1593JoeKuoD6Init[]   =   { 1, 3, 7, 7, 17, 13, 89, 177, 297, 267, 545, 3861, 329, 13267, 0 };
            const std::uint32_t dim1594JoeKuoD6Init[]   =   { 1, 3, 5, 15, 27, 33, 1, 231, 181, 557, 447, 379, 7845, 1295, 0 };
            const std::uint32_t dim1595JoeKuoD6Init[]   =   { 1, 1, 5, 13, 3, 63, 59, 33, 263, 877, 1867, 1383, 641, 7139, 0 };
            const std::uint32_t dim1596JoeKuoD6Init[]   =   { 1, 3, 7, 5, 13, 51, 9, 113, 223, 605, 1189, 4063, 6925, 9563, 0 };
            const std::uint32_t dim1597JoeKuoD6Init[]   =   { 1, 1, 1, 13, 5, 35, 83, 107, 295, 231, 265, 5, 4087, 6407, 0 };
            const std::uint32_t dim1598JoeKuoD6Init[]   =   { 1, 1, 5, 1, 7, 25, 95, 137, 97, 987, 1753, 2781, 1369, 6903, 0 };
            const std::uint32_t dim1599JoeKuoD6Init[]   =   { 1, 1, 5, 13, 19, 61, 77, 229, 193, 165, 811, 249, 79, 10719, 0 };
            const std::uint32_t dim1600JoeKuoD6Init[]   =   { 1, 3, 7, 7, 27, 9, 119, 193, 459, 43, 1989, 2959, 3595, 6341, 0 };
            const std::uint32_t dim1601JoeKuoD6Init[]   =   { 1, 1, 5, 11, 5, 43, 35, 33, 25, 581, 897, 351, 4201, 3971, 0 };
            const std::uint32_t dim1602JoeKuoD6Init[]   =   { 1, 1, 7, 11, 21, 29, 53, 45, 359, 197, 313, 3825, 6717, 4077, 0 };
            const std::uint32_t dim1603JoeKuoD6Init[]   =   { 1, 1, 1, 15, 3, 45, 99, 133, 357, 315, 1159, 241, 2463, 11253, 0 };
            const std::uint32_t dim1604JoeKuoD6Init[]   =   { 1, 1, 7, 11, 9, 33, 111, 85, 443, 601, 447, 337, 6471, 7029, 0 };
            const std::uint32_t dim1605JoeKuoD6Init[]   =   { 1, 3, 7, 9, 13, 33, 25, 31, 9, 729, 1763, 4077, 7575, 7877, 0 };
            const std::uint32_t dim1606JoeKuoD6Init[]   =   { 1, 3, 5, 13, 13, 37, 29, 103, 53, 229, 591, 1073, 1323, 14405, 0 };
            const std::uint32_t dim1607JoeKuoD6Init[]   =   { 1, 1, 5, 1, 17, 33, 15, 183, 473, 297, 2003, 93, 4955, 1787, 0 };
            const std::uint32_t dim1608JoeKuoD6Init[]   =   { 1, 1, 5, 13, 5, 29, 113, 161, 267, 451, 1193, 149, 273, 11809, 0 };
            const std::uint32_t dim1609JoeKuoD6Init[]   =   { 1, 1, 1, 9, 17, 39, 47, 233, 165, 373, 955, 2891, 7523, 7235, 0 };
            const std::uint32_t dim1610JoeKuoD6Init[]   =   { 1, 1, 1, 3, 7, 21, 115, 205, 153, 449, 339, 2073, 1077, 5749, 0 };
            const std::uint32_t dim1611JoeKuoD6Init[]   =   { 1, 1, 7, 13, 9, 39, 117, 187, 37, 753, 227, 3519, 7391, 5751, 0 };
            const std::uint32_t dim1612JoeKuoD6Init[]   =   { 1, 1, 1, 9, 5, 19, 41, 161, 141, 195, 1719, 3321, 5, 12877, 0 };
            const std::uint32_t dim1613JoeKuoD6Init[]   =   { 1, 3, 7, 11, 21, 13, 83, 55, 299, 75, 1905, 3765, 4685, 12297, 0 };
            const std::uint32_t dim1614JoeKuoD6Init[]   =   { 1, 1, 7, 3, 3, 23, 111, 243, 187, 297, 1061, 2515, 977, 9555, 0 };
            const std::uint32_t dim1615JoeKuoD6Init[]   =   { 1, 3, 7, 3, 29, 11, 103, 177, 225, 875, 1649, 1401, 6383, 8309, 0 };
            const std::uint32_t dim1616JoeKuoD6Init[]   =   { 1, 3, 5, 3, 3, 41, 71, 3, 373, 757, 701, 2825, 1521, 13217, 0 };
            const std::uint32_t dim1617JoeKuoD6Init[]   =   { 1, 1, 5, 3, 11, 5, 103, 227, 209, 723, 1543, 3895, 6345, 7901, 0 };
            const std::uint32_t dim1618JoeKuoD6Init[]   =   { 1, 1, 5, 1, 9, 51, 77, 67, 359, 937, 557, 993, 3871, 3577, 0 };
            const std::uint32_t dim1619JoeKuoD6Init[]   =   { 1, 3, 7, 1, 1, 15, 121, 239, 29, 113, 1123, 3877, 6941, 14129, 0 };
            const std::uint32_t dim1620JoeKuoD6Init[]   =   { 1, 1, 5, 1, 27, 61, 83, 113, 185, 601, 947, 3933, 381, 13869, 0 };
            const std::uint32_t dim1621JoeKuoD6Init[]   =   { 1, 1, 5, 3, 5, 37, 97, 31, 81, 367, 747, 1811, 5313, 14151, 0 };
            const std::uint32_t dim1622JoeKuoD6Init[]   =   { 1, 3, 5, 9, 27, 61, 87, 31, 185, 521, 837, 959, 5001, 3957, 0 };
            const std::uint32_t dim1623JoeKuoD6Init[]   =   { 1, 3, 5, 3, 11, 61, 37, 19, 107, 749, 1345, 3829, 6701, 4315, 0 };
            const std::uint32_t dim1624JoeKuoD6Init[]   =   { 1, 3, 1, 15, 13, 45, 101, 113, 243, 963, 1861, 3283, 1419, 12131, 0 };
            const std::uint32_t dim1625JoeKuoD6Init[]   =   { 1, 1, 7, 1, 11, 63, 17, 117, 271, 819, 677, 669, 1991, 12511, 0 };
            const std::uint32_t dim1626JoeKuoD6Init[]   =   { 1, 1, 1, 13, 13, 33, 41, 73, 187, 537, 993, 3147, 1013, 16063, 0 };
            const std::uint32_t dim1627JoeKuoD6Init[]   =   { 1, 3, 1, 1, 25, 21, 107, 81, 117, 917, 113, 349, 4475, 9149, 0 };
            const std::uint32_t dim1628JoeKuoD6Init[]   =   { 1, 1, 1, 11, 21, 21, 29, 251, 125, 681, 141, 2893, 5843, 14359, 0 };
            const std::uint32_t dim1629JoeKuoD6Init[]   =   { 1, 3, 3, 1, 5, 41, 85, 163, 387, 29, 1593, 221, 2769, 10809, 0 };
            const std::uint32_t dim1630JoeKuoD6Init[]   =   { 1, 3, 5, 11, 1, 17, 69, 127, 273, 449, 1855, 2971, 7031, 10583, 0 };
            const std::uint32_t dim1631JoeKuoD6Init[]   =   { 1, 1, 5, 7, 1, 61, 9, 211, 123, 563, 111, 1883, 5801, 2191, 0 };
            const std::uint32_t dim1632JoeKuoD6Init[]   =   { 1, 1, 3, 11, 11, 51, 1, 81, 405, 803, 2017, 161, 5429, 731, 0 };
            const std::uint32_t dim1633JoeKuoD6Init[]   =   { 1, 1, 7, 9, 15, 55, 65, 51, 459, 485, 1539, 3135, 2929, 7867, 0 };
            const std::uint32_t dim1634JoeKuoD6Init[]   =   { 1, 1, 7, 11, 3, 45, 15, 7, 331, 417, 1813, 4009, 1341, 10965, 0 };
            const std::uint32_t dim1635JoeKuoD6Init[]   =   { 1, 1, 1, 5, 9, 29, 89, 121, 277, 509, 1989, 1293, 4787, 16097, 0 };
            const std::uint32_t dim1636JoeKuoD6Init[]   =   { 1, 1, 3, 9, 17, 45, 97, 197, 339, 943, 1377, 2947, 5833, 7, 0 };
            const std::uint32_t dim1637JoeKuoD6Init[]   =   { 1, 1, 7, 9, 15, 61, 75, 233, 401, 705, 825, 2521, 3787, 14387, 0 };
            const std::uint32_t dim1638JoeKuoD6Init[]   =   { 1, 1, 7, 15, 25, 57, 3, 43, 361, 459, 1551, 1859, 6787, 2293, 0 };
            const std::uint32_t dim1639JoeKuoD6Init[]   =   { 1, 3, 3, 11, 11, 35, 91, 65, 43, 509, 1829, 1149, 4801, 4109, 0 };
            const std::uint32_t dim1640JoeKuoD6Init[]   =   { 1, 3, 5, 9, 15, 3, 81, 109, 231, 481, 417, 2505, 315, 6693, 0 };
            const std::uint32_t dim1641JoeKuoD6Init[]   =   { 1, 1, 3, 9, 3, 7, 107, 221, 297, 543, 149, 579, 927, 79, 0 };
            const std::uint32_t dim1642JoeKuoD6Init[]   =   { 1, 3, 1, 11, 17, 3, 81, 137, 157, 587, 741, 1277, 2631, 3953, 0 };
            const std::uint32_t dim1643JoeKuoD6Init[]   =   { 1, 1, 7, 5, 13, 43, 117, 19, 495, 185, 1105, 605, 5249, 11099, 0 };
            const std::uint32_t dim1644JoeKuoD6Init[]   =   { 1, 1, 7, 9, 23, 55, 91, 213, 21, 779, 857, 2047, 7813, 10053, 0 };
            const std::uint32_t dim1645JoeKuoD6Init[]   =   { 1, 1, 1, 1, 27, 7, 39, 181, 63, 519, 1073, 3147, 4111, 363, 0 };
            const std::uint32_t dim1646JoeKuoD6Init[]   =   { 1, 3, 7, 9, 15, 61, 7, 139, 495, 805, 1545, 3789, 2411, 3989, 0 };
            const std::uint32_t dim1647JoeKuoD6Init[]   =   { 1, 1, 3, 1, 25, 11, 23, 241, 167, 607, 479, 153, 7787, 13929, 0 };
            const std::uint32_t dim1648JoeKuoD6Init[]   =   { 1, 3, 5, 15, 29, 35, 45, 71, 457, 297, 883, 3021, 5361, 15427, 0 };
            const std::uint32_t dim1649JoeKuoD6Init[]   =   { 1, 3, 1, 7, 29, 27, 93, 241, 427, 89, 1185, 37, 3863, 14095, 0 };
            const std::uint32_t dim1650JoeKuoD6Init[]   =   { 1, 3, 1, 5, 5, 45, 51, 15, 235, 889, 1649, 2331, 2713, 10943, 0 };
            const std::uint32_t dim1651JoeKuoD6Init[]   =   { 1, 1, 3, 11, 11, 15, 71, 85, 135, 163, 139, 1147, 1043, 3195, 0 };
            const std::uint32_t dim1652JoeKuoD6Init[]   =   { 1, 3, 5, 13, 3, 43, 71, 131, 473, 933, 569, 2491, 7751, 1865, 0 };
            const std::uint32_t dim1653JoeKuoD6Init[]   =   { 1, 1, 7, 9, 21, 37, 105, 227, 329, 509, 1319, 307, 1557, 14625, 0 };
            const std::uint32_t dim1654JoeKuoD6Init[]   =   { 1, 1, 3, 13, 15, 1, 25, 93, 335, 953, 769, 4039, 369, 10727, 0 };
            const std::uint32_t dim1655JoeKuoD6Init[]   =   { 1, 3, 7, 5, 17, 21, 59, 89, 437, 679, 437, 1543, 7663, 5005, 0 };
            const std::uint32_t dim1656JoeKuoD6Init[]   =   { 1, 1, 7, 15, 27, 49, 125, 13, 397, 877, 1087, 2191, 4711, 9065, 0 };
            const std::uint32_t dim1657JoeKuoD6Init[]   =   { 1, 1, 7, 5, 15, 47, 115, 125, 187, 31, 1003, 2575, 5397, 3883, 0 };
            const std::uint32_t dim1658JoeKuoD6Init[]   =   { 1, 1, 7, 11, 15, 1, 127, 207, 383, 707, 183, 1053, 3123, 14071, 0 };
            const std::uint32_t dim1659JoeKuoD6Init[]   =   { 1, 3, 3, 1, 31, 53, 15, 19, 477, 245, 777, 1613, 5813, 7443, 0 };
            const std::uint32_t dim1660JoeKuoD6Init[]   =   { 1, 3, 1, 11, 23, 59, 65, 23, 493, 157, 1389, 2833, 4535, 3907, 0 };
            const std::uint32_t dim1661JoeKuoD6Init[]   =   { 1, 1, 7, 1, 19, 7, 51, 135, 327, 441, 1841, 3091, 3451, 14381, 0 };
            const std::uint32_t dim1662JoeKuoD6Init[]   =   { 1, 1, 7, 7, 3, 37, 29, 249, 437, 319, 1693, 945, 7639, 5923, 0 };
            const std::uint32_t dim1663JoeKuoD6Init[]   =   { 1, 3, 7, 15, 7, 61, 81, 127, 383, 99, 23, 3833, 3973, 7651, 0 };
            const std::uint32_t dim1664JoeKuoD6Init[]   =   { 1, 3, 1, 7, 7, 21, 119, 185, 243, 619, 1363, 2033, 4835, 5089, 0 };
            const std::uint32_t dim1665JoeKuoD6Init[]   =   { 1, 3, 1, 1, 3, 27, 63, 145, 271, 735, 695, 3981, 3049, 5433, 0 };
            const std::uint32_t dim1666JoeKuoD6Init[]   =   { 1, 3, 3, 1, 3, 29, 79, 211, 279, 819, 501, 3665, 1455, 10455, 0 };
            const std::uint32_t dim1667JoeKuoD6Init[]   =   { 1, 1, 3, 3, 31, 61, 113, 5, 411, 91, 489, 3257, 5939, 6715, 0 };
            const std::uint32_t dim1668JoeKuoD6Init[]   =   { 1, 1, 5, 1, 23, 11, 103, 89, 377, 441, 43, 967, 3383, 8717, 0 };
            const std::uint32_t dim1669JoeKuoD6Init[]   =   { 1, 1, 5, 13, 29, 39, 97, 189, 197, 621, 1755, 333, 6783, 9711, 0 };
            const std::uint32_t dim1670JoeKuoD6Init[]   =   { 1, 1, 5, 13, 27, 17, 97, 197, 351, 799, 335, 765, 5329, 12549, 0 };
            const std::uint32_t dim1671JoeKuoD6Init[]   =   { 1, 1, 5, 11, 29, 17, 9, 211, 127, 633, 1187, 3965, 4145, 12667, 0 };
            const std::uint32_t dim1672JoeKuoD6Init[]   =   { 1, 1, 7, 5, 27, 29, 65, 115, 287, 325, 461, 5, 899, 2027, 0 };
            const std::uint32_t dim1673JoeKuoD6Init[]   =   { 1, 1, 1, 5, 27, 17, 31, 13, 231, 627, 1163, 649, 1693, 9975, 0 };
            const std::uint32_t dim1674JoeKuoD6Init[]   =   { 1, 3, 1, 15, 7, 49, 113, 123, 427, 603, 347, 2785, 7129, 4645, 0 };
            const std::uint32_t dim1675JoeKuoD6Init[]   =   { 1, 1, 3, 7, 1, 33, 113, 105, 411, 939, 205, 3965, 4361, 4649, 0 };
            const std::uint32_t dim1676JoeKuoD6Init[]   =   { 1, 1, 1, 1, 5, 21, 35, 159, 275, 929, 1193, 3205, 4787, 3515, 0 };
            const std::uint32_t dim1677JoeKuoD6Init[]   =   { 1, 1, 1, 5, 1, 21, 29, 191, 275, 233, 1239, 515, 4349, 14989, 0 };
            const std::uint32_t dim1678JoeKuoD6Init[]   =   { 1, 1, 5, 11, 27, 43, 111, 83, 153, 577, 1537, 149, 231, 839, 0 };
            const std::uint32_t dim1679JoeKuoD6Init[]   =   { 1, 3, 5, 13, 21, 19, 57, 69, 87, 163, 271, 3535, 1057, 8517, 0 };
            const std::uint32_t dim1680JoeKuoD6Init[]   =   { 1, 3, 3, 13, 17, 49, 65, 45, 457, 241, 391, 2033, 2507, 7771, 0 };
            const std::uint32_t dim1681JoeKuoD6Init[]   =   { 1, 1, 5, 7, 11, 19, 79, 133, 341, 761, 27, 3905, 4137, 14363, 0 };
            const std::uint32_t dim1682JoeKuoD6Init[]   =   { 1, 3, 3, 13, 19, 1, 11, 139, 249, 245, 1393, 2151, 2857, 1665, 0 };
            const std::uint32_t dim1683JoeKuoD6Init[]   =   { 1, 1, 3, 15, 11, 7, 127, 47, 385, 1007, 713, 2235, 5489, 8755, 0 };
            const std::uint32_t dim1684JoeKuoD6Init[]   =   { 1, 3, 5, 13, 19, 21, 21, 167, 405, 655, 1653, 889, 7367, 4177, 0 };
            const std::uint32_t dim1685JoeKuoD6Init[]   =   { 1, 1, 5, 3, 19, 63, 99, 39, 89, 415, 951, 2863, 6569, 3797, 0 };
            const std::uint32_t dim1686JoeKuoD6Init[]   =   { 1, 1, 1, 13, 31, 29, 119, 35, 311, 839, 1749, 941, 7487, 2385, 0 };
            const std::uint32_t dim1687JoeKuoD6Init[]   =   { 1, 3, 7, 3, 17, 3, 97, 143, 465, 345, 1457, 2201, 5329, 359, 0 };
            const std::uint32_t dim1688JoeKuoD6Init[]   =   { 1, 3, 7, 11, 1, 15, 3, 115, 335, 567, 1749, 1811, 3491, 15939, 0 };
            const std::uint32_t dim1689JoeKuoD6Init[]   =   { 1, 1, 3, 13, 3, 21, 7, 141, 149, 571, 1877, 473, 2143, 9569, 0 };
            const std::uint32_t dim1690JoeKuoD6Init[]   =   { 1, 3, 3, 11, 23, 61, 47, 179, 297, 453, 181, 3405, 2981, 13409, 0 };
            const std::uint32_t dim1691JoeKuoD6Init[]   =   { 1, 3, 1, 13, 1, 43, 5, 201, 371, 1003, 367, 2709, 7675, 14973, 0 };
            const std::uint32_t dim1692JoeKuoD6Init[]   =   { 1, 3, 3, 15, 29, 17, 19, 241, 495, 317, 1135, 2227, 6457, 4783, 0 };
            const std::uint32_t dim1693JoeKuoD6Init[]   =   { 1, 3, 3, 7, 29, 9, 57, 95, 261, 531, 1717, 3389, 7991, 3793, 0 };
            const std::uint32_t dim1694JoeKuoD6Init[]   =   { 1, 1, 1, 5, 31, 43, 73, 119, 499, 589, 1529, 3337, 4097, 15641, 0 };
            const std::uint32_t dim1695JoeKuoD6Init[]   =   { 1, 1, 7, 9, 29, 43, 127, 91, 243, 979, 1325, 2835, 2787, 9445, 0 };
            const std::uint32_t dim1696JoeKuoD6Init[]   =   { 1, 1, 7, 5, 9, 3, 115, 199, 219, 901, 747, 1077, 3197, 2443, 0 };
            const std::uint32_t dim1697JoeKuoD6Init[]   =   { 1, 3, 5, 1, 3, 43, 7, 117, 297, 313, 1043, 1579, 5099, 13289, 0 };
            const std::uint32_t dim1698JoeKuoD6Init[]   =   { 1, 1, 7, 11, 29, 33, 15, 121, 131, 579, 317, 1871, 1121, 11653, 0 };
            const std::uint32_t dim1699JoeKuoD6Init[]   =   { 1, 1, 5, 9, 25, 25, 43, 89, 355, 1011, 1385, 2901, 6387, 1653, 0 };
            const std::uint32_t dim1700JoeKuoD6Init[]   =   { 1, 1, 1, 9, 5, 47, 61, 165, 85, 757, 1397, 1177, 1657, 4899, 0 };
            const std::uint32_t dim1701JoeKuoD6Init[]   =   { 1, 1, 3, 9, 11, 49, 15, 139, 261, 613, 931, 1299, 2777, 2835, 0 };
            const std::uint32_t dim1702JoeKuoD6Init[]   =   { 1, 1, 1, 5, 3, 55, 83, 227, 125, 581, 1607, 1171, 6681, 14463, 0 };
            const std::uint32_t dim1703JoeKuoD6Init[]   =   { 1, 3, 5, 13, 5, 55, 3, 247, 493, 155, 1073, 3743, 5719, 4019, 0 };
            const std::uint32_t dim1704JoeKuoD6Init[]   =   { 1, 1, 7, 1, 11, 23, 13, 75, 399, 847, 499, 1643, 6977, 3699, 0 };
            const std::uint32_t dim1705JoeKuoD6Init[]   =   { 1, 3, 1, 9, 11, 41, 47, 131, 313, 627, 481, 2469, 3281, 979, 0 };
            const std::uint32_t dim1706JoeKuoD6Init[]   =   { 1, 3, 5, 13, 29, 3, 65, 101, 11, 29, 1807, 153, 1487, 16109, 0 };
            const std::uint32_t dim1707JoeKuoD6Init[]   =   { 1, 1, 5, 9, 13, 31, 83, 195, 351, 355, 467, 3871, 3085, 4441, 0 };
            const std::uint32_t dim1708JoeKuoD6Init[]   =   { 1, 3, 5, 3, 19, 21, 111, 179, 143, 361, 1619, 1547, 3409, 6905, 0 };
            const std::uint32_t dim1709JoeKuoD6Init[]   =   { 1, 1, 5, 9, 31, 1, 93, 199, 491, 135, 1627, 2559, 1389, 14561, 0 };
            const std::uint32_t dim1710JoeKuoD6Init[]   =   { 1, 3, 3, 9, 25, 53, 3, 105, 39, 445, 259, 1045, 1129, 9153, 0 };
            const std::uint32_t dim1711JoeKuoD6Init[]   =   { 1, 1, 5, 9, 19, 63, 71, 9, 73, 435, 1377, 4015, 1821, 6453, 0 };
            const std::uint32_t dim1712JoeKuoD6Init[]   =   { 1, 3, 7, 13, 19, 13, 37, 247, 391, 23, 1491, 1257, 6395, 237, 0 };
            const std::uint32_t dim1713JoeKuoD6Init[]   =   { 1, 1, 3, 3, 19, 55, 109, 23, 227, 747, 729, 2221, 727, 2209, 0 };
            const std::uint32_t dim1714JoeKuoD6Init[]   =   { 1, 1, 5, 11, 25, 21, 75, 37, 219, 355, 1005, 1895, 7039, 5225, 0 };
            const std::uint32_t dim1715JoeKuoD6Init[]   =   { 1, 3, 5, 13, 11, 43, 9, 67, 87, 797, 1077, 245, 4521, 11845, 0 };
            const std::uint32_t dim1716JoeKuoD6Init[]   =   { 1, 3, 5, 3, 15, 29, 127, 237, 277, 373, 1859, 3083, 587, 1123, 0 };
            const std::uint32_t dim1717JoeKuoD6Init[]   =   { 1, 1, 7, 15, 13, 7, 103, 53, 13, 965, 1497, 775, 3439, 1501, 0 };
            const std::uint32_t dim1718JoeKuoD6Init[]   =   { 1, 3, 3, 15, 17, 13, 97, 169, 67, 953, 189, 2739, 1459, 10543, 0 };
            const std::uint32_t dim1719JoeKuoD6Init[]   =   { 1, 1, 5, 1, 17, 39, 15, 127, 327, 989, 1471, 3235, 2801, 15311, 0 };
            const std::uint32_t dim1720JoeKuoD6Init[]   =   { 1, 1, 1, 15, 5, 37, 55, 155, 47, 463, 1851, 3467, 2765, 9359, 0 };
            const std::uint32_t dim1721JoeKuoD6Init[]   =   { 1, 3, 3, 15, 1, 13, 93, 239, 291, 115, 365, 61, 395, 15853, 0 };
            const std::uint32_t dim1722JoeKuoD6Init[]   =   { 1, 1, 5, 1, 19, 27, 61, 95, 105, 369, 1557, 961, 6917, 3621, 0 };
            const std::uint32_t dim1723JoeKuoD6Init[]   =   { 1, 3, 3, 9, 7, 35, 115, 53, 111, 345, 1145, 1687, 3401, 12107, 0 };
            const std::uint32_t dim1724JoeKuoD6Init[]   =   { 1, 1, 1, 5, 7, 31, 63, 19, 373, 79, 1369, 3037, 2835, 4439, 0 };
            const std::uint32_t dim1725JoeKuoD6Init[]   =   { 1, 3, 7, 9, 11, 17, 29, 33, 331, 447, 1981, 3333, 6535, 6557, 0 };
            const std::uint32_t dim1726JoeKuoD6Init[]   =   { 1, 3, 3, 5, 11, 41, 29, 43, 365, 279, 1919, 945, 179, 1987, 0 };
            const std::uint32_t dim1727JoeKuoD6Init[]   =   { 1, 3, 1, 13, 7, 7, 25, 33, 103, 367, 1267, 763, 5691, 8643, 0 };
            const std::uint32_t dim1728JoeKuoD6Init[]   =   { 1, 3, 1, 5, 11, 15, 3, 213, 511, 211, 1069, 4047, 3335, 12729, 0 };
            const std::uint32_t dim1729JoeKuoD6Init[]   =   { 1, 1, 3, 1, 5, 11, 27, 201, 361, 537, 679, 3709, 293, 2997, 0 };
            const std::uint32_t dim1730JoeKuoD6Init[]   =   { 1, 1, 3, 1, 25, 15, 19, 185, 369, 577, 1625, 655, 2363, 3861, 0 };
            const std::uint32_t dim1731JoeKuoD6Init[]   =   { 1, 1, 5, 5, 1, 47, 61, 45, 411, 597, 955, 1007, 3775, 5809, 0 };
            const std::uint32_t dim1732JoeKuoD6Init[]   =   { 1, 1, 5, 3, 27, 51, 101, 167, 429, 333, 1703, 3541, 2947, 3695, 0 };
            const std::uint32_t dim1733JoeKuoD6Init[]   =   { 1, 3, 5, 5, 1, 53, 17, 63, 141, 215, 1223, 3129, 635, 15919, 0 };
            const std::uint32_t dim1734JoeKuoD6Init[]   =   { 1, 3, 3, 1, 23, 31, 25, 11, 195, 241, 995, 3941, 573, 13855, 0 };
            const std::uint32_t dim1735JoeKuoD6Init[]   =   { 1, 3, 3, 7, 17, 13, 71, 203, 465, 479, 1857, 1493, 8067, 7113, 0 };
            const std::uint32_t dim1736JoeKuoD6Init[]   =   { 1, 1, 5, 3, 11, 57, 9, 59, 225, 691, 425, 2423, 6031, 6631, 0 };
            const std::uint32_t dim1737JoeKuoD6Init[]   =   { 1, 3, 7, 1, 29, 57, 103, 123, 401, 807, 471, 2759, 5113, 15937, 0 };
            const std::uint32_t dim1738JoeKuoD6Init[]   =   { 1, 3, 1, 1, 3, 1, 67, 123, 157, 655, 519, 323, 1853, 15041, 0 };
            const std::uint32_t dim1739JoeKuoD6Init[]   =   { 1, 1, 7, 5, 11, 11, 105, 135, 247, 689, 1141, 2347, 7113, 9347, 0 };
            const std::uint32_t dim1740JoeKuoD6Init[]   =   { 1, 1, 3, 11, 15, 37, 87, 3, 209, 575, 1521, 3863, 3893, 211, 0 };
            const std::uint32_t dim1741JoeKuoD6Init[]   =   { 1, 3, 1, 3, 29, 55, 115, 31, 19, 195, 985, 3275, 363, 9801, 0 };
            const std::uint32_t dim1742JoeKuoD6Init[]   =   { 1, 1, 3, 9, 13, 31, 57, 251, 201, 275, 1751, 389, 1463, 13159, 0 };
            const std::uint32_t dim1743JoeKuoD6Init[]   =   { 1, 3, 5, 15, 19, 51, 127, 255, 397, 243, 29, 3007, 7845, 4687, 0 };
            const std::uint32_t dim1744JoeKuoD6Init[]   =   { 1, 1, 7, 15, 9, 37, 39, 217, 509, 137, 1123, 3361, 6323, 5323, 0 };
            const std::uint32_t dim1745JoeKuoD6Init[]   =   { 1, 3, 7, 5, 25, 3, 93, 203, 345, 581, 261, 2811, 4829, 6977, 0 };
            const std::uint32_t dim1746JoeKuoD6Init[]   =   { 1, 1, 7, 1, 15, 41, 51, 227, 447, 893, 1209, 3865, 5229, 4277, 0 };
            const std::uint32_t dim1747JoeKuoD6Init[]   =   { 1, 1, 1, 5, 31, 19, 23, 195, 359, 853, 595, 337, 2503, 16371, 0 };
            const std::uint32_t dim1748JoeKuoD6Init[]   =   { 1, 3, 7, 5, 5, 13, 89, 157, 351, 777, 151, 3565, 4219, 7423, 0 };
            const std::uint32_t dim1749JoeKuoD6Init[]   =   { 1, 1, 1, 5, 7, 1, 9, 89, 175, 909, 1523, 2295, 7949, 6739, 0 };
            const std::uint32_t dim1750JoeKuoD6Init[]   =   { 1, 3, 5, 15, 27, 17, 11, 235, 19, 105, 457, 465, 3819, 11335, 0 };
            const std::uint32_t dim1751JoeKuoD6Init[]   =   { 1, 3, 1, 13, 3, 41, 85, 221, 451, 613, 543, 2265, 6831, 1725, 0 };
            const std::uint32_t dim1752JoeKuoD6Init[]   =   { 1, 1, 7, 7, 3, 29, 9, 197, 455, 665, 343, 1811, 5395, 393, 0 };
            const std::uint32_t dim1753JoeKuoD6Init[]   =   { 1, 1, 3, 13, 29, 55, 71, 95, 475, 615, 2029, 123, 413, 16127, 0 };
            const std::uint32_t dim1754JoeKuoD6Init[]   =   { 1, 1, 5, 9, 15, 61, 9, 51, 105, 271, 511, 2801, 693, 11839, 0 };
            const std::uint32_t dim1755JoeKuoD6Init[]   =   { 1, 1, 7, 13, 29, 9, 105, 59, 377, 635, 717, 4033, 6963, 10541, 0 };
            const std::uint32_t dim1756JoeKuoD6Init[]   =   { 1, 1, 1, 13, 7, 13, 59, 17, 335, 355, 77, 3665, 7003, 9521, 0 };
            const std::uint32_t dim1757JoeKuoD6Init[]   =   { 1, 3, 1, 1, 23, 43, 51, 209, 151, 365, 1021, 2859, 3937, 2899, 0 };
            const std::uint32_t dim1758JoeKuoD6Init[]   =   { 1, 1, 3, 3, 31, 41, 111, 107, 171, 433, 1233, 505, 2971, 6927, 0 };
            const std::uint32_t dim1759JoeKuoD6Init[]   =   { 1, 3, 7, 13, 17, 25, 127, 195, 257, 551, 1867, 2145, 3695, 14567, 0 };
            const std::uint32_t dim1760JoeKuoD6Init[]   =   { 1, 1, 5, 13, 13, 45, 39, 195, 55, 991, 1981, 1043, 5875, 581, 0 };
            const std::uint32_t dim1761JoeKuoD6Init[]   =   { 1, 3, 3, 11, 25, 31, 91, 153, 415, 449, 1301, 563, 7755, 10671, 0 };
            const std::uint32_t dim1762JoeKuoD6Init[]   =   { 1, 1, 3, 5, 31, 63, 1, 157, 229, 949, 971, 137, 6589, 8387, 0 };
            const std::uint32_t dim1763JoeKuoD6Init[]   =   { 1, 3, 7, 15, 25, 7, 89, 133, 73, 497, 1361, 613, 455, 1005, 0 };
            const std::uint32_t dim1764JoeKuoD6Init[]   =   { 1, 3, 3, 1, 13, 5, 119, 93, 175, 511, 1923, 763, 7573, 7545, 0 };
            const std::uint32_t dim1765JoeKuoD6Init[]   =   { 1, 1, 3, 15, 27, 59, 49, 205, 497, 485, 117, 2523, 4495, 15153, 0 };
            const std::uint32_t dim1766JoeKuoD6Init[]   =   { 1, 3, 7, 9, 15, 47, 111, 31, 363, 11, 475, 2931, 6813, 1259, 0 };
            const std::uint32_t dim1767JoeKuoD6Init[]   =   { 1, 1, 5, 5, 1, 35, 95, 225, 17, 991, 809, 2601, 6455, 13803, 0 };
            const std::uint32_t dim1768JoeKuoD6Init[]   =   { 1, 1, 5, 5, 15, 1, 1, 171, 433, 887, 1813, 3431, 2471, 7803, 0 };
            const std::uint32_t dim1769JoeKuoD6Init[]   =   { 1, 3, 3, 15, 1, 15, 43, 179, 15, 949, 1881, 1027, 6989, 8955, 0 };
            const std::uint32_t dim1770JoeKuoD6Init[]   =   { 1, 3, 7, 13, 1, 3, 49, 183, 373, 175, 1733, 913, 929, 1065, 0 };
            const std::uint32_t dim1771JoeKuoD6Init[]   =   { 1, 3, 5, 7, 15, 51, 107, 115, 323, 357, 167, 2069, 7541, 9601, 0 };
            const std::uint32_t dim1772JoeKuoD6Init[]   =   { 1, 1, 3, 5, 5, 21, 31, 107, 21, 299, 1937, 43, 3673, 8155, 0 };
            const std::uint32_t dim1773JoeKuoD6Init[]   =   { 1, 3, 5, 11, 9, 55, 35, 113, 29, 99, 161, 1607, 8141, 4951, 0 };
            const std::uint32_t dim1774JoeKuoD6Init[]   =   { 1, 3, 7, 15, 25, 7, 113, 179, 213, 19, 1717, 1027, 2021, 11263, 0 };
            const std::uint32_t dim1775JoeKuoD6Init[]   =   { 1, 1, 5, 1, 31, 33, 85, 111, 67, 95, 2013, 2217, 871, 5329, 0 };
            const std::uint32_t dim1776JoeKuoD6Init[]   =   { 1, 1, 1, 7, 7, 63, 67, 145, 495, 419, 1945, 3437, 6255, 151, 0 };
            const std::uint32_t dim1777JoeKuoD6Init[]   =   { 1, 3, 5, 7, 17, 37, 97, 187, 215, 399, 1603, 2195, 5923, 769, 0 };
            const std::uint32_t dim1778JoeKuoD6Init[]   =   { 1, 1, 3, 9, 25, 1, 119, 193, 385, 861, 2005, 2769, 675, 767, 0 };
            const std::uint32_t dim1779JoeKuoD6Init[]   =   { 1, 3, 1, 15, 19, 7, 5, 227, 173, 383, 289, 461, 579, 3689, 0 };
            const std::uint32_t dim1780JoeKuoD6Init[]   =   { 1, 3, 1, 11, 1, 37, 93, 239, 465, 891, 1479, 921, 4439, 15265, 0 };
            const std::uint32_t dim1781JoeKuoD6Init[]   =   { 1, 1, 1, 13, 27, 61, 99, 69, 279, 655, 1853, 1593, 6319, 9003, 0 };
            const std::uint32_t dim1782JoeKuoD6Init[]   =   { 1, 1, 1, 11, 5, 7, 19, 7, 387, 303, 321, 931, 5809, 16029, 0 };
            const std::uint32_t dim1783JoeKuoD6Init[]   =   { 1, 1, 1, 15, 21, 55, 43, 107, 217, 687, 19, 3225, 3419, 9991, 0 };
            const std::uint32_t dim1784JoeKuoD6Init[]   =   { 1, 1, 7, 5, 7, 55, 79, 41, 317, 357, 859, 1205, 191, 9395, 0 };
            const std::uint32_t dim1785JoeKuoD6Init[]   =   { 1, 1, 3, 11, 3, 43, 7, 133, 115, 995, 1205, 1055, 4153, 10481, 0 };
            const std::uint32_t dim1786JoeKuoD6Init[]   =   { 1, 1, 7, 11, 31, 57, 53, 9, 459, 223, 1969, 3513, 7033, 8505, 0 };
            const std::uint32_t dim1787JoeKuoD6Init[]   =   { 1, 1, 3, 7, 17, 11, 115, 255, 281, 97, 1685, 2039, 2845, 11637, 0 };
            const std::uint32_t dim1788JoeKuoD6Init[]   =   { 1, 3, 7, 1, 23, 41, 69, 199, 53, 105, 657, 1453, 4429, 1101, 0 };
            const std::uint32_t dim1789JoeKuoD6Init[]   =   { 1, 3, 1, 5, 11, 33, 91, 131, 191, 73, 823, 117, 1053, 127, 0 };
            const std::uint32_t dim1790JoeKuoD6Init[]   =   { 1, 3, 7, 11, 7, 3, 21, 65, 187, 103, 1393, 1797, 6673, 1409, 0 };
            const std::uint32_t dim1791JoeKuoD6Init[]   =   { 1, 3, 7, 1, 31, 25, 25, 161, 299, 275, 417, 2267, 6861, 1255, 0 };
            const std::uint32_t dim1792JoeKuoD6Init[]   =   { 1, 3, 5, 13, 5, 11, 61, 155, 115, 1001, 747, 889, 3235, 5709, 0 };
            const std::uint32_t dim1793JoeKuoD6Init[]   =   { 1, 3, 7, 7, 7, 1, 97, 177, 507, 273, 1781, 3455, 5123, 15607, 0 };
            const std::uint32_t dim1794JoeKuoD6Init[]   =   { 1, 1, 7, 5, 1, 7, 59, 49, 147, 343, 97, 3517, 5611, 8705, 0 };
            const std::uint32_t dim1795JoeKuoD6Init[]   =   { 1, 1, 5, 13, 21, 29, 13, 21, 503, 515, 1217, 3905, 5513, 15849, 0 };
            const std::uint32_t dim1796JoeKuoD6Init[]   =   { 1, 3, 1, 9, 9, 39, 65, 111, 385, 757, 583, 2225, 2039, 2817, 0 };
            const std::uint32_t dim1797JoeKuoD6Init[]   =   { 1, 3, 3, 15, 23, 17, 63, 169, 503, 949, 849, 461, 6799, 669, 0 };
            const std::uint32_t dim1798JoeKuoD6Init[]   =   { 1, 1, 1, 3, 1, 41, 63, 159, 251, 457, 521, 1653, 623, 3287, 0 };
            const std::uint32_t dim1799JoeKuoD6Init[]   =   { 1, 1, 7, 3, 9, 1, 41, 37, 441, 921, 1415, 2955, 5841, 1451, 0 };
            const std::uint32_t dim1800JoeKuoD6Init[]   =   { 1, 1, 5, 11, 23, 29, 89, 185, 413, 357, 1131, 2369, 3835, 6233, 0 };
            const std::uint32_t dim1801JoeKuoD6Init[]   =   { 1, 1, 5, 15, 27, 35, 17, 73, 315, 911, 1761, 797, 5349, 3219, 0 };
            const std::uint32_t dim1802JoeKuoD6Init[]   =   { 1, 3, 7, 11, 21, 9, 119, 233, 249, 901, 189, 3625, 2691, 16201, 0 };
            const std::uint32_t dim1803JoeKuoD6Init[]   =   { 1, 3, 3, 13, 29, 61, 105, 145, 187, 79, 609, 321, 4289, 3933, 0 };
            const std::uint32_t dim1804JoeKuoD6Init[]   =   { 1, 3, 1, 15, 19, 63, 13, 185, 115, 219, 1021, 1205, 4273, 11521, 0 };
            const std::uint32_t dim1805JoeKuoD6Init[]   =   { 1, 1, 3, 3, 23, 31, 93, 153, 87, 947, 1039, 469, 4047, 8869, 0 };
            const std::uint32_t dim1806JoeKuoD6Init[]   =   { 1, 1, 1, 1, 9, 1, 85, 3, 15, 995, 455, 2769, 6781, 16203, 0 };
            const std::uint32_t dim1807JoeKuoD6Init[]   =   { 1, 1, 3, 3, 13, 7, 55, 215, 185, 367, 765, 441, 4497, 1521, 0 };
            const std::uint32_t dim1808JoeKuoD6Init[]   =   { 1, 1, 1, 5, 1, 31, 13, 95, 417, 735, 975, 3407, 4871, 16133, 0 };
            const std::uint32_t dim1809JoeKuoD6Init[]   =   { 1, 1, 3, 3, 5, 43, 111, 107, 419, 515, 1075, 3597, 1187, 4143, 0 };
            const std::uint32_t dim1810JoeKuoD6Init[]   =   { 1, 1, 3, 13, 31, 51, 83, 163, 489, 887, 863, 599, 9, 13861, 0 };
            const std::uint32_t dim1811JoeKuoD6Init[]   =   { 1, 3, 3, 3, 19, 27, 91, 115, 103, 969, 593, 3667, 1867, 15433, 0 };
            const std::uint32_t dim1812JoeKuoD6Init[]   =   { 1, 3, 3, 13, 7, 25, 47, 141, 57, 553, 1785, 1709, 7453, 2209, 0 };
            const std::uint32_t dim1813JoeKuoD6Init[]   =   { 1, 3, 1, 13, 11, 13, 71, 219, 5, 451, 2043, 1605, 6439, 12203, 0 };
            const std::uint32_t dim1814JoeKuoD6Init[]   =   { 1, 3, 1, 13, 5, 57, 61, 223, 401, 413, 321, 1365, 619, 12477, 0 };
            const std::uint32_t dim1815JoeKuoD6Init[]   =   { 1, 3, 1, 5, 25, 57, 89, 211, 195, 455, 1165, 3979, 6313, 5751, 0 };
            const std::uint32_t dim1816JoeKuoD6Init[]   =   { 1, 1, 1, 9, 31, 23, 71, 145, 89, 285, 1593, 1171, 5685, 15459, 0 };
            const std::uint32_t dim1817JoeKuoD6Init[]   =   { 1, 3, 7, 7, 9, 41, 65, 251, 65, 137, 1577, 3027, 5555, 2865, 0 };
            const std::uint32_t dim1818JoeKuoD6Init[]   =   { 1, 1, 5, 13, 27, 5, 125, 21, 171, 647, 983, 2921, 6623, 5695, 0 };
            const std::uint32_t dim1819JoeKuoD6Init[]   =   { 1, 1, 1, 13, 15, 9, 117, 197, 123, 953, 1191, 3657, 5757, 15957, 0 };
            const std::uint32_t dim1820JoeKuoD6Init[]   =   { 1, 1, 3, 7, 29, 13, 5, 175, 395, 127, 679, 255, 6055, 7639, 0 };
            const std::uint32_t dim1821JoeKuoD6Init[]   =   { 1, 3, 7, 15, 15, 51, 77, 147, 319, 147, 1775, 3983, 3175, 5723, 0 };
            const std::uint32_t dim1822JoeKuoD6Init[]   =   { 1, 3, 3, 3, 7, 11, 119, 41, 43, 153, 975, 679, 3081, 10359, 0 };
            const std::uint32_t dim1823JoeKuoD6Init[]   =   { 1, 1, 5, 13, 3, 7, 65, 67, 63, 399, 1561, 2789, 2083, 12289, 0 };
            const std::uint32_t dim1824JoeKuoD6Init[]   =   { 1, 1, 7, 3, 19, 53, 103, 67, 35, 865, 161, 93, 2533, 3851, 0 };
            const std::uint32_t dim1825JoeKuoD6Init[]   =   { 1, 1, 1, 11, 31, 9, 29, 189, 199, 817, 1571, 395, 345, 3777, 0 };
            const std::uint32_t dim1826JoeKuoD6Init[]   =   { 1, 3, 5, 11, 31, 3, 9, 67, 277, 735, 181, 2777, 3009, 7233, 0 };
            const std::uint32_t dim1827JoeKuoD6Init[]   =   { 1, 1, 3, 3, 17, 7, 17, 3, 375, 933, 237, 3919, 5409, 3355, 0 };
            const std::uint32_t dim1828JoeKuoD6Init[]   =   { 1, 3, 3, 5, 9, 27, 19, 77, 221, 3, 1965, 309, 3001, 15977, 0 };
            const std::uint32_t dim1829JoeKuoD6Init[]   =   { 1, 1, 5, 1, 3, 33, 35, 133, 37, 709, 627, 1705, 2525, 4307, 0 };
            const std::uint32_t dim1830JoeKuoD6Init[]   =   { 1, 1, 7, 3, 25, 21, 105, 55, 375, 681, 881, 1299, 5879, 459, 0 };
            const std::uint32_t dim1831JoeKuoD6Init[]   =   { 1, 3, 7, 1, 13, 7, 113, 103, 313, 515, 1041, 3683, 4619, 5093, 0 };
            const std::uint32_t dim1832JoeKuoD6Init[]   =   { 1, 1, 3, 7, 19, 43, 83, 37, 39, 133, 1759, 1171, 1521, 13717, 0 };
            const std::uint32_t dim1833JoeKuoD6Init[]   =   { 1, 1, 7, 13, 7, 35, 15, 155, 293, 1001, 157, 3883, 405, 1797, 0 };
            const std::uint32_t dim1834JoeKuoD6Init[]   =   { 1, 1, 3, 3, 13, 19, 125, 49, 333, 387, 339, 1815, 4503, 7359, 0 };
            const std::uint32_t dim1835JoeKuoD6Init[]   =   { 1, 1, 3, 13, 19, 19, 105, 225, 151, 27, 1251, 885, 4815, 7863, 0 };
            const std::uint32_t dim1836JoeKuoD6Init[]   =   { 1, 1, 1, 5, 7, 59, 17, 145, 77, 117, 1355, 1429, 2301, 16177, 0 };
            const std::uint32_t dim1837JoeKuoD6Init[]   =   { 1, 3, 3, 13, 5, 31, 119, 167, 459, 727, 1799, 2537, 695, 13637, 0 };
            const std::uint32_t dim1838JoeKuoD6Init[]   =   { 1, 3, 3, 3, 27, 51, 107, 85, 267, 57, 1279, 823, 6247, 3603, 0 };
            const std::uint32_t dim1839JoeKuoD6Init[]   =   { 1, 1, 7, 15, 29, 17, 67, 197, 215, 465, 109, 3461, 5269, 15287, 0 };
            const std::uint32_t dim1840JoeKuoD6Init[]   =   { 1, 1, 3, 5, 11, 15, 123, 53, 293, 797, 1105, 1777, 6509, 217, 0 };
            const std::uint32_t dim1841JoeKuoD6Init[]   =   { 1, 3, 3, 13, 3, 5, 109, 53, 203, 693, 871, 135, 369, 11149, 0 };
            const std::uint32_t dim1842JoeKuoD6Init[]   =   { 1, 3, 5, 15, 17, 43, 81, 235, 119, 817, 1777, 261, 8049, 4251, 0 };
            const std::uint32_t dim1843JoeKuoD6Init[]   =   { 1, 1, 3, 7, 7, 13, 87, 99, 481, 931, 1507, 651, 5267, 8281, 0 };
            const std::uint32_t dim1844JoeKuoD6Init[]   =   { 1, 3, 1, 13, 27, 43, 77, 225, 341, 163, 933, 429, 4943, 7781, 0 };
            const std::uint32_t dim1845JoeKuoD6Init[]   =   { 1, 1, 7, 1, 1, 49, 85, 211, 449, 479, 1395, 787, 5653, 14891, 0 };
            const std::uint32_t dim1846JoeKuoD6Init[]   =   { 1, 1, 5, 9, 25, 13, 49, 85, 125, 85, 1281, 3365, 4305, 11791, 0 };
            const std::uint32_t dim1847JoeKuoD6Init[]   =   { 1, 3, 1, 13, 3, 31, 117, 39, 43, 151, 663, 669, 1571, 5207, 0 };
            const std::uint32_t dim1848JoeKuoD6Init[]   =   { 1, 3, 7, 15, 17, 7, 79, 163, 37, 841, 1799, 1787, 4501, 3785, 0 };
            const std::uint32_t dim1849JoeKuoD6Init[]   =   { 1, 1, 3, 9, 1, 23, 67, 191, 449, 931, 1521, 2705, 887, 7037, 0 };
            const std::uint32_t dim1850JoeKuoD6Init[]   =   { 1, 1, 1, 1, 5, 13, 55, 161, 419, 577, 1703, 2589, 2651, 2873, 0 };
            const std::uint32_t dim1851JoeKuoD6Init[]   =   { 1, 3, 3, 3, 5, 19, 37, 169, 69, 1003, 1755, 3101, 1469, 8583, 0 };
            const std::uint32_t dim1852JoeKuoD6Init[]   =   { 1, 1, 1, 1, 11, 33, 105, 79, 283, 91, 299, 835, 3193, 5593, 0 };
            const std::uint32_t dim1853JoeKuoD6Init[]   =   { 1, 3, 3, 13, 25, 21, 81, 213, 465, 475, 331, 457, 61, 9511, 0 };
            const std::uint32_t dim1854JoeKuoD6Init[]   =   { 1, 1, 3, 11, 1, 11, 77, 95, 455, 949, 1999, 1833, 1275, 5631, 0 };
            const std::uint32_t dim1855JoeKuoD6Init[]   =   { 1, 1, 1, 1, 15, 25, 51, 137, 275, 451, 1179, 3595, 5177, 7105, 0 };
            const std::uint32_t dim1856JoeKuoD6Init[]   =   { 1, 3, 3, 3, 3, 59, 79, 143, 393, 583, 349, 3039, 7079, 14245, 0 };
            const std::uint32_t dim1857JoeKuoD6Init[]   =   { 1, 1, 7, 9, 21, 11, 123, 105, 53, 297, 803, 4025, 5421, 14527, 0 };
            const std::uint32_t dim1858JoeKuoD6Init[]   =   { 1, 3, 7, 11, 21, 15, 103, 109, 311, 321, 1217, 2777, 5457, 1823, 0 };
            const std::uint32_t dim1859JoeKuoD6Init[]   =   { 1, 3, 5, 11, 19, 31, 79, 89, 295, 413, 817, 499, 3699, 14411, 0 };
            const std::uint32_t dim1860JoeKuoD6Init[]   =   { 1, 1, 1, 5, 11, 3, 81, 13, 315, 841, 1543, 411, 6883, 6347, 0 };
            const std::uint32_t dim1861JoeKuoD6Init[]   =   { 1, 3, 3, 11, 23, 43, 23, 131, 17, 517, 995, 2687, 7443, 15085, 0 };
            const std::uint32_t dim1862JoeKuoD6Init[]   =   { 1, 1, 1, 1, 11, 57, 73, 9, 123, 905, 1763, 1789, 3701, 7131, 0 };
            const std::uint32_t dim1863JoeKuoD6Init[]   =   { 1, 1, 3, 5, 9, 53, 99, 229, 43, 207, 625, 1583, 6727, 15249, 0 };
            const std::uint32_t dim1864JoeKuoD6Init[]   =   { 1, 1, 7, 7, 17, 39, 91, 1, 297, 711, 225, 513, 7391, 291, 0 };
            const std::uint32_t dim1865JoeKuoD6Init[]   =   { 1, 1, 7, 11, 7, 55, 111, 129, 423, 521, 1807, 3015, 1449, 12321, 0 };
            const std::uint32_t dim1866JoeKuoD6Init[]   =   { 1, 3, 7, 3, 13, 9, 125, 187, 11, 485, 647, 275, 3495, 11989, 0 };
            const std::uint32_t dim1867JoeKuoD6Init[]   =   { 1, 1, 3, 11, 11, 25, 49, 33, 361, 105, 271, 3841, 4837, 2437, 30181, 0 };
            const std::uint32_t dim1868JoeKuoD6Init[]   =   { 1, 3, 5, 1, 27, 15, 119, 35, 159, 273, 1489, 3157, 5433, 3337, 26859, 0 };
            const std::uint32_t dim1869JoeKuoD6Init[]   =   { 1, 3, 5, 13, 23, 31, 97, 145, 41, 605, 1455, 59, 5389, 5527, 14447, 0 };
            const std::uint32_t dim1870JoeKuoD6Init[]   =   { 1, 1, 7, 9, 7, 41, 61, 193, 353, 879, 1805, 581, 5447, 11177, 7331, 0 };
            const std::uint32_t dim1871JoeKuoD6Init[]   =   { 1, 1, 7, 11, 29, 19, 55, 207, 361, 759, 63, 2255, 2119, 14671, 21783, 0 };
            const std::uint32_t dim1872JoeKuoD6Init[]   =   { 1, 3, 1, 13, 17, 7, 73, 179, 103, 23, 917, 1205, 4925, 1691, 5419, 0 };
            const std::uint32_t dim1873JoeKuoD6Init[]   =   { 1, 3, 5, 3, 15, 3, 9, 109, 227, 861, 867, 3529, 1535, 489, 22873, 0 };
            const std::uint32_t dim1874JoeKuoD6Init[]   =   { 1, 3, 3, 9, 15, 15, 95, 193, 385, 997, 1525, 1865, 1425, 4079, 14771, 0 };
            const std::uint32_t dim1875JoeKuoD6Init[]   =   { 1, 1, 3, 5, 5, 29, 49, 171, 171, 623, 1167, 3743, 1809, 12009, 7043, 0 };
            const std::uint32_t dim1876JoeKuoD6Init[]   =   { 1, 3, 7, 5, 23, 11, 87, 183, 299, 555, 1857, 489, 3505, 9161, 28763, 0 };
            const std::uint32_t dim1877JoeKuoD6Init[]   =   { 1, 3, 5, 9, 19, 21, 85, 127, 337, 439, 1183, 1891, 1877, 4373, 10451, 0 };
            const std::uint32_t dim1878JoeKuoD6Init[]   =   { 1, 3, 7, 13, 27, 17, 29, 83, 463, 385, 1167, 3453, 4523, 4759, 9321, 0 };
            const std::uint32_t dim1879JoeKuoD6Init[]   =   { 1, 1, 3, 7, 21, 59, 65, 83, 177, 763, 317, 2913, 7527, 5967, 17167, 0 };
            const std::uint32_t dim1880JoeKuoD6Init[]   =   { 1, 1, 7, 15, 13, 27, 49, 35, 253, 101, 1699, 355, 2181, 10859, 24221, 0 };
            const std::uint32_t dim1881JoeKuoD6Init[]   =   { 1, 1, 5, 1, 17, 17, 81, 91, 349, 655, 1373, 2225, 945, 899, 31801, 0 };
            const std::uint32_t dim1882JoeKuoD6Init[]   =   { 1, 3, 7, 11, 5, 1, 81, 53, 215, 587, 167, 4045, 5671, 5597, 13529, 0 };
            const std::uint32_t dim1883JoeKuoD6Init[]   =   { 1, 3, 5, 15, 1, 9, 59, 235, 315, 195, 909, 2237, 505, 10415, 28145, 0 };
            const std::uint32_t dim1884JoeKuoD6Init[]   =   { 1, 1, 1, 3, 9, 31, 41, 43, 275, 921, 25, 671, 5737, 11241, 4193, 0 };
            const std::uint32_t dim1885JoeKuoD6Init[]   =   { 1, 3, 3, 13, 29, 13, 95, 213, 317, 995, 1489, 3779, 3043, 8569, 28823, 0 };
            const std::uint32_t dim1886JoeKuoD6Init[]   =   { 1, 1, 7, 5, 9, 49, 125, 241, 87, 153, 1673, 3849, 7253, 1715, 11627, 0 };
            const std::uint32_t dim1887JoeKuoD6Init[]   =   { 1, 1, 3, 9, 27, 27, 19, 223, 63, 463, 1095, 1395, 6643, 11589, 2145, 0 };
            const std::uint32_t dim1888JoeKuoD6Init[]   =   { 1, 1, 3, 15, 21, 17, 45, 23, 357, 11, 1307, 1791, 2481, 2123, 24341, 0 };
            const std::uint32_t dim1889JoeKuoD6Init[]   =   { 1, 3, 5, 15, 31, 53, 117, 51, 433, 193, 1239, 3329, 2403, 12745, 32219, 0 };
            const std::uint32_t dim1890JoeKuoD6Init[]   =   { 1, 1, 5, 9, 7, 27, 9, 115, 417, 579, 83, 173, 4717, 15665, 27463, 0 };
            const std::uint32_t dim1891JoeKuoD6Init[]   =   { 1, 3, 5, 7, 9, 9, 31, 35, 249, 567, 331, 905, 5101, 14817, 14255, 0 };
            const std::uint32_t dim1892JoeKuoD6Init[]   =   { 1, 3, 7, 3, 1, 61, 29, 129, 119, 421, 1597, 2987, 3041, 7629, 23451, 0 };
            const std::uint32_t dim1893JoeKuoD6Init[]   =   { 1, 1, 7, 9, 13, 1, 99, 105, 107, 509, 989, 2259, 1009, 6827, 8903, 0 };
            const std::uint32_t dim1894JoeKuoD6Init[]   =   { 1, 3, 5, 15, 11, 29, 85, 29, 265, 105, 2035, 3349, 3543, 13903, 10213, 0 };
            const std::uint32_t dim1895JoeKuoD6Init[]   =   { 1, 3, 1, 1, 25, 19, 53, 139, 467, 485, 491, 3067, 7353, 13861, 25819, 0 };
            const std::uint32_t dim1896JoeKuoD6Init[]   =   { 1, 1, 5, 3, 3, 43, 41, 185, 45, 463, 351, 2823, 2519, 6705, 11395, 0 };
            const std::uint32_t dim1897JoeKuoD6Init[]   =   { 1, 3, 7, 13, 11, 15, 87, 221, 427, 673, 1631, 599, 3259, 10691, 31283, 0 };
            const std::uint32_t dim1898JoeKuoD6Init[]   =   { 1, 3, 5, 11, 9, 9, 15, 49, 275, 335, 1613, 3587, 5309, 14849, 26475, 0 };
            const std::uint32_t dim1899JoeKuoD6Init[]   =   { 1, 3, 7, 9, 29, 13, 79, 225, 381, 781, 1411, 2761, 7157, 14983, 19717, 0 };
            const std::uint32_t dim1900JoeKuoD6Init[]   =   { 1, 1, 7, 11, 29, 25, 117, 183, 101, 651, 653, 3157, 445, 14389, 23293, 0 };
            const std::uint32_t dim1901JoeKuoD6Init[]   =   { 1, 1, 1, 3, 5, 33, 73, 155, 473, 387, 591, 2045, 5965, 16299, 31499, 0 };
            const std::uint32_t dim1902JoeKuoD6Init[]   =   { 1, 3, 1, 7, 11, 33, 29, 21, 491, 937, 729, 4075, 975, 2461, 18991, 0 };
            const std::uint32_t dim1903JoeKuoD6Init[]   =   { 1, 3, 7, 15, 29, 39, 105, 111, 173, 943, 69, 295, 8175, 13037, 26131, 0 };
            const std::uint32_t dim1904JoeKuoD6Init[]   =   { 1, 1, 5, 15, 7, 5, 97, 147, 105, 887, 443, 2595, 5889, 10753, 1619, 0 };
            const std::uint32_t dim1905JoeKuoD6Init[]   =   { 1, 3, 3, 15, 11, 45, 87, 207, 353, 909, 1847, 323, 2283, 12885, 16415, 0 };
            const std::uint32_t dim1906JoeKuoD6Init[]   =   { 1, 1, 5, 3, 19, 33, 43, 79, 115, 653, 359, 2873, 4609, 12439, 6339, 0 };
            const std::uint32_t dim1907JoeKuoD6Init[]   =   { 1, 3, 7, 9, 17, 61, 49, 227, 291, 69, 1753, 3899, 483, 3187, 29041, 0 };
            const std::uint32_t dim1908JoeKuoD6Init[]   =   { 1, 3, 5, 3, 25, 35, 61, 211, 393, 199, 691, 1779, 6295, 13371, 15817, 0 };
            const std::uint32_t dim1909JoeKuoD6Init[]   =   { 1, 3, 7, 5, 7, 23, 37, 91, 245, 915, 579, 867, 6193, 1063, 17363, 0 };
            const std::uint32_t dim1910JoeKuoD6Init[]   =   { 1, 3, 7, 7, 23, 51, 41, 63, 375, 3, 159, 1889, 4419, 1687, 17977, 0 };
            const std::uint32_t dim1911JoeKuoD6Init[]   =   { 1, 1, 1, 7, 13, 11, 53, 43, 317, 325, 1749, 2423, 4123, 8595, 20773, 0 };
            const std::uint32_t dim1912JoeKuoD6Init[]   =   { 1, 1, 7, 7, 9, 9, 61, 113, 437, 213, 1407, 645, 4345, 807, 30411, 0 };
            const std::uint32_t dim1913JoeKuoD6Init[]   =   { 1, 3, 3, 11, 17, 39, 17, 113, 391, 385, 581, 2023, 7449, 10153, 22033, 0 };
            const std::uint32_t dim1914JoeKuoD6Init[]   =   { 1, 1, 3, 5, 29, 31, 101, 215, 379, 377, 1113, 2855, 7147, 14377, 25515, 0 };
            const std::uint32_t dim1915JoeKuoD6Init[]   =   { 1, 3, 5, 5, 13, 3, 121, 125, 227, 969, 11, 1115, 5657, 9209, 6117, 0 };
            const std::uint32_t dim1916JoeKuoD6Init[]   =   { 1, 3, 7, 15, 29, 17, 33, 123, 317, 301, 749, 1365, 5619, 605, 1613, 0 };
            const std::uint32_t dim1917JoeKuoD6Init[]   =   { 1, 3, 1, 15, 7, 53, 125, 249, 219, 655, 105, 2825, 1649, 12783, 19777, 0 };
            const std::uint32_t dim1918JoeKuoD6Init[]   =   { 1, 1, 7, 1, 25, 53, 19, 53, 157, 373, 1855, 495, 5065, 9465, 2313, 0 };
            const std::uint32_t dim1919JoeKuoD6Init[]   =   { 1, 3, 5, 13, 3, 57, 57, 161, 431, 415, 1859, 1033, 6349, 1577, 31579, 0 };
            const std::uint32_t dim1920JoeKuoD6Init[]   =   { 1, 1, 7, 5, 23, 63, 29, 221, 13, 965, 1997, 2265, 1583, 10491, 9551, 0 };
            const std::uint32_t dim1921JoeKuoD6Init[]   =   { 1, 1, 3, 13, 31, 25, 23, 61, 285, 5, 2005, 879, 795, 13299, 19685, 0 };
            const std::uint32_t dim1922JoeKuoD6Init[]   =   { 1, 1, 7, 1, 21, 45, 121, 89, 263, 543, 1333, 2711, 219, 10823, 26139, 0 };
            const std::uint32_t dim1923JoeKuoD6Init[]   =   { 1, 1, 3, 3, 27, 13, 19, 117, 161, 457, 1541, 295, 4953, 12125, 14503, 0 };
            const std::uint32_t dim1924JoeKuoD6Init[]   =   { 1, 3, 5, 3, 7, 63, 13, 247, 439, 681, 977, 2537, 6923, 10323, 7349, 0 };
            const std::uint32_t dim1925JoeKuoD6Init[]   =   { 1, 3, 5, 9, 3, 51, 81, 251, 349, 983, 581, 2515, 2281, 2849, 31915, 0 };
            const std::uint32_t dim1926JoeKuoD6Init[]   =   { 1, 3, 5, 3, 11, 63, 47, 137, 303, 627, 91, 2269, 7097, 2145, 31059, 0 };
            const std::uint32_t dim1927JoeKuoD6Init[]   =   { 1, 1, 3, 15, 13, 17, 53, 27, 133, 13, 117, 1837, 4103, 5843, 29153, 0 };
            const std::uint32_t dim1928JoeKuoD6Init[]   =   { 1, 1, 5, 13, 21, 33, 37, 253, 465, 209, 309, 49, 3209, 15677, 14569, 0 };
            const std::uint32_t dim1929JoeKuoD6Init[]   =   { 1, 1, 7, 15, 13, 21, 33, 203, 499, 141, 1155, 3893, 1663, 2115, 27459, 0 };
            const std::uint32_t dim1930JoeKuoD6Init[]   =   { 1, 3, 5, 11, 21, 9, 39, 157, 257, 273, 1257, 1831, 515, 7969, 20133, 0 };
            const std::uint32_t dim1931JoeKuoD6Init[]   =   { 1, 1, 3, 13, 19, 29, 15, 189, 103, 219, 1395, 517, 7425, 6585, 15865, 0 };
            const std::uint32_t dim1932JoeKuoD6Init[]   =   { 1, 1, 5, 11, 21, 31, 49, 151, 39, 537, 1783, 3449, 6915, 223, 11587, 0 };
            const std::uint32_t dim1933JoeKuoD6Init[]   =   { 1, 3, 3, 11, 7, 63, 69, 31, 27, 911, 1903, 2821, 7977, 12949, 32257, 0 };
            const std::uint32_t dim1934JoeKuoD6Init[]   =   { 1, 1, 7, 9, 25, 45, 23, 233, 511, 595, 1383, 1721, 6789, 12055, 21179, 0 };
            const std::uint32_t dim1935JoeKuoD6Init[]   =   { 1, 1, 7, 13, 1, 27, 123, 49, 439, 683, 501, 641, 1947, 6111, 25423, 0 };
            const std::uint32_t dim1936JoeKuoD6Init[]   =   { 1, 3, 3, 5, 1, 23, 57, 241, 243, 593, 2039, 1617, 2209, 5171, 9675, 0 };
            const std::uint32_t dim1937JoeKuoD6Init[]   =   { 1, 1, 1, 7, 5, 19, 83, 55, 481, 125, 177, 1021, 1139, 11403, 23099, 0 };
            const std::uint32_t dim1938JoeKuoD6Init[]   =   { 1, 1, 3, 5, 29, 39, 33, 217, 461, 907, 733, 3795, 4811, 12939, 27715, 0 };
            const std::uint32_t dim1939JoeKuoD6Init[]   =   { 1, 3, 7, 3, 7, 11, 39, 165, 495, 147, 999, 1827, 817, 603, 9293, 0 };
            const std::uint32_t dim1940JoeKuoD6Init[]   =   { 1, 3, 7, 15, 25, 53, 35, 15, 431, 733, 1213, 2907, 8087, 3939, 27363, 0 };
            const std::uint32_t dim1941JoeKuoD6Init[]   =   { 1, 3, 7, 13, 13, 9, 33, 27, 485, 183, 455, 3341, 2555, 4985, 8793, 0 };
            const std::uint32_t dim1942JoeKuoD6Init[]   =   { 1, 1, 1, 15, 25, 47, 75, 21, 205, 15, 1639, 3067, 1295, 11693, 16903, 0 };
            const std::uint32_t dim1943JoeKuoD6Init[]   =   { 1, 1, 1, 15, 3, 31, 93, 57, 43, 185, 251, 1899, 7885, 10829, 3609, 0 };
            const std::uint32_t dim1944JoeKuoD6Init[]   =   { 1, 1, 3, 1, 29, 9, 69, 223, 221, 537, 365, 3411, 5771, 15279, 5309, 0 };
            const std::uint32_t dim1945JoeKuoD6Init[]   =   { 1, 1, 7, 5, 1, 5, 125, 243, 213, 1003, 1571, 3355, 3981, 8781, 25993, 0 };
            const std::uint32_t dim1946JoeKuoD6Init[]   =   { 1, 1, 1, 13, 7, 19, 53, 243, 301, 75, 1183, 2723, 6687, 13, 16581, 0 };
            const std::uint32_t dim1947JoeKuoD6Init[]   =   { 1, 3, 1, 13, 17, 51, 91, 239, 437, 191, 1065, 2495, 5755, 3405, 8299, 0 };
            const std::uint32_t dim1948JoeKuoD6Init[]   =   { 1, 1, 5, 5, 11, 59, 21, 169, 299, 123, 1845, 2199, 2157, 14461, 10327, 0 };
            const std::uint32_t dim1949JoeKuoD6Init[]   =   { 1, 3, 7, 7, 19, 47, 51, 179, 41, 19, 1347, 2325, 8063, 5993, 15653, 0 };
            const std::uint32_t dim1950JoeKuoD6Init[]   =   { 1, 1, 1, 9, 25, 27, 7, 133, 223, 533, 719, 353, 7093, 8285, 10375, 0 };
            const std::uint32_t dim1951JoeKuoD6Init[]   =   { 1, 3, 5, 15, 31, 5, 67, 39, 441, 495, 977, 3699, 1435, 11385, 14567, 0 };
            const std::uint32_t dim1952JoeKuoD6Init[]   =   { 1, 1, 3, 15, 15, 39, 25, 33, 91, 523, 249, 4035, 769, 5181, 9691, 0 };
            const std::uint32_t dim1953JoeKuoD6Init[]   =   { 1, 1, 3, 3, 3, 57, 83, 187, 423, 165, 161, 3453, 2241, 981, 8429, 0 };
            const std::uint32_t dim1954JoeKuoD6Init[]   =   { 1, 1, 7, 15, 1, 17, 57, 189, 283, 11, 823, 3505, 7025, 11879, 15441, 0 };
            const std::uint32_t dim1955JoeKuoD6Init[]   =   { 1, 1, 3, 11, 1, 41, 7, 255, 385, 339, 607, 1405, 1473, 13697, 9491, 0 };
            const std::uint32_t dim1956JoeKuoD6Init[]   =   { 1, 1, 7, 15, 5, 9, 91, 99, 211, 233, 51, 2663, 1165, 9283, 18495, 0 };
            const std::uint32_t dim1957JoeKuoD6Init[]   =   { 1, 1, 3, 7, 21, 37, 13, 91, 39, 27, 1021, 2813, 5937, 6645, 3403, 0 };
            const std::uint32_t dim1958JoeKuoD6Init[]   =   { 1, 3, 1, 1, 29, 29, 5, 69, 399, 665, 1407, 3921, 2653, 11753, 18925, 0 };
            const std::uint32_t dim1959JoeKuoD6Init[]   =   { 1, 3, 7, 15, 13, 41, 39, 1, 437, 549, 161, 2315, 5631, 8335, 22661, 0 };
            const std::uint32_t dim1960JoeKuoD6Init[]   =   { 1, 1, 3, 1, 7, 17, 115, 61, 69, 955, 475, 3763, 8035, 927, 17893, 0 };
            const std::uint32_t dim1961JoeKuoD6Init[]   =   { 1, 3, 1, 13, 21, 59, 81, 145, 463, 145, 1941, 2777, 7453, 14229, 11281, 0 };
            const std::uint32_t dim1962JoeKuoD6Init[]   =   { 1, 1, 1, 15, 15, 11, 27, 165, 461, 395, 1645, 3611, 7463, 12379, 26787, 0 };
            const std::uint32_t dim1963JoeKuoD6Init[]   =   { 1, 1, 7, 9, 29, 19, 27, 123, 21, 149, 1643, 4001, 7207, 6769, 4647, 0 };
            const std::uint32_t dim1964JoeKuoD6Init[]   =   { 1, 1, 1, 11, 13, 9, 103, 139, 185, 587, 591, 1113, 2223, 11667, 32671, 0 };
            const std::uint32_t dim1965JoeKuoD6Init[]   =   { 1, 3, 1, 1, 31, 13, 19, 93, 229, 125, 1471, 2369, 3055, 10277, 28563, 0 };
            const std::uint32_t dim1966JoeKuoD6Init[]   =   { 1, 3, 7, 5, 7, 53, 99, 175, 161, 851, 617, 4027, 2357, 11199, 1931, 0 };
            const std::uint32_t dim1967JoeKuoD6Init[]   =   { 1, 3, 5, 11, 3, 31, 111, 179, 237, 845, 539, 1057, 259, 3417, 26637, 0 };
            const std::uint32_t dim1968JoeKuoD6Init[]   =   { 1, 1, 5, 3, 21, 49, 125, 119, 463, 403, 737, 1811, 3941, 13015, 29081, 0 };
            const std::uint32_t dim1969JoeKuoD6Init[]   =   { 1, 3, 5, 13, 5, 29, 69, 251, 313, 357, 663, 1097, 3307, 12845, 28495, 0 };
            const std::uint32_t dim1970JoeKuoD6Init[]   =   { 1, 3, 3, 5, 29, 17, 89, 15, 411, 409, 2013, 757, 4085, 12521, 11131, 0 };
            const std::uint32_t dim1971JoeKuoD6Init[]   =   { 1, 1, 1, 15, 7, 51, 3, 193, 493, 133, 381, 2027, 227, 6635, 12931, 0 };
            const std::uint32_t dim1972JoeKuoD6Init[]   =   { 1, 1, 1, 15, 7, 23, 99, 203, 323, 1007, 1465, 2887, 2215, 1787, 22069, 0 };
            const std::uint32_t dim1973JoeKuoD6Init[]   =   { 1, 1, 5, 9, 29, 59, 77, 151, 509, 313, 415, 3977, 5431, 8019, 8571, 0 };
            const std::uint32_t dim1974JoeKuoD6Init[]   =   { 1, 3, 1, 15, 19, 13, 57, 217, 87, 119, 25, 1149, 5667, 3765, 6959, 0 };
            const std::uint32_t dim1975JoeKuoD6Init[]   =   { 1, 3, 7, 13, 19, 31, 119, 3, 457, 117, 905, 361, 1483, 12405, 27005, 0 };
            const std::uint32_t dim1976JoeKuoD6Init[]   =   { 1, 3, 5, 11, 15, 35, 61, 77, 119, 51, 1753, 2765, 1091, 10573, 23595, 0 };
            const std::uint32_t dim1977JoeKuoD6Init[]   =   { 1, 3, 3, 7, 1, 35, 17, 93, 197, 511, 1253, 3031, 2739, 15127, 15147, 0 };
            const std::uint32_t dim1978JoeKuoD6Init[]   =   { 1, 3, 3, 1, 11, 55, 55, 107, 161, 75, 129, 2195, 2023, 4877, 25797, 0 };
            const std::uint32_t dim1979JoeKuoD6Init[]   =   { 1, 3, 5, 7, 23, 19, 113, 167, 167, 271, 1303, 125, 5057, 1323, 5165, 0 };
            const std::uint32_t dim1980JoeKuoD6Init[]   =   { 1, 1, 5, 3, 21, 31, 11, 119, 215, 483, 1535, 407, 6485, 15401, 30297, 0 };
            const std::uint32_t dim1981JoeKuoD6Init[]   =   { 1, 3, 5, 9, 21, 5, 77, 95, 443, 247, 913, 605, 365, 7465, 19707, 0 };
            const std::uint32_t dim1982JoeKuoD6Init[]   =   { 1, 3, 1, 7, 17, 59, 9, 35, 391, 767, 1493, 475, 4725, 7529, 31579, 0 };
            const std::uint32_t dim1983JoeKuoD6Init[]   =   { 1, 3, 3, 7, 31, 21, 61, 31, 421, 179, 273, 771, 5745, 10575, 32765, 0 };
            const std::uint32_t dim1984JoeKuoD6Init[]   =   { 1, 3, 5, 15, 27, 13, 125, 55, 423, 1021, 497, 3521, 6903, 15111, 8285, 0 };
            const std::uint32_t dim1985JoeKuoD6Init[]   =   { 1, 1, 5, 9, 13, 31, 105, 93, 421, 709, 643, 1079, 1533, 9149, 10799, 0 };
            const std::uint32_t dim1986JoeKuoD6Init[]   =   { 1, 3, 1, 11, 19, 29, 53, 199, 319, 247, 655, 3039, 6411, 12267, 14245, 0 };
            const std::uint32_t dim1987JoeKuoD6Init[]   =   { 1, 3, 1, 11, 9, 57, 5, 91, 469, 149, 259, 329, 5433, 6941, 15093, 0 };
            const std::uint32_t dim1988JoeKuoD6Init[]   =   { 1, 3, 1, 5, 5, 51, 59, 25, 455, 367, 1623, 441, 3155, 11695, 20767, 0 };
            const std::uint32_t dim1989JoeKuoD6Init[]   =   { 1, 3, 7, 7, 11, 49, 113, 95, 91, 389, 605, 1973, 2051, 2315, 22229, 0 };
            const std::uint32_t dim1990JoeKuoD6Init[]   =   { 1, 3, 5, 3, 19, 11, 99, 135, 433, 781, 1473, 885, 1105, 3573, 3739, 0 };
            const std::uint32_t dim1991JoeKuoD6Init[]   =   { 1, 3, 1, 11, 3, 25, 9, 227, 433, 723, 317, 139, 6627, 8067, 28439, 0 };
            const std::uint32_t dim1992JoeKuoD6Init[]   =   { 1, 1, 1, 9, 9, 9, 5, 63, 241, 215, 1991, 2949, 3943, 775, 31511, 0 };
            const std::uint32_t dim1993JoeKuoD6Init[]   =   { 1, 1, 3, 7, 17, 49, 35, 167, 131, 107, 1295, 2465, 4577, 11147, 29833, 0 };
            const std::uint32_t dim1994JoeKuoD6Init[]   =   { 1, 1, 5, 1, 5, 25, 119, 129, 391, 743, 1069, 2957, 349, 6891, 13635, 0 };
            const std::uint32_t dim1995JoeKuoD6Init[]   =   { 1, 3, 1, 7, 9, 31, 63, 253, 215, 51, 1347, 2361, 3125, 13049, 28461, 0 };
            const std::uint32_t dim1996JoeKuoD6Init[]   =   { 1, 1, 7, 9, 3, 31, 21, 163, 255, 47, 259, 535, 5461, 3349, 30649, 0 };
            const std::uint32_t dim1997JoeKuoD6Init[]   =   { 1, 3, 3, 13, 17, 33, 87, 47, 243, 709, 929, 3943, 3107, 3421, 13721, 0 };
            const std::uint32_t dim1998JoeKuoD6Init[]   =   { 1, 3, 5, 11, 25, 61, 61, 173, 397, 735, 2005, 3355, 8121, 11593, 27697, 0 };
            const std::uint32_t dim1999JoeKuoD6Init[]   =   { 1, 3, 5, 15, 17, 43, 63, 231, 275, 311, 1277, 2669, 7307, 2099, 9755, 0 };
            const std::uint32_t dim2000JoeKuoD6Init[]   =   { 1, 3, 5, 3, 25, 43, 71, 191, 9, 121, 1873, 3747, 7491, 14055, 24293, 0 };
            const std::uint32_t dim2001JoeKuoD6Init[]   =   { 1, 3, 5, 13, 17, 35, 113, 113, 385, 941, 39, 2705, 1225, 5167, 1373, 0 };
            const std::uint32_t dim2002JoeKuoD6Init[]   =   { 1, 3, 5, 5, 7, 35, 19, 105, 487, 71, 139, 627, 4187, 3183, 713, 0 };
            const std::uint32_t dim2003JoeKuoD6Init[]   =   { 1, 1, 5, 13, 29, 29, 103, 5, 157, 869, 1675, 423, 6689, 10697, 5303, 0 };
            const std::uint32_t dim2004JoeKuoD6Init[]   =   { 1, 1, 5, 1, 29, 31, 61, 111, 473, 963, 685, 1483, 2383, 8109, 8495, 0 };
            const std::uint32_t dim2005JoeKuoD6Init[]   =   { 1, 1, 5, 3, 19, 13, 95, 113, 217, 59, 1353, 1647, 3617, 3271, 2321, 0 };
            const std::uint32_t dim2006JoeKuoD6Init[]   =   { 1, 3, 5, 7, 25, 35, 59, 131, 309, 445, 415, 93, 1453, 8789, 30201, 0 };
            const std::uint32_t dim2007JoeKuoD6Init[]   =   { 1, 1, 5, 1, 5, 43, 71, 241, 123, 189, 831, 3469, 8093, 6187, 32721, 0 };
            const std::uint32_t dim2008JoeKuoD6Init[]   =   { 1, 3, 7, 5, 25, 31, 123, 171, 319, 379, 889, 2365, 4881, 12225, 16609, 0 };
            const std::uint32_t dim2009JoeKuoD6Init[]   =   { 1, 3, 1, 11, 27, 43, 121, 63, 291, 591, 811, 1995, 4777, 2083, 31385, 0 };
            const std::uint32_t dim2010JoeKuoD6Init[]   =   { 1, 1, 5, 11, 27, 53, 85, 187, 461, 823, 703, 399, 6925, 11517, 28697, 0 };
            const std::uint32_t dim2011JoeKuoD6Init[]   =   { 1, 1, 3, 5, 13, 11, 33, 121, 93, 717, 1275, 3877, 4247, 5845, 26909, 0 };
            const std::uint32_t dim2012JoeKuoD6Init[]   =   { 1, 3, 1, 9, 7, 5, 47, 199, 367, 561, 185, 2855, 5997, 2699, 7581, 0 };
            const std::uint32_t dim2013JoeKuoD6Init[]   =   { 1, 1, 5, 9, 23, 11, 71, 201, 61, 729, 1011, 3529, 663, 1413, 25675, 0 };
            const std::uint32_t dim2014JoeKuoD6Init[]   =   { 1, 3, 7, 13, 27, 21, 11, 127, 281, 487, 1217, 3129, 5541, 3129, 17783, 0 };
            const std::uint32_t dim2015JoeKuoD6Init[]   =   { 1, 1, 5, 9, 1, 29, 85, 193, 213, 743, 1473, 611, 391, 9405, 21137, 0 };
            const std::uint32_t dim2016JoeKuoD6Init[]   =   { 1, 3, 3, 3, 31, 63, 37, 147, 39, 351, 79, 3069, 2441, 8901, 8777, 0 };
            const std::uint32_t dim2017JoeKuoD6Init[]   =   { 1, 1, 7, 7, 25, 49, 55, 47, 441, 343, 1267, 1123, 5917, 14395, 10579, 0 };
            const std::uint32_t dim2018JoeKuoD6Init[]   =   { 1, 1, 7, 1, 13, 55, 55, 123, 103, 773, 125, 2145, 4743, 13347, 2589, 0 };
            const std::uint32_t dim2019JoeKuoD6Init[]   =   { 1, 3, 7, 3, 9, 33, 25, 183, 469, 213, 291, 75, 6725, 6847, 26745, 0 };
            const std::uint32_t dim2020JoeKuoD6Init[]   =   { 1, 3, 3, 7, 15, 43, 7, 79, 171, 21, 1767, 2537, 4285, 12007, 24039, 0 };
            const std::uint32_t dim2021JoeKuoD6Init[]   =   { 1, 3, 7, 13, 9, 61, 125, 23, 227, 879, 215, 1635, 2835, 883, 15939, 0 };
            const std::uint32_t dim2022JoeKuoD6Init[]   =   { 1, 1, 5, 13, 25, 45, 63, 43, 183, 829, 149, 989, 987, 3819, 12181, 0 };
            const std::uint32_t dim2023JoeKuoD6Init[]   =   { 1, 1, 3, 7, 19, 27, 35, 83, 135, 459, 785, 131, 2655, 3329, 3009, 0 };
            const std::uint32_t dim2024JoeKuoD6Init[]   =   { 1, 1, 7, 5, 11, 41, 9, 219, 475, 985, 1329, 3787, 1975, 4679, 8627, 0 };
            const std::uint32_t dim2025JoeKuoD6Init[]   =   { 1, 1, 7, 3, 1, 17, 91, 155, 3, 763, 1879, 233, 215, 2955, 25993, 0 };
            const std::uint32_t dim2026JoeKuoD6Init[]   =   { 1, 1, 1, 11, 25, 11, 23, 227, 453, 775, 1935, 3833, 4583, 269, 705, 0 };
            const std::uint32_t dim2027JoeKuoD6Init[]   =   { 1, 3, 3, 11, 7, 25, 105, 21, 449, 555, 1275, 3475, 5503, 15617, 813, 0 };
            const std::uint32_t dim2028JoeKuoD6Init[]   =   { 1, 3, 7, 13, 31, 37, 25, 255, 233, 663, 1155, 1563, 4775, 7449, 29949, 0 };
            const std::uint32_t dim2029JoeKuoD6Init[]   =   { 1, 1, 3, 1, 23, 51, 51, 137, 63, 809, 349, 2789, 6953, 10605, 18959, 0 };
            const std::uint32_t dim2030JoeKuoD6Init[]   =   { 1, 3, 3, 13, 21, 45, 15, 161, 393, 229, 437, 2967, 4019, 3893, 21305, 0 };
            const std::uint32_t dim2031JoeKuoD6Init[]   =   { 1, 1, 3, 7, 5, 11, 15, 211, 287, 131, 1847, 2569, 7881, 15669, 31037, 0 };
            const std::uint32_t dim2032JoeKuoD6Init[]   =   { 1, 3, 3, 15, 27, 19, 85, 251, 221, 639, 665, 3729, 5771, 7873, 28005, 0 };
            const std::uint32_t dim2033JoeKuoD6Init[]   =   { 1, 3, 7, 15, 15, 47, 93, 215, 343, 85, 1401, 1375, 2949, 13661, 25453, 0 };
            const std::uint32_t dim2034JoeKuoD6Init[]   =   { 1, 1, 1, 9, 7, 51, 53, 217, 471, 389, 551, 1141, 1767, 2237, 17797, 0 };
            const std::uint32_t dim2035JoeKuoD6Init[]   =   { 1, 1, 7, 9, 3, 29, 65, 29, 223, 591, 1719, 1049, 7643, 3853, 29867, 0 };
            const std::uint32_t dim2036JoeKuoD6Init[]   =   { 1, 1, 1, 11, 13, 41, 85, 29, 451, 387, 1783, 3733, 8033, 4711, 31643, 0 };
            const std::uint32_t dim2037JoeKuoD6Init[]   =   { 1, 3, 1, 11, 11, 57, 75, 153, 7, 373, 2011, 271, 469, 3267, 18969, 0 };
            const std::uint32_t dim2038JoeKuoD6Init[]   =   { 1, 1, 5, 3, 19, 43, 7, 243, 385, 293, 923, 843, 4895, 469, 8421, 0 };
            const std::uint32_t dim2039JoeKuoD6Init[]   =   { 1, 3, 1, 15, 29, 47, 17, 125, 471, 927, 349, 3859, 3059, 11483, 14791, 0 };
            const std::uint32_t dim2040JoeKuoD6Init[]   =   { 1, 3, 1, 11, 17, 17, 111, 109, 9, 213, 1313, 3903, 4411, 4329, 28277, 0 };
            const std::uint32_t dim2041JoeKuoD6Init[]   =   { 1, 3, 3, 15, 1, 55, 47, 69, 143, 789, 1149, 3833, 5053, 6949, 10569, 0 };
            const std::uint32_t dim2042JoeKuoD6Init[]   =   { 1, 3, 5, 7, 11, 15, 79, 83, 123, 937, 1115, 2775, 3041, 11869, 21167, 0 };
            const std::uint32_t dim2043JoeKuoD6Init[]   =   { 1, 3, 7, 13, 9, 47, 45, 221, 139, 923, 1661, 1379, 2485, 7233, 6035, 0 };
            const std::uint32_t dim2044JoeKuoD6Init[]   =   { 1, 1, 3, 3, 11, 55, 77, 3, 87, 693, 1991, 1145, 2783, 16207, 24569, 0 };
            const std::uint32_t dim2045JoeKuoD6Init[]   =   { 1, 1, 5, 11, 3, 35, 91, 9, 391, 927, 101, 1839, 3755, 10345, 16907, 0 };
            const std::uint32_t dim2046JoeKuoD6Init[]   =   { 1, 3, 5, 3, 5, 49, 79, 91, 205, 443, 1369, 197, 2537, 11219, 17765, 0 };
            const std::uint32_t dim2047JoeKuoD6Init[]   =   { 1, 1, 3, 15, 9, 7, 25, 25, 357, 247, 477, 421, 7679, 5987, 30079, 0 };
            const std::uint32_t dim2048JoeKuoD6Init[]   =   { 1, 1, 5, 3, 29, 5, 89, 117, 481, 491, 371, 389, 7101, 2253, 23617, 0 };
            const std::uint32_t dim2049JoeKuoD6Init[]   =   { 1, 1, 5, 13, 29, 59, 17, 181, 511, 291, 1991, 3499, 8177, 5559, 30045, 0 };
            const std::uint32_t dim2050JoeKuoD6Init[]   =   { 1, 3, 3, 11, 23, 31, 117, 217, 241, 115, 749, 945, 1897, 12253, 8473, 0 };
            const std::uint32_t dim2051JoeKuoD6Init[]   =   { 1, 1, 7, 15, 25, 47, 31, 1, 165, 311, 635, 3629, 1593, 8305, 30033, 0 };
            const std::uint32_t dim2052JoeKuoD6Init[]   =   { 1, 3, 5, 9, 3, 17, 101, 237, 379, 503, 49, 929, 1687, 3865, 26723, 0 };
            const std::uint32_t dim2053JoeKuoD6Init[]   =   { 1, 3, 5, 5, 15, 41, 1, 239, 53, 215, 1733, 827, 579, 4089, 6579, 0 };
            const std::uint32_t dim2054JoeKuoD6Init[]   =   { 1, 3, 1, 15, 15, 21, 35, 21, 403, 257, 1475, 2403, 4705, 11553, 203, 0 };
            const std::uint32_t dim2055JoeKuoD6Init[]   =   { 1, 3, 5, 11, 9, 53, 113, 9, 447, 511, 543, 3141, 7389, 11249, 431, 0 };
            const std::uint32_t dim2056JoeKuoD6Init[]   =   { 1, 3, 5, 9, 9, 11, 55, 93, 325, 411, 305, 2573, 6871, 12339, 6435, 0 };
            const std::uint32_t dim2057JoeKuoD6Init[]   =   { 1, 3, 3, 7, 31, 27, 21, 113, 99, 853, 365, 589, 3731, 10875, 12767, 0 };
            const std::uint32_t dim2058JoeKuoD6Init[]   =   { 1, 3, 1, 7, 15, 27, 31, 17, 275, 93, 1161, 2619, 1329, 7307, 587, 0 };
            const std::uint32_t dim2059JoeKuoD6Init[]   =   { 1, 3, 5, 9, 17, 47, 49, 237, 27, 193, 1237, 591, 5151, 5521, 31583, 0 };
            const std::uint32_t dim2060JoeKuoD6Init[]   =   { 1, 3, 5, 3, 13, 1, 27, 87, 43, 977, 305, 3293, 2475, 14571, 18321, 0 };
            const std::uint32_t dim2061JoeKuoD6Init[]   =   { 1, 1, 5, 7, 15, 13, 101, 1, 291, 807, 1711, 2277, 5573, 11051, 13133, 0 };
            const std::uint32_t dim2062JoeKuoD6Init[]   =   { 1, 3, 3, 1, 9, 3, 65, 81, 415, 733, 1527, 2747, 6069, 159, 7095, 0 };
            const std::uint32_t dim2063JoeKuoD6Init[]   =   { 1, 3, 3, 15, 27, 1, 71, 49, 231, 851, 2039, 613, 1899, 2537, 14511, 0 };
            const std::uint32_t dim2064JoeKuoD6Init[]   =   { 1, 1, 1, 11, 3, 41, 55, 23, 247, 1011, 581, 2363, 2745, 1337, 20931, 0 };
            const std::uint32_t dim2065JoeKuoD6Init[]   =   { 1, 1, 3, 11, 17, 61, 67, 255, 143, 357, 945, 3407, 5817, 4155, 23851, 0 };
            const std::uint32_t dim2066JoeKuoD6Init[]   =   { 1, 3, 5, 3, 23, 1, 75, 247, 265, 413, 1899, 2565, 6629, 15655, 16117, 0 };
            const std::uint32_t dim2067JoeKuoD6Init[]   =   { 1, 1, 1, 9, 11, 49, 11, 189, 223, 177, 1457, 1931, 163, 15905, 17297, 0 };
            const std::uint32_t dim2068JoeKuoD6Init[]   =   { 1, 3, 7, 13, 17, 1, 111, 189, 343, 961, 427, 2507, 2393, 8653, 6353, 0 };
            const std::uint32_t dim2069JoeKuoD6Init[]   =   { 1, 3, 7, 13, 23, 61, 59, 51, 313, 963, 791, 3681, 5637, 3965, 9263, 0 };
            const std::uint32_t dim2070JoeKuoD6Init[]   =   { 1, 3, 7, 7, 21, 53, 127, 141, 499, 859, 337, 2835, 3195, 4351, 32369, 0 };
            const std::uint32_t dim2071JoeKuoD6Init[]   =   { 1, 1, 7, 5, 1, 5, 53, 63, 497, 535, 35, 305, 4395, 9757, 13193, 0 };
            const std::uint32_t dim2072JoeKuoD6Init[]   =   { 1, 1, 5, 13, 13, 31, 59, 229, 211, 745, 1453, 3677, 3005, 7703, 23907, 0 };
            const std::uint32_t dim2073JoeKuoD6Init[]   =   { 1, 3, 5, 5, 7, 63, 17, 197, 493, 861, 499, 3015, 6349, 1815, 7437, 0 };
            const std::uint32_t dim2074JoeKuoD6Init[]   =   { 1, 1, 1, 13, 13, 37, 29, 189, 253, 1017, 321, 3145, 407, 7547, 17099, 0 };
            const std::uint32_t dim2075JoeKuoD6Init[]   =   { 1, 3, 3, 3, 23, 53, 69, 77, 175, 17, 1831, 841, 3851, 1295, 32107, 0 };
            const std::uint32_t dim2076JoeKuoD6Init[]   =   { 1, 3, 7, 13, 13, 39, 107, 237, 389, 729, 635, 3717, 3041, 3169, 14987, 0 };
            const std::uint32_t dim2077JoeKuoD6Init[]   =   { 1, 1, 3, 1, 25, 7, 69, 35, 495, 49, 659, 2783, 6051, 13875, 23927, 0 };
            const std::uint32_t dim2078JoeKuoD6Init[]   =   { 1, 3, 7, 5, 5, 25, 49, 7, 193, 493, 93, 657, 1515, 13975, 14155, 0 };
            const std::uint32_t dim2079JoeKuoD6Init[]   =   { 1, 3, 1, 1, 11, 15, 113, 45, 21, 595, 731, 3397, 4117, 9711, 16625, 0 };
            const std::uint32_t dim2080JoeKuoD6Init[]   =   { 1, 3, 3, 9, 19, 19, 59, 7, 105, 579, 599, 2859, 97, 14717, 15361, 0 };
            const std::uint32_t dim2081JoeKuoD6Init[]   =   { 1, 1, 1, 5, 27, 49, 113, 5, 367, 563, 1397, 2805, 3021, 3111, 20671, 0 };
            const std::uint32_t dim2082JoeKuoD6Init[]   =   { 1, 3, 3, 15, 27, 51, 99, 167, 109, 365, 1959, 1523, 6959, 14405, 18191, 0 };
            const std::uint32_t dim2083JoeKuoD6Init[]   =   { 1, 3, 1, 5, 21, 51, 125, 67, 123, 45, 1657, 51, 4825, 14081, 31049, 0 };
            const std::uint32_t dim2084JoeKuoD6Init[]   =   { 1, 1, 5, 7, 21, 59, 21, 249, 77, 793, 1687, 2561, 2241, 4321, 7477, 0 };
            const std::uint32_t dim2085JoeKuoD6Init[]   =   { 1, 1, 1, 7, 15, 35, 71, 29, 267, 611, 1813, 1823, 7039, 3299, 9919, 0 };
            const std::uint32_t dim2086JoeKuoD6Init[]   =   { 1, 3, 7, 11, 21, 59, 109, 213, 371, 785, 659, 1687, 4827, 6017, 19619, 0 };
            const std::uint32_t dim2087JoeKuoD6Init[]   =   { 1, 1, 3, 11, 27, 17, 1, 55, 367, 939, 333, 127, 5105, 2405, 28139, 0 };
            const std::uint32_t dim2088JoeKuoD6Init[]   =   { 1, 1, 7, 13, 5, 35, 59, 133, 509, 573, 625, 3857, 7935, 5279, 3727, 0 };
            const std::uint32_t dim2089JoeKuoD6Init[]   =   { 1, 1, 1, 7, 11, 47, 127, 157, 19, 403, 151, 1143, 7407, 8985, 32521, 0 };
            const std::uint32_t dim2090JoeKuoD6Init[]   =   { 1, 3, 1, 1, 5, 13, 105, 123, 63, 139, 1569, 1983, 563, 7175, 27705, 0 };
            const std::uint32_t dim2091JoeKuoD6Init[]   =   { 1, 1, 3, 13, 9, 35, 105, 227, 145, 21, 1369, 57, 393, 2921, 18511, 0 };
            const std::uint32_t dim2092JoeKuoD6Init[]   =   { 1, 3, 1, 7, 17, 61, 99, 187, 261, 281, 437, 2219, 5999, 1857, 18001, 0 };
            const std::uint32_t dim2093JoeKuoD6Init[]   =   { 1, 3, 3, 5, 1, 59, 67, 45, 451, 439, 2005, 3607, 3, 7167, 14227, 0 };
            const std::uint32_t dim2094JoeKuoD6Init[]   =   { 1, 3, 3, 3, 29, 19, 25, 251, 275, 733, 1749, 4021, 871, 3227, 13701, 0 };
            const std::uint32_t dim2095JoeKuoD6Init[]   =   { 1, 3, 3, 13, 27, 53, 57, 243, 491, 521, 1921, 1037, 5013, 5703, 15261, 0 };
            const std::uint32_t dim2096JoeKuoD6Init[]   =   { 1, 3, 1, 11, 13, 57, 1, 15, 123, 533, 785, 335, 1423, 14269, 3483, 0 };
            const std::uint32_t dim2097JoeKuoD6Init[]   =   { 1, 3, 7, 13, 15, 55, 5, 139, 385, 47, 1981, 1291, 7397, 12925, 29445, 0 };
            const std::uint32_t dim2098JoeKuoD6Init[]   =   { 1, 1, 7, 1, 23, 23, 59, 93, 117, 57, 63, 3047, 4849, 11637, 25311, 0 };
            const std::uint32_t dim2099JoeKuoD6Init[]   =   { 1, 1, 7, 13, 19, 37, 25, 203, 477, 447, 1345, 3485, 2099, 13347, 11621, 0 };
            const std::uint32_t dim2100JoeKuoD6Init[]   =   { 1, 1, 7, 3, 11, 23, 81, 17, 41, 735, 1149, 3253, 7665, 8291, 22293, 0 };
            const std::uint32_t dim2101JoeKuoD6Init[]   =   { 1, 1, 5, 3, 15, 9, 57, 167, 463, 493, 747, 1947, 6471, 1111, 31619, 0 };
            const std::uint32_t dim2102JoeKuoD6Init[]   =   { 1, 1, 5, 15, 7, 15, 107, 205, 325, 167, 1749, 927, 3589, 6127, 7617, 0 };
            const std::uint32_t dim2103JoeKuoD6Init[]   =   { 1, 1, 1, 13, 21, 25, 83, 147, 411, 399, 1423, 2279, 3661, 7591, 17429, 0 };
            const std::uint32_t dim2104JoeKuoD6Init[]   =   { 1, 1, 1, 9, 5, 17, 69, 205, 243, 647, 473, 1717, 1977, 10725, 2913, 0 };
            const std::uint32_t dim2105JoeKuoD6Init[]   =   { 1, 1, 3, 5, 5, 37, 103, 15, 485, 641, 1761, 3755, 6997, 10985, 11773, 0 };
            const std::uint32_t dim2106JoeKuoD6Init[]   =   { 1, 1, 5, 13, 9, 51, 87, 195, 97, 807, 1801, 961, 6341, 4307, 29105, 0 };
            const std::uint32_t dim2107JoeKuoD6Init[]   =   { 1, 3, 1, 13, 9, 35, 83, 61, 387, 817, 951, 3993, 7831, 8479, 23941, 0 };
            const std::uint32_t dim2108JoeKuoD6Init[]   =   { 1, 1, 7, 11, 19, 47, 75, 37, 91, 337, 953, 1169, 163, 2259, 24713, 0 };
            const std::uint32_t dim2109JoeKuoD6Init[]   =   { 1, 1, 1, 11, 13, 15, 83, 171, 159, 87, 619, 2973, 2653, 13725, 12499, 0 };
            const std::uint32_t dim2110JoeKuoD6Init[]   =   { 1, 3, 5, 3, 5, 63, 119, 25, 343, 269, 553, 2183, 959, 3825, 22189, 0 };
            const std::uint32_t dim2111JoeKuoD6Init[]   =   { 1, 1, 5, 15, 5, 37, 89, 109, 497, 1013, 265, 669, 1859, 2647, 3445, 0 };
            const std::uint32_t dim2112JoeKuoD6Init[]   =   { 1, 3, 3, 9, 21, 21, 15, 245, 107, 649, 367, 1601, 7279, 15783, 4943, 0 };
            const std::uint32_t dim2113JoeKuoD6Init[]   =   { 1, 3, 3, 15, 5, 41, 125, 113, 159, 161, 1191, 3491, 3531, 55, 20857, 0 };
            const std::uint32_t dim2114JoeKuoD6Init[]   =   { 1, 3, 5, 9, 21, 57, 21, 195, 99, 193, 1915, 2923, 6349, 15085, 24929, 0 };
            const std::uint32_t dim2115JoeKuoD6Init[]   =   { 1, 1, 1, 11, 31, 11, 73, 141, 361, 621, 1021, 2067, 5115, 12665, 26845, 0 };
            const std::uint32_t dim2116JoeKuoD6Init[]   =   { 1, 1, 1, 3, 29, 11, 43, 61, 209, 923, 1753, 1937, 843, 205, 8367, 0 };
            const std::uint32_t dim2117JoeKuoD6Init[]   =   { 1, 1, 1, 5, 15, 33, 119, 209, 215, 973, 1775, 815, 6693, 7957, 14517, 0 };
            const std::uint32_t dim2118JoeKuoD6Init[]   =   { 1, 1, 1, 5, 17, 57, 27, 147, 489, 59, 1439, 2279, 445, 11791, 19739, 0 };
            const std::uint32_t dim2119JoeKuoD6Init[]   =   { 1, 3, 1, 7, 11, 55, 1, 83, 305, 17, 1909, 405, 2325, 5293, 28559, 0 };
            const std::uint32_t dim2120JoeKuoD6Init[]   =   { 1, 3, 3, 7, 11, 27, 103, 157, 455, 1005, 2033, 3145, 1919, 15723, 25197, 0 };
            const std::uint32_t dim2121JoeKuoD6Init[]   =   { 1, 1, 5, 11, 15, 51, 37, 131, 503, 1007, 1795, 2421, 1335, 7413, 21741, 0 };
            const std::uint32_t dim2122JoeKuoD6Init[]   =   { 1, 1, 3, 1, 23, 63, 69, 83, 419, 283, 583, 123, 7725, 2243, 8403, 0 };
            const std::uint32_t dim2123JoeKuoD6Init[]   =   { 1, 1, 5, 5, 27, 45, 109, 17, 299, 65, 351, 947, 1165, 10723, 2053, 0 };
            const std::uint32_t dim2124JoeKuoD6Init[]   =   { 1, 1, 3, 3, 23, 61, 115, 253, 1, 931, 1481, 3187, 441, 14735, 27207, 0 };
            const std::uint32_t dim2125JoeKuoD6Init[]   =   { 1, 1, 5, 3, 25, 11, 83, 141, 359, 343, 901, 1629, 731, 12841, 14357, 0 };
            const std::uint32_t dim2126JoeKuoD6Init[]   =   { 1, 1, 3, 9, 7, 45, 97, 3, 299, 217, 663, 1527, 6379, 4527, 26147, 0 };
            const std::uint32_t dim2127JoeKuoD6Init[]   =   { 1, 1, 7, 9, 11, 53, 9, 203, 337, 713, 1517, 719, 4587, 11443, 26905, 0 };
            const std::uint32_t dim2128JoeKuoD6Init[]   =   { 1, 1, 7, 9, 11, 41, 125, 213, 237, 377, 361, 3231, 4223, 3263, 12655, 0 };
            const std::uint32_t dim2129JoeKuoD6Init[]   =   { 1, 3, 7, 7, 7, 33, 99, 19, 117, 273, 985, 107, 3831, 10135, 19423, 0 };
            const std::uint32_t dim2130JoeKuoD6Init[]   =   { 1, 1, 5, 15, 25, 41, 13, 125, 449, 169, 1149, 4021, 5663, 3077, 19163, 0 };
            const std::uint32_t dim2131JoeKuoD6Init[]   =   { 1, 3, 5, 9, 25, 57, 47, 103, 269, 51, 1805, 2503, 6687, 8065, 12045, 0 };
            const std::uint32_t dim2132JoeKuoD6Init[]   =   { 1, 3, 5, 7, 3, 35, 87, 225, 189, 229, 931, 3293, 1347, 1427, 3269, 0 };
            const std::uint32_t dim2133JoeKuoD6Init[]   =   { 1, 1, 1, 3, 5, 31, 61, 19, 247, 9, 1667, 343, 559, 2703, 3763, 0 };
            const std::uint32_t dim2134JoeKuoD6Init[]   =   { 1, 3, 5, 15, 31, 19, 57, 187, 109, 121, 1287, 2269, 659, 16235, 1273, 0 };
            const std::uint32_t dim2135JoeKuoD6Init[]   =   { 1, 1, 1, 3, 5, 47, 59, 243, 255, 97, 1959, 1723, 1347, 3019, 26989, 0 };
            const std::uint32_t dim2136JoeKuoD6Init[]   =   { 1, 3, 3, 15, 29, 35, 75, 67, 497, 731, 193, 3307, 3579, 12005, 7209, 0 };
            const std::uint32_t dim2137JoeKuoD6Init[]   =   { 1, 1, 5, 9, 13, 35, 79, 213, 51, 983, 1927, 1793, 5037, 5463, 965, 0 };
            const std::uint32_t dim2138JoeKuoD6Init[]   =   { 1, 1, 7, 11, 5, 41, 7, 83, 15, 411, 1775, 3515, 6755, 3249, 16425, 0 };
            const std::uint32_t dim2139JoeKuoD6Init[]   =   { 1, 3, 5, 1, 19, 61, 3, 19, 395, 819, 1331, 179, 5225, 5333, 3601, 0 };
            const std::uint32_t dim2140JoeKuoD6Init[]   =   { 1, 1, 3, 9, 7, 5, 87, 15, 387, 609, 1465, 277, 987, 8377, 903, 0 };
            const std::uint32_t dim2141JoeKuoD6Init[]   =   { 1, 1, 1, 3, 15, 11, 123, 107, 355, 333, 285, 1801, 6989, 1549, 25791, 0 };
            const std::uint32_t dim2142JoeKuoD6Init[]   =   { 1, 1, 7, 13, 27, 13, 73, 111, 481, 227, 1091, 365, 5713, 5087, 27217, 0 };
            const std::uint32_t dim2143JoeKuoD6Init[]   =   { 1, 3, 3, 15, 1, 55, 95, 213, 377, 405, 139, 1867, 2175, 4217, 28813, 0 };
            const std::uint32_t dim2144JoeKuoD6Init[]   =   { 1, 3, 5, 11, 21, 43, 109, 155, 181, 901, 1951, 507, 4389, 10815, 3141, 0 };
            const std::uint32_t dim2145JoeKuoD6Init[]   =   { 1, 1, 1, 15, 17, 11, 43, 215, 501, 19, 259, 3479, 6381, 6927, 31247, 0 };
            const std::uint32_t dim2146JoeKuoD6Init[]   =   { 1, 3, 5, 15, 19, 61, 75, 41, 391, 95, 865, 1441, 7993, 13979, 24663, 0 };
            const std::uint32_t dim2147JoeKuoD6Init[]   =   { 1, 3, 1, 3, 21, 15, 115, 213, 1, 645, 777, 1517, 2543, 11223, 3633, 0 };
            const std::uint32_t dim2148JoeKuoD6Init[]   =   { 1, 3, 5, 3, 9, 57, 39, 211, 407, 65, 1795, 2805, 2799, 8691, 1987, 0 };
            const std::uint32_t dim2149JoeKuoD6Init[]   =   { 1, 1, 3, 13, 17, 55, 47, 113, 29, 139, 1301, 3303, 1129, 13947, 29821, 0 };
            const std::uint32_t dim2150JoeKuoD6Init[]   =   { 1, 1, 3, 13, 5, 35, 97, 151, 477, 409, 1397, 3399, 4421, 15929, 6163, 0 };
            const std::uint32_t dim2151JoeKuoD6Init[]   =   { 1, 3, 1, 9, 21, 51, 99, 133, 149, 763, 623, 173, 4311, 11081, 1095, 0 };
            const std::uint32_t dim2152JoeKuoD6Init[]   =   { 1, 3, 7, 15, 13, 3, 99, 3, 195, 907, 1335, 1355, 7977, 5773, 32383, 0 };
            const std::uint32_t dim2153JoeKuoD6Init[]   =   { 1, 1, 3, 9, 17, 43, 43, 217, 475, 917, 1373, 1677, 4871, 9619, 16657, 0 };
            const std::uint32_t dim2154JoeKuoD6Init[]   =   { 1, 3, 3, 7, 31, 31, 55, 11, 73, 693, 25, 417, 1195, 6225, 32279, 0 };
            const std::uint32_t dim2155JoeKuoD6Init[]   =   { 1, 3, 5, 9, 21, 57, 127, 149, 79, 379, 1609, 2543, 6473, 16033, 27191, 0 };
            const std::uint32_t dim2156JoeKuoD6Init[]   =   { 1, 1, 5, 1, 13, 9, 81, 153, 297, 789, 1749, 2819, 3961, 11231, 24927, 0 };
            const std::uint32_t dim2157JoeKuoD6Init[]   =   { 1, 3, 5, 3, 23, 61, 45, 43, 43, 133, 1481, 1543, 2991, 13739, 10287, 0 };
            const std::uint32_t dim2158JoeKuoD6Init[]   =   { 1, 1, 3, 9, 25, 43, 31, 177, 337, 193, 1083, 1, 991, 9725, 8379, 0 };
            const std::uint32_t dim2159JoeKuoD6Init[]   =   { 1, 3, 5, 11, 13, 33, 65, 83, 421, 149, 409, 2443, 7423, 8847, 29599, 0 };
            const std::uint32_t dim2160JoeKuoD6Init[]   =   { 1, 1, 5, 11, 11, 1, 23, 225, 77, 585, 1505, 2525, 739, 10915, 25733, 0 };
            const std::uint32_t dim2161JoeKuoD6Init[]   =   { 1, 3, 7, 13, 7, 55, 3, 223, 415, 521, 1865, 2349, 5663, 7455, 16569, 0 };
            const std::uint32_t dim2162JoeKuoD6Init[]   =   { 1, 1, 7, 13, 1, 45, 121, 49, 463, 99, 1061, 2559, 5087, 13389, 11035, 0 };
            const std::uint32_t dim2163JoeKuoD6Init[]   =   { 1, 3, 7, 11, 31, 51, 35, 235, 385, 1023, 1771, 2013, 5437, 4877, 22119, 0 };
            const std::uint32_t dim2164JoeKuoD6Init[]   =   { 1, 3, 3, 11, 21, 3, 11, 119, 81, 737, 1093, 2377, 4055, 1121, 15767, 0 };
            const std::uint32_t dim2165JoeKuoD6Init[]   =   { 1, 1, 5, 13, 9, 3, 83, 217, 387, 249, 1047, 1861, 4103, 15367, 24545, 0 };
            const std::uint32_t dim2166JoeKuoD6Init[]   =   { 1, 3, 3, 1, 5, 37, 43, 183, 383, 463, 937, 1165, 1481, 959, 17047, 0 };
            const std::uint32_t dim2167JoeKuoD6Init[]   =   { 1, 1, 3, 5, 7, 43, 127, 243, 81, 1021, 165, 753, 4711, 12965, 22049, 0 };
            const std::uint32_t dim2168JoeKuoD6Init[]   =   { 1, 1, 5, 5, 3, 61, 65, 53, 425, 89, 5, 1467, 1395, 9579, 8961, 0 };
            const std::uint32_t dim2169JoeKuoD6Init[]   =   { 1, 3, 7, 13, 11, 35, 123, 21, 83, 689, 667, 1203, 5959, 15697, 26885, 0 };
            const std::uint32_t dim2170JoeKuoD6Init[]   =   { 1, 1, 5, 13, 9, 49, 41, 101, 291, 339, 1067, 657, 4453, 1137, 21131, 0 };
            const std::uint32_t dim2171JoeKuoD6Init[]   =   { 1, 3, 3, 3, 17, 61, 11, 213, 27, 805, 1691, 1057, 6011, 11941, 18883, 0 };
            const std::uint32_t dim2172JoeKuoD6Init[]   =   { 1, 3, 1, 7, 3, 51, 5, 63, 121, 3, 245, 2631, 3737, 16121, 26803, 0 };
            const std::uint32_t dim2173JoeKuoD6Init[]   =   { 1, 3, 1, 1, 23, 51, 79, 19, 161, 107, 609, 3489, 3389, 4035, 2427, 0 };
            const std::uint32_t dim2174JoeKuoD6Init[]   =   { 1, 3, 1, 1, 17, 11, 101, 101, 373, 63, 1641, 285, 1333, 165, 14025, 0 };
            const std::uint32_t dim2175JoeKuoD6Init[]   =   { 1, 1, 1, 5, 1, 51, 83, 137, 45, 1019, 821, 867, 6055, 10443, 9857, 0 };
            const std::uint32_t dim2176JoeKuoD6Init[]   =   { 1, 3, 1, 5, 17, 23, 25, 181, 429, 495, 317, 3219, 5963, 13945, 9969, 0 };
            const std::uint32_t dim2177JoeKuoD6Init[]   =   { 1, 3, 7, 3, 3, 15, 123, 191, 369, 177, 1697, 2113, 3889, 5201, 21839, 0 };
            const std::uint32_t dim2178JoeKuoD6Init[]   =   { 1, 3, 1, 11, 21, 39, 51, 139, 271, 605, 1007, 3513, 3365, 3781, 6799, 0 };
            const std::uint32_t dim2179JoeKuoD6Init[]   =   { 1, 1, 7, 5, 13, 19, 47, 165, 249, 405, 255, 1295, 4513, 14395, 5587, 0 };
            const std::uint32_t dim2180JoeKuoD6Init[]   =   { 1, 1, 3, 7, 5, 17, 99, 1, 393, 31, 621, 797, 6113, 16003, 32043, 0 };
            const std::uint32_t dim2181JoeKuoD6Init[]   =   { 1, 3, 5, 13, 11, 21, 65, 81, 147, 443, 775, 3671, 7029, 11749, 3339, 0 };
            const std::uint32_t dim2182JoeKuoD6Init[]   =   { 1, 3, 7, 1, 23, 33, 99, 177, 161, 577, 1729, 617, 3465, 11787, 17577, 0 };
            const std::uint32_t dim2183JoeKuoD6Init[]   =   { 1, 1, 5, 7, 15, 15, 53, 193, 97, 255, 1223, 545, 5153, 873, 24525, 0 };
            const std::uint32_t dim2184JoeKuoD6Init[]   =   { 1, 3, 5, 1, 7, 57, 47, 121, 383, 835, 1709, 2363, 4731, 12163, 7001, 0 };
            const std::uint32_t dim2185JoeKuoD6Init[]   =   { 1, 3, 3, 11, 19, 33, 63, 99, 387, 95, 783, 1009, 6373, 4021, 7685, 0 };
            const std::uint32_t dim2186JoeKuoD6Init[]   =   { 1, 1, 1, 15, 25, 33, 73, 135, 335, 785, 935, 1927, 5847, 10501, 7719, 0 };
            const std::uint32_t dim2187JoeKuoD6Init[]   =   { 1, 1, 5, 3, 27, 45, 71, 215, 489, 157, 1189, 2577, 6901, 10219, 3025, 0 };
            const std::uint32_t dim2188JoeKuoD6Init[]   =   { 1, 1, 7, 7, 21, 3, 97, 225, 101, 159, 293, 2789, 7955, 14829, 1209, 0 };
            const std::uint32_t dim2189JoeKuoD6Init[]   =   { 1, 3, 1, 5, 23, 41, 83, 63, 361, 195, 1707, 2081, 5363, 6327, 179, 0 };
            const std::uint32_t dim2190JoeKuoD6Init[]   =   { 1, 1, 3, 1, 21, 51, 59, 67, 175, 363, 825, 2971, 3321, 8837, 11805, 0 };
            const std::uint32_t dim2191JoeKuoD6Init[]   =   { 1, 3, 7, 1, 19, 3, 15, 21, 429, 675, 1589, 2615, 2575, 1537, 7139, 0 };
            const std::uint32_t dim2192JoeKuoD6Init[]   =   { 1, 3, 3, 5, 21, 29, 17, 115, 345, 397, 523, 1699, 7043, 11173, 3023, 0 };
            const std::uint32_t dim2193JoeKuoD6Init[]   =   { 1, 1, 5, 7, 19, 63, 99, 175, 91, 433, 153, 3749, 517, 13667, 7423, 0 };
            const std::uint32_t dim2194JoeKuoD6Init[]   =   { 1, 3, 7, 3, 25, 23, 53, 149, 65, 551, 1231, 365, 6637, 15137, 16319, 0 };
            const std::uint32_t dim2195JoeKuoD6Init[]   =   { 1, 3, 7, 13, 5, 45, 11, 151, 323, 31, 1749, 409, 6753, 10503, 14991, 0 };
            const std::uint32_t dim2196JoeKuoD6Init[]   =   { 1, 3, 7, 3, 5, 21, 29, 117, 321, 341, 1811, 3619, 4337, 12255, 8629, 0 };
            const std::uint32_t dim2197JoeKuoD6Init[]   =   { 1, 3, 7, 3, 7, 3, 5, 221, 407, 671, 1763, 3669, 2353, 8175, 23489, 0 };
            const std::uint32_t dim2198JoeKuoD6Init[]   =   { 1, 1, 3, 7, 11, 55, 53, 185, 247, 35, 1823, 513, 1379, 11827, 20069, 0 };
            const std::uint32_t dim2199JoeKuoD6Init[]   =   { 1, 3, 3, 5, 29, 51, 73, 191, 185, 961, 881, 2019, 5651, 1019, 15587, 0 };
            const std::uint32_t dim2200JoeKuoD6Init[]   =   { 1, 3, 7, 13, 7, 55, 59, 5, 417, 829, 453, 2339, 587, 13283, 797, 0 };
            const std::uint32_t dim2201JoeKuoD6Init[]   =   { 1, 3, 7, 3, 11, 41, 75, 85, 65, 149, 1583, 529, 2707, 11479, 7109, 0 };
            const std::uint32_t dim2202JoeKuoD6Init[]   =   { 1, 3, 7, 9, 13, 57, 37, 243, 91, 613, 665, 171, 1631, 13737, 2377, 0 };
            const std::uint32_t dim2203JoeKuoD6Init[]   =   { 1, 1, 3, 7, 5, 43, 97, 53, 477, 793, 999, 3647, 2555, 7371, 19295, 0 };
            const std::uint32_t dim2204JoeKuoD6Init[]   =   { 1, 1, 7, 1, 1, 9, 99, 253, 317, 817, 1559, 2081, 2529, 14611, 15997, 0 };
            const std::uint32_t dim2205JoeKuoD6Init[]   =   { 1, 3, 3, 1, 5, 41, 57, 121, 387, 441, 709, 1511, 7045, 8409, 13297, 0 };
            const std::uint32_t dim2206JoeKuoD6Init[]   =   { 1, 1, 1, 13, 29, 57, 63, 183, 327, 473, 1943, 213, 3973, 16289, 2739, 0 };
            const std::uint32_t dim2207JoeKuoD6Init[]   =   { 1, 3, 7, 9, 25, 15, 75, 185, 335, 881, 1041, 3339, 4471, 6823, 21121, 0 };
            const std::uint32_t dim2208JoeKuoD6Init[]   =   { 1, 3, 3, 13, 23, 3, 57, 117, 511, 927, 771, 3229, 949, 15487, 11963, 0 };
            const std::uint32_t dim2209JoeKuoD6Init[]   =   { 1, 1, 3, 7, 27, 19, 55, 207, 331, 705, 1945, 797, 7125, 10493, 16585, 0 };
            const std::uint32_t dim2210JoeKuoD6Init[]   =   { 1, 3, 1, 1, 29, 7, 91, 93, 459, 93, 1501, 1927, 6415, 16255, 9823, 0 };
            const std::uint32_t dim2211JoeKuoD6Init[]   =   { 1, 1, 5, 5, 31, 11, 97, 179, 505, 807, 877, 4003, 4377, 8851, 4239, 0 };
            const std::uint32_t dim2212JoeKuoD6Init[]   =   { 1, 1, 3, 5, 11, 25, 17, 131, 23, 95, 311, 1429, 2029, 13091, 23739, 0 };
            const std::uint32_t dim2213JoeKuoD6Init[]   =   { 1, 1, 3, 11, 13, 27, 33, 127, 481, 117, 1127, 1619, 6493, 8507, 6615, 0 };
            const std::uint32_t dim2214JoeKuoD6Init[]   =   { 1, 3, 1, 13, 19, 27, 89, 101, 27, 235, 1579, 1701, 4421, 16037, 16239, 0 };
            const std::uint32_t dim2215JoeKuoD6Init[]   =   { 1, 3, 1, 15, 1, 15, 3, 117, 317, 475, 1691, 2423, 5519, 1703, 2969, 0 };
            const std::uint32_t dim2216JoeKuoD6Init[]   =   { 1, 1, 3, 1, 13, 15, 19, 37, 237, 467, 1321, 453, 2169, 13313, 31499, 0 };
            const std::uint32_t dim2217JoeKuoD6Init[]   =   { 1, 1, 3, 15, 29, 55, 31, 199, 85, 285, 967, 367, 3941, 151, 20587, 0 };
            const std::uint32_t dim2218JoeKuoD6Init[]   =   { 1, 3, 7, 15, 7, 13, 31, 35, 117, 543, 1179, 3441, 3039, 11225, 30229, 0 };
            const std::uint32_t dim2219JoeKuoD6Init[]   =   { 1, 1, 3, 15, 3, 43, 1, 63, 353, 395, 1775, 3493, 5175, 13193, 25343, 0 };
            const std::uint32_t dim2220JoeKuoD6Init[]   =   { 1, 3, 3, 15, 17, 25, 57, 205, 411, 83, 1877, 2093, 5599, 12115, 8751, 0 };
            const std::uint32_t dim2221JoeKuoD6Init[]   =   { 1, 1, 1, 11, 15, 9, 115, 99, 85, 887, 987, 4015, 7077, 3739, 21505, 0 };
            const std::uint32_t dim2222JoeKuoD6Init[]   =   { 1, 3, 1, 11, 25, 39, 127, 37, 329, 273, 1531, 3211, 7115, 15501, 26575, 0 };
            const std::uint32_t dim2223JoeKuoD6Init[]   =   { 1, 1, 5, 13, 15, 3, 3, 101, 431, 645, 493, 723, 8083, 1423, 14879, 0 };
            const std::uint32_t dim2224JoeKuoD6Init[]   =   { 1, 3, 3, 5, 31, 35, 37, 131, 259, 849, 325, 3403, 3627, 3295, 30885, 0 };
            const std::uint32_t dim2225JoeKuoD6Init[]   =   { 1, 3, 7, 1, 9, 3, 31, 201, 379, 907, 1005, 3333, 7457, 2533, 30357, 0 };
            const std::uint32_t dim2226JoeKuoD6Init[]   =   { 1, 3, 1, 9, 7, 7, 95, 103, 121, 157, 895, 2683, 5839, 12403, 14327, 0 };
            const std::uint32_t dim2227JoeKuoD6Init[]   =   { 1, 3, 7, 3, 13, 5, 55, 233, 3, 855, 859, 1115, 3883, 8041, 3353, 0 };
            const std::uint32_t dim2228JoeKuoD6Init[]   =   { 1, 1, 5, 9, 3, 55, 99, 79, 263, 831, 1579, 205, 5673, 1999, 14879, 0 };
            const std::uint32_t dim2229JoeKuoD6Init[]   =   { 1, 3, 1, 5, 17, 25, 85, 19, 189, 141, 877, 667, 4461, 11915, 23247, 0 };
            const std::uint32_t dim2230JoeKuoD6Init[]   =   { 1, 1, 5, 5, 1, 35, 15, 219, 469, 725, 1793, 3683, 3661, 15627, 30197, 0 };
            const std::uint32_t dim2231JoeKuoD6Init[]   =   { 1, 1, 7, 5, 27, 3, 41, 153, 431, 487, 759, 1345, 6735, 9937, 26277, 0 };
            const std::uint32_t dim2232JoeKuoD6Init[]   =   { 1, 1, 1, 11, 11, 13, 41, 121, 265, 465, 1447, 5, 3407, 1907, 10037, 0 };
            const std::uint32_t dim2233JoeKuoD6Init[]   =   { 1, 3, 5, 9, 15, 63, 5, 7, 407, 83, 365, 3687, 7721, 6973, 16967, 0 };
            const std::uint32_t dim2234JoeKuoD6Init[]   =   { 1, 1, 7, 7, 5, 41, 75, 155, 417, 565, 1199, 1111, 2823, 10703, 22561, 0 };
            const std::uint32_t dim2235JoeKuoD6Init[]   =   { 1, 3, 7, 5, 7, 43, 39, 185, 105, 327, 1977, 1137, 3261, 10583, 11661, 0 };
            const std::uint32_t dim2236JoeKuoD6Init[]   =   { 1, 3, 7, 7, 19, 19, 103, 137, 169, 273, 1357, 3413, 7647, 10531, 32489, 0 };
            const std::uint32_t dim2237JoeKuoD6Init[]   =   { 1, 1, 3, 13, 13, 3, 81, 23, 161, 295, 735, 2031, 1027, 15513, 20165, 0 };
            const std::uint32_t dim2238JoeKuoD6Init[]   =   { 1, 1, 5, 1, 15, 1, 91, 35, 375, 207, 1417, 1115, 2237, 11749, 8509, 0 };
            const std::uint32_t dim2239JoeKuoD6Init[]   =   { 1, 3, 7, 3, 25, 51, 49, 219, 195, 417, 1523, 3953, 5739, 7499, 27071, 0 };
            const std::uint32_t dim2240JoeKuoD6Init[]   =   { 1, 1, 3, 11, 23, 29, 19, 81, 421, 633, 513, 547, 7545, 29, 11909, 0 };
            const std::uint32_t dim2241JoeKuoD6Init[]   =   { 1, 1, 1, 7, 13, 61, 33, 243, 221, 231, 111, 879, 2861, 1795, 27531, 0 };
            const std::uint32_t dim2242JoeKuoD6Init[]   =   { 1, 3, 7, 3, 19, 21, 1, 141, 159, 605, 969, 3013, 6583, 2447, 19919, 0 };
            const std::uint32_t dim2243JoeKuoD6Init[]   =   { 1, 3, 7, 3, 31, 9, 91, 83, 29, 873, 929, 43, 2253, 12539, 23951, 0 };
            const std::uint32_t dim2244JoeKuoD6Init[]   =   { 1, 1, 5, 3, 31, 15, 87, 105, 319, 973, 1489, 3417, 3377, 15749, 2357, 0 };
            const std::uint32_t dim2245JoeKuoD6Init[]   =   { 1, 1, 3, 15, 7, 23, 3, 81, 383, 419, 713, 997, 6873, 593, 285, 0 };
            const std::uint32_t dim2246JoeKuoD6Init[]   =   { 1, 3, 3, 1, 29, 13, 29, 101, 441, 693, 2039, 2951, 5921, 12129, 12053, 0 };
            const std::uint32_t dim2247JoeKuoD6Init[]   =   { 1, 1, 3, 15, 9, 29, 97, 117, 421, 433, 1017, 125, 3607, 9415, 6843, 0 };
            const std::uint32_t dim2248JoeKuoD6Init[]   =   { 1, 3, 5, 9, 11, 13, 75, 155, 413, 75, 109, 1599, 6161, 16115, 12621, 0 };
            const std::uint32_t dim2249JoeKuoD6Init[]   =   { 1, 3, 3, 3, 11, 13, 49, 225, 401, 599, 1815, 1643, 7853, 13305, 25195, 0 };
            const std::uint32_t dim2250JoeKuoD6Init[]   =   { 1, 3, 7, 5, 15, 11, 27, 95, 387, 931, 549, 2179, 3397, 15883, 16563, 0 };
            const std::uint32_t dim2251JoeKuoD6Init[]   =   { 1, 1, 7, 3, 9, 39, 121, 5, 453, 27, 1747, 657, 2593, 1289, 12577, 0 };
            const std::uint32_t dim2252JoeKuoD6Init[]   =   { 1, 3, 7, 5, 25, 25, 109, 49, 185, 985, 631, 803, 3865, 8955, 17901, 0 };
            const std::uint32_t dim2253JoeKuoD6Init[]   =   { 1, 1, 3, 13, 3, 59, 47, 49, 139, 275, 1471, 2995, 5593, 14011, 18741, 0 };
            const std::uint32_t dim2254JoeKuoD6Init[]   =   { 1, 1, 5, 15, 29, 11, 97, 225, 245, 291, 1873, 2365, 767, 3419, 14943, 0 };
            const std::uint32_t dim2255JoeKuoD6Init[]   =   { 1, 3, 3, 5, 15, 17, 19, 209, 359, 891, 1375, 2003, 7247, 5299, 28841, 0 };
            const std::uint32_t dim2256JoeKuoD6Init[]   =   { 1, 3, 7, 7, 9, 55, 105, 35, 77, 47, 1023, 13, 2901, 847, 10265, 0 };
            const std::uint32_t dim2257JoeKuoD6Init[]   =   { 1, 3, 7, 7, 7, 5, 65, 233, 141, 277, 1333, 2357, 443, 7257, 21979, 0 };
            const std::uint32_t dim2258JoeKuoD6Init[]   =   { 1, 3, 5, 11, 13, 63, 41, 87, 193, 737, 1085, 2317, 7869, 10149, 12163, 0 };
            const std::uint32_t dim2259JoeKuoD6Init[]   =   { 1, 3, 1, 1, 7, 57, 75, 235, 461, 857, 155, 2679, 5925, 2565, 10881, 0 };
            const std::uint32_t dim2260JoeKuoD6Init[]   =   { 1, 1, 7, 15, 13, 41, 63, 135, 433, 387, 1943, 2249, 5469, 11679, 28661, 0 };
            const std::uint32_t dim2261JoeKuoD6Init[]   =   { 1, 3, 3, 13, 5, 3, 103, 161, 367, 649, 789, 1179, 4163, 5699, 16787, 0 };
            const std::uint32_t dim2262JoeKuoD6Init[]   =   { 1, 3, 7, 7, 31, 13, 45, 141, 113, 769, 1035, 457, 6709, 14989, 27311, 0 };
            const std::uint32_t dim2263JoeKuoD6Init[]   =   { 1, 1, 3, 1, 1, 43, 119, 145, 111, 593, 1139, 417, 637, 4437, 17285, 0 };
            const std::uint32_t dim2264JoeKuoD6Init[]   =   { 1, 3, 5, 9, 9, 33, 19, 99, 201, 685, 1793, 2621, 6857, 8769, 5623, 0 };
            const std::uint32_t dim2265JoeKuoD6Init[]   =   { 1, 3, 5, 5, 23, 43, 27, 189, 325, 415, 215, 1253, 3599, 1215, 10093, 0 };
            const std::uint32_t dim2266JoeKuoD6Init[]   =   { 1, 1, 3, 13, 11, 35, 113, 173, 503, 19, 1459, 503, 5363, 3967, 13945, 0 };
            const std::uint32_t dim2267JoeKuoD6Init[]   =   { 1, 1, 5, 11, 31, 49, 13, 173, 199, 623, 1231, 2495, 6581, 7957, 25321, 0 };
            const std::uint32_t dim2268JoeKuoD6Init[]   =   { 1, 3, 1, 9, 23, 3, 79, 149, 505, 937, 1839, 3701, 1673, 8589, 8031, 0 };
            const std::uint32_t dim2269JoeKuoD6Init[]   =   { 1, 3, 3, 5, 21, 27, 107, 11, 505, 407, 177, 3593, 4729, 12773, 11685, 0 };
            const std::uint32_t dim2270JoeKuoD6Init[]   =   { 1, 3, 1, 11, 29, 49, 79, 53, 61, 895, 2035, 563, 5613, 6065, 6207, 0 };
            const std::uint32_t dim2271JoeKuoD6Init[]   =   { 1, 1, 3, 7, 1, 53, 3, 215, 99, 865, 1749, 3533, 4305, 1243, 28463, 0 };
            const std::uint32_t dim2272JoeKuoD6Init[]   =   { 1, 1, 1, 13, 31, 59, 115, 53, 403, 909, 847, 103, 4967, 10623, 30073, 0 };
            const std::uint32_t dim2273JoeKuoD6Init[]   =   { 1, 1, 7, 5, 27, 1, 119, 83, 457, 81, 395, 811, 6221, 14337, 541, 0 };
            const std::uint32_t dim2274JoeKuoD6Init[]   =   { 1, 1, 5, 5, 5, 53, 83, 117, 269, 327, 875, 101, 3343, 715, 26339, 0 };
            const std::uint32_t dim2275JoeKuoD6Init[]   =   { 1, 1, 1, 11, 31, 39, 121, 147, 305, 383, 1211, 1897, 7647, 11687, 18907, 0 };
            const std::uint32_t dim2276JoeKuoD6Init[]   =   { 1, 3, 3, 15, 23, 53, 17, 85, 395, 503, 61, 1745, 4713, 4641, 13787, 0 };
            const std::uint32_t dim2277JoeKuoD6Init[]   =   { 1, 1, 7, 7, 27, 1, 105, 29, 287, 37, 959, 975, 4427, 4705, 10175, 0 };
            const std::uint32_t dim2278JoeKuoD6Init[]   =   { 1, 3, 3, 5, 7, 63, 57, 199, 27, 107, 1095, 3923, 6969, 713, 11619, 0 };
            const std::uint32_t dim2279JoeKuoD6Init[]   =   { 1, 3, 5, 1, 5, 49, 85, 45, 449, 45, 49, 3419, 1109, 455, 15917, 0 };
            const std::uint32_t dim2280JoeKuoD6Init[]   =   { 1, 1, 1, 5, 13, 15, 39, 27, 467, 85, 1537, 3055, 1977, 8829, 25231, 0 };
            const std::uint32_t dim2281JoeKuoD6Init[]   =   { 1, 1, 1, 15, 1, 47, 23, 121, 147, 547, 1865, 1491, 779, 3515, 12667, 0 };
            const std::uint32_t dim2282JoeKuoD6Init[]   =   { 1, 3, 3, 1, 19, 5, 77, 101, 1, 721, 1149, 2967, 4925, 11889, 16655, 0 };
            const std::uint32_t dim2283JoeKuoD6Init[]   =   { 1, 1, 1, 7, 1, 35, 95, 239, 127, 855, 1031, 455, 7631, 6039, 21983, 0 };
            const std::uint32_t dim2284JoeKuoD6Init[]   =   { 1, 3, 7, 9, 23, 43, 75, 105, 335, 223, 1825, 3217, 413, 7473, 30005, 0 };
            const std::uint32_t dim2285JoeKuoD6Init[]   =   { 1, 1, 5, 15, 29, 9, 43, 145, 223, 523, 511, 323, 5955, 11141, 22533, 0 };
            const std::uint32_t dim2286JoeKuoD6Init[]   =   { 1, 1, 3, 1, 13, 61, 93, 133, 461, 233, 383, 693, 7347, 3165, 27493, 0 };
            const std::uint32_t dim2287JoeKuoD6Init[]   =   { 1, 3, 7, 1, 13, 45, 113, 207, 53, 1007, 815, 1145, 2937, 289, 22195, 0 };
            const std::uint32_t dim2288JoeKuoD6Init[]   =   { 1, 3, 5, 5, 19, 17, 113, 89, 19, 1023, 1625, 3277, 697, 5187, 15433, 0 };
            const std::uint32_t dim2289JoeKuoD6Init[]   =   { 1, 1, 3, 13, 21, 15, 15, 197, 409, 391, 1993, 2475, 3189, 4431, 29585, 0 };
            const std::uint32_t dim2290JoeKuoD6Init[]   =   { 1, 1, 5, 5, 31, 7, 111, 231, 187, 543, 45, 3863, 3811, 4573, 4437, 0 };
            const std::uint32_t dim2291JoeKuoD6Init[]   =   { 1, 3, 3, 7, 19, 7, 123, 23, 79, 513, 189, 3663, 1291, 13257, 8949, 0 };
            const std::uint32_t dim2292JoeKuoD6Init[]   =   { 1, 1, 5, 13, 3, 53, 109, 133, 157, 223, 651, 3059, 6055, 14455, 26903, 0 };
            const std::uint32_t dim2293JoeKuoD6Init[]   =   { 1, 1, 7, 1, 23, 63, 59, 229, 17, 199, 643, 637, 7631, 13647, 7399, 0 };
            const std::uint32_t dim2294JoeKuoD6Init[]   =   { 1, 1, 1, 3, 1, 51, 119, 67, 335, 543, 913, 3565, 4795, 13405, 7463, 0 };
            const std::uint32_t dim2295JoeKuoD6Init[]   =   { 1, 1, 5, 3, 31, 5, 91, 97, 23, 223, 837, 1353, 1929, 12043, 10039, 0 };
            const std::uint32_t dim2296JoeKuoD6Init[]   =   { 1, 3, 5, 7, 19, 3, 79, 171, 301, 687, 1545, 355, 4709, 12965, 16797, 0 };
            const std::uint32_t dim2297JoeKuoD6Init[]   =   { 1, 3, 5, 11, 11, 49, 111, 123, 251, 569, 1605, 401, 5439, 13519, 8847, 0 };
            const std::uint32_t dim2298JoeKuoD6Init[]   =   { 1, 3, 1, 3, 3, 53, 7, 55, 369, 633, 181, 4037, 2993, 15815, 8661, 0 };
            const std::uint32_t dim2299JoeKuoD6Init[]   =   { 1, 1, 1, 13, 31, 29, 75, 167, 279, 597, 539, 1791, 8013, 4387, 9717, 0 };
            const std::uint32_t dim2300JoeKuoD6Init[]   =   { 1, 1, 5, 7, 17, 15, 99, 183, 211, 49, 225, 3143, 4537, 13141, 23375, 0 };
            const std::uint32_t dim2301JoeKuoD6Init[]   =   { 1, 1, 3, 5, 3, 59, 25, 149, 467, 69, 1939, 1007, 2765, 4693, 29815, 0 };
            const std::uint32_t dim2302JoeKuoD6Init[]   =   { 1, 3, 1, 3, 17, 33, 119, 189, 447, 251, 879, 177, 5395, 13487, 9587, 0 };
            const std::uint32_t dim2303JoeKuoD6Init[]   =   { 1, 3, 3, 7, 15, 31, 115, 3, 21, 817, 475, 1849, 6041, 12541, 18701, 0 };
            const std::uint32_t dim2304JoeKuoD6Init[]   =   { 1, 1, 5, 13, 31, 33, 7, 115, 361, 587, 1919, 1007, 3537, 7493, 19357, 0 };
            const std::uint32_t dim2305JoeKuoD6Init[]   =   { 1, 3, 7, 13, 23, 35, 15, 111, 123, 633, 805, 1983, 2109, 14477, 4985, 0 };
            const std::uint32_t dim2306JoeKuoD6Init[]   =   { 1, 3, 3, 11, 25, 13, 11, 205, 97, 893, 927, 1291, 4007, 13593, 29693, 0 };
            const std::uint32_t dim2307JoeKuoD6Init[]   =   { 1, 3, 5, 15, 9, 13, 121, 89, 215, 823, 1389, 1581, 8095, 4707, 16061, 0 };
            const std::uint32_t dim2308JoeKuoD6Init[]   =   { 1, 3, 1, 3, 23, 39, 83, 23, 47, 941, 1419, 2389, 5699, 7519, 5829, 0 };
            const std::uint32_t dim2309JoeKuoD6Init[]   =   { 1, 3, 1, 9, 23, 43, 79, 237, 93, 203, 695, 225, 5645, 3591, 16775, 0 };
            const std::uint32_t dim2310JoeKuoD6Init[]   =   { 1, 3, 5, 3, 15, 19, 89, 129, 375, 125, 225, 1323, 2267, 11607, 17937, 0 };
            const std::uint32_t dim2311JoeKuoD6Init[]   =   { 1, 3, 3, 1, 31, 37, 93, 133, 377, 959, 707, 621, 7179, 15493, 30287, 0 };
            const std::uint32_t dim2312JoeKuoD6Init[]   =   { 1, 3, 7, 13, 5, 13, 15, 1, 37, 525, 1641, 2829, 6139, 4069, 19187, 0 };
            const std::uint32_t dim2313JoeKuoD6Init[]   =   { 1, 3, 3, 9, 17, 3, 67, 97, 375, 845, 403, 973, 3919, 2275, 31627, 0 };
            const std::uint32_t dim2314JoeKuoD6Init[]   =   { 1, 1, 3, 3, 25, 7, 91, 67, 271, 465, 481, 3477, 5229, 241, 8411, 0 };
            const std::uint32_t dim2315JoeKuoD6Init[]   =   { 1, 1, 1, 11, 1, 41, 109, 115, 75, 787, 309, 2887, 179, 9073, 13895, 0 };
            const std::uint32_t dim2316JoeKuoD6Init[]   =   { 1, 3, 3, 15, 11, 31, 113, 91, 303, 907, 1933, 2167, 7799, 11821, 20659, 0 };
            const std::uint32_t dim2317JoeKuoD6Init[]   =   { 1, 3, 1, 15, 27, 17, 21, 41, 99, 137, 1397, 929, 5819, 11977, 6201, 0 };
            const std::uint32_t dim2318JoeKuoD6Init[]   =   { 1, 1, 7, 13, 21, 29, 47, 239, 287, 305, 899, 2711, 1723, 3315, 199, 0 };
            const std::uint32_t dim2319JoeKuoD6Init[]   =   { 1, 1, 1, 3, 31, 21, 101, 149, 107, 761, 1197, 1703, 4803, 8411, 10649, 0 };
            const std::uint32_t dim2320JoeKuoD6Init[]   =   { 1, 1, 5, 15, 23, 45, 109, 221, 85, 619, 169, 1013, 3305, 9451, 26189, 0 };
            const std::uint32_t dim2321JoeKuoD6Init[]   =   { 1, 3, 5, 13, 7, 57, 19, 153, 231, 627, 565, 1595, 6309, 5037, 25505, 0 };
            const std::uint32_t dim2322JoeKuoD6Init[]   =   { 1, 1, 7, 7, 1, 45, 43, 79, 271, 59, 219, 2255, 1785, 7919, 24061, 0 };
            const std::uint32_t dim2323JoeKuoD6Init[]   =   { 1, 3, 7, 5, 31, 57, 57, 231, 33, 227, 531, 679, 1141, 85, 19777, 0 };
            const std::uint32_t dim2324JoeKuoD6Init[]   =   { 1, 1, 3, 15, 11, 59, 59, 169, 459, 693, 907, 1191, 3783, 12809, 6263, 0 };
            const std::uint32_t dim2325JoeKuoD6Init[]   =   { 1, 1, 7, 13, 19, 21, 105, 65, 267, 141, 1547, 781, 7295, 13565, 17775, 0 };
            const std::uint32_t dim2326JoeKuoD6Init[]   =   { 1, 3, 3, 5, 31, 63, 97, 155, 477, 661, 329, 797, 2539, 4061, 10537, 0 };
            const std::uint32_t dim2327JoeKuoD6Init[]   =   { 1, 3, 3, 7, 11, 17, 119, 89, 71, 103, 1043, 413, 6035, 12829, 11559, 0 };
            const std::uint32_t dim2328JoeKuoD6Init[]   =   { 1, 3, 1, 9, 5, 19, 53, 185, 103, 629, 2015, 1257, 5163, 10581, 13449, 0 };
            const std::uint32_t dim2329JoeKuoD6Init[]   =   { 1, 1, 1, 5, 23, 35, 25, 129, 179, 959, 677, 2249, 6315, 12151, 3459, 0 };
            const std::uint32_t dim2330JoeKuoD6Init[]   =   { 1, 1, 1, 1, 9, 47, 93, 45, 35, 45, 265, 2065, 6225, 25, 27135, 0 };
            const std::uint32_t dim2331JoeKuoD6Init[]   =   { 1, 3, 1, 11, 21, 53, 127, 163, 311, 667, 597, 1561, 4515, 23, 9551, 0 };
            const std::uint32_t dim2332JoeKuoD6Init[]   =   { 1, 1, 3, 3, 7, 47, 105, 211, 241, 95, 389, 899, 6001, 8129, 19889, 0 };
            const std::uint32_t dim2333JoeKuoD6Init[]   =   { 1, 1, 3, 15, 29, 45, 9, 27, 483, 799, 269, 1811, 4493, 7109, 22149, 0 };
            const std::uint32_t dim2334JoeKuoD6Init[]   =   { 1, 1, 3, 3, 29, 5, 57, 205, 187, 615, 1677, 3987, 4577, 8799, 16311, 0 };
            const std::uint32_t dim2335JoeKuoD6Init[]   =   { 1, 1, 5, 3, 15, 5, 91, 101, 319, 445, 1261, 2039, 4071, 8249, 11611, 0 };
            const std::uint32_t dim2336JoeKuoD6Init[]   =   { 1, 3, 7, 11, 19, 17, 1, 185, 153, 579, 1001, 2031, 2295, 16335, 24771, 0 };
            const std::uint32_t dim2337JoeKuoD6Init[]   =   { 1, 3, 3, 15, 13, 45, 93, 185, 319, 667, 1085, 93, 577, 11551, 11355, 0 };
            const std::uint32_t dim2338JoeKuoD6Init[]   =   { 1, 1, 7, 13, 3, 61, 45, 191, 51, 981, 1151, 2715, 2503, 4147, 4587, 0 };
            const std::uint32_t dim2339JoeKuoD6Init[]   =   { 1, 1, 3, 3, 27, 17, 71, 141, 57, 981, 1033, 333, 4639, 15885, 1039, 0 };
            const std::uint32_t dim2340JoeKuoD6Init[]   =   { 1, 3, 3, 15, 21, 55, 33, 123, 357, 893, 829, 4045, 5027, 11727, 13357, 0 };
            const std::uint32_t dim2341JoeKuoD6Init[]   =   { 1, 1, 1, 9, 31, 47, 27, 223, 311, 205, 179, 3411, 4019, 10997, 28115, 0 };
            const std::uint32_t dim2342JoeKuoD6Init[]   =   { 1, 3, 5, 1, 3, 39, 15, 7, 501, 641, 735, 295, 2005, 12641, 19779, 0 };
            const std::uint32_t dim2343JoeKuoD6Init[]   =   { 1, 3, 3, 1, 15, 1, 75, 243, 329, 267, 1323, 2285, 5389, 11881, 15737, 0 };
            const std::uint32_t dim2344JoeKuoD6Init[]   =   { 1, 1, 3, 3, 13, 17, 101, 99, 209, 939, 1147, 3221, 5159, 3435, 183, 0 };
            const std::uint32_t dim2345JoeKuoD6Init[]   =   { 1, 1, 1, 1, 27, 43, 29, 179, 179, 659, 807, 313, 4165, 963, 11317, 0 };
            const std::uint32_t dim2346JoeKuoD6Init[]   =   { 1, 1, 3, 13, 9, 51, 125, 245, 381, 555, 1383, 3887, 2045, 12829, 12029, 0 };
            const std::uint32_t dim2347JoeKuoD6Init[]   =   { 1, 1, 1, 9, 29, 39, 55, 127, 235, 617, 1553, 3133, 7735, 14725, 16733, 0 };
            const std::uint32_t dim2348JoeKuoD6Init[]   =   { 1, 1, 3, 5, 15, 9, 47, 217, 89, 987, 1083, 1045, 4745, 12915, 13719, 0 };
            const std::uint32_t dim2349JoeKuoD6Init[]   =   { 1, 3, 3, 7, 23, 3, 35, 79, 45, 435, 1549, 2645, 2831, 10359, 10041, 0 };
            const std::uint32_t dim2350JoeKuoD6Init[]   =   { 1, 1, 7, 15, 31, 61, 25, 223, 511, 319, 487, 1677, 739, 7097, 18417, 0 };
            const std::uint32_t dim2351JoeKuoD6Init[]   =   { 1, 1, 7, 5, 19, 21, 123, 237, 299, 367, 1341, 1449, 2949, 8629, 11051, 0 };
            const std::uint32_t dim2352JoeKuoD6Init[]   =   { 1, 3, 7, 7, 31, 53, 125, 33, 257, 719, 1297, 895, 5095, 10237, 12309, 0 };
            const std::uint32_t dim2353JoeKuoD6Init[]   =   { 1, 3, 1, 5, 31, 59, 73, 211, 97, 209, 1289, 4033, 6143, 14275, 7997, 0 };
            const std::uint32_t dim2354JoeKuoD6Init[]   =   { 1, 1, 5, 7, 31, 5, 75, 105, 389, 985, 9, 4033, 1185, 7821, 19083, 0 };
            const std::uint32_t dim2355JoeKuoD6Init[]   =   { 1, 1, 1, 15, 11, 39, 73, 253, 275, 813, 25, 3441, 2493, 5873, 3739, 0 };
            const std::uint32_t dim2356JoeKuoD6Init[]   =   { 1, 3, 7, 1, 31, 19, 119, 5, 109, 397, 1329, 3347, 5941, 12449, 2533, 0 };
            const std::uint32_t dim2357JoeKuoD6Init[]   =   { 1, 1, 1, 1, 5, 59, 61, 175, 435, 985, 65, 3781, 5425, 15073, 16361, 0 };
            const std::uint32_t dim2358JoeKuoD6Init[]   =   { 1, 3, 5, 7, 31, 13, 53, 87, 69, 305, 1455, 273, 2197, 4277, 24423, 0 };
            const std::uint32_t dim2359JoeKuoD6Init[]   =   { 1, 3, 3, 15, 13, 13, 91, 171, 71, 583, 15, 3599, 6801, 10041, 26097, 0 };
            const std::uint32_t dim2360JoeKuoD6Init[]   =   { 1, 3, 3, 5, 5, 13, 91, 225, 63, 69, 1795, 341, 461, 5015, 9471, 0 };
            const std::uint32_t dim2361JoeKuoD6Init[]   =   { 1, 3, 7, 5, 21, 55, 109, 39, 459, 925, 229, 2855, 5807, 2117, 31739, 0 };
            const std::uint32_t dim2362JoeKuoD6Init[]   =   { 1, 1, 3, 3, 1, 5, 17, 177, 401, 727, 1555, 3097, 1243, 5933, 14579, 0 };
            const std::uint32_t dim2363JoeKuoD6Init[]   =   { 1, 1, 7, 3, 19, 19, 37, 87, 105, 73, 197, 4067, 6237, 10553, 9207, 0 };
            const std::uint32_t dim2364JoeKuoD6Init[]   =   { 1, 1, 3, 15, 1, 55, 119, 115, 441, 3, 1003, 1631, 197, 12929, 25385, 0 };
            const std::uint32_t dim2365JoeKuoD6Init[]   =   { 1, 3, 7, 11, 31, 1, 119, 49, 467, 647, 685, 2771, 3689, 11049, 26787, 0 };
            const std::uint32_t dim2366JoeKuoD6Init[]   =   { 1, 1, 1, 11, 19, 19, 21, 73, 459, 935, 615, 371, 1099, 14407, 10375, 0 };
            const std::uint32_t dim2367JoeKuoD6Init[]   =   { 1, 3, 5, 13, 15, 3, 107, 179, 259, 677, 1101, 315, 7673, 14639, 11241, 0 };
            const std::uint32_t dim2368JoeKuoD6Init[]   =   { 1, 1, 7, 9, 15, 21, 93, 25, 349, 23, 1087, 27, 5691, 12997, 29301, 0 };
            const std::uint32_t dim2369JoeKuoD6Init[]   =   { 1, 3, 3, 5, 7, 43, 1, 195, 69, 753, 1315, 2629, 3259, 5595, 19439, 0 };
            const std::uint32_t dim2370JoeKuoD6Init[]   =   { 1, 3, 5, 5, 31, 9, 75, 217, 217, 197, 1925, 2033, 3585, 15219, 20251, 0 };
            const std::uint32_t dim2371JoeKuoD6Init[]   =   { 1, 1, 5, 11, 17, 31, 3, 209, 315, 49, 949, 2267, 4611, 4375, 16431, 0 };
            const std::uint32_t dim2372JoeKuoD6Init[]   =   { 1, 1, 7, 9, 17, 35, 13, 115, 119, 553, 1527, 2857, 3599, 391, 25101, 0 };
            const std::uint32_t dim2373JoeKuoD6Init[]   =   { 1, 3, 3, 15, 13, 59, 17, 177, 301, 719, 909, 1663, 5033, 1129, 529, 0 };
            const std::uint32_t dim2374JoeKuoD6Init[]   =   { 1, 1, 7, 5, 15, 13, 99, 157, 379, 975, 1019, 2251, 3807, 10621, 351, 0 };
            const std::uint32_t dim2375JoeKuoD6Init[]   =   { 1, 3, 3, 13, 5, 57, 5, 31, 361, 981, 883, 3723, 2259, 5151, 11783, 0 };
            const std::uint32_t dim2376JoeKuoD6Init[]   =   { 1, 1, 1, 13, 1, 43, 125, 19, 77, 509, 1817, 3795, 1863, 8401, 27253, 0 };
            const std::uint32_t dim2377JoeKuoD6Init[]   =   { 1, 1, 5, 7, 19, 41, 21, 151, 89, 189, 769, 1937, 4497, 13607, 24691, 0 };
            const std::uint32_t dim2378JoeKuoD6Init[]   =   { 1, 1, 1, 9, 21, 9, 1, 195, 31, 907, 1719, 1549, 809, 13629, 16597, 0 };
            const std::uint32_t dim2379JoeKuoD6Init[]   =   { 1, 1, 1, 3, 21, 61, 103, 219, 311, 849, 523, 21, 4533, 6367, 3935, 0 };
            const std::uint32_t dim2380JoeKuoD6Init[]   =   { 1, 1, 7, 9, 7, 33, 77, 19, 489, 933, 1729, 1813, 6741, 10701, 7, 0 };
            const std::uint32_t dim2381JoeKuoD6Init[]   =   { 1, 1, 1, 5, 23, 53, 43, 63, 453, 209, 1313, 2847, 2641, 13783, 14983, 0 };
            const std::uint32_t dim2382JoeKuoD6Init[]   =   { 1, 3, 7, 7, 15, 45, 83, 241, 509, 659, 213, 221, 5205, 6019, 18945, 0 };
            const std::uint32_t dim2383JoeKuoD6Init[]   =   { 1, 1, 5, 9, 25, 43, 37, 9, 191, 505, 765, 295, 953, 1045, 11203, 0 };
            const std::uint32_t dim2384JoeKuoD6Init[]   =   { 1, 3, 7, 11, 5, 49, 45, 177, 379, 695, 355, 1711, 7747, 497, 7597, 0 };
            const std::uint32_t dim2385JoeKuoD6Init[]   =   { 1, 1, 5, 13, 23, 47, 101, 145, 301, 207, 195, 2225, 8093, 15345, 14097, 0 };
            const std::uint32_t dim2386JoeKuoD6Init[]   =   { 1, 3, 7, 13, 9, 9, 55, 223, 343, 921, 1825, 3281, 2627, 855, 27651, 0 };
            const std::uint32_t dim2387JoeKuoD6Init[]   =   { 1, 1, 7, 1, 21, 1, 67, 149, 433, 111, 577, 3675, 495, 9043, 23613, 0 };
            const std::uint32_t dim2388JoeKuoD6Init[]   =   { 1, 3, 1, 13, 9, 39, 37, 73, 117, 559, 1131, 2511, 7599, 8393, 24747, 0 };
            const std::uint32_t dim2389JoeKuoD6Init[]   =   { 1, 3, 3, 7, 11, 15, 85, 229, 7, 21, 1649, 739, 375, 13991, 27053, 0 };
            const std::uint32_t dim2390JoeKuoD6Init[]   =   { 1, 1, 5, 5, 15, 41, 49, 117, 173, 825, 1343, 377, 1789, 12519, 30667, 0 };
            const std::uint32_t dim2391JoeKuoD6Init[]   =   { 1, 1, 7, 15, 9, 11, 97, 99, 347, 729, 9, 1703, 1177, 5189, 9061, 0 };
            const std::uint32_t dim2392JoeKuoD6Init[]   =   { 1, 1, 5, 11, 15, 25, 99, 63, 89, 675, 561, 215, 8111, 3955, 24635, 0 };
            const std::uint32_t dim2393JoeKuoD6Init[]   =   { 1, 1, 1, 1, 7, 53, 99, 193, 233, 731, 733, 1883, 7783, 14413, 14003, 0 };
            const std::uint32_t dim2394JoeKuoD6Init[]   =   { 1, 3, 5, 7, 31, 23, 45, 153, 337, 293, 443, 2301, 5135, 7455, 13123, 0 };
            const std::uint32_t dim2395JoeKuoD6Init[]   =   { 1, 3, 1, 3, 23, 53, 23, 165, 53, 875, 1543, 1035, 4247, 5101, 28445, 0 };
            const std::uint32_t dim2396JoeKuoD6Init[]   =   { 1, 1, 1, 15, 13, 41, 77, 93, 205, 743, 1101, 1413, 2371, 7183, 12337, 0 };
            const std::uint32_t dim2397JoeKuoD6Init[]   =   { 1, 1, 3, 15, 17, 63, 25, 101, 147, 149, 1207, 3525, 2661, 9539, 11145, 0 };
            const std::uint32_t dim2398JoeKuoD6Init[]   =   { 1, 3, 1, 9, 17, 5, 3, 35, 389, 909, 1017, 2803, 5243, 13025, 8851, 0 };
            const std::uint32_t dim2399JoeKuoD6Init[]   =   { 1, 1, 7, 15, 19, 27, 69, 91, 71, 547, 1421, 831, 6969, 5517, 28233, 0 };
            const std::uint32_t dim2400JoeKuoD6Init[]   =   { 1, 1, 3, 3, 17, 45, 55, 63, 263, 819, 1211, 2739, 655, 13269, 22281, 0 };
            const std::uint32_t dim2401JoeKuoD6Init[]   =   { 1, 3, 1, 5, 23, 13, 81, 251, 83, 551, 491, 1029, 3561, 357, 23393, 0 };
            const std::uint32_t dim2402JoeKuoD6Init[]   =   { 1, 3, 1, 13, 25, 27, 93, 143, 407, 403, 1395, 1733, 3187, 1917, 31453, 0 };
            const std::uint32_t dim2403JoeKuoD6Init[]   =   { 1, 1, 7, 13, 3, 21, 85, 113, 483, 461, 1343, 561, 2081, 10857, 24253, 0 };
            const std::uint32_t dim2404JoeKuoD6Init[]   =   { 1, 1, 1, 1, 11, 11, 53, 135, 25, 163, 1729, 617, 1533, 10881, 16041, 0 };
            const std::uint32_t dim2405JoeKuoD6Init[]   =   { 1, 1, 5, 1, 3, 49, 125, 139, 77, 891, 815, 3431, 4875, 12513, 4595, 0 };
            const std::uint32_t dim2406JoeKuoD6Init[]   =   { 1, 1, 1, 1, 27, 63, 111, 109, 421, 425, 345, 1613, 5447, 1357, 32413, 0 };
            const std::uint32_t dim2407JoeKuoD6Init[]   =   { 1, 3, 5, 3, 17, 5, 37, 171, 259, 281, 1003, 2901, 3241, 15557, 21415, 0 };
            const std::uint32_t dim2408JoeKuoD6Init[]   =   { 1, 1, 5, 11, 15, 55, 75, 199, 493, 215, 1625, 2345, 7873, 2325, 11003, 0 };
            const std::uint32_t dim2409JoeKuoD6Init[]   =   { 1, 3, 7, 1, 21, 33, 23, 5, 495, 941, 1185, 475, 5799, 15161, 10677, 0 };
            const std::uint32_t dim2410JoeKuoD6Init[]   =   { 1, 1, 5, 9, 31, 37, 37, 29, 217, 389, 297, 3097, 7319, 2601, 15307, 0 };
            const std::uint32_t dim2411JoeKuoD6Init[]   =   { 1, 3, 7, 5, 7, 45, 111, 167, 297, 275, 1669, 2489, 1511, 15753, 1289, 0 };
            const std::uint32_t dim2412JoeKuoD6Init[]   =   { 1, 3, 1, 7, 3, 45, 19, 11, 189, 199, 1227, 2647, 1897, 9077, 17189, 0 };
            const std::uint32_t dim2413JoeKuoD6Init[]   =   { 1, 1, 1, 13, 15, 39, 19, 179, 147, 341, 283, 3029, 7599, 8937, 18761, 0 };
            const std::uint32_t dim2414JoeKuoD6Init[]   =   { 1, 3, 3, 9, 3, 11, 41, 255, 365, 835, 921, 389, 919, 15223, 14541, 0 };
            const std::uint32_t dim2415JoeKuoD6Init[]   =   { 1, 1, 3, 3, 5, 37, 29, 203, 313, 271, 1207, 487, 3711, 3811, 26757, 0 };
            const std::uint32_t dim2416JoeKuoD6Init[]   =   { 1, 3, 7, 9, 19, 53, 49, 139, 351, 537, 1681, 1595, 5399, 13839, 28685, 0 };
            const std::uint32_t dim2417JoeKuoD6Init[]   =   { 1, 3, 1, 1, 15, 35, 21, 37, 247, 891, 1855, 1243, 3137, 10381, 30379, 0 };
            const std::uint32_t dim2418JoeKuoD6Init[]   =   { 1, 3, 7, 5, 9, 47, 91, 25, 479, 337, 781, 3545, 1045, 9491, 22853, 0 };
            const std::uint32_t dim2419JoeKuoD6Init[]   =   { 1, 1, 5, 15, 19, 31, 81, 5, 117, 923, 565, 2443, 7383, 1795, 11685, 0 };
            const std::uint32_t dim2420JoeKuoD6Init[]   =   { 1, 3, 3, 5, 17, 15, 21, 245, 489, 889, 2047, 2737, 7445, 14785, 13401, 0 };
            const std::uint32_t dim2421JoeKuoD6Init[]   =   { 1, 1, 1, 15, 19, 45, 67, 117, 299, 607, 953, 743, 6863, 12123, 6701, 0 };
            const std::uint32_t dim2422JoeKuoD6Init[]   =   { 1, 1, 3, 1, 1, 43, 19, 129, 345, 861, 209, 2387, 7205, 7131, 8235, 0 };
            const std::uint32_t dim2423JoeKuoD6Init[]   =   { 1, 3, 5, 1, 1, 13, 75, 99, 333, 157, 23, 1217, 1857, 15479, 16031, 0 };
            const std::uint32_t dim2424JoeKuoD6Init[]   =   { 1, 3, 3, 11, 7, 61, 119, 89, 491, 401, 227, 1739, 3807, 16003, 2875, 0 };
            const std::uint32_t dim2425JoeKuoD6Init[]   =   { 1, 3, 7, 15, 13, 55, 3, 159, 405, 593, 975, 361, 2563, 6061, 28087, 0 };
            const std::uint32_t dim2426JoeKuoD6Init[]   =   { 1, 1, 3, 13, 19, 5, 5, 9, 119, 41, 33, 1111, 4443, 4663, 28841, 0 };
            const std::uint32_t dim2427JoeKuoD6Init[]   =   { 1, 1, 7, 7, 25, 59, 125, 255, 49, 947, 1673, 2947, 6369, 2267, 8813, 0 };
            const std::uint32_t dim2428JoeKuoD6Init[]   =   { 1, 1, 5, 15, 25, 25, 111, 193, 217, 193, 821, 2779, 69, 2957, 27043, 0 };
            const std::uint32_t dim2429JoeKuoD6Init[]   =   { 1, 3, 5, 7, 21, 19, 51, 157, 203, 487, 1745, 1875, 911, 14071, 7557, 0 };
            const std::uint32_t dim2430JoeKuoD6Init[]   =   { 1, 1, 5, 9, 3, 15, 55, 73, 313, 245, 1061, 1929, 3035, 607, 11563, 0 };
            const std::uint32_t dim2431JoeKuoD6Init[]   =   { 1, 1, 5, 7, 3, 57, 105, 121, 461, 43, 803, 1801, 4059, 2157, 17547, 0 };
            const std::uint32_t dim2432JoeKuoD6Init[]   =   { 1, 3, 7, 7, 19, 11, 1, 121, 499, 841, 601, 3515, 2969, 13697, 8917, 0 };
            const std::uint32_t dim2433JoeKuoD6Init[]   =   { 1, 3, 3, 3, 13, 35, 113, 231, 391, 689, 697, 2871, 7387, 715, 27005, 0 };
            const std::uint32_t dim2434JoeKuoD6Init[]   =   { 1, 1, 1, 13, 19, 5, 17, 43, 175, 291, 987, 1917, 7635, 15655, 10689, 0 };
            const std::uint32_t dim2435JoeKuoD6Init[]   =   { 1, 1, 7, 15, 19, 37, 121, 243, 125, 623, 1231, 29, 2325, 5147, 21435, 0 };
            const std::uint32_t dim2436JoeKuoD6Init[]   =   { 1, 3, 5, 15, 25, 27, 57, 187, 77, 401, 1489, 2977, 5415, 3381, 2551, 0 };
            const std::uint32_t dim2437JoeKuoD6Init[]   =   { 1, 1, 1, 7, 1, 1, 85, 27, 115, 559, 9, 2365, 711, 5733, 2819, 0 };
            const std::uint32_t dim2438JoeKuoD6Init[]   =   { 1, 3, 1, 15, 9, 29, 61, 113, 169, 349, 591, 1061, 6041, 7613, 23691, 0 };
            const std::uint32_t dim2439JoeKuoD6Init[]   =   { 1, 1, 5, 1, 13, 45, 49, 227, 345, 563, 87, 3597, 3961, 7205, 8441, 0 };
            const std::uint32_t dim2440JoeKuoD6Init[]   =   { 1, 1, 1, 5, 3, 21, 121, 183, 463, 83, 1365, 539, 1485, 10063, 24867, 0 };
            const std::uint32_t dim2441JoeKuoD6Init[]   =   { 1, 3, 5, 5, 3, 61, 101, 237, 41, 147, 1907, 3049, 7583, 8283, 6099, 0 };
            const std::uint32_t dim2442JoeKuoD6Init[]   =   { 1, 3, 1, 15, 31, 57, 19, 155, 445, 805, 1793, 207, 1975, 3357, 14281, 0 };
            const std::uint32_t dim2443JoeKuoD6Init[]   =   { 1, 1, 7, 13, 9, 39, 27, 73, 165, 345, 543, 4095, 133, 10469, 11573, 0 };
            const std::uint32_t dim2444JoeKuoD6Init[]   =   { 1, 1, 7, 15, 17, 57, 99, 81, 359, 367, 1057, 1173, 4225, 15127, 2615, 0 };
            const std::uint32_t dim2445JoeKuoD6Init[]   =   { 1, 3, 5, 3, 31, 23, 113, 111, 495, 947, 1625, 1195, 2053, 1509, 1347, 0 };
            const std::uint32_t dim2446JoeKuoD6Init[]   =   { 1, 1, 5, 5, 9, 47, 25, 63, 455, 107, 771, 3815, 3827, 16287, 11615, 0 };
            const std::uint32_t dim2447JoeKuoD6Init[]   =   { 1, 1, 7, 9, 17, 61, 51, 215, 63, 123, 1253, 3927, 721, 9647, 3283, 0 };
            const std::uint32_t dim2448JoeKuoD6Init[]   =   { 1, 1, 5, 15, 11, 17, 83, 255, 473, 107, 681, 763, 7855, 8043, 31503, 0 };
            const std::uint32_t dim2449JoeKuoD6Init[]   =   { 1, 3, 1, 7, 7, 31, 37, 5, 253, 155, 2017, 609, 1421, 14927, 25241, 0 };
            const std::uint32_t dim2450JoeKuoD6Init[]   =   { 1, 3, 3, 13, 31, 25, 21, 241, 431, 193, 681, 2265, 5091, 11479, 21443, 0 };
            const std::uint32_t dim2451JoeKuoD6Init[]   =   { 1, 3, 5, 5, 15, 9, 49, 255, 157, 995, 631, 1995, 3605, 9085, 24245, 0 };
            const std::uint32_t dim2452JoeKuoD6Init[]   =   { 1, 3, 3, 7, 19, 31, 85, 153, 493, 951, 451, 1587, 6609, 3681, 13205, 0 };
            const std::uint32_t dim2453JoeKuoD6Init[]   =   { 1, 1, 5, 1, 17, 41, 107, 231, 307, 361, 575, 3239, 3443, 16159, 20625, 0 };
            const std::uint32_t dim2454JoeKuoD6Init[]   =   { 1, 1, 7, 9, 31, 49, 93, 79, 181, 117, 1241, 3645, 4901, 12599, 13247, 0 };
            const std::uint32_t dim2455JoeKuoD6Init[]   =   { 1, 3, 3, 9, 7, 31, 127, 201, 11, 199, 1851, 23, 5667, 8159, 20951, 0 };
            const std::uint32_t dim2456JoeKuoD6Init[]   =   { 1, 3, 3, 7, 3, 37, 29, 189, 65, 461, 769, 321, 6577, 16223, 16865, 0 };
            const std::uint32_t dim2457JoeKuoD6Init[]   =   { 1, 1, 5, 11, 1, 13, 91, 167, 33, 111, 1445, 1047, 2479, 12623, 22893, 0 };
            const std::uint32_t dim2458JoeKuoD6Init[]   =   { 1, 1, 3, 1, 3, 1, 47, 185, 329, 903, 1651, 3005, 907, 1255, 8303, 0 };
            const std::uint32_t dim2459JoeKuoD6Init[]   =   { 1, 3, 5, 13, 19, 31, 5, 233, 265, 769, 1303, 2503, 2229, 14019, 20257, 0 };
            const std::uint32_t dim2460JoeKuoD6Init[]   =   { 1, 3, 7, 3, 27, 11, 67, 195, 5, 661, 125, 3761, 7211, 16043, 7267, 0 };
            const std::uint32_t dim2461JoeKuoD6Init[]   =   { 1, 1, 1, 3, 27, 13, 115, 25, 473, 417, 1751, 2223, 2099, 5913, 14273, 0 };
            const std::uint32_t dim2462JoeKuoD6Init[]   =   { 1, 3, 7, 15, 13, 53, 99, 115, 225, 737, 1621, 539, 4131, 471, 31865, 0 };
            const std::uint32_t dim2463JoeKuoD6Init[]   =   { 1, 1, 5, 5, 25, 19, 39, 207, 153, 569, 1755, 2477, 3065, 7383, 29919, 0 };
            const std::uint32_t dim2464JoeKuoD6Init[]   =   { 1, 3, 5, 11, 13, 59, 33, 3, 435, 273, 701, 3819, 7291, 11803, 26111, 0 };
            const std::uint32_t dim2465JoeKuoD6Init[]   =   { 1, 1, 3, 9, 29, 19, 71, 59, 93, 1019, 887, 83, 4675, 7541, 26821, 0 };
            const std::uint32_t dim2466JoeKuoD6Init[]   =   { 1, 3, 1, 3, 21, 53, 71, 73, 43, 321, 1581, 1399, 4043, 12995, 16825, 0 };
            const std::uint32_t dim2467JoeKuoD6Init[]   =   { 1, 3, 7, 15, 3, 13, 37, 11, 93, 873, 1193, 3481, 451, 15869, 17879, 0 };
            const std::uint32_t dim2468JoeKuoD6Init[]   =   { 1, 3, 1, 11, 31, 19, 101, 57, 129, 753, 853, 463, 6757, 11083, 8667, 0 };
            const std::uint32_t dim2469JoeKuoD6Init[]   =   { 1, 3, 5, 15, 25, 41, 25, 197, 235, 609, 905, 993, 3233, 1935, 24661, 0 };
            const std::uint32_t dim2470JoeKuoD6Init[]   =   { 1, 3, 1, 5, 21, 7, 53, 107, 473, 77, 1135, 1045, 4933, 5615, 15931, 0 };
            const std::uint32_t dim2471JoeKuoD6Init[]   =   { 1, 3, 7, 11, 3, 9, 105, 183, 151, 527, 425, 975, 4073, 913, 2793, 0 };
            const std::uint32_t dim2472JoeKuoD6Init[]   =   { 1, 1, 7, 13, 19, 61, 81, 9, 413, 851, 1723, 1113, 1453, 8635, 3353, 0 };
            const std::uint32_t dim2473JoeKuoD6Init[]   =   { 1, 3, 7, 15, 19, 53, 83, 31, 441, 343, 575, 935, 4543, 1303, 12567, 0 };
            const std::uint32_t dim2474JoeKuoD6Init[]   =   { 1, 1, 1, 5, 29, 19, 119, 75, 3, 591, 845, 649, 1717, 13695, 26905, 0 };
            const std::uint32_t dim2475JoeKuoD6Init[]   =   { 1, 1, 7, 9, 5, 53, 127, 191, 15, 773, 1433, 2899, 21, 4977, 17839, 0 };
            const std::uint32_t dim2476JoeKuoD6Init[]   =   { 1, 1, 5, 9, 21, 9, 99, 115, 397, 99, 725, 3835, 973, 1219, 21159, 0 };
            const std::uint32_t dim2477JoeKuoD6Init[]   =   { 1, 3, 5, 3, 7, 39, 29, 93, 303, 913, 981, 3549, 5225, 10907, 393, 0 };
            const std::uint32_t dim2478JoeKuoD6Init[]   =   { 1, 3, 3, 11, 9, 25, 105, 101, 1, 867, 389, 2241, 773, 14123, 10015, 0 };
            const std::uint32_t dim2479JoeKuoD6Init[]   =   { 1, 1, 5, 1, 1, 37, 117, 213, 391, 779, 1851, 1485, 1277, 5607, 819, 0 };
            const std::uint32_t dim2480JoeKuoD6Init[]   =   { 1, 3, 7, 1, 3, 5, 43, 47, 483, 367, 749, 1693, 4961, 15257, 3775, 0 };
            const std::uint32_t dim2481JoeKuoD6Init[]   =   { 1, 3, 3, 1, 27, 11, 21, 83, 437, 379, 1041, 393, 5611, 2421, 31739, 0 };
            const std::uint32_t dim2482JoeKuoD6Init[]   =   { 1, 3, 5, 7, 19, 1, 79, 63, 53, 201, 1159, 2501, 6327, 11317, 9537, 0 };
            const std::uint32_t dim2483JoeKuoD6Init[]   =   { 1, 3, 5, 13, 9, 37, 61, 217, 427, 913, 1311, 3503, 5473, 10583, 19723, 0 };
            const std::uint32_t dim2484JoeKuoD6Init[]   =   { 1, 1, 3, 9, 11, 29, 121, 175, 141, 515, 925, 837, 6011, 10419, 32157, 0 };
            const std::uint32_t dim2485JoeKuoD6Init[]   =   { 1, 3, 5, 9, 27, 57, 97, 175, 365, 367, 1737, 3845, 1257, 12243, 2201, 0 };
            const std::uint32_t dim2486JoeKuoD6Init[]   =   { 1, 3, 3, 9, 23, 1, 53, 123, 127, 333, 1335, 707, 5747, 6541, 9809, 0 };
            const std::uint32_t dim2487JoeKuoD6Init[]   =   { 1, 3, 1, 9, 17, 37, 101, 41, 91, 61, 433, 979, 4345, 12351, 10829, 0 };
            const std::uint32_t dim2488JoeKuoD6Init[]   =   { 1, 3, 3, 13, 3, 21, 15, 49, 257, 99, 1793, 2987, 5233, 11625, 28069, 0 };
            const std::uint32_t dim2489JoeKuoD6Init[]   =   { 1, 1, 7, 11, 21, 13, 89, 11, 135, 153, 783, 2893, 6815, 12007, 15605, 0 };
            const std::uint32_t dim2490JoeKuoD6Init[]   =   { 1, 3, 7, 13, 5, 61, 73, 5, 269, 699, 925, 2925, 5919, 5841, 24875, 0 };
            const std::uint32_t dim2491JoeKuoD6Init[]   =   { 1, 3, 5, 5, 25, 45, 43, 93, 15, 927, 1253, 319, 1173, 14559, 20221, 0 };
            const std::uint32_t dim2492JoeKuoD6Init[]   =   { 1, 1, 3, 3, 27, 45, 9, 103, 447, 627, 1239, 3869, 2169, 49, 17917, 0 };
            const std::uint32_t dim2493JoeKuoD6Init[]   =   { 1, 3, 7, 7, 11, 9, 1, 1, 1, 527, 825, 3295, 623, 2095, 10537, 0 };
            const std::uint32_t dim2494JoeKuoD6Init[]   =   { 1, 3, 3, 11, 21, 11, 59, 165, 33, 743, 1461, 1535, 6393, 1301, 17823, 0 };
            const std::uint32_t dim2495JoeKuoD6Init[]   =   { 1, 1, 7, 3, 19, 43, 47, 245, 469, 551, 1447, 1963, 169, 1481, 31925, 0 };
            const std::uint32_t dim2496JoeKuoD6Init[]   =   { 1, 1, 3, 1, 11, 21, 51, 7, 251, 199, 1153, 767, 6417, 3417, 30171, 0 };
            const std::uint32_t dim2497JoeKuoD6Init[]   =   { 1, 3, 7, 1, 31, 5, 41, 103, 447, 263, 211, 2029, 8021, 4705, 10579, 0 };
            const std::uint32_t dim2498JoeKuoD6Init[]   =   { 1, 1, 3, 5, 17, 25, 55, 75, 393, 107, 2017, 2389, 1685, 14021, 9161, 0 };
            const std::uint32_t dim2499JoeKuoD6Init[]   =   { 1, 1, 1, 9, 13, 1, 75, 237, 205, 461, 689, 2531, 2839, 13925, 23351, 0 };
            const std::uint32_t dim2500JoeKuoD6Init[]   =   { 1, 3, 7, 1, 23, 39, 33, 189, 157, 571, 239, 1053, 1559, 1685, 23059, 0 };
            const std::uint32_t dim2501JoeKuoD6Init[]   =   { 1, 3, 3, 3, 27, 61, 71, 121, 49, 157, 1341, 1707, 2417, 11689, 26507, 0 };
            const std::uint32_t dim2502JoeKuoD6Init[]   =   { 1, 3, 7, 7, 19, 63, 47, 53, 95, 791, 1467, 1273, 2045, 755, 8555, 0 };
            const std::uint32_t dim2503JoeKuoD6Init[]   =   { 1, 1, 3, 15, 27, 33, 21, 253, 317, 153, 1509, 1765, 3809, 601, 5907, 0 };
            const std::uint32_t dim2504JoeKuoD6Init[]   =   { 1, 3, 5, 15, 11, 17, 97, 91, 165, 199, 1751, 2135, 1315, 3077, 29995, 0 };
            const std::uint32_t dim2505JoeKuoD6Init[]   =   { 1, 3, 1, 5, 3, 33, 93, 49, 39, 743, 341, 2549, 7603, 3369, 30889, 0 };
            const std::uint32_t dim2506JoeKuoD6Init[]   =   { 1, 1, 3, 13, 3, 5, 87, 63, 293, 785, 1591, 675, 3915, 2209, 18201, 0 };
            const std::uint32_t dim2507JoeKuoD6Init[]   =   { 1, 3, 3, 11, 3, 15, 69, 231, 241, 127, 429, 2201, 8173, 12549, 25745, 0 };
            const std::uint32_t dim2508JoeKuoD6Init[]   =   { 1, 1, 5, 11, 15, 39, 3, 29, 125, 685, 643, 1385, 829, 7347, 28793, 0 };
            const std::uint32_t dim2509JoeKuoD6Init[]   =   { 1, 1, 7, 15, 27, 15, 59, 237, 299, 773, 1097, 3875, 6503, 7129, 28495, 0 };
            const std::uint32_t dim2510JoeKuoD6Init[]   =   { 1, 3, 5, 13, 9, 17, 31, 227, 69, 443, 1633, 525, 1659, 14681, 15209, 0 };
            const std::uint32_t dim2511JoeKuoD6Init[]   =   { 1, 3, 5, 5, 13, 51, 69, 173, 111, 433, 279, 2145, 2091, 9741, 24881, 0 };
            const std::uint32_t dim2512JoeKuoD6Init[]   =   { 1, 3, 1, 7, 7, 35, 55, 51, 357, 99, 1789, 333, 2073, 10151, 14527, 0 };
            const std::uint32_t dim2513JoeKuoD6Init[]   =   { 1, 3, 3, 7, 13, 41, 101, 87, 425, 701, 1143, 2733, 6473, 8667, 17419, 0 };
            const std::uint32_t dim2514JoeKuoD6Init[]   =   { 1, 1, 5, 5, 25, 29, 63, 31, 385, 537, 563, 607, 6723, 9251, 6531, 0 };
            const std::uint32_t dim2515JoeKuoD6Init[]   =   { 1, 3, 5, 5, 9, 63, 111, 131, 239, 723, 705, 2805, 6579, 12691, 17521, 0 };
            const std::uint32_t dim2516JoeKuoD6Init[]   =   { 1, 3, 1, 7, 31, 55, 101, 225, 477, 271, 611, 3179, 7859, 9835, 2165, 0 };
            const std::uint32_t dim2517JoeKuoD6Init[]   =   { 1, 1, 3, 3, 5, 15, 81, 127, 391, 333, 419, 1091, 5997, 12315, 31521, 0 };
            const std::uint32_t dim2518JoeKuoD6Init[]   =   { 1, 3, 5, 15, 23, 7, 35, 109, 181, 295, 825, 419, 969, 15753, 9365, 0 };
            const std::uint32_t dim2519JoeKuoD6Init[]   =   { 1, 3, 5, 5, 25, 23, 69, 177, 325, 359, 1577, 619, 6233, 11753, 8103, 0 };
            const std::uint32_t dim2520JoeKuoD6Init[]   =   { 1, 3, 5, 11, 31, 13, 79, 61, 241, 1011, 1961, 949, 6211, 497, 7099, 0 };
            const std::uint32_t dim2521JoeKuoD6Init[]   =   { 1, 3, 5, 3, 25, 19, 67, 235, 337, 1015, 1485, 355, 3653, 12735, 14503, 0 };
            const std::uint32_t dim2522JoeKuoD6Init[]   =   { 1, 3, 5, 7, 31, 23, 35, 231, 147, 15, 263, 1995, 431, 5941, 18931, 0 };
            const std::uint32_t dim2523JoeKuoD6Init[]   =   { 1, 3, 3, 7, 1, 35, 37, 7, 85, 443, 715, 743, 2189, 12537, 17427, 0 };
            const std::uint32_t dim2524JoeKuoD6Init[]   =   { 1, 1, 3, 1, 7, 41, 1, 209, 121, 929, 661, 3999, 955, 5123, 31115, 0 };
            const std::uint32_t dim2525JoeKuoD6Init[]   =   { 1, 1, 3, 5, 11, 43, 127, 125, 107, 293, 273, 2071, 3003, 11631, 7769, 0 };
            const std::uint32_t dim2526JoeKuoD6Init[]   =   { 1, 1, 1, 13, 13, 29, 39, 217, 111, 779, 1287, 1675, 4201, 4869, 20403, 0 };
            const std::uint32_t dim2527JoeKuoD6Init[]   =   { 1, 1, 3, 15, 25, 53, 25, 135, 389, 925, 1971, 663, 7545, 2673, 7725, 0 };
            const std::uint32_t dim2528JoeKuoD6Init[]   =   { 1, 1, 5, 13, 3, 59, 97, 91, 357, 45, 947, 3031, 8095, 6269, 13975, 0 };
            const std::uint32_t dim2529JoeKuoD6Init[]   =   { 1, 1, 5, 15, 25, 31, 1, 171, 375, 939, 507, 3591, 1089, 13605, 2813, 0 };
            const std::uint32_t dim2530JoeKuoD6Init[]   =   { 1, 1, 3, 7, 25, 21, 41, 131, 147, 737, 9, 1603, 1859, 11573, 28397, 0 };
            const std::uint32_t dim2531JoeKuoD6Init[]   =   { 1, 3, 3, 9, 21, 9, 59, 27, 169, 875, 711, 1389, 2899, 7937, 4173, 0 };
            const std::uint32_t dim2532JoeKuoD6Init[]   =   { 1, 1, 5, 9, 13, 29, 71, 39, 51, 337, 1067, 2661, 1203, 5967, 19249, 0 };
            const std::uint32_t dim2533JoeKuoD6Init[]   =   { 1, 3, 7, 1, 17, 21, 43, 79, 181, 741, 1901, 3445, 7171, 2109, 1589, 0 };
            const std::uint32_t dim2534JoeKuoD6Init[]   =   { 1, 1, 3, 9, 23, 37, 105, 51, 227, 775, 1265, 2987, 2197, 13903, 28891, 0 };
            const std::uint32_t dim2535JoeKuoD6Init[]   =   { 1, 1, 1, 13, 23, 47, 111, 41, 93, 261, 75, 2155, 4301, 11517, 16101, 0 };
            const std::uint32_t dim2536JoeKuoD6Init[]   =   { 1, 1, 3, 3, 27, 27, 123, 125, 501, 775, 413, 1065, 7607, 15065, 26013, 0 };
            const std::uint32_t dim2537JoeKuoD6Init[]   =   { 1, 3, 7, 3, 27, 11, 59, 87, 207, 743, 1765, 2969, 913, 8101, 11583, 0 };
            const std::uint32_t dim2538JoeKuoD6Init[]   =   { 1, 3, 3, 1, 23, 7, 113, 17, 285, 993, 695, 2399, 5019, 4779, 28917, 0 };
            const std::uint32_t dim2539JoeKuoD6Init[]   =   { 1, 3, 1, 5, 11, 51, 49, 139, 213, 435, 1475, 2209, 6695, 12981, 9851, 0 };
            const std::uint32_t dim2540JoeKuoD6Init[]   =   { 1, 3, 5, 7, 1, 63, 31, 151, 173, 767, 1453, 1497, 6911, 9597, 25551, 0 };
            const std::uint32_t dim2541JoeKuoD6Init[]   =   { 1, 1, 7, 7, 21, 53, 39, 159, 389, 231, 309, 359, 7701, 14819, 5175, 0 };
            const std::uint32_t dim2542JoeKuoD6Init[]   =   { 1, 1, 1, 1, 11, 47, 83, 29, 247, 89, 369, 2727, 3103, 14421, 17369, 0 };
            const std::uint32_t dim2543JoeKuoD6Init[]   =   { 1, 3, 1, 5, 25, 25, 111, 245, 239, 755, 113, 1765, 3583, 917, 403, 0 };
            const std::uint32_t dim2544JoeKuoD6Init[]   =   { 1, 3, 3, 3, 5, 59, 85, 151, 463, 591, 743, 3767, 121, 2927, 11031, 0 };
            const std::uint32_t dim2545JoeKuoD6Init[]   =   { 1, 3, 5, 9, 11, 39, 77, 161, 275, 233, 1991, 2683, 6545, 2423, 32113, 0 };
            const std::uint32_t dim2546JoeKuoD6Init[]   =   { 1, 3, 5, 11, 5, 57, 13, 229, 329, 757, 1863, 3959, 4243, 7265, 15599, 0 };
            const std::uint32_t dim2547JoeKuoD6Init[]   =   { 1, 1, 1, 1, 1, 23, 19, 67, 453, 593, 2011, 1813, 4695, 8903, 9623, 0 };
            const std::uint32_t dim2548JoeKuoD6Init[]   =   { 1, 3, 3, 7, 1, 29, 103, 255, 493, 647, 1709, 4065, 4199, 949, 28829, 0 };
            const std::uint32_t dim2549JoeKuoD6Init[]   =   { 1, 1, 7, 9, 3, 55, 53, 33, 5, 223, 423, 3347, 7647, 7211, 25157, 0 };
            const std::uint32_t dim2550JoeKuoD6Init[]   =   { 1, 3, 5, 13, 3, 43, 79, 255, 471, 573, 1007, 2119, 6731, 10047, 23179, 0 };
            const std::uint32_t dim2551JoeKuoD6Init[]   =   { 1, 1, 1, 3, 7, 39, 55, 61, 53, 377, 435, 401, 3307, 12621, 14299, 0 };
            const std::uint32_t dim2552JoeKuoD6Init[]   =   { 1, 3, 3, 7, 21, 31, 67, 17, 243, 425, 747, 2995, 1389, 2557, 18415, 0 };
            const std::uint32_t dim2553JoeKuoD6Init[]   =   { 1, 3, 1, 3, 3, 39, 75, 11, 447, 249, 1135, 1011, 1657, 10767, 19501, 0 };
            const std::uint32_t dim2554JoeKuoD6Init[]   =   { 1, 3, 1, 11, 17, 51, 117, 129, 17, 143, 785, 103, 5049, 14703, 28479, 0 };
            const std::uint32_t dim2555JoeKuoD6Init[]   =   { 1, 3, 7, 5, 13, 17, 75, 255, 75, 661, 1175, 477, 1811, 1479, 15783, 0 };
            const std::uint32_t dim2556JoeKuoD6Init[]   =   { 1, 3, 7, 9, 11, 57, 101, 77, 431, 247, 997, 3657, 5117, 6815, 3841, 0 };
            const std::uint32_t dim2557JoeKuoD6Init[]   =   { 1, 1, 5, 1, 17, 21, 101, 183, 209, 69, 299, 1585, 6381, 12983, 10053, 0 };
            const std::uint32_t dim2558JoeKuoD6Init[]   =   { 1, 1, 7, 3, 5, 13, 21, 63, 83, 857, 749, 1251, 5363, 9629, 16563, 0 };
            const std::uint32_t dim2559JoeKuoD6Init[]   =   { 1, 3, 3, 9, 3, 59, 9, 45, 55, 489, 137, 2423, 2661, 12111, 4375, 0 };
            const std::uint32_t dim2560JoeKuoD6Init[]   =   { 1, 1, 5, 9, 23, 9, 41, 177, 447, 671, 1631, 3115, 4215, 14435, 8743, 0 };
            const std::uint32_t dim2561JoeKuoD6Init[]   =   { 1, 3, 7, 11, 19, 23, 15, 221, 413, 783, 1247, 2343, 4397, 3145, 32043, 0 };
            const std::uint32_t dim2562JoeKuoD6Init[]   =   { 1, 3, 3, 1, 31, 55, 31, 87, 333, 849, 1777, 343, 5199, 1507, 11621, 0 };
            const std::uint32_t dim2563JoeKuoD6Init[]   =   { 1, 3, 7, 3, 17, 57, 63, 63, 111, 977, 631, 3019, 2953, 14273, 29209, 0 };
            const std::uint32_t dim2564JoeKuoD6Init[]   =   { 1, 3, 1, 13, 9, 39, 87, 15, 397, 185, 701, 1487, 3807, 13727, 19883, 0 };
            const std::uint32_t dim2565JoeKuoD6Init[]   =   { 1, 3, 7, 1, 17, 57, 57, 157, 119, 181, 899, 353, 3603, 15041, 7421, 0 };
            const std::uint32_t dim2566JoeKuoD6Init[]   =   { 1, 1, 7, 3, 29, 13, 29, 191, 105, 373, 961, 1991, 5531, 6793, 29497, 0 };
            const std::uint32_t dim2567JoeKuoD6Init[]   =   { 1, 3, 3, 11, 7, 61, 65, 39, 215, 187, 191, 1651, 2481, 3951, 24965, 0 };
            const std::uint32_t dim2568JoeKuoD6Init[]   =   { 1, 1, 7, 5, 25, 11, 105, 23, 257, 771, 1359, 2837, 7821, 12223, 28033, 0 };
            const std::uint32_t dim2569JoeKuoD6Init[]   =   { 1, 3, 5, 11, 3, 3, 23, 139, 407, 885, 1679, 2979, 8149, 14281, 12487, 0 };
            const std::uint32_t dim2570JoeKuoD6Init[]   =   { 1, 3, 7, 3, 21, 45, 13, 85, 249, 1015, 2023, 1429, 965, 7091, 31721, 0 };
            const std::uint32_t dim2571JoeKuoD6Init[]   =   { 1, 1, 1, 13, 19, 5, 119, 47, 91, 285, 211, 2607, 4287, 9197, 455, 0 };
            const std::uint32_t dim2572JoeKuoD6Init[]   =   { 1, 3, 1, 1, 9, 59, 25, 137, 121, 287, 577, 3325, 2365, 8823, 5033, 0 };
            const std::uint32_t dim2573JoeKuoD6Init[]   =   { 1, 3, 3, 13, 25, 63, 99, 43, 15, 855, 245, 3189, 59, 5181, 21299, 0 };
            const std::uint32_t dim2574JoeKuoD6Init[]   =   { 1, 3, 5, 11, 7, 9, 41, 157, 359, 773, 1347, 2049, 4589, 13731, 32133, 0 };
            const std::uint32_t dim2575JoeKuoD6Init[]   =   { 1, 1, 7, 11, 31, 37, 83, 105, 183, 375, 79, 1821, 1989, 15199, 22207, 0 };
            const std::uint32_t dim2576JoeKuoD6Init[]   =   { 1, 1, 5, 3, 23, 37, 127, 9, 467, 651, 993, 69, 6943, 4093, 20871, 0 };
            const std::uint32_t dim2577JoeKuoD6Init[]   =   { 1, 1, 3, 15, 31, 49, 123, 149, 211, 371, 1825, 3011, 485, 1251, 17343, 0 };
            const std::uint32_t dim2578JoeKuoD6Init[]   =   { 1, 1, 1, 15, 11, 33, 127, 251, 89, 317, 1869, 219, 2275, 14201, 27063, 0 };
            const std::uint32_t dim2579JoeKuoD6Init[]   =   { 1, 1, 5, 5, 19, 5, 81, 35, 233, 95, 9, 863, 725, 11095, 16217, 0 };
            const std::uint32_t dim2580JoeKuoD6Init[]   =   { 1, 1, 1, 15, 23, 47, 51, 43, 169, 637, 865, 57, 1509, 1683, 7587, 0 };
            const std::uint32_t dim2581JoeKuoD6Init[]   =   { 1, 3, 1, 3, 7, 7, 117, 187, 273, 303, 717, 3091, 2083, 3315, 647, 0 };
            const std::uint32_t dim2582JoeKuoD6Init[]   =   { 1, 1, 5, 15, 13, 27, 23, 227, 145, 547, 1783, 987, 6895, 7135, 11023, 0 };
            const std::uint32_t dim2583JoeKuoD6Init[]   =   { 1, 1, 5, 11, 21, 39, 57, 203, 477, 17, 985, 1729, 4297, 7483, 13263, 0 };
            const std::uint32_t dim2584JoeKuoD6Init[]   =   { 1, 3, 7, 9, 3, 49, 71, 45, 143, 967, 39, 583, 2123, 5165, 17437, 0 };
            const std::uint32_t dim2585JoeKuoD6Init[]   =   { 1, 1, 1, 9, 21, 51, 71, 163, 441, 709, 397, 445, 6167, 7753, 11513, 0 };
            const std::uint32_t dim2586JoeKuoD6Init[]   =   { 1, 1, 7, 7, 27, 35, 5, 181, 449, 53, 621, 3401, 5263, 4557, 9141, 0 };
            const std::uint32_t dim2587JoeKuoD6Init[]   =   { 1, 1, 5, 7, 7, 37, 83, 111, 485, 881, 465, 3371, 5603, 371, 29393, 0 };
            const std::uint32_t dim2588JoeKuoD6Init[]   =   { 1, 3, 1, 15, 7, 47, 41, 245, 377, 823, 309, 3929, 2159, 13917, 13365, 0 };
            const std::uint32_t dim2589JoeKuoD6Init[]   =   { 1, 3, 7, 7, 7, 29, 25, 141, 19, 611, 79, 2689, 109, 12321, 8345, 0 };
            const std::uint32_t dim2590JoeKuoD6Init[]   =   { 1, 1, 1, 13, 3, 53, 113, 151, 381, 791, 137, 3185, 3567, 211, 597, 0 };
            const std::uint32_t dim2591JoeKuoD6Init[]   =   { 1, 1, 3, 9, 7, 53, 87, 89, 491, 861, 467, 3763, 2025, 4187, 9637, 0 };
            const std::uint32_t dim2592JoeKuoD6Init[]   =   { 1, 1, 7, 1, 27, 33, 71, 41, 63, 1011, 741, 1135, 175, 3739, 21493, 0 };
            const std::uint32_t dim2593JoeKuoD6Init[]   =   { 1, 3, 3, 5, 9, 19, 55, 175, 325, 55, 1193, 1423, 2049, 9633, 17515, 0 };
            const std::uint32_t dim2594JoeKuoD6Init[]   =   { 1, 1, 3, 1, 27, 55, 69, 103, 401, 707, 825, 399, 6799, 13199, 6295, 0 };
            const std::uint32_t dim2595JoeKuoD6Init[]   =   { 1, 3, 7, 3, 19, 63, 25, 151, 17, 159, 1673, 615, 6317, 13261, 26267, 0 };
            const std::uint32_t dim2596JoeKuoD6Init[]   =   { 1, 3, 7, 9, 27, 1, 77, 129, 423, 647, 707, 2579, 3525, 6723, 31615, 0 };
            const std::uint32_t dim2597JoeKuoD6Init[]   =   { 1, 3, 3, 7, 7, 31, 35, 241, 309, 369, 895, 3683, 4795, 11319, 451, 0 };
            const std::uint32_t dim2598JoeKuoD6Init[]   =   { 1, 3, 5, 7, 17, 7, 117, 141, 267, 713, 569, 1915, 4369, 7793, 30853, 0 };
            const std::uint32_t dim2599JoeKuoD6Init[]   =   { 1, 3, 7, 1, 29, 61, 81, 73, 413, 13, 1977, 3229, 5853, 8451, 15539, 0 };
            const std::uint32_t dim2600JoeKuoD6Init[]   =   { 1, 3, 7, 1, 5, 45, 109, 21, 431, 487, 2019, 2647, 927, 16015, 10711, 0 };
            const std::uint32_t dim2601JoeKuoD6Init[]   =   { 1, 3, 1, 3, 11, 19, 37, 183, 451, 377, 269, 3993, 3229, 4899, 26561, 0 };
            const std::uint32_t dim2602JoeKuoD6Init[]   =   { 1, 3, 1, 11, 5, 19, 121, 55, 57, 117, 687, 83, 3047, 1367, 17595, 0 };
            const std::uint32_t dim2603JoeKuoD6Init[]   =   { 1, 3, 1, 7, 17, 31, 41, 219, 239, 963, 199, 2895, 5599, 7639, 17201, 0 };
            const std::uint32_t dim2604JoeKuoD6Init[]   =   { 1, 3, 3, 5, 27, 53, 71, 183, 509, 771, 1809, 1539, 2229, 4893, 17115, 0 };
            const std::uint32_t dim2605JoeKuoD6Init[]   =   { 1, 1, 3, 9, 9, 9, 13, 49, 265, 643, 1929, 859, 497, 9797, 27771, 0 };
            const std::uint32_t dim2606JoeKuoD6Init[]   =   { 1, 3, 7, 11, 19, 39, 115, 139, 207, 903, 963, 1849, 4403, 6229, 10021, 0 };
            const std::uint32_t dim2607JoeKuoD6Init[]   =   { 1, 3, 7, 13, 3, 57, 99, 223, 503, 423, 1755, 807, 1885, 213, 18723, 0 };
            const std::uint32_t dim2608JoeKuoD6Init[]   =   { 1, 3, 7, 15, 11, 15, 111, 193, 243, 599, 593, 3385, 5393, 15073, 17777, 0 };
            const std::uint32_t dim2609JoeKuoD6Init[]   =   { 1, 1, 5, 3, 19, 63, 121, 207, 99, 435, 1961, 2747, 6405, 3971, 23481, 0 };
            const std::uint32_t dim2610JoeKuoD6Init[]   =   { 1, 3, 5, 13, 9, 29, 79, 131, 415, 49, 229, 1003, 3263, 12975, 15987, 0 };
            const std::uint32_t dim2611JoeKuoD6Init[]   =   { 1, 1, 3, 7, 1, 41, 127, 155, 29, 73, 963, 659, 2741, 3465, 2595, 0 };
            const std::uint32_t dim2612JoeKuoD6Init[]   =   { 1, 1, 3, 5, 23, 23, 93, 233, 113, 521, 427, 1557, 6917, 12953, 22441, 0 };
            const std::uint32_t dim2613JoeKuoD6Init[]   =   { 1, 1, 5, 13, 5, 25, 85, 191, 387, 69, 955, 243, 4473, 9813, 21711, 0 };
            const std::uint32_t dim2614JoeKuoD6Init[]   =   { 1, 3, 3, 7, 1, 53, 95, 65, 231, 995, 539, 2103, 5513, 14087, 28655, 0 };
            const std::uint32_t dim2615JoeKuoD6Init[]   =   { 1, 3, 5, 3, 17, 13, 19, 227, 197, 91, 1437, 1121, 3307, 6903, 3297, 0 };
            const std::uint32_t dim2616JoeKuoD6Init[]   =   { 1, 1, 5, 11, 31, 29, 109, 171, 257, 783, 861, 9, 4895, 1859, 10909, 0 };
            const std::uint32_t dim2617JoeKuoD6Init[]   =   { 1, 1, 7, 13, 5, 47, 61, 5, 363, 351, 1525, 823, 2883, 12435, 17629, 0 };
            const std::uint32_t dim2618JoeKuoD6Init[]   =   { 1, 1, 5, 11, 9, 3, 69, 159, 371, 477, 1223, 1973, 2757, 413, 31223, 0 };
            const std::uint32_t dim2619JoeKuoD6Init[]   =   { 1, 1, 3, 5, 23, 45, 43, 195, 423, 829, 1673, 1563, 6633, 14775, 21097, 0 };
            const std::uint32_t dim2620JoeKuoD6Init[]   =   { 1, 1, 3, 3, 13, 9, 107, 209, 49, 609, 1047, 3691, 7483, 4269, 7557, 0 };
            const std::uint32_t dim2621JoeKuoD6Init[]   =   { 1, 1, 3, 15, 3, 43, 73, 161, 53, 813, 325, 3439, 7009, 8691, 11711, 0 };
            const std::uint32_t dim2622JoeKuoD6Init[]   =   { 1, 1, 3, 3, 23, 45, 99, 61, 407, 15, 1515, 1557, 953, 8567, 13729, 0 };
            const std::uint32_t dim2623JoeKuoD6Init[]   =   { 1, 1, 5, 9, 31, 35, 117, 57, 227, 923, 1373, 1811, 3405, 11979, 10149, 0 };
            const std::uint32_t dim2624JoeKuoD6Init[]   =   { 1, 1, 3, 9, 15, 53, 105, 209, 153, 67, 1477, 667, 3077, 4911, 3871, 0 };
            const std::uint32_t dim2625JoeKuoD6Init[]   =   { 1, 1, 3, 3, 21, 53, 93, 101, 183, 1023, 3, 3041, 5815, 9043, 5801, 0 };
            const std::uint32_t dim2626JoeKuoD6Init[]   =   { 1, 3, 3, 5, 17, 49, 127, 161, 321, 869, 1369, 923, 3235, 711, 30007, 0 };
            const std::uint32_t dim2627JoeKuoD6Init[]   =   { 1, 1, 3, 3, 15, 17, 97, 229, 389, 159, 1075, 2001, 7905, 15191, 14693, 0 };
            const std::uint32_t dim2628JoeKuoD6Init[]   =   { 1, 1, 5, 11, 5, 5, 121, 173, 95, 173, 1883, 3915, 1439, 9981, 24375, 0 };
            const std::uint32_t dim2629JoeKuoD6Init[]   =   { 1, 3, 3, 1, 31, 53, 29, 189, 37, 623, 217, 949, 3959, 7189, 25427, 0 };
            const std::uint32_t dim2630JoeKuoD6Init[]   =   { 1, 3, 5, 9, 21, 45, 101, 23, 355, 729, 797, 2317, 2931, 7433, 29175, 0 };
            const std::uint32_t dim2631JoeKuoD6Init[]   =   { 1, 3, 7, 1, 1, 63, 63, 155, 237, 865, 1169, 43, 7335, 6445, 7979, 0 };
            const std::uint32_t dim2632JoeKuoD6Init[]   =   { 1, 3, 7, 7, 11, 51, 37, 199, 503, 991, 319, 3013, 7885, 12837, 32419, 0 };
            const std::uint32_t dim2633JoeKuoD6Init[]   =   { 1, 3, 7, 7, 27, 31, 101, 243, 37, 811, 1909, 109, 6455, 7903, 11821, 0 };
            const std::uint32_t dim2634JoeKuoD6Init[]   =   { 1, 1, 3, 13, 23, 21, 89, 99, 243, 605, 1017, 1871, 1101, 12825, 8227, 0 };
            const std::uint32_t dim2635JoeKuoD6Init[]   =   { 1, 3, 3, 13, 19, 3, 51, 59, 501, 605, 385, 2189, 3229, 7981, 31407, 0 };
            const std::uint32_t dim2636JoeKuoD6Init[]   =   { 1, 1, 1, 1, 25, 11, 127, 215, 295, 237, 1245, 3657, 7803, 3897, 655, 0 };
            const std::uint32_t dim2637JoeKuoD6Init[]   =   { 1, 1, 7, 7, 5, 9, 63, 129, 143, 417, 795, 3409, 2847, 5887, 3093, 0 };
            const std::uint32_t dim2638JoeKuoD6Init[]   =   { 1, 3, 3, 13, 7, 57, 67, 57, 5, 847, 1185, 3349, 4841, 11457, 8857, 0 };
            const std::uint32_t dim2639JoeKuoD6Init[]   =   { 1, 1, 3, 3, 9, 53, 51, 43, 85, 437, 13, 2543, 3651, 15493, 767, 0 };
            const std::uint32_t dim2640JoeKuoD6Init[]   =   { 1, 1, 7, 9, 1, 49, 97, 115, 133, 1011, 1399, 2653, 7765, 13999, 12097, 0 };
            const std::uint32_t dim2641JoeKuoD6Init[]   =   { 1, 1, 5, 1, 3, 27, 123, 107, 389, 401, 1759, 1333, 1371, 5277, 14865, 0 };
            const std::uint32_t dim2642JoeKuoD6Init[]   =   { 1, 1, 5, 1, 13, 23, 3, 123, 137, 821, 399, 1671, 3095, 3121, 31387, 0 };
            const std::uint32_t dim2643JoeKuoD6Init[]   =   { 1, 1, 5, 3, 7, 35, 57, 237, 509, 753, 1783, 2815, 6495, 13283, 7091, 0 };
            const std::uint32_t dim2644JoeKuoD6Init[]   =   { 1, 1, 7, 11, 5, 37, 77, 109, 7, 969, 1087, 3705, 1695, 14223, 28959, 0 };
            const std::uint32_t dim2645JoeKuoD6Init[]   =   { 1, 3, 1, 11, 25, 5, 25, 163, 179, 185, 671, 1031, 4537, 11601, 9323, 0 };
            const std::uint32_t dim2646JoeKuoD6Init[]   =   { 1, 1, 3, 7, 17, 25, 49, 221, 183, 619, 1953, 343, 4523, 14883, 6833, 0 };
            const std::uint32_t dim2647JoeKuoD6Init[]   =   { 1, 3, 7, 5, 27, 19, 59, 153, 11, 807, 513, 3019, 6875, 5307, 8405, 0 };
            const std::uint32_t dim2648JoeKuoD6Init[]   =   { 1, 1, 1, 13, 25, 41, 21, 109, 321, 135, 497, 1235, 5177, 5167, 18609, 0 };
            const std::uint32_t dim2649JoeKuoD6Init[]   =   { 1, 1, 7, 5, 21, 53, 25, 197, 411, 503, 1009, 1921, 4305, 2633, 31415, 0 };
            const std::uint32_t dim2650JoeKuoD6Init[]   =   { 1, 3, 5, 1, 25, 45, 27, 227, 271, 903, 639, 3805, 657, 8683, 29585, 0 };
            const std::uint32_t dim2651JoeKuoD6Init[]   =   { 1, 1, 5, 3, 9, 49, 37, 35, 351, 491, 851, 2983, 31, 5619, 6919, 0 };
            const std::uint32_t dim2652JoeKuoD6Init[]   =   { 1, 1, 5, 3, 11, 49, 33, 153, 393, 1017, 1561, 2795, 4435, 12589, 22349, 0 };
            const std::uint32_t dim2653JoeKuoD6Init[]   =   { 1, 1, 1, 15, 17, 29, 49, 245, 217, 359, 1133, 393, 3317, 415, 16407, 0 };
            const std::uint32_t dim2654JoeKuoD6Init[]   =   { 1, 1, 3, 5, 3, 9, 95, 63, 319, 319, 1009, 19, 6453, 16279, 6975, 0 };
            const std::uint32_t dim2655JoeKuoD6Init[]   =   { 1, 1, 5, 9, 3, 25, 67, 95, 369, 237, 285, 2409, 671, 5143, 121, 0 };
            const std::uint32_t dim2656JoeKuoD6Init[]   =   { 1, 1, 3, 1, 9, 49, 35, 87, 317, 185, 445, 2263, 7923, 10183, 26615, 0 };
            const std::uint32_t dim2657JoeKuoD6Init[]   =   { 1, 3, 3, 11, 9, 59, 29, 135, 129, 477, 353, 3571, 1057, 16329, 23523, 0 };
            const std::uint32_t dim2658JoeKuoD6Init[]   =   { 1, 1, 1, 15, 13, 11, 19, 5, 133, 827, 1799, 1893, 1939, 1101, 12147, 0 };
            const std::uint32_t dim2659JoeKuoD6Init[]   =   { 1, 1, 3, 3, 15, 49, 33, 185, 511, 1013, 41, 3499, 6235, 7643, 16725, 0 };
            const std::uint32_t dim2660JoeKuoD6Init[]   =   { 1, 1, 5, 11, 27, 45, 89, 157, 63, 137, 2047, 1275, 4995, 625, 6111, 0 };
            const std::uint32_t dim2661JoeKuoD6Init[]   =   { 1, 3, 7, 11, 3, 1, 121, 1, 341, 33, 1895, 3033, 3929, 10257, 21037, 0 };
            const std::uint32_t dim2662JoeKuoD6Init[]   =   { 1, 3, 3, 11, 7, 11, 117, 5, 115, 287, 335, 3415, 5397, 15065, 19121, 0 };
            const std::uint32_t dim2663JoeKuoD6Init[]   =   { 1, 3, 3, 13, 21, 25, 15, 125, 277, 125, 801, 3761, 2623, 11333, 16867, 0 };
            const std::uint32_t dim2664JoeKuoD6Init[]   =   { 1, 3, 5, 11, 19, 33, 21, 71, 499, 747, 1515, 185, 1759, 14623, 895, 0 };
            const std::uint32_t dim2665JoeKuoD6Init[]   =   { 1, 3, 7, 1, 29, 35, 9, 203, 277, 299, 1509, 2017, 2897, 14175, 1643, 0 };
            const std::uint32_t dim2666JoeKuoD6Init[]   =   { 1, 3, 5, 11, 7, 47, 111, 197, 459, 941, 1619, 2119, 2191, 11049, 6811, 0 };
            const std::uint32_t dim2667JoeKuoD6Init[]   =   { 1, 1, 5, 9, 7, 43, 103, 115, 87, 269, 1235, 77, 5887, 1611, 29041, 0 };
            const std::uint32_t dim2668JoeKuoD6Init[]   =   { 1, 1, 5, 7, 1, 61, 83, 225, 179, 81, 1145, 2403, 1485, 8967, 20607, 0 };
            const std::uint32_t dim2669JoeKuoD6Init[]   =   { 1, 3, 3, 1, 25, 47, 27, 157, 359, 803, 1683, 1995, 6445, 13113, 17899, 0 };
            const std::uint32_t dim2670JoeKuoD6Init[]   =   { 1, 3, 1, 7, 21, 37, 43, 119, 245, 49, 1581, 2275, 3311, 4087, 29765, 0 };
            const std::uint32_t dim2671JoeKuoD6Init[]   =   { 1, 1, 3, 13, 5, 33, 49, 191, 455, 105, 665, 3855, 3207, 2671, 32203, 0 };
            const std::uint32_t dim2672JoeKuoD6Init[]   =   { 1, 3, 1, 1, 25, 63, 19, 217, 17, 353, 947, 1951, 4097, 9041, 11921, 0 };
            const std::uint32_t dim2673JoeKuoD6Init[]   =   { 1, 3, 1, 7, 21, 31, 113, 97, 347, 993, 1799, 3831, 3711, 6193, 1235, 0 };
            const std::uint32_t dim2674JoeKuoD6Init[]   =   { 1, 1, 1, 5, 3, 63, 11, 203, 425, 445, 1361, 531, 1265, 1755, 11685, 0 };
            const std::uint32_t dim2675JoeKuoD6Init[]   =   { 1, 3, 1, 7, 13, 29, 23, 85, 57, 467, 1835, 133, 7961, 4175, 2445, 0 };
            const std::uint32_t dim2676JoeKuoD6Init[]   =   { 1, 1, 1, 15, 23, 27, 37, 5, 123, 913, 1293, 1633, 3113, 5413, 26407, 0 };
            const std::uint32_t dim2677JoeKuoD6Init[]   =   { 1, 1, 5, 13, 27, 1, 121, 151, 303, 931, 375, 3679, 1863, 12301, 30907, 0 };
            const std::uint32_t dim2678JoeKuoD6Init[]   =   { 1, 3, 1, 9, 31, 9, 49, 203, 177, 937, 1503, 933, 5867, 12533, 13621, 0 };
            const std::uint32_t dim2679JoeKuoD6Init[]   =   { 1, 3, 3, 15, 1, 41, 23, 191, 191, 931, 837, 3553, 2611, 4735, 18105, 0 };
            const std::uint32_t dim2680JoeKuoD6Init[]   =   { 1, 1, 5, 7, 27, 49, 51, 111, 435, 195, 1229, 711, 7145, 14571, 31707, 0 };
            const std::uint32_t dim2681JoeKuoD6Init[]   =   { 1, 1, 7, 7, 3, 41, 59, 203, 291, 903, 1727, 2757, 1463, 6287, 31535, 0 };
            const std::uint32_t dim2682JoeKuoD6Init[]   =   { 1, 1, 7, 13, 23, 5, 75, 3, 207, 525, 411, 2133, 2231, 477, 7155, 0 };
            const std::uint32_t dim2683JoeKuoD6Init[]   =   { 1, 3, 5, 7, 13, 19, 111, 225, 489, 83, 1177, 4077, 4617, 14413, 7133, 0 };
            const std::uint32_t dim2684JoeKuoD6Init[]   =   { 1, 3, 1, 7, 9, 59, 3, 113, 379, 803, 1289, 3347, 4127, 6669, 14867, 0 };
            const std::uint32_t dim2685JoeKuoD6Init[]   =   { 1, 3, 7, 3, 31, 37, 87, 79, 399, 749, 995, 1611, 3137, 12543, 31955, 0 };
            const std::uint32_t dim2686JoeKuoD6Init[]   =   { 1, 1, 5, 7, 21, 59, 49, 45, 511, 639, 1033, 2169, 3265, 15001, 10745, 0 };
            const std::uint32_t dim2687JoeKuoD6Init[]   =   { 1, 1, 5, 1, 25, 19, 23, 203, 11, 883, 1031, 4087, 5059, 11321, 21675, 0 };
            const std::uint32_t dim2688JoeKuoD6Init[]   =   { 1, 3, 7, 5, 11, 27, 33, 205, 163, 289, 501, 3505, 1515, 1895, 15889, 0 };
            const std::uint32_t dim2689JoeKuoD6Init[]   =   { 1, 3, 1, 1, 23, 7, 39, 239, 29, 119, 1499, 2071, 6495, 12107, 5339, 0 };
            const std::uint32_t dim2690JoeKuoD6Init[]   =   { 1, 3, 1, 1, 23, 29, 55, 181, 327, 905, 427, 1033, 427, 3687, 5367, 0 };
            const std::uint32_t dim2691JoeKuoD6Init[]   =   { 1, 3, 3, 7, 21, 27, 115, 127, 393, 855, 1291, 2121, 381, 9995, 29757, 0 };
            const std::uint32_t dim2692JoeKuoD6Init[]   =   { 1, 3, 5, 1, 25, 13, 15, 183, 269, 1005, 1531, 3451, 3975, 9479, 23695, 0 };
            const std::uint32_t dim2693JoeKuoD6Init[]   =   { 1, 3, 7, 7, 19, 31, 111, 97, 33, 179, 1343, 2069, 977, 5043, 9129, 0 };
            const std::uint32_t dim2694JoeKuoD6Init[]   =   { 1, 3, 1, 5, 17, 57, 99, 129, 379, 829, 837, 1845, 3613, 7351, 19291, 0 };
            const std::uint32_t dim2695JoeKuoD6Init[]   =   { 1, 3, 3, 5, 31, 23, 119, 229, 135, 389, 9, 705, 6697, 15441, 5303, 0 };
            const std::uint32_t dim2696JoeKuoD6Init[]   =   { 1, 1, 1, 11, 25, 31, 105, 95, 5, 931, 789, 375, 7543, 9957, 28627, 0 };
            const std::uint32_t dim2697JoeKuoD6Init[]   =   { 1, 1, 7, 15, 21, 17, 19, 103, 389, 545, 1725, 2867, 4251, 3829, 6907, 0 };
            const std::uint32_t dim2698JoeKuoD6Init[]   =   { 1, 3, 7, 7, 15, 37, 97, 65, 337, 409, 1649, 2869, 7929, 8905, 21989, 0 };
            const std::uint32_t dim2699JoeKuoD6Init[]   =   { 1, 3, 5, 3, 11, 15, 69, 29, 353, 207, 233, 411, 2047, 10303, 31655, 0 };
            const std::uint32_t dim2700JoeKuoD6Init[]   =   { 1, 3, 3, 7, 27, 43, 125, 107, 69, 981, 215, 1955, 3589, 597, 12703, 0 };
            const std::uint32_t dim2701JoeKuoD6Init[]   =   { 1, 1, 7, 9, 25, 13, 109, 73, 227, 663, 1115, 285, 471, 3359, 15787, 0 };
            const std::uint32_t dim2702JoeKuoD6Init[]   =   { 1, 3, 7, 5, 1, 45, 7, 79, 441, 149, 701, 1457, 6595, 14829, 20865, 0 };
            const std::uint32_t dim2703JoeKuoD6Init[]   =   { 1, 3, 7, 15, 15, 47, 83, 239, 295, 23, 1085, 813, 1209, 3573, 2855, 0 };
            const std::uint32_t dim2704JoeKuoD6Init[]   =   { 1, 1, 3, 15, 13, 7, 59, 67, 255, 537, 1841, 3857, 6821, 15175, 13997, 0 };
            const std::uint32_t dim2705JoeKuoD6Init[]   =   { 1, 3, 1, 1, 9, 57, 59, 21, 21, 41, 1693, 2805, 7953, 1389, 14105, 0 };
            const std::uint32_t dim2706JoeKuoD6Init[]   =   { 1, 3, 5, 15, 19, 49, 107, 117, 99, 607, 145, 53, 1863, 9383, 12029, 0 };
            const std::uint32_t dim2707JoeKuoD6Init[]   =   { 1, 3, 3, 13, 1, 39, 5, 141, 503, 265, 281, 1785, 2673, 6597, 6333, 0 };
            const std::uint32_t dim2708JoeKuoD6Init[]   =   { 1, 1, 5, 3, 3, 19, 3, 181, 169, 269, 955, 2399, 3157, 11053, 8563, 0 };
            const std::uint32_t dim2709JoeKuoD6Init[]   =   { 1, 3, 3, 13, 11, 1, 95, 43, 179, 507, 443, 209, 3239, 14239, 21829, 0 };
            const std::uint32_t dim2710JoeKuoD6Init[]   =   { 1, 1, 7, 9, 3, 17, 99, 179, 445, 479, 1897, 1507, 5753, 4757, 2135, 0 };
            const std::uint32_t dim2711JoeKuoD6Init[]   =   { 1, 3, 3, 1, 9, 51, 29, 13, 295, 291, 927, 85, 5707, 7447, 32319, 0 };
            const std::uint32_t dim2712JoeKuoD6Init[]   =   { 1, 1, 1, 3, 13, 11, 21, 157, 213, 327, 1071, 591, 2639, 15405, 6617, 0 };
            const std::uint32_t dim2713JoeKuoD6Init[]   =   { 1, 3, 5, 1, 7, 25, 55, 47, 495, 681, 727, 2707, 2955, 705, 7489, 0 };
            const std::uint32_t dim2714JoeKuoD6Init[]   =   { 1, 1, 3, 9, 17, 3, 73, 67, 465, 367, 1473, 3195, 7825, 5299, 1817, 0 };
            const std::uint32_t dim2715JoeKuoD6Init[]   =   { 1, 1, 1, 1, 19, 31, 77, 253, 71, 599, 1601, 871, 2243, 6699, 13013, 0 };
            const std::uint32_t dim2716JoeKuoD6Init[]   =   { 1, 1, 7, 9, 21, 1, 71, 115, 5, 65, 767, 925, 7901, 10761, 19431, 0 };
            const std::uint32_t dim2717JoeKuoD6Init[]   =   { 1, 3, 1, 7, 23, 31, 31, 15, 105, 391, 585, 2995, 2635, 10607, 24951, 0 };
            const std::uint32_t dim2718JoeKuoD6Init[]   =   { 1, 3, 3, 1, 19, 25, 71, 211, 41, 197, 787, 225, 6781, 813, 10117, 0 };
            const std::uint32_t dim2719JoeKuoD6Init[]   =   { 1, 3, 3, 3, 17, 29, 3, 153, 231, 643, 1151, 447, 3699, 9625, 26677, 0 };
            const std::uint32_t dim2720JoeKuoD6Init[]   =   { 1, 1, 5, 9, 1, 25, 71, 21, 395, 297, 557, 3841, 233, 1877, 4569, 0 };
            const std::uint32_t dim2721JoeKuoD6Init[]   =   { 1, 1, 3, 13, 1, 45, 115, 61, 5, 937, 173, 2109, 2927, 9599, 9155, 0 };
            const std::uint32_t dim2722JoeKuoD6Init[]   =   { 1, 1, 3, 3, 15, 21, 61, 121, 253, 285, 1083, 3545, 5537, 6773, 2629, 0 };
            const std::uint32_t dim2723JoeKuoD6Init[]   =   { 1, 3, 3, 15, 13, 63, 33, 77, 49, 849, 1795, 2771, 5481, 9833, 603, 0 };
            const std::uint32_t dim2724JoeKuoD6Init[]   =   { 1, 1, 7, 5, 1, 39, 113, 237, 225, 1005, 1687, 2297, 3213, 2605, 14669, 0 };
            const std::uint32_t dim2725JoeKuoD6Init[]   =   { 1, 1, 3, 1, 11, 1, 39, 23, 67, 441, 1235, 2545, 3139, 15901, 29243, 0 };
            const std::uint32_t dim2726JoeKuoD6Init[]   =   { 1, 3, 1, 3, 15, 49, 39, 57, 311, 345, 525, 223, 4923, 6311, 25275, 0 };
            const std::uint32_t dim2727JoeKuoD6Init[]   =   { 1, 1, 5, 7, 9, 13, 69, 11, 349, 423, 1773, 1055, 1001, 9359, 17025, 0 };
            const std::uint32_t dim2728JoeKuoD6Init[]   =   { 1, 1, 1, 13, 15, 63, 89, 207, 335, 591, 1223, 2701, 55, 12471, 13127, 0 };
            const std::uint32_t dim2729JoeKuoD6Init[]   =   { 1, 1, 3, 5, 15, 19, 83, 67, 407, 113, 1961, 779, 5803, 12417, 21751, 0 };
            const std::uint32_t dim2730JoeKuoD6Init[]   =   { 1, 3, 3, 1, 21, 53, 81, 95, 405, 427, 1047, 2443, 4153, 5843, 22511, 0 };
            const std::uint32_t dim2731JoeKuoD6Init[]   =   { 1, 1, 7, 7, 7, 25, 115, 155, 453, 537, 741, 2379, 2343, 16035, 19587, 0 };
            const std::uint32_t dim2732JoeKuoD6Init[]   =   { 1, 3, 3, 11, 27, 21, 111, 121, 503, 437, 803, 3399, 5303, 10163, 18199, 0 };
            const std::uint32_t dim2733JoeKuoD6Init[]   =   { 1, 1, 5, 13, 19, 27, 7, 81, 259, 545, 965, 743, 4533, 8813, 21253, 0 };
            const std::uint32_t dim2734JoeKuoD6Init[]   =   { 1, 1, 5, 5, 1, 59, 37, 11, 105, 343, 75, 1319, 6317, 9593, 1699, 0 };
            const std::uint32_t dim2735JoeKuoD6Init[]   =   { 1, 3, 1, 9, 13, 9, 115, 131, 387, 1023, 253, 693, 5191, 12777, 10565, 0 };
            const std::uint32_t dim2736JoeKuoD6Init[]   =   { 1, 3, 1, 15, 7, 35, 111, 195, 287, 305, 533, 1901, 3363, 10085, 30791, 0 };
            const std::uint32_t dim2737JoeKuoD6Init[]   =   { 1, 1, 3, 9, 27, 51, 21, 77, 413, 925, 717, 791, 4147, 585, 5649, 0 };
            const std::uint32_t dim2738JoeKuoD6Init[]   =   { 1, 3, 3, 5, 25, 59, 79, 249, 185, 567, 71, 1997, 7373, 2327, 18637, 0 };
            const std::uint32_t dim2739JoeKuoD6Init[]   =   { 1, 3, 3, 11, 15, 21, 97, 99, 391, 57, 1973, 29, 7451, 2529, 25737, 0 };
            const std::uint32_t dim2740JoeKuoD6Init[]   =   { 1, 3, 7, 5, 7, 59, 93, 5, 287, 469, 1639, 3637, 5465, 14431, 32265, 0 };
            const std::uint32_t dim2741JoeKuoD6Init[]   =   { 1, 1, 3, 11, 3, 1, 71, 75, 427, 299, 811, 3697, 3529, 5433, 26957, 0 };
            const std::uint32_t dim2742JoeKuoD6Init[]   =   { 1, 3, 1, 9, 19, 59, 37, 255, 165, 1005, 19, 2851, 4309, 455, 9485, 0 };
            const std::uint32_t dim2743JoeKuoD6Init[]   =   { 1, 1, 1, 5, 1, 55, 15, 233, 133, 47, 1831, 713, 2601, 1017, 3201, 0 };
            const std::uint32_t dim2744JoeKuoD6Init[]   =   { 1, 1, 5, 5, 21, 55, 127, 69, 377, 41, 25, 2295, 7595, 4733, 11615, 0 };
            const std::uint32_t dim2745JoeKuoD6Init[]   =   { 1, 1, 5, 3, 23, 5, 7, 181, 161, 775, 1095, 2271, 6637, 14489, 6873, 0 };
            const std::uint32_t dim2746JoeKuoD6Init[]   =   { 1, 3, 5, 9, 9, 15, 5, 133, 357, 21, 127, 2685, 6299, 4363, 17573, 0 };
            const std::uint32_t dim2747JoeKuoD6Init[]   =   { 1, 3, 3, 9, 13, 39, 51, 223, 201, 401, 1839, 2461, 7633, 6039, 10445, 0 };
            const std::uint32_t dim2748JoeKuoD6Init[]   =   { 1, 1, 5, 1, 9, 21, 19, 249, 227, 359, 255, 2895, 4117, 2073, 27687, 0 };
            const std::uint32_t dim2749JoeKuoD6Init[]   =   { 1, 1, 5, 15, 5, 61, 113, 161, 95, 3, 877, 2775, 293, 6655, 4023, 0 };
            const std::uint32_t dim2750JoeKuoD6Init[]   =   { 1, 3, 7, 1, 7, 55, 73, 39, 295, 403, 985, 2315, 1667, 13525, 1453, 0 };
            const std::uint32_t dim2751JoeKuoD6Init[]   =   { 1, 1, 5, 1, 27, 1, 85, 195, 11, 713, 1841, 3895, 3131, 2193, 17607, 0 };
            const std::uint32_t dim2752JoeKuoD6Init[]   =   { 1, 3, 5, 13, 25, 1, 119, 97, 239, 167, 1393, 1753, 6989, 12155, 12509, 0 };
            const std::uint32_t dim2753JoeKuoD6Init[]   =   { 1, 1, 7, 15, 31, 21, 41, 255, 425, 445, 165, 2097, 5627, 4971, 13207, 0 };
            const std::uint32_t dim2754JoeKuoD6Init[]   =   { 1, 1, 1, 15, 13, 33, 81, 105, 453, 197, 13, 1547, 7381, 8709, 15103, 0 };
            const std::uint32_t dim2755JoeKuoD6Init[]   =   { 1, 1, 3, 11, 11, 33, 107, 123, 483, 367, 121, 995, 1911, 8205, 22577, 0 };
            const std::uint32_t dim2756JoeKuoD6Init[]   =   { 1, 1, 1, 9, 9, 43, 71, 49, 273, 431, 1705, 3313, 4259, 16291, 14345, 0 };
            const std::uint32_t dim2757JoeKuoD6Init[]   =   { 1, 1, 1, 7, 3, 1, 43, 213, 97, 547, 1559, 1149, 2791, 3751, 887, 0 };
            const std::uint32_t dim2758JoeKuoD6Init[]   =   { 1, 1, 3, 15, 25, 47, 49, 251, 425, 35, 295, 3767, 6305, 9633, 5045, 0 };
            const std::uint32_t dim2759JoeKuoD6Init[]   =   { 1, 3, 3, 1, 5, 55, 91, 245, 27, 981, 331, 555, 6553, 11017, 15289, 0 };
            const std::uint32_t dim2760JoeKuoD6Init[]   =   { 1, 1, 3, 7, 1, 23, 23, 155, 223, 565, 1005, 3211, 3847, 7479, 3643, 0 };
            const std::uint32_t dim2761JoeKuoD6Init[]   =   { 1, 1, 5, 1, 17, 7, 47, 95, 35, 779, 1685, 2099, 7505, 15425, 18089, 0 };
            const std::uint32_t dim2762JoeKuoD6Init[]   =   { 1, 3, 3, 7, 3, 63, 83, 151, 211, 147, 611, 1171, 1681, 7687, 13423, 0 };
            const std::uint32_t dim2763JoeKuoD6Init[]   =   { 1, 3, 3, 1, 3, 27, 107, 117, 497, 537, 195, 3075, 2753, 1665, 19399, 0 };
            const std::uint32_t dim2764JoeKuoD6Init[]   =   { 1, 1, 1, 7, 23, 5, 103, 209, 117, 845, 1243, 1283, 4253, 9723, 20937, 0 };
            const std::uint32_t dim2765JoeKuoD6Init[]   =   { 1, 3, 1, 1, 5, 49, 7, 13, 419, 125, 287, 1599, 8161, 1275, 24661, 0 };
            const std::uint32_t dim2766JoeKuoD6Init[]   =   { 1, 3, 3, 3, 13, 63, 23, 183, 39, 979, 1301, 2349, 905, 15805, 30151, 0 };
            const std::uint32_t dim2767JoeKuoD6Init[]   =   { 1, 1, 3, 9, 17, 11, 97, 189, 189, 511, 1779, 2077, 6891, 11623, 23949, 0 };
            const std::uint32_t dim2768JoeKuoD6Init[]   =   { 1, 1, 7, 11, 13, 45, 15, 37, 11, 853, 915, 1569, 6103, 10633, 3137, 0 };
            const std::uint32_t dim2769JoeKuoD6Init[]   =   { 1, 3, 3, 5, 15, 61, 91, 255, 131, 821, 1755, 1501, 2663, 1747, 941, 0 };
            const std::uint32_t dim2770JoeKuoD6Init[]   =   { 1, 1, 3, 7, 19, 19, 65, 95, 499, 239, 2023, 3185, 4649, 3861, 3767, 0 };
            const std::uint32_t dim2771JoeKuoD6Init[]   =   { 1, 3, 5, 15, 15, 63, 55, 93, 127, 303, 171, 1763, 4991, 9479, 9917, 0 };
            const std::uint32_t dim2772JoeKuoD6Init[]   =   { 1, 3, 7, 5, 31, 53, 111, 35, 433, 163, 1903, 3991, 3585, 643, 21941, 0 };
            const std::uint32_t dim2773JoeKuoD6Init[]   =   { 1, 3, 1, 9, 27, 39, 67, 89, 487, 349, 587, 1723, 4311, 11321, 25785, 0 };
            const std::uint32_t dim2774JoeKuoD6Init[]   =   { 1, 3, 5, 7, 1, 63, 23, 237, 507, 689, 1341, 441, 1721, 843, 20335, 0 };
            const std::uint32_t dim2775JoeKuoD6Init[]   =   { 1, 1, 3, 3, 31, 63, 83, 103, 25, 799, 1379, 1817, 3809, 12285, 16673, 0 };
            const std::uint32_t dim2776JoeKuoD6Init[]   =   { 1, 1, 5, 3, 25, 29, 99, 193, 21, 549, 33, 3109, 4135, 10071, 32355, 0 };
            const std::uint32_t dim2777JoeKuoD6Init[]   =   { 1, 3, 1, 7, 13, 27, 83, 189, 121, 167, 379, 1503, 7955, 13189, 313, 0 };
            const std::uint32_t dim2778JoeKuoD6Init[]   =   { 1, 3, 5, 15, 25, 19, 83, 87, 257, 237, 709, 1169, 1561, 7117, 4785, 0 };
            const std::uint32_t dim2779JoeKuoD6Init[]   =   { 1, 1, 1, 7, 9, 55, 21, 5, 439, 367, 403, 2311, 6243, 8349, 13127, 0 };
            const std::uint32_t dim2780JoeKuoD6Init[]   =   { 1, 3, 7, 3, 5, 35, 51, 67, 453, 767, 29, 3293, 6665, 11459, 2799, 0 };
            const std::uint32_t dim2781JoeKuoD6Init[]   =   { 1, 3, 3, 3, 5, 19, 59, 7, 367, 683, 783, 1317, 7119, 6129, 19525, 0 };
            const std::uint32_t dim2782JoeKuoD6Init[]   =   { 1, 1, 5, 5, 5, 19, 61, 67, 381, 291, 875, 2179, 2481, 9325, 11253, 0 };
            const std::uint32_t dim2783JoeKuoD6Init[]   =   { 1, 3, 5, 5, 7, 47, 107, 9, 141, 667, 1989, 821, 3909, 1733, 10187, 0 };
            const std::uint32_t dim2784JoeKuoD6Init[]   =   { 1, 1, 7, 7, 31, 61, 1, 71, 477, 689, 1539, 3617, 8105, 6535, 3293, 0 };
            const std::uint32_t dim2785JoeKuoD6Init[]   =   { 1, 1, 5, 5, 23, 9, 103, 197, 241, 249, 297, 3607, 6217, 1673, 30103, 0 };
            const std::uint32_t dim2786JoeKuoD6Init[]   =   { 1, 3, 1, 5, 23, 15, 115, 105, 365, 51, 825, 2687, 359, 16325, 15083, 0 };
            const std::uint32_t dim2787JoeKuoD6Init[]   =   { 1, 1, 3, 11, 29, 45, 65, 251, 169, 189, 1243, 2345, 1345, 14471, 25631, 0 };
            const std::uint32_t dim2788JoeKuoD6Init[]   =   { 1, 1, 5, 9, 7, 63, 81, 167, 309, 539, 1169, 3949, 4193, 12047, 1491, 0 };
            const std::uint32_t dim2789JoeKuoD6Init[]   =   { 1, 3, 1, 9, 29, 33, 89, 167, 67, 73, 1885, 477, 5745, 13365, 6819, 0 };
            const std::uint32_t dim2790JoeKuoD6Init[]   =   { 1, 3, 7, 9, 9, 49, 95, 13, 157, 997, 1725, 935, 7543, 6349, 18277, 0 };
            const std::uint32_t dim2791JoeKuoD6Init[]   =   { 1, 1, 5, 5, 11, 59, 97, 17, 303, 469, 93, 2761, 7395, 9021, 24299, 0 };
            const std::uint32_t dim2792JoeKuoD6Init[]   =   { 1, 1, 7, 3, 27, 63, 71, 99, 407, 139, 711, 2589, 4715, 5405, 3277, 0 };
            const std::uint32_t dim2793JoeKuoD6Init[]   =   { 1, 3, 7, 3, 11, 15, 49, 57, 271, 493, 1165, 2839, 8191, 2609, 14759, 0 };
            const std::uint32_t dim2794JoeKuoD6Init[]   =   { 1, 1, 1, 7, 21, 15, 71, 245, 413, 473, 1321, 1165, 1027, 6983, 12867, 0 };
            const std::uint32_t dim2795JoeKuoD6Init[]   =   { 1, 1, 5, 3, 15, 21, 19, 197, 401, 627, 2047, 2761, 5807, 5751, 28025, 0 };
            const std::uint32_t dim2796JoeKuoD6Init[]   =   { 1, 1, 3, 3, 5, 57, 19, 209, 341, 165, 489, 455, 231, 14385, 12457, 0 };
            const std::uint32_t dim2797JoeKuoD6Init[]   =   { 1, 3, 3, 11, 13, 63, 79, 129, 17, 315, 1881, 1069, 177, 12013, 29567, 0 };
            const std::uint32_t dim2798JoeKuoD6Init[]   =   { 1, 1, 3, 7, 31, 29, 51, 235, 475, 375, 617, 437, 6379, 8505, 23079, 0 };
            const std::uint32_t dim2799JoeKuoD6Init[]   =   { 1, 1, 3, 7, 27, 3, 3, 137, 203, 959, 363, 371, 2899, 13491, 22979, 0 };
            const std::uint32_t dim2800JoeKuoD6Init[]   =   { 1, 3, 3, 3, 9, 1, 57, 7, 363, 537, 713, 2417, 509, 7747, 22135, 0 };
            const std::uint32_t dim2801JoeKuoD6Init[]   =   { 1, 3, 3, 3, 13, 21, 79, 121, 487, 921, 113, 281, 2853, 14855, 19747, 0 };
            const std::uint32_t dim2802JoeKuoD6Init[]   =   { 1, 1, 1, 11, 3, 53, 89, 123, 307, 585, 567, 1925, 505, 15935, 20419, 0 };
            const std::uint32_t dim2803JoeKuoD6Init[]   =   { 1, 1, 3, 3, 15, 45, 77, 197, 499, 683, 1405, 3573, 981, 14135, 19763, 0 };
            const std::uint32_t dim2804JoeKuoD6Init[]   =   { 1, 1, 1, 11, 27, 31, 61, 191, 29, 601, 373, 2011, 6193, 3599, 4387, 0 };
            const std::uint32_t dim2805JoeKuoD6Init[]   =   { 1, 3, 5, 9, 7, 13, 1, 193, 469, 603, 1315, 3329, 3761, 8355, 10425, 0 };
            const std::uint32_t dim2806JoeKuoD6Init[]   =   { 1, 1, 3, 9, 29, 61, 103, 17, 117, 251, 2029, 2963, 3763, 16117, 6627, 0 };
            const std::uint32_t dim2807JoeKuoD6Init[]   =   { 1, 3, 1, 3, 7, 51, 91, 145, 497, 657, 871, 3707, 5905, 10449, 14901, 0 };
            const std::uint32_t dim2808JoeKuoD6Init[]   =   { 1, 1, 3, 1, 3, 53, 23, 149, 461, 333, 1809, 1315, 1815, 8223, 13297, 0 };
            const std::uint32_t dim2809JoeKuoD6Init[]   =   { 1, 1, 1, 7, 15, 31, 3, 47, 443, 829, 1305, 893, 4191, 9681, 32661, 0 };
            const std::uint32_t dim2810JoeKuoD6Init[]   =   { 1, 3, 1, 3, 27, 43, 51, 221, 295, 825, 649, 2953, 6203, 8237, 20253, 0 };
            const std::uint32_t dim2811JoeKuoD6Init[]   =   { 1, 3, 1, 3, 9, 35, 41, 195, 249, 225, 387, 3789, 1499, 2559, 28413, 0 };
            const std::uint32_t dim2812JoeKuoD6Init[]   =   { 1, 1, 5, 15, 19, 29, 13, 115, 333, 787, 787, 723, 2987, 6227, 10865, 0 };
            const std::uint32_t dim2813JoeKuoD6Init[]   =   { 1, 3, 5, 13, 5, 59, 5, 251, 79, 387, 11, 3167, 6619, 13317, 18979, 0 };
            const std::uint32_t dim2814JoeKuoD6Init[]   =   { 1, 1, 7, 11, 31, 51, 43, 1, 189, 519, 1945, 2129, 4365, 14059, 3139, 0 };
            const std::uint32_t dim2815JoeKuoD6Init[]   =   { 1, 1, 7, 5, 31, 9, 43, 19, 151, 533, 1061, 3849, 6871, 6941, 14935, 0 };
            const std::uint32_t dim2816JoeKuoD6Init[]   =   { 1, 3, 7, 5, 19, 57, 7, 129, 25, 353, 17, 1739, 6513, 399, 28835, 0 };
            const std::uint32_t dim2817JoeKuoD6Init[]   =   { 1, 3, 5, 15, 25, 15, 37, 125, 39, 239, 271, 65, 2189, 10449, 11815, 0 };
            const std::uint32_t dim2818JoeKuoD6Init[]   =   { 1, 3, 7, 15, 19, 57, 47, 245, 509, 945, 385, 3987, 3585, 14711, 9655, 0 };
            const std::uint32_t dim2819JoeKuoD6Init[]   =   { 1, 1, 3, 13, 21, 31, 13, 81, 9, 489, 1321, 63, 1363, 2219, 19541, 0 };
            const std::uint32_t dim2820JoeKuoD6Init[]   =   { 1, 1, 5, 7, 3, 57, 25, 147, 23, 553, 889, 307, 6429, 15807, 12861, 0 };
            const std::uint32_t dim2821JoeKuoD6Init[]   =   { 1, 1, 3, 15, 29, 21, 99, 237, 151, 881, 675, 3625, 1159, 11759, 21347, 0 };
            const std::uint32_t dim2822JoeKuoD6Init[]   =   { 1, 1, 7, 1, 9, 13, 111, 239, 235, 609, 1569, 3271, 2837, 13807, 7301, 0 };
            const std::uint32_t dim2823JoeKuoD6Init[]   =   { 1, 3, 1, 15, 7, 59, 27, 81, 129, 9, 647, 3595, 1877, 1067, 1859, 0 };
            const std::uint32_t dim2824JoeKuoD6Init[]   =   { 1, 3, 7, 1, 3, 25, 119, 57, 145, 441, 1045, 789, 215, 1265, 9369, 0 };
            const std::uint32_t dim2825JoeKuoD6Init[]   =   { 1, 3, 7, 3, 17, 25, 87, 211, 441, 229, 223, 2795, 7241, 7007, 20575, 0 };
            const std::uint32_t dim2826JoeKuoD6Init[]   =   { 1, 1, 3, 1, 13, 1, 55, 227, 389, 141, 1097, 2487, 7603, 4161, 5025, 0 };
            const std::uint32_t dim2827JoeKuoD6Init[]   =   { 1, 1, 3, 5, 15, 29, 29, 145, 233, 209, 891, 89, 8097, 2897, 26685, 0 };
            const std::uint32_t dim2828JoeKuoD6Init[]   =   { 1, 1, 3, 1, 29, 53, 19, 95, 161, 359, 435, 3313, 4955, 7965, 21015, 0 };
            const std::uint32_t dim2829JoeKuoD6Init[]   =   { 1, 3, 5, 9, 19, 3, 109, 77, 29, 937, 1663, 125, 2453, 1069, 20639, 0 };
            const std::uint32_t dim2830JoeKuoD6Init[]   =   { 1, 3, 7, 13, 5, 23, 43, 231, 347, 591, 1963, 2491, 4045, 16029, 8149, 0 };
            const std::uint32_t dim2831JoeKuoD6Init[]   =   { 1, 1, 5, 1, 13, 3, 75, 211, 419, 929, 901, 3453, 8121, 799, 8897, 0 };
            const std::uint32_t dim2832JoeKuoD6Init[]   =   { 1, 1, 7, 15, 11, 11, 123, 111, 309, 415, 1071, 975, 2009, 12945, 19617, 0 };
            const std::uint32_t dim2833JoeKuoD6Init[]   =   { 1, 1, 1, 7, 31, 35, 81, 255, 89, 643, 451, 513, 497, 11751, 24215, 0 };
            const std::uint32_t dim2834JoeKuoD6Init[]   =   { 1, 3, 5, 5, 25, 17, 5, 165, 139, 929, 1927, 1353, 7427, 9719, 17087, 0 };
            const std::uint32_t dim2835JoeKuoD6Init[]   =   { 1, 3, 5, 1, 21, 55, 79, 85, 333, 847, 1305, 851, 5057, 8361, 18269, 0 };
            const std::uint32_t dim2836JoeKuoD6Init[]   =   { 1, 3, 7, 15, 27, 17, 55, 125, 395, 223, 271, 781, 1639, 10569, 11143, 0 };
            const std::uint32_t dim2837JoeKuoD6Init[]   =   { 1, 1, 7, 9, 7, 33, 127, 85, 209, 339, 483, 241, 2523, 14951, 6855, 0 };
            const std::uint32_t dim2838JoeKuoD6Init[]   =   { 1, 1, 3, 9, 5, 19, 9, 183, 435, 343, 1105, 3139, 7617, 1311, 267, 0 };
            const std::uint32_t dim2839JoeKuoD6Init[]   =   { 1, 1, 5, 1, 15, 53, 11, 63, 113, 241, 855, 3123, 4777, 3495, 23345, 0 };
            const std::uint32_t dim2840JoeKuoD6Init[]   =   { 1, 3, 1, 5, 19, 29, 119, 205, 167, 683, 289, 1629, 4977, 8981, 6867, 0 };
            const std::uint32_t dim2841JoeKuoD6Init[]   =   { 1, 3, 1, 1, 31, 63, 95, 159, 267, 231, 863, 3385, 5315, 7267, 13757, 0 };
            const std::uint32_t dim2842JoeKuoD6Init[]   =   { 1, 3, 5, 11, 19, 21, 53, 41, 125, 179, 533, 1279, 3759, 7073, 13905, 0 };
            const std::uint32_t dim2843JoeKuoD6Init[]   =   { 1, 3, 5, 9, 17, 7, 27, 67, 97, 809, 1423, 2743, 2859, 16121, 329, 0 };
            const std::uint32_t dim2844JoeKuoD6Init[]   =   { 1, 3, 1, 15, 1, 41, 59, 155, 509, 51, 1827, 3739, 3879, 13369, 30821, 0 };
            const std::uint32_t dim2845JoeKuoD6Init[]   =   { 1, 3, 3, 7, 21, 31, 7, 13, 347, 919, 1225, 497, 5051, 3769, 20211, 0 };
            const std::uint32_t dim2846JoeKuoD6Init[]   =   { 1, 3, 7, 13, 31, 9, 127, 195, 123, 387, 3, 3593, 6623, 9827, 29319, 0 };
            const std::uint32_t dim2847JoeKuoD6Init[]   =   { 1, 1, 3, 9, 7, 27, 95, 211, 287, 189, 1683, 1999, 7641, 14983, 4699, 0 };
            const std::uint32_t dim2848JoeKuoD6Init[]   =   { 1, 1, 5, 3, 7, 21, 29, 189, 101, 423, 885, 3275, 6569, 11023, 22265, 0 };
            const std::uint32_t dim2849JoeKuoD6Init[]   =   { 1, 3, 5, 3, 9, 33, 79, 75, 327, 975, 287, 3025, 2157, 7301, 24447, 0 };
            const std::uint32_t dim2850JoeKuoD6Init[]   =   { 1, 3, 3, 15, 31, 27, 63, 1, 71, 119, 1151, 517, 6131, 11055, 179, 0 };
            const std::uint32_t dim2851JoeKuoD6Init[]   =   { 1, 3, 7, 11, 23, 15, 101, 247, 349, 735, 673, 997, 6451, 229, 32103, 0 };
            const std::uint32_t dim2852JoeKuoD6Init[]   =   { 1, 3, 5, 15, 7, 1, 51, 135, 207, 741, 1831, 1235, 4747, 11915, 22009, 0 };
            const std::uint32_t dim2853JoeKuoD6Init[]   =   { 1, 3, 1, 13, 9, 31, 19, 221, 465, 681, 627, 2595, 5617, 14201, 30355, 0 };
            const std::uint32_t dim2854JoeKuoD6Init[]   =   { 1, 1, 3, 1, 13, 49, 55, 155, 11, 885, 1275, 3591, 2217, 6659, 30885, 0 };
            const std::uint32_t dim2855JoeKuoD6Init[]   =   { 1, 1, 7, 11, 27, 57, 93, 95, 243, 63, 1405, 2049, 7689, 15943, 18503, 0 };
            const std::uint32_t dim2856JoeKuoD6Init[]   =   { 1, 1, 7, 7, 5, 11, 47, 189, 467, 631, 1665, 2717, 4285, 2087, 1435, 0 };
            const std::uint32_t dim2857JoeKuoD6Init[]   =   { 1, 1, 3, 11, 7, 27, 127, 3, 231, 757, 435, 2545, 3537, 9127, 19915, 0 };
            const std::uint32_t dim2858JoeKuoD6Init[]   =   { 1, 1, 5, 13, 5, 29, 85, 127, 339, 875, 497, 1573, 6553, 11983, 18029, 0 };
            const std::uint32_t dim2859JoeKuoD6Init[]   =   { 1, 3, 1, 1, 21, 3, 15, 91, 231, 683, 1529, 2651, 4147, 13437, 23861, 0 };
            const std::uint32_t dim2860JoeKuoD6Init[]   =   { 1, 3, 1, 7, 27, 17, 19, 179, 243, 223, 1037, 1501, 5935, 2259, 25185, 0 };
            const std::uint32_t dim2861JoeKuoD6Init[]   =   { 1, 1, 3, 15, 11, 19, 127, 27, 483, 219, 583, 2555, 531, 3451, 17875, 0 };
            const std::uint32_t dim2862JoeKuoD6Init[]   =   { 1, 1, 1, 13, 31, 39, 89, 149, 363, 741, 1355, 4067, 3171, 6783, 1799, 0 };
            const std::uint32_t dim2863JoeKuoD6Init[]   =   { 1, 1, 3, 11, 25, 51, 45, 235, 379, 123, 1701, 725, 1991, 7471, 9833, 0 };
            const std::uint32_t dim2864JoeKuoD6Init[]   =   { 1, 1, 5, 13, 15, 47, 13, 201, 263, 57, 375, 2963, 7475, 15929, 13775, 0 };
            const std::uint32_t dim2865JoeKuoD6Init[]   =   { 1, 1, 3, 1, 29, 29, 11, 161, 345, 253, 97, 255, 7267, 2379, 3933, 0 };
            const std::uint32_t dim2866JoeKuoD6Init[]   =   { 1, 3, 1, 15, 3, 47, 11, 69, 347, 747, 795, 2401, 3367, 2383, 6125, 0 };
            const std::uint32_t dim2867JoeKuoD6Init[]   =   { 1, 1, 7, 3, 1, 49, 101, 47, 71, 761, 1503, 2619, 191, 8895, 873, 0 };
            const std::uint32_t dim2868JoeKuoD6Init[]   =   { 1, 3, 3, 5, 25, 41, 93, 85, 427, 109, 1675, 2409, 4317, 9233, 30283, 0 };
            const std::uint32_t dim2869JoeKuoD6Init[]   =   { 1, 1, 3, 9, 11, 3, 67, 159, 425, 751, 887, 1415, 403, 15977, 10739, 0 };
            const std::uint32_t dim2870JoeKuoD6Init[]   =   { 1, 1, 5, 13, 9, 1, 9, 103, 481, 601, 931, 1957, 5763, 7095, 27141, 0 };
            const std::uint32_t dim2871JoeKuoD6Init[]   =   { 1, 1, 3, 15, 29, 13, 43, 33, 297, 269, 1041, 1411, 3461, 12043, 10045, 0 };
            const std::uint32_t dim2872JoeKuoD6Init[]   =   { 1, 3, 5, 3, 3, 3, 5, 7, 185, 753, 133, 1561, 5595, 13777, 25795, 0 };
            const std::uint32_t dim2873JoeKuoD6Init[]   =   { 1, 3, 5, 5, 1, 19, 29, 145, 163, 149, 619, 2603, 7757, 10035, 10189, 0 };
            const std::uint32_t dim2874JoeKuoD6Init[]   =   { 1, 3, 7, 15, 27, 15, 111, 173, 135, 117, 157, 2601, 7919, 12111, 22795, 0 };
            const std::uint32_t dim2875JoeKuoD6Init[]   =   { 1, 3, 1, 1, 29, 27, 65, 31, 101, 715, 289, 3643, 2335, 6789, 23397, 0 };
            const std::uint32_t dim2876JoeKuoD6Init[]   =   { 1, 3, 1, 3, 11, 45, 71, 109, 321, 423, 1695, 169, 3075, 12423, 11391, 0 };
            const std::uint32_t dim2877JoeKuoD6Init[]   =   { 1, 1, 3, 9, 13, 51, 35, 121, 203, 279, 433, 2725, 7951, 2105, 27333, 0 };
            const std::uint32_t dim2878JoeKuoD6Init[]   =   { 1, 1, 1, 15, 23, 31, 25, 105, 501, 441, 1511, 3133, 2811, 10595, 21779, 0 };
            const std::uint32_t dim2879JoeKuoD6Init[]   =   { 1, 1, 5, 13, 7, 1, 97, 193, 121, 993, 1347, 1903, 1883, 6583, 24535, 0 };
            const std::uint32_t dim2880JoeKuoD6Init[]   =   { 1, 1, 7, 9, 7, 29, 17, 41, 101, 447, 1289, 387, 1891, 2723, 26091, 0 };
            const std::uint32_t dim2881JoeKuoD6Init[]   =   { 1, 1, 3, 3, 3, 53, 81, 81, 177, 165, 195, 3413, 8177, 3817, 8453, 0 };
            const std::uint32_t dim2882JoeKuoD6Init[]   =   { 1, 3, 7, 15, 15, 31, 23, 31, 337, 439, 1773, 63, 5351, 5491, 1767, 0 };
            const std::uint32_t dim2883JoeKuoD6Init[]   =   { 1, 3, 1, 11, 5, 15, 23, 75, 437, 553, 429, 2705, 3625, 13851, 19865, 0 };
            const std::uint32_t dim2884JoeKuoD6Init[]   =   { 1, 3, 3, 9, 13, 15, 33, 235, 215, 415, 1737, 1409, 2101, 14623, 14717, 0 };
            const std::uint32_t dim2885JoeKuoD6Init[]   =   { 1, 3, 7, 7, 13, 51, 101, 217, 175, 813, 1639, 4009, 1625, 4991, 17525, 0 };
            const std::uint32_t dim2886JoeKuoD6Init[]   =   { 1, 1, 5, 13, 23, 33, 29, 175, 39, 673, 557, 3239, 5129, 11049, 27227, 0 };
            const std::uint32_t dim2887JoeKuoD6Init[]   =   { 1, 3, 7, 13, 1, 37, 33, 139, 493, 891, 1883, 2525, 5741, 15795, 5875, 0 };
            const std::uint32_t dim2888JoeKuoD6Init[]   =   { 1, 3, 1, 15, 15, 27, 127, 111, 147, 363, 725, 3077, 4341, 9131, 24635, 0 };
            const std::uint32_t dim2889JoeKuoD6Init[]   =   { 1, 1, 7, 3, 17, 25, 59, 135, 177, 635, 73, 3455, 3083, 6009, 13033, 0 };
            const std::uint32_t dim2890JoeKuoD6Init[]   =   { 1, 1, 1, 5, 15, 53, 93, 161, 215, 459, 1087, 179, 2235, 8885, 15309, 0 };
            const std::uint32_t dim2891JoeKuoD6Init[]   =   { 1, 1, 7, 13, 7, 17, 75, 173, 449, 855, 103, 2739, 3421, 11811, 18805, 0 };
            const std::uint32_t dim2892JoeKuoD6Init[]   =   { 1, 1, 7, 9, 5, 11, 53, 75, 247, 249, 1201, 953, 2455, 4589, 6027, 0 };
            const std::uint32_t dim2893JoeKuoD6Init[]   =   { 1, 1, 5, 13, 27, 51, 119, 39, 137, 11, 1435, 3773, 3889, 6081, 11829, 0 };
            const std::uint32_t dim2894JoeKuoD6Init[]   =   { 1, 1, 5, 5, 5, 35, 1, 197, 501, 185, 1039, 1563, 6421, 14373, 25655, 0 };
            const std::uint32_t dim2895JoeKuoD6Init[]   =   { 1, 1, 3, 13, 31, 55, 115, 183, 483, 655, 1351, 3203, 725, 3299, 22579, 0 };
            const std::uint32_t dim2896JoeKuoD6Init[]   =   { 1, 3, 5, 11, 31, 31, 83, 59, 395, 21, 1881, 2821, 2251, 11781, 26265, 0 };
            const std::uint32_t dim2897JoeKuoD6Init[]   =   { 1, 3, 7, 13, 21, 19, 103, 21, 403, 443, 1951, 55, 985, 15983, 15087, 0 };
            const std::uint32_t dim2898JoeKuoD6Init[]   =   { 1, 1, 5, 15, 29, 11, 51, 53, 255, 183, 1475, 1491, 259, 387, 10303, 0 };
            const std::uint32_t dim2899JoeKuoD6Init[]   =   { 1, 3, 5, 7, 21, 37, 45, 39, 479, 637, 1325, 3753, 3319, 7403, 31759, 0 };
            const std::uint32_t dim2900JoeKuoD6Init[]   =   { 1, 1, 3, 5, 7, 43, 89, 53, 269, 187, 995, 141, 119, 8139, 29699, 0 };
            const std::uint32_t dim2901JoeKuoD6Init[]   =   { 1, 1, 1, 5, 1, 53, 3, 23, 379, 223, 1889, 4035, 1437, 12425, 9051, 0 };
            const std::uint32_t dim2902JoeKuoD6Init[]   =   { 1, 3, 1, 13, 3, 31, 61, 43, 249, 449, 901, 1921, 3495, 8599, 5263, 0 };
            const std::uint32_t dim2903JoeKuoD6Init[]   =   { 1, 1, 3, 5, 3, 25, 35, 133, 25, 597, 915, 3663, 5147, 11831, 24269, 0 };
            const std::uint32_t dim2904JoeKuoD6Init[]   =   { 1, 1, 1, 9, 21, 27, 93, 93, 217, 299, 1881, 3647, 4825, 7989, 24121, 0 };
            const std::uint32_t dim2905JoeKuoD6Init[]   =   { 1, 3, 1, 15, 5, 15, 49, 129, 315, 631, 2037, 1567, 4043, 15589, 30905, 0 };
            const std::uint32_t dim2906JoeKuoD6Init[]   =   { 1, 3, 3, 7, 25, 5, 123, 51, 47, 471, 1563, 3947, 7975, 3681, 9611, 0 };
            const std::uint32_t dim2907JoeKuoD6Init[]   =   { 1, 3, 7, 15, 1, 17, 73, 245, 465, 95, 95, 1159, 1319, 4675, 8841, 0 };
            const std::uint32_t dim2908JoeKuoD6Init[]   =   { 1, 1, 3, 15, 5, 51, 35, 71, 423, 651, 753, 173, 2131, 15799, 29601, 0 };
            const std::uint32_t dim2909JoeKuoD6Init[]   =   { 1, 1, 1, 1, 3, 53, 83, 187, 445, 827, 1549, 979, 5363, 1701, 2149, 0 };
            const std::uint32_t dim2910JoeKuoD6Init[]   =   { 1, 1, 7, 9, 3, 15, 65, 161, 37, 233, 771, 3749, 727, 6857, 17175, 0 };
            const std::uint32_t dim2911JoeKuoD6Init[]   =   { 1, 1, 7, 7, 27, 29, 107, 247, 249, 353, 773, 3677, 7273, 5419, 29397, 0 };
            const std::uint32_t dim2912JoeKuoD6Init[]   =   { 1, 3, 3, 7, 31, 49, 87, 159, 145, 497, 1715, 2115, 5035, 6431, 7245, 0 };
            const std::uint32_t dim2913JoeKuoD6Init[]   =   { 1, 3, 3, 5, 7, 31, 51, 117, 101, 617, 557, 2551, 6589, 13295, 31975, 0 };
            const std::uint32_t dim2914JoeKuoD6Init[]   =   { 1, 1, 3, 3, 15, 27, 125, 163, 169, 893, 1771, 25, 5787, 10267, 10297, 0 };
            const std::uint32_t dim2915JoeKuoD6Init[]   =   { 1, 1, 1, 5, 9, 47, 85, 65, 289, 783, 1105, 4035, 4111, 2589, 24575, 0 };
            const std::uint32_t dim2916JoeKuoD6Init[]   =   { 1, 3, 3, 13, 23, 33, 7, 49, 301, 531, 1713, 2755, 5543, 8153, 24099, 0 };
            const std::uint32_t dim2917JoeKuoD6Init[]   =   { 1, 1, 5, 9, 7, 39, 101, 67, 417, 923, 757, 1537, 5553, 12233, 20881, 0 };
            const std::uint32_t dim2918JoeKuoD6Init[]   =   { 1, 1, 5, 1, 19, 7, 25, 123, 125, 183, 573, 3317, 6867, 871, 17631, 0 };
            const std::uint32_t dim2919JoeKuoD6Init[]   =   { 1, 1, 3, 15, 19, 13, 117, 41, 129, 715, 1525, 2257, 2179, 10807, 23271, 0 };
            const std::uint32_t dim2920JoeKuoD6Init[]   =   { 1, 3, 1, 5, 25, 53, 19, 169, 289, 569, 1135, 1967, 7001, 15883, 15113, 0 };
            const std::uint32_t dim2921JoeKuoD6Init[]   =   { 1, 3, 7, 15, 7, 37, 127, 147, 415, 313, 1541, 1889, 3763, 16199, 12681, 0 };
            const std::uint32_t dim2922JoeKuoD6Init[]   =   { 1, 1, 3, 9, 1, 35, 95, 137, 237, 951, 899, 3177, 6073, 10655, 31687, 0 };
            const std::uint32_t dim2923JoeKuoD6Init[]   =   { 1, 1, 5, 5, 29, 57, 45, 253, 297, 529, 1553, 467, 8035, 15675, 21691, 0 };
            const std::uint32_t dim2924JoeKuoD6Init[]   =   { 1, 3, 7, 15, 25, 41, 59, 81, 87, 985, 1001, 2369, 661, 7551, 11829, 0 };
            const std::uint32_t dim2925JoeKuoD6Init[]   =   { 1, 1, 7, 9, 27, 21, 7, 233, 309, 67, 701, 2737, 4261, 2467, 15691, 0 };
            const std::uint32_t dim2926JoeKuoD6Init[]   =   { 1, 3, 7, 1, 19, 55, 47, 155, 333, 101, 517, 1991, 4619, 10435, 27241, 0 };
            const std::uint32_t dim2927JoeKuoD6Init[]   =   { 1, 1, 7, 3, 23, 35, 7, 125, 157, 537, 933, 3281, 4975, 8969, 27581, 0 };
            const std::uint32_t dim2928JoeKuoD6Init[]   =   { 1, 1, 3, 7, 19, 53, 81, 103, 461, 435, 777, 335, 5261, 12249, 9695, 0 };
            const std::uint32_t dim2929JoeKuoD6Init[]   =   { 1, 3, 1, 7, 19, 9, 75, 245, 355, 37, 1855, 1339, 3107, 7251, 16543, 0 };
            const std::uint32_t dim2930JoeKuoD6Init[]   =   { 1, 1, 1, 3, 5, 35, 39, 223, 113, 423, 1423, 713, 6113, 349, 24147, 0 };
            const std::uint32_t dim2931JoeKuoD6Init[]   =   { 1, 3, 1, 1, 15, 31, 11, 75, 499, 345, 1253, 2629, 2551, 7483, 25395, 0 };
            const std::uint32_t dim2932JoeKuoD6Init[]   =   { 1, 1, 3, 11, 25, 25, 3, 211, 185, 45, 1865, 1805, 3303, 11091, 529, 0 };
            const std::uint32_t dim2933JoeKuoD6Init[]   =   { 1, 3, 1, 1, 9, 21, 7, 165, 107, 641, 1083, 2805, 2099, 5855, 18477, 0 };
            const std::uint32_t dim2934JoeKuoD6Init[]   =   { 1, 3, 5, 3, 9, 21, 77, 103, 505, 277, 335, 797, 3869, 2957, 1979, 0 };
            const std::uint32_t dim2935JoeKuoD6Init[]   =   { 1, 3, 5, 15, 31, 23, 77, 247, 303, 891, 1261, 3233, 3495, 13111, 13185, 0 };
            const std::uint32_t dim2936JoeKuoD6Init[]   =   { 1, 3, 5, 11, 11, 35, 49, 229, 149, 931, 881, 775, 2949, 3141, 29157, 0 };
            const std::uint32_t dim2937JoeKuoD6Init[]   =   { 1, 1, 3, 5, 19, 57, 23, 95, 347, 221, 195, 3561, 1481, 2063, 3979, 0 };
            const std::uint32_t dim2938JoeKuoD6Init[]   =   { 1, 3, 5, 3, 13, 1, 23, 173, 431, 29, 421, 3235, 2751, 4447, 28283, 0 };
            const std::uint32_t dim2939JoeKuoD6Init[]   =   { 1, 1, 5, 13, 23, 3, 1, 9, 327, 855, 1251, 2997, 6129, 4223, 11555, 0 };
            const std::uint32_t dim2940JoeKuoD6Init[]   =   { 1, 3, 7, 13, 29, 21, 37, 229, 217, 353, 1239, 3955, 491, 12183, 14777, 0 };
            const std::uint32_t dim2941JoeKuoD6Init[]   =   { 1, 1, 5, 5, 1, 33, 103, 187, 183, 939, 1873, 2633, 6143, 15405, 17353, 0 };
            const std::uint32_t dim2942JoeKuoD6Init[]   =   { 1, 1, 1, 9, 21, 27, 71, 129, 499, 279, 1181, 4053, 2485, 1961, 30603, 0 };
            const std::uint32_t dim2943JoeKuoD6Init[]   =   { 1, 1, 3, 15, 21, 37, 45, 201, 221, 187, 727, 1241, 6171, 1383, 22277, 0 };
            const std::uint32_t dim2944JoeKuoD6Init[]   =   { 1, 3, 7, 5, 21, 17, 67, 177, 323, 601, 633, 865, 6131, 10329, 8689, 0 };
            const std::uint32_t dim2945JoeKuoD6Init[]   =   { 1, 3, 5, 9, 15, 45, 71, 43, 359, 651, 103, 403, 3249, 11769, 6567, 0 };
            const std::uint32_t dim2946JoeKuoD6Init[]   =   { 1, 3, 3, 13, 3, 23, 101, 145, 367, 999, 1489, 3673, 2959, 10855, 16029, 0 };
            const std::uint32_t dim2947JoeKuoD6Init[]   =   { 1, 3, 7, 3, 13, 43, 123, 87, 55, 1015, 141, 2917, 6567, 16025, 25555, 0 };
            const std::uint32_t dim2948JoeKuoD6Init[]   =   { 1, 3, 1, 3, 17, 7, 21, 161, 41, 889, 1315, 1897, 639, 15451, 3049, 0 };
            const std::uint32_t dim2949JoeKuoD6Init[]   =   { 1, 3, 5, 15, 27, 33, 55, 17, 81, 431, 325, 909, 3547, 10121, 17815, 0 };
            const std::uint32_t dim2950JoeKuoD6Init[]   =   { 1, 1, 3, 1, 15, 37, 43, 137, 203, 191, 1129, 1585, 435, 3177, 769, 0 };
            const std::uint32_t dim2951JoeKuoD6Init[]   =   { 1, 3, 7, 11, 21, 23, 125, 41, 17, 951, 465, 3691, 3465, 13247, 13779, 0 };
            const std::uint32_t dim2952JoeKuoD6Init[]   =   { 1, 3, 3, 1, 31, 23, 43, 101, 405, 739, 1061, 2955, 5643, 16137, 8763, 0 };
            const std::uint32_t dim2953JoeKuoD6Init[]   =   { 1, 1, 5, 1, 19, 33, 99, 109, 203, 65, 395, 2775, 1373, 2557, 5875, 0 };
            const std::uint32_t dim2954JoeKuoD6Init[]   =   { 1, 3, 3, 3, 27, 51, 79, 63, 331, 365, 1071, 1661, 4549, 8561, 1719, 0 };
            const std::uint32_t dim2955JoeKuoD6Init[]   =   { 1, 3, 3, 9, 3, 17, 53, 161, 141, 489, 1325, 1709, 1381, 5093, 171, 0 };
            const std::uint32_t dim2956JoeKuoD6Init[]   =   { 1, 1, 7, 15, 9, 3, 95, 237, 197, 949, 7, 1837, 729, 10111, 6637, 0 };
            const std::uint32_t dim2957JoeKuoD6Init[]   =   { 1, 1, 3, 3, 19, 31, 57, 173, 483, 861, 1001, 1919, 3389, 11777, 20693, 0 };
            const std::uint32_t dim2958JoeKuoD6Init[]   =   { 1, 3, 1, 9, 27, 13, 113, 177, 75, 925, 949, 119, 4759, 7775, 23033, 0 };
            const std::uint32_t dim2959JoeKuoD6Init[]   =   { 1, 1, 7, 15, 23, 15, 65, 61, 137, 653, 1843, 323, 379, 15157, 29885, 0 };
            const std::uint32_t dim2960JoeKuoD6Init[]   =   { 1, 3, 3, 7, 29, 3, 11, 205, 347, 745, 1477, 3929, 5749, 4735, 29435, 0 };
            const std::uint32_t dim2961JoeKuoD6Init[]   =   { 1, 3, 5, 9, 1, 11, 111, 15, 7, 69, 45, 3607, 1099, 9203, 21301, 0 };
            const std::uint32_t dim2962JoeKuoD6Init[]   =   { 1, 3, 3, 3, 23, 3, 83, 173, 73, 485, 681, 1867, 3839, 11823, 13339, 0 };
            const std::uint32_t dim2963JoeKuoD6Init[]   =   { 1, 1, 3, 11, 31, 43, 107, 127, 465, 389, 1595, 427, 1571, 5885, 29569, 0 };
            const std::uint32_t dim2964JoeKuoD6Init[]   =   { 1, 1, 7, 9, 27, 25, 117, 27, 287, 391, 279, 3247, 35, 12973, 5483, 0 };
            const std::uint32_t dim2965JoeKuoD6Init[]   =   { 1, 3, 7, 11, 19, 55, 45, 127, 245, 945, 305, 3907, 2455, 3163, 31, 0 };
            const std::uint32_t dim2966JoeKuoD6Init[]   =   { 1, 1, 7, 11, 15, 17, 65, 15, 37, 207, 1447, 3027, 2281, 6557, 16717, 0 };
            const std::uint32_t dim2967JoeKuoD6Init[]   =   { 1, 1, 1, 13, 5, 27, 33, 213, 29, 603, 1171, 3235, 2255, 2017, 30999, 0 };
            const std::uint32_t dim2968JoeKuoD6Init[]   =   { 1, 3, 1, 5, 11, 1, 73, 233, 69, 125, 397, 297, 3337, 6191, 31055, 0 };
            const std::uint32_t dim2969JoeKuoD6Init[]   =   { 1, 1, 1, 15, 1, 1, 65, 145, 201, 917, 1891, 2999, 4069, 10413, 15819, 0 };
            const std::uint32_t dim2970JoeKuoD6Init[]   =   { 1, 3, 5, 13, 15, 51, 115, 167, 311, 375, 1069, 2595, 3337, 753, 11903, 0 };
            const std::uint32_t dim2971JoeKuoD6Init[]   =   { 1, 1, 3, 1, 1, 23, 69, 125, 147, 915, 1945, 411, 979, 13863, 30443, 0 };
            const std::uint32_t dim2972JoeKuoD6Init[]   =   { 1, 3, 1, 11, 5, 1, 93, 23, 135, 93, 1689, 23, 3519, 4491, 24673, 0 };
            const std::uint32_t dim2973JoeKuoD6Init[]   =   { 1, 1, 7, 3, 11, 59, 93, 153, 487, 475, 1191, 1455, 5963, 8259, 18811, 0 };
            const std::uint32_t dim2974JoeKuoD6Init[]   =   { 1, 1, 3, 1, 13, 15, 55, 71, 433, 33, 491, 1835, 5695, 10509, 347, 0 };
            const std::uint32_t dim2975JoeKuoD6Init[]   =   { 1, 1, 1, 15, 19, 1, 23, 47, 235, 101, 1057, 901, 5477, 7079, 30885, 0 };
            const std::uint32_t dim2976JoeKuoD6Init[]   =   { 1, 1, 5, 13, 11, 43, 119, 77, 441, 121, 783, 827, 1757, 12751, 31593, 0 };
            const std::uint32_t dim2977JoeKuoD6Init[]   =   { 1, 3, 7, 11, 19, 17, 37, 225, 329, 231, 515, 1541, 7371, 6355, 10905, 0 };
            const std::uint32_t dim2978JoeKuoD6Init[]   =   { 1, 1, 5, 13, 7, 11, 35, 215, 345, 577, 147, 2803, 3291, 4631, 5329, 0 };
            const std::uint32_t dim2979JoeKuoD6Init[]   =   { 1, 1, 3, 9, 21, 55, 113, 251, 25, 221, 1445, 3385, 1589, 4109, 29897, 0 };
            const std::uint32_t dim2980JoeKuoD6Init[]   =   { 1, 1, 5, 7, 9, 45, 5, 33, 331, 285, 1101, 3131, 2713, 5653, 3823, 0 };
            const std::uint32_t dim2981JoeKuoD6Init[]   =   { 1, 3, 7, 7, 5, 39, 43, 167, 481, 629, 777, 1827, 4653, 403, 4781, 0 };
            const std::uint32_t dim2982JoeKuoD6Init[]   =   { 1, 3, 3, 7, 31, 33, 31, 159, 313, 673, 1425, 663, 5819, 1297, 26627, 0 };
            const std::uint32_t dim2983JoeKuoD6Init[]   =   { 1, 3, 3, 1, 19, 61, 117, 93, 373, 491, 1031, 757, 4185, 771, 7265, 0 };
            const std::uint32_t dim2984JoeKuoD6Init[]   =   { 1, 1, 7, 9, 3, 45, 65, 223, 437, 41, 1139, 2733, 5963, 2709, 25429, 0 };
            const std::uint32_t dim2985JoeKuoD6Init[]   =   { 1, 3, 5, 11, 21, 27, 31, 127, 255, 761, 1865, 1319, 6583, 9235, 10717, 0 };
            const std::uint32_t dim2986JoeKuoD6Init[]   =   { 1, 1, 1, 5, 21, 1, 63, 43, 413, 557, 567, 2893, 8017, 2307, 29525, 0 };
            const std::uint32_t dim2987JoeKuoD6Init[]   =   { 1, 1, 7, 3, 31, 1, 15, 235, 215, 395, 1971, 469, 5275, 431, 5349, 0 };
            const std::uint32_t dim2988JoeKuoD6Init[]   =   { 1, 1, 1, 13, 25, 59, 71, 245, 389, 279, 1293, 89, 6551, 10285, 14495, 0 };
            const std::uint32_t dim2989JoeKuoD6Init[]   =   { 1, 1, 5, 5, 9, 63, 17, 229, 425, 939, 877, 3689, 7229, 6707, 30771, 0 };
            const std::uint32_t dim2990JoeKuoD6Init[]   =   { 1, 3, 7, 7, 11, 29, 43, 41, 25, 237, 1585, 3735, 2617, 7541, 26243, 0 };
            const std::uint32_t dim2991JoeKuoD6Init[]   =   { 1, 1, 7, 9, 21, 5, 69, 231, 361, 39, 1695, 3043, 2973, 5487, 12857, 0 };
            const std::uint32_t dim2992JoeKuoD6Init[]   =   { 1, 1, 5, 3, 17, 63, 91, 217, 407, 133, 1373, 4021, 1737, 10043, 4561, 0 };
            const std::uint32_t dim2993JoeKuoD6Init[]   =   { 1, 3, 7, 9, 31, 13, 101, 231, 175, 457, 89, 2167, 2725, 8505, 375, 0 };
            const std::uint32_t dim2994JoeKuoD6Init[]   =   { 1, 1, 3, 15, 31, 11, 27, 211, 347, 291, 1881, 3091, 3307, 5117, 13341, 0 };
            const std::uint32_t dim2995JoeKuoD6Init[]   =   { 1, 3, 5, 5, 13, 25, 5, 197, 237, 135, 635, 1175, 5085, 14737, 10807, 0 };
            const std::uint32_t dim2996JoeKuoD6Init[]   =   { 1, 3, 3, 9, 7, 63, 107, 127, 147, 477, 1813, 2619, 8089, 2651, 26549, 0 };
            const std::uint32_t dim2997JoeKuoD6Init[]   =   { 1, 1, 5, 11, 15, 45, 27, 133, 45, 621, 707, 2679, 5929, 19, 9599, 0 };
            const std::uint32_t dim2998JoeKuoD6Init[]   =   { 1, 3, 7, 9, 21, 37, 41, 255, 69, 1009, 1999, 367, 6177, 10017, 3549, 0 };
            const std::uint32_t dim2999JoeKuoD6Init[]   =   { 1, 1, 1, 15, 19, 55, 73, 189, 423, 983, 1811, 2551, 4765, 12077, 18205, 0 };
            const std::uint32_t dim3000JoeKuoD6Init[]   =   { 1, 1, 5, 7, 17, 13, 25, 225, 463, 471, 631, 1811, 5797, 3235, 32253, 0 };
            const std::uint32_t dim3001JoeKuoD6Init[]   =   { 1, 3, 7, 1, 29, 7, 123, 187, 331, 735, 1757, 1115, 2077, 15725, 2183, 0 };
            const std::uint32_t dim3002JoeKuoD6Init[]   =   { 1, 3, 7, 9, 17, 61, 111, 93, 21, 1003, 1905, 3719, 2111, 11845, 6427, 0 };
            const std::uint32_t dim3003JoeKuoD6Init[]   =   { 1, 3, 7, 7, 17, 21, 51, 59, 115, 723, 2039, 2833, 5969, 5737, 18407, 0 };
            const std::uint32_t dim3004JoeKuoD6Init[]   =   { 1, 3, 3, 13, 9, 47, 95, 233, 13, 281, 1049, 619, 405, 16205, 20097, 0 };
            const std::uint32_t dim3005JoeKuoD6Init[]   =   { 1, 3, 7, 13, 9, 41, 11, 171, 453, 713, 587, 1669, 2489, 10277, 18599, 0 };
            const std::uint32_t dim3006JoeKuoD6Init[]   =   { 1, 3, 3, 13, 21, 41, 123, 173, 511, 399, 859, 1515, 5773, 12535, 26289, 0 };
            const std::uint32_t dim3007JoeKuoD6Init[]   =   { 1, 1, 7, 15, 11, 3, 113, 111, 73, 7, 1191, 2573, 7713, 465, 27615, 0 };
            const std::uint32_t dim3008JoeKuoD6Init[]   =   { 1, 1, 7, 15, 5, 5, 39, 11, 489, 13, 1041, 1639, 7879, 11899, 6899, 0 };
            const std::uint32_t dim3009JoeKuoD6Init[]   =   { 1, 1, 5, 9, 27, 31, 15, 237, 401, 795, 1675, 2361, 7333, 12507, 14627, 0 };
            const std::uint32_t dim3010JoeKuoD6Init[]   =   { 1, 3, 1, 7, 21, 53, 31, 81, 189, 683, 1283, 419, 7585, 9207, 15053, 0 };
            const std::uint32_t dim3011JoeKuoD6Init[]   =   { 1, 3, 5, 11, 21, 1, 49, 251, 403, 489, 1235, 429, 4855, 4081, 17575, 0 };
            const std::uint32_t dim3012JoeKuoD6Init[]   =   { 1, 3, 1, 15, 29, 33, 77, 53, 105, 731, 749, 2677, 3967, 7967, 18723, 0 };
            const std::uint32_t dim3013JoeKuoD6Init[]   =   { 1, 3, 3, 11, 9, 47, 11, 95, 137, 923, 599, 1585, 1969, 9625, 19171, 0 };
            const std::uint32_t dim3014JoeKuoD6Init[]   =   { 1, 1, 1, 5, 7, 7, 85, 49, 339, 883, 261, 2125, 3831, 9797, 16395, 0 };
            const std::uint32_t dim3015JoeKuoD6Init[]   =   { 1, 3, 3, 3, 5, 9, 33, 99, 75, 889, 101, 2099, 6635, 11511, 21573, 0 };
            const std::uint32_t dim3016JoeKuoD6Init[]   =   { 1, 1, 5, 11, 1, 11, 79, 49, 7, 131, 471, 1235, 3287, 14777, 12053, 0 };
            const std::uint32_t dim3017JoeKuoD6Init[]   =   { 1, 1, 5, 15, 9, 9, 83, 15, 21, 899, 1785, 2349, 3471, 6723, 1405, 0 };
            const std::uint32_t dim3018JoeKuoD6Init[]   =   { 1, 3, 5, 11, 1, 7, 121, 223, 509, 859, 1037, 491, 5529, 481, 17029, 0 };
            const std::uint32_t dim3019JoeKuoD6Init[]   =   { 1, 1, 7, 5, 17, 35, 91, 171, 113, 65, 423, 2371, 5105, 12827, 31087, 0 };
            const std::uint32_t dim3020JoeKuoD6Init[]   =   { 1, 1, 3, 3, 21, 47, 55, 11, 159, 51, 263, 2113, 661, 9147, 28929, 0 };
            const std::uint32_t dim3021JoeKuoD6Init[]   =   { 1, 1, 1, 9, 19, 7, 43, 223, 207, 787, 543, 2141, 4247, 7369, 29031, 0 };
            const std::uint32_t dim3022JoeKuoD6Init[]   =   { 1, 1, 7, 11, 11, 51, 121, 9, 211, 905, 687, 889, 1827, 13395, 3507, 0 };
            const std::uint32_t dim3023JoeKuoD6Init[]   =   { 1, 3, 1, 7, 15, 23, 5, 139, 469, 569, 33, 3477, 5391, 13665, 17011, 0 };
            const std::uint32_t dim3024JoeKuoD6Init[]   =   { 1, 1, 1, 15, 29, 29, 29, 201, 63, 1019, 97, 1671, 9, 4617, 19833, 0 };
            const std::uint32_t dim3025JoeKuoD6Init[]   =   { 1, 1, 5, 15, 25, 5, 67, 225, 189, 919, 1471, 1451, 5017, 16189, 31555, 0 };
            const std::uint32_t dim3026JoeKuoD6Init[]   =   { 1, 3, 5, 5, 15, 51, 89, 221, 149, 863, 43, 2381, 1767, 8037, 5319, 0 };
            const std::uint32_t dim3027JoeKuoD6Init[]   =   { 1, 3, 3, 1, 15, 17, 5, 77, 69, 27, 1883, 63, 5987, 1497, 3723, 0 };
            const std::uint32_t dim3028JoeKuoD6Init[]   =   { 1, 3, 7, 11, 7, 5, 113, 229, 123, 709, 1531, 641, 6655, 14923, 22947, 0 };
            const std::uint32_t dim3029JoeKuoD6Init[]   =   { 1, 3, 1, 13, 21, 15, 45, 175, 81, 499, 1113, 587, 7573, 11689, 15651, 0 };
            const std::uint32_t dim3030JoeKuoD6Init[]   =   { 1, 3, 1, 1, 29, 43, 101, 37, 131, 757, 465, 743, 2737, 8063, 23967, 0 };
            const std::uint32_t dim3031JoeKuoD6Init[]   =   { 1, 1, 7, 13, 9, 21, 39, 177, 51, 691, 2047, 1519, 6137, 5271, 8703, 0 };
            const std::uint32_t dim3032JoeKuoD6Init[]   =   { 1, 1, 3, 3, 5, 55, 63, 21, 3, 317, 461, 527, 2673, 16211, 6721, 0 };
            const std::uint32_t dim3033JoeKuoD6Init[]   =   { 1, 3, 5, 5, 5, 47, 7, 241, 387, 589, 323, 203, 7241, 14761, 13287, 0 };
            const std::uint32_t dim3034JoeKuoD6Init[]   =   { 1, 3, 5, 3, 23, 63, 55, 61, 231, 1023, 1315, 1181, 243, 7389, 25639, 0 };
            const std::uint32_t dim3035JoeKuoD6Init[]   =   { 1, 1, 7, 13, 31, 43, 41, 81, 127, 887, 1513, 4055, 1361, 2443, 6963, 0 };
            const std::uint32_t dim3036JoeKuoD6Init[]   =   { 1, 1, 1, 5, 7, 43, 43, 33, 323, 911, 1373, 3053, 6503, 513, 6457, 0 };
            const std::uint32_t dim3037JoeKuoD6Init[]   =   { 1, 1, 7, 11, 25, 61, 21, 149, 205, 349, 1433, 1587, 149, 7275, 5465, 0 };
            const std::uint32_t dim3038JoeKuoD6Init[]   =   { 1, 3, 5, 5, 11, 9, 31, 217, 119, 511, 209, 3325, 2023, 2877, 463, 0 };
            const std::uint32_t dim3039JoeKuoD6Init[]   =   { 1, 3, 5, 15, 21, 47, 89, 41, 347, 849, 1375, 3311, 807, 11443, 27643, 0 };
            const std::uint32_t dim3040JoeKuoD6Init[]   =   { 1, 1, 5, 7, 29, 43, 123, 191, 321, 373, 447, 2145, 1221, 2071, 12689, 0 };
            const std::uint32_t dim3041JoeKuoD6Init[]   =   { 1, 3, 5, 15, 1, 21, 43, 141, 461, 779, 1109, 2915, 909, 8585, 19859, 0 };
            const std::uint32_t dim3042JoeKuoD6Init[]   =   { 1, 3, 3, 11, 5, 17, 57, 13, 393, 661, 1761, 2455, 43, 8593, 20505, 0 };
            const std::uint32_t dim3043JoeKuoD6Init[]   =   { 1, 3, 5, 1, 31, 47, 65, 249, 77, 513, 851, 2381, 3447, 693, 7729, 0 };
            const std::uint32_t dim3044JoeKuoD6Init[]   =   { 1, 3, 5, 15, 31, 19, 83, 47, 369, 697, 1815, 819, 7573, 9245, 8013, 0 };
            const std::uint32_t dim3045JoeKuoD6Init[]   =   { 1, 3, 5, 5, 11, 25, 27, 151, 107, 339, 299, 3869, 3393, 5661, 2947, 0 };
            const std::uint32_t dim3046JoeKuoD6Init[]   =   { 1, 1, 3, 1, 1, 59, 85, 57, 175, 465, 239, 3115, 7157, 7035, 11463, 0 };
            const std::uint32_t dim3047JoeKuoD6Init[]   =   { 1, 1, 7, 5, 31, 41, 53, 149, 121, 743, 189, 159, 5289, 2945, 1179, 0 };
            const std::uint32_t dim3048JoeKuoD6Init[]   =   { 1, 3, 3, 15, 23, 51, 83, 25, 159, 163, 61, 713, 4529, 5253, 1603, 0 };
            const std::uint32_t dim3049JoeKuoD6Init[]   =   { 1, 3, 5, 11, 7, 29, 15, 177, 507, 695, 1305, 1863, 7525, 3063, 27433, 0 };
            const std::uint32_t dim3050JoeKuoD6Init[]   =   { 1, 1, 3, 11, 5, 41, 115, 227, 409, 951, 591, 4003, 7717, 4369, 15637, 0 };
            const std::uint32_t dim3051JoeKuoD6Init[]   =   { 1, 1, 7, 11, 23, 55, 71, 135, 51, 411, 2003, 2375, 6823, 1711, 4443, 0 };
            const std::uint32_t dim3052JoeKuoD6Init[]   =   { 1, 3, 1, 3, 31, 47, 31, 233, 243, 3, 313, 1649, 6955, 13679, 32327, 0 };
            const std::uint32_t dim3053JoeKuoD6Init[]   =   { 1, 1, 3, 11, 29, 9, 1, 79, 247, 677, 685, 3107, 5987, 9675, 29523, 0 };
            const std::uint32_t dim3054JoeKuoD6Init[]   =   { 1, 1, 1, 7, 25, 31, 39, 241, 483, 839, 1143, 437, 2317, 2437, 173, 0 };
            const std::uint32_t dim3055JoeKuoD6Init[]   =   { 1, 1, 5, 1, 17, 19, 83, 57, 39, 479, 715, 1911, 1091, 10937, 22145, 0 };
            const std::uint32_t dim3056JoeKuoD6Init[]   =   { 1, 1, 7, 1, 27, 45, 35, 55, 477, 719, 217, 3349, 7717, 6853, 9699, 0 };
            const std::uint32_t dim3057JoeKuoD6Init[]   =   { 1, 3, 1, 11, 9, 39, 25, 223, 303, 713, 151, 2611, 4629, 5855, 31729, 0 };
            const std::uint32_t dim3058JoeKuoD6Init[]   =   { 1, 1, 1, 11, 13, 35, 53, 39, 167, 779, 1673, 1221, 6281, 15113, 32027, 0 };
            const std::uint32_t dim3059JoeKuoD6Init[]   =   { 1, 1, 5, 9, 19, 63, 89, 113, 199, 107, 1015, 835, 2879, 9499, 25597, 0 };
            const std::uint32_t dim3060JoeKuoD6Init[]   =   { 1, 1, 7, 3, 19, 37, 15, 23, 449, 641, 1811, 3407, 6775, 6283, 31157, 0 };
            const std::uint32_t dim3061JoeKuoD6Init[]   =   { 1, 1, 3, 1, 19, 15, 31, 99, 511, 897, 1693, 2093, 955, 15897, 26693, 0 };
            const std::uint32_t dim3062JoeKuoD6Init[]   =   { 1, 1, 5, 1, 5, 15, 47, 19, 441, 541, 1621, 3877, 6407, 15991, 1931, 0 };
            const std::uint32_t dim3063JoeKuoD6Init[]   =   { 1, 3, 5, 9, 21, 61, 15, 77, 265, 351, 879, 3835, 6555, 2349, 23235, 0 };
            const std::uint32_t dim3064JoeKuoD6Init[]   =   { 1, 1, 5, 11, 25, 37, 29, 181, 341, 641, 1213, 1319, 6359, 6231, 32573, 0 };
            const std::uint32_t dim3065JoeKuoD6Init[]   =   { 1, 1, 1, 7, 1, 37, 87, 123, 33, 913, 111, 2613, 4895, 12595, 26633, 0 };
            const std::uint32_t dim3066JoeKuoD6Init[]   =   { 1, 3, 5, 3, 27, 11, 45, 89, 183, 241, 1355, 783, 3343, 239, 8643, 0 };
            const std::uint32_t dim3067JoeKuoD6Init[]   =   { 1, 3, 7, 7, 9, 35, 67, 187, 233, 577, 1445, 3063, 6039, 16233, 1453, 0 };
            const std::uint32_t dim3068JoeKuoD6Init[]   =   { 1, 1, 3, 13, 27, 11, 23, 15, 95, 63, 1931, 911, 8149, 6833, 3051, 0 };
            const std::uint32_t dim3069JoeKuoD6Init[]   =   { 1, 3, 3, 5, 29, 49, 125, 117, 47, 143, 423, 3215, 3605, 3677, 17155, 0 };
            const std::uint32_t dim3070JoeKuoD6Init[]   =   { 1, 3, 1, 1, 31, 1, 123, 195, 83, 893, 1947, 339, 2927, 7183, 15443, 0 };
            const std::uint32_t dim3071JoeKuoD6Init[]   =   { 1, 1, 7, 13, 31, 15, 91, 207, 39, 275, 439, 2617, 3093, 11041, 24997, 0 };
            const std::uint32_t dim3072JoeKuoD6Init[]   =   { 1, 1, 5, 3, 3, 41, 13, 67, 361, 497, 25, 3807, 3551, 9681, 21043, 0 };
            const std::uint32_t dim3073JoeKuoD6Init[]   =   { 1, 3, 3, 3, 11, 27, 103, 59, 427, 327, 1705, 29, 8127, 1641, 20847, 0 };
            const std::uint32_t dim3074JoeKuoD6Init[]   =   { 1, 3, 7, 5, 3, 37, 81, 137, 225, 101, 187, 3067, 2491, 12687, 16227, 0 };
            const std::uint32_t dim3075JoeKuoD6Init[]   =   { 1, 3, 5, 15, 15, 33, 69, 223, 225, 771, 1917, 2293, 2889, 12083, 23971, 0 };
            const std::uint32_t dim3076JoeKuoD6Init[]   =   { 1, 1, 3, 5, 11, 9, 121, 81, 203, 425, 1189, 2011, 3041, 3247, 739, 0 };
            const std::uint32_t dim3077JoeKuoD6Init[]   =   { 1, 3, 1, 1, 13, 9, 39, 169, 437, 571, 1481, 3355, 3895, 8975, 31031, 0 };
            const std::uint32_t dim3078JoeKuoD6Init[]   =   { 1, 3, 1, 11, 1, 43, 35, 35, 293, 11, 657, 1415, 5021, 14463, 17945, 0 };
            const std::uint32_t dim3079JoeKuoD6Init[]   =   { 1, 1, 5, 5, 13, 47, 91, 15, 159, 23, 971, 3575, 757, 13477, 31757, 0 };
            const std::uint32_t dim3080JoeKuoD6Init[]   =   { 1, 1, 7, 1, 5, 63, 69, 27, 71, 129, 123, 3767, 89, 7865, 1189, 0 };
            const std::uint32_t dim3081JoeKuoD6Init[]   =   { 1, 3, 3, 5, 23, 1, 83, 3, 487, 491, 217, 2583, 3889, 15009, 9227, 0 };
            const std::uint32_t dim3082JoeKuoD6Init[]   =   { 1, 3, 5, 15, 25, 1, 73, 107, 245, 191, 1449, 571, 1403, 6953, 17457, 0 };
            const std::uint32_t dim3083JoeKuoD6Init[]   =   { 1, 3, 3, 3, 27, 19, 25, 105, 207, 857, 1161, 3657, 2107, 7955, 517, 0 };
            const std::uint32_t dim3084JoeKuoD6Init[]   =   { 1, 3, 3, 9, 21, 29, 5, 103, 219, 35, 3, 1635, 4815, 15797, 29839, 0 };
            const std::uint32_t dim3085JoeKuoD6Init[]   =   { 1, 1, 7, 7, 3, 63, 75, 77, 13, 57, 603, 2333, 7761, 14397, 10875, 0 };
            const std::uint32_t dim3086JoeKuoD6Init[]   =   { 1, 3, 7, 13, 3, 11, 5, 255, 1, 947, 1695, 1927, 7447, 7407, 20797, 0 };
            const std::uint32_t dim3087JoeKuoD6Init[]   =   { 1, 1, 5, 1, 1, 21, 105, 73, 429, 973, 1801, 3943, 6161, 1309, 3359, 0 };
            const std::uint32_t dim3088JoeKuoD6Init[]   =   { 1, 1, 3, 15, 27, 9, 9, 129, 117, 545, 9, 1983, 6351, 10925, 27337, 0 };
            const std::uint32_t dim3089JoeKuoD6Init[]   =   { 1, 3, 3, 5, 5, 5, 13, 155, 503, 875, 1243, 2259, 3445, 11953, 6517, 0 };
            const std::uint32_t dim3090JoeKuoD6Init[]   =   { 1, 1, 7, 3, 29, 21, 121, 147, 413, 423, 1887, 2429, 2765, 16335, 3071, 0 };
            const std::uint32_t dim3091JoeKuoD6Init[]   =   { 1, 1, 7, 9, 5, 53, 41, 137, 463, 583, 1627, 1731, 6675, 3703, 8177, 0 };
            const std::uint32_t dim3092JoeKuoD6Init[]   =   { 1, 3, 5, 11, 31, 29, 67, 159, 425, 25, 1457, 139, 5019, 701, 7357, 0 };
            const std::uint32_t dim3093JoeKuoD6Init[]   =   { 1, 3, 1, 5, 25, 15, 123, 123, 245, 859, 249, 2175, 2137, 5765, 4873, 0 };
            const std::uint32_t dim3094JoeKuoD6Init[]   =   { 1, 1, 3, 5, 23, 1, 111, 111, 111, 469, 1473, 1777, 3579, 13503, 2569, 0 };
            const std::uint32_t dim3095JoeKuoD6Init[]   =   { 1, 1, 7, 3, 17, 23, 51, 23, 499, 135, 713, 3317, 807, 9589, 11349, 0 };
            const std::uint32_t dim3096JoeKuoD6Init[]   =   { 1, 1, 1, 15, 9, 51, 75, 159, 359, 773, 1521, 2913, 5901, 3047, 14649, 0 };
            const std::uint32_t dim3097JoeKuoD6Init[]   =   { 1, 1, 3, 1, 13, 61, 117, 195, 49, 267, 57, 1769, 3621, 9415, 29443, 0 };
            const std::uint32_t dim3098JoeKuoD6Init[]   =   { 1, 3, 7, 11, 3, 25, 33, 31, 315, 191, 359, 3399, 2481, 13831, 20205, 0 };
            const std::uint32_t dim3099JoeKuoD6Init[]   =   { 1, 3, 3, 5, 31, 43, 35, 125, 291, 51, 1469, 3857, 1707, 2641, 32137, 0 };
            const std::uint32_t dim3100JoeKuoD6Init[]   =   { 1, 3, 5, 1, 25, 11, 113, 137, 211, 159, 1667, 939, 6439, 5337, 32059, 0 };
            const std::uint32_t dim3101JoeKuoD6Init[]   =   { 1, 3, 3, 11, 31, 61, 99, 49, 383, 343, 395, 51, 6931, 16039, 5901, 0 };
            const std::uint32_t dim3102JoeKuoD6Init[]   =   { 1, 1, 3, 5, 9, 63, 63, 49, 405, 915, 1505, 2141, 6749, 7799, 17313, 0 };
            const std::uint32_t dim3103JoeKuoD6Init[]   =   { 1, 3, 7, 11, 15, 11, 49, 161, 155, 869, 121, 301, 6561, 4279, 15233, 0 };
            const std::uint32_t dim3104JoeKuoD6Init[]   =   { 1, 1, 5, 13, 19, 13, 103, 59, 503, 293, 701, 2527, 5327, 13927, 5025, 0 };
            const std::uint32_t dim3105JoeKuoD6Init[]   =   { 1, 1, 7, 1, 1, 37, 55, 155, 485, 399, 855, 2677, 5927, 9657, 2795, 0 };
            const std::uint32_t dim3106JoeKuoD6Init[]   =   { 1, 1, 1, 5, 19, 15, 121, 69, 385, 75, 1567, 2649, 5601, 12981, 15903, 0 };
            const std::uint32_t dim3107JoeKuoD6Init[]   =   { 1, 1, 1, 11, 19, 21, 45, 59, 505, 737, 15, 1383, 1177, 8375, 15557, 0 };
            const std::uint32_t dim3108JoeKuoD6Init[]   =   { 1, 1, 7, 13, 29, 19, 123, 127, 469, 773, 733, 3289, 8087, 5803, 27897, 0 };
            const std::uint32_t dim3109JoeKuoD6Init[]   =   { 1, 3, 3, 11, 19, 55, 101, 67, 485, 939, 607, 1521, 6161, 12235, 16499, 0 };
            const std::uint32_t dim3110JoeKuoD6Init[]   =   { 1, 3, 5, 13, 29, 31, 31, 9, 453, 151, 1055, 3873, 405, 12877, 29829, 0 };
            const std::uint32_t dim3111JoeKuoD6Init[]   =   { 1, 3, 5, 1, 17, 1, 17, 131, 107, 1003, 1749, 1849, 6207, 2153, 21275, 0 };
            const std::uint32_t dim3112JoeKuoD6Init[]   =   { 1, 3, 7, 15, 7, 25, 51, 143, 51, 517, 1841, 1771, 5389, 4633, 11123, 0 };
            const std::uint32_t dim3113JoeKuoD6Init[]   =   { 1, 3, 7, 11, 23, 7, 89, 95, 403, 361, 835, 585, 2783, 8091, 5141, 0 };
            const std::uint32_t dim3114JoeKuoD6Init[]   =   { 1, 3, 1, 9, 1, 53, 115, 11, 493, 587, 305, 3605, 1711, 4169, 20013, 0 };
            const std::uint32_t dim3115JoeKuoD6Init[]   =   { 1, 3, 7, 3, 17, 59, 55, 251, 49, 759, 1227, 3685, 7765, 1445, 20385, 0 };
            const std::uint32_t dim3116JoeKuoD6Init[]   =   { 1, 1, 5, 7, 29, 55, 19, 157, 129, 927, 893, 1235, 1955, 8153, 2865, 0 };
            const std::uint32_t dim3117JoeKuoD6Init[]   =   { 1, 3, 1, 15, 21, 35, 81, 53, 175, 939, 1635, 3597, 747, 14011, 12867, 0 };
            const std::uint32_t dim3118JoeKuoD6Init[]   =   { 1, 3, 7, 1, 27, 61, 91, 73, 405, 677, 603, 2715, 7099, 941, 24523, 0 };
            const std::uint32_t dim3119JoeKuoD6Init[]   =   { 1, 3, 5, 9, 13, 45, 35, 167, 57, 483, 735, 2777, 7847, 6257, 13109, 0 };
            const std::uint32_t dim3120JoeKuoD6Init[]   =   { 1, 3, 5, 7, 1, 3, 97, 13, 159, 533, 1791, 1061, 981, 10795, 26165, 0 };
            const std::uint32_t dim3121JoeKuoD6Init[]   =   { 1, 1, 5, 13, 27, 5, 125, 25, 251, 221, 1909, 197, 6987, 11537, 15287, 0 };
            const std::uint32_t dim3122JoeKuoD6Init[]   =   { 1, 3, 5, 5, 27, 15, 1, 131, 375, 923, 81, 3153, 6071, 2515, 23729, 0 };
            const std::uint32_t dim3123JoeKuoD6Init[]   =   { 1, 3, 3, 9, 9, 23, 71, 13, 465, 261, 937, 1549, 5993, 11325, 15065, 0 };
            const std::uint32_t dim3124JoeKuoD6Init[]   =   { 1, 3, 1, 3, 7, 63, 17, 129, 435, 23, 215, 2251, 1561, 9703, 26483, 0 };
            const std::uint32_t dim3125JoeKuoD6Init[]   =   { 1, 1, 3, 1, 5, 53, 77, 109, 9, 605, 371, 2081, 6023, 7145, 15837, 0 };
            const std::uint32_t dim3126JoeKuoD6Init[]   =   { 1, 3, 7, 11, 27, 39, 115, 47, 259, 337, 1857, 3465, 1549, 7747, 8525, 0 };
            const std::uint32_t dim3127JoeKuoD6Init[]   =   { 1, 3, 7, 7, 29, 29, 75, 77, 29, 661, 899, 3137, 2661, 15271, 28093, 0 };
            const std::uint32_t dim3128JoeKuoD6Init[]   =   { 1, 1, 1, 3, 3, 3, 11, 219, 39, 757, 1465, 249, 7445, 7013, 15187, 0 };
            const std::uint32_t dim3129JoeKuoD6Init[]   =   { 1, 3, 7, 15, 15, 1, 39, 245, 427, 1003, 1493, 1913, 6435, 14787, 13481, 0 };
            const std::uint32_t dim3130JoeKuoD6Init[]   =   { 1, 1, 7, 3, 3, 37, 5, 97, 343, 833, 1379, 1551, 5403, 1843, 5877, 0 };
            const std::uint32_t dim3131JoeKuoD6Init[]   =   { 1, 3, 1, 1, 3, 17, 17, 163, 339, 691, 1707, 1845, 5941, 4259, 24531, 0 };
            const std::uint32_t dim3132JoeKuoD6Init[]   =   { 1, 1, 1, 1, 27, 21, 85, 221, 71, 949, 1753, 391, 6349, 15901, 20811, 0 };
            const std::uint32_t dim3133JoeKuoD6Init[]   =   { 1, 1, 1, 5, 31, 19, 45, 99, 469, 783, 1747, 3807, 5889, 9485, 13715, 0 };
            const std::uint32_t dim3134JoeKuoD6Init[]   =   { 1, 3, 1, 9, 23, 21, 39, 25, 421, 713, 461, 2857, 5023, 5341, 6409, 0 };
            const std::uint32_t dim3135JoeKuoD6Init[]   =   { 1, 3, 7, 5, 25, 19, 59, 147, 387, 857, 375, 3103, 1261, 13697, 25675, 0 };
            const std::uint32_t dim3136JoeKuoD6Init[]   =   { 1, 3, 5, 5, 31, 21, 49, 251, 463, 441, 473, 3487, 3915, 11151, 17721, 0 };
            const std::uint32_t dim3137JoeKuoD6Init[]   =   { 1, 1, 3, 9, 15, 47, 81, 219, 143, 141, 81, 1705, 5847, 3437, 30521, 0 };
            const std::uint32_t dim3138JoeKuoD6Init[]   =   { 1, 1, 7, 3, 25, 19, 97, 41, 77, 105, 1337, 695, 7589, 8587, 7509, 0 };
            const std::uint32_t dim3139JoeKuoD6Init[]   =   { 1, 1, 5, 13, 3, 11, 61, 19, 139, 667, 963, 1567, 5715, 7079, 15967, 0 };
            const std::uint32_t dim3140JoeKuoD6Init[]   =   { 1, 1, 5, 5, 5, 29, 67, 57, 477, 173, 1163, 727, 823, 15635, 17705, 0 };
            const std::uint32_t dim3141JoeKuoD6Init[]   =   { 1, 3, 7, 11, 13, 39, 57, 193, 73, 617, 535, 1623, 4581, 4451, 2589, 0 };
            const std::uint32_t dim3142JoeKuoD6Init[]   =   { 1, 1, 5, 5, 9, 27, 75, 127, 325, 413, 1669, 1749, 8045, 16199, 12237, 0 };
            const std::uint32_t dim3143JoeKuoD6Init[]   =   { 1, 1, 3, 1, 17, 23, 27, 189, 319, 953, 347, 909, 4401, 12791, 25077, 0 };
            const std::uint32_t dim3144JoeKuoD6Init[]   =   { 1, 1, 3, 3, 17, 51, 37, 79, 301, 607, 885, 1169, 3275, 3327, 20013, 0 };
            const std::uint32_t dim3145JoeKuoD6Init[]   =   { 1, 3, 5, 3, 21, 9, 99, 213, 387, 889, 575, 3591, 5377, 2981, 23989, 0 };
            const std::uint32_t dim3146JoeKuoD6Init[]   =   { 1, 3, 3, 13, 11, 7, 23, 255, 279, 853, 453, 2377, 8123, 15393, 9669, 0 };
            const std::uint32_t dim3147JoeKuoD6Init[]   =   { 1, 3, 1, 7, 11, 9, 109, 35, 405, 449, 1967, 2943, 3485, 5031, 14273, 0 };
            const std::uint32_t dim3148JoeKuoD6Init[]   =   { 1, 3, 3, 1, 25, 27, 43, 115, 435, 675, 1937, 1477, 4831, 9417, 7017, 0 };
            const std::uint32_t dim3149JoeKuoD6Init[]   =   { 1, 1, 7, 13, 19, 45, 83, 241, 487, 215, 1453, 209, 4061, 1765, 15623, 0 };
            const std::uint32_t dim3150JoeKuoD6Init[]   =   { 1, 1, 7, 7, 21, 31, 95, 9, 287, 1005, 1933, 3405, 6913, 7733, 18975, 0 };
            const std::uint32_t dim3151JoeKuoD6Init[]   =   { 1, 1, 1, 11, 13, 11, 25, 39, 283, 57, 255, 2809, 5767, 6127, 6705, 0 };
            const std::uint32_t dim3152JoeKuoD6Init[]   =   { 1, 3, 1, 11, 1, 51, 73, 181, 261, 215, 385, 2777, 5169, 12431, 23563, 0 };
            const std::uint32_t dim3153JoeKuoD6Init[]   =   { 1, 3, 3, 9, 9, 39, 123, 197, 501, 679, 109, 3369, 4817, 8855, 7997, 0 };
            const std::uint32_t dim3154JoeKuoD6Init[]   =   { 1, 1, 5, 1, 29, 61, 15, 183, 453, 999, 1211, 3217, 8035, 5153, 19975, 0 };
            const std::uint32_t dim3155JoeKuoD6Init[]   =   { 1, 3, 7, 11, 11, 21, 51, 45, 379, 793, 289, 309, 1229, 7159, 581, 0 };
            const std::uint32_t dim3156JoeKuoD6Init[]   =   { 1, 1, 3, 9, 17, 11, 75, 67, 289, 191, 1083, 2949, 6063, 6611, 21595, 0 };
            const std::uint32_t dim3157JoeKuoD6Init[]   =   { 1, 3, 7, 3, 27, 45, 59, 193, 485, 277, 27, 1219, 2389, 15875, 6273, 0 };
            const std::uint32_t dim3158JoeKuoD6Init[]   =   { 1, 1, 5, 3, 31, 29, 65, 197, 115, 163, 9, 783, 5573, 2833, 12603, 0 };
            const std::uint32_t dim3159JoeKuoD6Init[]   =   { 1, 1, 3, 7, 5, 53, 115, 181, 175, 749, 1335, 1151, 2131, 12467, 15811, 0 };
            const std::uint32_t dim3160JoeKuoD6Init[]   =   { 1, 1, 1, 9, 27, 39, 11, 1, 443, 677, 777, 1857, 7459, 3177, 3875, 0 };
            const std::uint32_t dim3161JoeKuoD6Init[]   =   { 1, 1, 7, 7, 17, 3, 23, 161, 105, 603, 1991, 3845, 465, 11467, 2077, 0 };
            const std::uint32_t dim3162JoeKuoD6Init[]   =   { 1, 1, 3, 13, 5, 23, 39, 35, 399, 795, 265, 207, 1823, 15069, 31839, 0 };
            const std::uint32_t dim3163JoeKuoD6Init[]   =   { 1, 1, 1, 1, 29, 61, 89, 193, 41, 99, 315, 1021, 6109, 12507, 19973, 0 };
            const std::uint32_t dim3164JoeKuoD6Init[]   =   { 1, 1, 5, 3, 13, 57, 119, 251, 215, 695, 1521, 4081, 2481, 657, 855, 0 };
            const std::uint32_t dim3165JoeKuoD6Init[]   =   { 1, 1, 7, 3, 25, 5, 3, 133, 111, 385, 773, 1027, 4327, 3031, 3537, 0 };
            const std::uint32_t dim3166JoeKuoD6Init[]   =   { 1, 3, 7, 5, 5, 27, 43, 117, 479, 83, 1421, 2791, 6551, 6231, 10353, 0 };
            const std::uint32_t dim3167JoeKuoD6Init[]   =   { 1, 1, 1, 13, 3, 29, 35, 71, 85, 821, 1671, 3057, 797, 13683, 7025, 0 };
            const std::uint32_t dim3168JoeKuoD6Init[]   =   { 1, 3, 7, 1, 1, 47, 117, 233, 141, 993, 1381, 2551, 1031, 11765, 18429, 0 };
            const std::uint32_t dim3169JoeKuoD6Init[]   =   { 1, 3, 1, 3, 13, 3, 77, 29, 35, 807, 1109, 695, 5605, 5477, 449, 0 };
            const std::uint32_t dim3170JoeKuoD6Init[]   =   { 1, 1, 1, 15, 21, 37, 117, 105, 273, 311, 1287, 1415, 1221, 1847, 19487, 0 };
            const std::uint32_t dim3171JoeKuoD6Init[]   =   { 1, 3, 1, 11, 21, 61, 107, 225, 335, 501, 1995, 2399, 5475, 12613, 18877, 0 };
            const std::uint32_t dim3172JoeKuoD6Init[]   =   { 1, 3, 3, 1, 31, 41, 27, 205, 103, 837, 639, 2007, 2759, 12471, 1457, 0 };
            const std::uint32_t dim3173JoeKuoD6Init[]   =   { 1, 1, 7, 13, 29, 39, 71, 245, 105, 235, 1277, 1515, 6129, 15947, 26653, 0 };
            const std::uint32_t dim3174JoeKuoD6Init[]   =   { 1, 1, 7, 5, 7, 13, 87, 251, 315, 1017, 587, 2917, 5911, 2919, 29715, 0 };
            const std::uint32_t dim3175JoeKuoD6Init[]   =   { 1, 1, 1, 3, 7, 19, 81, 243, 177, 917, 2023, 2365, 7465, 4901, 29841, 0 };
            const std::uint32_t dim3176JoeKuoD6Init[]   =   { 1, 3, 5, 15, 1, 31, 15, 147, 285, 1003, 1757, 47, 6925, 1197, 19633, 0 };
            const std::uint32_t dim3177JoeKuoD6Init[]   =   { 1, 1, 5, 7, 27, 25, 47, 209, 85, 403, 1399, 2331, 3663, 595, 13407, 0 };
            const std::uint32_t dim3178JoeKuoD6Init[]   =   { 1, 3, 5, 9, 7, 25, 7, 139, 389, 817, 1153, 1421, 5735, 9577, 10269, 0 };
            const std::uint32_t dim3179JoeKuoD6Init[]   =   { 1, 1, 1, 9, 5, 61, 49, 117, 389, 541, 433, 1405, 2575, 223, 7265, 0 };
            const std::uint32_t dim3180JoeKuoD6Init[]   =   { 1, 1, 5, 7, 15, 1, 81, 207, 435, 843, 835, 3797, 7637, 5333, 31115, 0 };
            const std::uint32_t dim3181JoeKuoD6Init[]   =   { 1, 3, 7, 11, 13, 3, 47, 249, 301, 715, 2015, 3049, 8155, 10989, 26051, 0 };
            const std::uint32_t dim3182JoeKuoD6Init[]   =   { 1, 1, 7, 7, 3, 33, 119, 113, 381, 575, 367, 41, 3317, 11727, 4351, 0 };
            const std::uint32_t dim3183JoeKuoD6Init[]   =   { 1, 3, 3, 13, 9, 3, 51, 37, 173, 137, 533, 1827, 631, 10047, 6267, 0 };
            const std::uint32_t dim3184JoeKuoD6Init[]   =   { 1, 3, 3, 11, 17, 39, 61, 245, 13, 139, 1281, 1319, 1233, 13629, 32269, 0 };
            const std::uint32_t dim3185JoeKuoD6Init[]   =   { 1, 1, 1, 7, 15, 17, 91, 109, 163, 609, 11, 3251, 7653, 14035, 31755, 0 };
            const std::uint32_t dim3186JoeKuoD6Init[]   =   { 1, 3, 3, 15, 13, 21, 55, 231, 385, 133, 1833, 2637, 6935, 14303, 26745, 0 };
            const std::uint32_t dim3187JoeKuoD6Init[]   =   { 1, 1, 1, 7, 17, 41, 125, 141, 89, 823, 1411, 3637, 6211, 13323, 6111, 0 };
            const std::uint32_t dim3188JoeKuoD6Init[]   =   { 1, 1, 1, 11, 1, 21, 9, 43, 97, 685, 1223, 1491, 121, 1793, 2397, 0 };
            const std::uint32_t dim3189JoeKuoD6Init[]   =   { 1, 3, 5, 5, 17, 17, 5, 223, 129, 865, 1839, 1137, 6391, 4377, 9233, 0 };
            const std::uint32_t dim3190JoeKuoD6Init[]   =   { 1, 3, 7, 15, 21, 55, 5, 77, 341, 637, 1853, 1435, 1195, 9283, 21257, 0 };
            const std::uint32_t dim3191JoeKuoD6Init[]   =   { 1, 3, 5, 1, 9, 49, 43, 211, 127, 655, 1397, 1235, 5279, 2351, 24229, 0 };
            const std::uint32_t dim3192JoeKuoD6Init[]   =   { 1, 3, 5, 3, 25, 29, 13, 229, 25, 675, 837, 2753, 2125, 9863, 11293, 0 };
            const std::uint32_t dim3193JoeKuoD6Init[]   =   { 1, 3, 5, 7, 23, 43, 127, 1, 163, 237, 337, 3019, 7747, 16227, 2881, 0 };
            const std::uint32_t dim3194JoeKuoD6Init[]   =   { 1, 3, 5, 5, 25, 9, 43, 171, 421, 521, 1885, 337, 7873, 6347, 13181, 0 };
            const std::uint32_t dim3195JoeKuoD6Init[]   =   { 1, 3, 5, 5, 7, 47, 107, 173, 163, 191, 625, 3389, 2833, 7945, 24787, 0 };
            const std::uint32_t dim3196JoeKuoD6Init[]   =   { 1, 1, 7, 3, 27, 57, 27, 209, 253, 815, 301, 1633, 3945, 5051, 28851, 0 };
            const std::uint32_t dim3197JoeKuoD6Init[]   =   { 1, 3, 7, 9, 9, 51, 103, 213, 437, 189, 1857, 1331, 5551, 10641, 27405, 0 };
            const std::uint32_t dim3198JoeKuoD6Init[]   =   { 1, 1, 5, 5, 15, 1, 25, 105, 117, 347, 161, 3369, 3589, 12903, 23559, 0 };
            const std::uint32_t dim3199JoeKuoD6Init[]   =   { 1, 1, 1, 5, 3, 61, 93, 51, 81, 281, 1383, 745, 4137, 2005, 3635, 0 };
            const std::uint32_t dim3200JoeKuoD6Init[]   =   { 1, 3, 7, 5, 13, 57, 111, 211, 303, 477, 359, 4019, 6779, 5129, 22035, 0 };
            const std::uint32_t dim3201JoeKuoD6Init[]   =   { 1, 1, 1, 7, 17, 29, 113, 113, 201, 531, 749, 739, 2879, 3315, 18733, 0 };
            const std::uint32_t dim3202JoeKuoD6Init[]   =   { 1, 3, 7, 13, 21, 55, 21, 183, 359, 75, 377, 2211, 4281, 14317, 28307, 0 };
            const std::uint32_t dim3203JoeKuoD6Init[]   =   { 1, 3, 7, 1, 21, 1, 49, 213, 317, 75, 113, 1741, 7963, 12785, 11571, 0 };
            const std::uint32_t dim3204JoeKuoD6Init[]   =   { 1, 3, 7, 9, 11, 31, 29, 101, 261, 141, 715, 2727, 8187, 2075, 32433, 0 };
            const std::uint32_t dim3205JoeKuoD6Init[]   =   { 1, 3, 7, 3, 23, 9, 17, 143, 385, 211, 593, 241, 6567, 10777, 6677, 0 };
            const std::uint32_t dim3206JoeKuoD6Init[]   =   { 1, 1, 3, 15, 3, 17, 117, 99, 91, 793, 989, 2421, 5643, 16103, 9759, 0 };
            const std::uint32_t dim3207JoeKuoD6Init[]   =   { 1, 3, 7, 11, 23, 43, 107, 35, 421, 431, 743, 853, 7939, 12169, 4199, 0 };
            const std::uint32_t dim3208JoeKuoD6Init[]   =   { 1, 1, 1, 11, 21, 53, 17, 203, 123, 395, 59, 929, 255, 7585, 10945, 0 };
            const std::uint32_t dim3209JoeKuoD6Init[]   =   { 1, 3, 3, 15, 17, 57, 57, 133, 67, 71, 1685, 903, 4079, 15423, 26495, 0 };
            const std::uint32_t dim3210JoeKuoD6Init[]   =   { 1, 1, 1, 15, 3, 47, 95, 39, 405, 407, 1557, 3001, 6225, 15187, 5663, 0 };
            const std::uint32_t dim3211JoeKuoD6Init[]   =   { 1, 3, 5, 5, 13, 47, 33, 61, 375, 1023, 1981, 2773, 2375, 11321, 17731, 0 };
            const std::uint32_t dim3212JoeKuoD6Init[]   =   { 1, 3, 5, 9, 17, 59, 117, 95, 493, 149, 1269, 2865, 369, 2109, 24601, 0 };
            const std::uint32_t dim3213JoeKuoD6Init[]   =   { 1, 3, 5, 13, 17, 63, 67, 247, 95, 721, 67, 305, 6179, 15399, 32559, 0 };
            const std::uint32_t dim3214JoeKuoD6Init[]   =   { 1, 1, 5, 1, 3, 21, 41, 15, 453, 475, 2017, 3193, 5903, 897, 4237, 0 };
            const std::uint32_t dim3215JoeKuoD6Init[]   =   { 1, 1, 5, 3, 15, 41, 1, 141, 441, 575, 155, 3791, 7711, 11231, 24611, 0 };
            const std::uint32_t dim3216JoeKuoD6Init[]   =   { 1, 3, 7, 1, 17, 53, 27, 169, 31, 437, 963, 1793, 7777, 1917, 29311, 0 };
            const std::uint32_t dim3217JoeKuoD6Init[]   =   { 1, 3, 3, 13, 9, 27, 77, 87, 329, 885, 749, 1713, 6013, 6921, 629, 0 };
            const std::uint32_t dim3218JoeKuoD6Init[]   =   { 1, 3, 5, 13, 3, 7, 53, 27, 353, 267, 925, 2141, 439, 15175, 30851, 0 };
            const std::uint32_t dim3219JoeKuoD6Init[]   =   { 1, 3, 3, 13, 17, 57, 35, 101, 265, 901, 1825, 2159, 6149, 5967, 24023, 0 };
            const std::uint32_t dim3220JoeKuoD6Init[]   =   { 1, 1, 5, 11, 13, 51, 99, 111, 193, 415, 1541, 2929, 5045, 3147, 12587, 0 };
            const std::uint32_t dim3221JoeKuoD6Init[]   =   { 1, 3, 7, 11, 15, 9, 33, 17, 511, 815, 299, 1077, 6171, 10451, 15039, 0 };
            const std::uint32_t dim3222JoeKuoD6Init[]   =   { 1, 1, 1, 15, 25, 63, 51, 137, 449, 951, 1051, 1101, 4725, 2463, 7355, 0 };
            const std::uint32_t dim3223JoeKuoD6Init[]   =   { 1, 1, 1, 7, 27, 63, 29, 179, 317, 521, 1459, 827, 6599, 13459, 15439, 0 };
            const std::uint32_t dim3224JoeKuoD6Init[]   =   { 1, 3, 3, 15, 17, 31, 37, 191, 229, 245, 181, 941, 5761, 1849, 31599, 0 };
            const std::uint32_t dim3225JoeKuoD6Init[]   =   { 1, 1, 1, 9, 27, 45, 67, 239, 481, 615, 1667, 3751, 8141, 10013, 2125, 0 };
            const std::uint32_t dim3226JoeKuoD6Init[]   =   { 1, 1, 1, 1, 13, 51, 117, 135, 73, 151, 1291, 2541, 1411, 3767, 26949, 0 };
            const std::uint32_t dim3227JoeKuoD6Init[]   =   { 1, 3, 1, 9, 7, 11, 21, 187, 243, 857, 1951, 865, 7273, 2041, 8155, 0 };
            const std::uint32_t dim3228JoeKuoD6Init[]   =   { 1, 1, 3, 3, 19, 33, 89, 115, 455, 137, 707, 1867, 4221, 2433, 9119, 0 };
            const std::uint32_t dim3229JoeKuoD6Init[]   =   { 1, 1, 3, 11, 5, 3, 121, 1, 71, 951, 603, 3873, 723, 3285, 19289, 0 };
            const std::uint32_t dim3230JoeKuoD6Init[]   =   { 1, 3, 7, 15, 21, 1, 117, 17, 455, 519, 731, 3003, 5741, 9557, 29163, 0 };
            const std::uint32_t dim3231JoeKuoD6Init[]   =   { 1, 1, 3, 13, 25, 5, 43, 147, 209, 895, 255, 1231, 241, 487, 15593, 0 };
            const std::uint32_t dim3232JoeKuoD6Init[]   =   { 1, 1, 3, 13, 7, 1, 89, 187, 217, 927, 2029, 3521, 2777, 8103, 22819, 0 };
            const std::uint32_t dim3233JoeKuoD6Init[]   =   { 1, 1, 7, 11, 7, 33, 3, 73, 5, 489, 227, 2259, 7031, 6425, 26135, 0 };
            const std::uint32_t dim3234JoeKuoD6Init[]   =   { 1, 3, 3, 7, 31, 19, 97, 201, 455, 819, 945, 2771, 8083, 8711, 2835, 0 };
            const std::uint32_t dim3235JoeKuoD6Init[]   =   { 1, 1, 1, 5, 15, 45, 43, 157, 245, 967, 877, 2289, 4499, 9891, 18827, 0 };
            const std::uint32_t dim3236JoeKuoD6Init[]   =   { 1, 3, 1, 7, 21, 59, 123, 63, 231, 485, 1781, 1211, 4597, 5269, 1607, 0 };
            const std::uint32_t dim3237JoeKuoD6Init[]   =   { 1, 1, 1, 13, 23, 39, 105, 55, 249, 991, 1625, 3089, 3825, 4275, 29139, 0 };
            const std::uint32_t dim3238JoeKuoD6Init[]   =   { 1, 3, 3, 1, 29, 29, 55, 169, 13, 895, 1355, 1101, 6063, 12935, 23215, 0 };
            const std::uint32_t dim3239JoeKuoD6Init[]   =   { 1, 1, 5, 5, 31, 49, 99, 137, 209, 1017, 1179, 3931, 637, 14131, 19285, 0 };
            const std::uint32_t dim3240JoeKuoD6Init[]   =   { 1, 1, 1, 1, 3, 11, 119, 11, 215, 337, 243, 3883, 3807, 7335, 11901, 0 };
            const std::uint32_t dim3241JoeKuoD6Init[]   =   { 1, 3, 7, 3, 7, 27, 71, 225, 219, 367, 1213, 2739, 1185, 10175, 21313, 0 };
            const std::uint32_t dim3242JoeKuoD6Init[]   =   { 1, 3, 7, 13, 7, 49, 23, 223, 61, 1011, 797, 1335, 6711, 5961, 5605, 0 };
            const std::uint32_t dim3243JoeKuoD6Init[]   =   { 1, 3, 3, 11, 19, 37, 1, 149, 39, 661, 929, 2125, 2299, 5181, 28083, 0 };
            const std::uint32_t dim3244JoeKuoD6Init[]   =   { 1, 3, 3, 13, 13, 9, 67, 21, 463, 279, 529, 523, 6705, 11011, 31695, 0 };
            const std::uint32_t dim3245JoeKuoD6Init[]   =   { 1, 3, 1, 5, 13, 1, 123, 3, 291, 625, 1949, 2713, 5917, 10343, 13627, 0 };
            const std::uint32_t dim3246JoeKuoD6Init[]   =   { 1, 1, 3, 9, 27, 41, 3, 207, 103, 265, 811, 549, 6109, 313, 8889, 0 };
            const std::uint32_t dim3247JoeKuoD6Init[]   =   { 1, 3, 3, 13, 23, 43, 99, 33, 279, 463, 955, 793, 4113, 10615, 16957, 0 };
            const std::uint32_t dim3248JoeKuoD6Init[]   =   { 1, 1, 5, 7, 11, 49, 79, 45, 17, 937, 359, 1037, 1099, 3003, 31561, 0 };
            const std::uint32_t dim3249JoeKuoD6Init[]   =   { 1, 1, 1, 7, 3, 45, 111, 35, 109, 983, 53, 4057, 7349, 3599, 2209, 0 };
            const std::uint32_t dim3250JoeKuoD6Init[]   =   { 1, 3, 7, 11, 9, 43, 27, 9, 85, 529, 1497, 347, 759, 12449, 11373, 0 };
            const std::uint32_t dim3251JoeKuoD6Init[]   =   { 1, 1, 3, 9, 17, 1, 49, 31, 367, 813, 1385, 2025, 773, 4679, 4543, 0 };
            const std::uint32_t dim3252JoeKuoD6Init[]   =   { 1, 1, 5, 15, 15, 9, 43, 97, 239, 995, 1037, 841, 4167, 12113, 23765, 0 };
            const std::uint32_t dim3253JoeKuoD6Init[]   =   { 1, 3, 5, 9, 29, 53, 123, 49, 221, 113, 1157, 73, 6087, 1363, 11029, 0 };
            const std::uint32_t dim3254JoeKuoD6Init[]   =   { 1, 3, 1, 13, 3, 15, 69, 199, 279, 919, 5, 161, 4817, 15031, 121, 0 };
            const std::uint32_t dim3255JoeKuoD6Init[]   =   { 1, 3, 1, 9, 3, 31, 117, 77, 393, 241, 645, 3181, 1067, 15879, 2037, 0 };
            const std::uint32_t dim3256JoeKuoD6Init[]   =   { 1, 3, 3, 15, 3, 63, 57, 33, 117, 789, 941, 1301, 5865, 12693, 3523, 0 };
            const std::uint32_t dim3257JoeKuoD6Init[]   =   { 1, 1, 5, 13, 3, 61, 51, 151, 175, 305, 95, 1557, 6567, 7841, 13903, 0 };
            const std::uint32_t dim3258JoeKuoD6Init[]   =   { 1, 3, 3, 5, 15, 25, 127, 79, 245, 767, 645, 3933, 1357, 12579, 4067, 0 };
            const std::uint32_t dim3259JoeKuoD6Init[]   =   { 1, 3, 5, 11, 21, 31, 13, 251, 127, 231, 1795, 2627, 1191, 3363, 23543, 0 };
            const std::uint32_t dim3260JoeKuoD6Init[]   =   { 1, 1, 3, 5, 7, 49, 121, 57, 131, 481, 1879, 525, 5225, 337, 1957, 0 };
            const std::uint32_t dim3261JoeKuoD6Init[]   =   { 1, 1, 5, 13, 9, 55, 27, 37, 211, 125, 119, 3373, 251, 12357, 13975, 0 };
            const std::uint32_t dim3262JoeKuoD6Init[]   =   { 1, 3, 3, 15, 1, 51, 91, 119, 233, 993, 203, 1635, 1167, 6327, 29119, 0 };
            const std::uint32_t dim3263JoeKuoD6Init[]   =   { 1, 1, 7, 1, 13, 5, 23, 253, 121, 989, 1105, 3321, 3221, 6073, 21185, 0 };
            const std::uint32_t dim3264JoeKuoD6Init[]   =   { 1, 1, 3, 15, 13, 49, 121, 247, 247, 133, 485, 1067, 7875, 411, 7647, 0 };
            const std::uint32_t dim3265JoeKuoD6Init[]   =   { 1, 3, 7, 13, 31, 37, 127, 241, 145, 133, 53, 267, 2029, 3703, 16123, 0 };
            const std::uint32_t dim3266JoeKuoD6Init[]   =   { 1, 3, 1, 15, 15, 9, 15, 89, 35, 367, 401, 61, 1953, 7873, 17861, 0 };
            const std::uint32_t dim3267JoeKuoD6Init[]   =   { 1, 1, 1, 1, 1, 41, 71, 249, 213, 779, 1385, 1767, 999, 15151, 16647, 0 };
            const std::uint32_t dim3268JoeKuoD6Init[]   =   { 1, 3, 7, 13, 31, 23, 123, 235, 343, 949, 309, 3777, 3587, 853, 19779, 0 };
            const std::uint32_t dim3269JoeKuoD6Init[]   =   { 1, 1, 3, 13, 29, 35, 5, 37, 63, 757, 303, 1579, 3443, 243, 11873, 0 };
            const std::uint32_t dim3270JoeKuoD6Init[]   =   { 1, 3, 1, 9, 19, 49, 81, 53, 11, 901, 1857, 147, 3103, 14019, 21, 0 };
            const std::uint32_t dim3271JoeKuoD6Init[]   =   { 1, 3, 7, 13, 3, 39, 99, 99, 45, 91, 1567, 551, 3129, 4809, 29057, 0 };
            const std::uint32_t dim3272JoeKuoD6Init[]   =   { 1, 3, 7, 3, 3, 27, 17, 231, 377, 381, 1479, 2525, 2595, 2799, 25737, 0 };
            const std::uint32_t dim3273JoeKuoD6Init[]   =   { 1, 3, 5, 15, 15, 25, 103, 215, 301, 59, 1417, 981, 7579, 12731, 22329, 0 };
            const std::uint32_t dim3274JoeKuoD6Init[]   =   { 1, 1, 1, 13, 5, 31, 61, 31, 349, 925, 1301, 685, 435, 11567, 10715, 0 };
            const std::uint32_t dim3275JoeKuoD6Init[]   =   { 1, 1, 7, 9, 19, 57, 109, 1, 37, 377, 1015, 2273, 6741, 3191, 15949, 0 };
            const std::uint32_t dim3276JoeKuoD6Init[]   =   { 1, 3, 3, 13, 3, 23, 103, 127, 11, 59, 1847, 1175, 425, 3423, 20643, 0 };
            const std::uint32_t dim3277JoeKuoD6Init[]   =   { 1, 3, 3, 7, 3, 11, 105, 141, 55, 217, 1427, 477, 667, 9403, 11905, 0 };
            const std::uint32_t dim3278JoeKuoD6Init[]   =   { 1, 3, 3, 5, 3, 27, 11, 187, 495, 907, 1925, 445, 6639, 8159, 15225, 0 };
            const std::uint32_t dim3279JoeKuoD6Init[]   =   { 1, 3, 1, 5, 27, 31, 77, 213, 73, 343, 1123, 3609, 2431, 15329, 32165, 0 };
            const std::uint32_t dim3280JoeKuoD6Init[]   =   { 1, 1, 7, 5, 1, 11, 105, 139, 485, 1007, 709, 3509, 5231, 11717, 31433, 0 };
            const std::uint32_t dim3281JoeKuoD6Init[]   =   { 1, 1, 3, 15, 23, 49, 95, 169, 399, 1019, 19, 2013, 5311, 7951, 22609, 0 };
            const std::uint32_t dim3282JoeKuoD6Init[]   =   { 1, 3, 1, 7, 13, 3, 29, 203, 209, 701, 1791, 2615, 5351, 4237, 12565, 0 };
            const std::uint32_t dim3283JoeKuoD6Init[]   =   { 1, 3, 1, 15, 27, 11, 91, 31, 205, 205, 1683, 901, 5129, 6049, 11865, 0 };
            const std::uint32_t dim3284JoeKuoD6Init[]   =   { 1, 1, 7, 7, 27, 59, 21, 3, 209, 79, 769, 4013, 2041, 2645, 11561, 0 };
            const std::uint32_t dim3285JoeKuoD6Init[]   =   { 1, 3, 7, 11, 5, 45, 39, 243, 185, 871, 795, 1845, 8043, 6285, 20991, 0 };
            const std::uint32_t dim3286JoeKuoD6Init[]   =   { 1, 1, 5, 7, 13, 7, 15, 165, 349, 179, 789, 1269, 3787, 5429, 26567, 0 };
            const std::uint32_t dim3287JoeKuoD6Init[]   =   { 1, 3, 3, 13, 31, 23, 75, 41, 177, 735, 1889, 4039, 3519, 15003, 965, 0 };
            const std::uint32_t dim3288JoeKuoD6Init[]   =   { 1, 3, 1, 7, 15, 57, 15, 139, 27, 469, 1003, 691, 7893, 9643, 30983, 0 };
            const std::uint32_t dim3289JoeKuoD6Init[]   =   { 1, 3, 1, 13, 23, 27, 3, 237, 233, 875, 99, 883, 6167, 5463, 6245, 0 };
            const std::uint32_t dim3290JoeKuoD6Init[]   =   { 1, 1, 5, 13, 25, 57, 79, 51, 147, 619, 1147, 279, 6583, 1939, 477, 0 };
            const std::uint32_t dim3291JoeKuoD6Init[]   =   { 1, 3, 5, 5, 31, 61, 125, 163, 213, 699, 583, 3865, 615, 9707, 11651, 0 };
            const std::uint32_t dim3292JoeKuoD6Init[]   =   { 1, 1, 5, 1, 5, 21, 93, 239, 31, 641, 777, 27, 5247, 8993, 21053, 0 };
            const std::uint32_t dim3293JoeKuoD6Init[]   =   { 1, 3, 7, 9, 1, 13, 61, 57, 503, 453, 83, 3271, 2845, 1121, 18639, 0 };
            const std::uint32_t dim3294JoeKuoD6Init[]   =   { 1, 1, 7, 5, 29, 53, 13, 219, 379, 441, 821, 3179, 4877, 2535, 7557, 0 };
            const std::uint32_t dim3295JoeKuoD6Init[]   =   { 1, 1, 7, 13, 9, 53, 17, 183, 265, 393, 587, 2753, 6453, 7135, 24737, 0 };
            const std::uint32_t dim3296JoeKuoD6Init[]   =   { 1, 1, 1, 13, 11, 23, 73, 109, 393, 1013, 559, 755, 7291, 6631, 26509, 0 };
            const std::uint32_t dim3297JoeKuoD6Init[]   =   { 1, 3, 1, 5, 5, 15, 107, 103, 355, 307, 1559, 837, 5413, 5285, 17489, 0 };
            const std::uint32_t dim3298JoeKuoD6Init[]   =   { 1, 1, 5, 7, 17, 21, 21, 23, 109, 709, 1947, 3585, 3629, 4669, 949, 0 };
            const std::uint32_t dim3299JoeKuoD6Init[]   =   { 1, 3, 7, 1, 9, 33, 85, 147, 467, 259, 1913, 199, 7399, 9551, 22387, 0 };
            const std::uint32_t dim3300JoeKuoD6Init[]   =   { 1, 3, 5, 11, 15, 53, 23, 41, 249, 515, 1161, 2467, 1299, 7449, 2613, 0 };
            const std::uint32_t dim3301JoeKuoD6Init[]   =   { 1, 1, 5, 5, 5, 29, 91, 139, 487, 545, 321, 3035, 4545, 6747, 21673, 0 };
            const std::uint32_t dim3302JoeKuoD6Init[]   =   { 1, 1, 3, 13, 23, 49, 95, 103, 25, 119, 469, 2515, 2551, 841, 25089, 0 };
            const std::uint32_t dim3303JoeKuoD6Init[]   =   { 1, 1, 5, 7, 11, 31, 31, 197, 245, 715, 257, 4043, 8099, 11531, 5617, 0 };
            const std::uint32_t dim3304JoeKuoD6Init[]   =   { 1, 1, 3, 3, 19, 7, 9, 179, 103, 995, 191, 179, 3843, 5215, 27639, 0 };
            const std::uint32_t dim3305JoeKuoD6Init[]   =   { 1, 3, 1, 7, 23, 59, 25, 65, 399, 211, 1453, 3511, 7203, 16015, 32197, 0 };
            const std::uint32_t dim3306JoeKuoD6Init[]   =   { 1, 3, 3, 5, 9, 35, 109, 67, 197, 449, 643, 519, 5751, 15551, 11331, 0 };
            const std::uint32_t dim3307JoeKuoD6Init[]   =   { 1, 3, 5, 3, 1, 17, 53, 201, 265, 351, 467, 911, 1117, 7183, 20371, 0 };
            const std::uint32_t dim3308JoeKuoD6Init[]   =   { 1, 1, 7, 7, 27, 17, 93, 81, 227, 619, 1191, 735, 815, 12615, 2719, 0 };
            const std::uint32_t dim3309JoeKuoD6Init[]   =   { 1, 3, 1, 15, 19, 3, 83, 75, 343, 297, 1019, 3469, 4383, 13299, 29755, 0 };
            const std::uint32_t dim3310JoeKuoD6Init[]   =   { 1, 1, 5, 3, 13, 55, 119, 169, 85, 595, 299, 2469, 5625, 2877, 16117, 0 };
            const std::uint32_t dim3311JoeKuoD6Init[]   =   { 1, 1, 3, 5, 15, 17, 61, 161, 47, 393, 143, 867, 5517, 9495, 12795, 0 };
            const std::uint32_t dim3312JoeKuoD6Init[]   =   { 1, 3, 5, 1, 27, 31, 113, 125, 251, 687, 969, 1473, 2245, 6355, 13655, 0 };
            const std::uint32_t dim3313JoeKuoD6Init[]   =   { 1, 1, 1, 5, 5, 37, 29, 133, 443, 899, 277, 2353, 7223, 4459, 19159, 0 };
            const std::uint32_t dim3314JoeKuoD6Init[]   =   { 1, 1, 3, 9, 19, 27, 53, 145, 195, 167, 2045, 447, 1803, 1895, 8431, 0 };
            const std::uint32_t dim3315JoeKuoD6Init[]   =   { 1, 1, 3, 9, 5, 27, 91, 147, 233, 451, 475, 27, 4629, 16181, 16437, 0 };
            const std::uint32_t dim3316JoeKuoD6Init[]   =   { 1, 3, 5, 3, 29, 17, 53, 167, 433, 689, 1131, 2985, 1553, 11697, 6993, 0 };
            const std::uint32_t dim3317JoeKuoD6Init[]   =   { 1, 3, 3, 13, 21, 43, 69, 229, 399, 525, 179, 237, 7017, 5703, 17653, 0 };
            const std::uint32_t dim3318JoeKuoD6Init[]   =   { 1, 1, 3, 15, 13, 39, 75, 163, 229, 875, 197, 477, 3667, 15501, 15801, 0 };
            const std::uint32_t dim3319JoeKuoD6Init[]   =   { 1, 1, 7, 15, 15, 51, 81, 187, 487, 673, 865, 1915, 1009, 5935, 8097, 0 };
            const std::uint32_t dim3320JoeKuoD6Init[]   =   { 1, 3, 5, 5, 7, 3, 63, 77, 495, 815, 391, 2321, 1007, 15661, 30715, 0 };
            const std::uint32_t dim3321JoeKuoD6Init[]   =   { 1, 1, 7, 3, 17, 25, 83, 173, 173, 911, 1373, 2957, 4549, 15977, 17695, 0 };
            const std::uint32_t dim3322JoeKuoD6Init[]   =   { 1, 1, 7, 13, 13, 23, 77, 147, 497, 1003, 1687, 1795, 1393, 1881, 8479, 0 };
            const std::uint32_t dim3323JoeKuoD6Init[]   =   { 1, 3, 7, 11, 27, 43, 97, 25, 61, 457, 203, 2573, 5943, 15021, 4003, 0 };
            const std::uint32_t dim3324JoeKuoD6Init[]   =   { 1, 3, 3, 13, 9, 37, 37, 25, 219, 889, 1535, 2791, 4531, 13679, 12663, 0 };
            const std::uint32_t dim3325JoeKuoD6Init[]   =   { 1, 1, 3, 1, 17, 7, 51, 123, 89, 887, 1467, 1645, 3767, 6383, 30837, 0 };
            const std::uint32_t dim3326JoeKuoD6Init[]   =   { 1, 3, 3, 1, 21, 47, 5, 151, 83, 257, 569, 2711, 637, 12569, 16893, 0 };
            const std::uint32_t dim3327JoeKuoD6Init[]   =   { 1, 3, 7, 1, 31, 37, 73, 3, 115, 919, 1817, 2483, 4811, 15245, 4375, 0 };
            const std::uint32_t dim3328JoeKuoD6Init[]   =   { 1, 1, 1, 5, 1, 39, 39, 231, 9, 733, 455, 3383, 4777, 7235, 12631, 0 };
            const std::uint32_t dim3329JoeKuoD6Init[]   =   { 1, 1, 7, 9, 13, 25, 55, 25, 73, 59, 1699, 929, 755, 1279, 5583, 0 };
            const std::uint32_t dim3330JoeKuoD6Init[]   =   { 1, 3, 5, 3, 9, 49, 79, 55, 479, 179, 1159, 4079, 3503, 11603, 12361, 0 };
            const std::uint32_t dim3331JoeKuoD6Init[]   =   { 1, 1, 5, 9, 21, 45, 31, 163, 377, 817, 219, 147, 2581, 12769, 30783, 0 };
            const std::uint32_t dim3332JoeKuoD6Init[]   =   { 1, 3, 1, 7, 15, 27, 39, 189, 493, 259, 1663, 1213, 961, 11089, 16079, 0 };
            const std::uint32_t dim3333JoeKuoD6Init[]   =   { 1, 1, 5, 9, 5, 41, 13, 153, 313, 337, 1027, 1267, 4249, 13071, 27043, 0 };
            const std::uint32_t dim3334JoeKuoD6Init[]   =   { 1, 3, 7, 3, 13, 11, 23, 255, 51, 527, 317, 3217, 5037, 12723, 17411, 0 };
            const std::uint32_t dim3335JoeKuoD6Init[]   =   { 1, 1, 5, 1, 25, 57, 83, 97, 233, 513, 1283, 2675, 4111, 4111, 32141, 0 };
            const std::uint32_t dim3336JoeKuoD6Init[]   =   { 1, 3, 3, 15, 25, 33, 103, 81, 155, 189, 139, 1179, 2691, 15119, 13959, 0 };
            const std::uint32_t dim3337JoeKuoD6Init[]   =   { 1, 3, 3, 1, 25, 55, 67, 19, 19, 9, 437, 579, 4273, 10733, 7125, 0 };
            const std::uint32_t dim3338JoeKuoD6Init[]   =   { 1, 1, 1, 7, 23, 41, 47, 5, 435, 749, 595, 199, 3941, 7199, 4795, 0 };
            const std::uint32_t dim3339JoeKuoD6Init[]   =   { 1, 3, 1, 15, 5, 49, 35, 9, 199, 703, 1769, 3269, 5689, 13063, 22771, 0 };
            const std::uint32_t dim3340JoeKuoD6Init[]   =   { 1, 1, 5, 5, 21, 55, 125, 55, 63, 149, 1167, 3577, 1051, 3921, 20545, 0 };
            const std::uint32_t dim3341JoeKuoD6Init[]   =   { 1, 3, 7, 13, 29, 53, 107, 193, 163, 339, 1335, 1573, 5809, 5681, 29487, 0 };
            const std::uint32_t dim3342JoeKuoD6Init[]   =   { 1, 1, 1, 9, 17, 9, 91, 177, 211, 453, 1807, 1881, 6051, 225, 6021, 0 };
            const std::uint32_t dim3343JoeKuoD6Init[]   =   { 1, 1, 1, 13, 15, 1, 29, 43, 181, 105, 1945, 2313, 6429, 2901, 6221, 0 };
            const std::uint32_t dim3344JoeKuoD6Init[]   =   { 1, 3, 5, 11, 29, 55, 115, 115, 187, 1013, 697, 1885, 121, 12387, 32443, 0 };
            const std::uint32_t dim3345JoeKuoD6Init[]   =   { 1, 1, 1, 7, 19, 51, 21, 107, 55, 125, 1655, 2281, 3293, 15749, 27521, 0 };
            const std::uint32_t dim3346JoeKuoD6Init[]   =   { 1, 1, 7, 9, 19, 9, 81, 93, 139, 401, 193, 73, 5159, 9323, 6019, 0 };
            const std::uint32_t dim3347JoeKuoD6Init[]   =   { 1, 1, 7, 9, 15, 51, 115, 69, 247, 599, 1163, 2251, 1211, 8827, 15581, 0 };
            const std::uint32_t dim3348JoeKuoD6Init[]   =   { 1, 1, 7, 9, 5, 39, 75, 185, 321, 911, 849, 843, 6791, 10407, 10513, 0 };
            const std::uint32_t dim3349JoeKuoD6Init[]   =   { 1, 1, 5, 5, 15, 9, 21, 47, 459, 681, 2001, 1545, 5939, 7073, 29043, 0 };
            const std::uint32_t dim3350JoeKuoD6Init[]   =   { 1, 3, 1, 11, 13, 25, 53, 97, 487, 797, 567, 3757, 5597, 6313, 18531, 0 };
            const std::uint32_t dim3351JoeKuoD6Init[]   =   { 1, 1, 3, 3, 29, 55, 11, 219, 325, 591, 2015, 383, 2595, 11855, 22501, 0 };
            const std::uint32_t dim3352JoeKuoD6Init[]   =   { 1, 1, 1, 5, 15, 57, 33, 125, 323, 749, 1843, 4019, 2075, 6673, 6957, 0 };
            const std::uint32_t dim3353JoeKuoD6Init[]   =   { 1, 1, 5, 7, 19, 7, 47, 239, 51, 107, 1081, 467, 5493, 7617, 10355, 0 };
            const std::uint32_t dim3354JoeKuoD6Init[]   =   { 1, 3, 1, 1, 11, 3, 67, 199, 175, 421, 935, 309, 4449, 6363, 9183, 0 };
            const std::uint32_t dim3355JoeKuoD6Init[]   =   { 1, 1, 1, 7, 9, 33, 3, 219, 481, 513, 417, 1267, 2863, 765, 18431, 0 };
            const std::uint32_t dim3356JoeKuoD6Init[]   =   { 1, 3, 1, 1, 19, 1, 89, 109, 415, 105, 487, 3241, 7465, 9233, 16307, 0 };
            const std::uint32_t dim3357JoeKuoD6Init[]   =   { 1, 1, 3, 13, 9, 43, 25, 231, 383, 789, 1855, 691, 3465, 2387, 11715, 0 };
            const std::uint32_t dim3358JoeKuoD6Init[]   =   { 1, 3, 3, 3, 13, 39, 63, 107, 33, 265, 437, 117, 3179, 5543, 28179, 0 };
            const std::uint32_t dim3359JoeKuoD6Init[]   =   { 1, 3, 3, 13, 21, 5, 31, 111, 321, 425, 253, 3501, 3209, 15429, 18383, 0 };
            const std::uint32_t dim3360JoeKuoD6Init[]   =   { 1, 3, 5, 9, 1, 27, 117, 187, 433, 459, 1999, 1069, 4857, 8591, 26343, 0 };
            const std::uint32_t dim3361JoeKuoD6Init[]   =   { 1, 1, 7, 3, 15, 43, 11, 193, 391, 341, 1203, 1259, 7265, 1783, 13161, 0 };
            const std::uint32_t dim3362JoeKuoD6Init[]   =   { 1, 1, 7, 1, 5, 15, 45, 143, 193, 985, 1105, 3483, 2421, 9687, 22347, 0 };
            const std::uint32_t dim3363JoeKuoD6Init[]   =   { 1, 3, 7, 13, 21, 17, 79, 231, 487, 663, 1101, 1025, 5779, 14681, 29181, 0 };
            const std::uint32_t dim3364JoeKuoD6Init[]   =   { 1, 1, 3, 9, 15, 19, 55, 219, 27, 963, 1513, 1017, 3907, 12279, 32655, 0 };
            const std::uint32_t dim3365JoeKuoD6Init[]   =   { 1, 3, 7, 3, 31, 27, 17, 1, 51, 861, 529, 1225, 6395, 15787, 5231, 0 };
            const std::uint32_t dim3366JoeKuoD6Init[]   =   { 1, 3, 3, 11, 27, 7, 101, 143, 21, 191, 1437, 2393, 4097, 14319, 6977, 0 };
            const std::uint32_t dim3367JoeKuoD6Init[]   =   { 1, 3, 3, 3, 25, 35, 105, 141, 433, 269, 1469, 2939, 5387, 7373, 7863, 0 };
            const std::uint32_t dim3368JoeKuoD6Init[]   =   { 1, 3, 7, 5, 5, 21, 23, 11, 217, 357, 1847, 101, 1161, 5297, 14879, 0 };
            const std::uint32_t dim3369JoeKuoD6Init[]   =   { 1, 3, 1, 3, 25, 23, 81, 217, 505, 161, 1667, 1343, 1751, 2463, 26431, 0 };
            const std::uint32_t dim3370JoeKuoD6Init[]   =   { 1, 1, 3, 1, 17, 51, 125, 205, 385, 351, 731, 2911, 2749, 2689, 27031, 0 };
            const std::uint32_t dim3371JoeKuoD6Init[]   =   { 1, 1, 5, 5, 5, 17, 31, 171, 477, 671, 167, 1797, 8047, 10123, 4325, 0 };
            const std::uint32_t dim3372JoeKuoD6Init[]   =   { 1, 1, 7, 1, 11, 23, 123, 161, 99, 1007, 765, 1965, 5395, 16193, 17751, 0 };
            const std::uint32_t dim3373JoeKuoD6Init[]   =   { 1, 3, 1, 9, 13, 11, 111, 217, 31, 753, 377, 2267, 7893, 7195, 24999, 0 };
            const std::uint32_t dim3374JoeKuoD6Init[]   =   { 1, 3, 1, 9, 21, 53, 127, 121, 151, 395, 1447, 1411, 5179, 12043, 27607, 0 };
            const std::uint32_t dim3375JoeKuoD6Init[]   =   { 1, 1, 5, 3, 11, 37, 97, 139, 113, 835, 229, 3741, 827, 5527, 5779, 0 };
            const std::uint32_t dim3376JoeKuoD6Init[]   =   { 1, 1, 7, 7, 27, 55, 11, 55, 429, 269, 1179, 233, 1053, 10225, 16703, 0 };
            const std::uint32_t dim3377JoeKuoD6Init[]   =   { 1, 1, 1, 3, 15, 9, 67, 119, 95, 753, 511, 2507, 3953, 6403, 27635, 0 };
            const std::uint32_t dim3378JoeKuoD6Init[]   =   { 1, 3, 3, 7, 27, 57, 25, 27, 249, 515, 193, 4043, 2017, 751, 10949, 0 };
            const std::uint32_t dim3379JoeKuoD6Init[]   =   { 1, 3, 1, 9, 31, 57, 67, 21, 177, 573, 1835, 2015, 6201, 2383, 31087, 0 };
            const std::uint32_t dim3380JoeKuoD6Init[]   =   { 1, 1, 5, 1, 19, 3, 89, 243, 69, 387, 1905, 3465, 2775, 7713, 30081, 0 };
            const std::uint32_t dim3381JoeKuoD6Init[]   =   { 1, 1, 3, 3, 9, 59, 15, 89, 85, 605, 881, 263, 2551, 797, 16541, 0 };
            const std::uint32_t dim3382JoeKuoD6Init[]   =   { 1, 3, 7, 11, 25, 41, 59, 139, 405, 571, 1147, 2963, 4175, 12901, 6309, 0 };
            const std::uint32_t dim3383JoeKuoD6Init[]   =   { 1, 3, 1, 5, 29, 29, 11, 243, 183, 281, 807, 1, 7079, 10079, 13865, 0 };
            const std::uint32_t dim3384JoeKuoD6Init[]   =   { 1, 3, 7, 5, 5, 1, 89, 55, 423, 157, 675, 1849, 241, 6467, 15459, 0 };
            const std::uint32_t dim3385JoeKuoD6Init[]   =   { 1, 1, 7, 11, 15, 63, 89, 109, 501, 549, 317, 3043, 1151, 3895, 19851, 0 };
            const std::uint32_t dim3386JoeKuoD6Init[]   =   { 1, 3, 1, 15, 7, 23, 97, 97, 225, 737, 1117, 3325, 209, 14169, 10813, 0 };
            const std::uint32_t dim3387JoeKuoD6Init[]   =   { 1, 3, 7, 13, 13, 39, 91, 153, 395, 879, 1041, 3753, 5577, 1985, 25247, 0 };
            const std::uint32_t dim3388JoeKuoD6Init[]   =   { 1, 1, 1, 3, 17, 15, 113, 143, 101, 901, 1119, 1819, 3577, 3441, 31511, 0 };
            const std::uint32_t dim3389JoeKuoD6Init[]   =   { 1, 3, 1, 11, 15, 27, 21, 37, 287, 121, 451, 1353, 2173, 299, 18791, 0 };
            const std::uint32_t dim3390JoeKuoD6Init[]   =   { 1, 3, 3, 5, 23, 1, 49, 145, 315, 769, 99, 1385, 5961, 9121, 1465, 0 };
            const std::uint32_t dim3391JoeKuoD6Init[]   =   { 1, 3, 3, 13, 21, 39, 39, 233, 271, 113, 615, 2257, 3765, 5921, 313, 0 };
            const std::uint32_t dim3392JoeKuoD6Init[]   =   { 1, 3, 7, 7, 25, 45, 11, 237, 83, 203, 929, 1819, 2679, 11583, 30091, 0 };
            const std::uint32_t dim3393JoeKuoD6Init[]   =   { 1, 1, 1, 7, 21, 63, 85, 251, 133, 991, 1515, 2547, 6051, 7279, 3569, 0 };
            const std::uint32_t dim3394JoeKuoD6Init[]   =   { 1, 3, 7, 15, 11, 19, 87, 17, 313, 283, 1021, 2743, 4855, 13741, 17955, 0 };
            const std::uint32_t dim3395JoeKuoD6Init[]   =   { 1, 1, 7, 13, 29, 13, 61, 93, 81, 91, 995, 907, 4847, 2599, 20041, 0 };
            const std::uint32_t dim3396JoeKuoD6Init[]   =   { 1, 1, 3, 11, 13, 45, 103, 33, 243, 109, 2029, 121, 231, 16179, 13741, 0 };
            const std::uint32_t dim3397JoeKuoD6Init[]   =   { 1, 3, 5, 9, 9, 5, 73, 225, 199, 723, 611, 1909, 2345, 10257, 9909, 0 };
            const std::uint32_t dim3398JoeKuoD6Init[]   =   { 1, 1, 3, 11, 7, 5, 33, 89, 431, 899, 803, 3173, 6131, 16097, 20561, 0 };
            const std::uint32_t dim3399JoeKuoD6Init[]   =   { 1, 3, 3, 7, 7, 47, 23, 47, 411, 69, 239, 661, 5591, 10457, 24245, 0 };
            const std::uint32_t dim3400JoeKuoD6Init[]   =   { 1, 1, 5, 15, 25, 35, 87, 23, 115, 939, 1579, 119, 4001, 13791, 9729, 0 };
            const std::uint32_t dim3401JoeKuoD6Init[]   =   { 1, 3, 5, 11, 25, 45, 29, 195, 369, 237, 735, 155, 123, 4415, 32255, 0 };
            const std::uint32_t dim3402JoeKuoD6Init[]   =   { 1, 3, 3, 9, 13, 53, 15, 77, 313, 75, 529, 925, 5679, 14585, 19889, 0 };
            const std::uint32_t dim3403JoeKuoD6Init[]   =   { 1, 1, 7, 15, 15, 27, 105, 13, 31, 669, 563, 1809, 4321, 7797, 4177, 0 };
            const std::uint32_t dim3404JoeKuoD6Init[]   =   { 1, 1, 5, 9, 3, 29, 111, 177, 33, 235, 1951, 1561, 141, 4803, 16327, 0 };
            const std::uint32_t dim3405JoeKuoD6Init[]   =   { 1, 1, 1, 7, 9, 41, 1, 149, 95, 933, 115, 1619, 771, 8189, 8781, 0 };
            const std::uint32_t dim3406JoeKuoD6Init[]   =   { 1, 1, 5, 3, 13, 41, 33, 159, 355, 159, 1243, 1439, 6571, 14397, 31321, 0 };
            const std::uint32_t dim3407JoeKuoD6Init[]   =   { 1, 1, 7, 11, 9, 15, 91, 145, 457, 255, 1449, 611, 1449, 2521, 28949, 0 };
            const std::uint32_t dim3408JoeKuoD6Init[]   =   { 1, 3, 7, 5, 27, 57, 35, 99, 447, 287, 743, 1163, 4379, 7361, 3831, 0 };
            const std::uint32_t dim3409JoeKuoD6Init[]   =   { 1, 3, 3, 7, 15, 53, 41, 83, 133, 571, 1739, 531, 2921, 11527, 21941, 0 };
            const std::uint32_t dim3410JoeKuoD6Init[]   =   { 1, 1, 1, 13, 9, 27, 39, 113, 429, 447, 595, 3171, 5245, 4095, 14847, 0 };
            const std::uint32_t dim3411JoeKuoD6Init[]   =   { 1, 1, 3, 7, 19, 19, 21, 101, 489, 1011, 265, 3899, 3225, 11701, 5193, 0 };
            const std::uint32_t dim3412JoeKuoD6Init[]   =   { 1, 3, 7, 3, 15, 25, 103, 213, 441, 215, 1483, 263, 3561, 7915, 7969, 0 };
            const std::uint32_t dim3413JoeKuoD6Init[]   =   { 1, 3, 3, 3, 11, 47, 97, 29, 489, 867, 1347, 2155, 4871, 8001, 18305, 0 };
            const std::uint32_t dim3414JoeKuoD6Init[]   =   { 1, 3, 1, 9, 25, 15, 61, 17, 343, 775, 1765, 3803, 4577, 8437, 12605, 0 };
            const std::uint32_t dim3415JoeKuoD6Init[]   =   { 1, 1, 5, 3, 11, 39, 69, 23, 23, 65, 1967, 2429, 1703, 6671, 14981, 0 };
            const std::uint32_t dim3416JoeKuoD6Init[]   =   { 1, 1, 5, 15, 23, 59, 125, 51, 225, 439, 2019, 2589, 7781, 13111, 2911, 0 };
            const std::uint32_t dim3417JoeKuoD6Init[]   =   { 1, 1, 1, 3, 1, 31, 37, 245, 203, 305, 821, 367, 5211, 9791, 21777, 0 };
            const std::uint32_t dim3418JoeKuoD6Init[]   =   { 1, 1, 5, 9, 9, 31, 97, 25, 271, 83, 343, 2461, 1805, 14383, 10059, 0 };
            const std::uint32_t dim3419JoeKuoD6Init[]   =   { 1, 1, 5, 13, 15, 33, 127, 109, 137, 963, 961, 1647, 7881, 8133, 22359, 0 };
            const std::uint32_t dim3420JoeKuoD6Init[]   =   { 1, 1, 3, 7, 25, 31, 123, 241, 283, 1, 1781, 23, 971, 6485, 127, 0 };
            const std::uint32_t dim3421JoeKuoD6Init[]   =   { 1, 1, 5, 15, 15, 27, 25, 145, 395, 679, 979, 571, 1585, 14787, 7465, 0 };
            const std::uint32_t dim3422JoeKuoD6Init[]   =   { 1, 1, 5, 7, 13, 11, 7, 131, 511, 597, 379, 1513, 6267, 16039, 1503, 0 };
            const std::uint32_t dim3423JoeKuoD6Init[]   =   { 1, 1, 1, 13, 15, 49, 73, 217, 353, 577, 1913, 1127, 961, 11557, 24993, 0 };
            const std::uint32_t dim3424JoeKuoD6Init[]   =   { 1, 3, 3, 9, 7, 3, 105, 141, 377, 687, 1917, 485, 983, 11149, 23303, 0 };
            const std::uint32_t dim3425JoeKuoD6Init[]   =   { 1, 1, 3, 15, 11, 7, 117, 179, 505, 67, 1817, 913, 5757, 1981, 1637, 0 };
            const std::uint32_t dim3426JoeKuoD6Init[]   =   { 1, 1, 1, 7, 5, 29, 3, 43, 223, 295, 1895, 3425, 5355, 5155, 17197, 0 };
            const std::uint32_t dim3427JoeKuoD6Init[]   =   { 1, 1, 7, 9, 21, 59, 121, 245, 73, 233, 1527, 869, 4145, 7995, 6473, 0 };
            const std::uint32_t dim3428JoeKuoD6Init[]   =   { 1, 1, 5, 13, 17, 21, 89, 179, 495, 669, 453, 2603, 5969, 6161, 4743, 0 };
            const std::uint32_t dim3429JoeKuoD6Init[]   =   { 1, 1, 7, 11, 25, 21, 103, 131, 391, 249, 1633, 2603, 2207, 8987, 15487, 0 };
            const std::uint32_t dim3430JoeKuoD6Init[]   =   { 1, 3, 7, 9, 13, 45, 99, 251, 115, 597, 1505, 2421, 1231, 10015, 24295, 0 };
            const std::uint32_t dim3431JoeKuoD6Init[]   =   { 1, 1, 5, 5, 31, 49, 17, 67, 463, 813, 1491, 3309, 7881, 8109, 7289, 0 };
            const std::uint32_t dim3432JoeKuoD6Init[]   =   { 1, 3, 1, 15, 23, 35, 123, 21, 169, 499, 95, 603, 1829, 7865, 26313, 0 };
            const std::uint32_t dim3433JoeKuoD6Init[]   =   { 1, 1, 7, 1, 9, 29, 45, 65, 95, 97, 673, 3673, 2969, 2317, 22209, 0 };
            const std::uint32_t dim3434JoeKuoD6Init[]   =   { 1, 1, 3, 7, 29, 33, 121, 17, 331, 487, 1901, 1951, 5383, 9375, 4029, 0 };
            const std::uint32_t dim3435JoeKuoD6Init[]   =   { 1, 3, 7, 9, 25, 43, 91, 147, 141, 401, 1647, 2697, 4645, 7179, 31857, 0 };
            const std::uint32_t dim3436JoeKuoD6Init[]   =   { 1, 3, 5, 11, 9, 31, 127, 105, 39, 883, 1635, 919, 5069, 2875, 24519, 0 };
            const std::uint32_t dim3437JoeKuoD6Init[]   =   { 1, 1, 5, 9, 1, 63, 73, 135, 95, 503, 385, 3903, 545, 12635, 27569, 0 };
            const std::uint32_t dim3438JoeKuoD6Init[]   =   { 1, 1, 3, 11, 27, 31, 47, 173, 55, 339, 1255, 1947, 793, 14133, 13963, 0 };
            const std::uint32_t dim3439JoeKuoD6Init[]   =   { 1, 1, 3, 15, 17, 33, 113, 249, 401, 743, 1307, 3123, 627, 1253, 13285, 0 };
            const std::uint32_t dim3440JoeKuoD6Init[]   =   { 1, 1, 3, 1, 9, 7, 39, 65, 281, 107, 833, 193, 2987, 12267, 31335, 0 };
            const std::uint32_t dim3441JoeKuoD6Init[]   =   { 1, 1, 7, 3, 15, 21, 99, 211, 39, 179, 587, 1169, 6455, 8225, 2049, 0 };
            const std::uint32_t dim3442JoeKuoD6Init[]   =   { 1, 3, 5, 13, 5, 13, 123, 1, 223, 273, 731, 2967, 4793, 4229, 26031, 0 };
            const std::uint32_t dim3443JoeKuoD6Init[]   =   { 1, 1, 1, 1, 3, 17, 7, 23, 225, 757, 743, 1257, 2047, 12509, 25467, 0 };
            const std::uint32_t dim3444JoeKuoD6Init[]   =   { 1, 1, 7, 15, 29, 3, 15, 113, 227, 675, 1295, 2777, 2921, 5485, 2577, 0 };
            const std::uint32_t dim3445JoeKuoD6Init[]   =   { 1, 3, 7, 13, 19, 21, 85, 129, 45, 599, 317, 1513, 4953, 10383, 25253, 0 };
            const std::uint32_t dim3446JoeKuoD6Init[]   =   { 1, 1, 7, 11, 13, 47, 127, 67, 219, 131, 905, 2005, 851, 15243, 5777, 0 };
            const std::uint32_t dim3447JoeKuoD6Init[]   =   { 1, 1, 5, 3, 23, 57, 57, 189, 153, 37, 955, 2049, 1295, 15119, 27213, 0 };
            const std::uint32_t dim3448JoeKuoD6Init[]   =   { 1, 3, 7, 11, 13, 61, 3, 241, 269, 789, 1595, 2369, 4843, 11347, 21543, 0 };
            const std::uint32_t dim3449JoeKuoD6Init[]   =   { 1, 1, 5, 5, 25, 21, 19, 237, 3, 605, 1343, 3965, 3511, 7889, 27759, 0 };
            const std::uint32_t dim3450JoeKuoD6Init[]   =   { 1, 3, 1, 15, 21, 15, 123, 5, 345, 945, 283, 1313, 335, 2085, 19505, 0 };
            const std::uint32_t dim3451JoeKuoD6Init[]   =   { 1, 1, 3, 3, 5, 21, 123, 89, 67, 11, 1247, 1155, 287, 13455, 5693, 0 };
            const std::uint32_t dim3452JoeKuoD6Init[]   =   { 1, 3, 3, 13, 1, 53, 101, 27, 387, 379, 19, 751, 2445, 11737, 975, 0 };
            const std::uint32_t dim3453JoeKuoD6Init[]   =   { 1, 3, 3, 3, 9, 29, 81, 117, 443, 145, 1619, 1813, 8125, 5829, 28617, 0 };
            const std::uint32_t dim3454JoeKuoD6Init[]   =   { 1, 1, 5, 15, 27, 15, 83, 83, 61, 715, 1655, 1631, 3457, 2727, 2163, 0 };
            const std::uint32_t dim3455JoeKuoD6Init[]   =   { 1, 3, 1, 5, 11, 11, 121, 7, 135, 883, 927, 1817, 6839, 12361, 24119, 0 };
            const std::uint32_t dim3456JoeKuoD6Init[]   =   { 1, 3, 7, 11, 23, 59, 39, 165, 109, 355, 1303, 381, 5697, 275, 3771, 0 };
            const std::uint32_t dim3457JoeKuoD6Init[]   =   { 1, 3, 5, 11, 11, 5, 81, 157, 55, 435, 613, 127, 4087, 3791, 21627, 0 };
            const std::uint32_t dim3458JoeKuoD6Init[]   =   { 1, 3, 7, 15, 13, 37, 83, 195, 207, 771, 51, 3685, 6389, 1229, 11101, 0 };
            const std::uint32_t dim3459JoeKuoD6Init[]   =   { 1, 3, 7, 13, 31, 3, 9, 13, 487, 95, 77, 809, 5809, 12887, 29933, 0 };
            const std::uint32_t dim3460JoeKuoD6Init[]   =   { 1, 1, 3, 7, 25, 9, 13, 29, 353, 659, 1785, 3825, 3729, 13109, 12973, 0 };
            const std::uint32_t dim3461JoeKuoD6Init[]   =   { 1, 1, 1, 5, 21, 3, 97, 1, 245, 917, 29, 1429, 8141, 7569, 32493, 0 };
            const std::uint32_t dim3462JoeKuoD6Init[]   =   { 1, 3, 1, 9, 19, 13, 13, 109, 377, 1007, 1737, 1939, 1419, 1145, 5065, 0 };
            const std::uint32_t dim3463JoeKuoD6Init[]   =   { 1, 1, 7, 9, 27, 57, 53, 69, 423, 43, 1629, 1003, 1473, 10809, 5659, 0 };
            const std::uint32_t dim3464JoeKuoD6Init[]   =   { 1, 1, 1, 9, 1, 45, 11, 231, 351, 155, 663, 2783, 3491, 5725, 25207, 0 };
            const std::uint32_t dim3465JoeKuoD6Init[]   =   { 1, 1, 1, 3, 15, 25, 77, 89, 231, 813, 657, 2603, 4885, 1383, 14499, 0 };
            const std::uint32_t dim3466JoeKuoD6Init[]   =   { 1, 3, 5, 5, 9, 21, 101, 181, 449, 491, 737, 803, 659, 11771, 545, 0 };
            const std::uint32_t dim3467JoeKuoD6Init[]   =   { 1, 3, 7, 9, 7, 19, 27, 199, 265, 329, 1031, 1235, 3191, 10071, 16281, 0 };
            const std::uint32_t dim3468JoeKuoD6Init[]   =   { 1, 1, 7, 11, 27, 55, 3, 127, 503, 1003, 1041, 1953, 5835, 4851, 13485, 0 };
            const std::uint32_t dim3469JoeKuoD6Init[]   =   { 1, 1, 7, 15, 5, 45, 97, 61, 221, 497, 1949, 3163, 4707, 8441, 1437, 0 };
            const std::uint32_t dim3470JoeKuoD6Init[]   =   { 1, 3, 5, 1, 3, 35, 107, 9, 473, 971, 227, 2225, 3999, 3095, 18879, 0 };
            const std::uint32_t dim3471JoeKuoD6Init[]   =   { 1, 1, 1, 9, 21, 59, 21, 1, 41, 435, 575, 491, 1839, 1095, 9727, 0 };
            const std::uint32_t dim3472JoeKuoD6Init[]   =   { 1, 3, 5, 9, 13, 29, 123, 251, 465, 701, 1105, 829, 573, 11503, 11861, 0 };
            const std::uint32_t dim3473JoeKuoD6Init[]   =   { 1, 3, 3, 13, 27, 59, 29, 111, 225, 973, 561, 1481, 835, 9261, 13831, 0 };
            const std::uint32_t dim3474JoeKuoD6Init[]   =   { 1, 1, 1, 7, 17, 3, 97, 211, 333, 315, 571, 3523, 7305, 6461, 20139, 0 };
            const std::uint32_t dim3475JoeKuoD6Init[]   =   { 1, 3, 7, 11, 31, 21, 105, 247, 113, 863, 1767, 381, 4623, 8935, 7911, 0 };
            const std::uint32_t dim3476JoeKuoD6Init[]   =   { 1, 1, 5, 7, 29, 45, 17, 155, 69, 17, 655, 1983, 6385, 6177, 7961, 0 };
            const std::uint32_t dim3477JoeKuoD6Init[]   =   { 1, 3, 3, 15, 31, 15, 63, 81, 309, 115, 393, 3445, 689, 13963, 18887, 0 };
            const std::uint32_t dim3478JoeKuoD6Init[]   =   { 1, 1, 5, 1, 19, 39, 127, 61, 357, 53, 195, 2745, 7853, 5753, 3669, 0 };
            const std::uint32_t dim3479JoeKuoD6Init[]   =   { 1, 3, 7, 7, 17, 51, 57, 145, 451, 365, 1517, 909, 4265, 10737, 9579, 0 };
            const std::uint32_t dim3480JoeKuoD6Init[]   =   { 1, 1, 3, 13, 3, 37, 121, 103, 257, 47, 1685, 2951, 5753, 15379, 8899, 0 };
            const std::uint32_t dim3481JoeKuoD6Init[]   =   { 1, 1, 5, 7, 31, 63, 61, 197, 97, 773, 133, 1517, 3093, 14879, 22941, 0 };
            const std::uint32_t dim3482JoeKuoD6Init[]   =   { 1, 1, 5, 1, 3, 9, 27, 53, 97, 663, 1915, 409, 471, 1391, 24853, 0 };
            const std::uint32_t dim3483JoeKuoD6Init[]   =   { 1, 1, 1, 7, 21, 53, 69, 5, 187, 571, 2023, 997, 323, 12059, 7071, 0 };
            const std::uint32_t dim3484JoeKuoD6Init[]   =   { 1, 3, 3, 1, 7, 59, 55, 157, 101, 123, 1301, 3709, 4673, 3897, 28791, 0 };
            const std::uint32_t dim3485JoeKuoD6Init[]   =   { 1, 3, 7, 5, 5, 23, 39, 139, 365, 415, 1481, 3415, 6323, 11109, 5719, 0 };
            const std::uint32_t dim3486JoeKuoD6Init[]   =   { 1, 3, 5, 3, 5, 11, 23, 143, 243, 229, 183, 3367, 3187, 8151, 28351, 0 };
            const std::uint32_t dim3487JoeKuoD6Init[]   =   { 1, 3, 7, 9, 5, 37, 29, 23, 437, 827, 985, 2879, 7611, 1391, 19087, 0 };
            const std::uint32_t dim3488JoeKuoD6Init[]   =   { 1, 3, 3, 5, 7, 9, 5, 143, 217, 757, 1697, 2459, 453, 8679, 4513, 0 };
            const std::uint32_t dim3489JoeKuoD6Init[]   =   { 1, 3, 5, 5, 11, 33, 3, 143, 293, 921, 185, 2461, 5547, 12247, 28591, 0 };
            const std::uint32_t dim3490JoeKuoD6Init[]   =   { 1, 3, 7, 5, 3, 53, 43, 179, 235, 417, 1307, 1367, 3695, 12809, 1807, 0 };
            const std::uint32_t dim3491JoeKuoD6Init[]   =   { 1, 3, 1, 11, 15, 43, 115, 229, 157, 25, 687, 3347, 271, 5777, 8557, 0 };
            const std::uint32_t dim3492JoeKuoD6Init[]   =   { 1, 3, 7, 5, 27, 37, 55, 135, 209, 47, 1603, 957, 5785, 11141, 10407, 0 };
            const std::uint32_t dim3493JoeKuoD6Init[]   =   { 1, 1, 1, 15, 17, 17, 103, 29, 489, 493, 119, 1707, 3463, 1815, 32055, 0 };
            const std::uint32_t dim3494JoeKuoD6Init[]   =   { 1, 3, 7, 11, 17, 13, 115, 145, 77, 515, 1911, 477, 5997, 8731, 3143, 0 };
            const std::uint32_t dim3495JoeKuoD6Init[]   =   { 1, 3, 1, 13, 31, 41, 73, 91, 231, 1, 455, 2023, 4691, 3613, 16329, 0 };
            const std::uint32_t dim3496JoeKuoD6Init[]   =   { 1, 1, 5, 15, 15, 39, 17, 117, 131, 657, 1939, 2245, 2575, 195, 25209, 0 };
            const std::uint32_t dim3497JoeKuoD6Init[]   =   { 1, 3, 7, 15, 5, 51, 69, 141, 499, 931, 1165, 2119, 1703, 10867, 28443, 0 };
            const std::uint32_t dim3498JoeKuoD6Init[]   =   { 1, 1, 1, 15, 13, 45, 45, 103, 115, 177, 651, 2545, 1417, 5349, 3385, 0 };
            const std::uint32_t dim3499JoeKuoD6Init[]   =   { 1, 3, 3, 1, 1, 41, 117, 15, 225, 861, 843, 2775, 4543, 6275, 14671, 0 };
            const std::uint32_t dim3500JoeKuoD6Init[]   =   { 1, 3, 5, 15, 5, 35, 87, 193, 341, 55, 1131, 945, 6865, 11271, 18705, 0 };
            const std::uint32_t dim3501JoeKuoD6Init[]   =   { 1, 3, 5, 9, 13, 35, 71, 197, 79, 351, 3, 3939, 1105, 12455, 28921, 0 };
            const std::uint32_t dim3502JoeKuoD6Init[]   =   { 1, 3, 1, 13, 9, 23, 89, 165, 59, 257, 1369, 161, 6255, 2997, 19175, 0 };
            const std::uint32_t dim3503JoeKuoD6Init[]   =   { 1, 3, 5, 3, 5, 41, 107, 231, 111, 207, 1865, 2079, 5891, 2487, 5863, 0 };
            const std::uint32_t dim3504JoeKuoD6Init[]   =   { 1, 3, 7, 15, 3, 3, 105, 235, 263, 991, 367, 1885, 1769, 7805, 11909, 0 };
            const std::uint32_t dim3505JoeKuoD6Init[]   =   { 1, 3, 3, 5, 15, 59, 67, 247, 77, 367, 1641, 1959, 1921, 5939, 17355, 0 };
            const std::uint32_t dim3506JoeKuoD6Init[]   =   { 1, 1, 7, 1, 3, 53, 37, 5, 221, 779, 1353, 1633, 2769, 6355, 8505, 0 };
            const std::uint32_t dim3507JoeKuoD6Init[]   =   { 1, 1, 7, 13, 11, 13, 73, 227, 115, 523, 355, 3127, 7545, 8409, 22335, 0 };
            const std::uint32_t dim3508JoeKuoD6Init[]   =   { 1, 1, 5, 11, 21, 15, 91, 115, 427, 683, 461, 2433, 6313, 4595, 24401, 0 };
            const std::uint32_t dim3509JoeKuoD6Init[]   =   { 1, 3, 7, 5, 29, 21, 57, 215, 423, 717, 1455, 705, 6835, 4503, 26077, 0 };
            const std::uint32_t dim3510JoeKuoD6Init[]   =   { 1, 1, 1, 15, 3, 33, 25, 227, 381, 477, 1023, 2751, 2229, 631, 16903, 0 };
            const std::uint32_t dim3511JoeKuoD6Init[]   =   { 1, 3, 1, 11, 9, 17, 59, 73, 53, 671, 251, 1729, 7593, 12473, 22533, 0 };
            const std::uint32_t dim3512JoeKuoD6Init[]   =   { 1, 3, 3, 1, 3, 35, 37, 173, 459, 143, 135, 3871, 2689, 8007, 4379, 0 };
            const std::uint32_t dim3513JoeKuoD6Init[]   =   { 1, 3, 5, 9, 23, 19, 43, 45, 493, 509, 1851, 1615, 5675, 13793, 6973, 0 };
            const std::uint32_t dim3514JoeKuoD6Init[]   =   { 1, 3, 3, 15, 5, 17, 77, 85, 451, 753, 579, 1057, 4851, 6017, 4195, 0 };
            const std::uint32_t dim3515JoeKuoD6Init[]   =   { 1, 3, 3, 5, 31, 29, 81, 159, 103, 391, 15, 899, 4623, 5957, 31961, 0 };
            const std::uint32_t dim3516JoeKuoD6Init[]   =   { 1, 1, 1, 7, 17, 57, 81, 17, 177, 633, 49, 2793, 5229, 5995, 9491, 0 };
            const std::uint32_t dim3517JoeKuoD6Init[]   =   { 1, 1, 7, 15, 17, 19, 65, 57, 189, 239, 1229, 929, 2681, 12845, 29311, 0 };
            const std::uint32_t dim3518JoeKuoD6Init[]   =   { 1, 3, 1, 11, 13, 47, 61, 203, 383, 875, 943, 139, 4217, 8279, 1047, 0 };
            const std::uint32_t dim3519JoeKuoD6Init[]   =   { 1, 3, 7, 13, 23, 7, 1, 69, 47, 537, 1325, 3101, 685, 14057, 19953, 0 };
            const std::uint32_t dim3520JoeKuoD6Init[]   =   { 1, 3, 3, 1, 1, 7, 39, 77, 47, 755, 527, 2985, 5433, 15095, 27741, 0 };
            const std::uint32_t dim3521JoeKuoD6Init[]   =   { 1, 1, 7, 5, 23, 57, 79, 155, 81, 937, 1071, 3929, 1655, 3831, 17351, 0 };
            const std::uint32_t dim3522JoeKuoD6Init[]   =   { 1, 3, 7, 1, 3, 41, 13, 235, 207, 487, 1883, 2247, 1231, 2751, 15615, 0 };
            const std::uint32_t dim3523JoeKuoD6Init[]   =   { 1, 1, 7, 1, 21, 57, 95, 191, 119, 483, 283, 2221, 5665, 14819, 26097, 0 };
            const std::uint32_t dim3524JoeKuoD6Init[]   =   { 1, 3, 1, 1, 9, 59, 27, 51, 393, 31, 925, 715, 7705, 14885, 28767, 0 };
            const std::uint32_t dim3525JoeKuoD6Init[]   =   { 1, 1, 3, 3, 3, 61, 109, 131, 113, 249, 1331, 2521, 2973, 6375, 20093, 0 };
            const std::uint32_t dim3526JoeKuoD6Init[]   =   { 1, 3, 7, 9, 31, 37, 125, 245, 237, 245, 111, 379, 7495, 15531, 2325, 0 };
            const std::uint32_t dim3527JoeKuoD6Init[]   =   { 1, 3, 7, 13, 21, 21, 57, 21, 449, 969, 417, 2999, 509, 639, 7797, 0 };
            const std::uint32_t dim3528JoeKuoD6Init[]   =   { 1, 3, 7, 7, 7, 29, 11, 175, 55, 705, 891, 863, 3021, 10071, 10267, 0 };
            const std::uint32_t dim3529JoeKuoD6Init[]   =   { 1, 1, 3, 13, 19, 17, 127, 57, 449, 579, 337, 899, 1235, 11269, 4245, 0 };
            const std::uint32_t dim3530JoeKuoD6Init[]   =   { 1, 1, 1, 11, 29, 61, 35, 75, 249, 683, 287, 45, 3277, 7521, 2073, 0 };
            const std::uint32_t dim3531JoeKuoD6Init[]   =   { 1, 3, 5, 5, 15, 25, 77, 63, 63, 801, 1387, 1533, 2185, 10899, 28381, 0 };
            const std::uint32_t dim3532JoeKuoD6Init[]   =   { 1, 3, 1, 1, 21, 49, 3, 249, 419, 575, 87, 3749, 2523, 16125, 9483, 0 };
            const std::uint32_t dim3533JoeKuoD6Init[]   =   { 1, 1, 1, 11, 21, 43, 85, 211, 449, 439, 1495, 1841, 4765, 15253, 1467, 0 };
            const std::uint32_t dim3534JoeKuoD6Init[]   =   { 1, 3, 3, 15, 3, 37, 31, 243, 187, 995, 1103, 2723, 1523, 15967, 28649, 0 };
            const std::uint32_t dim3535JoeKuoD6Init[]   =   { 1, 1, 5, 11, 9, 11, 17, 87, 335, 125, 1079, 1657, 1237, 8059, 29833, 0 };
            const std::uint32_t dim3536JoeKuoD6Init[]   =   { 1, 3, 1, 3, 3, 41, 35, 37, 33, 61, 505, 3203, 5, 101, 8571, 0 };
            const std::uint32_t dim3537JoeKuoD6Init[]   =   { 1, 1, 3, 11, 9, 11, 85, 235, 261, 473, 109, 2127, 5745, 6389, 7431, 0 };
            const std::uint32_t dim3538JoeKuoD6Init[]   =   { 1, 1, 5, 15, 3, 55, 77, 97, 17, 193, 1267, 3063, 6531, 9797, 8639, 0 };
            const std::uint32_t dim3539JoeKuoD6Init[]   =   { 1, 1, 5, 5, 25, 41, 79, 83, 485, 697, 149, 1023, 89, 6115, 15227, 0 };
            const std::uint32_t dim3540JoeKuoD6Init[]   =   { 1, 1, 3, 15, 1, 9, 73, 251, 33, 599, 1017, 353, 4305, 16033, 29663, 0 };
            const std::uint32_t dim3541JoeKuoD6Init[]   =   { 1, 3, 7, 15, 3, 1, 89, 39, 125, 337, 1445, 3131, 3685, 9849, 25829, 0 };
            const std::uint32_t dim3542JoeKuoD6Init[]   =   { 1, 3, 7, 3, 19, 1, 63, 179, 349, 135, 185, 2977, 2527, 15087, 18133, 0 };
            const std::uint32_t dim3543JoeKuoD6Init[]   =   { 1, 1, 3, 3, 23, 7, 91, 221, 325, 723, 345, 81, 8077, 5501, 8453, 0 };
            const std::uint32_t dim3544JoeKuoD6Init[]   =   { 1, 1, 3, 9, 7, 3, 13, 173, 479, 161, 1989, 3255, 2069, 6717, 559, 0 };
            const std::uint32_t dim3545JoeKuoD6Init[]   =   { 1, 3, 3, 5, 9, 61, 93, 203, 277, 367, 1141, 981, 4745, 12625, 21003, 0 };
            const std::uint32_t dim3546JoeKuoD6Init[]   =   { 1, 3, 5, 5, 27, 17, 5, 211, 403, 701, 5, 3091, 4611, 5615, 23667, 0 };
            const std::uint32_t dim3547JoeKuoD6Init[]   =   { 1, 1, 3, 1, 21, 61, 125, 77, 57, 463, 1499, 791, 2087, 2805, 18829, 0 };
            const std::uint32_t dim3548JoeKuoD6Init[]   =   { 1, 3, 5, 3, 11, 41, 125, 231, 119, 837, 831, 1331, 7439, 2381, 3759, 0 };
            const std::uint32_t dim3549JoeKuoD6Init[]   =   { 1, 3, 1, 11, 19, 59, 117, 107, 443, 699, 315, 1491, 2581, 15871, 17159, 0 };
            const std::uint32_t dim3550JoeKuoD6Init[]   =   { 1, 3, 5, 11, 5, 9, 121, 35, 209, 877, 527, 3493, 4657, 16093, 17589, 0 };
            const std::uint32_t dim3551JoeKuoD6Init[]   =   { 1, 1, 7, 15, 9, 43, 119, 29, 381, 479, 1443, 3171, 5053, 9625, 21161, 0 };
            const std::uint32_t dim3552JoeKuoD6Init[]   =   { 1, 1, 3, 5, 15, 21, 31, 223, 83, 399, 1529, 3605, 6343, 10469, 10099, 0 };
            const std::uint32_t dim3553JoeKuoD6Init[]   =   { 1, 1, 3, 5, 5, 45, 23, 123, 353, 971, 85, 3069, 3245, 6569, 13241, 0 };
            const std::uint32_t dim3554JoeKuoD6Init[]   =   { 1, 1, 1, 3, 25, 49, 5, 77, 491, 881, 993, 1195, 7677, 5709, 10807, 0 };
            const std::uint32_t dim3555JoeKuoD6Init[]   =   { 1, 3, 3, 3, 5, 49, 127, 255, 183, 583, 1599, 987, 7281, 7149, 28507, 0 };
            const std::uint32_t dim3556JoeKuoD6Init[]   =   { 1, 1, 5, 1, 13, 55, 55, 157, 197, 25, 1971, 3161, 3903, 8919, 13563, 0 };
            const std::uint32_t dim3557JoeKuoD6Init[]   =   { 1, 3, 7, 9, 3, 37, 79, 193, 25, 103, 843, 2651, 6341, 2653, 24337, 0 };
            const std::uint32_t dim3558JoeKuoD6Init[]   =   { 1, 1, 7, 3, 25, 49, 99, 139, 45, 211, 2033, 2331, 7037, 7177, 1755, 0 };
            const std::uint32_t dim3559JoeKuoD6Init[]   =   { 1, 3, 7, 3, 5, 19, 127, 135, 403, 221, 141, 1065, 3935, 2745, 25979, 0 };
            const std::uint32_t dim3560JoeKuoD6Init[]   =   { 1, 1, 3, 3, 31, 23, 111, 37, 261, 7, 835, 2379, 7927, 8181, 23751, 0 };
            const std::uint32_t dim3561JoeKuoD6Init[]   =   { 1, 3, 7, 15, 1, 39, 79, 3, 103, 427, 1917, 809, 5039, 689, 1939, 0 };
            const std::uint32_t dim3562JoeKuoD6Init[]   =   { 1, 1, 1, 15, 29, 37, 39, 243, 149, 353, 763, 3405, 5751, 9441, 6653, 0 };
            const std::uint32_t dim3563JoeKuoD6Init[]   =   { 1, 3, 3, 11, 1, 57, 125, 151, 445, 423, 841, 2265, 5017, 15863, 13057, 0 };
            const std::uint32_t dim3564JoeKuoD6Init[]   =   { 1, 3, 5, 13, 11, 49, 61, 159, 211, 917, 561, 1903, 3985, 11117, 28969, 0 };
            const std::uint32_t dim3565JoeKuoD6Init[]   =   { 1, 3, 5, 13, 29, 5, 35, 51, 91, 291, 9, 3713, 3341, 4551, 12085, 0 };
            const std::uint32_t dim3566JoeKuoD6Init[]   =   { 1, 3, 3, 1, 1, 39, 111, 141, 319, 179, 1709, 1605, 5063, 13279, 10003, 0 };
            const std::uint32_t dim3567JoeKuoD6Init[]   =   { 1, 1, 3, 9, 7, 59, 91, 41, 343, 475, 1669, 2311, 5141, 12661, 25847, 0 };
            const std::uint32_t dim3568JoeKuoD6Init[]   =   { 1, 3, 5, 9, 9, 11, 49, 221, 1, 243, 791, 229, 503, 373, 19189, 0 };
            const std::uint32_t dim3569JoeKuoD6Init[]   =   { 1, 1, 5, 11, 17, 13, 45, 57, 215, 491, 1601, 2183, 3713, 429, 22007, 0 };
            const std::uint32_t dim3570JoeKuoD6Init[]   =   { 1, 1, 3, 11, 31, 61, 23, 237, 261, 955, 1085, 1541, 2601, 909, 7749, 0 };
            const std::uint32_t dim3571JoeKuoD6Init[]   =   { 1, 1, 3, 9, 13, 11, 121, 173, 177, 551, 1757, 2745, 2265, 4611, 743, 0 };
            const std::uint32_t dim3572JoeKuoD6Init[]   =   { 1, 1, 3, 15, 23, 43, 107, 239, 463, 369, 1857, 1073, 1247, 1029, 22557, 0 };
            const std::uint32_t dim3573JoeKuoD6Init[]   =   { 1, 1, 3, 11, 23, 35, 89, 93, 41, 941, 1141, 2339, 1423, 8007, 28685, 0 };
            const std::uint32_t dim3574JoeKuoD6Init[]   =   { 1, 3, 5, 13, 29, 7, 79, 15, 59, 145, 1237, 2215, 1257, 12621, 31101, 0 };
            const std::uint32_t dim3575JoeKuoD6Init[]   =   { 1, 1, 3, 7, 13, 55, 57, 229, 205, 1009, 341, 3901, 5189, 957, 32587, 0 };
            const std::uint32_t dim3576JoeKuoD6Init[]   =   { 1, 3, 7, 11, 1, 1, 41, 7, 365, 407, 1609, 1423, 6483, 5171, 32519, 0 };
            const std::uint32_t dim3577JoeKuoD6Init[]   =   { 1, 3, 7, 3, 17, 31, 125, 27, 125, 335, 1395, 2639, 329, 2549, 14449, 0 };
            const std::uint32_t dim3578JoeKuoD6Init[]   =   { 1, 3, 3, 7, 19, 45, 11, 73, 123, 179, 1685, 3385, 2379, 3387, 16793, 0 };
            const std::uint32_t dim3579JoeKuoD6Init[]   =   { 1, 3, 7, 5, 31, 25, 47, 153, 121, 453, 935, 3953, 2081, 12145, 24979, 0 };
            const std::uint32_t dim3580JoeKuoD6Init[]   =   { 1, 1, 7, 13, 25, 11, 65, 3, 277, 237, 1129, 1801, 4165, 9065, 18747, 0 };
            const std::uint32_t dim3581JoeKuoD6Init[]   =   { 1, 1, 7, 7, 13, 5, 37, 253, 507, 645, 1355, 3401, 6707, 6329, 11237, 0 };
            const std::uint32_t dim3582JoeKuoD6Init[]   =   { 1, 1, 3, 15, 17, 49, 3, 233, 407, 451, 69, 3859, 3171, 12303, 21031, 0 };
            const std::uint32_t dim3583JoeKuoD6Init[]   =   { 1, 1, 3, 3, 9, 53, 119, 117, 401, 903, 1449, 3639, 4083, 2095, 22085, 0 };
            const std::uint32_t dim3584JoeKuoD6Init[]   =   { 1, 3, 7, 15, 5, 61, 117, 193, 137, 431, 195, 4019, 3047, 5049, 14281, 0 };
            const std::uint32_t dim3585JoeKuoD6Init[]   =   { 1, 1, 1, 15, 17, 19, 29, 83, 449, 257, 1105, 1949, 1749, 3459, 6343, 0 };
            const std::uint32_t dim3586JoeKuoD6Init[]   =   { 1, 1, 1, 15, 23, 39, 61, 219, 109, 365, 863, 1813, 6673, 15999, 5101, 0 };
            const std::uint32_t dim3587JoeKuoD6Init[]   =   { 1, 1, 5, 5, 13, 11, 37, 151, 365, 719, 1233, 2425, 1285, 1721, 1205, 0 };
            const std::uint32_t dim3588JoeKuoD6Init[]   =   { 1, 3, 3, 3, 7, 53, 109, 153, 45, 425, 1741, 1229, 4405, 8071, 25155, 0 };
            const std::uint32_t dim3589JoeKuoD6Init[]   =   { 1, 3, 1, 1, 1, 13, 39, 49, 413, 77, 1367, 2553, 5563, 7659, 3467, 0 };
            const std::uint32_t dim3590JoeKuoD6Init[]   =   { 1, 1, 5, 9, 3, 49, 23, 11, 445, 121, 1505, 877, 4137, 1809, 2429, 0 };
            const std::uint32_t dim3591JoeKuoD6Init[]   =   { 1, 1, 1, 11, 21, 13, 93, 33, 493, 805, 775, 2939, 2961, 13625, 31879, 0 };
            const std::uint32_t dim3592JoeKuoD6Init[]   =   { 1, 1, 7, 5, 1, 59, 63, 131, 373, 23, 337, 2107, 5315, 4889, 22851, 0 };
            const std::uint32_t dim3593JoeKuoD6Init[]   =   { 1, 1, 3, 13, 21, 47, 15, 131, 353, 793, 1891, 1757, 5793, 1147, 23697, 0 };
            const std::uint32_t dim3594JoeKuoD6Init[]   =   { 1, 3, 5, 13, 7, 59, 25, 135, 259, 109, 1835, 429, 8153, 7355, 145, 0 };
            const std::uint32_t dim3595JoeKuoD6Init[]   =   { 1, 3, 3, 13, 9, 47, 121, 89, 89, 635, 1079, 2353, 4803, 11369, 12653, 0 };
            const std::uint32_t dim3596JoeKuoD6Init[]   =   { 1, 3, 5, 9, 23, 39, 49, 231, 105, 603, 613, 2021, 6073, 11819, 10595, 0 };
            const std::uint32_t dim3597JoeKuoD6Init[]   =   { 1, 3, 7, 7, 7, 19, 19, 155, 347, 387, 1459, 3793, 619, 14437, 2455, 0 };
            const std::uint32_t dim3598JoeKuoD6Init[]   =   { 1, 1, 1, 15, 21, 35, 19, 185, 483, 425, 479, 3429, 5403, 10791, 14219, 0 };
            const std::uint32_t dim3599JoeKuoD6Init[]   =   { 1, 1, 3, 11, 5, 51, 105, 63, 493, 677, 1457, 2865, 5619, 9321, 19583, 0 };
            const std::uint32_t dim3600JoeKuoD6Init[]   =   { 1, 1, 3, 3, 23, 1, 77, 177, 263, 289, 1567, 3837, 5359, 3269, 16023, 0 };
            const std::uint32_t dim3601JoeKuoD6Init[]   =   { 1, 1, 7, 3, 13, 61, 79, 77, 51, 953, 1417, 795, 4467, 2981, 25131, 0 };
            const std::uint32_t dim3602JoeKuoD6Init[]   =   { 1, 1, 5, 13, 23, 13, 29, 185, 337, 7, 149, 3609, 8119, 9545, 16579, 0 };
            const std::uint32_t dim3603JoeKuoD6Init[]   =   { 1, 3, 1, 5, 23, 9, 123, 15, 99, 55, 1021, 3709, 1521, 15189, 22193, 0 };
            const std::uint32_t dim3604JoeKuoD6Init[]   =   { 1, 3, 7, 9, 13, 41, 39, 45, 49, 181, 1587, 3213, 1037, 14775, 3333, 0 };
            const std::uint32_t dim3605JoeKuoD6Init[]   =   { 1, 1, 1, 7, 29, 55, 59, 31, 411, 601, 191, 283, 3211, 7951, 7919, 0 };
            const std::uint32_t dim3606JoeKuoD6Init[]   =   { 1, 1, 7, 7, 21, 47, 7, 193, 343, 831, 1267, 3289, 1015, 13093, 2717, 0 };
            const std::uint32_t dim3607JoeKuoD6Init[]   =   { 1, 3, 7, 1, 17, 9, 97, 19, 279, 827, 1699, 3573, 3137, 3535, 17791, 0 };
            const std::uint32_t dim3608JoeKuoD6Init[]   =   { 1, 1, 5, 11, 27, 15, 103, 135, 35, 625, 1575, 97, 7013, 13353, 19333, 0 };
            const std::uint32_t dim3609JoeKuoD6Init[]   =   { 1, 3, 3, 7, 17, 13, 49, 135, 435, 743, 1799, 2655, 4839, 2893, 31153, 0 };
            const std::uint32_t dim3610JoeKuoD6Init[]   =   { 1, 1, 5, 1, 3, 41, 1, 195, 53, 803, 1575, 2939, 3873, 10495, 5211, 0 };
            const std::uint32_t dim3611JoeKuoD6Init[]   =   { 1, 3, 1, 15, 19, 19, 37, 59, 355, 483, 685, 3899, 4645, 15127, 3479, 0 };
            const std::uint32_t dim3612JoeKuoD6Init[]   =   { 1, 1, 5, 3, 25, 9, 9, 229, 101, 631, 1165, 4091, 3723, 10655, 9463, 0 };
            const std::uint32_t dim3613JoeKuoD6Init[]   =   { 1, 3, 5, 15, 5, 13, 91, 61, 19, 469, 1675, 3331, 3121, 3435, 4111, 0 };
            const std::uint32_t dim3614JoeKuoD6Init[]   =   { 1, 1, 7, 1, 31, 61, 23, 83, 165, 551, 1097, 3825, 5385, 4723, 3635, 0 };
            const std::uint32_t dim3615JoeKuoD6Init[]   =   { 1, 3, 7, 15, 9, 31, 11, 121, 503, 855, 561, 1647, 1229, 1147, 15997, 0 };
            const std::uint32_t dim3616JoeKuoD6Init[]   =   { 1, 3, 7, 13, 21, 47, 41, 195, 197, 719, 1263, 3609, 7515, 2659, 30713, 0 };
            const std::uint32_t dim3617JoeKuoD6Init[]   =   { 1, 1, 1, 7, 31, 61, 101, 101, 479, 571, 605, 301, 6633, 15587, 23665, 0 };
            const std::uint32_t dim3618JoeKuoD6Init[]   =   { 1, 3, 7, 3, 25, 39, 35, 225, 135, 463, 53, 709, 5129, 4135, 10421, 0 };
            const std::uint32_t dim3619JoeKuoD6Init[]   =   { 1, 1, 5, 13, 19, 55, 107, 15, 163, 287, 673, 899, 5197, 4619, 3465, 0 };
            const std::uint32_t dim3620JoeKuoD6Init[]   =   { 1, 3, 3, 5, 21, 49, 15, 105, 283, 877, 1875, 1079, 3431, 13053, 26599, 0 };
            const std::uint32_t dim3621JoeKuoD6Init[]   =   { 1, 1, 7, 1, 1, 1, 95, 113, 119, 575, 1159, 2325, 6895, 12177, 4369, 0 };
            const std::uint32_t dim3622JoeKuoD6Init[]   =   { 1, 1, 1, 11, 25, 25, 83, 207, 301, 729, 1947, 2321, 3621, 15707, 11303, 0 };
            const std::uint32_t dim3623JoeKuoD6Init[]   =   { 1, 1, 5, 5, 7, 63, 83, 105, 211, 175, 1817, 2883, 5385, 7437, 24865, 0 };
            const std::uint32_t dim3624JoeKuoD6Init[]   =   { 1, 3, 7, 5, 23, 39, 19, 211, 151, 295, 573, 223, 5065, 6345, 23187, 0 };
            const std::uint32_t dim3625JoeKuoD6Init[]   =   { 1, 1, 7, 11, 15, 31, 89, 123, 57, 695, 685, 1799, 659, 9929, 22933, 0 };
            const std::uint32_t dim3626JoeKuoD6Init[]   =   { 1, 1, 7, 7, 19, 17, 27, 137, 117, 141, 1481, 869, 7061, 3073, 19671, 0 };
            const std::uint32_t dim3627JoeKuoD6Init[]   =   { 1, 3, 3, 11, 9, 19, 123, 93, 39, 517, 883, 3769, 2267, 8089, 6617, 0 };
            const std::uint32_t dim3628JoeKuoD6Init[]   =   { 1, 3, 1, 7, 9, 61, 51, 241, 319, 853, 1239, 899, 105, 1677, 29351, 0 };
            const std::uint32_t dim3629JoeKuoD6Init[]   =   { 1, 1, 7, 15, 13, 59, 85, 175, 223, 87, 905, 3175, 3405, 3489, 18475, 0 };
            const std::uint32_t dim3630JoeKuoD6Init[]   =   { 1, 1, 1, 15, 1, 55, 79, 97, 315, 605, 851, 4015, 3689, 9371, 31523, 0 };
            const std::uint32_t dim3631JoeKuoD6Init[]   =   { 1, 1, 5, 15, 1, 39, 91, 27, 211, 881, 1375, 2307, 5791, 10185, 23093, 0 };
            const std::uint32_t dim3632JoeKuoD6Init[]   =   { 1, 3, 1, 5, 3, 17, 59, 219, 105, 623, 21, 2843, 3427, 4799, 3793, 0 };
            const std::uint32_t dim3633JoeKuoD6Init[]   =   { 1, 3, 3, 7, 21, 55, 17, 29, 397, 93, 1981, 4047, 935, 5971, 14589, 0 };
            const std::uint32_t dim3634JoeKuoD6Init[]   =   { 1, 1, 3, 9, 5, 57, 63, 27, 373, 815, 167, 205, 367, 4945, 30041, 0 };
            const std::uint32_t dim3635JoeKuoD6Init[]   =   { 1, 1, 5, 9, 7, 3, 69, 35, 197, 309, 1729, 3735, 1523, 10427, 26253, 0 };
            const std::uint32_t dim3636JoeKuoD6Init[]   =   { 1, 1, 3, 7, 7, 49, 35, 189, 297, 311, 2025, 305, 3863, 14393, 2533, 0 };
            const std::uint32_t dim3637JoeKuoD6Init[]   =   { 1, 3, 3, 9, 17, 31, 5, 17, 167, 601, 909, 3149, 2533, 12123, 25325, 0 };
            const std::uint32_t dim3638JoeKuoD6Init[]   =   { 1, 3, 5, 3, 11, 41, 69, 199, 79, 611, 133, 3519, 5955, 4609, 27403, 0 };
            const std::uint32_t dim3639JoeKuoD6Init[]   =   { 1, 3, 3, 13, 3, 17, 53, 165, 361, 797, 1447, 869, 6707, 6541, 32249, 0 };
            const std::uint32_t dim3640JoeKuoD6Init[]   =   { 1, 3, 1, 1, 29, 47, 17, 45, 473, 199, 1595, 3095, 3635, 6965, 21859, 0 };
            const std::uint32_t dim3641JoeKuoD6Init[]   =   { 1, 1, 3, 9, 1, 15, 59, 163, 91, 811, 1087, 1707, 6743, 12643, 29901, 0 };
            const std::uint32_t dim3642JoeKuoD6Init[]   =   { 1, 1, 1, 3, 19, 21, 7, 209, 121, 821, 709, 1085, 5333, 7689, 28355, 0 };
            const std::uint32_t dim3643JoeKuoD6Init[]   =   { 1, 3, 1, 15, 5, 27, 115, 31, 37, 79, 1347, 155, 3709, 13251, 32151, 0 };
            const std::uint32_t dim3644JoeKuoD6Init[]   =   { 1, 3, 7, 15, 27, 27, 127, 231, 137, 205, 1665, 1461, 299, 2797, 879, 0 };
            const std::uint32_t dim3645JoeKuoD6Init[]   =   { 1, 1, 1, 7, 13, 3, 127, 13, 253, 481, 1435, 1895, 2665, 7611, 17761, 0 };
            const std::uint32_t dim3646JoeKuoD6Init[]   =   { 1, 1, 3, 7, 7, 21, 71, 247, 301, 183, 1785, 331, 4835, 2251, 4493, 0 };
            const std::uint32_t dim3647JoeKuoD6Init[]   =   { 1, 3, 7, 9, 9, 1, 77, 169, 103, 647, 1959, 1847, 5803, 3421, 15915, 0 };
            const std::uint32_t dim3648JoeKuoD6Init[]   =   { 1, 3, 1, 7, 19, 17, 81, 45, 263, 549, 1607, 2177, 1117, 14427, 16451, 0 };
            const std::uint32_t dim3649JoeKuoD6Init[]   =   { 1, 1, 7, 15, 27, 25, 27, 27, 33, 813, 1667, 253, 2749, 927, 29707, 0 };
            const std::uint32_t dim3650JoeKuoD6Init[]   =   { 1, 1, 7, 3, 17, 29, 13, 67, 417, 303, 19, 3809, 7225, 12775, 3933, 0 };
            const std::uint32_t dim3651JoeKuoD6Init[]   =   { 1, 1, 1, 11, 13, 41, 77, 217, 281, 659, 1099, 3047, 1619, 525, 4313, 0 };
            const std::uint32_t dim3652JoeKuoD6Init[]   =   { 1, 3, 3, 9, 23, 47, 5, 33, 219, 531, 77, 2307, 1893, 8335, 8281, 0 };
            const std::uint32_t dim3653JoeKuoD6Init[]   =   { 1, 3, 7, 3, 3, 35, 27, 249, 159, 495, 431, 3001, 1475, 11505, 15693, 0 };
            const std::uint32_t dim3654JoeKuoD6Init[]   =   { 1, 1, 5, 9, 21, 49, 43, 159, 465, 959, 179, 993, 121, 11569, 21027, 0 };
            const std::uint32_t dim3655JoeKuoD6Init[]   =   { 1, 3, 1, 5, 1, 61, 9, 221, 231, 55, 191, 2829, 3331, 8911, 15109, 0 };
            const std::uint32_t dim3656JoeKuoD6Init[]   =   { 1, 1, 7, 1, 7, 35, 67, 97, 159, 191, 935, 3151, 6397, 10751, 1835, 0 };
            const std::uint32_t dim3657JoeKuoD6Init[]   =   { 1, 1, 1, 7, 15, 39, 127, 163, 437, 333, 829, 753, 8151, 13239, 523, 0 };
            const std::uint32_t dim3658JoeKuoD6Init[]   =   { 1, 1, 3, 13, 9, 25, 73, 155, 445, 239, 2035, 15, 5243, 15531, 1733, 0 };
            const std::uint32_t dim3659JoeKuoD6Init[]   =   { 1, 3, 7, 15, 5, 25, 3, 55, 117, 57, 783, 1509, 7043, 13159, 8557, 0 };
            const std::uint32_t dim3660JoeKuoD6Init[]   =   { 1, 3, 5, 1, 21, 55, 89, 119, 199, 79, 161, 1597, 3263, 3335, 5757, 0 };
            const std::uint32_t dim3661JoeKuoD6Init[]   =   { 1, 3, 7, 5, 27, 23, 85, 113, 111, 211, 389, 1513, 2759, 7945, 931, 0 };
            const std::uint32_t dim3662JoeKuoD6Init[]   =   { 1, 1, 1, 7, 1, 5, 17, 177, 357, 619, 5, 2583, 621, 2973, 28845, 0 };
            const std::uint32_t dim3663JoeKuoD6Init[]   =   { 1, 3, 7, 13, 11, 21, 47, 99, 421, 279, 1541, 1305, 4571, 6127, 20735, 0 };
            const std::uint32_t dim3664JoeKuoD6Init[]   =   { 1, 3, 5, 5, 23, 43, 19, 137, 425, 409, 1625, 2671, 4385, 3197, 25753, 0 };
            const std::uint32_t dim3665JoeKuoD6Init[]   =   { 1, 1, 7, 5, 27, 17, 57, 15, 383, 181, 951, 2115, 5237, 1495, 9671, 0 };
            const std::uint32_t dim3666JoeKuoD6Init[]   =   { 1, 3, 3, 11, 9, 1, 53, 127, 375, 499, 1487, 121, 1465, 3175, 24337, 0 };
            const std::uint32_t dim3667JoeKuoD6Init[]   =   { 1, 3, 7, 11, 29, 35, 67, 129, 221, 439, 1159, 3501, 7741, 8885, 11381, 20707, 0 };
            const std::uint32_t dim3668JoeKuoD6Init[]   =   { 1, 3, 5, 11, 29, 59, 23, 117, 343, 637, 1825, 1687, 2823, 11641, 3311, 23603, 0 };
            const std::uint32_t dim3669JoeKuoD6Init[]   =   { 1, 1, 5, 11, 1, 35, 103, 155, 233, 575, 1761, 503, 4175, 6105, 29737, 32681, 0 };
            const std::uint32_t dim3670JoeKuoD6Init[]   =   { 1, 3, 3, 1, 5, 63, 27, 71, 245, 433, 1779, 2475, 5479, 4705, 10795, 34247, 0 };
            const std::uint32_t dim3671JoeKuoD6Init[]   =   { 1, 3, 5, 7, 29, 45, 117, 5, 393, 849, 843, 3131, 6995, 9979, 28907, 30115, 0 };
            const std::uint32_t dim3672JoeKuoD6Init[]   =   { 1, 3, 5, 9, 27, 29, 69, 5, 395, 561, 1531, 409, 2779, 8785, 16405, 27315, 0 };
            const std::uint32_t dim3673JoeKuoD6Init[]   =   { 1, 3, 1, 9, 15, 29, 85, 3, 331, 19, 1941, 567, 6957, 747, 1627, 11347, 0 };
            const std::uint32_t dim3674JoeKuoD6Init[]   =   { 1, 1, 3, 9, 27, 45, 47, 127, 133, 921, 1817, 2231, 6333, 14371, 12799, 9831, 0 };
            const std::uint32_t dim3675JoeKuoD6Init[]   =   { 1, 1, 5, 15, 31, 7, 125, 13, 455, 159, 331, 3629, 4705, 11261, 3657, 36307, 0 };
            const std::uint32_t dim3676JoeKuoD6Init[]   =   { 1, 1, 5, 9, 11, 53, 51, 35, 87, 885, 1975, 3899, 1013, 7667, 32385, 33635, 0 };
            const std::uint32_t dim3677JoeKuoD6Init[]   =   { 1, 1, 1, 3, 7, 45, 107, 177, 193, 765, 731, 139, 5563, 623, 16485, 54999, 0 };
            const std::uint32_t dim3678JoeKuoD6Init[]   =   { 1, 1, 5, 9, 17, 53, 117, 69, 385, 587, 1483, 149, 2769, 3013, 18183, 10173, 0 };
            const std::uint32_t dim3679JoeKuoD6Init[]   =   { 1, 1, 5, 11, 5, 3, 25, 153, 351, 749, 801, 3077, 3209, 11189, 25241, 14115, 0 };
            const std::uint32_t dim3680JoeKuoD6Init[]   =   { 1, 1, 7, 9, 1, 47, 41, 247, 135, 163, 899, 1517, 5647, 10595, 32531, 12497, 0 };
            const std::uint32_t dim3681JoeKuoD6Init[]   =   { 1, 3, 5, 11, 5, 61, 111, 215, 251, 279, 825, 2155, 3527, 173, 10973, 59257, 0 };
            const std::uint32_t dim3682JoeKuoD6Init[]   =   { 1, 3, 5, 11, 25, 15, 71, 83, 135, 231, 1415, 3761, 7513, 8337, 28979, 43615, 0 };
            const std::uint32_t dim3683JoeKuoD6Init[]   =   { 1, 3, 5, 13, 19, 5, 55, 165, 141, 119, 1891, 2255, 4735, 16217, 26195, 50527, 0 };
            const std::uint32_t dim3684JoeKuoD6Init[]   =   { 1, 1, 7, 15, 23, 59, 59, 191, 1, 855, 453, 2619, 5013, 14749, 24335, 44339, 0 };
            const std::uint32_t dim3685JoeKuoD6Init[]   =   { 1, 1, 1, 13, 15, 41, 51, 147, 229, 495, 1191, 867, 1525, 581, 29713, 26391, 0 };
            const std::uint32_t dim3686JoeKuoD6Init[]   =   { 1, 1, 1, 9, 29, 5, 59, 127, 105, 417, 301, 2249, 6335, 3513, 17373, 52977, 0 };
            const std::uint32_t dim3687JoeKuoD6Init[]   =   { 1, 1, 3, 7, 21, 27, 109, 143, 63, 347, 1429, 2889, 2597, 10243, 9913, 22687, 0 };
            const std::uint32_t dim3688JoeKuoD6Init[]   =   { 1, 3, 5, 5, 7, 3, 125, 147, 313, 351, 1163, 415, 5615, 5571, 7089, 55621, 0 };
            const std::uint32_t dim3689JoeKuoD6Init[]   =   { 1, 3, 3, 3, 31, 43, 101, 93, 9, 671, 135, 333, 2169, 11169, 7403, 50707, 0 };
            const std::uint32_t dim3690JoeKuoD6Init[]   =   { 1, 1, 7, 13, 15, 33, 125, 155, 227, 827, 1047, 2441, 3007, 10881, 19969, 63805, 0 };
            const std::uint32_t dim3691JoeKuoD6Init[]   =   { 1, 3, 3, 5, 31, 33, 29, 249, 159, 797, 1475, 841, 6933, 6417, 25629, 61865, 0 };
            const std::uint32_t dim3692JoeKuoD6Init[]   =   { 1, 3, 3, 15, 11, 55, 11, 117, 149, 911, 1589, 3133, 6477, 6123, 10471, 41099, 0 };
            const std::uint32_t dim3693JoeKuoD6Init[]   =   { 1, 3, 3, 9, 27, 37, 1, 119, 509, 969, 831, 3771, 2093, 13621, 31737, 43269, 0 };
            const std::uint32_t dim3694JoeKuoD6Init[]   =   { 1, 1, 1, 1, 9, 23, 119, 109, 487, 753, 1673, 2163, 3349, 4741, 29971, 3407, 0 };
            const std::uint32_t dim3695JoeKuoD6Init[]   =   { 1, 3, 3, 7, 25, 7, 67, 9, 461, 631, 651, 2271, 5663, 2621, 3953, 20975, 0 };
            const std::uint32_t dim3696JoeKuoD6Init[]   =   { 1, 1, 5, 11, 13, 31, 29, 255, 371, 517, 845, 3649, 1187, 10061, 22887, 58417, 0 };
            const std::uint32_t dim3697JoeKuoD6Init[]   =   { 1, 3, 5, 13, 29, 1, 11, 137, 151, 249, 167, 1243, 997, 11023, 11875, 42315, 0 };
            const std::uint32_t dim3698JoeKuoD6Init[]   =   { 1, 1, 5, 5, 5, 55, 103, 71, 255, 1023, 209, 1005, 2147, 11527, 17863, 6661, 0 };
            const std::uint32_t dim3699JoeKuoD6Init[]   =   { 1, 1, 3, 3, 31, 39, 7, 151, 353, 775, 1313, 1257, 4197, 2625, 9571, 27269, 0 };
            const std::uint32_t dim3700JoeKuoD6Init[]   =   { 1, 1, 1, 3, 7, 17, 3, 127, 501, 503, 1879, 2329, 3049, 10603, 2111, 33189, 0 };
            const std::uint32_t dim3701JoeKuoD6Init[]   =   { 1, 3, 3, 7, 13, 59, 93, 13, 375, 483, 1991, 2257, 3003, 1699, 4339, 51827, 0 };
            const std::uint32_t dim3702JoeKuoD6Init[]   =   { 1, 3, 7, 15, 27, 41, 59, 225, 405, 807, 1545, 2581, 1173, 14137, 3413, 39299, 0 };
            const std::uint32_t dim3703JoeKuoD6Init[]   =   { 1, 1, 1, 3, 9, 23, 37, 123, 465, 1023, 1065, 1455, 5107, 3839, 20451, 11461, 0 };
            const std::uint32_t dim3704JoeKuoD6Init[]   =   { 1, 1, 1, 11, 19, 55, 91, 121, 317, 199, 215, 3031, 7223, 11891, 21463, 64921, 0 };
            const std::uint32_t dim3705JoeKuoD6Init[]   =   { 1, 3, 7, 11, 19, 5, 5, 115, 399, 219, 71, 1465, 281, 14451, 26807, 42541, 0 };
            const std::uint32_t dim3706JoeKuoD6Init[]   =   { 1, 3, 5, 13, 3, 33, 75, 35, 19, 559, 761, 947, 7479, 15325, 31453, 20561, 0 };
            const std::uint32_t dim3707JoeKuoD6Init[]   =   { 1, 3, 3, 13, 23, 47, 99, 73, 331, 353, 401, 1737, 6235, 13781, 5547, 56443, 0 };
            const std::uint32_t dim3708JoeKuoD6Init[]   =   { 1, 3, 3, 13, 21, 37, 41, 205, 87, 399, 51, 3175, 7403, 12875, 21129, 7079, 0 };
            const std::uint32_t dim3709JoeKuoD6Init[]   =   { 1, 3, 5, 11, 15, 47, 33, 39, 465, 871, 277, 2351, 695, 1953, 24293, 20595, 0 };
            const std::uint32_t dim3710JoeKuoD6Init[]   =   { 1, 1, 7, 11, 13, 15, 115, 59, 469, 715, 191, 1927, 905, 13463, 29005, 46789, 0 };
            const std::uint32_t dim3711JoeKuoD6Init[]   =   { 1, 3, 5, 9, 13, 55, 79, 17, 265, 887, 905, 3985, 6907, 3379, 20055, 58569, 0 };
            const std::uint32_t dim3712JoeKuoD6Init[]   =   { 1, 1, 7, 11, 21, 29, 23, 109, 17, 427, 1623, 2219, 3857, 3709, 25033, 63823, 0 };
            const std::uint32_t dim3713JoeKuoD6Init[]   =   { 1, 3, 5, 15, 19, 27, 113, 15, 25, 63, 1885, 2693, 5301, 9385, 14137, 26097, 0 };
            const std::uint32_t dim3714JoeKuoD6Init[]   =   { 1, 3, 3, 11, 17, 5, 73, 143, 79, 957, 461, 1709, 4909, 2285, 18113, 8401, 0 };
            const std::uint32_t dim3715JoeKuoD6Init[]   =   { 1, 1, 3, 7, 9, 9, 101, 127, 137, 755, 1359, 1965, 83, 13335, 27763, 7941, 0 };
            const std::uint32_t dim3716JoeKuoD6Init[]   =   { 1, 1, 1, 3, 13, 61, 95, 61, 295, 615, 555, 2163, 8155, 14043, 21465, 46741, 0 };
            const std::uint32_t dim3717JoeKuoD6Init[]   =   { 1, 1, 1, 13, 29, 19, 111, 17, 373, 153, 1703, 2199, 7209, 15845, 1879, 7493, 0 };
            const std::uint32_t dim3718JoeKuoD6Init[]   =   { 1, 3, 1, 13, 21, 51, 49, 51, 255, 151, 207, 1915, 7629, 2705, 8739, 7467, 0 };
            const std::uint32_t dim3719JoeKuoD6Init[]   =   { 1, 3, 7, 5, 21, 21, 23, 193, 467, 739, 519, 2315, 2953, 10633, 9163, 6007, 0 };
            const std::uint32_t dim3720JoeKuoD6Init[]   =   { 1, 3, 1, 5, 23, 19, 23, 247, 93, 297, 1089, 2349, 4683, 13609, 7615, 18647, 0 };
            const std::uint32_t dim3721JoeKuoD6Init[]   =   { 1, 1, 3, 3, 21, 39, 19, 71, 93, 1, 133, 3531, 7503, 2819, 24211, 1739, 0 };
            const std::uint32_t dim3722JoeKuoD6Init[]   =   { 1, 3, 5, 13, 9, 43, 31, 111, 493, 739, 705, 2715, 3613, 11877, 27945, 46053, 0 };
            const std::uint32_t dim3723JoeKuoD6Init[]   =   { 1, 1, 7, 13, 27, 59, 103, 129, 53, 531, 1379, 1441, 5341, 14937, 5079, 39881, 0 };
            const std::uint32_t dim3724JoeKuoD6Init[]   =   { 1, 1, 3, 3, 11, 63, 91, 95, 433, 393, 715, 809, 591, 4141, 17417, 54107, 0 };
            const std::uint32_t dim3725JoeKuoD6Init[]   =   { 1, 3, 5, 1, 7, 25, 25, 175, 205, 803, 183, 1441, 1279, 2753, 20001, 56677, 0 };
            const std::uint32_t dim3726JoeKuoD6Init[]   =   { 1, 1, 5, 3, 13, 23, 77, 25, 133, 137, 1907, 1313, 2463, 14339, 13, 57757, 0 };
            const std::uint32_t dim3727JoeKuoD6Init[]   =   { 1, 1, 5, 9, 23, 35, 1, 119, 111, 61, 403, 1815, 1985, 5651, 10883, 55943, 0 };
            const std::uint32_t dim3728JoeKuoD6Init[]   =   { 1, 3, 1, 7, 21, 43, 115, 7, 107, 719, 759, 1521, 467, 8735, 29785, 63821, 0 };
            const std::uint32_t dim3729JoeKuoD6Init[]   =   { 1, 1, 3, 13, 19, 17, 51, 141, 399, 569, 703, 2221, 2809, 13355, 1907, 15837, 0 };
            const std::uint32_t dim3730JoeKuoD6Init[]   =   { 1, 1, 5, 15, 15, 53, 57, 31, 481, 69, 1439, 4049, 6727, 11307, 20683, 63517, 0 };
            const std::uint32_t dim3731JoeKuoD6Init[]   =   { 1, 1, 1, 3, 13, 27, 9, 255, 363, 131, 1745, 2489, 6451, 6585, 12873, 35405, 0 };
            const std::uint32_t dim3732JoeKuoD6Init[]   =   { 1, 3, 5, 1, 17, 31, 113, 135, 449, 915, 1017, 2317, 6821, 5483, 30707, 45279, 0 };
            const std::uint32_t dim3733JoeKuoD6Init[]   =   { 1, 3, 5, 1, 13, 47, 25, 53, 413, 545, 1777, 3049, 7527, 9689, 25935, 9919, 0 };
            const std::uint32_t dim3734JoeKuoD6Init[]   =   { 1, 3, 7, 11, 17, 39, 13, 131, 295, 517, 1755, 2977, 6267, 12351, 8957, 17765, 0 };
            const std::uint32_t dim3735JoeKuoD6Init[]   =   { 1, 1, 7, 5, 27, 57, 47, 21, 125, 429, 1169, 1717, 5455, 16359, 29065, 6671, 0 };
            const std::uint32_t dim3736JoeKuoD6Init[]   =   { 1, 1, 5, 5, 21, 15, 79, 241, 83, 515, 859, 2351, 3125, 7465, 30475, 19759, 0 };
            const std::uint32_t dim3737JoeKuoD6Init[]   =   { 1, 3, 1, 9, 11, 5, 81, 11, 7, 221, 141, 3329, 3435, 323, 18999, 54735, 0 };
            const std::uint32_t dim3738JoeKuoD6Init[]   =   { 1, 1, 1, 15, 7, 57, 87, 251, 63, 561, 929, 1367, 2511, 14527, 9335, 38775, 0 };
            const std::uint32_t dim3739JoeKuoD6Init[]   =   { 1, 3, 3, 9, 23, 37, 59, 105, 179, 515, 235, 2445, 433, 13039, 27005, 48829, 0 };
            const std::uint32_t dim3740JoeKuoD6Init[]   =   { 1, 1, 1, 1, 23, 37, 103, 31, 89, 921, 1687, 831, 387, 10237, 1241, 19295, 0 };
            const std::uint32_t dim3741JoeKuoD6Init[]   =   { 1, 3, 3, 7, 25, 23, 57, 251, 309, 579, 603, 807, 7383, 8579, 4025, 16757, 0 };
            const std::uint32_t dim3742JoeKuoD6Init[]   =   { 1, 1, 3, 15, 23, 59, 29, 33, 467, 641, 1271, 2915, 2549, 14767, 26557, 43483, 0 };
            const std::uint32_t dim3743JoeKuoD6Init[]   =   { 1, 1, 7, 13, 1, 57, 23, 129, 321, 75, 189, 4087, 5011, 4355, 25759, 37153, 0 };
            const std::uint32_t dim3744JoeKuoD6Init[]   =   { 1, 1, 5, 1, 21, 57, 25, 183, 37, 669, 259, 1381, 877, 10245, 16643, 61035, 0 };
            const std::uint32_t dim3745JoeKuoD6Init[]   =   { 1, 1, 7, 5, 11, 11, 85, 141, 393, 957, 1745, 2243, 1681, 5583, 16527, 12017, 0 };
            const std::uint32_t dim3746JoeKuoD6Init[]   =   { 1, 1, 5, 15, 23, 31, 5, 169, 287, 527, 1831, 2937, 7533, 9739, 24305, 2239, 0 };
            const std::uint32_t dim3747JoeKuoD6Init[]   =   { 1, 1, 7, 1, 7, 13, 3, 243, 189, 309, 607, 3659, 6369, 7649, 24255, 55373, 0 };
            const std::uint32_t dim3748JoeKuoD6Init[]   =   { 1, 1, 1, 3, 3, 59, 103, 209, 287, 913, 1223, 1063, 7715, 6073, 26697, 25671, 0 };
            const std::uint32_t dim3749JoeKuoD6Init[]   =   { 1, 3, 7, 5, 19, 19, 117, 191, 275, 637, 991, 2199, 2921, 10553, 21211, 25981, 0 };
            const std::uint32_t dim3750JoeKuoD6Init[]   =   { 1, 3, 3, 5, 29, 59, 17, 13, 127, 57, 1405, 3181, 2237, 1795, 21419, 43421, 0 };
            const std::uint32_t dim3751JoeKuoD6Init[]   =   { 1, 1, 1, 15, 25, 41, 11, 117, 463, 425, 305, 1441, 4307, 7967, 17529, 4043, 0 };
            const std::uint32_t dim3752JoeKuoD6Init[]   =   { 1, 3, 5, 5, 19, 53, 69, 73, 453, 611, 1583, 1721, 6303, 10561, 18527, 48973, 0 };
            const std::uint32_t dim3753JoeKuoD6Init[]   =   { 1, 1, 7, 11, 15, 61, 87, 69, 463, 771, 819, 469, 8165, 8897, 29657, 55161, 0 };
            const std::uint32_t dim3754JoeKuoD6Init[]   =   { 1, 1, 5, 1, 15, 25, 23, 47, 287, 457, 1219, 473, 4127, 3349, 9425, 41541, 0 };
            const std::uint32_t dim3755JoeKuoD6Init[]   =   { 1, 3, 7, 5, 17, 17, 33, 161, 239, 231, 241, 1297, 4879, 12761, 20939, 65261, 0 };
            const std::uint32_t dim3756JoeKuoD6Init[]   =   { 1, 3, 3, 9, 19, 53, 95, 89, 117, 333, 1815, 2217, 7779, 8213, 4667, 58395, 0 };
            const std::uint32_t dim3757JoeKuoD6Init[]   =   { 1, 3, 3, 9, 17, 7, 41, 99, 371, 797, 729, 2851, 2003, 4463, 20793, 54315, 0 };
            const std::uint32_t dim3758JoeKuoD6Init[]   =   { 1, 3, 5, 5, 23, 39, 19, 235, 163, 365, 141, 791, 455, 2761, 9115, 53351, 0 };
            const std::uint32_t dim3759JoeKuoD6Init[]   =   { 1, 3, 3, 3, 9, 27, 29, 139, 165, 867, 2023, 1333, 3771, 10451, 9141, 41177, 0 };
            const std::uint32_t dim3760JoeKuoD6Init[]   =   { 1, 1, 3, 7, 3, 11, 125, 157, 355, 519, 187, 3381, 1151, 1629, 25247, 42797, 0 };
            const std::uint32_t dim3761JoeKuoD6Init[]   =   { 1, 3, 3, 3, 21, 25, 37, 155, 257, 311, 961, 1945, 1383, 5679, 7857, 7183, 0 };
            const std::uint32_t dim3762JoeKuoD6Init[]   =   { 1, 3, 3, 5, 29, 11, 49, 125, 171, 605, 1923, 2781, 2555, 5063, 5075, 43301, 0 };
            const std::uint32_t dim3763JoeKuoD6Init[]   =   { 1, 3, 5, 9, 27, 1, 27, 149, 253, 205, 1299, 2901, 2891, 975, 7641, 8115, 0 };
            const std::uint32_t dim3764JoeKuoD6Init[]   =   { 1, 3, 5, 3, 31, 7, 49, 215, 81, 791, 1485, 837, 5051, 1947, 7521, 25723, 0 };
            const std::uint32_t dim3765JoeKuoD6Init[]   =   { 1, 3, 5, 7, 23, 25, 69, 13, 3, 859, 441, 3577, 1687, 6559, 8687, 46757, 0 };
            const std::uint32_t dim3766JoeKuoD6Init[]   =   { 1, 1, 1, 9, 1, 59, 3, 31, 251, 187, 617, 2607, 4635, 6121, 8565, 8871, 0 };
            const std::uint32_t dim3767JoeKuoD6Init[]   =   { 1, 3, 3, 9, 29, 37, 127, 87, 153, 633, 1691, 2729, 3167, 3219, 21237, 25573, 0 };
            const std::uint32_t dim3768JoeKuoD6Init[]   =   { 1, 1, 5, 13, 19, 63, 93, 235, 299, 621, 405, 663, 6639, 12265, 9303, 42719, 0 };
            const std::uint32_t dim3769JoeKuoD6Init[]   =   { 1, 1, 3, 9, 25, 11, 9, 231, 101, 335, 1793, 1497, 7069, 4171, 30199, 63, 0 };
            const std::uint32_t dim3770JoeKuoD6Init[]   =   { 1, 1, 1, 1, 5, 19, 17, 217, 165, 413, 925, 1409, 6559, 14537, 22057, 44331, 0 };
            const std::uint32_t dim3771JoeKuoD6Init[]   =   { 1, 1, 3, 7, 11, 51, 45, 217, 57, 795, 951, 2933, 6705, 137, 30525, 9679, 0 };
            const std::uint32_t dim3772JoeKuoD6Init[]   =   { 1, 1, 3, 15, 27, 47, 35, 125, 363, 619, 1027, 2861, 3923, 10459, 16789, 27277, 0 };
            const std::uint32_t dim3773JoeKuoD6Init[]   =   { 1, 1, 7, 7, 13, 37, 33, 29, 385, 851, 143, 119, 7345, 4251, 25121, 31609, 0 };
            const std::uint32_t dim3774JoeKuoD6Init[]   =   { 1, 3, 1, 1, 17, 25, 119, 7, 365, 397, 601, 2087, 6903, 15345, 14671, 37889, 0 };
            const std::uint32_t dim3775JoeKuoD6Init[]   =   { 1, 3, 1, 13, 19, 51, 41, 139, 133, 723, 25, 2621, 1257, 7037, 9527, 50037, 0 };
            const std::uint32_t dim3776JoeKuoD6Init[]   =   { 1, 1, 5, 11, 5, 59, 119, 75, 397, 545, 1095, 585, 3271, 1049, 123, 33029, 0 };
            const std::uint32_t dim3777JoeKuoD6Init[]   =   { 1, 1, 7, 11, 9, 27, 21, 197, 177, 31, 453, 2457, 2733, 7787, 1923, 24639, 0 };
            const std::uint32_t dim3778JoeKuoD6Init[]   =   { 1, 1, 7, 13, 29, 13, 91, 91, 243, 279, 601, 1699, 7169, 4727, 7815, 29099, 0 };
            const std::uint32_t dim3779JoeKuoD6Init[]   =   { 1, 3, 7, 5, 1, 35, 27, 235, 163, 913, 1479, 769, 7179, 1983, 25977, 55373, 0 };
            const std::uint32_t dim3780JoeKuoD6Init[]   =   { 1, 3, 5, 11, 9, 33, 99, 141, 301, 109, 1785, 129, 1707, 5181, 4797, 9979, 0 };
            const std::uint32_t dim3781JoeKuoD6Init[]   =   { 1, 1, 1, 13, 3, 47, 89, 43, 293, 87, 1689, 3885, 7747, 5607, 477, 31887, 0 };
            const std::uint32_t dim3782JoeKuoD6Init[]   =   { 1, 1, 5, 1, 9, 21, 73, 37, 45, 621, 1855, 3691, 4899, 2191, 13459, 23543, 0 };
            const std::uint32_t dim3783JoeKuoD6Init[]   =   { 1, 1, 1, 1, 7, 39, 61, 125, 341, 905, 213, 1755, 241, 13407, 8791, 10165, 0 };
            const std::uint32_t dim3784JoeKuoD6Init[]   =   { 1, 1, 1, 1, 19, 31, 79, 19, 55, 875, 1017, 1787, 4879, 533, 15029, 52295, 0 };
            const std::uint32_t dim3785JoeKuoD6Init[]   =   { 1, 3, 1, 1, 9, 59, 113, 71, 113, 649, 561, 71, 5253, 783, 7389, 19361, 0 };
            const std::uint32_t dim3786JoeKuoD6Init[]   =   { 1, 1, 1, 11, 5, 39, 61, 225, 291, 907, 795, 1099, 597, 11829, 15137, 42865, 0 };
            const std::uint32_t dim3787JoeKuoD6Init[]   =   { 1, 3, 1, 5, 25, 11, 71, 155, 271, 309, 1981, 1253, 463, 1133, 20833, 48625, 0 };
            const std::uint32_t dim3788JoeKuoD6Init[]   =   { 1, 3, 5, 9, 7, 41, 87, 241, 457, 899, 1493, 3675, 3025, 10607, 22569, 52813, 0 };
            const std::uint32_t dim3789JoeKuoD6Init[]   =   { 1, 3, 7, 13, 7, 37, 37, 103, 281, 915, 1259, 4049, 559, 173, 4123, 63767, 0 };
            const std::uint32_t dim3790JoeKuoD6Init[]   =   { 1, 3, 7, 15, 13, 57, 9, 51, 39, 549, 1431, 2887, 1081, 4643, 16331, 14221, 0 };
            const std::uint32_t dim3791JoeKuoD6Init[]   =   { 1, 3, 5, 7, 13, 1, 101, 125, 25, 713, 1423, 513, 3323, 9951, 7163, 20969, 0 };
            const std::uint32_t dim3792JoeKuoD6Init[]   =   { 1, 1, 7, 15, 11, 25, 25, 3, 47, 531, 1529, 471, 6191, 10051, 29671, 49085, 0 };
            const std::uint32_t dim3793JoeKuoD6Init[]   =   { 1, 1, 3, 5, 23, 51, 117, 141, 55, 275, 761, 1923, 6267, 2291, 3701, 26615, 0 };
            const std::uint32_t dim3794JoeKuoD6Init[]   =   { 1, 1, 7, 9, 15, 19, 111, 65, 137, 373, 1753, 3591, 1137, 11639, 28591, 27265, 0 };
            const std::uint32_t dim3795JoeKuoD6Init[]   =   { 1, 3, 1, 15, 29, 5, 67, 13, 425, 961, 453, 2481, 1407, 3479, 23303, 30407, 0 };
            const std::uint32_t dim3796JoeKuoD6Init[]   =   { 1, 1, 5, 3, 19, 39, 39, 123, 351, 77, 1339, 1765, 3767, 1907, 13627, 23877, 0 };
            const std::uint32_t dim3797JoeKuoD6Init[]   =   { 1, 3, 5, 9, 23, 7, 103, 177, 221, 197, 561, 2121, 7231, 12053, 30127, 29849, 0 };
            const std::uint32_t dim3798JoeKuoD6Init[]   =   { 1, 1, 5, 7, 15, 1, 3, 123, 197, 493, 171, 2425, 3865, 4061, 31883, 2491, 0 };
            const std::uint32_t dim3799JoeKuoD6Init[]   =   { 1, 1, 3, 13, 29, 33, 99, 67, 327, 969, 1793, 1871, 1839, 13059, 7605, 16797, 0 };
            const std::uint32_t dim3800JoeKuoD6Init[]   =   { 1, 3, 5, 11, 25, 53, 25, 93, 303, 623, 1889, 1471, 1213, 14459, 8527, 25095, 0 };
            const std::uint32_t dim3801JoeKuoD6Init[]   =   { 1, 1, 1, 13, 15, 3, 115, 3, 289, 743, 1855, 359, 2375, 13765, 19711, 40765, 0 };
            const std::uint32_t dim3802JoeKuoD6Init[]   =   { 1, 1, 7, 11, 27, 51, 85, 163, 219, 871, 637, 2011, 5981, 587, 17521, 17333, 0 };
            const std::uint32_t dim3803JoeKuoD6Init[]   =   { 1, 3, 5, 1, 21, 59, 49, 39, 305, 513, 2017, 285, 5817, 13123, 27765, 46741, 0 };
            const std::uint32_t dim3804JoeKuoD6Init[]   =   { 1, 3, 3, 7, 21, 39, 71, 163, 423, 845, 783, 397, 7319, 10677, 13407, 47471, 0 };
            const std::uint32_t dim3805JoeKuoD6Init[]   =   { 1, 3, 7, 5, 21, 59, 99, 179, 473, 687, 1393, 723, 2245, 2933, 25943, 7769, 0 };
            const std::uint32_t dim3806JoeKuoD6Init[]   =   { 1, 1, 5, 9, 5, 45, 71, 189, 165, 555, 643, 2289, 3133, 12319, 22209, 1533, 0 };
            const std::uint32_t dim3807JoeKuoD6Init[]   =   { 1, 1, 3, 9, 7, 43, 1, 155, 323, 169, 339, 2561, 4049, 4953, 5289, 8783, 0 };
            const std::uint32_t dim3808JoeKuoD6Init[]   =   { 1, 3, 1, 11, 15, 5, 25, 201, 267, 891, 561, 501, 575, 15147, 1743, 45237, 0 };
            const std::uint32_t dim3809JoeKuoD6Init[]   =   { 1, 3, 5, 13, 25, 27, 105, 205, 165, 795, 975, 943, 7413, 10299, 14839, 54895, 0 };
            const std::uint32_t dim3810JoeKuoD6Init[]   =   { 1, 1, 5, 1, 17, 43, 69, 103, 449, 917, 103, 945, 513, 709, 11647, 28065, 0 };
            const std::uint32_t dim3811JoeKuoD6Init[]   =   { 1, 1, 3, 15, 23, 51, 23, 7, 159, 743, 177, 3457, 415, 1775, 25353, 36385, 0 };
            const std::uint32_t dim3812JoeKuoD6Init[]   =   { 1, 3, 5, 13, 9, 63, 121, 19, 165, 449, 1523, 1959, 6901, 12281, 29149, 45999, 0 };
            const std::uint32_t dim3813JoeKuoD6Init[]   =   { 1, 3, 7, 11, 17, 19, 9, 155, 373, 753, 1313, 2205, 3571, 16317, 16151, 15325, 0 };
            const std::uint32_t dim3814JoeKuoD6Init[]   =   { 1, 3, 3, 7, 15, 43, 65, 183, 407, 123, 1151, 375, 3461, 6673, 12985, 21005, 0 };
            const std::uint32_t dim3815JoeKuoD6Init[]   =   { 1, 3, 7, 7, 9, 1, 87, 247, 489, 123, 1677, 1947, 7961, 13497, 27919, 28993, 0 };
            const std::uint32_t dim3816JoeKuoD6Init[]   =   { 1, 3, 3, 7, 19, 21, 95, 227, 217, 133, 69, 1535, 699, 3521, 29255, 34733, 0 };
            const std::uint32_t dim3817JoeKuoD6Init[]   =   { 1, 3, 5, 3, 7, 57, 45, 251, 407, 81, 1259, 2425, 2217, 13097, 12773, 14643, 0 };
            const std::uint32_t dim3818JoeKuoD6Init[]   =   { 1, 1, 1, 11, 23, 37, 13, 229, 467, 591, 1521, 469, 3763, 2289, 14233, 24053, 0 };
            const std::uint32_t dim3819JoeKuoD6Init[]   =   { 1, 3, 5, 1, 27, 53, 105, 5, 85, 765, 1973, 2597, 5725, 1063, 18145, 961, 0 };
            const std::uint32_t dim3820JoeKuoD6Init[]   =   { 1, 3, 7, 1, 21, 47, 115, 95, 403, 3, 1593, 3379, 7371, 15553, 12503, 57979, 0 };
            const std::uint32_t dim3821JoeKuoD6Init[]   =   { 1, 1, 3, 1, 1, 35, 121, 29, 379, 245, 919, 2673, 3503, 14197, 31193, 8355, 0 };
            const std::uint32_t dim3822JoeKuoD6Init[]   =   { 1, 3, 5, 11, 19, 49, 97, 7, 195, 1013, 1671, 3415, 2009, 13389, 4837, 27453, 0 };
            const std::uint32_t dim3823JoeKuoD6Init[]   =   { 1, 1, 5, 13, 9, 15, 115, 97, 463, 449, 303, 2681, 1215, 12559, 15685, 21321, 0 };
            const std::uint32_t dim3824JoeKuoD6Init[]   =   { 1, 3, 5, 13, 23, 5, 113, 193, 419, 301, 1121, 317, 5503, 4683, 25519, 65, 0 };
            const std::uint32_t dim3825JoeKuoD6Init[]   =   { 1, 3, 3, 7, 15, 29, 45, 97, 323, 475, 143, 1173, 4033, 8939, 31849, 3575, 0 };
            const std::uint32_t dim3826JoeKuoD6Init[]   =   { 1, 1, 7, 7, 21, 1, 101, 143, 197, 409, 855, 1753, 5211, 3763, 11139, 37309, 0 };
            const std::uint32_t dim3827JoeKuoD6Init[]   =   { 1, 1, 3, 13, 25, 33, 55, 45, 381, 349, 991, 535, 4823, 3701, 31629, 48037, 0 };
            const std::uint32_t dim3828JoeKuoD6Init[]   =   { 1, 3, 1, 11, 17, 51, 27, 57, 409, 551, 949, 365, 8093, 10831, 19697, 39437, 0 };
            const std::uint32_t dim3829JoeKuoD6Init[]   =   { 1, 3, 5, 3, 31, 33, 81, 49, 91, 865, 469, 2115, 377, 8237, 31907, 38239, 0 };
            const std::uint32_t dim3830JoeKuoD6Init[]   =   { 1, 1, 3, 7, 29, 59, 57, 17, 121, 889, 1557, 1797, 5001, 14209, 21355, 59739, 0 };
            const std::uint32_t dim3831JoeKuoD6Init[]   =   { 1, 1, 5, 9, 11, 45, 89, 87, 397, 785, 525, 1593, 5251, 12449, 23579, 54265, 0 };
            const std::uint32_t dim3832JoeKuoD6Init[]   =   { 1, 3, 5, 11, 5, 31, 19, 47, 207, 331, 91, 1691, 5171, 53, 15945, 33349, 0 };
            const std::uint32_t dim3833JoeKuoD6Init[]   =   { 1, 1, 1, 15, 11, 41, 91, 177, 505, 871, 815, 3673, 5631, 9915, 1133, 37861, 0 };
            const std::uint32_t dim3834JoeKuoD6Init[]   =   { 1, 3, 5, 5, 25, 63, 53, 231, 55, 51, 481, 303, 1859, 11973, 28557, 22045, 0 };
            const std::uint32_t dim3835JoeKuoD6Init[]   =   { 1, 1, 5, 3, 27, 11, 37, 91, 363, 411, 1131, 3369, 377, 6585, 7353, 42949, 0 };
            const std::uint32_t dim3836JoeKuoD6Init[]   =   { 1, 3, 1, 9, 31, 63, 83, 23, 405, 941, 119, 1471, 2509, 15507, 29239, 49613, 0 };
            const std::uint32_t dim3837JoeKuoD6Init[]   =   { 1, 1, 5, 1, 11, 63, 117, 237, 407, 231, 1425, 71, 8005, 4023, 9029, 59819, 0 };
            const std::uint32_t dim3838JoeKuoD6Init[]   =   { 1, 1, 5, 7, 1, 9, 43, 87, 351, 63, 1075, 3381, 5447, 2437, 24983, 26905, 0 };
            const std::uint32_t dim3839JoeKuoD6Init[]   =   { 1, 3, 7, 5, 5, 35, 33, 89, 251, 819, 1735, 2625, 6363, 6837, 27603, 26669, 0 };
            const std::uint32_t dim3840JoeKuoD6Init[]   =   { 1, 3, 7, 13, 29, 63, 51, 245, 371, 791, 907, 3499, 3033, 8443, 20023, 1805, 0 };
            const std::uint32_t dim3841JoeKuoD6Init[]   =   { 1, 1, 5, 7, 13, 15, 109, 197, 451, 709, 929, 3193, 5727, 11185, 29479, 1671, 0 };
            const std::uint32_t dim3842JoeKuoD6Init[]   =   { 1, 1, 7, 13, 19, 23, 97, 9, 359, 635, 777, 39, 893, 2531, 13563, 19295, 0 };
            const std::uint32_t dim3843JoeKuoD6Init[]   =   { 1, 1, 5, 1, 31, 63, 55, 7, 157, 877, 991, 1317, 1595, 2019, 21435, 52255, 0 };
            const std::uint32_t dim3844JoeKuoD6Init[]   =   { 1, 1, 5, 3, 19, 37, 23, 13, 335, 431, 483, 615, 2431, 505, 26245, 63323, 0 };
            const std::uint32_t dim3845JoeKuoD6Init[]   =   { 1, 3, 7, 5, 5, 9, 37, 65, 303, 423, 1907, 2661, 7213, 2975, 29045, 16243, 0 };
            const std::uint32_t dim3846JoeKuoD6Init[]   =   { 1, 3, 1, 5, 13, 37, 115, 217, 227, 159, 707, 1387, 943, 4935, 5503, 35171, 0 };
            const std::uint32_t dim3847JoeKuoD6Init[]   =   { 1, 3, 7, 9, 19, 15, 87, 233, 453, 159, 169, 1077, 2129, 413, 19773, 629, 0 };
            const std::uint32_t dim3848JoeKuoD6Init[]   =   { 1, 1, 5, 15, 29, 39, 37, 243, 233, 365, 1843, 2219, 1255, 15287, 603, 13511, 0 };
            const std::uint32_t dim3849JoeKuoD6Init[]   =   { 1, 1, 3, 3, 31, 53, 33, 125, 497, 597, 127, 1829, 3905, 2611, 4263, 40971, 0 };
            const std::uint32_t dim3850JoeKuoD6Init[]   =   { 1, 3, 5, 9, 11, 47, 71, 215, 383, 321, 1445, 135, 5953, 8791, 22073, 16537, 0 };
            const std::uint32_t dim3851JoeKuoD6Init[]   =   { 1, 3, 3, 13, 15, 7, 7, 133, 401, 459, 1117, 3165, 4105, 11943, 22431, 56821, 0 };
            const std::uint32_t dim3852JoeKuoD6Init[]   =   { 1, 1, 7, 9, 31, 39, 19, 7, 19, 401, 79, 3641, 6815, 1489, 7537, 49467, 0 };
            const std::uint32_t dim3853JoeKuoD6Init[]   =   { 1, 3, 7, 7, 17, 11, 91, 205, 251, 321, 515, 3521, 311, 3169, 271, 34749, 0 };
            const std::uint32_t dim3854JoeKuoD6Init[]   =   { 1, 3, 3, 7, 29, 15, 5, 153, 83, 603, 1373, 997, 4939, 9811, 243, 5375, 0 };
            const std::uint32_t dim3855JoeKuoD6Init[]   =   { 1, 1, 3, 11, 21, 47, 25, 221, 237, 177, 535, 2819, 6213, 7877, 26795, 36609, 0 };
            const std::uint32_t dim3856JoeKuoD6Init[]   =   { 1, 3, 7, 3, 31, 1, 69, 73, 47, 653, 139, 1649, 7183, 1293, 26507, 38415, 0 };
            const std::uint32_t dim3857JoeKuoD6Init[]   =   { 1, 1, 1, 13, 17, 41, 23, 73, 115, 509, 787, 3733, 1871, 171, 29967, 39941, 0 };
            const std::uint32_t dim3858JoeKuoD6Init[]   =   { 1, 3, 5, 1, 9, 7, 61, 23, 105, 381, 1421, 2887, 3717, 643, 26375, 57991, 0 };
            const std::uint32_t dim3859JoeKuoD6Init[]   =   { 1, 3, 3, 3, 19, 3, 101, 117, 393, 83, 1255, 3331, 6481, 8661, 20855, 28875, 0 };
            const std::uint32_t dim3860JoeKuoD6Init[]   =   { 1, 3, 5, 11, 21, 13, 111, 193, 51, 899, 159, 1989, 7931, 10511, 3933, 447, 0 };
            const std::uint32_t dim3861JoeKuoD6Init[]   =   { 1, 1, 5, 15, 23, 35, 49, 139, 397, 145, 597, 1847, 7077, 715, 20227, 42183, 0 };
            const std::uint32_t dim3862JoeKuoD6Init[]   =   { 1, 3, 3, 3, 17, 3, 87, 233, 35, 317, 337, 237, 6901, 3439, 20033, 10307, 0 };
            const std::uint32_t dim3863JoeKuoD6Init[]   =   { 1, 3, 5, 3, 11, 35, 13, 171, 7, 963, 1443, 1501, 7617, 963, 25453, 62589, 0 };
            const std::uint32_t dim3864JoeKuoD6Init[]   =   { 1, 1, 1, 5, 11, 9, 39, 175, 409, 411, 1407, 2743, 4255, 989, 15823, 1707, 0 };
            const std::uint32_t dim3865JoeKuoD6Init[]   =   { 1, 1, 7, 13, 27, 55, 63, 239, 355, 417, 2007, 2299, 2921, 1637, 10687, 60615, 0 };
            const std::uint32_t dim3866JoeKuoD6Init[]   =   { 1, 1, 7, 9, 5, 61, 57, 73, 263, 307, 2003, 1763, 639, 5885, 14709, 16985, 0 };
            const std::uint32_t dim3867JoeKuoD6Init[]   =   { 1, 1, 3, 3, 21, 55, 19, 249, 509, 533, 1361, 1397, 2777, 15523, 4389, 13339, 0 };
            const std::uint32_t dim3868JoeKuoD6Init[]   =   { 1, 3, 5, 15, 9, 3, 91, 237, 451, 299, 1541, 4083, 879, 7859, 21585, 14833, 0 };
            const std::uint32_t dim3869JoeKuoD6Init[]   =   { 1, 1, 7, 3, 31, 47, 49, 231, 123, 391, 1633, 2567, 5577, 1631, 27951, 22913, 0 };
            const std::uint32_t dim3870JoeKuoD6Init[]   =   { 1, 3, 7, 13, 11, 13, 1, 111, 183, 87, 839, 1915, 5523, 3677, 13065, 38225, 0 };
            const std::uint32_t dim3871JoeKuoD6Init[]   =   { 1, 1, 3, 7, 15, 15, 63, 241, 167, 345, 653, 701, 4725, 12911, 11545, 24475, 0 };
            const std::uint32_t dim3872JoeKuoD6Init[]   =   { 1, 1, 3, 7, 25, 15, 49, 235, 331, 639, 965, 1117, 7147, 3789, 3309, 20255, 0 };
            const std::uint32_t dim3873JoeKuoD6Init[]   =   { 1, 3, 5, 7, 7, 63, 93, 241, 253, 31, 951, 3723, 3359, 7303, 191, 36427, 0 };
            const std::uint32_t dim3874JoeKuoD6Init[]   =   { 1, 3, 7, 9, 9, 59, 5, 107, 181, 413, 1269, 3121, 1929, 11921, 8931, 47459, 0 };
            const std::uint32_t dim3875JoeKuoD6Init[]   =   { 1, 3, 1, 15, 25, 27, 13, 47, 295, 111, 1287, 2551, 4887, 4145, 17063, 42037, 0 };
            const std::uint32_t dim3876JoeKuoD6Init[]   =   { 1, 3, 3, 13, 17, 17, 21, 17, 491, 845, 1463, 1305, 1375, 16149, 19331, 25043, 0 };
            const std::uint32_t dim3877JoeKuoD6Init[]   =   { 1, 3, 5, 1, 27, 5, 93, 139, 283, 711, 1141, 1743, 5001, 8851, 19351, 12275, 0 };
            const std::uint32_t dim3878JoeKuoD6Init[]   =   { 1, 1, 1, 1, 23, 25, 51, 63, 429, 735, 201, 3785, 6677, 16375, 19681, 17857, 0 };
            const std::uint32_t dim3879JoeKuoD6Init[]   =   { 1, 3, 3, 3, 9, 63, 71, 147, 463, 465, 1163, 1045, 6967, 12537, 31853, 38391, 0 };
            const std::uint32_t dim3880JoeKuoD6Init[]   =   { 1, 3, 7, 1, 5, 51, 79, 239, 389, 3, 601, 3787, 7635, 16295, 1681, 63971, 0 };
            const std::uint32_t dim3881JoeKuoD6Init[]   =   { 1, 3, 1, 3, 5, 31, 103, 89, 321, 971, 783, 3685, 1155, 10353, 2167, 35423, 0 };
            const std::uint32_t dim3882JoeKuoD6Init[]   =   { 1, 1, 5, 15, 25, 19, 93, 59, 361, 217, 1141, 597, 5877, 15961, 1593, 22925, 0 };
            const std::uint32_t dim3883JoeKuoD6Init[]   =   { 1, 3, 1, 9, 25, 59, 69, 89, 477, 89, 487, 237, 5625, 9579, 30421, 21883, 0 };
            const std::uint32_t dim3884JoeKuoD6Init[]   =   { 1, 1, 3, 7, 1, 5, 13, 225, 9, 981, 1081, 1407, 6855, 15215, 21713, 62313, 0 };
            const std::uint32_t dim3885JoeKuoD6Init[]   =   { 1, 1, 7, 15, 11, 13, 119, 109, 151, 245, 1195, 3741, 755, 8047, 15431, 21001, 0 };
            const std::uint32_t dim3886JoeKuoD6Init[]   =   { 1, 3, 7, 3, 17, 47, 107, 137, 99, 255, 1597, 3281, 5779, 13487, 15061, 19199, 0 };
            const std::uint32_t dim3887JoeKuoD6Init[]   =   { 1, 1, 3, 3, 9, 39, 77, 227, 511, 839, 1375, 3887, 25, 14763, 13259, 217, 0 };
            const std::uint32_t dim3888JoeKuoD6Init[]   =   { 1, 3, 5, 7, 17, 3, 87, 61, 439, 287, 709, 4085, 4251, 8945, 28203, 24011, 0 };
            const std::uint32_t dim3889JoeKuoD6Init[]   =   { 1, 3, 1, 1, 29, 25, 49, 101, 209, 359, 285, 1593, 4161, 2943, 23225, 6381, 0 };
            const std::uint32_t dim3890JoeKuoD6Init[]   =   { 1, 1, 3, 13, 1, 45, 87, 7, 491, 399, 905, 1403, 4791, 7419, 14355, 47767, 0 };
            const std::uint32_t dim3891JoeKuoD6Init[]   =   { 1, 1, 7, 15, 13, 25, 111, 197, 297, 301, 499, 4007, 2235, 7681, 4641, 32447, 0 };
            const std::uint32_t dim3892JoeKuoD6Init[]   =   { 1, 1, 3, 3, 27, 41, 97, 83, 405, 353, 1609, 201, 1503, 10673, 29377, 20445, 0 };
            const std::uint32_t dim3893JoeKuoD6Init[]   =   { 1, 1, 7, 3, 9, 47, 65, 191, 207, 545, 377, 3011, 7361, 3467, 14073, 46769, 0 };
            const std::uint32_t dim3894JoeKuoD6Init[]   =   { 1, 1, 7, 5, 7, 39, 9, 91, 187, 949, 1829, 161, 3689, 4145, 32675, 23263, 0 };
            const std::uint32_t dim3895JoeKuoD6Init[]   =   { 1, 1, 5, 9, 29, 9, 83, 113, 77, 673, 613, 3645, 6671, 8583, 27701, 18615, 0 };
            const std::uint32_t dim3896JoeKuoD6Init[]   =   { 1, 3, 5, 9, 29, 13, 127, 247, 285, 845, 463, 539, 4441, 1867, 12469, 16213, 0 };
            const std::uint32_t dim3897JoeKuoD6Init[]   =   { 1, 3, 7, 15, 1, 29, 47, 157, 239, 595, 563, 1103, 3431, 2849, 28125, 19969, 0 };
            const std::uint32_t dim3898JoeKuoD6Init[]   =   { 1, 1, 1, 15, 25, 13, 1, 131, 57, 257, 2021, 169, 7603, 10721, 21675, 63171, 0 };
            const std::uint32_t dim3899JoeKuoD6Init[]   =   { 1, 3, 5, 3, 5, 19, 31, 57, 275, 381, 775, 681, 1145, 12237, 5141, 29375, 0 };
            const std::uint32_t dim3900JoeKuoD6Init[]   =   { 1, 3, 5, 13, 27, 13, 47, 201, 267, 581, 1563, 3845, 951, 7209, 27253, 19755, 0 };
            const std::uint32_t dim3901JoeKuoD6Init[]   =   { 1, 3, 5, 15, 19, 35, 57, 17, 61, 273, 967, 3029, 1747, 1753, 31321, 23711, 0 };
            const std::uint32_t dim3902JoeKuoD6Init[]   =   { 1, 1, 1, 5, 13, 13, 7, 177, 335, 393, 1401, 1411, 4703, 8259, 1281, 39835, 0 };
            const std::uint32_t dim3903JoeKuoD6Init[]   =   { 1, 1, 3, 15, 25, 27, 27, 121, 183, 105, 663, 1375, 6987, 7151, 13763, 39323, 0 };
            const std::uint32_t dim3904JoeKuoD6Init[]   =   { 1, 3, 7, 5, 15, 1, 81, 129, 455, 163, 675, 81, 3735, 14409, 7269, 16425, 0 };
            const std::uint32_t dim3905JoeKuoD6Init[]   =   { 1, 3, 3, 11, 13, 7, 79, 157, 165, 663, 229, 3539, 1837, 6485, 30729, 42157, 0 };
            const std::uint32_t dim3906JoeKuoD6Init[]   =   { 1, 1, 5, 15, 9, 9, 9, 47, 133, 863, 43, 1461, 511, 13991, 24781, 19221, 0 };
            const std::uint32_t dim3907JoeKuoD6Init[]   =   { 1, 3, 1, 7, 31, 33, 103, 13, 159, 689, 1353, 4025, 6051, 7683, 1741, 30047, 0 };
            const std::uint32_t dim3908JoeKuoD6Init[]   =   { 1, 1, 3, 11, 5, 45, 71, 219, 475, 585, 1207, 3163, 4661, 4713, 12729, 30445, 0 };
            const std::uint32_t dim3909JoeKuoD6Init[]   =   { 1, 3, 7, 5, 5, 53, 101, 227, 129, 521, 91, 1129, 4683, 11235, 24697, 45055, 0 };
            const std::uint32_t dim3910JoeKuoD6Init[]   =   { 1, 1, 3, 13, 1, 43, 7, 1, 73, 857, 1713, 185, 1685, 2369, 24187, 40419, 0 };
            const std::uint32_t dim3911JoeKuoD6Init[]   =   { 1, 1, 7, 7, 21, 7, 13, 177, 503, 1003, 1091, 2411, 1433, 9063, 13901, 3329, 0 };
            const std::uint32_t dim3912JoeKuoD6Init[]   =   { 1, 1, 7, 1, 7, 41, 99, 203, 325, 249, 1763, 545, 2981, 14125, 7815, 11385, 0 };
            const std::uint32_t dim3913JoeKuoD6Init[]   =   { 1, 3, 7, 11, 3, 11, 95, 137, 325, 701, 1177, 1631, 4483, 2955, 30229, 25577, 0 };
            const std::uint32_t dim3914JoeKuoD6Init[]   =   { 1, 1, 7, 7, 17, 45, 77, 103, 143, 97, 1963, 3635, 1539, 10491, 23483, 22767, 0 };
            const std::uint32_t dim3915JoeKuoD6Init[]   =   { 1, 1, 7, 15, 7, 5, 81, 63, 243, 55, 39, 207, 2315, 8285, 8155, 11631, 0 };
            const std::uint32_t dim3916JoeKuoD6Init[]   =   { 1, 3, 5, 15, 23, 19, 115, 9, 125, 851, 161, 3767, 3513, 1855, 11139, 1719, 0 };
            const std::uint32_t dim3917JoeKuoD6Init[]   =   { 1, 3, 7, 11, 11, 23, 15, 13, 235, 5, 1039, 1425, 6485, 5539, 8967, 64809, 0 };
            const std::uint32_t dim3918JoeKuoD6Init[]   =   { 1, 3, 5, 7, 19, 11, 83, 135, 45, 905, 1081, 1857, 3185, 13555, 21365, 38143, 0 };
            const std::uint32_t dim3919JoeKuoD6Init[]   =   { 1, 1, 5, 1, 25, 27, 119, 109, 167, 847, 1539, 2653, 797, 11185, 23501, 22389, 0 };
            const std::uint32_t dim3920JoeKuoD6Init[]   =   { 1, 1, 7, 7, 11, 3, 51, 97, 277, 557, 207, 3645, 825, 8521, 26653, 60071, 0 };
            const std::uint32_t dim3921JoeKuoD6Init[]   =   { 1, 3, 3, 15, 17, 35, 57, 7, 267, 549, 97, 243, 1137, 10311, 6737, 19077, 0 };
            const std::uint32_t dim3922JoeKuoD6Init[]   =   { 1, 1, 1, 15, 23, 33, 27, 203, 415, 1023, 1145, 1881, 7715, 4413, 3727, 5185, 0 };
            const std::uint32_t dim3923JoeKuoD6Init[]   =   { 1, 1, 3, 3, 13, 47, 63, 13, 75, 505, 595, 2911, 4029, 14187, 23151, 42877, 0 };
            const std::uint32_t dim3924JoeKuoD6Init[]   =   { 1, 1, 5, 15, 23, 5, 11, 65, 147, 675, 1961, 2177, 727, 15077, 23759, 10195, 0 };
            const std::uint32_t dim3925JoeKuoD6Init[]   =   { 1, 3, 5, 9, 9, 39, 69, 229, 341, 627, 1331, 3139, 3921, 9219, 14887, 4659, 0 };
            const std::uint32_t dim3926JoeKuoD6Init[]   =   { 1, 1, 7, 3, 1, 35, 49, 71, 165, 83, 719, 2771, 6475, 7821, 16709, 4449, 0 };
            const std::uint32_t dim3927JoeKuoD6Init[]   =   { 1, 3, 5, 5, 23, 15, 3, 57, 465, 77, 121, 3767, 6841, 13601, 12035, 14075, 0 };
            const std::uint32_t dim3928JoeKuoD6Init[]   =   { 1, 1, 7, 3, 3, 23, 45, 131, 287, 941, 713, 415, 6865, 14209, 29555, 55493, 0 };
            const std::uint32_t dim3929JoeKuoD6Init[]   =   { 1, 3, 5, 11, 29, 35, 55, 75, 225, 779, 569, 1795, 1377, 12765, 19081, 47287, 0 };
            const std::uint32_t dim3930JoeKuoD6Init[]   =   { 1, 3, 7, 3, 31, 47, 127, 89, 157, 737, 1395, 3615, 7923, 14731, 15797, 40061, 0 };
            const std::uint32_t dim3931JoeKuoD6Init[]   =   { 1, 1, 1, 11, 21, 37, 21, 59, 9, 141, 193, 3095, 3435, 12371, 26931, 61861, 0 };
            const std::uint32_t dim3932JoeKuoD6Init[]   =   { 1, 1, 3, 7, 13, 51, 15, 153, 77, 1013, 651, 3949, 6229, 14297, 1039, 46139, 0 };
            const std::uint32_t dim3933JoeKuoD6Init[]   =   { 1, 3, 3, 13, 7, 43, 95, 61, 217, 3, 549, 739, 123, 3661, 15375, 13919, 0 };
            const std::uint32_t dim3934JoeKuoD6Init[]   =   { 1, 3, 5, 9, 13, 37, 101, 89, 55, 413, 1089, 775, 7575, 13063, 31393, 29583, 0 };
            const std::uint32_t dim3935JoeKuoD6Init[]   =   { 1, 1, 3, 9, 25, 63, 119, 143, 499, 145, 603, 2067, 4713, 13457, 14053, 117, 0 };
            const std::uint32_t dim3936JoeKuoD6Init[]   =   { 1, 1, 5, 9, 7, 23, 57, 253, 115, 591, 2003, 63, 7615, 11493, 28519, 47087, 0 };
            const std::uint32_t dim3937JoeKuoD6Init[]   =   { 1, 1, 7, 3, 7, 53, 121, 33, 233, 645, 1093, 1697, 7213, 2603, 10743, 51303, 0 };
            const std::uint32_t dim3938JoeKuoD6Init[]   =   { 1, 3, 5, 7, 13, 31, 17, 125, 93, 969, 159, 1529, 7165, 7371, 8707, 56953, 0 };
            const std::uint32_t dim3939JoeKuoD6Init[]   =   { 1, 3, 3, 1, 13, 9, 91, 25, 171, 843, 1635, 2043, 1043, 15893, 11409, 53689, 0 };
            const std::uint32_t dim3940JoeKuoD6Init[]   =   { 1, 3, 5, 7, 13, 19, 89, 97, 203, 923, 1109, 2061, 463, 11703, 8925, 56015, 0 };
            const std::uint32_t dim3941JoeKuoD6Init[]   =   { 1, 3, 5, 11, 5, 21, 79, 237, 195, 649, 717, 211, 919, 12855, 3045, 39659, 0 };
            const std::uint32_t dim3942JoeKuoD6Init[]   =   { 1, 1, 1, 15, 13, 19, 21, 69, 393, 257, 1263, 309, 3209, 8403, 24467, 6467, 0 };
            const std::uint32_t dim3943JoeKuoD6Init[]   =   { 1, 1, 1, 11, 7, 27, 59, 117, 379, 353, 943, 2513, 3869, 4567, 12989, 13139, 0 };
            const std::uint32_t dim3944JoeKuoD6Init[]   =   { 1, 1, 1, 3, 13, 43, 11, 15, 149, 237, 1555, 71, 2357, 15773, 21419, 40571, 0 };
            const std::uint32_t dim3945JoeKuoD6Init[]   =   { 1, 3, 1, 9, 19, 23, 59, 215, 15, 921, 1729, 249, 3785, 7171, 1233, 3449, 0 };
            const std::uint32_t dim3946JoeKuoD6Init[]   =   { 1, 1, 1, 7, 7, 37, 63, 205, 75, 599, 951, 2513, 3347, 2497, 8019, 5433, 0 };
            const std::uint32_t dim3947JoeKuoD6Init[]   =   { 1, 3, 3, 15, 27, 17, 25, 201, 23, 699, 1525, 465, 1115, 12299, 14747, 40363, 0 };
            const std::uint32_t dim3948JoeKuoD6Init[]   =   { 1, 1, 1, 3, 29, 59, 115, 233, 107, 815, 291, 3821, 7325, 7381, 21445, 33917, 0 };
            const std::uint32_t dim3949JoeKuoD6Init[]   =   { 1, 3, 1, 11, 11, 33, 107, 171, 421, 893, 587, 3373, 4101, 3885, 25383, 12035, 0 };
            const std::uint32_t dim3950JoeKuoD6Init[]   =   { 1, 3, 3, 7, 5, 23, 43, 51, 357, 77, 1327, 2995, 1321, 1571, 26419, 23603, 0 };
            const std::uint32_t dim3951JoeKuoD6Init[]   =   { 1, 3, 7, 9, 27, 57, 101, 51, 215, 215, 469, 303, 723, 2903, 30569, 42631, 0 };
            const std::uint32_t dim3952JoeKuoD6Init[]   =   { 1, 3, 3, 13, 1, 7, 63, 205, 143, 321, 1439, 253, 2667, 1271, 11761, 55631, 0 };
            const std::uint32_t dim3953JoeKuoD6Init[]   =   { 1, 1, 7, 9, 3, 7, 7, 15, 503, 875, 1619, 1715, 5047, 5665, 5503, 17745, 0 };
            const std::uint32_t dim3954JoeKuoD6Init[]   =   { 1, 1, 7, 15, 19, 49, 65, 31, 245, 371, 377, 2963, 6185, 5519, 10743, 33231, 0 };
            const std::uint32_t dim3955JoeKuoD6Init[]   =   { 1, 1, 7, 3, 25, 27, 115, 51, 299, 451, 285, 1709, 6153, 14881, 17861, 22071, 0 };
            const std::uint32_t dim3956JoeKuoD6Init[]   =   { 1, 3, 1, 5, 21, 21, 127, 185, 325, 995, 213, 3279, 4769, 15943, 2589, 29567, 0 };
            const std::uint32_t dim3957JoeKuoD6Init[]   =   { 1, 3, 7, 5, 21, 9, 63, 59, 159, 743, 663, 2965, 97, 8993, 25633, 29033, 0 };
            const std::uint32_t dim3958JoeKuoD6Init[]   =   { 1, 3, 7, 13, 3, 35, 59, 101, 21, 659, 1531, 3995, 795, 2143, 21749, 52715, 0 };
            const std::uint32_t dim3959JoeKuoD6Init[]   =   { 1, 3, 3, 15, 27, 29, 95, 1, 501, 425, 417, 2351, 7877, 4127, 3633, 23347, 0 };
            const std::uint32_t dim3960JoeKuoD6Init[]   =   { 1, 3, 5, 7, 7, 49, 55, 19, 329, 467, 425, 1609, 6987, 16123, 26879, 42883, 0 };
            const std::uint32_t dim3961JoeKuoD6Init[]   =   { 1, 1, 1, 15, 17, 21, 13, 13, 85, 7, 677, 3739, 5491, 6299, 29957, 55765, 0 };
            const std::uint32_t dim3962JoeKuoD6Init[]   =   { 1, 1, 1, 7, 31, 21, 1, 5, 193, 659, 979, 3409, 3151, 6615, 7445, 8151, 0 };
            const std::uint32_t dim3963JoeKuoD6Init[]   =   { 1, 3, 1, 1, 11, 61, 27, 205, 263, 805, 955, 3469, 1233, 1609, 15329, 13353, 0 };
            const std::uint32_t dim3964JoeKuoD6Init[]   =   { 1, 3, 3, 9, 3, 29, 59, 75, 149, 557, 663, 3887, 3369, 3397, 10611, 9511, 0 };
            const std::uint32_t dim3965JoeKuoD6Init[]   =   { 1, 1, 7, 13, 29, 21, 101, 139, 99, 411, 569, 2343, 6901, 1685, 20599, 49543, 0 };
            const std::uint32_t dim3966JoeKuoD6Init[]   =   { 1, 3, 3, 15, 11, 3, 87, 89, 5, 293, 291, 1405, 1489, 9877, 32505, 32263, 0 };
            const std::uint32_t dim3967JoeKuoD6Init[]   =   { 1, 1, 5, 5, 19, 45, 89, 5, 381, 253, 1339, 707, 4645, 14177, 29441, 8965, 0 };
            const std::uint32_t dim3968JoeKuoD6Init[]   =   { 1, 3, 7, 15, 27, 45, 25, 177, 81, 229, 1339, 2143, 6547, 6841, 23449, 14813, 0 };
            const std::uint32_t dim3969JoeKuoD6Init[]   =   { 1, 1, 1, 3, 27, 23, 81, 157, 53, 513, 1435, 277, 2353, 3545, 21461, 51479, 0 };
            const std::uint32_t dim3970JoeKuoD6Init[]   =   { 1, 3, 1, 3, 3, 17, 75, 139, 283, 881, 1157, 2081, 937, 14549, 10215, 13053, 0 };
            const std::uint32_t dim3971JoeKuoD6Init[]   =   { 1, 1, 7, 9, 25, 27, 27, 133, 21, 559, 225, 613, 6931, 11785, 23413, 35757, 0 };
            const std::uint32_t dim3972JoeKuoD6Init[]   =   { 1, 1, 3, 13, 19, 9, 65, 49, 453, 779, 621, 1151, 1807, 13269, 6515, 17113, 0 };
            const std::uint32_t dim3973JoeKuoD6Init[]   =   { 1, 1, 1, 13, 21, 49, 39, 79, 119, 401, 903, 493, 3779, 7389, 29425, 28091, 0 };
            const std::uint32_t dim3974JoeKuoD6Init[]   =   { 1, 3, 1, 3, 23, 57, 59, 213, 463, 839, 1201, 1951, 5197, 13035, 29657, 35517, 0 };
            const std::uint32_t dim3975JoeKuoD6Init[]   =   { 1, 3, 7, 7, 3, 49, 29, 181, 367, 101, 1277, 3329, 3563, 10373, 29757, 62555, 0 };
            const std::uint32_t dim3976JoeKuoD6Init[]   =   { 1, 3, 1, 7, 31, 31, 117, 213, 373, 57, 1095, 2733, 3431, 3915, 7665, 44459, 0 };
            const std::uint32_t dim3977JoeKuoD6Init[]   =   { 1, 1, 7, 5, 9, 25, 47, 117, 355, 495, 1367, 2579, 5617, 787, 27655, 18885, 0 };
            const std::uint32_t dim3978JoeKuoD6Init[]   =   { 1, 1, 1, 3, 9, 39, 113, 87, 107, 477, 891, 2273, 4239, 7521, 147, 1737, 0 };
            const std::uint32_t dim3979JoeKuoD6Init[]   =   { 1, 1, 1, 3, 13, 61, 81, 225, 113, 441, 889, 1915, 3897, 15179, 4053, 5925, 0 };
            const std::uint32_t dim3980JoeKuoD6Init[]   =   { 1, 1, 5, 3, 15, 47, 59, 187, 475, 197, 1381, 33, 4605, 1487, 14359, 33769, 0 };
            const std::uint32_t dim3981JoeKuoD6Init[]   =   { 1, 3, 7, 15, 23, 45, 53, 215, 129, 465, 795, 53, 7077, 9517, 2663, 55397, 0 };
            const std::uint32_t dim3982JoeKuoD6Init[]   =   { 1, 1, 7, 13, 25, 49, 105, 255, 245, 153, 1093, 2123, 2823, 5125, 17483, 49003, 0 };
            const std::uint32_t dim3983JoeKuoD6Init[]   =   { 1, 1, 1, 13, 31, 5, 7, 243, 255, 231, 1663, 1007, 7573, 405, 29183, 11367, 0 };
            const std::uint32_t dim3984JoeKuoD6Init[]   =   { 1, 1, 5, 13, 15, 15, 115, 91, 63, 1013, 1713, 1945, 6397, 14213, 24417, 40807, 0 };
            const std::uint32_t dim3985JoeKuoD6Init[]   =   { 1, 1, 5, 3, 19, 49, 91, 25, 43, 601, 25, 2405, 1973, 629, 497, 12625, 0 };
            const std::uint32_t dim3986JoeKuoD6Init[]   =   { 1, 1, 3, 5, 13, 45, 11, 81, 251, 545, 1155, 1409, 7187, 847, 2835, 32909, 0 };
            const std::uint32_t dim3987JoeKuoD6Init[]   =   { 1, 3, 1, 13, 27, 57, 1, 103, 465, 809, 1727, 3721, 3347, 3791, 17247, 8377, 0 };
            const std::uint32_t dim3988JoeKuoD6Init[]   =   { 1, 3, 3, 15, 25, 31, 91, 91, 119, 205, 1431, 703, 5327, 7323, 30415, 61955, 0 };
            const std::uint32_t dim3989JoeKuoD6Init[]   =   { 1, 3, 5, 11, 19, 39, 79, 243, 109, 463, 1869, 2133, 4139, 10461, 14793, 24025, 0 };
            const std::uint32_t dim3990JoeKuoD6Init[]   =   { 1, 3, 5, 7, 23, 41, 5, 7, 249, 3, 1743, 489, 4921, 397, 30955, 22207, 0 };
            const std::uint32_t dim3991JoeKuoD6Init[]   =   { 1, 3, 5, 15, 3, 7, 115, 19, 217, 231, 1183, 3723, 5055, 12967, 7855, 5067, 0 };
            const std::uint32_t dim3992JoeKuoD6Init[]   =   { 1, 3, 3, 3, 11, 31, 113, 41, 429, 797, 557, 1199, 1819, 1933, 9917, 32229, 0 };
            const std::uint32_t dim3993JoeKuoD6Init[]   =   { 1, 1, 5, 3, 13, 63, 31, 183, 465, 915, 723, 3227, 4125, 2813, 26313, 34287, 0 };
            const std::uint32_t dim3994JoeKuoD6Init[]   =   { 1, 1, 7, 5, 31, 55, 117, 243, 37, 885, 85, 1067, 3895, 15655, 28527, 32109, 0 };
            const std::uint32_t dim3995JoeKuoD6Init[]   =   { 1, 3, 7, 15, 17, 43, 43, 173, 119, 187, 1161, 599, 4595, 1681, 11981, 681, 0 };
            const std::uint32_t dim3996JoeKuoD6Init[]   =   { 1, 1, 7, 7, 29, 47, 25, 93, 411, 103, 783, 1029, 1927, 3569, 27647, 8281, 0 };
            const std::uint32_t dim3997JoeKuoD6Init[]   =   { 1, 3, 3, 9, 19, 57, 31, 183, 141, 889, 157, 2267, 5701, 6273, 25739, 34039, 0 };
            const std::uint32_t dim3998JoeKuoD6Init[]   =   { 1, 3, 5, 1, 29, 35, 105, 165, 505, 299, 1149, 2397, 2013, 11591, 15917, 4791, 0 };
            const std::uint32_t dim3999JoeKuoD6Init[]   =   { 1, 3, 3, 9, 7, 35, 47, 77, 69, 335, 585, 1131, 531, 8597, 307, 55985, 0 };
            const std::uint32_t dim4000JoeKuoD6Init[]   =   { 1, 3, 7, 1, 29, 9, 25, 155, 149, 845, 567, 3735, 3501, 9365, 12025, 19131, 0 };
            const std::uint32_t dim4001JoeKuoD6Init[]   =   { 1, 3, 5, 3, 11, 31, 25, 9, 411, 519, 1611, 1441, 1487, 10049, 14373, 24605, 0 };
            const std::uint32_t dim4002JoeKuoD6Init[]   =   { 1, 3, 3, 5, 3, 7, 101, 107, 339, 155, 1843, 2529, 443, 8177, 28655, 8151, 0 };
            const std::uint32_t dim4003JoeKuoD6Init[]   =   { 1, 1, 7, 5, 29, 37, 73, 131, 125, 451, 947, 797, 5053, 10155, 30801, 27235, 0 };
            const std::uint32_t dim4004JoeKuoD6Init[]   =   { 1, 1, 7, 13, 19, 47, 101, 45, 495, 457, 1293, 1971, 5495, 12737, 17687, 26123, 0 };
            const std::uint32_t dim4005JoeKuoD6Init[]   =   { 1, 1, 7, 7, 11, 11, 75, 177, 251, 553, 1883, 3379, 1429, 12227, 10301, 16467, 0 };
            const std::uint32_t dim4006JoeKuoD6Init[]   =   { 1, 3, 3, 9, 3, 61, 95, 35, 97, 551, 233, 2045, 4873, 9109, 10019, 64523, 0 };
            const std::uint32_t dim4007JoeKuoD6Init[]   =   { 1, 3, 1, 5, 11, 3, 15, 177, 301, 573, 2029, 191, 5551, 12083, 27287, 57235, 0 };
            const std::uint32_t dim4008JoeKuoD6Init[]   =   { 1, 3, 5, 1, 21, 9, 121, 169, 347, 187, 57, 3163, 5609, 1921, 17581, 28351, 0 };
            const std::uint32_t dim4009JoeKuoD6Init[]   =   { 1, 3, 3, 1, 31, 51, 15, 45, 429, 245, 573, 1595, 5343, 7519, 17009, 1299, 0 };
            const std::uint32_t dim4010JoeKuoD6Init[]   =   { 1, 1, 7, 3, 13, 47, 109, 65, 389, 867, 963, 145, 1089, 9749, 19625, 43121, 0 };
            const std::uint32_t dim4011JoeKuoD6Init[]   =   { 1, 3, 1, 7, 21, 61, 77, 67, 143, 579, 625, 2007, 6343, 4259, 21233, 237, 0 };
            const std::uint32_t dim4012JoeKuoD6Init[]   =   { 1, 3, 5, 9, 27, 15, 107, 91, 399, 895, 645, 2301, 439, 6789, 18299, 47285, 0 };
            const std::uint32_t dim4013JoeKuoD6Init[]   =   { 1, 3, 3, 5, 13, 11, 43, 199, 505, 409, 25, 2057, 479, 6031, 9561, 51613, 0 };
            const std::uint32_t dim4014JoeKuoD6Init[]   =   { 1, 1, 7, 13, 15, 55, 105, 53, 171, 925, 1849, 2881, 6951, 13069, 865, 41019, 0 };
            const std::uint32_t dim4015JoeKuoD6Init[]   =   { 1, 3, 1, 9, 17, 31, 45, 23, 411, 185, 189, 2123, 2583, 12713, 12681, 2231, 0 };
            const std::uint32_t dim4016JoeKuoD6Init[]   =   { 1, 3, 7, 9, 3, 63, 11, 253, 177, 127, 545, 3293, 4449, 15995, 10223, 33529, 0 };
            const std::uint32_t dim4017JoeKuoD6Init[]   =   { 1, 1, 5, 11, 13, 7, 53, 161, 421, 551, 697, 627, 3879, 1639, 24419, 3337, 0 };
            const std::uint32_t dim4018JoeKuoD6Init[]   =   { 1, 1, 7, 7, 27, 7, 37, 205, 429, 407, 1133, 3563, 2921, 6173, 11173, 3009, 0 };
            const std::uint32_t dim4019JoeKuoD6Init[]   =   { 1, 3, 3, 15, 31, 39, 117, 81, 337, 729, 567, 2299, 1481, 3189, 1795, 40299, 0 };
            const std::uint32_t dim4020JoeKuoD6Init[]   =   { 1, 3, 5, 15, 15, 47, 91, 127, 275, 55, 951, 3423, 2879, 6115, 1549, 2287, 0 };
            const std::uint32_t dim4021JoeKuoD6Init[]   =   { 1, 3, 3, 11, 17, 3, 127, 207, 141, 889, 185, 1095, 4567, 1371, 30545, 54445, 0 };
            const std::uint32_t dim4022JoeKuoD6Init[]   =   { 1, 1, 7, 3, 25, 11, 11, 139, 43, 1, 1977, 397, 5775, 6913, 13249, 46767, 0 };
            const std::uint32_t dim4023JoeKuoD6Init[]   =   { 1, 1, 7, 7, 27, 13, 31, 251, 191, 1015, 161, 3719, 5321, 13013, 25187, 51881, 0 };
            const std::uint32_t dim4024JoeKuoD6Init[]   =   { 1, 1, 1, 1, 3, 3, 13, 19, 423, 349, 1955, 2103, 6395, 3315, 23809, 25925, 0 };
            const std::uint32_t dim4025JoeKuoD6Init[]   =   { 1, 3, 5, 13, 3, 59, 41, 167, 423, 93, 1299, 2623, 5829, 8537, 8701, 43757, 0 };
            const std::uint32_t dim4026JoeKuoD6Init[]   =   { 1, 3, 5, 11, 9, 19, 127, 119, 329, 819, 7, 3809, 5305, 3643, 27369, 61827, 0 };
            const std::uint32_t dim4027JoeKuoD6Init[]   =   { 1, 3, 1, 15, 25, 43, 55, 159, 205, 911, 983, 2825, 3751, 7845, 12023, 18431, 0 };
            const std::uint32_t dim4028JoeKuoD6Init[]   =   { 1, 3, 3, 13, 11, 1, 65, 133, 479, 181, 679, 981, 3317, 6241, 11693, 9619, 0 };
            const std::uint32_t dim4029JoeKuoD6Init[]   =   { 1, 3, 3, 3, 21, 25, 117, 183, 127, 73, 703, 1469, 257, 11229, 10167, 50847, 0 };
            const std::uint32_t dim4030JoeKuoD6Init[]   =   { 1, 1, 5, 13, 5, 5, 113, 15, 231, 269, 989, 465, 3267, 15239, 29503, 42855, 0 };
            const std::uint32_t dim4031JoeKuoD6Init[]   =   { 1, 3, 3, 15, 9, 63, 79, 27, 21, 709, 1969, 3761, 1015, 13619, 4205, 40591, 0 };
            const std::uint32_t dim4032JoeKuoD6Init[]   =   { 1, 1, 7, 11, 29, 3, 5, 45, 107, 131, 1287, 3551, 849, 2003, 27451, 47103, 0 };
            const std::uint32_t dim4033JoeKuoD6Init[]   =   { 1, 3, 5, 11, 3, 47, 59, 53, 369, 249, 915, 2475, 7539, 763, 7063, 63971, 0 };
            const std::uint32_t dim4034JoeKuoD6Init[]   =   { 1, 1, 5, 1, 7, 53, 45, 127, 321, 341, 635, 2277, 1383, 10951, 29055, 45087, 0 };
            const std::uint32_t dim4035JoeKuoD6Init[]   =   { 1, 3, 7, 3, 5, 1, 119, 79, 487, 93, 25, 491, 4085, 6403, 27779, 8753, 0 };
            const std::uint32_t dim4036JoeKuoD6Init[]   =   { 1, 1, 1, 3, 9, 59, 49, 141, 323, 703, 1175, 423, 4323, 10083, 4289, 28931, 0 };
            const std::uint32_t dim4037JoeKuoD6Init[]   =   { 1, 3, 3, 15, 31, 31, 73, 15, 187, 653, 91, 1707, 1431, 9861, 19071, 8137, 0 };
            const std::uint32_t dim4038JoeKuoD6Init[]   =   { 1, 1, 1, 5, 27, 63, 93, 1, 329, 353, 863, 473, 7681, 10653, 15819, 8495, 0 };
            const std::uint32_t dim4039JoeKuoD6Init[]   =   { 1, 1, 1, 5, 25, 57, 119, 167, 219, 319, 231, 1065, 6217, 5131, 1513, 49281, 0 };
            const std::uint32_t dim4040JoeKuoD6Init[]   =   { 1, 3, 7, 3, 17, 3, 113, 91, 201, 179, 1907, 3423, 821, 12927, 24827, 49403, 0 };
            const std::uint32_t dim4041JoeKuoD6Init[]   =   { 1, 1, 5, 7, 19, 63, 75, 151, 387, 489, 777, 2049, 1151, 1351, 25687, 4143, 0 };
            const std::uint32_t dim4042JoeKuoD6Init[]   =   { 1, 3, 5, 7, 9, 37, 9, 3, 87, 385, 1667, 2139, 7527, 16133, 30023, 28783, 0 };
            const std::uint32_t dim4043JoeKuoD6Init[]   =   { 1, 1, 5, 9, 11, 55, 95, 73, 413, 867, 589, 2901, 3021, 413, 5955, 38921, 0 };
            const std::uint32_t dim4044JoeKuoD6Init[]   =   { 1, 3, 5, 15, 1, 17, 17, 7, 485, 323, 519, 2325, 2255, 4211, 20661, 28931, 0 };
            const std::uint32_t dim4045JoeKuoD6Init[]   =   { 1, 1, 5, 13, 21, 19, 85, 189, 167, 645, 1475, 3095, 7123, 3351, 7961, 20967, 0 };
            const std::uint32_t dim4046JoeKuoD6Init[]   =   { 1, 1, 7, 13, 3, 47, 13, 213, 237, 291, 285, 1465, 1765, 12361, 32651, 54205, 0 };
            const std::uint32_t dim4047JoeKuoD6Init[]   =   { 1, 3, 7, 13, 13, 27, 71, 35, 67, 117, 647, 2359, 3295, 8445, 24761, 29379, 0 };
            const std::uint32_t dim4048JoeKuoD6Init[]   =   { 1, 1, 1, 3, 3, 19, 23, 37, 5, 1019, 5, 1605, 2291, 14015, 9311, 39751, 0 };
            const std::uint32_t dim4049JoeKuoD6Init[]   =   { 1, 3, 3, 3, 31, 1, 65, 159, 221, 675, 1061, 971, 2333, 8265, 14361, 3263, 0 };
            const std::uint32_t dim4050JoeKuoD6Init[]   =   { 1, 1, 3, 7, 3, 5, 81, 17, 101, 991, 753, 2883, 4977, 4409, 1757, 26803, 0 };
            const std::uint32_t dim4051JoeKuoD6Init[]   =   { 1, 1, 5, 9, 13, 25, 45, 43, 199, 967, 829, 713, 4547, 7223, 6497, 53895, 0 };
            const std::uint32_t dim4052JoeKuoD6Init[]   =   { 1, 1, 7, 5, 23, 15, 89, 179, 509, 147, 315, 133, 111, 15577, 23427, 5229, 0 };
            const std::uint32_t dim4053JoeKuoD6Init[]   =   { 1, 3, 3, 7, 27, 7, 113, 65, 315, 135, 1309, 1179, 5755, 7513, 6815, 5137, 0 };
            const std::uint32_t dim4054JoeKuoD6Init[]   =   { 1, 1, 3, 7, 1, 13, 29, 155, 477, 721, 71, 865, 3897, 3331, 30641, 65471, 0 };
            const std::uint32_t dim4055JoeKuoD6Init[]   =   { 1, 1, 7, 3, 29, 45, 83, 3, 461, 109, 1545, 1365, 6633, 16137, 23859, 5995, 0 };
            const std::uint32_t dim4056JoeKuoD6Init[]   =   { 1, 3, 1, 1, 3, 33, 77, 83, 459, 187, 879, 3731, 6939, 6707, 23409, 24245, 0 };
            const std::uint32_t dim4057JoeKuoD6Init[]   =   { 1, 3, 5, 5, 13, 43, 127, 41, 29, 735, 1391, 2947, 4873, 4627, 15, 41719, 0 };
            const std::uint32_t dim4058JoeKuoD6Init[]   =   { 1, 3, 1, 3, 17, 17, 51, 93, 189, 227, 449, 2809, 825, 2009, 9563, 41435, 0 };
            const std::uint32_t dim4059JoeKuoD6Init[]   =   { 1, 3, 3, 11, 25, 47, 113, 173, 141, 919, 677, 117, 5293, 815, 23749, 19789, 0 };
            const std::uint32_t dim4060JoeKuoD6Init[]   =   { 1, 1, 1, 13, 15, 61, 121, 223, 53, 389, 489, 1527, 4771, 8975, 8005, 14275, 0 };
            const std::uint32_t dim4061JoeKuoD6Init[]   =   { 1, 1, 3, 15, 31, 57, 111, 145, 279, 991, 489, 3239, 7647, 473, 31279, 33447, 0 };
            const std::uint32_t dim4062JoeKuoD6Init[]   =   { 1, 1, 7, 5, 31, 13, 75, 185, 395, 611, 609, 159, 7931, 9887, 4115, 53121, 0 };
            const std::uint32_t dim4063JoeKuoD6Init[]   =   { 1, 3, 5, 5, 13, 39, 103, 237, 77, 913, 511, 1583, 6763, 14523, 4247, 63403, 0 };
            const std::uint32_t dim4064JoeKuoD6Init[]   =   { 1, 1, 1, 15, 11, 5, 43, 43, 297, 827, 747, 5, 3785, 15021, 11291, 36743, 0 };
            const std::uint32_t dim4065JoeKuoD6Init[]   =   { 1, 1, 7, 9, 9, 53, 113, 95, 403, 53, 1335, 4033, 8147, 11963, 6523, 23675, 0 };
            const std::uint32_t dim4066JoeKuoD6Init[]   =   { 1, 1, 5, 9, 27, 29, 69, 79, 327, 409, 1147, 1579, 2625, 12227, 30933, 9057, 0 };
            const std::uint32_t dim4067JoeKuoD6Init[]   =   { 1, 1, 1, 7, 1, 33, 29, 173, 5, 517, 437, 2035, 57, 12825, 22095, 65519, 0 };
            const std::uint32_t dim4068JoeKuoD6Init[]   =   { 1, 1, 3, 7, 27, 29, 53, 79, 429, 707, 589, 2605, 339, 7039, 19319, 17649, 0 };
            const std::uint32_t dim4069JoeKuoD6Init[]   =   { 1, 3, 3, 11, 9, 57, 43, 117, 39, 193, 1427, 2553, 6877, 7653, 29041, 44865, 0 };
            const std::uint32_t dim4070JoeKuoD6Init[]   =   { 1, 3, 3, 7, 23, 45, 29, 151, 265, 739, 365, 3565, 6447, 9761, 24021, 679, 0 };
            const std::uint32_t dim4071JoeKuoD6Init[]   =   { 1, 3, 5, 1, 1, 43, 73, 55, 131, 175, 959, 659, 7315, 15145, 18301, 14865, 0 };
            const std::uint32_t dim4072JoeKuoD6Init[]   =   { 1, 1, 3, 5, 15, 15, 91, 113, 359, 241, 1627, 1069, 1761, 211, 32671, 58833, 0 };
            const std::uint32_t dim4073JoeKuoD6Init[]   =   { 1, 3, 3, 7, 29, 27, 79, 53, 409, 81, 693, 3137, 7385, 11007, 28459, 28621, 0 };
            const std::uint32_t dim4074JoeKuoD6Init[]   =   { 1, 1, 7, 5, 29, 7, 67, 195, 77, 773, 1361, 2153, 4459, 7301, 5129, 17797, 0 };
            const std::uint32_t dim4075JoeKuoD6Init[]   =   { 1, 3, 3, 7, 25, 27, 91, 223, 115, 91, 1645, 2167, 1955, 9601, 22127, 13055, 0 };
            const std::uint32_t dim4076JoeKuoD6Init[]   =   { 1, 3, 7, 3, 27, 53, 67, 249, 51, 151, 663, 3231, 895, 6777, 3037, 56755, 0 };
            const std::uint32_t dim4077JoeKuoD6Init[]   =   { 1, 1, 5, 1, 25, 63, 71, 179, 375, 301, 1127, 2125, 783, 14481, 7293, 47883, 0 };
            const std::uint32_t dim4078JoeKuoD6Init[]   =   { 1, 1, 3, 9, 25, 3, 39, 69, 1, 85, 1271, 1571, 1953, 5077, 20369, 44827, 0 };
            const std::uint32_t dim4079JoeKuoD6Init[]   =   { 1, 3, 1, 13, 11, 61, 77, 59, 127, 475, 1609, 3553, 2553, 15589, 9351, 59787, 0 };
            const std::uint32_t dim4080JoeKuoD6Init[]   =   { 1, 3, 1, 5, 21, 7, 61, 27, 199, 653, 1243, 2481, 5369, 12903, 30229, 39453, 0 };
            const std::uint32_t dim4081JoeKuoD6Init[]   =   { 1, 3, 7, 3, 13, 15, 107, 153, 501, 573, 863, 3179, 6019, 15177, 16075, 43767, 0 };
            const std::uint32_t dim4082JoeKuoD6Init[]   =   { 1, 1, 7, 1, 23, 55, 17, 35, 5, 137, 1707, 1377, 6857, 15361, 27299, 61871, 0 };
            const std::uint32_t dim4083JoeKuoD6Init[]   =   { 1, 3, 5, 7, 27, 17, 87, 213, 95, 125, 1239, 3923, 4193, 11049, 12783, 45017, 0 };
            const std::uint32_t dim4084JoeKuoD6Init[]   =   { 1, 1, 5, 15, 9, 55, 11, 217, 7, 249, 369, 205, 4251, 13785, 24781, 48929, 0 };
            const std::uint32_t dim4085JoeKuoD6Init[]   =   { 1, 3, 7, 1, 15, 35, 33, 107, 503, 563, 1591, 3487, 7495, 1767, 24791, 31281, 0 };
            const std::uint32_t dim4086JoeKuoD6Init[]   =   { 1, 3, 1, 11, 3, 15, 47, 193, 289, 253, 909, 1105, 5119, 1415, 7737, 4341, 0 };
            const std::uint32_t dim4087JoeKuoD6Init[]   =   { 1, 1, 1, 3, 23, 33, 53, 187, 469, 573, 835, 2049, 791, 1177, 31051, 30955, 0 };
            const std::uint32_t dim4088JoeKuoD6Init[]   =   { 1, 3, 3, 11, 15, 51, 77, 143, 369, 991, 1103, 1293, 6019, 6361, 26301, 20741, 0 };
            const std::uint32_t dim4089JoeKuoD6Init[]   =   { 1, 1, 1, 5, 17, 19, 85, 135, 113, 593, 579, 1063, 7173, 2491, 9355, 19223, 0 };
            const std::uint32_t dim4090JoeKuoD6Init[]   =   { 1, 1, 5, 15, 25, 51, 107, 193, 31, 1, 1693, 125, 6223, 14619, 22683, 26321, 0 };
            const std::uint32_t dim4091JoeKuoD6Init[]   =   { 1, 1, 7, 1, 17, 45, 87, 39, 87, 499, 1185, 2763, 3989, 2863, 24555, 33817, 0 };
            const std::uint32_t dim4092JoeKuoD6Init[]   =   { 1, 3, 1, 11, 31, 5, 121, 231, 185, 793, 255, 2785, 5261, 3687, 21711, 3941, 0 };
            const std::uint32_t dim4093JoeKuoD6Init[]   =   { 1, 3, 7, 15, 5, 59, 73, 227, 365, 937, 893, 2155, 4385, 14345, 6813, 28461, 0 };
            const std::uint32_t dim4094JoeKuoD6Init[]   =   { 1, 1, 5, 7, 7, 23, 7, 239, 431, 45, 1015, 1663, 1893, 5035, 24075, 2119, 0 };
            const std::uint32_t dim4095JoeKuoD6Init[]   =   { 1, 3, 5, 1, 3, 15, 63, 103, 119, 801, 1681, 3463, 6083, 6453, 11379, 8205, 0 };
            const std::uint32_t dim4096JoeKuoD6Init[]   =   { 1, 3, 7, 9, 21, 61, 9, 9, 433, 541, 603, 3905, 3787, 10187, 3643, 21319, 0 };
            const std::uint32_t dim4097JoeKuoD6Init[]   =   { 1, 3, 5, 3, 11, 1, 101, 243, 363, 559, 561, 1163, 455, 4657, 1147, 39961, 0 };
            const std::uint32_t dim4098JoeKuoD6Init[]   =   { 1, 3, 5, 13, 17, 37, 57, 47, 483, 571, 1579, 1137, 8125, 12271, 23279, 1615, 0 };
            const std::uint32_t dim4099JoeKuoD6Init[]   =   { 1, 3, 5, 1, 21, 5, 13, 155, 75, 705, 389, 2855, 6345, 2279, 12627, 49451, 0 };
            const std::uint32_t dim4100JoeKuoD6Init[]   =   { 1, 1, 3, 9, 15, 51, 73, 99, 445, 227, 1705, 2175, 8111, 9381, 31555, 48491, 0 };
            const std::uint32_t dim4101JoeKuoD6Init[]   =   { 1, 3, 3, 5, 9, 63, 107, 51, 461, 979, 1033, 421, 4807, 11707, 13261, 26015, 0 };
            const std::uint32_t dim4102JoeKuoD6Init[]   =   { 1, 1, 5, 3, 13, 53, 117, 249, 57, 851, 1391, 3245, 35, 16043, 24399, 63667, 0 };
            const std::uint32_t dim4103JoeKuoD6Init[]   =   { 1, 3, 1, 11, 23, 33, 57, 125, 385, 495, 871, 199, 4269, 2269, 22897, 23597, 0 };
            const std::uint32_t dim4104JoeKuoD6Init[]   =   { 1, 3, 5, 15, 29, 11, 77, 21, 479, 369, 723, 3721, 1121, 9463, 19775, 54525, 0 };
            const std::uint32_t dim4105JoeKuoD6Init[]   =   { 1, 3, 5, 7, 7, 45, 29, 153, 395, 223, 1917, 3713, 5087, 10827, 1383, 36823, 0 };
            const std::uint32_t dim4106JoeKuoD6Init[]   =   { 1, 3, 1, 3, 31, 19, 111, 55, 275, 923, 917, 2925, 673, 6579, 18783, 5137, 0 };
            const std::uint32_t dim4107JoeKuoD6Init[]   =   { 1, 3, 1, 15, 25, 31, 59, 255, 31, 697, 1751, 381, 299, 295, 14037, 40953, 0 };
            const std::uint32_t dim4108JoeKuoD6Init[]   =   { 1, 3, 1, 7, 15, 23, 69, 219, 351, 183, 1083, 2227, 6249, 9385, 13167, 2901, 0 };
            const std::uint32_t dim4109JoeKuoD6Init[]   =   { 1, 3, 7, 1, 5, 61, 117, 13, 67, 521, 41, 2929, 3937, 1215, 25593, 32627, 0 };
            const std::uint32_t dim4110JoeKuoD6Init[]   =   { 1, 3, 5, 1, 9, 47, 63, 39, 371, 657, 491, 2243, 4049, 10517, 12409, 40597, 0 };
            const std::uint32_t dim4111JoeKuoD6Init[]   =   { 1, 3, 7, 15, 17, 3, 77, 13, 275, 225, 487, 2055, 1293, 15927, 31773, 18275, 0 };
            const std::uint32_t dim4112JoeKuoD6Init[]   =   { 1, 1, 5, 13, 11, 57, 113, 27, 191, 363, 1341, 3487, 8031, 13801, 7563, 40675, 0 };
            const std::uint32_t dim4113JoeKuoD6Init[]   =   { 1, 1, 3, 3, 27, 31, 103, 143, 271, 305, 2033, 3623, 4219, 9307, 7501, 8959, 0 };
            const std::uint32_t dim4114JoeKuoD6Init[]   =   { 1, 1, 1, 13, 1, 3, 27, 97, 475, 143, 333, 2997, 1807, 4231, 27437, 59717, 0 };
            const std::uint32_t dim4115JoeKuoD6Init[]   =   { 1, 3, 7, 5, 5, 3, 69, 233, 309, 511, 1429, 1887, 2745, 4969, 17595, 5451, 0 };
            const std::uint32_t dim4116JoeKuoD6Init[]   =   { 1, 1, 7, 3, 23, 17, 115, 89, 265, 467, 257, 2027, 5331, 1195, 4451, 8621, 0 };
            const std::uint32_t dim4117JoeKuoD6Init[]   =   { 1, 1, 7, 13, 29, 35, 117, 155, 99, 327, 853, 3595, 2997, 10745, 21619, 26549, 0 };
            const std::uint32_t dim4118JoeKuoD6Init[]   =   { 1, 3, 3, 13, 1, 13, 75, 151, 67, 271, 1609, 1117, 4293, 4645, 12005, 55983, 0 };
            const std::uint32_t dim4119JoeKuoD6Init[]   =   { 1, 1, 1, 13, 1, 61, 101, 63, 161, 261, 1759, 567, 665, 2339, 9157, 55603, 0 };
            const std::uint32_t dim4120JoeKuoD6Init[]   =   { 1, 1, 7, 11, 25, 19, 71, 27, 255, 435, 227, 4087, 4309, 14903, 14513, 30207, 0 };
            const std::uint32_t dim4121JoeKuoD6Init[]   =   { 1, 3, 3, 3, 11, 41, 1, 67, 383, 403, 45, 1521, 1535, 3353, 27361, 7549, 0 };
            const std::uint32_t dim4122JoeKuoD6Init[]   =   { 1, 1, 1, 1, 13, 51, 31, 137, 147, 907, 19, 3639, 3739, 877, 15005, 60357, 0 };
            const std::uint32_t dim4123JoeKuoD6Init[]   =   { 1, 1, 3, 11, 11, 23, 29, 173, 105, 873, 1727, 2761, 2015, 7491, 17491, 41065, 0 };
            const std::uint32_t dim4124JoeKuoD6Init[]   =   { 1, 1, 5, 3, 31, 1, 119, 53, 11, 731, 393, 4031, 4421, 15715, 6431, 18089, 0 };
            const std::uint32_t dim4125JoeKuoD6Init[]   =   { 1, 1, 3, 5, 15, 37, 55, 147, 307, 521, 711, 3085, 5989, 8081, 23351, 35259, 0 };
            const std::uint32_t dim4126JoeKuoD6Init[]   =   { 1, 3, 5, 13, 21, 19, 47, 107, 447, 713, 1655, 2809, 4741, 2105, 9255, 103, 0 };
            const std::uint32_t dim4127JoeKuoD6Init[]   =   { 1, 3, 1, 3, 17, 47, 63, 125, 343, 763, 1777, 607, 5625, 9517, 7221, 27257, 0 };
            const std::uint32_t dim4128JoeKuoD6Init[]   =   { 1, 1, 7, 5, 31, 13, 67, 255, 41, 947, 99, 721, 7367, 11427, 1357, 12383, 0 };
            const std::uint32_t dim4129JoeKuoD6Init[]   =   { 1, 1, 7, 3, 23, 27, 73, 185, 189, 545, 1877, 3169, 5419, 15873, 29059, 23983, 0 };
            const std::uint32_t dim4130JoeKuoD6Init[]   =   { 1, 1, 3, 1, 5, 13, 81, 45, 79, 717, 819, 3539, 7561, 7319, 5113, 27273, 0 };
            const std::uint32_t dim4131JoeKuoD6Init[]   =   { 1, 3, 7, 9, 21, 25, 71, 247, 41, 583, 771, 3745, 1883, 5717, 755, 14549, 0 };
            const std::uint32_t dim4132JoeKuoD6Init[]   =   { 1, 1, 3, 7, 23, 25, 87, 143, 499, 515, 1753, 1229, 173, 10629, 30579, 29643, 0 };
            const std::uint32_t dim4133JoeKuoD6Init[]   =   { 1, 3, 1, 13, 29, 33, 31, 69, 503, 117, 1717, 101, 7647, 1567, 28677, 3079, 0 };
            const std::uint32_t dim4134JoeKuoD6Init[]   =   { 1, 3, 1, 15, 29, 45, 57, 81, 171, 813, 505, 3647, 3913, 5557, 2477, 42429, 0 };
            const std::uint32_t dim4135JoeKuoD6Init[]   =   { 1, 1, 5, 13, 21, 13, 81, 5, 471, 221, 1563, 1741, 7269, 16327, 22687, 5291, 0 };
            const std::uint32_t dim4136JoeKuoD6Init[]   =   { 1, 3, 5, 3, 23, 41, 107, 61, 95, 79, 467, 1533, 739, 6791, 26911, 20309, 0 };
            const std::uint32_t dim4137JoeKuoD6Init[]   =   { 1, 3, 7, 7, 3, 53, 71, 163, 459, 975, 687, 1115, 5241, 299, 26361, 38583, 0 };
            const std::uint32_t dim4138JoeKuoD6Init[]   =   { 1, 3, 1, 9, 3, 63, 7, 133, 421, 325, 823, 1175, 6201, 5707, 31539, 34645, 0 };
            const std::uint32_t dim4139JoeKuoD6Init[]   =   { 1, 3, 7, 5, 27, 27, 107, 239, 247, 257, 1367, 3685, 7839, 11693, 3237, 13085, 0 };
            const std::uint32_t dim4140JoeKuoD6Init[]   =   { 1, 1, 1, 3, 27, 41, 51, 69, 271, 809, 1453, 519, 1301, 2367, 637, 5267, 0 };
            const std::uint32_t dim4141JoeKuoD6Init[]   =   { 1, 3, 7, 13, 19, 17, 3, 69, 369, 447, 1685, 4075, 6143, 11387, 5411, 29825, 0 };
            const std::uint32_t dim4142JoeKuoD6Init[]   =   { 1, 1, 3, 1, 25, 61, 79, 163, 1, 905, 1969, 2735, 7709, 16121, 20441, 4543, 0 };
            const std::uint32_t dim4143JoeKuoD6Init[]   =   { 1, 3, 7, 5, 15, 29, 7, 245, 343, 803, 1719, 3993, 983, 2925, 10393, 6053, 0 };
            const std::uint32_t dim4144JoeKuoD6Init[]   =   { 1, 3, 1, 7, 17, 55, 63, 29, 441, 387, 885, 3269, 1977, 1927, 3657, 47043, 0 };
            const std::uint32_t dim4145JoeKuoD6Init[]   =   { 1, 1, 3, 1, 17, 59, 51, 9, 173, 327, 1185, 3241, 3785, 10907, 19429, 22209, 0 };
            const std::uint32_t dim4146JoeKuoD6Init[]   =   { 1, 1, 3, 13, 21, 57, 125, 5, 359, 437, 1231, 2441, 5813, 9991, 283, 52555, 0 };
            const std::uint32_t dim4147JoeKuoD6Init[]   =   { 1, 3, 1, 7, 15, 19, 39, 125, 405, 381, 1757, 4075, 5565, 2065, 295, 8867, 0 };
            const std::uint32_t dim4148JoeKuoD6Init[]   =   { 1, 3, 3, 11, 7, 33, 95, 19, 253, 141, 1093, 1787, 7495, 5229, 15923, 44157, 0 };
            const std::uint32_t dim4149JoeKuoD6Init[]   =   { 1, 3, 7, 15, 1, 49, 69, 163, 85, 345, 901, 2329, 8003, 9915, 2209, 33979, 0 };
            const std::uint32_t dim4150JoeKuoD6Init[]   =   { 1, 1, 1, 9, 23, 51, 125, 163, 257, 681, 565, 945, 6375, 8679, 5985, 28919, 0 };
            const std::uint32_t dim4151JoeKuoD6Init[]   =   { 1, 3, 5, 7, 11, 23, 123, 231, 377, 121, 1519, 2061, 2957, 14537, 17625, 37773, 0 };
            const std::uint32_t dim4152JoeKuoD6Init[]   =   { 1, 3, 5, 1, 17, 43, 89, 119, 455, 279, 1857, 3405, 5225, 13035, 6055, 30861, 0 };
            const std::uint32_t dim4153JoeKuoD6Init[]   =   { 1, 3, 7, 15, 31, 63, 25, 225, 3, 527, 355, 1435, 5763, 15203, 26579, 45659, 0 };
            const std::uint32_t dim4154JoeKuoD6Init[]   =   { 1, 1, 1, 3, 27, 43, 71, 193, 135, 5, 683, 925, 7023, 7711, 2807, 56003, 0 };
            const std::uint32_t dim4155JoeKuoD6Init[]   =   { 1, 1, 1, 11, 3, 3, 109, 29, 109, 683, 419, 3295, 1961, 5953, 8887, 1523, 0 };
            const std::uint32_t dim4156JoeKuoD6Init[]   =   { 1, 3, 3, 11, 17, 39, 19, 225, 103, 249, 81, 3875, 4515, 3969, 24745, 60031, 0 };
            const std::uint32_t dim4157JoeKuoD6Init[]   =   { 1, 1, 3, 3, 3, 23, 15, 149, 305, 399, 1347, 1001, 597, 10003, 22123, 29919, 0 };
            const std::uint32_t dim4158JoeKuoD6Init[]   =   { 1, 3, 5, 1, 23, 35, 123, 7, 283, 283, 759, 3061, 2011, 7771, 32201, 40667, 0 };
            const std::uint32_t dim4159JoeKuoD6Init[]   =   { 1, 3, 7, 15, 23, 5, 81, 51, 357, 79, 133, 285, 425, 7743, 13499, 18983, 0 };
            const std::uint32_t dim4160JoeKuoD6Init[]   =   { 1, 3, 3, 5, 17, 37, 75, 221, 473, 111, 335, 683, 7353, 2283, 13457, 61171, 0 };
            const std::uint32_t dim4161JoeKuoD6Init[]   =   { 1, 3, 1, 7, 13, 45, 13, 223, 149, 209, 727, 3553, 2573, 177, 855, 44139, 0 };
            const std::uint32_t dim4162JoeKuoD6Init[]   =   { 1, 1, 3, 15, 23, 5, 103, 139, 17, 29, 1961, 3021, 5745, 12963, 30669, 44171, 0 };
            const std::uint32_t dim4163JoeKuoD6Init[]   =   { 1, 3, 1, 1, 3, 33, 67, 203, 29, 785, 71, 1693, 4487, 10221, 24523, 51223, 0 };
            const std::uint32_t dim4164JoeKuoD6Init[]   =   { 1, 1, 5, 7, 7, 27, 17, 183, 229, 669, 1675, 3751, 3233, 10677, 7509, 52313, 0 };
            const std::uint32_t dim4165JoeKuoD6Init[]   =   { 1, 1, 5, 5, 25, 35, 21, 163, 483, 399, 195, 3465, 6349, 545, 18861, 31759, 0 };
            const std::uint32_t dim4166JoeKuoD6Init[]   =   { 1, 3, 1, 5, 15, 39, 13, 157, 71, 841, 447, 3625, 53, 12745, 2719, 27617, 0 };
            const std::uint32_t dim4167JoeKuoD6Init[]   =   { 1, 1, 5, 5, 3, 45, 113, 121, 263, 887, 709, 2189, 3811, 1409, 10451, 48777, 0 };
            const std::uint32_t dim4168JoeKuoD6Init[]   =   { 1, 1, 5, 15, 9, 41, 31, 95, 377, 215, 437, 3633, 433, 11935, 15283, 55451, 0 };
            const std::uint32_t dim4169JoeKuoD6Init[]   =   { 1, 1, 7, 7, 13, 23, 79, 3, 451, 409, 1103, 1771, 553, 3175, 28703, 49357, 0 };
            const std::uint32_t dim4170JoeKuoD6Init[]   =   { 1, 3, 1, 1, 13, 33, 95, 133, 419, 851, 955, 3985, 5869, 14219, 253, 46883, 0 };
            const std::uint32_t dim4171JoeKuoD6Init[]   =   { 1, 3, 3, 3, 23, 55, 91, 207, 281, 355, 361, 261, 6837, 4401, 25455, 25313, 0 };
            const std::uint32_t dim4172JoeKuoD6Init[]   =   { 1, 3, 5, 9, 27, 9, 107, 51, 69, 555, 835, 3541, 1827, 5737, 31225, 55619, 0 };
            const std::uint32_t dim4173JoeKuoD6Init[]   =   { 1, 1, 1, 11, 27, 51, 79, 85, 447, 447, 9, 2803, 377, 4347, 2183, 61257, 0 };
            const std::uint32_t dim4174JoeKuoD6Init[]   =   { 1, 1, 1, 3, 23, 21, 51, 217, 297, 135, 573, 689, 4947, 14143, 26247, 43061, 0 };
            const std::uint32_t dim4175JoeKuoD6Init[]   =   { 1, 3, 1, 7, 15, 13, 27, 151, 463, 707, 43, 3641, 4999, 3783, 9083, 22085, 0 };
            const std::uint32_t dim4176JoeKuoD6Init[]   =   { 1, 3, 3, 5, 3, 1, 15, 119, 343, 605, 105, 2939, 2259, 889, 21759, 34073, 0 };
            const std::uint32_t dim4177JoeKuoD6Init[]   =   { 1, 1, 1, 7, 3, 63, 103, 1, 235, 317, 263, 2701, 7331, 15921, 17295, 613, 0 };
            const std::uint32_t dim4178JoeKuoD6Init[]   =   { 1, 1, 7, 3, 19, 3, 5, 17, 105, 491, 755, 233, 5397, 12365, 16325, 59377, 0 };
            const std::uint32_t dim4179JoeKuoD6Init[]   =   { 1, 3, 3, 15, 15, 27, 37, 151, 481, 949, 1473, 233, 1925, 15471, 24957, 3241, 0 };
            const std::uint32_t dim4180JoeKuoD6Init[]   =   { 1, 1, 7, 5, 9, 61, 49, 91, 169, 179, 701, 3957, 473, 15087, 6109, 25083, 0 };
            const std::uint32_t dim4181JoeKuoD6Init[]   =   { 1, 3, 3, 11, 27, 43, 5, 33, 69, 705, 733, 2675, 2677, 4235, 11109, 15557, 0 };
            const std::uint32_t dim4182JoeKuoD6Init[]   =   { 1, 3, 1, 3, 17, 19, 101, 119, 289, 341, 1395, 563, 6859, 10359, 10077, 26905, 0 };
            const std::uint32_t dim4183JoeKuoD6Init[]   =   { 1, 1, 1, 15, 21, 47, 41, 145, 439, 583, 1755, 1977, 5235, 15961, 21315, 60577, 0 };
            const std::uint32_t dim4184JoeKuoD6Init[]   =   { 1, 1, 5, 3, 9, 59, 71, 143, 27, 1007, 313, 1567, 1685, 11063, 28889, 44253, 0 };
            const std::uint32_t dim4185JoeKuoD6Init[]   =   { 1, 1, 5, 5, 29, 29, 43, 127, 13, 585, 1245, 187, 2697, 8791, 19561, 6463, 0 };
            const std::uint32_t dim4186JoeKuoD6Init[]   =   { 1, 1, 3, 11, 29, 39, 127, 75, 23, 521, 421, 3115, 139, 5429, 23341, 58035, 0 };
            const std::uint32_t dim4187JoeKuoD6Init[]   =   { 1, 1, 3, 1, 27, 35, 27, 9, 185, 653, 887, 2715, 3775, 1753, 22105, 62095, 0 };
            const std::uint32_t dim4188JoeKuoD6Init[]   =   { 1, 1, 5, 5, 5, 63, 23, 31, 317, 1001, 1751, 1185, 7933, 525, 30501, 15565, 0 };
            const std::uint32_t dim4189JoeKuoD6Init[]   =   { 1, 1, 1, 5, 9, 27, 79, 91, 453, 995, 1041, 3213, 8027, 5855, 7435, 64079, 0 };
            const std::uint32_t dim4190JoeKuoD6Init[]   =   { 1, 1, 3, 11, 1, 51, 27, 195, 139, 41, 1891, 1437, 1033, 11671, 3235, 35083, 0 };
            const std::uint32_t dim4191JoeKuoD6Init[]   =   { 1, 3, 1, 3, 11, 25, 33, 249, 373, 497, 1631, 293, 3657, 10741, 15831, 59545, 0 };
            const std::uint32_t dim4192JoeKuoD6Init[]   =   { 1, 1, 1, 1, 15, 63, 13, 165, 113, 559, 1615, 3579, 1993, 1907, 22335, 47791, 0 };
            const std::uint32_t dim4193JoeKuoD6Init[]   =   { 1, 1, 3, 15, 13, 49, 63, 235, 31, 811, 1729, 221, 5143, 11547, 30029, 52003, 0 };
            const std::uint32_t dim4194JoeKuoD6Init[]   =   { 1, 1, 5, 13, 29, 61, 25, 221, 421, 221, 583, 373, 2341, 7493, 13981, 54141, 0 };
            const std::uint32_t dim4195JoeKuoD6Init[]   =   { 1, 1, 5, 11, 21, 49, 71, 249, 237, 369, 1273, 1067, 4411, 409, 7219, 52933, 0 };
            const std::uint32_t dim4196JoeKuoD6Init[]   =   { 1, 3, 1, 1, 13, 23, 53, 15, 137, 553, 401, 2247, 5591, 14021, 445, 20433, 0 };
            const std::uint32_t dim4197JoeKuoD6Init[]   =   { 1, 1, 7, 7, 7, 23, 19, 189, 119, 643, 847, 2123, 5343, 11839, 4575, 60461, 0 };
            const std::uint32_t dim4198JoeKuoD6Init[]   =   { 1, 1, 5, 5, 11, 19, 111, 219, 185, 499, 595, 723, 3519, 10891, 27603, 29261, 0 };
            const std::uint32_t dim4199JoeKuoD6Init[]   =   { 1, 3, 3, 1, 9, 13, 95, 227, 459, 133, 1535, 3481, 7187, 14797, 16511, 6737, 0 };
            const std::uint32_t dim4200JoeKuoD6Init[]   =   { 1, 1, 7, 7, 19, 57, 117, 7, 455, 941, 455, 797, 6313, 10071, 18651, 25013, 0 };
            const std::uint32_t dim4201JoeKuoD6Init[]   =   { 1, 3, 7, 3, 25, 25, 79, 19, 383, 971, 1625, 2803, 2461, 633, 32317, 48407, 0 };
            const std::uint32_t dim4202JoeKuoD6Init[]   =   { 1, 1, 7, 7, 25, 43, 93, 135, 155, 685, 2001, 3007, 7315, 15555, 30401, 36291, 0 };
            const std::uint32_t dim4203JoeKuoD6Init[]   =   { 1, 1, 1, 5, 13, 33, 123, 221, 341, 105, 1075, 3125, 5323, 14293, 29875, 52215, 0 };
            const std::uint32_t dim4204JoeKuoD6Init[]   =   { 1, 1, 3, 9, 29, 51, 25, 59, 171, 563, 1695, 2845, 6067, 10671, 2909, 33977, 0 };
            const std::uint32_t dim4205JoeKuoD6Init[]   =   { 1, 3, 3, 7, 25, 21, 39, 65, 485, 949, 1773, 2775, 6019, 14587, 6715, 54793, 0 };
            const std::uint32_t dim4206JoeKuoD6Init[]   =   { 1, 1, 7, 11, 17, 57, 125, 17, 111, 167, 289, 3939, 7357, 2289, 1717, 45225, 0 };
            const std::uint32_t dim4207JoeKuoD6Init[]   =   { 1, 1, 7, 7, 21, 55, 3, 139, 471, 747, 1437, 1353, 7657, 13133, 14193, 38191, 0 };
            const std::uint32_t dim4208JoeKuoD6Init[]   =   { 1, 3, 5, 7, 25, 57, 55, 17, 315, 159, 437, 933, 7493, 6025, 2775, 24287, 0 };
            const std::uint32_t dim4209JoeKuoD6Init[]   =   { 1, 1, 7, 1, 15, 45, 67, 191, 355, 681, 1763, 1237, 105, 1425, 26089, 42879, 0 };
            const std::uint32_t dim4210JoeKuoD6Init[]   =   { 1, 1, 5, 13, 13, 53, 25, 127, 103, 155, 935, 2561, 475, 4341, 30541, 43835, 0 };
            const std::uint32_t dim4211JoeKuoD6Init[]   =   { 1, 1, 5, 15, 27, 59, 99, 173, 189, 41, 105, 3287, 4071, 15005, 18301, 34487, 0 };
            const std::uint32_t dim4212JoeKuoD6Init[]   =   { 1, 1, 5, 11, 21, 9, 57, 115, 495, 561, 579, 397, 3049, 2007, 5041, 37345, 0 };
            const std::uint32_t dim4213JoeKuoD6Init[]   =   { 1, 1, 5, 11, 15, 11, 101, 241, 69, 483, 1007, 4069, 5221, 5323, 20177, 24397, 0 };
            const std::uint32_t dim4214JoeKuoD6Init[]   =   { 1, 1, 1, 7, 29, 15, 119, 161, 21, 517, 847, 2217, 4487, 4817, 24053, 21683, 0 };
            const std::uint32_t dim4215JoeKuoD6Init[]   =   { 1, 3, 1, 3, 3, 51, 85, 63, 345, 799, 1699, 3961, 7109, 3931, 28173, 46851, 0 };
            const std::uint32_t dim4216JoeKuoD6Init[]   =   { 1, 1, 5, 7, 15, 25, 97, 139, 331, 969, 1129, 2451, 3107, 12235, 12949, 29837, 0 };
            const std::uint32_t dim4217JoeKuoD6Init[]   =   { 1, 3, 7, 1, 19, 21, 51, 155, 295, 565, 29, 2107, 341, 14611, 15281, 50727, 0 };
            const std::uint32_t dim4218JoeKuoD6Init[]   =   { 1, 3, 1, 11, 3, 37, 13, 217, 429, 217, 301, 1217, 5655, 13845, 32465, 23559, 0 };
            const std::uint32_t dim4219JoeKuoD6Init[]   =   { 1, 3, 3, 9, 9, 57, 79, 231, 433, 703, 699, 3813, 7035, 5885, 19185, 52551, 0 };
            const std::uint32_t dim4220JoeKuoD6Init[]   =   { 1, 1, 1, 5, 19, 17, 31, 209, 49, 515, 279, 909, 5881, 2673, 23635, 23101, 0 };
            const std::uint32_t dim4221JoeKuoD6Init[]   =   { 1, 1, 5, 7, 3, 3, 119, 139, 245, 775, 1009, 1157, 1405, 9737, 17671, 62981, 0 };
            const std::uint32_t dim4222JoeKuoD6Init[]   =   { 1, 3, 7, 11, 17, 21, 105, 21, 67, 871, 233, 3607, 571, 9141, 9751, 28093, 0 };
            const std::uint32_t dim4223JoeKuoD6Init[]   =   { 1, 1, 3, 13, 5, 53, 91, 181, 143, 375, 1113, 705, 837, 10505, 11459, 57753, 0 };
            const std::uint32_t dim4224JoeKuoD6Init[]   =   { 1, 3, 5, 11, 9, 19, 107, 229, 305, 107, 1027, 691, 4677, 8987, 7931, 951, 0 };
            const std::uint32_t dim4225JoeKuoD6Init[]   =   { 1, 1, 7, 9, 9, 17, 39, 195, 103, 315, 517, 123, 7167, 7039, 3571, 40469, 0 };
            const std::uint32_t dim4226JoeKuoD6Init[]   =   { 1, 1, 1, 5, 1, 21, 121, 53, 427, 111, 717, 1065, 2843, 5873, 28411, 42443, 0 };
            const std::uint32_t dim4227JoeKuoD6Init[]   =   { 1, 1, 3, 11, 27, 7, 37, 255, 429, 363, 997, 2429, 6871, 1271, 29375, 62897, 0 };
            const std::uint32_t dim4228JoeKuoD6Init[]   =   { 1, 3, 3, 13, 23, 23, 123, 119, 213, 51, 771, 1603, 1621, 1497, 23667, 13443, 0 };
            const std::uint32_t dim4229JoeKuoD6Init[]   =   { 1, 1, 3, 13, 17, 21, 81, 17, 211, 815, 1751, 3875, 4001, 3927, 6185, 28753, 0 };
            const std::uint32_t dim4230JoeKuoD6Init[]   =   { 1, 3, 1, 5, 13, 41, 23, 187, 475, 353, 1307, 543, 5077, 3459, 20553, 29119, 0 };
            const std::uint32_t dim4231JoeKuoD6Init[]   =   { 1, 1, 1, 7, 1, 39, 3, 247, 375, 101, 81, 1515, 1079, 15307, 18865, 63115, 0 };
            const std::uint32_t dim4232JoeKuoD6Init[]   =   { 1, 1, 5, 9, 23, 7, 61, 45, 379, 553, 435, 1805, 4147, 2289, 22081, 40041, 0 };
            const std::uint32_t dim4233JoeKuoD6Init[]   =   { 1, 1, 7, 3, 17, 13, 107, 169, 119, 981, 1825, 3329, 7779, 12245, 28367, 6749, 0 };
            const std::uint32_t dim4234JoeKuoD6Init[]   =   { 1, 3, 3, 13, 29, 13, 93, 155, 331, 507, 1073, 279, 6615, 14077, 3005, 10171, 0 };
            const std::uint32_t dim4235JoeKuoD6Init[]   =   { 1, 1, 5, 7, 29, 23, 81, 181, 321, 921, 1531, 2607, 7291, 1255, 29889, 30095, 0 };
            const std::uint32_t dim4236JoeKuoD6Init[]   =   { 1, 1, 1, 5, 7, 1, 9, 231, 203, 559, 243, 3999, 3649, 7939, 14729, 34771, 0 };
            const std::uint32_t dim4237JoeKuoD6Init[]   =   { 1, 3, 7, 3, 17, 29, 79, 251, 305, 641, 1125, 1155, 7139, 6721, 43, 34927, 0 };
            const std::uint32_t dim4238JoeKuoD6Init[]   =   { 1, 1, 5, 13, 21, 39, 55, 103, 143, 487, 849, 1111, 1105, 8483, 5417, 10521, 0 };
            const std::uint32_t dim4239JoeKuoD6Init[]   =   { 1, 1, 5, 5, 19, 5, 111, 49, 95, 917, 843, 2539, 6831, 9019, 16045, 59363, 0 };
            const std::uint32_t dim4240JoeKuoD6Init[]   =   { 1, 3, 3, 11, 7, 45, 87, 51, 49, 615, 603, 1623, 5351, 11939, 21945, 40539, 0 };
            const std::uint32_t dim4241JoeKuoD6Init[]   =   { 1, 1, 5, 9, 9, 33, 113, 37, 163, 853, 1313, 4021, 965, 11465, 8573, 24425, 0 };
            const std::uint32_t dim4242JoeKuoD6Init[]   =   { 1, 3, 3, 9, 17, 19, 121, 95, 93, 441, 1951, 3335, 6279, 16087, 14763, 60771, 0 };
            const std::uint32_t dim4243JoeKuoD6Init[]   =   { 1, 3, 3, 9, 13, 15, 19, 129, 257, 641, 533, 1667, 5959, 2259, 10439, 29745, 0 };
            const std::uint32_t dim4244JoeKuoD6Init[]   =   { 1, 1, 7, 7, 11, 31, 45, 247, 233, 101, 899, 2033, 7803, 11423, 30645, 7723, 0 };
            const std::uint32_t dim4245JoeKuoD6Init[]   =   { 1, 3, 5, 11, 23, 3, 69, 79, 319, 125, 1463, 2047, 7311, 5819, 445, 13725, 0 };
            const std::uint32_t dim4246JoeKuoD6Init[]   =   { 1, 1, 1, 3, 7, 43, 83, 89, 467, 709, 1993, 3773, 7805, 305, 15701, 51101, 0 };
            const std::uint32_t dim4247JoeKuoD6Init[]   =   { 1, 1, 7, 5, 19, 53, 77, 237, 27, 853, 1003, 2041, 5739, 4663, 9783, 23761, 0 };
            const std::uint32_t dim4248JoeKuoD6Init[]   =   { 1, 1, 3, 7, 19, 31, 71, 33, 479, 693, 1503, 9, 2779, 1481, 9413, 36227, 0 };
            const std::uint32_t dim4249JoeKuoD6Init[]   =   { 1, 3, 1, 11, 9, 23, 1, 99, 247, 33, 1987, 1577, 8029, 7785, 29947, 38751, 0 };
            const std::uint32_t dim4250JoeKuoD6Init[]   =   { 1, 1, 1, 3, 15, 57, 23, 53, 431, 553, 1433, 2447, 1871, 10701, 30961, 12281, 0 };
            const std::uint32_t dim4251JoeKuoD6Init[]   =   { 1, 3, 5, 9, 11, 49, 123, 91, 87, 155, 301, 3339, 6183, 15895, 17309, 45927, 0 };
            const std::uint32_t dim4252JoeKuoD6Init[]   =   { 1, 1, 1, 9, 9, 41, 79, 123, 261, 547, 1931, 2553, 7405, 14431, 24079, 20769, 0 };
            const std::uint32_t dim4253JoeKuoD6Init[]   =   { 1, 3, 1, 3, 31, 17, 17, 137, 419, 591, 1693, 3977, 861, 16025, 189, 60995, 0 };
            const std::uint32_t dim4254JoeKuoD6Init[]   =   { 1, 3, 7, 11, 19, 47, 107, 243, 87, 135, 507, 189, 1397, 3841, 22999, 50781, 0 };
            const std::uint32_t dim4255JoeKuoD6Init[]   =   { 1, 3, 5, 5, 15, 11, 19, 239, 133, 295, 673, 2389, 4753, 4363, 21669, 25579, 0 };
            const std::uint32_t dim4256JoeKuoD6Init[]   =   { 1, 3, 5, 7, 19, 43, 55, 129, 239, 89, 1731, 1381, 5483, 11773, 9201, 17745, 0 };
            const std::uint32_t dim4257JoeKuoD6Init[]   =   { 1, 3, 1, 13, 3, 15, 77, 131, 417, 845, 1953, 2871, 1789, 10343, 11363, 20699, 0 };
            const std::uint32_t dim4258JoeKuoD6Init[]   =   { 1, 3, 7, 1, 9, 43, 55, 223, 239, 317, 1951, 2725, 209, 3853, 2201, 6839, 0 };
            const std::uint32_t dim4259JoeKuoD6Init[]   =   { 1, 3, 1, 3, 7, 35, 29, 21, 149, 779, 467, 65, 811, 4859, 14021, 38429, 0 };
            const std::uint32_t dim4260JoeKuoD6Init[]   =   { 1, 3, 7, 1, 19, 31, 97, 9, 11, 415, 689, 1513, 2475, 5039, 5669, 65103, 0 };
            const std::uint32_t dim4261JoeKuoD6Init[]   =   { 1, 3, 3, 3, 11, 25, 37, 247, 189, 911, 429, 2395, 3653, 79, 28115, 23513, 0 };
            const std::uint32_t dim4262JoeKuoD6Init[]   =   { 1, 1, 5, 5, 5, 27, 25, 45, 291, 455, 741, 2259, 8131, 11779, 14693, 58729, 0 };
            const std::uint32_t dim4263JoeKuoD6Init[]   =   { 1, 3, 3, 7, 21, 33, 67, 49, 153, 491, 1811, 1955, 925, 15555, 13801, 48717, 0 };
            const std::uint32_t dim4264JoeKuoD6Init[]   =   { 1, 3, 1, 3, 11, 53, 105, 129, 457, 225, 497, 1123, 973, 2901, 26655, 3643, 0 };
            const std::uint32_t dim4265JoeKuoD6Init[]   =   { 1, 1, 7, 13, 29, 49, 71, 37, 321, 865, 735, 357, 7629, 6011, 28221, 39041, 0 };
            const std::uint32_t dim4266JoeKuoD6Init[]   =   { 1, 3, 5, 3, 19, 59, 65, 199, 69, 391, 1735, 3075, 287, 16213, 3211, 22425, 0 };
            const std::uint32_t dim4267JoeKuoD6Init[]   =   { 1, 1, 1, 5, 15, 61, 67, 255, 5, 689, 759, 155, 7245, 5881, 21685, 3863, 0 };
            const std::uint32_t dim4268JoeKuoD6Init[]   =   { 1, 1, 3, 11, 23, 63, 69, 241, 359, 735, 371, 603, 2707, 15833, 31795, 14901, 0 };
            const std::uint32_t dim4269JoeKuoD6Init[]   =   { 1, 1, 1, 7, 19, 33, 83, 19, 13, 667, 317, 3891, 5497, 8213, 4913, 22387, 0 };
            const std::uint32_t dim4270JoeKuoD6Init[]   =   { 1, 3, 5, 9, 13, 21, 11, 187, 249, 647, 349, 605, 2199, 5033, 29773, 48953, 0 };
            const std::uint32_t dim4271JoeKuoD6Init[]   =   { 1, 3, 3, 11, 3, 3, 93, 235, 441, 933, 383, 2007, 4015, 4175, 3937, 20623, 0 };
            const std::uint32_t dim4272JoeKuoD6Init[]   =   { 1, 3, 7, 13, 3, 61, 87, 219, 263, 651, 1343, 2709, 31, 16249, 4749, 28909, 0 };
            const std::uint32_t dim4273JoeKuoD6Init[]   =   { 1, 3, 1, 1, 17, 19, 101, 107, 499, 127, 13, 2123, 5597, 3751, 14527, 12009, 0 };
            const std::uint32_t dim4274JoeKuoD6Init[]   =   { 1, 3, 5, 13, 27, 57, 1, 195, 107, 947, 1475, 2831, 6449, 16117, 20555, 61513, 0 };
            const std::uint32_t dim4275JoeKuoD6Init[]   =   { 1, 3, 1, 9, 9, 47, 89, 187, 401, 299, 637, 197, 1235, 12655, 25025, 24443, 0 };
            const std::uint32_t dim4276JoeKuoD6Init[]   =   { 1, 1, 3, 5, 9, 57, 33, 41, 451, 983, 391, 2707, 705, 13913, 28843, 34091, 0 };
            const std::uint32_t dim4277JoeKuoD6Init[]   =   { 1, 3, 5, 3, 29, 19, 61, 31, 349, 253, 1267, 3345, 2151, 11309, 19623, 62407, 0 };
            const std::uint32_t dim4278JoeKuoD6Init[]   =   { 1, 1, 1, 3, 11, 37, 31, 59, 1, 253, 103, 2811, 1871, 4239, 26311, 32507, 0 };
            const std::uint32_t dim4279JoeKuoD6Init[]   =   { 1, 1, 5, 7, 7, 7, 69, 63, 281, 901, 1785, 2131, 4265, 253, 13997, 30177, 0 };
            const std::uint32_t dim4280JoeKuoD6Init[]   =   { 1, 3, 1, 11, 3, 27, 111, 67, 411, 751, 241, 293, 6271, 4187, 22119, 63737, 0 };
            const std::uint32_t dim4281JoeKuoD6Init[]   =   { 1, 3, 5, 5, 27, 19, 45, 203, 81, 59, 1839, 935, 4847, 1869, 12037, 30971, 0 };
            const std::uint32_t dim4282JoeKuoD6Init[]   =   { 1, 1, 3, 9, 19, 25, 9, 27, 373, 875, 1735, 689, 2957, 7873, 29771, 4093, 0 };
            const std::uint32_t dim4283JoeKuoD6Init[]   =   { 1, 1, 7, 11, 13, 39, 11, 129, 53, 433, 1731, 899, 5855, 10221, 24165, 50205, 0 };
            const std::uint32_t dim4284JoeKuoD6Init[]   =   { 1, 3, 1, 15, 25, 31, 85, 49, 325, 299, 183, 287, 2425, 15353, 25999, 59129, 0 };
            const std::uint32_t dim4285JoeKuoD6Init[]   =   { 1, 1, 5, 5, 17, 25, 23, 5, 287, 677, 591, 981, 429, 15297, 14573, 61095, 0 };
            const std::uint32_t dim4286JoeKuoD6Init[]   =   { 1, 1, 5, 15, 5, 15, 67, 195, 209, 341, 1621, 1379, 3031, 5469, 31563, 49291, 0 };
            const std::uint32_t dim4287JoeKuoD6Init[]   =   { 1, 1, 1, 1, 25, 33, 61, 201, 15, 125, 969, 1965, 2021, 10253, 23801, 28165, 0 };
            const std::uint32_t dim4288JoeKuoD6Init[]   =   { 1, 1, 5, 5, 13, 17, 5, 245, 11, 133, 287, 1929, 4331, 15919, 29663, 10243, 0 };
            const std::uint32_t dim4289JoeKuoD6Init[]   =   { 1, 1, 7, 9, 19, 33, 39, 191, 489, 631, 69, 1883, 2183, 14993, 32715, 62217, 0 };
            const std::uint32_t dim4290JoeKuoD6Init[]   =   { 1, 3, 3, 13, 23, 61, 103, 193, 501, 431, 437, 417, 6557, 11701, 27577, 42943, 0 };
            const std::uint32_t dim4291JoeKuoD6Init[]   =   { 1, 3, 3, 9, 9, 27, 69, 247, 469, 841, 733, 813, 2673, 7145, 5385, 44917, 0 };
            const std::uint32_t dim4292JoeKuoD6Init[]   =   { 1, 1, 7, 9, 5, 13, 19, 71, 323, 923, 1885, 3031, 4507, 13787, 14149, 1483, 0 };
            const std::uint32_t dim4293JoeKuoD6Init[]   =   { 1, 3, 1, 5, 1, 15, 89, 229, 301, 733, 1343, 2415, 6463, 1875, 9293, 6037, 0 };
            const std::uint32_t dim4294JoeKuoD6Init[]   =   { 1, 3, 1, 5, 29, 57, 67, 121, 311, 441, 1079, 1963, 7137, 6745, 9893, 22811, 0 };
            const std::uint32_t dim4295JoeKuoD6Init[]   =   { 1, 1, 7, 7, 25, 13, 27, 61, 331, 361, 481, 3783, 3061, 7827, 18885, 27583, 0 };
            const std::uint32_t dim4296JoeKuoD6Init[]   =   { 1, 3, 1, 5, 17, 47, 19, 83, 309, 65, 1573, 3437, 5623, 12691, 21075, 27789, 0 };
            const std::uint32_t dim4297JoeKuoD6Init[]   =   { 1, 1, 7, 9, 13, 51, 7, 209, 131, 111, 1143, 53, 7277, 9297, 20869, 33121, 0 };
            const std::uint32_t dim4298JoeKuoD6Init[]   =   { 1, 1, 3, 9, 13, 17, 57, 89, 239, 281, 775, 333, 5631, 2805, 10195, 9665, 0 };
            const std::uint32_t dim4299JoeKuoD6Init[]   =   { 1, 1, 3, 7, 19, 39, 71, 79, 63, 551, 103, 3169, 2761, 13929, 20751, 18951, 0 };
            const std::uint32_t dim4300JoeKuoD6Init[]   =   { 1, 1, 7, 11, 5, 23, 7, 249, 447, 483, 433, 3117, 1421, 14991, 5397, 19813, 0 };
            const std::uint32_t dim4301JoeKuoD6Init[]   =   { 1, 3, 1, 13, 3, 9, 109, 241, 181, 33, 853, 3939, 3751, 2151, 28375, 64443, 0 };
            const std::uint32_t dim4302JoeKuoD6Init[]   =   { 1, 1, 7, 7, 3, 33, 65, 211, 251, 631, 1819, 3913, 3353, 12975, 19117, 51515, 0 };
            const std::uint32_t dim4303JoeKuoD6Init[]   =   { 1, 1, 1, 13, 3, 21, 9, 203, 223, 229, 1399, 117, 6297, 11535, 16383, 12541, 0 };
            const std::uint32_t dim4304JoeKuoD6Init[]   =   { 1, 1, 5, 7, 25, 9, 53, 27, 497, 103, 1915, 2179, 3679, 11375, 18907, 63385, 0 };
            const std::uint32_t dim4305JoeKuoD6Init[]   =   { 1, 3, 1, 5, 1, 53, 91, 169, 87, 387, 377, 1121, 7241, 5133, 1949, 13433, 0 };
            const std::uint32_t dim4306JoeKuoD6Init[]   =   { 1, 1, 1, 3, 27, 35, 61, 189, 241, 445, 287, 325, 127, 2363, 30663, 43557, 0 };
            const std::uint32_t dim4307JoeKuoD6Init[]   =   { 1, 3, 1, 3, 17, 47, 59, 237, 213, 979, 807, 85, 4621, 9915, 13631, 55657, 0 };
            const std::uint32_t dim4308JoeKuoD6Init[]   =   { 1, 3, 5, 7, 27, 5, 101, 89, 495, 675, 1181, 2295, 1913, 3731, 32639, 58297, 0 };
            const std::uint32_t dim4309JoeKuoD6Init[]   =   { 1, 3, 3, 11, 5, 41, 49, 229, 93, 659, 927, 3425, 4083, 11859, 10603, 20631, 0 };
            const std::uint32_t dim4310JoeKuoD6Init[]   =   { 1, 3, 5, 11, 31, 51, 67, 69, 253, 497, 1665, 1985, 5439, 15999, 4175, 62175, 0 };
            const std::uint32_t dim4311JoeKuoD6Init[]   =   { 1, 1, 7, 11, 1, 21, 95, 19, 205, 513, 1329, 1821, 1251, 2381, 32623, 23923, 0 };
            const std::uint32_t dim4312JoeKuoD6Init[]   =   { 1, 1, 5, 13, 3, 1, 29, 175, 315, 865, 599, 1695, 1391, 2313, 31035, 19159, 0 };
            const std::uint32_t dim4313JoeKuoD6Init[]   =   { 1, 3, 3, 1, 3, 45, 109, 93, 481, 285, 869, 3441, 3715, 1355, 9581, 50173, 0 };
            const std::uint32_t dim4314JoeKuoD6Init[]   =   { 1, 3, 7, 7, 15, 35, 107, 107, 315, 213, 281, 2073, 4689, 5877, 31, 40967, 0 };
            const std::uint32_t dim4315JoeKuoD6Init[]   =   { 1, 1, 3, 11, 11, 3, 73, 41, 79, 37, 481, 1993, 931, 7677, 11321, 45735, 0 };
            const std::uint32_t dim4316JoeKuoD6Init[]   =   { 1, 1, 7, 1, 15, 21, 65, 237, 263, 849, 863, 4039, 3171, 13381, 30373, 51639, 0 };
            const std::uint32_t dim4317JoeKuoD6Init[]   =   { 1, 1, 1, 3, 21, 57, 113, 3, 487, 41, 1277, 633, 2839, 4977, 14537, 31749, 0 };
            const std::uint32_t dim4318JoeKuoD6Init[]   =   { 1, 1, 5, 1, 1, 55, 71, 181, 147, 895, 1839, 2157, 3187, 6403, 30367, 48915, 0 };
            const std::uint32_t dim4319JoeKuoD6Init[]   =   { 1, 1, 5, 3, 9, 17, 19, 127, 115, 875, 831, 2439, 7475, 1921, 18657, 27709, 0 };
            const std::uint32_t dim4320JoeKuoD6Init[]   =   { 1, 3, 3, 13, 29, 11, 35, 81, 291, 483, 625, 3957, 6017, 12543, 18773, 2471, 0 };
            const std::uint32_t dim4321JoeKuoD6Init[]   =   { 1, 3, 3, 13, 11, 39, 7, 85, 493, 209, 819, 3277, 4275, 8997, 22943, 33199, 0 };
            const std::uint32_t dim4322JoeKuoD6Init[]   =   { 1, 1, 1, 7, 11, 25, 1, 57, 505, 135, 1713, 3051, 5893, 10711, 10681, 12235, 0 };
            const std::uint32_t dim4323JoeKuoD6Init[]   =   { 1, 3, 5, 11, 23, 33, 13, 107, 289, 251, 235, 1747, 4097, 12237, 17559, 5063, 0 };
            const std::uint32_t dim4324JoeKuoD6Init[]   =   { 1, 3, 3, 9, 19, 17, 23, 45, 297, 147, 1301, 2057, 7871, 9971, 1965, 62449, 0 };
            const std::uint32_t dim4325JoeKuoD6Init[]   =   { 1, 1, 7, 3, 17, 21, 19, 203, 289, 897, 1967, 3519, 3261, 8199, 24181, 23273, 0 };
            const std::uint32_t dim4326JoeKuoD6Init[]   =   { 1, 1, 7, 11, 1, 17, 25, 63, 509, 969, 47, 1329, 701, 5227, 419, 14839, 0 };
            const std::uint32_t dim4327JoeKuoD6Init[]   =   { 1, 3, 5, 11, 1, 41, 81, 157, 395, 97, 1919, 3043, 6015, 15, 23733, 55485, 0 };
            const std::uint32_t dim4328JoeKuoD6Init[]   =   { 1, 1, 3, 11, 17, 37, 17, 181, 179, 297, 1007, 1559, 6275, 11645, 7535, 28941, 0 };
            const std::uint32_t dim4329JoeKuoD6Init[]   =   { 1, 3, 7, 15, 5, 47, 31, 237, 215, 563, 207, 1867, 6635, 6857, 11837, 22865, 0 };
            const std::uint32_t dim4330JoeKuoD6Init[]   =   { 1, 3, 1, 7, 7, 39, 51, 179, 57, 987, 893, 2715, 1045, 5799, 19805, 54275, 0 };
            const std::uint32_t dim4331JoeKuoD6Init[]   =   { 1, 1, 7, 15, 25, 9, 127, 243, 323, 1013, 929, 2891, 7549, 1071, 17663, 15247, 0 };
            const std::uint32_t dim4332JoeKuoD6Init[]   =   { 1, 1, 1, 5, 25, 23, 101, 9, 371, 89, 1749, 3559, 8071, 13887, 14807, 42825, 0 };
            const std::uint32_t dim4333JoeKuoD6Init[]   =   { 1, 3, 3, 11, 21, 41, 3, 77, 3, 709, 1745, 3615, 4141, 5275, 28329, 59739, 0 };
            const std::uint32_t dim4334JoeKuoD6Init[]   =   { 1, 1, 7, 13, 1, 11, 73, 183, 363, 241, 863, 3983, 3235, 293, 649, 441, 0 };
            const std::uint32_t dim4335JoeKuoD6Init[]   =   { 1, 1, 5, 3, 13, 27, 13, 191, 57, 639, 1803, 2353, 3143, 12763, 5771, 36155, 0 };
            const std::uint32_t dim4336JoeKuoD6Init[]   =   { 1, 1, 5, 3, 1, 53, 85, 45, 283, 823, 1213, 3261, 4599, 13267, 4613, 12657, 0 };
            const std::uint32_t dim4337JoeKuoD6Init[]   =   { 1, 3, 5, 15, 27, 49, 59, 123, 357, 527, 337, 2751, 3999, 8525, 12501, 40621, 0 };
            const std::uint32_t dim4338JoeKuoD6Init[]   =   { 1, 1, 1, 7, 1, 55, 85, 17, 447, 599, 1315, 2313, 1649, 907, 25647, 3251, 0 };
            const std::uint32_t dim4339JoeKuoD6Init[]   =   { 1, 3, 5, 13, 9, 1, 37, 121, 143, 1, 631, 2273, 1673, 3649, 27533, 28731, 0 };
            const std::uint32_t dim4340JoeKuoD6Init[]   =   { 1, 1, 7, 13, 9, 31, 57, 249, 397, 815, 501, 895, 1217, 11387, 8635, 65193, 0 };
            const std::uint32_t dim4341JoeKuoD6Init[]   =   { 1, 1, 5, 5, 9, 35, 95, 193, 133, 513, 1929, 3841, 3063, 2383, 24413, 51185, 0 };
            const std::uint32_t dim4342JoeKuoD6Init[]   =   { 1, 1, 1, 13, 3, 49, 45, 191, 15, 181, 1819, 3741, 1227, 12775, 9461, 44951, 0 };
            const std::uint32_t dim4343JoeKuoD6Init[]   =   { 1, 1, 1, 1, 3, 45, 121, 19, 269, 829, 517, 3913, 183, 11019, 24969, 21973, 0 };
            const std::uint32_t dim4344JoeKuoD6Init[]   =   { 1, 1, 5, 11, 31, 39, 125, 189, 401, 57, 1557, 1727, 1415, 4025, 30353, 36589, 0 };
            const std::uint32_t dim4345JoeKuoD6Init[]   =   { 1, 1, 3, 9, 3, 55, 125, 187, 409, 499, 1853, 2781, 4323, 16159, 16345, 34659, 0 };
            const std::uint32_t dim4346JoeKuoD6Init[]   =   { 1, 3, 5, 11, 31, 5, 125, 137, 197, 475, 2003, 617, 1289, 8365, 28981, 57537, 0 };
            const std::uint32_t dim4347JoeKuoD6Init[]   =   { 1, 1, 1, 5, 19, 29, 83, 127, 311, 177, 1635, 2187, 5377, 12841, 7591, 6095, 0 };
            const std::uint32_t dim4348JoeKuoD6Init[]   =   { 1, 3, 5, 5, 21, 39, 65, 197, 115, 411, 1457, 3011, 7021, 14119, 61, 21107, 0 };
            const std::uint32_t dim4349JoeKuoD6Init[]   =   { 1, 3, 3, 9, 19, 57, 99, 23, 451, 507, 973, 415, 7123, 11367, 29767, 23763, 0 };
            const std::uint32_t dim4350JoeKuoD6Init[]   =   { 1, 1, 5, 7, 29, 23, 47, 11, 267, 873, 591, 373, 7097, 3783, 23289, 5547, 0 };
            const std::uint32_t dim4351JoeKuoD6Init[]   =   { 1, 1, 5, 15, 7, 7, 7, 91, 389, 841, 1995, 459, 7013, 3109, 23615, 21519, 0 };
            const std::uint32_t dim4352JoeKuoD6Init[]   =   { 1, 3, 1, 1, 13, 25, 87, 235, 193, 201, 713, 1633, 3117, 13609, 17211, 573, 0 };
            const std::uint32_t dim4353JoeKuoD6Init[]   =   { 1, 1, 1, 9, 27, 53, 105, 39, 217, 781, 997, 661, 6243, 6427, 17739, 62239, 0 };
            const std::uint32_t dim4354JoeKuoD6Init[]   =   { 1, 1, 7, 3, 3, 49, 75, 125, 239, 195, 215, 2983, 1185, 4743, 12069, 55509, 0 };
            const std::uint32_t dim4355JoeKuoD6Init[]   =   { 1, 1, 5, 15, 31, 11, 9, 91, 253, 361, 571, 1589, 2425, 4279, 3765, 46519, 0 };
            const std::uint32_t dim4356JoeKuoD6Init[]   =   { 1, 1, 3, 3, 21, 49, 49, 213, 399, 253, 1565, 2447, 453, 7957, 24799, 58503, 0 };
            const std::uint32_t dim4357JoeKuoD6Init[]   =   { 1, 1, 7, 1, 5, 59, 81, 97, 209, 477, 17, 3085, 3655, 599, 24011, 14981, 0 };
            const std::uint32_t dim4358JoeKuoD6Init[]   =   { 1, 3, 3, 13, 19, 49, 7, 35, 111, 169, 629, 1587, 5345, 13699, 21187, 30199, 0 };
            const std::uint32_t dim4359JoeKuoD6Init[]   =   { 1, 1, 3, 13, 19, 59, 73, 127, 475, 509, 9, 2661, 711, 15835, 31429, 33885, 0 };
            const std::uint32_t dim4360JoeKuoD6Init[]   =   { 1, 3, 5, 3, 31, 15, 43, 185, 29, 897, 1041, 1057, 6285, 13925, 4023, 25741, 0 };
            const std::uint32_t dim4361JoeKuoD6Init[]   =   { 1, 3, 5, 11, 1, 33, 63, 155, 175, 501, 1147, 3395, 3285, 16237, 22315, 50945, 0 };
            const std::uint32_t dim4362JoeKuoD6Init[]   =   { 1, 3, 3, 3, 5, 13, 77, 227, 85, 139, 139, 1, 7147, 2023, 32705, 38753, 0 };
            const std::uint32_t dim4363JoeKuoD6Init[]   =   { 1, 3, 5, 11, 31, 59, 35, 179, 489, 537, 1537, 2877, 4937, 10825, 2445, 34907, 0 };
            const std::uint32_t dim4364JoeKuoD6Init[]   =   { 1, 3, 7, 11, 17, 17, 95, 223, 165, 925, 829, 3971, 1, 7393, 8825, 25705, 0 };
            const std::uint32_t dim4365JoeKuoD6Init[]   =   { 1, 1, 1, 1, 25, 17, 25, 143, 385, 907, 1381, 1823, 3819, 8475, 5321, 12037, 0 };
            const std::uint32_t dim4366JoeKuoD6Init[]   =   { 1, 1, 5, 11, 7, 47, 97, 85, 105, 23, 263, 1329, 1905, 12121, 29635, 41249, 0 };
            const std::uint32_t dim4367JoeKuoD6Init[]   =   { 1, 1, 7, 11, 1, 51, 13, 13, 5, 143, 83, 3831, 959, 6083, 16997, 59887, 0 };
            const std::uint32_t dim4368JoeKuoD6Init[]   =   { 1, 3, 3, 13, 25, 9, 31, 5, 215, 791, 767, 1733, 2715, 14283, 25795, 54249, 0 };
            const std::uint32_t dim4369JoeKuoD6Init[]   =   { 1, 3, 7, 5, 11, 19, 125, 81, 71, 131, 1869, 1111, 6763, 5275, 23095, 1139, 0 };
            const std::uint32_t dim4370JoeKuoD6Init[]   =   { 1, 3, 3, 9, 25, 43, 119, 49, 133, 217, 521, 1367, 5867, 6829, 29871, 60383, 0 };
            const std::uint32_t dim4371JoeKuoD6Init[]   =   { 1, 1, 7, 9, 5, 11, 59, 157, 279, 301, 481, 3273, 7943, 3273, 27783, 17271, 0 };
            const std::uint32_t dim4372JoeKuoD6Init[]   =   { 1, 3, 3, 13, 11, 57, 13, 5, 435, 169, 541, 517, 2359, 9121, 27911, 15679, 0 };
            const std::uint32_t dim4373JoeKuoD6Init[]   =   { 1, 1, 3, 9, 9, 55, 65, 113, 21, 807, 373, 2825, 1527, 15565, 8339, 7227, 0 };
            const std::uint32_t dim4374JoeKuoD6Init[]   =   { 1, 3, 5, 9, 1, 1, 49, 255, 477, 821, 1647, 713, 6841, 3187, 22649, 51469, 0 };
            const std::uint32_t dim4375JoeKuoD6Init[]   =   { 1, 3, 3, 11, 13, 43, 63, 139, 71, 809, 993, 2429, 833, 6545, 10987, 39567, 0 };
            const std::uint32_t dim4376JoeKuoD6Init[]   =   { 1, 1, 1, 9, 19, 23, 47, 199, 191, 827, 391, 837, 1209, 2493, 24071, 46589, 0 };
            const std::uint32_t dim4377JoeKuoD6Init[]   =   { 1, 1, 5, 13, 25, 51, 39, 43, 103, 899, 1729, 2389, 2965, 189, 3063, 50609, 0 };
            const std::uint32_t dim4378JoeKuoD6Init[]   =   { 1, 1, 3, 1, 5, 29, 105, 201, 503, 199, 507, 205, 2389, 695, 15233, 50353, 0 };
            const std::uint32_t dim4379JoeKuoD6Init[]   =   { 1, 3, 1, 7, 19, 53, 45, 21, 89, 545, 1885, 765, 6673, 13485, 9987, 2609, 0 };
            const std::uint32_t dim4380JoeKuoD6Init[]   =   { 1, 3, 7, 13, 17, 7, 59, 23, 159, 309, 1407, 2483, 1807, 15733, 5603, 52989, 0 };
            const std::uint32_t dim4381JoeKuoD6Init[]   =   { 1, 1, 1, 11, 13, 19, 123, 185, 413, 745, 361, 2391, 6697, 2281, 11999, 13175, 0 };
            const std::uint32_t dim4382JoeKuoD6Init[]   =   { 1, 3, 5, 5, 11, 49, 123, 173, 325, 667, 895, 1067, 8121, 10577, 30561, 17391, 0 };
            const std::uint32_t dim4383JoeKuoD6Init[]   =   { 1, 1, 5, 5, 23, 21, 77, 223, 281, 161, 141, 345, 3879, 11393, 26907, 53805, 0 };
            const std::uint32_t dim4384JoeKuoD6Init[]   =   { 1, 3, 3, 5, 3, 47, 17, 109, 185, 139, 957, 1417, 4553, 6101, 29537, 34821, 0 };
            const std::uint32_t dim4385JoeKuoD6Init[]   =   { 1, 1, 5, 3, 29, 49, 89, 61, 45, 593, 269, 1483, 2971, 991, 21239, 29301, 0 };
            const std::uint32_t dim4386JoeKuoD6Init[]   =   { 1, 1, 3, 13, 29, 45, 33, 253, 291, 783, 737, 2363, 2651, 8627, 21785, 58419, 0 };
            const std::uint32_t dim4387JoeKuoD6Init[]   =   { 1, 3, 7, 15, 29, 15, 81, 185, 363, 681, 1737, 3789, 4365, 3295, 23205, 4457, 0 };
            const std::uint32_t dim4388JoeKuoD6Init[]   =   { 1, 3, 3, 11, 15, 39, 67, 167, 197, 357, 871, 2201, 5377, 6299, 20873, 59283, 0 };
            const std::uint32_t dim4389JoeKuoD6Init[]   =   { 1, 3, 3, 5, 9, 15, 127, 49, 21, 719, 357, 425, 5507, 9639, 275, 47503, 0 };
            const std::uint32_t dim4390JoeKuoD6Init[]   =   { 1, 1, 7, 1, 13, 63, 111, 121, 21, 481, 247, 3147, 5783, 8947, 20809, 42039, 0 };
            const std::uint32_t dim4391JoeKuoD6Init[]   =   { 1, 1, 3, 3, 31, 33, 9, 69, 187, 517, 2029, 2205, 7661, 4757, 27525, 9665, 0 };
            const std::uint32_t dim4392JoeKuoD6Init[]   =   { 1, 1, 1, 13, 7, 41, 103, 161, 233, 221, 693, 213, 4609, 7771, 28703, 17407, 0 };
            const std::uint32_t dim4393JoeKuoD6Init[]   =   { 1, 3, 7, 15, 31, 47, 27, 111, 479, 1003, 1687, 347, 2179, 11861, 8169, 31941, 0 };
            const std::uint32_t dim4394JoeKuoD6Init[]   =   { 1, 1, 3, 5, 5, 63, 25, 125, 199, 147, 589, 3565, 3449, 8331, 8923, 31207, 0 };
            const std::uint32_t dim4395JoeKuoD6Init[]   =   { 1, 1, 3, 11, 19, 25, 77, 99, 299, 19, 1641, 2193, 4299, 3635, 20621, 267, 0 };
            const std::uint32_t dim4396JoeKuoD6Init[]   =   { 1, 3, 7, 11, 9, 59, 7, 167, 1, 775, 29, 1935, 3723, 11835, 2887, 65285, 0 };
            const std::uint32_t dim4397JoeKuoD6Init[]   =   { 1, 1, 7, 13, 5, 47, 101, 155, 235, 93, 465, 3581, 1837, 7675, 10789, 45167, 0 };
            const std::uint32_t dim4398JoeKuoD6Init[]   =   { 1, 1, 3, 5, 9, 59, 121, 109, 59, 821, 1625, 343, 1591, 3875, 13729, 56381, 0 };
            const std::uint32_t dim4399JoeKuoD6Init[]   =   { 1, 1, 1, 9, 27, 53, 93, 215, 133, 561, 39, 2591, 1041, 11913, 24493, 37921, 0 };
            const std::uint32_t dim4400JoeKuoD6Init[]   =   { 1, 1, 1, 7, 23, 7, 81, 107, 219, 943, 563, 1083, 5803, 5687, 32559, 62727, 0 };
            const std::uint32_t dim4401JoeKuoD6Init[]   =   { 1, 3, 7, 7, 21, 53, 3, 5, 231, 601, 1561, 103, 3837, 2675, 5263, 23375, 0 };
            const std::uint32_t dim4402JoeKuoD6Init[]   =   { 1, 1, 3, 13, 15, 27, 89, 7, 251, 887, 951, 3001, 5687, 4921, 5091, 59337, 0 };
            const std::uint32_t dim4403JoeKuoD6Init[]   =   { 1, 3, 7, 15, 25, 53, 19, 155, 185, 503, 547, 1917, 7633, 15167, 14177, 46761, 0 };
            const std::uint32_t dim4404JoeKuoD6Init[]   =   { 1, 3, 5, 15, 21, 49, 13, 163, 471, 281, 1141, 3013, 6847, 9261, 15955, 9397, 0 };
            const std::uint32_t dim4405JoeKuoD6Init[]   =   { 1, 3, 3, 3, 1, 21, 19, 239, 479, 609, 65, 2735, 5337, 6293, 19351, 34135, 0 };
            const std::uint32_t dim4406JoeKuoD6Init[]   =   { 1, 1, 7, 1, 9, 1, 119, 23, 411, 535, 101, 1597, 2379, 2421, 31471, 36473, 0 };
            const std::uint32_t dim4407JoeKuoD6Init[]   =   { 1, 3, 1, 11, 31, 63, 17, 225, 45, 409, 59, 3943, 8043, 11759, 10667, 58793, 0 };
            const std::uint32_t dim4408JoeKuoD6Init[]   =   { 1, 1, 3, 3, 9, 49, 61, 239, 245, 765, 1945, 3567, 5355, 14799, 7141, 59511, 0 };
            const std::uint32_t dim4409JoeKuoD6Init[]   =   { 1, 3, 7, 9, 3, 33, 103, 99, 35, 799, 1347, 2253, 8189, 14177, 13479, 13749, 0 };
            const std::uint32_t dim4410JoeKuoD6Init[]   =   { 1, 3, 1, 15, 15, 51, 7, 179, 471, 265, 1571, 2983, 701, 15133, 7885, 29977, 0 };
            const std::uint32_t dim4411JoeKuoD6Init[]   =   { 1, 1, 5, 9, 15, 37, 49, 213, 113, 729, 1115, 2727, 2635, 8433, 11145, 46779, 0 };
            const std::uint32_t dim4412JoeKuoD6Init[]   =   { 1, 3, 5, 11, 7, 3, 115, 151, 133, 723, 7, 4063, 5807, 9845, 25829, 29315, 0 };
            const std::uint32_t dim4413JoeKuoD6Init[]   =   { 1, 3, 5, 9, 25, 55, 17, 135, 145, 379, 1603, 3459, 5773, 6545, 17509, 25847, 0 };
            const std::uint32_t dim4414JoeKuoD6Init[]   =   { 1, 1, 7, 11, 1, 61, 113, 147, 489, 775, 1347, 2199, 299, 9589, 19931, 1335, 0 };
            const std::uint32_t dim4415JoeKuoD6Init[]   =   { 1, 3, 1, 3, 1, 7, 27, 243, 355, 425, 1215, 3723, 3489, 9285, 12739, 24797, 0 };
            const std::uint32_t dim4416JoeKuoD6Init[]   =   { 1, 3, 5, 11, 15, 25, 57, 221, 247, 647, 259, 1665, 7055, 2835, 16411, 42999, 0 };
            const std::uint32_t dim4417JoeKuoD6Init[]   =   { 1, 1, 3, 7, 9, 25, 61, 233, 73, 235, 1539, 1865, 5671, 1329, 5767, 43039, 0 };
            const std::uint32_t dim4418JoeKuoD6Init[]   =   { 1, 1, 7, 9, 21, 11, 123, 7, 41, 407, 1485, 1723, 585, 10597, 16215, 63403, 0 };
            const std::uint32_t dim4419JoeKuoD6Init[]   =   { 1, 1, 5, 7, 27, 9, 123, 101, 273, 673, 1141, 3841, 4041, 13169, 8221, 12915, 0 };
            const std::uint32_t dim4420JoeKuoD6Init[]   =   { 1, 3, 1, 13, 3, 17, 105, 17, 237, 321, 855, 2821, 2467, 3503, 15187, 1689, 0 };
            const std::uint32_t dim4421JoeKuoD6Init[]   =   { 1, 1, 5, 5, 19, 23, 9, 205, 87, 153, 1543, 1193, 6619, 6845, 8459, 37533, 0 };
            const std::uint32_t dim4422JoeKuoD6Init[]   =   { 1, 1, 7, 15, 13, 29, 79, 9, 203, 211, 239, 2349, 3447, 7797, 19311, 58071, 0 };
            const std::uint32_t dim4423JoeKuoD6Init[]   =   { 1, 3, 5, 11, 5, 49, 71, 151, 333, 895, 1095, 2471, 2477, 14493, 16711, 14393, 0 };
            const std::uint32_t dim4424JoeKuoD6Init[]   =   { 1, 1, 5, 13, 17, 19, 25, 149, 111, 631, 763, 2535, 3631, 1809, 8163, 18037, 0 };
            const std::uint32_t dim4425JoeKuoD6Init[]   =   { 1, 3, 3, 13, 23, 61, 25, 179, 351, 247, 1021, 2413, 2585, 3731, 5435, 52723, 0 };
            const std::uint32_t dim4426JoeKuoD6Init[]   =   { 1, 1, 5, 11, 1, 39, 65, 59, 21, 927, 1989, 2823, 4857, 15521, 30495, 16067, 0 };
            const std::uint32_t dim4427JoeKuoD6Init[]   =   { 1, 3, 3, 7, 17, 5, 17, 125, 379, 875, 1565, 2435, 933, 6809, 20129, 26339, 0 };
            const std::uint32_t dim4428JoeKuoD6Init[]   =   { 1, 1, 7, 5, 3, 57, 51, 213, 455, 663, 2007, 3995, 4889, 9527, 23507, 3261, 0 };
            const std::uint32_t dim4429JoeKuoD6Init[]   =   { 1, 3, 7, 5, 1, 29, 85, 151, 165, 123, 1425, 2851, 4427, 7683, 21085, 28925, 0 };
            const std::uint32_t dim4430JoeKuoD6Init[]   =   { 1, 1, 5, 3, 11, 33, 127, 3, 41, 591, 1539, 3823, 125, 421, 9051, 55025, 0 };
            const std::uint32_t dim4431JoeKuoD6Init[]   =   { 1, 3, 1, 5, 7, 9, 69, 35, 59, 477, 1207, 1245, 6423, 11329, 26535, 37621, 0 };
            const std::uint32_t dim4432JoeKuoD6Init[]   =   { 1, 3, 1, 1, 15, 35, 17, 123, 303, 193, 1489, 2587, 1883, 4063, 1921, 60413, 0 };
            const std::uint32_t dim4433JoeKuoD6Init[]   =   { 1, 1, 5, 1, 7, 61, 39, 247, 139, 1015, 757, 823, 4757, 9307, 32287, 37241, 0 };
            const std::uint32_t dim4434JoeKuoD6Init[]   =   { 1, 1, 7, 15, 3, 5, 85, 93, 457, 999, 1331, 919, 5271, 11687, 24233, 38803, 0 };
            const std::uint32_t dim4435JoeKuoD6Init[]   =   { 1, 3, 3, 9, 5, 43, 37, 13, 505, 603, 1857, 2675, 2017, 9481, 10873, 54755, 0 };
            const std::uint32_t dim4436JoeKuoD6Init[]   =   { 1, 1, 5, 15, 13, 3, 7, 239, 471, 835, 553, 413, 4029, 8613, 15533, 58987, 0 };
            const std::uint32_t dim4437JoeKuoD6Init[]   =   { 1, 3, 1, 5, 19, 27, 21, 43, 57, 755, 1245, 2805, 3799, 2013, 21145, 10317, 0 };
            const std::uint32_t dim4438JoeKuoD6Init[]   =   { 1, 3, 5, 13, 9, 23, 35, 5, 315, 169, 399, 2641, 1525, 10561, 11917, 33009, 0 };
            const std::uint32_t dim4439JoeKuoD6Init[]   =   { 1, 3, 5, 7, 23, 53, 101, 105, 451, 207, 1271, 3067, 6725, 15525, 7951, 1283, 0 };
            const std::uint32_t dim4440JoeKuoD6Init[]   =   { 1, 1, 5, 5, 27, 21, 77, 143, 213, 443, 149, 2667, 5269, 10359, 25287, 5843, 0 };
            const std::uint32_t dim4441JoeKuoD6Init[]   =   { 1, 3, 5, 5, 25, 27, 109, 157, 459, 767, 765, 2667, 1833, 3781, 9077, 64321, 0 };
            const std::uint32_t dim4442JoeKuoD6Init[]   =   { 1, 3, 3, 13, 31, 25, 97, 237, 279, 431, 1713, 809, 1989, 10431, 5867, 42197, 0 };
            const std::uint32_t dim4443JoeKuoD6Init[]   =   { 1, 3, 7, 3, 9, 5, 5, 191, 73, 521, 787, 903, 3073, 2067, 24741, 57029, 0 };
            const std::uint32_t dim4444JoeKuoD6Init[]   =   { 1, 3, 3, 1, 3, 41, 125, 53, 125, 781, 865, 3677, 6279, 357, 10667, 1127, 0 };
            const std::uint32_t dim4445JoeKuoD6Init[]   =   { 1, 1, 5, 11, 25, 19, 99, 121, 359, 73, 607, 2149, 5739, 15669, 29457, 57549, 0 };
            const std::uint32_t dim4446JoeKuoD6Init[]   =   { 1, 1, 5, 3, 23, 5, 35, 55, 369, 239, 329, 3057, 3757, 12523, 5017, 52185, 0 };
            const std::uint32_t dim4447JoeKuoD6Init[]   =   { 1, 3, 3, 13, 17, 61, 69, 165, 267, 323, 2007, 2025, 4423, 15975, 31897, 37013, 0 };
            const std::uint32_t dim4448JoeKuoD6Init[]   =   { 1, 3, 7, 13, 19, 19, 87, 111, 389, 611, 1523, 963, 4671, 12569, 21839, 10919, 0 };
            const std::uint32_t dim4449JoeKuoD6Init[]   =   { 1, 1, 1, 3, 1, 27, 13, 227, 29, 457, 221, 127, 5335, 16247, 19559, 19185, 0 };
            const std::uint32_t dim4450JoeKuoD6Init[]   =   { 1, 3, 5, 7, 29, 21, 23, 157, 197, 87, 1591, 1829, 407, 15885, 14933, 1997, 0 };
            const std::uint32_t dim4451JoeKuoD6Init[]   =   { 1, 1, 1, 9, 3, 35, 43, 187, 195, 325, 197, 2905, 7323, 1563, 7659, 45185, 0 };
            const std::uint32_t dim4452JoeKuoD6Init[]   =   { 1, 1, 1, 15, 3, 23, 105, 33, 73, 495, 1409, 2583, 1099, 1041, 28955, 60293, 0 };
            const std::uint32_t dim4453JoeKuoD6Init[]   =   { 1, 3, 7, 13, 25, 19, 99, 137, 139, 719, 529, 1147, 5813, 11551, 30183, 14593, 0 };
            const std::uint32_t dim4454JoeKuoD6Init[]   =   { 1, 3, 3, 5, 17, 25, 73, 193, 309, 887, 1655, 1641, 2091, 12087, 21881, 1145, 0 };
            const std::uint32_t dim4455JoeKuoD6Init[]   =   { 1, 3, 1, 1, 27, 41, 13, 151, 83, 645, 327, 1795, 2717, 12433, 22751, 9823, 0 };
            const std::uint32_t dim4456JoeKuoD6Init[]   =   { 1, 1, 3, 7, 1, 43, 77, 229, 59, 499, 1883, 135, 3461, 9821, 219, 6111, 0 };
            const std::uint32_t dim4457JoeKuoD6Init[]   =   { 1, 3, 3, 3, 23, 7, 17, 67, 361, 565, 1621, 3253, 7973, 281, 3209, 48215, 0 };
            const std::uint32_t dim4458JoeKuoD6Init[]   =   { 1, 1, 3, 7, 31, 15, 97, 141, 197, 883, 1689, 269, 7487, 10403, 18903, 58147, 0 };
            const std::uint32_t dim4459JoeKuoD6Init[]   =   { 1, 3, 3, 3, 23, 9, 87, 125, 359, 527, 1251, 637, 1145, 12721, 14693, 6021, 0 };
            const std::uint32_t dim4460JoeKuoD6Init[]   =   { 1, 1, 3, 5, 13, 43, 105, 173, 205, 859, 1237, 1227, 1409, 15513, 25317, 30745, 0 };
            const std::uint32_t dim4461JoeKuoD6Init[]   =   { 1, 3, 3, 15, 31, 43, 125, 149, 145, 109, 975, 1167, 7629, 8373, 5923, 64117, 0 };
            const std::uint32_t dim4462JoeKuoD6Init[]   =   { 1, 3, 1, 15, 3, 33, 89, 173, 379, 615, 1401, 1567, 4453, 7461, 32555, 64369, 0 };
            const std::uint32_t dim4463JoeKuoD6Init[]   =   { 1, 3, 7, 11, 27, 23, 45, 7, 15, 21, 1663, 3327, 5611, 8535, 27669, 25525, 0 };
            const std::uint32_t dim4464JoeKuoD6Init[]   =   { 1, 1, 3, 15, 15, 61, 127, 145, 151, 41, 629, 767, 5801, 3395, 1157, 30033, 0 };
            const std::uint32_t dim4465JoeKuoD6Init[]   =   { 1, 1, 1, 5, 9, 63, 73, 9, 299, 237, 369, 1295, 4869, 6821, 19961, 32129, 0 };
            const std::uint32_t dim4466JoeKuoD6Init[]   =   { 1, 1, 5, 13, 19, 7, 119, 35, 319, 405, 1255, 1299, 4311, 14999, 24567, 4001, 0 };
            const std::uint32_t dim4467JoeKuoD6Init[]   =   { 1, 1, 1, 13, 9, 39, 13, 207, 355, 691, 37, 3137, 6073, 16179, 28661, 41, 0 };
            const std::uint32_t dim4468JoeKuoD6Init[]   =   { 1, 1, 3, 7, 21, 3, 123, 27, 187, 183, 769, 2367, 2957, 7065, 17855, 60805, 0 };
            const std::uint32_t dim4469JoeKuoD6Init[]   =   { 1, 1, 1, 1, 19, 31, 71, 85, 303, 617, 1007, 283, 8087, 11079, 11463, 65295, 0 };
            const std::uint32_t dim4470JoeKuoD6Init[]   =   { 1, 1, 3, 13, 25, 63, 61, 187, 401, 465, 1485, 801, 3649, 7763, 8495, 54479, 0 };
            const std::uint32_t dim4471JoeKuoD6Init[]   =   { 1, 3, 7, 3, 13, 51, 41, 119, 311, 699, 1113, 3631, 1981, 3259, 25871, 45659, 0 };
            const std::uint32_t dim4472JoeKuoD6Init[]   =   { 1, 3, 7, 13, 31, 27, 57, 181, 325, 107, 1745, 635, 3941, 3305, 14563, 29855, 0 };
            const std::uint32_t dim4473JoeKuoD6Init[]   =   { 1, 3, 7, 15, 5, 55, 5, 147, 365, 485, 1841, 3673, 6513, 11121, 5725, 18027, 0 };
            const std::uint32_t dim4474JoeKuoD6Init[]   =   { 1, 3, 5, 11, 13, 45, 35, 79, 109, 683, 1171, 3015, 2163, 4823, 4365, 42931, 0 };
            const std::uint32_t dim4475JoeKuoD6Init[]   =   { 1, 1, 7, 7, 13, 45, 57, 39, 297, 985, 1559, 487, 5071, 2657, 9401, 41889, 0 };
            const std::uint32_t dim4476JoeKuoD6Init[]   =   { 1, 1, 5, 9, 29, 33, 79, 237, 509, 537, 549, 3657, 7141, 15189, 30853, 36089, 0 };
            const std::uint32_t dim4477JoeKuoD6Init[]   =   { 1, 3, 5, 7, 31, 15, 75, 73, 237, 273, 865, 743, 2607, 7611, 18441, 12703, 0 };
            const std::uint32_t dim4478JoeKuoD6Init[]   =   { 1, 1, 1, 9, 27, 9, 35, 137, 265, 181, 1341, 1945, 5615, 161, 18369, 4791, 0 };
            const std::uint32_t dim4479JoeKuoD6Init[]   =   { 1, 3, 7, 11, 27, 29, 29, 43, 489, 177, 1489, 2927, 623, 14571, 22447, 46905, 0 };
            const std::uint32_t dim4480JoeKuoD6Init[]   =   { 1, 3, 3, 3, 19, 41, 107, 53, 239, 263, 1433, 1655, 7991, 7405, 2735, 25519, 0 };
            const std::uint32_t dim4481JoeKuoD6Init[]   =   { 1, 3, 5, 7, 19, 37, 73, 243, 215, 445, 1781, 3223, 187, 8443, 18185, 45093, 0 };
            const std::uint32_t dim4482JoeKuoD6Init[]   =   { 1, 1, 3, 13, 9, 57, 111, 111, 221, 505, 1261, 3045, 1655, 16247, 21033, 17993, 0 };
            const std::uint32_t dim4483JoeKuoD6Init[]   =   { 1, 1, 7, 5, 7, 55, 77, 5, 131, 969, 1481, 2883, 2645, 3003, 5601, 37063, 0 };
            const std::uint32_t dim4484JoeKuoD6Init[]   =   { 1, 1, 5, 15, 29, 55, 39, 197, 349, 29, 341, 67, 1977, 425, 4063, 42705, 0 };
            const std::uint32_t dim4485JoeKuoD6Init[]   =   { 1, 1, 7, 13, 1, 57, 81, 81, 129, 681, 1407, 2465, 3627, 2325, 31649, 18449, 0 };
            const std::uint32_t dim4486JoeKuoD6Init[]   =   { 1, 3, 5, 5, 23, 59, 35, 217, 393, 155, 1315, 105, 2285, 5167, 27997, 55193, 0 };
            const std::uint32_t dim4487JoeKuoD6Init[]   =   { 1, 1, 7, 3, 11, 59, 53, 179, 319, 819, 947, 3881, 765, 4219, 16405, 48055, 0 };
            const std::uint32_t dim4488JoeKuoD6Init[]   =   { 1, 1, 3, 9, 23, 9, 67, 67, 137, 523, 1585, 2441, 167, 5217, 12031, 14297, 0 };
            const std::uint32_t dim4489JoeKuoD6Init[]   =   { 1, 1, 5, 13, 31, 63, 121, 91, 439, 917, 203, 1519, 4363, 2391, 25755, 26677, 0 };
            const std::uint32_t dim4490JoeKuoD6Init[]   =   { 1, 1, 3, 5, 25, 31, 11, 95, 339, 817, 35, 3923, 7365, 10537, 5521, 54579, 0 };
            const std::uint32_t dim4491JoeKuoD6Init[]   =   { 1, 3, 7, 1, 3, 33, 47, 13, 139, 445, 1357, 3907, 7495, 8789, 26589, 43479, 0 };
            const std::uint32_t dim4492JoeKuoD6Init[]   =   { 1, 1, 1, 11, 5, 45, 61, 13, 167, 287, 931, 881, 5713, 12937, 12951, 21597, 0 };
            const std::uint32_t dim4493JoeKuoD6Init[]   =   { 1, 3, 5, 1, 29, 23, 7, 117, 503, 897, 733, 1113, 7205, 11507, 561, 34011, 0 };
            const std::uint32_t dim4494JoeKuoD6Init[]   =   { 1, 3, 5, 7, 3, 51, 21, 147, 35, 259, 689, 3801, 2481, 9673, 4065, 595, 0 };
            const std::uint32_t dim4495JoeKuoD6Init[]   =   { 1, 3, 3, 9, 9, 29, 5, 191, 393, 979, 1627, 937, 75, 2339, 24007, 30555, 0 };
            const std::uint32_t dim4496JoeKuoD6Init[]   =   { 1, 1, 5, 7, 9, 35, 111, 23, 113, 563, 1689, 1575, 6127, 9919, 2555, 52261, 0 };
            const std::uint32_t dim4497JoeKuoD6Init[]   =   { 1, 3, 1, 5, 31, 21, 117, 159, 473, 279, 1281, 311, 159, 3343, 27761, 59989, 0 };
            const std::uint32_t dim4498JoeKuoD6Init[]   =   { 1, 1, 5, 1, 23, 31, 67, 241, 401, 69, 933, 777, 267, 12411, 23767, 9047, 0 };
            const std::uint32_t dim4499JoeKuoD6Init[]   =   { 1, 1, 5, 1, 15, 49, 99, 15, 267, 913, 1581, 3713, 651, 14275, 10103, 57619, 0 };
            const std::uint32_t dim4500JoeKuoD6Init[]   =   { 1, 3, 5, 9, 19, 23, 95, 5, 449, 153, 1195, 1315, 2347, 12683, 10865, 50703, 0 };
            const std::uint32_t dim4501JoeKuoD6Init[]   =   { 1, 1, 1, 13, 17, 17, 115, 31, 135, 725, 795, 1695, 6199, 4179, 5223, 48457, 0 };
            const std::uint32_t dim4502JoeKuoD6Init[]   =   { 1, 3, 5, 15, 31, 15, 3, 247, 385, 269, 1665, 581, 2809, 6333, 7459, 14815, 0 };
            const std::uint32_t dim4503JoeKuoD6Init[]   =   { 1, 3, 7, 5, 15, 35, 117, 85, 11, 621, 1523, 981, 511, 14113, 4673, 22683, 0 };
            const std::uint32_t dim4504JoeKuoD6Init[]   =   { 1, 1, 7, 1, 27, 61, 119, 249, 431, 147, 173, 423, 1353, 4747, 12761, 32947, 0 };
            const std::uint32_t dim4505JoeKuoD6Init[]   =   { 1, 3, 7, 1, 23, 39, 15, 153, 219, 359, 1233, 169, 2817, 11043, 12435, 30135, 0 };
            const std::uint32_t dim4506JoeKuoD6Init[]   =   { 1, 1, 5, 1, 1, 55, 39, 1, 151, 865, 125, 2351, 6315, 1165, 20163, 43991, 0 };
            const std::uint32_t dim4507JoeKuoD6Init[]   =   { 1, 1, 3, 9, 25, 41, 115, 221, 129, 265, 1887, 4057, 7523, 13591, 5735, 59645, 0 };
            const std::uint32_t dim4508JoeKuoD6Init[]   =   { 1, 1, 5, 5, 19, 15, 9, 77, 511, 627, 153, 2015, 247, 15949, 9715, 45411, 0 };
            const std::uint32_t dim4509JoeKuoD6Init[]   =   { 1, 1, 7, 7, 17, 17, 107, 183, 39, 647, 1339, 3915, 4937, 537, 27011, 58937, 0 };
            const std::uint32_t dim4510JoeKuoD6Init[]   =   { 1, 3, 3, 13, 3, 3, 69, 201, 431, 65, 683, 121, 7017, 2791, 16713, 62555, 0 };
            const std::uint32_t dim4511JoeKuoD6Init[]   =   { 1, 3, 7, 3, 7, 41, 117, 237, 23, 757, 545, 3899, 1837, 5555, 7891, 29151, 0 };
            const std::uint32_t dim4512JoeKuoD6Init[]   =   { 1, 1, 1, 3, 27, 15, 39, 195, 353, 299, 1431, 2279, 1795, 13773, 24915, 49701, 0 };
            const std::uint32_t dim4513JoeKuoD6Init[]   =   { 1, 1, 5, 5, 7, 7, 125, 5, 401, 523, 1967, 2471, 7279, 7559, 12025, 60599, 0 };
            const std::uint32_t dim4514JoeKuoD6Init[]   =   { 1, 1, 1, 13, 13, 59, 13, 249, 465, 847, 1483, 975, 7729, 2773, 15745, 51237, 0 };
            const std::uint32_t dim4515JoeKuoD6Init[]   =   { 1, 1, 7, 9, 31, 41, 115, 141, 247, 355, 1109, 3239, 6495, 4515, 30145, 47705, 0 };
            const std::uint32_t dim4516JoeKuoD6Init[]   =   { 1, 1, 3, 13, 29, 41, 69, 179, 45, 271, 1909, 3095, 7199, 14049, 9903, 33383, 0 };
            const std::uint32_t dim4517JoeKuoD6Init[]   =   { 1, 1, 3, 13, 7, 45, 105, 105, 243, 121, 67, 3169, 237, 137, 4175, 54325, 0 };
            const std::uint32_t dim4518JoeKuoD6Init[]   =   { 1, 3, 3, 11, 19, 51, 93, 155, 79, 579, 1621, 1251, 7639, 15875, 25815, 56063, 0 };
            const std::uint32_t dim4519JoeKuoD6Init[]   =   { 1, 3, 3, 9, 27, 27, 77, 45, 217, 965, 1045, 875, 4515, 11261, 27859, 757, 0 };
            const std::uint32_t dim4520JoeKuoD6Init[]   =   { 1, 1, 3, 11, 17, 7, 81, 37, 299, 765, 977, 3371, 3163, 13267, 18345, 9239, 0 };
            const std::uint32_t dim4521JoeKuoD6Init[]   =   { 1, 1, 1, 3, 15, 23, 115, 11, 183, 511, 557, 3253, 153, 8465, 22659, 42143, 0 };
            const std::uint32_t dim4522JoeKuoD6Init[]   =   { 1, 1, 5, 13, 17, 61, 127, 219, 225, 981, 615, 731, 4069, 12637, 11601, 38257, 0 };
            const std::uint32_t dim4523JoeKuoD6Init[]   =   { 1, 1, 5, 3, 29, 3, 73, 79, 393, 779, 823, 2473, 3811, 4417, 9399, 50011, 0 };
            const std::uint32_t dim4524JoeKuoD6Init[]   =   { 1, 3, 3, 9, 21, 35, 61, 99, 115, 657, 629, 1129, 2355, 12665, 459, 40831, 0 };
            const std::uint32_t dim4525JoeKuoD6Init[]   =   { 1, 3, 1, 7, 25, 61, 53, 249, 15, 649, 665, 595, 1441, 8035, 5381, 7147, 0 };
            const std::uint32_t dim4526JoeKuoD6Init[]   =   { 1, 3, 1, 7, 19, 9, 27, 207, 205, 461, 1069, 4039, 6549, 2333, 29, 50067, 0 };
            const std::uint32_t dim4527JoeKuoD6Init[]   =   { 1, 1, 5, 3, 15, 7, 115, 205, 71, 73, 53, 71, 6049, 15293, 17041, 20313, 0 };
            const std::uint32_t dim4528JoeKuoD6Init[]   =   { 1, 1, 7, 7, 9, 7, 119, 99, 357, 729, 2041, 3355, 5333, 1263, 30521, 64867, 0 };
            const std::uint32_t dim4529JoeKuoD6Init[]   =   { 1, 1, 1, 7, 31, 63, 63, 159, 281, 295, 913, 2161, 8033, 13789, 17711, 14915, 0 };
            const std::uint32_t dim4530JoeKuoD6Init[]   =   { 1, 1, 7, 9, 29, 55, 69, 129, 453, 361, 1883, 17, 1765, 111, 10311, 55019, 0 };
            const std::uint32_t dim4531JoeKuoD6Init[]   =   { 1, 1, 5, 9, 21, 15, 31, 57, 291, 915, 945, 1775, 5905, 9073, 3271, 15571, 0 };
            const std::uint32_t dim4532JoeKuoD6Init[]   =   { 1, 1, 1, 7, 21, 11, 1, 9, 167, 143, 1535, 1267, 6675, 13037, 19513, 52027, 0 };
            const std::uint32_t dim4533JoeKuoD6Init[]   =   { 1, 3, 3, 7, 31, 45, 57, 105, 63, 121, 631, 679, 3873, 16333, 32069, 64725, 0 };
            const std::uint32_t dim4534JoeKuoD6Init[]   =   { 1, 1, 1, 9, 23, 41, 29, 207, 489, 319, 905, 3147, 4195, 2697, 5281, 1771, 0 };
            const std::uint32_t dim4535JoeKuoD6Init[]   =   { 1, 1, 1, 9, 25, 33, 57, 201, 405, 111, 407, 3489, 449, 8601, 1273, 42105, 0 };
            const std::uint32_t dim4536JoeKuoD6Init[]   =   { 1, 1, 1, 3, 19, 45, 123, 159, 237, 173, 781, 787, 7537, 15453, 25567, 53729, 0 };
            const std::uint32_t dim4537JoeKuoD6Init[]   =   { 1, 1, 7, 3, 29, 9, 89, 207, 345, 685, 1701, 2859, 8065, 9289, 2459, 28367, 0 };
            const std::uint32_t dim4538JoeKuoD6Init[]   =   { 1, 3, 1, 3, 31, 41, 55, 241, 81, 1001, 595, 1725, 853, 11427, 20617, 1717, 0 };
            const std::uint32_t dim4539JoeKuoD6Init[]   =   { 1, 1, 3, 3, 9, 45, 121, 69, 177, 1017, 211, 2753, 6923, 1387, 32063, 45337, 0 };
            const std::uint32_t dim4540JoeKuoD6Init[]   =   { 1, 1, 5, 15, 21, 23, 95, 61, 485, 403, 619, 3035, 4881, 13423, 17815, 35221, 0 };
            const std::uint32_t dim4541JoeKuoD6Init[]   =   { 1, 1, 3, 3, 3, 59, 23, 69, 77, 309, 227, 2877, 3739, 3539, 20083, 23415, 0 };
            const std::uint32_t dim4542JoeKuoD6Init[]   =   { 1, 3, 7, 3, 17, 43, 95, 239, 223, 353, 1237, 3239, 1369, 7245, 32401, 63889, 0 };
            const std::uint32_t dim4543JoeKuoD6Init[]   =   { 1, 1, 1, 5, 25, 63, 123, 3, 291, 819, 793, 241, 5619, 8871, 18341, 2757, 0 };
            const std::uint32_t dim4544JoeKuoD6Init[]   =   { 1, 3, 7, 15, 3, 21, 17, 97, 395, 333, 909, 3783, 3635, 751, 24227, 44281, 0 };
            const std::uint32_t dim4545JoeKuoD6Init[]   =   { 1, 3, 7, 13, 29, 49, 123, 195, 191, 159, 211, 1887, 3047, 4871, 2607, 32425, 0 };
            const std::uint32_t dim4546JoeKuoD6Init[]   =   { 1, 1, 7, 7, 15, 57, 91, 255, 267, 897, 441, 1581, 953, 6951, 17275, 50229, 0 };
            const std::uint32_t dim4547JoeKuoD6Init[]   =   { 1, 3, 7, 15, 1, 35, 91, 219, 7, 117, 119, 2687, 1215, 9517, 10849, 28347, 0 };
            const std::uint32_t dim4548JoeKuoD6Init[]   =   { 1, 1, 1, 1, 21, 55, 67, 221, 503, 883, 1037, 2965, 1485, 8557, 28091, 25459, 0 };
            const std::uint32_t dim4549JoeKuoD6Init[]   =   { 1, 3, 5, 9, 19, 3, 73, 123, 95, 307, 1339, 3669, 5077, 12049, 523, 21457, 0 };
            const std::uint32_t dim4550JoeKuoD6Init[]   =   { 1, 3, 1, 13, 3, 1, 111, 97, 371, 697, 1989, 3715, 7875, 6841, 7009, 17809, 0 };
            const std::uint32_t dim4551JoeKuoD6Init[]   =   { 1, 1, 1, 9, 25, 21, 19, 43, 329, 531, 491, 1147, 1469, 12841, 29651, 29517, 0 };
            const std::uint32_t dim4552JoeKuoD6Init[]   =   { 1, 1, 5, 1, 15, 63, 101, 197, 477, 245, 341, 61, 3803, 10001, 5519, 19083, 0 };
            const std::uint32_t dim4553JoeKuoD6Init[]   =   { 1, 3, 7, 5, 13, 43, 7, 143, 291, 531, 1727, 871, 7091, 5737, 24285, 51017, 0 };
            const std::uint32_t dim4554JoeKuoD6Init[]   =   { 1, 3, 5, 1, 17, 13, 15, 85, 361, 153, 989, 1367, 4705, 3599, 4441, 52471, 0 };
            const std::uint32_t dim4555JoeKuoD6Init[]   =   { 1, 1, 7, 13, 21, 43, 111, 29, 299, 439, 1929, 283, 5901, 14113, 3929, 55843, 0 };
            const std::uint32_t dim4556JoeKuoD6Init[]   =   { 1, 3, 3, 9, 31, 59, 63, 43, 91, 171, 733, 1359, 425, 8505, 19777, 54723, 0 };
            const std::uint32_t dim4557JoeKuoD6Init[]   =   { 1, 1, 5, 7, 31, 1, 97, 253, 331, 307, 1749, 2115, 2535, 9945, 11013, 14231, 0 };
            const std::uint32_t dim4558JoeKuoD6Init[]   =   { 1, 1, 5, 11, 13, 7, 109, 237, 301, 383, 683, 1603, 6393, 2437, 12101, 1767, 0 };
            const std::uint32_t dim4559JoeKuoD6Init[]   =   { 1, 1, 3, 11, 15, 61, 119, 199, 109, 265, 1431, 1729, 3409, 10129, 16945, 34681, 0 };
            const std::uint32_t dim4560JoeKuoD6Init[]   =   { 1, 3, 7, 9, 13, 59, 121, 73, 29, 513, 279, 457, 7985, 15199, 10185, 33621, 0 };
            const std::uint32_t dim4561JoeKuoD6Init[]   =   { 1, 3, 7, 7, 23, 17, 27, 65, 387, 487, 1803, 2789, 461, 11201, 7001, 40229, 0 };
            const std::uint32_t dim4562JoeKuoD6Init[]   =   { 1, 1, 3, 15, 9, 13, 55, 127, 33, 513, 1055, 643, 505, 3005, 6121, 64147, 0 };
            const std::uint32_t dim4563JoeKuoD6Init[]   =   { 1, 3, 5, 15, 5, 11, 77, 233, 175, 691, 171, 2491, 6915, 14195, 7845, 36499, 0 };
            const std::uint32_t dim4564JoeKuoD6Init[]   =   { 1, 1, 5, 11, 19, 45, 103, 207, 99, 645, 1739, 1517, 5907, 16035, 14559, 44007, 0 };
            const std::uint32_t dim4565JoeKuoD6Init[]   =   { 1, 3, 7, 15, 21, 27, 53, 107, 89, 291, 983, 3527, 1025, 2985, 13747, 32715, 0 };
            const std::uint32_t dim4566JoeKuoD6Init[]   =   { 1, 1, 3, 15, 23, 17, 27, 209, 77, 959, 813, 3597, 5809, 693, 10325, 16855, 0 };
            const std::uint32_t dim4567JoeKuoD6Init[]   =   { 1, 1, 7, 11, 23, 53, 123, 99, 211, 935, 1371, 1657, 4699, 2683, 27933, 21451, 0 };
            const std::uint32_t dim4568JoeKuoD6Init[]   =   { 1, 3, 3, 3, 17, 21, 93, 201, 423, 351, 1639, 227, 5719, 13111, 5993, 44615, 0 };
            const std::uint32_t dim4569JoeKuoD6Init[]   =   { 1, 1, 7, 3, 13, 49, 59, 255, 213, 147, 1441, 3593, 6419, 15657, 1947, 62713, 0 };
            const std::uint32_t dim4570JoeKuoD6Init[]   =   { 1, 3, 1, 7, 7, 41, 79, 135, 275, 585, 925, 3139, 4351, 1827, 23533, 63031, 0 };
            const std::uint32_t dim4571JoeKuoD6Init[]   =   { 1, 1, 7, 3, 11, 1, 13, 149, 29, 897, 1043, 2393, 3931, 6741, 19973, 46303, 0 };
            const std::uint32_t dim4572JoeKuoD6Init[]   =   { 1, 1, 1, 13, 13, 57, 9, 253, 149, 67, 1531, 4049, 3013, 13947, 3371, 35317, 0 };
            const std::uint32_t dim4573JoeKuoD6Init[]   =   { 1, 3, 1, 1, 15, 19, 11, 125, 179, 383, 1273, 1551, 6441, 6579, 19659, 31005, 0 };
            const std::uint32_t dim4574JoeKuoD6Init[]   =   { 1, 1, 3, 15, 29, 37, 11, 199, 273, 663, 549, 3167, 2049, 8815, 30719, 47905, 0 };
            const std::uint32_t dim4575JoeKuoD6Init[]   =   { 1, 1, 1, 15, 7, 9, 113, 231, 155, 27, 419, 1303, 4493, 5633, 5743, 51335, 0 };
            const std::uint32_t dim4576JoeKuoD6Init[]   =   { 1, 3, 5, 13, 21, 35, 7, 63, 391, 637, 2011, 841, 5933, 10563, 7593, 34767, 0 };
            const std::uint32_t dim4577JoeKuoD6Init[]   =   { 1, 3, 1, 15, 19, 13, 89, 127, 507, 715, 1305, 2989, 7551, 1953, 26101, 54913, 0 };
            const std::uint32_t dim4578JoeKuoD6Init[]   =   { 1, 1, 5, 1, 1, 33, 101, 211, 173, 761, 177, 2721, 6949, 15801, 6639, 21405, 0 };
            const std::uint32_t dim4579JoeKuoD6Init[]   =   { 1, 3, 1, 13, 15, 23, 113, 177, 43, 743, 57, 3875, 7833, 13619, 17637, 5547, 0 };
            const std::uint32_t dim4580JoeKuoD6Init[]   =   { 1, 1, 3, 13, 21, 7, 123, 83, 391, 731, 597, 2595, 1949, 14619, 17141, 60595, 0 };
            const std::uint32_t dim4581JoeKuoD6Init[]   =   { 1, 3, 7, 13, 31, 55, 15, 43, 17, 855, 233, 1411, 1063, 12977, 22159, 59185, 0 };
            const std::uint32_t dim4582JoeKuoD6Init[]   =   { 1, 3, 7, 7, 17, 53, 67, 37, 245, 941, 1213, 1965, 6635, 10189, 12979, 63503, 0 };
            const std::uint32_t dim4583JoeKuoD6Init[]   =   { 1, 1, 5, 15, 31, 23, 15, 175, 177, 643, 1705, 3541, 2009, 12005, 27281, 16821, 0 };
            const std::uint32_t dim4584JoeKuoD6Init[]   =   { 1, 3, 1, 13, 27, 37, 1, 171, 255, 445, 171, 3555, 8169, 399, 20975, 36195, 0 };
            const std::uint32_t dim4585JoeKuoD6Init[]   =   { 1, 3, 7, 11, 13, 15, 123, 65, 173, 317, 1991, 2093, 8073, 12831, 15455, 30175, 0 };
            const std::uint32_t dim4586JoeKuoD6Init[]   =   { 1, 3, 1, 7, 5, 53, 59, 219, 407, 501, 875, 2627, 1335, 14387, 25523, 28337, 0 };
            const std::uint32_t dim4587JoeKuoD6Init[]   =   { 1, 3, 3, 13, 13, 41, 93, 125, 41, 461, 887, 1085, 3393, 11945, 16329, 43531, 0 };
            const std::uint32_t dim4588JoeKuoD6Init[]   =   { 1, 3, 1, 11, 21, 39, 1, 185, 429, 285, 443, 1165, 451, 10903, 31511, 50555, 0 };
            const std::uint32_t dim4589JoeKuoD6Init[]   =   { 1, 1, 7, 5, 11, 25, 61, 171, 493, 733, 215, 1871, 7783, 14113, 2061, 58961, 0 };
            const std::uint32_t dim4590JoeKuoD6Init[]   =   { 1, 1, 7, 7, 27, 23, 53, 45, 131, 301, 275, 3855, 4883, 6303, 25269, 12697, 0 };
            const std::uint32_t dim4591JoeKuoD6Init[]   =   { 1, 3, 5, 7, 11, 15, 71, 101, 377, 803, 1369, 3741, 633, 10571, 30659, 31101, 0 };
            const std::uint32_t dim4592JoeKuoD6Init[]   =   { 1, 1, 5, 15, 19, 53, 3, 153, 411, 685, 1405, 109, 5755, 13311, 3713, 24579, 0 };
            const std::uint32_t dim4593JoeKuoD6Init[]   =   { 1, 1, 3, 3, 27, 7, 89, 39, 5, 853, 1757, 2927, 2889, 9735, 17959, 39301, 0 };
            const std::uint32_t dim4594JoeKuoD6Init[]   =   { 1, 3, 1, 3, 13, 41, 57, 71, 187, 285, 825, 1807, 7261, 2645, 21861, 1839, 0 };
            const std::uint32_t dim4595JoeKuoD6Init[]   =   { 1, 3, 3, 5, 15, 21, 23, 7, 341, 981, 891, 721, 7221, 3137, 28725, 54993, 0 };
            const std::uint32_t dim4596JoeKuoD6Init[]   =   { 1, 1, 5, 3, 3, 61, 59, 97, 205, 359, 185, 3361, 7637, 15473, 6351, 62097, 0 };
            const std::uint32_t dim4597JoeKuoD6Init[]   =   { 1, 1, 1, 9, 13, 11, 123, 71, 199, 251, 535, 371, 1605, 12107, 13833, 2019, 0 };
            const std::uint32_t dim4598JoeKuoD6Init[]   =   { 1, 1, 7, 13, 27, 1, 43, 73, 409, 601, 1481, 649, 3293, 12257, 23377, 17225, 0 };
            const std::uint32_t dim4599JoeKuoD6Init[]   =   { 1, 1, 7, 11, 15, 55, 99, 45, 261, 461, 1507, 3575, 4425, 9895, 20191, 61863, 0 };
            const std::uint32_t dim4600JoeKuoD6Init[]   =   { 1, 3, 7, 1, 3, 7, 19, 85, 139, 691, 1685, 137, 7547, 16143, 14193, 52479, 0 };
            const std::uint32_t dim4601JoeKuoD6Init[]   =   { 1, 3, 5, 9, 17, 61, 7, 189, 31, 641, 1381, 3999, 4909, 8463, 31761, 54493, 0 };
            const std::uint32_t dim4602JoeKuoD6Init[]   =   { 1, 1, 5, 15, 17, 15, 69, 111, 55, 1011, 1859, 2643, 6043, 5125, 15875, 611, 0 };
            const std::uint32_t dim4603JoeKuoD6Init[]   =   { 1, 1, 3, 5, 3, 33, 73, 227, 327, 369, 189, 1841, 5625, 1179, 18651, 34951, 0 };
            const std::uint32_t dim4604JoeKuoD6Init[]   =   { 1, 3, 7, 13, 1, 17, 109, 149, 89, 889, 799, 3423, 2599, 14525, 12763, 23855, 0 };
            const std::uint32_t dim4605JoeKuoD6Init[]   =   { 1, 1, 3, 15, 5, 63, 87, 7, 63, 171, 1215, 557, 3009, 16305, 23517, 40101, 0 };
            const std::uint32_t dim4606JoeKuoD6Init[]   =   { 1, 1, 3, 3, 29, 31, 79, 183, 401, 813, 41, 1111, 5669, 15697, 7813, 10215, 0 };
            const std::uint32_t dim4607JoeKuoD6Init[]   =   { 1, 1, 5, 7, 9, 25, 25, 57, 343, 375, 535, 3405, 1909, 3201, 2417, 52285, 0 };
            const std::uint32_t dim4608JoeKuoD6Init[]   =   { 1, 1, 5, 9, 25, 19, 33, 183, 29, 991, 1045, 2249, 2933, 12525, 13943, 10423, 0 };
            const std::uint32_t dim4609JoeKuoD6Init[]   =   { 1, 3, 1, 7, 3, 45, 49, 37, 429, 67, 821, 1289, 7311, 16165, 25861, 57715, 0 };
            const std::uint32_t dim4610JoeKuoD6Init[]   =   { 1, 1, 7, 3, 19, 3, 33, 153, 505, 683, 611, 1691, 6421, 15517, 19161, 49013, 0 };
            const std::uint32_t dim4611JoeKuoD6Init[]   =   { 1, 3, 7, 7, 21, 21, 85, 55, 293, 199, 1671, 1881, 7147, 8241, 16173, 51873, 0 };
            const std::uint32_t dim4612JoeKuoD6Init[]   =   { 1, 3, 1, 15, 3, 61, 97, 191, 435, 511, 1599, 2705, 1897, 2607, 1801, 48583, 0 };
            const std::uint32_t dim4613JoeKuoD6Init[]   =   { 1, 1, 5, 3, 9, 23, 23, 185, 401, 947, 33, 385, 7491, 14129, 14561, 13759, 0 };
            const std::uint32_t dim4614JoeKuoD6Init[]   =   { 1, 3, 5, 15, 19, 21, 37, 233, 149, 673, 29, 1315, 3487, 6705, 28283, 43135, 0 };
            const std::uint32_t dim4615JoeKuoD6Init[]   =   { 1, 1, 1, 11, 9, 35, 101, 255, 345, 829, 689, 2747, 2145, 2101, 24863, 35529, 0 };
            const std::uint32_t dim4616JoeKuoD6Init[]   =   { 1, 3, 7, 9, 5, 5, 53, 247, 157, 729, 1621, 129, 2485, 5371, 11115, 47771, 0 };
            const std::uint32_t dim4617JoeKuoD6Init[]   =   { 1, 1, 3, 9, 29, 29, 13, 229, 87, 281, 1119, 1085, 4423, 1667, 27067, 50397, 0 };
            const std::uint32_t dim4618JoeKuoD6Init[]   =   { 1, 1, 3, 7, 11, 29, 77, 85, 121, 495, 501, 3209, 3531, 2307, 11367, 34135, 0 };
            const std::uint32_t dim4619JoeKuoD6Init[]   =   { 1, 1, 7, 9, 3, 37, 33, 209, 493, 869, 367, 3221, 1643, 3353, 22851, 4313, 0 };
            const std::uint32_t dim4620JoeKuoD6Init[]   =   { 1, 1, 1, 7, 15, 53, 27, 17, 29, 345, 821, 1831, 1963, 10089, 5101, 32689, 0 };
            const std::uint32_t dim4621JoeKuoD6Init[]   =   { 1, 1, 3, 9, 9, 61, 31, 215, 497, 591, 1301, 157, 3329, 13877, 9017, 34673, 0 };
            const std::uint32_t dim4622JoeKuoD6Init[]   =   { 1, 1, 5, 1, 29, 49, 93, 139, 279, 167, 143, 279, 6145, 6247, 519, 8869, 0 };
            const std::uint32_t dim4623JoeKuoD6Init[]   =   { 1, 3, 3, 1, 25, 41, 81, 219, 505, 335, 1941, 2963, 413, 775, 4181, 55269, 0 };
            const std::uint32_t dim4624JoeKuoD6Init[]   =   { 1, 1, 1, 11, 27, 23, 91, 9, 497, 811, 1469, 1999, 5377, 2943, 17635, 11151, 0 };
            const std::uint32_t dim4625JoeKuoD6Init[]   =   { 1, 1, 5, 15, 17, 23, 15, 235, 271, 749, 1873, 3805, 5405, 7421, 24339, 14351, 0 };
            const std::uint32_t dim4626JoeKuoD6Init[]   =   { 1, 3, 7, 1, 5, 61, 81, 9, 269, 43, 1391, 2711, 6973, 11299, 2263, 8715, 0 };
            const std::uint32_t dim4627JoeKuoD6Init[]   =   { 1, 1, 5, 13, 11, 1, 69, 235, 25, 227, 63, 2591, 913, 12555, 6263, 38981, 0 };
            const std::uint32_t dim4628JoeKuoD6Init[]   =   { 1, 3, 1, 7, 17, 7, 97, 251, 149, 959, 1895, 1179, 4031, 15975, 20313, 64067, 0 };
            const std::uint32_t dim4629JoeKuoD6Init[]   =   { 1, 3, 7, 15, 3, 17, 85, 229, 149, 925, 585, 3755, 2359, 13131, 12665, 28861, 0 };
            const std::uint32_t dim4630JoeKuoD6Init[]   =   { 1, 3, 3, 9, 5, 31, 107, 93, 347, 851, 1249, 2161, 6095, 8315, 20259, 39527, 0 };
            const std::uint32_t dim4631JoeKuoD6Init[]   =   { 1, 3, 7, 7, 21, 63, 85, 241, 501, 627, 1211, 1713, 6907, 4229, 7557, 55719, 0 };
            const std::uint32_t dim4632JoeKuoD6Init[]   =   { 1, 1, 1, 13, 19, 43, 21, 177, 13, 353, 679, 511, 5565, 993, 25345, 25087, 0 };
            const std::uint32_t dim4633JoeKuoD6Init[]   =   { 1, 3, 3, 15, 21, 15, 87, 83, 381, 547, 1429, 2417, 2425, 2097, 20889, 12353, 0 };
            const std::uint32_t dim4634JoeKuoD6Init[]   =   { 1, 3, 1, 11, 23, 21, 69, 147, 427, 271, 1829, 525, 2951, 10773, 32425, 17685, 0 };
            const std::uint32_t dim4635JoeKuoD6Init[]   =   { 1, 3, 1, 7, 15, 55, 21, 131, 195, 927, 635, 3505, 3817, 14883, 1149, 10079, 0 };
            const std::uint32_t dim4636JoeKuoD6Init[]   =   { 1, 3, 3, 9, 23, 15, 45, 147, 249, 87, 377, 1551, 4343, 15373, 2895, 44973, 0 };
            const std::uint32_t dim4637JoeKuoD6Init[]   =   { 1, 3, 1, 7, 31, 63, 67, 107, 109, 1019, 815, 231, 8135, 559, 8175, 21735, 0 };
            const std::uint32_t dim4638JoeKuoD6Init[]   =   { 1, 1, 5, 7, 7, 63, 103, 133, 167, 883, 1647, 2827, 6015, 8541, 16963, 37129, 0 };
            const std::uint32_t dim4639JoeKuoD6Init[]   =   { 1, 3, 5, 9, 27, 25, 59, 147, 29, 943, 865, 1233, 2165, 15259, 2235, 25831, 0 };
            const std::uint32_t dim4640JoeKuoD6Init[]   =   { 1, 1, 5, 7, 25, 5, 67, 89, 493, 111, 359, 1115, 7963, 6545, 7749, 29179, 0 };
            const std::uint32_t dim4641JoeKuoD6Init[]   =   { 1, 3, 7, 5, 19, 17, 89, 195, 337, 115, 1417, 3837, 4761, 1959, 16205, 61597, 0 };
            const std::uint32_t dim4642JoeKuoD6Init[]   =   { 1, 1, 5, 11, 25, 43, 3, 111, 491, 897, 1541, 909, 4751, 739, 7827, 64485, 0 };
            const std::uint32_t dim4643JoeKuoD6Init[]   =   { 1, 1, 5, 15, 19, 61, 39, 111, 451, 419, 1657, 2427, 4589, 5577, 23967, 19259, 0 };
            const std::uint32_t dim4644JoeKuoD6Init[]   =   { 1, 3, 3, 1, 31, 15, 7, 131, 329, 847, 537, 1775, 3833, 5683, 17267, 16389, 0 };
            const std::uint32_t dim4645JoeKuoD6Init[]   =   { 1, 1, 7, 1, 9, 29, 13, 25, 409, 513, 1695, 2175, 5099, 727, 5723, 43547, 0 };
            const std::uint32_t dim4646JoeKuoD6Init[]   =   { 1, 1, 5, 7, 13, 11, 29, 123, 127, 193, 1647, 3157, 2149, 16209, 19909, 14473, 0 };
            const std::uint32_t dim4647JoeKuoD6Init[]   =   { 1, 1, 1, 15, 15, 37, 125, 157, 487, 143, 1891, 2895, 4397, 10685, 1463, 55027, 0 };
            const std::uint32_t dim4648JoeKuoD6Init[]   =   { 1, 3, 7, 1, 1, 15, 115, 105, 479, 529, 1095, 2687, 4483, 15027, 15487, 7113, 0 };
            const std::uint32_t dim4649JoeKuoD6Init[]   =   { 1, 1, 3, 9, 23, 63, 113, 211, 155, 931, 175, 3037, 2359, 10413, 24561, 21099, 0 };
            const std::uint32_t dim4650JoeKuoD6Init[]   =   { 1, 3, 3, 11, 5, 15, 13, 37, 257, 447, 203, 545, 2467, 9979, 17543, 62703, 0 };
            const std::uint32_t dim4651JoeKuoD6Init[]   =   { 1, 1, 3, 7, 17, 31, 83, 91, 79, 265, 1415, 2347, 5337, 7615, 27739, 33841, 0 };
            const std::uint32_t dim4652JoeKuoD6Init[]   =   { 1, 3, 5, 7, 17, 63, 37, 153, 347, 909, 1945, 7, 2071, 15195, 32083, 26713, 0 };
            const std::uint32_t dim4653JoeKuoD6Init[]   =   { 1, 1, 3, 11, 19, 51, 69, 21, 323, 635, 443, 1685, 6275, 13787, 20921, 45553, 0 };
            const std::uint32_t dim4654JoeKuoD6Init[]   =   { 1, 3, 3, 7, 15, 35, 67, 247, 257, 429, 2029, 523, 3219, 3893, 26677, 53273, 0 };
            const std::uint32_t dim4655JoeKuoD6Init[]   =   { 1, 1, 7, 9, 9, 3, 119, 121, 445, 149, 1539, 1887, 2995, 14867, 809, 48065, 0 };
            const std::uint32_t dim4656JoeKuoD6Init[]   =   { 1, 3, 5, 13, 15, 27, 75, 9, 217, 35, 1363, 2383, 4357, 1153, 20565, 62277, 0 };
            const std::uint32_t dim4657JoeKuoD6Init[]   =   { 1, 1, 7, 1, 21, 1, 11, 53, 331, 765, 407, 453, 2725, 11199, 645, 14915, 0 };
            const std::uint32_t dim4658JoeKuoD6Init[]   =   { 1, 1, 5, 1, 29, 11, 5, 159, 395, 53, 323, 1347, 5529, 8525, 24003, 20535, 0 };
            const std::uint32_t dim4659JoeKuoD6Init[]   =   { 1, 3, 3, 15, 9, 19, 87, 181, 391, 639, 703, 611, 997, 359, 2471, 58465, 0 };
            const std::uint32_t dim4660JoeKuoD6Init[]   =   { 1, 3, 5, 9, 27, 9, 117, 47, 223, 509, 1537, 1235, 3885, 6767, 17131, 63421, 0 };
            const std::uint32_t dim4661JoeKuoD6Init[]   =   { 1, 1, 5, 1, 15, 15, 113, 67, 477, 597, 1795, 3065, 4565, 3609, 16419, 19667, 0 };
            const std::uint32_t dim4662JoeKuoD6Init[]   =   { 1, 1, 7, 11, 1, 63, 33, 211, 271, 773, 499, 2309, 1303, 14015, 30377, 53195, 0 };
            const std::uint32_t dim4663JoeKuoD6Init[]   =   { 1, 1, 7, 11, 5, 23, 17, 183, 321, 315, 203, 3371, 907, 9331, 21031, 33765, 0 };
            const std::uint32_t dim4664JoeKuoD6Init[]   =   { 1, 3, 3, 7, 7, 53, 111, 69, 441, 283, 195, 2415, 7293, 7659, 2731, 5417, 0 };
            const std::uint32_t dim4665JoeKuoD6Init[]   =   { 1, 3, 5, 15, 3, 61, 5, 241, 427, 463, 1729, 653, 7671, 10979, 7247, 36931, 0 };
            const std::uint32_t dim4666JoeKuoD6Init[]   =   { 1, 3, 1, 9, 3, 5, 105, 117, 465, 853, 2005, 3925, 4419, 4441, 3701, 50747, 0 };
            const std::uint32_t dim4667JoeKuoD6Init[]   =   { 1, 1, 3, 7, 1, 3, 3, 149, 65, 405, 299, 99, 481, 14323, 11565, 6227, 0 };
            const std::uint32_t dim4668JoeKuoD6Init[]   =   { 1, 3, 7, 5, 29, 3, 19, 3, 253, 895, 879, 2435, 2151, 10673, 11013, 43055, 0 };
            const std::uint32_t dim4669JoeKuoD6Init[]   =   { 1, 3, 1, 11, 15, 57, 127, 197, 319, 913, 1039, 811, 7767, 5791, 31725, 8733, 0 };
            const std::uint32_t dim4670JoeKuoD6Init[]   =   { 1, 1, 7, 3, 13, 25, 25, 81, 229, 185, 39, 2789, 579, 4973, 28617, 60871, 0 };
            const std::uint32_t dim4671JoeKuoD6Init[]   =   { 1, 1, 7, 3, 25, 17, 41, 7, 103, 269, 55, 2651, 7579, 10935, 8917, 14323, 0 };
            const std::uint32_t dim4672JoeKuoD6Init[]   =   { 1, 3, 7, 7, 13, 7, 99, 205, 293, 877, 1893, 3013, 2389, 6021, 2645, 18175, 0 };
            const std::uint32_t dim4673JoeKuoD6Init[]   =   { 1, 1, 3, 7, 9, 39, 59, 187, 191, 761, 339, 3381, 2921, 5197, 16963, 43019, 0 };
            const std::uint32_t dim4674JoeKuoD6Init[]   =   { 1, 3, 3, 13, 7, 23, 41, 203, 311, 981, 323, 1675, 6689, 579, 3885, 64475, 0 };
            const std::uint32_t dim4675JoeKuoD6Init[]   =   { 1, 3, 5, 15, 21, 39, 35, 193, 167, 1009, 493, 829, 6571, 1299, 13061, 1163, 0 };
            const std::uint32_t dim4676JoeKuoD6Init[]   =   { 1, 1, 3, 5, 3, 19, 123, 123, 111, 599, 193, 3419, 7173, 5595, 12449, 52247, 0 };
            const std::uint32_t dim4677JoeKuoD6Init[]   =   { 1, 3, 5, 11, 9, 25, 65, 49, 239, 953, 481, 3455, 4335, 305, 22469, 11949, 0 };
            const std::uint32_t dim4678JoeKuoD6Init[]   =   { 1, 1, 3, 7, 15, 1, 13, 77, 147, 49, 1445, 931, 3405, 15951, 15215, 26451, 0 };
            const std::uint32_t dim4679JoeKuoD6Init[]   =   { 1, 3, 1, 1, 21, 53, 17, 7, 247, 243, 805, 795, 489, 13351, 13493, 30937, 0 };
            const std::uint32_t dim4680JoeKuoD6Init[]   =   { 1, 3, 7, 5, 5, 13, 39, 115, 397, 757, 423, 2559, 1677, 9449, 24563, 869, 0 };
            const std::uint32_t dim4681JoeKuoD6Init[]   =   { 1, 1, 3, 11, 23, 9, 27, 233, 165, 853, 1721, 599, 551, 11657, 27623, 40119, 0 };
            const std::uint32_t dim4682JoeKuoD6Init[]   =   { 1, 1, 3, 1, 3, 47, 75, 207, 113, 417, 1317, 2215, 2395, 1841, 23125, 50401, 0 };
            const std::uint32_t dim4683JoeKuoD6Init[]   =   { 1, 3, 3, 1, 13, 55, 103, 55, 351, 785, 1665, 3603, 7705, 4811, 21129, 38115, 0 };
            const std::uint32_t dim4684JoeKuoD6Init[]   =   { 1, 1, 1, 5, 5, 49, 93, 189, 317, 701, 1545, 1017, 4133, 7655, 19827, 52155, 0 };
            const std::uint32_t dim4685JoeKuoD6Init[]   =   { 1, 3, 3, 13, 17, 37, 7, 249, 139, 529, 235, 3801, 7871, 459, 15127, 13231, 0 };
            const std::uint32_t dim4686JoeKuoD6Init[]   =   { 1, 3, 7, 5, 7, 63, 99, 241, 131, 455, 1287, 3539, 8029, 12661, 23313, 54029, 0 };
            const std::uint32_t dim4687JoeKuoD6Init[]   =   { 1, 3, 1, 3, 29, 63, 51, 227, 497, 685, 1351, 449, 7851, 10815, 17379, 62097, 0 };
            const std::uint32_t dim4688JoeKuoD6Init[]   =   { 1, 3, 1, 11, 25, 61, 73, 29, 467, 533, 855, 853, 5557, 10953, 18307, 27135, 0 };
            const std::uint32_t dim4689JoeKuoD6Init[]   =   { 1, 1, 7, 3, 13, 49, 63, 171, 177, 283, 1365, 3087, 5445, 15109, 12523, 25193, 0 };
            const std::uint32_t dim4690JoeKuoD6Init[]   =   { 1, 3, 5, 15, 9, 39, 95, 81, 417, 199, 1653, 3673, 2663, 8101, 12199, 22759, 0 };
            const std::uint32_t dim4691JoeKuoD6Init[]   =   { 1, 1, 3, 9, 29, 15, 29, 215, 21, 721, 245, 1197, 7251, 5721, 6735, 7751, 0 };
            const std::uint32_t dim4692JoeKuoD6Init[]   =   { 1, 3, 5, 5, 21, 7, 81, 61, 157, 707, 819, 1689, 4203, 5559, 25483, 43325, 0 };
            const std::uint32_t dim4693JoeKuoD6Init[]   =   { 1, 1, 7, 13, 15, 51, 47, 197, 269, 921, 353, 2865, 6227, 537, 20015, 53823, 0 };
            const std::uint32_t dim4694JoeKuoD6Init[]   =   { 1, 1, 3, 5, 13, 25, 91, 221, 111, 587, 1119, 2343, 4651, 4641, 15915, 36323, 0 };
            const std::uint32_t dim4695JoeKuoD6Init[]   =   { 1, 1, 7, 11, 1, 45, 7, 215, 483, 545, 731, 3041, 3121, 8681, 20651, 4069, 0 };
            const std::uint32_t dim4696JoeKuoD6Init[]   =   { 1, 3, 7, 13, 13, 27, 109, 65, 103, 805, 299, 2069, 6017, 14565, 20505, 16161, 0 };
            const std::uint32_t dim4697JoeKuoD6Init[]   =   { 1, 1, 7, 5, 11, 33, 105, 213, 237, 583, 1033, 2333, 845, 6493, 505, 2563, 0 };
            const std::uint32_t dim4698JoeKuoD6Init[]   =   { 1, 1, 5, 7, 3, 5, 11, 173, 373, 341, 269, 177, 3175, 9413, 601, 13591, 0 };
            const std::uint32_t dim4699JoeKuoD6Init[]   =   { 1, 1, 5, 13, 7, 57, 61, 187, 121, 405, 665, 111, 7535, 3355, 14051, 511, 0 };
            const std::uint32_t dim4700JoeKuoD6Init[]   =   { 1, 1, 1, 3, 3, 29, 15, 253, 227, 123, 333, 1343, 7313, 1955, 17741, 30831, 0 };
            const std::uint32_t dim4701JoeKuoD6Init[]   =   { 1, 3, 5, 1, 5, 47, 65, 183, 199, 839, 925, 2711, 4609, 201, 15177, 29817, 0 };
            const std::uint32_t dim4702JoeKuoD6Init[]   =   { 1, 3, 7, 9, 21, 63, 5, 163, 265, 581, 1795, 3937, 4641, 2073, 32225, 60831, 0 };
            const std::uint32_t dim4703JoeKuoD6Init[]   =   { 1, 1, 1, 5, 7, 47, 125, 203, 511, 841, 1937, 3431, 1495, 12827, 5893, 19265, 0 };
            const std::uint32_t dim4704JoeKuoD6Init[]   =   { 1, 1, 5, 5, 9, 49, 17, 247, 391, 241, 3, 2253, 6319, 89, 4449, 6371, 0 };
            const std::uint32_t dim4705JoeKuoD6Init[]   =   { 1, 3, 1, 1, 31, 7, 51, 61, 461, 391, 273, 1609, 5825, 16029, 3851, 39213, 0 };
            const std::uint32_t dim4706JoeKuoD6Init[]   =   { 1, 3, 3, 7, 29, 21, 65, 75, 317, 925, 1319, 3827, 965, 5685, 17007, 64365, 0 };
            const std::uint32_t dim4707JoeKuoD6Init[]   =   { 1, 3, 1, 5, 23, 23, 109, 59, 31, 659, 635, 2209, 857, 9847, 2507, 18325, 0 };
            const std::uint32_t dim4708JoeKuoD6Init[]   =   { 1, 1, 1, 1, 17, 51, 53, 77, 461, 147, 229, 2821, 2405, 1259, 1121, 17429, 0 };
            const std::uint32_t dim4709JoeKuoD6Init[]   =   { 1, 3, 5, 3, 31, 3, 57, 157, 321, 731, 1609, 2139, 899, 12599, 19803, 51083, 0 };
            const std::uint32_t dim4710JoeKuoD6Init[]   =   { 1, 1, 3, 11, 27, 43, 73, 209, 431, 587, 1247, 2803, 3593, 1351, 18701, 33423, 0 };
            const std::uint32_t dim4711JoeKuoD6Init[]   =   { 1, 3, 5, 13, 27, 19, 67, 245, 339, 879, 2035, 1801, 5845, 3883, 22057, 15771, 0 };
            const std::uint32_t dim4712JoeKuoD6Init[]   =   { 1, 1, 3, 11, 11, 55, 93, 51, 57, 127, 1325, 3975, 3989, 2347, 18831, 2979, 0 };
            const std::uint32_t dim4713JoeKuoD6Init[]   =   { 1, 1, 1, 13, 17, 1, 17, 103, 303, 777, 1973, 2943, 7439, 8953, 27227, 10229, 0 };
            const std::uint32_t dim4714JoeKuoD6Init[]   =   { 1, 3, 3, 15, 1, 41, 53, 219, 415, 399, 995, 205, 7719, 10937, 31879, 755, 0 };
            const std::uint32_t dim4715JoeKuoD6Init[]   =   { 1, 3, 7, 9, 13, 7, 99, 93, 419, 1019, 1605, 161, 3831, 9147, 7877, 1333, 0 };
            const std::uint32_t dim4716JoeKuoD6Init[]   =   { 1, 3, 7, 15, 5, 51, 37, 115, 259, 549, 353, 2067, 7657, 1283, 20333, 2325, 0 };
            const std::uint32_t dim4717JoeKuoD6Init[]   =   { 1, 1, 3, 3, 23, 33, 63, 233, 363, 719, 1099, 471, 3079, 10577, 19063, 31535, 0 };
            const std::uint32_t dim4718JoeKuoD6Init[]   =   { 1, 3, 7, 15, 23, 19, 109, 105, 497, 881, 1055, 537, 4607, 239, 22785, 60201, 0 };
            const std::uint32_t dim4719JoeKuoD6Init[]   =   { 1, 3, 3, 5, 19, 11, 1, 207, 163, 437, 713, 667, 1427, 7505, 28055, 43101, 0 };
            const std::uint32_t dim4720JoeKuoD6Init[]   =   { 1, 3, 5, 5, 25, 45, 75, 9, 109, 545, 573, 2685, 1013, 2973, 18619, 55945, 0 };
            const std::uint32_t dim4721JoeKuoD6Init[]   =   { 1, 1, 1, 3, 27, 27, 39, 33, 285, 453, 613, 2707, 2155, 4355, 21105, 7969, 0 };
            const std::uint32_t dim4722JoeKuoD6Init[]   =   { 1, 3, 3, 9, 1, 31, 71, 101, 491, 409, 65, 1479, 5743, 525, 2863, 53657, 0 };
            const std::uint32_t dim4723JoeKuoD6Init[]   =   { 1, 1, 3, 1, 17, 63, 55, 11, 125, 447, 275, 2243, 6827, 5753, 32401, 13819, 0 };
            const std::uint32_t dim4724JoeKuoD6Init[]   =   { 1, 1, 3, 9, 21, 47, 5, 127, 285, 471, 1681, 945, 6141, 5651, 10273, 30811, 0 };
            const std::uint32_t dim4725JoeKuoD6Init[]   =   { 1, 3, 3, 1, 13, 53, 91, 3, 255, 429, 107, 2937, 2971, 10251, 15009, 37477, 0 };
            const std::uint32_t dim4726JoeKuoD6Init[]   =   { 1, 1, 7, 13, 21, 63, 73, 3, 63, 491, 101, 1981, 7457, 879, 6243, 22275, 0 };
            const std::uint32_t dim4727JoeKuoD6Init[]   =   { 1, 3, 1, 1, 11, 43, 121, 101, 293, 639, 645, 2723, 2075, 3629, 22105, 18199, 0 };
            const std::uint32_t dim4728JoeKuoD6Init[]   =   { 1, 1, 3, 1, 31, 9, 69, 97, 511, 663, 1147, 1237, 389, 255, 8661, 38533, 0 };
            const std::uint32_t dim4729JoeKuoD6Init[]   =   { 1, 3, 3, 7, 3, 13, 23, 71, 197, 439, 2003, 1771, 8073, 1549, 29089, 5409, 0 };
            const std::uint32_t dim4730JoeKuoD6Init[]   =   { 1, 3, 1, 1, 9, 23, 1, 221, 159, 699, 593, 3385, 3869, 10105, 22097, 34753, 0 };
            const std::uint32_t dim4731JoeKuoD6Init[]   =   { 1, 1, 7, 1, 29, 47, 41, 137, 333, 357, 325, 3151, 6641, 3823, 8763, 28327, 0 };
            const std::uint32_t dim4732JoeKuoD6Init[]   =   { 1, 3, 1, 7, 19, 19, 39, 225, 477, 619, 583, 229, 6177, 9615, 1203, 13711, 0 };
            const std::uint32_t dim4733JoeKuoD6Init[]   =   { 1, 1, 3, 13, 9, 41, 127, 147, 13, 301, 861, 2019, 3517, 1147, 21587, 42387, 0 };
            const std::uint32_t dim4734JoeKuoD6Init[]   =   { 1, 1, 5, 11, 9, 63, 11, 121, 251, 199, 483, 2287, 4667, 3887, 10611, 6019, 0 };
            const std::uint32_t dim4735JoeKuoD6Init[]   =   { 1, 1, 3, 13, 23, 19, 89, 73, 355, 399, 749, 687, 5707, 11443, 817, 38967, 0 };
            const std::uint32_t dim4736JoeKuoD6Init[]   =   { 1, 3, 5, 9, 3, 23, 115, 207, 373, 541, 73, 1285, 7245, 12505, 5787, 61207, 0 };
            const std::uint32_t dim4737JoeKuoD6Init[]   =   { 1, 3, 5, 15, 27, 37, 115, 203, 195, 793, 1577, 1283, 7299, 4025, 5319, 5375, 0 };
            const std::uint32_t dim4738JoeKuoD6Init[]   =   { 1, 1, 7, 15, 25, 19, 61, 11, 215, 771, 1057, 451, 1965, 13693, 25617, 42657, 0 };
            const std::uint32_t dim4739JoeKuoD6Init[]   =   { 1, 3, 3, 7, 1, 19, 23, 217, 175, 901, 2009, 2989, 5111, 5027, 4805, 37843, 0 };
            const std::uint32_t dim4740JoeKuoD6Init[]   =   { 1, 3, 1, 11, 11, 37, 3, 131, 459, 769, 201, 3979, 3009, 8691, 27005, 32175, 0 };
            const std::uint32_t dim4741JoeKuoD6Init[]   =   { 1, 3, 5, 7, 27, 27, 117, 23, 403, 1003, 1501, 785, 6313, 10187, 5085, 30751, 0 };
            const std::uint32_t dim4742JoeKuoD6Init[]   =   { 1, 1, 7, 3, 11, 41, 73, 151, 19, 657, 131, 1901, 3879, 14995, 24085, 56621, 0 };
            const std::uint32_t dim4743JoeKuoD6Init[]   =   { 1, 3, 7, 15, 23, 3, 61, 199, 67, 483, 1961, 3583, 5937, 5749, 16685, 11831, 0 };
            const std::uint32_t dim4744JoeKuoD6Init[]   =   { 1, 1, 3, 15, 25, 15, 97, 9, 299, 641, 883, 2901, 123, 1523, 7055, 15609, 0 };
            const std::uint32_t dim4745JoeKuoD6Init[]   =   { 1, 3, 5, 5, 31, 55, 19, 45, 239, 543, 2005, 1041, 1711, 11059, 19927, 17475, 0 };
            const std::uint32_t dim4746JoeKuoD6Init[]   =   { 1, 1, 3, 9, 5, 59, 105, 209, 323, 613, 1963, 2227, 2947, 11761, 21375, 13265, 0 };
            const std::uint32_t dim4747JoeKuoD6Init[]   =   { 1, 3, 3, 15, 1, 5, 117, 37, 93, 243, 305, 2299, 5163, 9205, 28761, 35987, 0 };
            const std::uint32_t dim4748JoeKuoD6Init[]   =   { 1, 1, 1, 5, 5, 29, 13, 147, 457, 187, 1729, 1547, 7745, 13155, 7833, 57449, 0 };
            const std::uint32_t dim4749JoeKuoD6Init[]   =   { 1, 3, 3, 13, 1, 51, 49, 253, 23, 389, 1611, 3045, 5909, 3947, 25105, 3327, 0 };
            const std::uint32_t dim4750JoeKuoD6Init[]   =   { 1, 3, 1, 11, 15, 47, 19, 15, 231, 57, 763, 1879, 1765, 14861, 22893, 19437, 0 };
            const std::uint32_t dim4751JoeKuoD6Init[]   =   { 1, 1, 3, 15, 1, 19, 85, 65, 139, 629, 361, 3513, 3807, 799, 8349, 29247, 0 };
            const std::uint32_t dim4752JoeKuoD6Init[]   =   { 1, 3, 3, 13, 9, 11, 65, 201, 471, 89, 355, 121, 3947, 10775, 3599, 6041, 0 };
            const std::uint32_t dim4753JoeKuoD6Init[]   =   { 1, 3, 7, 3, 5, 53, 33, 167, 431, 129, 1449, 3263, 7691, 12569, 7551, 41101, 0 };
            const std::uint32_t dim4754JoeKuoD6Init[]   =   { 1, 1, 3, 15, 9, 41, 5, 239, 361, 773, 955, 3663, 6051, 12889, 5841, 59615, 0 };
            const std::uint32_t dim4755JoeKuoD6Init[]   =   { 1, 1, 7, 5, 5, 33, 97, 9, 495, 845, 1953, 3533, 5715, 15055, 25211, 9351, 0 };
            const std::uint32_t dim4756JoeKuoD6Init[]   =   { 1, 3, 1, 11, 25, 37, 83, 153, 289, 739, 353, 1121, 7641, 2081, 28439, 38085, 0 };
            const std::uint32_t dim4757JoeKuoD6Init[]   =   { 1, 3, 1, 1, 27, 9, 63, 135, 395, 641, 1759, 3727, 4371, 5193, 2783, 12389, 0 };
            const std::uint32_t dim4758JoeKuoD6Init[]   =   { 1, 3, 3, 15, 3, 9, 5, 153, 111, 675, 1957, 3817, 4269, 10787, 3413, 34199, 0 };
            const std::uint32_t dim4759JoeKuoD6Init[]   =   { 1, 3, 5, 9, 23, 23, 97, 137, 255, 249, 333, 2329, 1055, 13769, 13109, 33443, 0 };
            const std::uint32_t dim4760JoeKuoD6Init[]   =   { 1, 1, 1, 15, 7, 37, 99, 219, 483, 755, 263, 3523, 6179, 4817, 29873, 12771, 0 };
            const std::uint32_t dim4761JoeKuoD6Init[]   =   { 1, 1, 3, 5, 23, 7, 77, 97, 105, 631, 175, 1911, 7271, 1009, 24081, 61207, 0 };
            const std::uint32_t dim4762JoeKuoD6Init[]   =   { 1, 3, 5, 3, 1, 31, 71, 91, 265, 669, 1839, 3989, 8127, 15001, 1419, 8895, 0 };
            const std::uint32_t dim4763JoeKuoD6Init[]   =   { 1, 3, 1, 13, 27, 51, 93, 155, 49, 991, 653, 203, 3863, 5363, 31969, 36083, 0 };
            const std::uint32_t dim4764JoeKuoD6Init[]   =   { 1, 3, 3, 7, 31, 27, 21, 73, 21, 675, 407, 1215, 2963, 6799, 15259, 13125, 0 };
            const std::uint32_t dim4765JoeKuoD6Init[]   =   { 1, 3, 5, 13, 5, 53, 19, 215, 243, 487, 689, 2519, 6393, 3987, 30847, 37919, 0 };
            const std::uint32_t dim4766JoeKuoD6Init[]   =   { 1, 3, 3, 7, 5, 31, 115, 231, 255, 955, 2023, 1487, 6575, 9873, 22585, 29951, 0 };
            const std::uint32_t dim4767JoeKuoD6Init[]   =   { 1, 3, 5, 11, 11, 57, 109, 203, 417, 29, 1311, 893, 1047, 2413, 9305, 38219, 0 };
            const std::uint32_t dim4768JoeKuoD6Init[]   =   { 1, 3, 1, 7, 23, 51, 113, 3, 105, 915, 1145, 3431, 7331, 3323, 31669, 21485, 0 };
            const std::uint32_t dim4769JoeKuoD6Init[]   =   { 1, 1, 7, 13, 9, 29, 119, 205, 403, 1023, 257, 863, 2983, 1895, 16539, 23385, 0 };
            const std::uint32_t dim4770JoeKuoD6Init[]   =   { 1, 1, 7, 13, 27, 21, 47, 139, 341, 509, 1107, 2197, 3649, 14301, 30789, 48783, 0 };
            const std::uint32_t dim4771JoeKuoD6Init[]   =   { 1, 3, 3, 7, 25, 19, 99, 11, 309, 919, 1809, 3015, 1587, 3779, 1289, 30207, 0 };
            const std::uint32_t dim4772JoeKuoD6Init[]   =   { 1, 3, 5, 11, 9, 43, 57, 171, 9, 151, 173, 2301, 7723, 2083, 319, 52883, 0 };
            const std::uint32_t dim4773JoeKuoD6Init[]   =   { 1, 1, 3, 1, 3, 13, 63, 11, 231, 117, 1257, 237, 581, 13871, 15501, 8741, 0 };
            const std::uint32_t dim4774JoeKuoD6Init[]   =   { 1, 3, 5, 9, 13, 63, 55, 155, 291, 721, 123, 929, 3351, 11651, 12513, 1779, 0 };
            const std::uint32_t dim4775JoeKuoD6Init[]   =   { 1, 3, 7, 3, 31, 5, 61, 81, 465, 639, 1363, 3157, 2401, 9513, 32559, 34477, 0 };
            const std::uint32_t dim4776JoeKuoD6Init[]   =   { 1, 3, 1, 15, 27, 25, 3, 117, 277, 13, 707, 3825, 7287, 10181, 30127, 57247, 0 };
            const std::uint32_t dim4777JoeKuoD6Init[]   =   { 1, 1, 7, 11, 21, 21, 53, 17, 407, 851, 1191, 285, 6815, 1595, 25507, 8099, 0 };
            const std::uint32_t dim4778JoeKuoD6Init[]   =   { 1, 3, 5, 9, 9, 61, 83, 61, 65, 671, 63, 311, 6897, 15327, 29809, 4899, 0 };
            const std::uint32_t dim4779JoeKuoD6Init[]   =   { 1, 1, 7, 1, 21, 45, 99, 235, 477, 461, 1119, 4087, 2057, 14861, 31969, 24357, 0 };
            const std::uint32_t dim4780JoeKuoD6Init[]   =   { 1, 1, 7, 9, 31, 9, 65, 123, 281, 273, 1059, 1625, 6265, 9635, 11563, 45053, 0 };
            const std::uint32_t dim4781JoeKuoD6Init[]   =   { 1, 3, 3, 7, 1, 41, 15, 23, 43, 727, 1271, 1741, 765, 13265, 4145, 1335, 0 };
            const std::uint32_t dim4782JoeKuoD6Init[]   =   { 1, 1, 3, 7, 17, 55, 107, 231, 263, 197, 659, 3621, 2789, 5171, 28635, 13595, 0 };
            const std::uint32_t dim4783JoeKuoD6Init[]   =   { 1, 1, 5, 1, 27, 23, 13, 83, 431, 507, 1571, 1573, 1733, 12171, 8181, 30843, 0 };
            const std::uint32_t dim4784JoeKuoD6Init[]   =   { 1, 3, 7, 11, 1, 53, 107, 39, 497, 579, 453, 1339, 1415, 10317, 2741, 34599, 0 };
            const std::uint32_t dim4785JoeKuoD6Init[]   =   { 1, 3, 3, 5, 31, 41, 49, 41, 33, 665, 1783, 87, 317, 6603, 22603, 22879, 0 };
            const std::uint32_t dim4786JoeKuoD6Init[]   =   { 1, 3, 1, 15, 5, 47, 41, 87, 231, 853, 1615, 2299, 4643, 9249, 15641, 14323, 0 };
            const std::uint32_t dim4787JoeKuoD6Init[]   =   { 1, 3, 7, 9, 5, 45, 55, 153, 31, 247, 67, 2335, 6057, 4379, 27579, 38437, 0 };
            const std::uint32_t dim4788JoeKuoD6Init[]   =   { 1, 1, 5, 7, 9, 3, 73, 81, 479, 909, 1097, 3945, 4485, 7815, 22855, 20825, 0 };
            const std::uint32_t dim4789JoeKuoD6Init[]   =   { 1, 3, 1, 15, 19, 43, 97, 57, 339, 167, 135, 1777, 7681, 9715, 13863, 6347, 0 };
            const std::uint32_t dim4790JoeKuoD6Init[]   =   { 1, 1, 1, 1, 5, 53, 33, 123, 449, 165, 1283, 2977, 5919, 12929, 32073, 61851, 0 };
            const std::uint32_t dim4791JoeKuoD6Init[]   =   { 1, 1, 5, 15, 27, 27, 19, 157, 267, 651, 1319, 3841, 7739, 9947, 16801, 41325, 0 };
            const std::uint32_t dim4792JoeKuoD6Init[]   =   { 1, 3, 7, 9, 19, 7, 83, 95, 401, 293, 437, 1983, 119, 7553, 11097, 11925, 0 };
            const std::uint32_t dim4793JoeKuoD6Init[]   =   { 1, 1, 3, 5, 21, 1, 53, 201, 385, 843, 1801, 99, 2697, 9659, 28789, 31417, 0 };
            const std::uint32_t dim4794JoeKuoD6Init[]   =   { 1, 1, 5, 5, 29, 57, 103, 89, 77, 597, 1849, 3433, 4267, 11167, 3841, 44023, 0 };
            const std::uint32_t dim4795JoeKuoD6Init[]   =   { 1, 1, 7, 1, 21, 47, 113, 253, 249, 431, 1899, 2859, 7345, 5725, 14805, 19999, 0 };
            const std::uint32_t dim4796JoeKuoD6Init[]   =   { 1, 3, 3, 5, 1, 11, 77, 213, 359, 665, 1855, 2743, 2407, 14677, 17957, 63257, 0 };
            const std::uint32_t dim4797JoeKuoD6Init[]   =   { 1, 3, 7, 13, 23, 29, 127, 183, 275, 849, 1005, 3159, 3867, 13029, 7527, 13035, 0 };
            const std::uint32_t dim4798JoeKuoD6Init[]   =   { 1, 1, 1, 15, 29, 47, 81, 225, 77, 879, 1279, 1929, 1457, 2025, 32229, 2847, 0 };
            const std::uint32_t dim4799JoeKuoD6Init[]   =   { 1, 1, 1, 3, 29, 45, 37, 189, 217, 53, 281, 1785, 1929, 763, 5875, 34303, 0 };
            const std::uint32_t dim4800JoeKuoD6Init[]   =   { 1, 3, 1, 9, 21, 61, 21, 149, 215, 13, 1221, 5, 7153, 14089, 3119, 33115, 0 };
            const std::uint32_t dim4801JoeKuoD6Init[]   =   { 1, 3, 7, 11, 7, 57, 89, 185, 485, 649, 1765, 747, 2983, 6791, 25015, 13627, 0 };
            const std::uint32_t dim4802JoeKuoD6Init[]   =   { 1, 1, 1, 9, 11, 53, 77, 203, 425, 237, 487, 2317, 1047, 8277, 23405, 30445, 0 };
            const std::uint32_t dim4803JoeKuoD6Init[]   =   { 1, 1, 3, 5, 7, 29, 39, 195, 109, 381, 655, 931, 4469, 16215, 10627, 64171, 0 };
            const std::uint32_t dim4804JoeKuoD6Init[]   =   { 1, 3, 1, 3, 5, 9, 89, 131, 509, 275, 489, 3161, 3701, 11951, 6579, 42839, 0 };
            const std::uint32_t dim4805JoeKuoD6Init[]   =   { 1, 3, 7, 13, 15, 37, 65, 91, 305, 433, 1815, 169, 3117, 47, 30331, 34863, 0 };
            const std::uint32_t dim4806JoeKuoD6Init[]   =   { 1, 3, 3, 9, 21, 3, 21, 113, 25, 833, 1579, 4021, 3481, 55, 20833, 46277, 0 };
            const std::uint32_t dim4807JoeKuoD6Init[]   =   { 1, 1, 1, 5, 19, 37, 61, 229, 61, 363, 817, 1235, 6235, 7261, 29917, 43057, 0 };
            const std::uint32_t dim4808JoeKuoD6Init[]   =   { 1, 3, 1, 9, 7, 59, 119, 189, 341, 945, 633, 3683, 2589, 15453, 4989, 40055, 0 };
            const std::uint32_t dim4809JoeKuoD6Init[]   =   { 1, 1, 1, 5, 25, 63, 61, 73, 207, 205, 1011, 2857, 8137, 2121, 26731, 46011, 0 };
            const std::uint32_t dim4810JoeKuoD6Init[]   =   { 1, 3, 7, 11, 13, 59, 107, 57, 49, 555, 441, 1771, 4939, 12107, 8263, 16243, 0 };
            const std::uint32_t dim4811JoeKuoD6Init[]   =   { 1, 3, 5, 13, 15, 49, 89, 217, 83, 225, 2001, 2727, 4651, 619, 16473, 47525, 0 };
            const std::uint32_t dim4812JoeKuoD6Init[]   =   { 1, 3, 5, 9, 5, 63, 115, 91, 337, 757, 703, 559, 1683, 14875, 30769, 30331, 0 };
            const std::uint32_t dim4813JoeKuoD6Init[]   =   { 1, 3, 1, 15, 3, 3, 119, 79, 487, 519, 523, 1177, 7105, 12343, 24671, 31711, 0 };
            const std::uint32_t dim4814JoeKuoD6Init[]   =   { 1, 1, 7, 15, 25, 63, 87, 23, 59, 277, 849, 953, 4567, 11309, 26181, 749, 0 };
            const std::uint32_t dim4815JoeKuoD6Init[]   =   { 1, 3, 7, 15, 5, 33, 21, 127, 3, 239, 839, 997, 7253, 8183, 19779, 4185, 0 };
            const std::uint32_t dim4816JoeKuoD6Init[]   =   { 1, 1, 5, 15, 25, 37, 99, 51, 465, 137, 1339, 541, 4319, 9883, 17425, 30743, 0 };
            const std::uint32_t dim4817JoeKuoD6Init[]   =   { 1, 3, 3, 5, 13, 7, 3, 249, 365, 749, 527, 3675, 3005, 12905, 9621, 899, 0 };
            const std::uint32_t dim4818JoeKuoD6Init[]   =   { 1, 3, 3, 7, 29, 31, 69, 21, 365, 1021, 1329, 2623, 3549, 5491, 21293, 63771, 0 };
            const std::uint32_t dim4819JoeKuoD6Init[]   =   { 1, 1, 5, 9, 5, 35, 53, 247, 193, 17, 227, 381, 5233, 821, 3991, 4439, 0 };
            const std::uint32_t dim4820JoeKuoD6Init[]   =   { 1, 1, 7, 15, 5, 59, 27, 167, 489, 335, 1565, 2999, 1777, 5009, 519, 57967, 0 };
            const std::uint32_t dim4821JoeKuoD6Init[]   =   { 1, 1, 1, 11, 25, 47, 23, 155, 419, 863, 1905, 355, 1089, 5871, 10149, 53341, 0 };
            const std::uint32_t dim4822JoeKuoD6Init[]   =   { 1, 1, 7, 7, 29, 55, 127, 83, 33, 309, 2017, 1021, 5987, 1101, 13657, 60587, 0 };
            const std::uint32_t dim4823JoeKuoD6Init[]   =   { 1, 1, 1, 7, 3, 1, 9, 75, 257, 407, 659, 529, 2087, 14759, 14483, 36425, 0 };
            const std::uint32_t dim4824JoeKuoD6Init[]   =   { 1, 3, 7, 3, 11, 29, 113, 255, 301, 799, 1171, 3721, 135, 3467, 7109, 50339, 0 };
            const std::uint32_t dim4825JoeKuoD6Init[]   =   { 1, 1, 1, 7, 21, 25, 15, 31, 61, 491, 57, 189, 2033, 4363, 31295, 16313, 0 };
            const std::uint32_t dim4826JoeKuoD6Init[]   =   { 1, 1, 5, 1, 5, 17, 33, 77, 483, 469, 355, 2245, 4165, 459, 30411, 29507, 0 };
            const std::uint32_t dim4827JoeKuoD6Init[]   =   { 1, 1, 3, 13, 1, 27, 29, 85, 491, 787, 1157, 1299, 4743, 14795, 32587, 12807, 0 };
            const std::uint32_t dim4828JoeKuoD6Init[]   =   { 1, 3, 3, 1, 23, 45, 35, 129, 3, 55, 969, 2387, 3929, 10397, 19879, 2723, 0 };
            const std::uint32_t dim4829JoeKuoD6Init[]   =   { 1, 1, 1, 7, 19, 3, 9, 23, 497, 347, 2039, 913, 5925, 7965, 5789, 40949, 0 };
            const std::uint32_t dim4830JoeKuoD6Init[]   =   { 1, 1, 7, 1, 29, 61, 89, 3, 133, 647, 1585, 2661, 1875, 1859, 3937, 12707, 0 };
            const std::uint32_t dim4831JoeKuoD6Init[]   =   { 1, 3, 3, 7, 25, 11, 41, 149, 427, 463, 901, 2433, 2617, 13511, 3443, 39867, 0 };
            const std::uint32_t dim4832JoeKuoD6Init[]   =   { 1, 1, 1, 5, 27, 33, 103, 251, 201, 1023, 1979, 3745, 6365, 14945, 22153, 55535, 0 };
            const std::uint32_t dim4833JoeKuoD6Init[]   =   { 1, 3, 1, 15, 23, 25, 57, 215, 111, 181, 385, 1123, 3095, 7085, 31863, 37393, 0 };
            const std::uint32_t dim4834JoeKuoD6Init[]   =   { 1, 3, 5, 13, 17, 35, 27, 159, 255, 241, 413, 1823, 5329, 1825, 28489, 58763, 0 };
            const std::uint32_t dim4835JoeKuoD6Init[]   =   { 1, 3, 1, 15, 3, 33, 97, 27, 409, 889, 409, 2315, 4743, 14827, 3037, 57149, 0 };
            const std::uint32_t dim4836JoeKuoD6Init[]   =   { 1, 1, 3, 5, 19, 63, 93, 51, 233, 715, 1571, 1101, 2751, 14805, 25683, 13323, 0 };
            const std::uint32_t dim4837JoeKuoD6Init[]   =   { 1, 3, 7, 3, 21, 15, 117, 179, 263, 229, 199, 2597, 3999, 3037, 3801, 4775, 0 };
            const std::uint32_t dim4838JoeKuoD6Init[]   =   { 1, 3, 3, 15, 1, 15, 49, 91, 383, 21, 1955, 773, 1213, 5971, 19525, 8699, 0 };
            const std::uint32_t dim4839JoeKuoD6Init[]   =   { 1, 3, 1, 15, 29, 49, 11, 101, 261, 761, 709, 3811, 4055, 15675, 32305, 15173, 0 };
            const std::uint32_t dim4840JoeKuoD6Init[]   =   { 1, 1, 1, 3, 9, 41, 127, 23, 413, 461, 237, 1595, 2257, 2971, 31845, 61485, 0 };
            const std::uint32_t dim4841JoeKuoD6Init[]   =   { 1, 1, 1, 11, 23, 13, 63, 21, 23, 209, 1317, 1071, 3619, 7275, 9343, 21455, 0 };
            const std::uint32_t dim4842JoeKuoD6Init[]   =   { 1, 1, 5, 9, 31, 35, 41, 249, 477, 569, 1175, 1571, 4679, 10337, 3507, 23415, 0 };
            const std::uint32_t dim4843JoeKuoD6Init[]   =   { 1, 3, 5, 11, 29, 3, 117, 65, 301, 913, 1709, 1765, 1801, 15513, 31495, 38131, 0 };
            const std::uint32_t dim4844JoeKuoD6Init[]   =   { 1, 3, 5, 11, 27, 3, 71, 195, 81, 313, 505, 3941, 3797, 2031, 24151, 65085, 0 };
            const std::uint32_t dim4845JoeKuoD6Init[]   =   { 1, 1, 1, 5, 13, 17, 59, 151, 191, 489, 1267, 3207, 4495, 15145, 12789, 46313, 0 };
            const std::uint32_t dim4846JoeKuoD6Init[]   =   { 1, 3, 1, 7, 29, 9, 25, 31, 33, 527, 1939, 4089, 333, 757, 8895, 25331, 0 };
            const std::uint32_t dim4847JoeKuoD6Init[]   =   { 1, 1, 1, 1, 9, 27, 11, 205, 211, 141, 1171, 1881, 4029, 10587, 30103, 39661, 0 };
            const std::uint32_t dim4848JoeKuoD6Init[]   =   { 1, 1, 3, 3, 23, 3, 23, 175, 355, 753, 183, 1331, 6403, 3369, 29891, 11109, 0 };
            const std::uint32_t dim4849JoeKuoD6Init[]   =   { 1, 3, 7, 3, 17, 25, 95, 145, 135, 525, 1073, 1841, 3951, 2027, 23053, 19699, 0 };
            const std::uint32_t dim4850JoeKuoD6Init[]   =   { 1, 1, 5, 3, 11, 43, 117, 67, 299, 885, 1095, 2777, 8185, 14331, 29543, 655, 0 };
            const std::uint32_t dim4851JoeKuoD6Init[]   =   { 1, 3, 7, 7, 3, 59, 127, 147, 323, 713, 99, 1179, 6395, 1821, 12673, 35587, 0 };
            const std::uint32_t dim4852JoeKuoD6Init[]   =   { 1, 3, 5, 3, 7, 11, 33, 87, 99, 967, 1443, 1585, 6215, 15125, 30747, 21513, 0 };
            const std::uint32_t dim4853JoeKuoD6Init[]   =   { 1, 3, 7, 11, 23, 5, 91, 171, 229, 601, 833, 3157, 1691, 15081, 20607, 7643, 0 };
            const std::uint32_t dim4854JoeKuoD6Init[]   =   { 1, 1, 3, 1, 5, 1, 39, 59, 157, 7, 601, 2079, 3045, 3693, 26511, 13245, 0 };
            const std::uint32_t dim4855JoeKuoD6Init[]   =   { 1, 3, 5, 9, 9, 27, 83, 135, 185, 379, 2027, 1407, 7409, 7363, 26471, 35907, 0 };
            const std::uint32_t dim4856JoeKuoD6Init[]   =   { 1, 3, 7, 15, 29, 49, 1, 69, 383, 915, 183, 3809, 4511, 8751, 4715, 7033, 0 };
            const std::uint32_t dim4857JoeKuoD6Init[]   =   { 1, 3, 3, 3, 1, 17, 71, 233, 243, 933, 1165, 3089, 3565, 6521, 13203, 13065, 0 };
            const std::uint32_t dim4858JoeKuoD6Init[]   =   { 1, 1, 5, 9, 9, 55, 53, 129, 331, 943, 587, 2573, 2247, 15101, 4987, 62983, 0 };
            const std::uint32_t dim4859JoeKuoD6Init[]   =   { 1, 3, 1, 13, 11, 43, 45, 127, 129, 857, 669, 321, 3915, 4477, 26973, 19911, 0 };
            const std::uint32_t dim4860JoeKuoD6Init[]   =   { 1, 3, 1, 13, 15, 3, 83, 23, 13, 441, 953, 2373, 3539, 4895, 26327, 61961, 0 };
            const std::uint32_t dim4861JoeKuoD6Init[]   =   { 1, 1, 5, 13, 23, 11, 125, 83, 339, 901, 1809, 2691, 3789, 15007, 10569, 65399, 0 };
            const std::uint32_t dim4862JoeKuoD6Init[]   =   { 1, 3, 1, 1, 17, 27, 105, 199, 435, 245, 1227, 3029, 3911, 1021, 2931, 24957, 0 };
            const std::uint32_t dim4863JoeKuoD6Init[]   =   { 1, 3, 1, 11, 17, 5, 123, 39, 413, 627, 1149, 3925, 6635, 8959, 31387, 65047, 0 };
            const std::uint32_t dim4864JoeKuoD6Init[]   =   { 1, 3, 5, 1, 23, 41, 93, 217, 21, 115, 1311, 3901, 2559, 2925, 30755, 7575, 0 };
            const std::uint32_t dim4865JoeKuoD6Init[]   =   { 1, 1, 3, 9, 13, 11, 63, 171, 135, 983, 1679, 395, 7349, 5153, 26405, 40589, 0 };
            const std::uint32_t dim4866JoeKuoD6Init[]   =   { 1, 3, 7, 13, 27, 47, 53, 169, 85, 871, 1087, 619, 7399, 9719, 6349, 59211, 0 };
            const std::uint32_t dim4867JoeKuoD6Init[]   =   { 1, 3, 3, 15, 31, 45, 3, 33, 11, 879, 929, 1977, 1939, 1049, 16159, 41515, 0 };
            const std::uint32_t dim4868JoeKuoD6Init[]   =   { 1, 3, 5, 11, 9, 27, 13, 23, 127, 747, 1121, 2497, 8141, 8601, 12431, 3243, 0 };
            const std::uint32_t dim4869JoeKuoD6Init[]   =   { 1, 3, 7, 15, 23, 43, 23, 225, 283, 13, 1837, 2089, 6435, 10121, 22307, 58767, 0 };
            const std::uint32_t dim4870JoeKuoD6Init[]   =   { 1, 1, 5, 11, 17, 3, 41, 221, 143, 669, 261, 1367, 7813, 15265, 32751, 62007, 0 };
            const std::uint32_t dim4871JoeKuoD6Init[]   =   { 1, 1, 1, 1, 5, 45, 41, 161, 327, 185, 1403, 485, 2831, 10025, 12555, 47661, 0 };
            const std::uint32_t dim4872JoeKuoD6Init[]   =   { 1, 3, 7, 1, 31, 55, 87, 83, 439, 929, 653, 4095, 5443, 7361, 27801, 12979, 0 };
            const std::uint32_t dim4873JoeKuoD6Init[]   =   { 1, 3, 1, 7, 1, 57, 11, 145, 55, 269, 711, 1889, 8023, 7171, 3247, 35691, 0 };
            const std::uint32_t dim4874JoeKuoD6Init[]   =   { 1, 1, 1, 3, 15, 1, 15, 131, 479, 797, 815, 2343, 1603, 10775, 21341, 20825, 0 };
            const std::uint32_t dim4875JoeKuoD6Init[]   =   { 1, 3, 5, 9, 3, 27, 31, 117, 441, 177, 215, 3991, 3197, 8397, 19195, 3883, 0 };
            const std::uint32_t dim4876JoeKuoD6Init[]   =   { 1, 1, 5, 13, 1, 19, 13, 27, 157, 1001, 43, 251, 7997, 7495, 16515, 44287, 0 };
            const std::uint32_t dim4877JoeKuoD6Init[]   =   { 1, 1, 3, 5, 17, 57, 117, 53, 413, 905, 551, 149, 7531, 14885, 32493, 34961, 0 };
            const std::uint32_t dim4878JoeKuoD6Init[]   =   { 1, 3, 3, 7, 27, 1, 7, 13, 259, 21, 189, 451, 6171, 3603, 12053, 45619, 0 };
            const std::uint32_t dim4879JoeKuoD6Init[]   =   { 1, 1, 7, 11, 5, 41, 59, 119, 419, 93, 1399, 629, 1269, 3789, 17035, 61583, 0 };
            const std::uint32_t dim4880JoeKuoD6Init[]   =   { 1, 3, 5, 11, 1, 11, 59, 83, 473, 273, 839, 3111, 3081, 10159, 6143, 16297, 0 };
            const std::uint32_t dim4881JoeKuoD6Init[]   =   { 1, 1, 5, 15, 25, 15, 17, 63, 275, 927, 189, 89, 6595, 4399, 27201, 57205, 0 };
            const std::uint32_t dim4882JoeKuoD6Init[]   =   { 1, 1, 7, 3, 31, 17, 63, 203, 321, 655, 1751, 2985, 3291, 11567, 15135, 49747, 0 };
            const std::uint32_t dim4883JoeKuoD6Init[]   =   { 1, 3, 5, 13, 27, 25, 89, 39, 299, 833, 1269, 271, 6481, 3045, 7203, 20279, 0 };
            const std::uint32_t dim4884JoeKuoD6Init[]   =   { 1, 3, 1, 1, 29, 13, 13, 37, 33, 563, 1825, 3257, 3153, 963, 25801, 15861, 0 };
            const std::uint32_t dim4885JoeKuoD6Init[]   =   { 1, 3, 5, 11, 15, 7, 49, 117, 479, 221, 579, 2995, 1673, 14927, 2869, 35547, 0 };
            const std::uint32_t dim4886JoeKuoD6Init[]   =   { 1, 3, 1, 11, 31, 11, 77, 161, 183, 187, 1967, 3037, 4441, 10547, 1443, 8619, 0 };
            const std::uint32_t dim4887JoeKuoD6Init[]   =   { 1, 1, 3, 11, 27, 41, 83, 179, 293, 421, 1395, 1673, 6375, 9801, 14265, 18117, 0 };
            const std::uint32_t dim4888JoeKuoD6Init[]   =   { 1, 1, 3, 7, 9, 19, 55, 235, 499, 637, 1121, 3583, 8007, 3749, 20903, 6179, 0 };
            const std::uint32_t dim4889JoeKuoD6Init[]   =   { 1, 3, 7, 13, 9, 55, 125, 77, 395, 9, 2005, 2247, 1609, 6805, 13099, 26367, 0 };
            const std::uint32_t dim4890JoeKuoD6Init[]   =   { 1, 3, 5, 13, 9, 41, 49, 133, 443, 995, 209, 341, 8013, 11037, 29663, 21161, 0 };
            const std::uint32_t dim4891JoeKuoD6Init[]   =   { 1, 3, 1, 1, 1, 47, 45, 243, 161, 433, 129, 39, 4885, 8777, 6395, 16953, 0 };
            const std::uint32_t dim4892JoeKuoD6Init[]   =   { 1, 3, 3, 15, 11, 13, 41, 113, 279, 657, 763, 2411, 7115, 463, 10759, 50493, 0 };
            const std::uint32_t dim4893JoeKuoD6Init[]   =   { 1, 1, 5, 5, 31, 5, 25, 181, 385, 445, 625, 313, 4983, 11763, 6065, 63835, 0 };
            const std::uint32_t dim4894JoeKuoD6Init[]   =   { 1, 3, 3, 15, 13, 25, 103, 5, 205, 223, 1327, 73, 677, 6751, 2071, 24963, 0 };
            const std::uint32_t dim4895JoeKuoD6Init[]   =   { 1, 1, 7, 15, 21, 61, 21, 11, 47, 775, 113, 991, 1943, 1459, 18049, 45025, 0 };
            const std::uint32_t dim4896JoeKuoD6Init[]   =   { 1, 3, 3, 1, 11, 43, 27, 89, 49, 711, 173, 181, 1261, 2751, 21321, 5467, 0 };
            const std::uint32_t dim4897JoeKuoD6Init[]   =   { 1, 3, 3, 7, 17, 7, 57, 61, 87, 973, 985, 1849, 559, 7319, 11457, 46071, 0 };
            const std::uint32_t dim4898JoeKuoD6Init[]   =   { 1, 1, 1, 1, 9, 37, 99, 157, 423, 189, 1355, 3983, 6357, 10825, 26517, 45815, 0 };
            const std::uint32_t dim4899JoeKuoD6Init[]   =   { 1, 1, 3, 11, 23, 33, 57, 55, 59, 831, 339, 725, 359, 14859, 17523, 36149, 0 };
            const std::uint32_t dim4900JoeKuoD6Init[]   =   { 1, 1, 5, 5, 27, 29, 47, 147, 153, 801, 1737, 3617, 5447, 8011, 30631, 7921, 0 };
            const std::uint32_t dim4901JoeKuoD6Init[]   =   { 1, 1, 5, 1, 11, 43, 35, 105, 69, 453, 1023, 875, 6755, 6015, 12449, 50235, 0 };
            const std::uint32_t dim4902JoeKuoD6Init[]   =   { 1, 3, 1, 5, 29, 31, 43, 89, 369, 891, 1447, 353, 8103, 2555, 1197, 64005, 0 };
            const std::uint32_t dim4903JoeKuoD6Init[]   =   { 1, 3, 3, 9, 21, 33, 117, 205, 473, 289, 1699, 2361, 7083, 13001, 24127, 48611, 0 };
            const std::uint32_t dim4904JoeKuoD6Init[]   =   { 1, 3, 3, 15, 3, 23, 79, 139, 475, 511, 181, 1331, 6137, 2653, 14071, 16947, 0 };
            const std::uint32_t dim4905JoeKuoD6Init[]   =   { 1, 3, 3, 1, 11, 47, 51, 217, 305, 599, 1609, 237, 4537, 5377, 717, 13269, 0 };
            const std::uint32_t dim4906JoeKuoD6Init[]   =   { 1, 1, 7, 3, 19, 31, 1, 173, 509, 817, 785, 1223, 5585, 8911, 643, 44575, 0 };
            const std::uint32_t dim4907JoeKuoD6Init[]   =   { 1, 1, 3, 11, 5, 11, 31, 129, 269, 369, 1833, 2885, 441, 11517, 2323, 26735, 0 };
            const std::uint32_t dim4908JoeKuoD6Init[]   =   { 1, 1, 5, 9, 7, 51, 31, 21, 5, 157, 541, 2939, 4569, 1679, 17467, 27995, 0 };
            const std::uint32_t dim4909JoeKuoD6Init[]   =   { 1, 1, 7, 3, 21, 33, 85, 213, 41, 851, 1947, 3205, 5065, 6079, 30789, 63677, 0 };
            const std::uint32_t dim4910JoeKuoD6Init[]   =   { 1, 1, 5, 3, 9, 53, 3, 179, 157, 407, 537, 1193, 4645, 13791, 28153, 11349, 0 };
            const std::uint32_t dim4911JoeKuoD6Init[]   =   { 1, 1, 7, 13, 25, 61, 9, 151, 263, 143, 1583, 2859, 6617, 8861, 4163, 40695, 0 };
            const std::uint32_t dim4912JoeKuoD6Init[]   =   { 1, 1, 1, 1, 7, 25, 19, 207, 335, 1019, 1919, 3893, 831, 12421, 4667, 38967, 0 };
            const std::uint32_t dim4913JoeKuoD6Init[]   =   { 1, 3, 5, 3, 5, 51, 81, 9, 425, 333, 451, 2569, 2771, 12145, 26065, 14385, 0 };
            const std::uint32_t dim4914JoeKuoD6Init[]   =   { 1, 1, 3, 7, 3, 49, 17, 147, 327, 331, 1197, 7, 3703, 15247, 9723, 52819, 0 };
            const std::uint32_t dim4915JoeKuoD6Init[]   =   { 1, 3, 3, 7, 27, 21, 117, 229, 255, 603, 195, 1049, 6243, 13593, 14553, 8267, 0 };
            const std::uint32_t dim4916JoeKuoD6Init[]   =   { 1, 1, 5, 15, 9, 53, 1, 187, 79, 151, 321, 1883, 6105, 13879, 8201, 53213, 0 };
            const std::uint32_t dim4917JoeKuoD6Init[]   =   { 1, 1, 1, 7, 21, 27, 103, 147, 351, 901, 1927, 2145, 2685, 453, 15173, 7371, 0 };
            const std::uint32_t dim4918JoeKuoD6Init[]   =   { 1, 1, 3, 5, 21, 27, 125, 77, 395, 27, 827, 3617, 6033, 1511, 29461, 18907, 0 };
            const std::uint32_t dim4919JoeKuoD6Init[]   =   { 1, 3, 5, 3, 3, 27, 75, 129, 441, 831, 1213, 2499, 5829, 12181, 7991, 58167, 0 };
            const std::uint32_t dim4920JoeKuoD6Init[]   =   { 1, 1, 1, 9, 3, 33, 85, 135, 45, 405, 1731, 551, 1251, 7895, 3975, 41621, 0 };
            const std::uint32_t dim4921JoeKuoD6Init[]   =   { 1, 3, 5, 7, 19, 19, 25, 7, 477, 569, 1089, 2705, 6157, 10279, 14029, 36229, 0 };
            const std::uint32_t dim4922JoeKuoD6Init[]   =   { 1, 3, 7, 3, 5, 19, 99, 137, 67, 361, 2021, 2891, 1957, 14961, 22673, 45707, 0 };
            const std::uint32_t dim4923JoeKuoD6Init[]   =   { 1, 3, 7, 1, 21, 11, 81, 225, 151, 235, 1761, 3875, 7427, 11213, 27023, 17945, 0 };
            const std::uint32_t dim4924JoeKuoD6Init[]   =   { 1, 1, 7, 1, 3, 1, 3, 123, 39, 769, 1467, 1907, 7833, 2099, 19, 54653, 0 };
            const std::uint32_t dim4925JoeKuoD6Init[]   =   { 1, 1, 1, 3, 25, 35, 33, 111, 407, 497, 1527, 3999, 3083, 6221, 8319, 56959, 0 };
            const std::uint32_t dim4926JoeKuoD6Init[]   =   { 1, 1, 3, 15, 21, 49, 113, 11, 191, 801, 1835, 3413, 3379, 13129, 3655, 23885, 0 };
            const std::uint32_t dim4927JoeKuoD6Init[]   =   { 1, 3, 1, 5, 21, 57, 87, 133, 409, 325, 569, 2099, 8143, 315, 23287, 21905, 0 };
            const std::uint32_t dim4928JoeKuoD6Init[]   =   { 1, 1, 5, 5, 21, 43, 25, 169, 265, 123, 81, 2683, 6137, 7341, 16383, 26435, 0 };
            const std::uint32_t dim4929JoeKuoD6Init[]   =   { 1, 3, 1, 5, 23, 17, 125, 173, 3, 829, 693, 751, 8021, 3701, 32643, 35405, 0 };
            const std::uint32_t dim4930JoeKuoD6Init[]   =   { 1, 1, 3, 1, 31, 13, 1, 195, 435, 487, 961, 1681, 1233, 6001, 3113, 29515, 0 };
            const std::uint32_t dim4931JoeKuoD6Init[]   =   { 1, 1, 7, 5, 9, 41, 81, 137, 257, 337, 1837, 145, 4191, 6313, 9991, 25541, 0 };
            const std::uint32_t dim4932JoeKuoD6Init[]   =   { 1, 1, 5, 13, 29, 13, 1, 117, 501, 991, 571, 793, 1433, 6005, 19, 61135, 0 };
            const std::uint32_t dim4933JoeKuoD6Init[]   =   { 1, 1, 7, 1, 9, 43, 65, 69, 297, 331, 1777, 1843, 6477, 13943, 1301, 51001, 0 };
            const std::uint32_t dim4934JoeKuoD6Init[]   =   { 1, 1, 1, 3, 7, 35, 23, 211, 33, 649, 255, 1831, 635, 9965, 16679, 14531, 0 };
            const std::uint32_t dim4935JoeKuoD6Init[]   =   { 1, 1, 1, 13, 23, 57, 113, 247, 321, 401, 1761, 4001, 1823, 14457, 5251, 4965, 0 };
            const std::uint32_t dim4936JoeKuoD6Init[]   =   { 1, 1, 5, 5, 31, 5, 53, 103, 297, 575, 1577, 2217, 977, 14415, 16953, 14793, 0 };
            const std::uint32_t dim4937JoeKuoD6Init[]   =   { 1, 1, 5, 7, 9, 19, 25, 29, 121, 563, 1707, 901, 6167, 10799, 11897, 31187, 0 };
            const std::uint32_t dim4938JoeKuoD6Init[]   =   { 1, 1, 5, 9, 17, 39, 89, 29, 251, 259, 411, 819, 6037, 4601, 11481, 46141, 0 };
            const std::uint32_t dim4939JoeKuoD6Init[]   =   { 1, 1, 1, 15, 23, 9, 65, 95, 189, 93, 1485, 2417, 5183, 5513, 26623, 42637, 0 };
            const std::uint32_t dim4940JoeKuoD6Init[]   =   { 1, 1, 5, 5, 3, 3, 113, 161, 463, 225, 1089, 2023, 2341, 14931, 28097, 56365, 0 };
            const std::uint32_t dim4941JoeKuoD6Init[]   =   { 1, 1, 5, 9, 9, 3, 109, 141, 27, 473, 107, 4023, 3279, 7595, 13289, 35649, 0 };
            const std::uint32_t dim4942JoeKuoD6Init[]   =   { 1, 1, 5, 3, 9, 37, 73, 153, 487, 57, 2035, 3583, 239, 2183, 10903, 171, 0 };
            const std::uint32_t dim4943JoeKuoD6Init[]   =   { 1, 3, 3, 15, 23, 39, 87, 217, 451, 597, 1817, 2883, 145, 11341, 16015, 16765, 0 };
            const std::uint32_t dim4944JoeKuoD6Init[]   =   { 1, 1, 7, 5, 19, 61, 45, 37, 473, 883, 277, 2801, 13, 7021, 3851, 53223, 0 };
            const std::uint32_t dim4945JoeKuoD6Init[]   =   { 1, 3, 3, 9, 1, 35, 97, 237, 279, 541, 1911, 661, 7603, 8183, 22071, 37317, 0 };
            const std::uint32_t dim4946JoeKuoD6Init[]   =   { 1, 3, 3, 11, 11, 63, 101, 71, 227, 259, 1545, 2779, 3859, 4859, 18957, 31749, 0 };
            const std::uint32_t dim4947JoeKuoD6Init[]   =   { 1, 3, 3, 1, 27, 29, 91, 215, 381, 607, 1701, 1709, 247, 12403, 29943, 59533, 0 };
            const std::uint32_t dim4948JoeKuoD6Init[]   =   { 1, 1, 7, 1, 11, 23, 47, 141, 37, 881, 1443, 3921, 3281, 7417, 1549, 50653, 0 };
            const std::uint32_t dim4949JoeKuoD6Init[]   =   { 1, 1, 7, 11, 23, 61, 17, 39, 373, 871, 1107, 1875, 1419, 3981, 1333, 11485, 0 };
            const std::uint32_t dim4950JoeKuoD6Init[]   =   { 1, 1, 7, 11, 21, 51, 127, 145, 129, 425, 1263, 1989, 699, 7317, 24827, 15049, 0 };
            const std::uint32_t dim4951JoeKuoD6Init[]   =   { 1, 1, 1, 11, 9, 59, 59, 67, 329, 841, 905, 467, 1905, 895, 29711, 25585, 0 };
            const std::uint32_t dim4952JoeKuoD6Init[]   =   { 1, 1, 1, 15, 3, 39, 11, 205, 297, 383, 445, 2139, 2935, 2399, 22237, 20355, 0 };
            const std::uint32_t dim4953JoeKuoD6Init[]   =   { 1, 3, 7, 7, 17, 9, 17, 205, 369, 1019, 1703, 755, 5507, 14749, 16461, 14519, 0 };
            const std::uint32_t dim4954JoeKuoD6Init[]   =   { 1, 3, 7, 3, 5, 31, 97, 35, 43, 249, 773, 4033, 6085, 1241, 24743, 22415, 0 };
            const std::uint32_t dim4955JoeKuoD6Init[]   =   { 1, 3, 7, 3, 17, 11, 45, 203, 251, 669, 1463, 1897, 7913, 2315, 30307, 15431, 0 };
            const std::uint32_t dim4956JoeKuoD6Init[]   =   { 1, 1, 5, 5, 7, 53, 83, 13, 1, 841, 423, 1059, 3951, 14209, 11113, 13931, 0 };
            const std::uint32_t dim4957JoeKuoD6Init[]   =   { 1, 3, 3, 5, 5, 15, 11, 71, 237, 553, 829, 3653, 4991, 1003, 8353, 52173, 0 };
            const std::uint32_t dim4958JoeKuoD6Init[]   =   { 1, 3, 3, 9, 27, 39, 83, 137, 315, 883, 1155, 3541, 3815, 10633, 13277, 20269, 0 };
            const std::uint32_t dim4959JoeKuoD6Init[]   =   { 1, 3, 3, 15, 13, 55, 43, 19, 345, 351, 1117, 1747, 1949, 3195, 12241, 52441, 0 };
            const std::uint32_t dim4960JoeKuoD6Init[]   =   { 1, 1, 3, 5, 1, 11, 113, 117, 37, 103, 1681, 3269, 1659, 14779, 30479, 31123, 0 };
            const std::uint32_t dim4961JoeKuoD6Init[]   =   { 1, 3, 7, 13, 1, 63, 9, 63, 65, 737, 785, 1713, 8123, 10053, 29871, 17647, 0 };
            const std::uint32_t dim4962JoeKuoD6Init[]   =   { 1, 1, 3, 5, 17, 45, 71, 37, 283, 145, 1927, 75, 7355, 4681, 2777, 31465, 0 };
            const std::uint32_t dim4963JoeKuoD6Init[]   =   { 1, 1, 3, 7, 21, 19, 113, 89, 67, 751, 99, 421, 201, 6345, 9473, 39849, 0 };
            const std::uint32_t dim4964JoeKuoD6Init[]   =   { 1, 1, 5, 11, 31, 57, 75, 79, 393, 745, 1435, 3039, 1175, 983, 923, 42867, 0 };
            const std::uint32_t dim4965JoeKuoD6Init[]   =   { 1, 1, 5, 9, 31, 47, 31, 61, 85, 651, 1733, 3973, 1979, 7223, 13817, 30593, 0 };
            const std::uint32_t dim4966JoeKuoD6Init[]   =   { 1, 1, 1, 11, 31, 21, 23, 177, 401, 55, 537, 3775, 3241, 15157, 11849, 15629, 0 };
            const std::uint32_t dim4967JoeKuoD6Init[]   =   { 1, 1, 1, 13, 31, 53, 79, 57, 35, 617, 61, 89, 6917, 6045, 23879, 45485, 0 };
            const std::uint32_t dim4968JoeKuoD6Init[]   =   { 1, 3, 7, 7, 3, 43, 57, 243, 107, 321, 273, 2171, 2069, 6171, 29181, 8281, 0 };
            const std::uint32_t dim4969JoeKuoD6Init[]   =   { 1, 1, 1, 11, 3, 27, 51, 57, 81, 795, 1673, 2601, 7335, 16243, 863, 20663, 0 };
            const std::uint32_t dim4970JoeKuoD6Init[]   =   { 1, 1, 5, 9, 7, 19, 31, 87, 509, 899, 1133, 1609, 2163, 7595, 10523, 43181, 0 };
            const std::uint32_t dim4971JoeKuoD6Init[]   =   { 1, 1, 1, 7, 21, 53, 103, 43, 507, 317, 685, 1329, 7057, 7275, 2277, 28271, 0 };
            const std::uint32_t dim4972JoeKuoD6Init[]   =   { 1, 1, 7, 7, 3, 35, 81, 81, 261, 587, 1571, 2771, 4653, 6517, 25101, 56753, 0 };
            const std::uint32_t dim4973JoeKuoD6Init[]   =   { 1, 3, 1, 11, 17, 61, 29, 137, 7, 929, 393, 2513, 2423, 5457, 6285, 12525, 0 };
            const std::uint32_t dim4974JoeKuoD6Init[]   =   { 1, 3, 1, 9, 25, 63, 17, 45, 439, 591, 273, 877, 7741, 8381, 32277, 24635, 0 };
            const std::uint32_t dim4975JoeKuoD6Init[]   =   { 1, 3, 1, 5, 19, 11, 17, 175, 297, 77, 961, 3331, 5193, 14347, 12713, 32067, 0 };
            const std::uint32_t dim4976JoeKuoD6Init[]   =   { 1, 1, 5, 11, 3, 17, 13, 21, 219, 653, 1279, 1657, 7659, 14459, 27661, 38093, 0 };
            const std::uint32_t dim4977JoeKuoD6Init[]   =   { 1, 3, 7, 7, 29, 17, 67, 35, 451, 91, 919, 3163, 7459, 14971, 4317, 42503, 0 };
            const std::uint32_t dim4978JoeKuoD6Init[]   =   { 1, 3, 3, 15, 7, 61, 69, 211, 349, 97, 911, 503, 3903, 12327, 11049, 29387, 0 };
            const std::uint32_t dim4979JoeKuoD6Init[]   =   { 1, 1, 7, 3, 5, 7, 63, 237, 387, 931, 693, 1143, 6545, 8529, 25217, 53087, 0 };
            const std::uint32_t dim4980JoeKuoD6Init[]   =   { 1, 1, 5, 7, 1, 13, 21, 169, 259, 289, 437, 649, 4905, 15261, 29997, 34043, 0 };
            const std::uint32_t dim4981JoeKuoD6Init[]   =   { 1, 1, 1, 9, 25, 13, 19, 229, 29, 213, 1941, 1501, 3463, 15761, 15635, 39687, 0 };
            const std::uint32_t dim4982JoeKuoD6Init[]   =   { 1, 1, 5, 7, 13, 29, 101, 57, 483, 913, 1025, 2139, 4327, 7847, 12455, 41797, 0 };
            const std::uint32_t dim4983JoeKuoD6Init[]   =   { 1, 1, 3, 11, 17, 27, 97, 79, 411, 9, 1797, 3721, 5291, 859, 8889, 6151, 0 };
            const std::uint32_t dim4984JoeKuoD6Init[]   =   { 1, 1, 1, 5, 17, 61, 45, 187, 157, 301, 1017, 1507, 6031, 4271, 32593, 23739, 0 };
            const std::uint32_t dim4985JoeKuoD6Init[]   =   { 1, 1, 3, 11, 31, 39, 7, 169, 15, 799, 1585, 2055, 4683, 13247, 23743, 50399, 0 };
            const std::uint32_t dim4986JoeKuoD6Init[]   =   { 1, 1, 1, 9, 25, 37, 15, 39, 339, 383, 1153, 1211, 5745, 15249, 26021, 39871, 0 };
            const std::uint32_t dim4987JoeKuoD6Init[]   =   { 1, 1, 3, 13, 17, 51, 27, 137, 231, 877, 309, 3633, 2575, 12259, 2743, 14781, 0 };
            const std::uint32_t dim4988JoeKuoD6Init[]   =   { 1, 1, 5, 7, 5, 33, 95, 19, 37, 829, 1489, 3525, 3887, 8277, 21867, 3581, 0 };
            const std::uint32_t dim4989JoeKuoD6Init[]   =   { 1, 1, 1, 15, 11, 33, 99, 213, 365, 549, 1603, 777, 3787, 12209, 14999, 50607, 0 };
            const std::uint32_t dim4990JoeKuoD6Init[]   =   { 1, 3, 1, 9, 23, 25, 57, 147, 73, 285, 1229, 1763, 4579, 14771, 4003, 38197, 0 };
            const std::uint32_t dim4991JoeKuoD6Init[]   =   { 1, 1, 5, 1, 15, 55, 25, 209, 135, 895, 311, 139, 2445, 6903, 12129, 27907, 0 };
            const std::uint32_t dim4992JoeKuoD6Init[]   =   { 1, 1, 5, 7, 23, 29, 33, 135, 325, 517, 2021, 1721, 4235, 2363, 12905, 18811, 0 };
            const std::uint32_t dim4993JoeKuoD6Init[]   =   { 1, 1, 1, 9, 3, 19, 69, 29, 157, 787, 1969, 3711, 8179, 5691, 4059, 25541, 0 };
            const std::uint32_t dim4994JoeKuoD6Init[]   =   { 1, 1, 5, 15, 1, 61, 11, 195, 317, 13, 923, 2149, 4001, 12843, 27109, 30625, 0 };
            const std::uint32_t dim4995JoeKuoD6Init[]   =   { 1, 3, 1, 7, 3, 13, 45, 187, 445, 859, 53, 3227, 4381, 8273, 32699, 48719, 0 };
            const std::uint32_t dim4996JoeKuoD6Init[]   =   { 1, 1, 7, 7, 21, 19, 47, 101, 119, 311, 577, 3309, 4585, 12109, 15153, 22915, 0 };
            const std::uint32_t dim4997JoeKuoD6Init[]   =   { 1, 3, 5, 15, 21, 39, 15, 211, 349, 237, 1873, 3333, 7837, 12811, 14321, 20227, 0 };
            const std::uint32_t dim4998JoeKuoD6Init[]   =   { 1, 1, 5, 5, 19, 47, 15, 239, 23, 763, 537, 1477, 2231, 10885, 19487, 47385, 0 };
            const std::uint32_t dim4999JoeKuoD6Init[]   =   { 1, 1, 3, 1, 19, 37, 67, 85, 11, 817, 869, 2249, 4111, 12411, 10405, 20055, 0 };
            const std::uint32_t dim5000JoeKuoD6Init[]   =   { 1, 1, 3, 3, 1, 41, 85, 137, 91, 369, 1863, 759, 303, 15859, 8063, 12811, 0 };
            const std::uint32_t dim5001JoeKuoD6Init[]   =   { 1, 3, 1, 11, 23, 1, 11, 219, 201, 573, 1573, 619, 2959, 6485, 7483, 46099, 0 };
            const std::uint32_t dim5002JoeKuoD6Init[]   =   { 1, 3, 3, 9, 13, 9, 9, 255, 47, 375, 409, 1435, 1665, 14967, 3247, 18193, 0 };
            const std::uint32_t dim5003JoeKuoD6Init[]   =   { 1, 1, 1, 5, 9, 61, 121, 173, 51, 415, 1621, 3947, 1379, 847, 23187, 39259, 0 };
            const std::uint32_t dim5004JoeKuoD6Init[]   =   { 1, 1, 1, 7, 3, 19, 95, 59, 187, 453, 1533, 445, 2699, 4817, 25983, 50925, 0 };
            const std::uint32_t dim5005JoeKuoD6Init[]   =   { 1, 3, 5, 13, 25, 25, 33, 5, 497, 1, 535, 1653, 6541, 10939, 17721, 43829, 0 };
            const std::uint32_t dim5006JoeKuoD6Init[]   =   { 1, 3, 7, 11, 9, 59, 115, 127, 85, 505, 541, 3243, 5853, 12673, 25275, 39577, 0 };
            const std::uint32_t dim5007JoeKuoD6Init[]   =   { 1, 3, 7, 1, 17, 25, 83, 127, 225, 295, 1823, 2051, 847, 4249, 13763, 5723, 0 };
            const std::uint32_t dim5008JoeKuoD6Init[]   =   { 1, 1, 1, 5, 3, 63, 39, 131, 191, 983, 119, 3287, 3335, 7969, 31347, 39439, 0 };
            const std::uint32_t dim5009JoeKuoD6Init[]   =   { 1, 3, 7, 9, 19, 31, 19, 91, 35, 677, 1229, 1371, 6497, 3315, 15239, 54235, 0 };
            const std::uint32_t dim5010JoeKuoD6Init[]   =   { 1, 1, 1, 15, 3, 49, 113, 199, 135, 35, 709, 385, 7923, 3711, 18351, 12711, 0 };
            const std::uint32_t dim5011JoeKuoD6Init[]   =   { 1, 1, 3, 15, 31, 13, 41, 1, 183, 95, 1625, 1675, 7881, 6607, 4165, 27151, 0 };
            const std::uint32_t dim5012JoeKuoD6Init[]   =   { 1, 3, 3, 15, 21, 57, 81, 49, 5, 297, 131, 883, 1113, 2497, 32129, 39139, 0 };
            const std::uint32_t dim5013JoeKuoD6Init[]   =   { 1, 3, 5, 7, 29, 47, 101, 173, 299, 879, 143, 3341, 3929, 6797, 8753, 47963, 0 };
            const std::uint32_t dim5014JoeKuoD6Init[]   =   { 1, 3, 3, 13, 11, 39, 27, 187, 27, 763, 1515, 1903, 5897, 10061, 14595, 12713, 0 };
            const std::uint32_t dim5015JoeKuoD6Init[]   =   { 1, 3, 5, 11, 27, 35, 37, 213, 45, 867, 1591, 3083, 8123, 5045, 31703, 61487, 0 };
            const std::uint32_t dim5016JoeKuoD6Init[]   =   { 1, 1, 3, 5, 3, 31, 23, 89, 369, 371, 1165, 3673, 6821, 333, 10881, 4153, 0 };
            const std::uint32_t dim5017JoeKuoD6Init[]   =   { 1, 1, 7, 13, 1, 33, 49, 195, 223, 197, 1799, 2427, 6171, 493, 13503, 23619, 0 };
            const std::uint32_t dim5018JoeKuoD6Init[]   =   { 1, 1, 3, 9, 5, 59, 105, 215, 449, 527, 1661, 2643, 309, 11239, 11633, 63459, 0 };
            const std::uint32_t dim5019JoeKuoD6Init[]   =   { 1, 1, 3, 11, 13, 11, 15, 99, 409, 807, 1911, 883, 1323, 9037, 6401, 545, 0 };
            const std::uint32_t dim5020JoeKuoD6Init[]   =   { 1, 1, 5, 7, 7, 7, 1, 167, 353, 923, 1403, 3109, 4981, 3877, 25451, 4667, 0 };
            const std::uint32_t dim5021JoeKuoD6Init[]   =   { 1, 1, 5, 11, 11, 25, 121, 153, 111, 785, 1301, 1497, 6267, 14919, 24125, 52029, 0 };
            const std::uint32_t dim5022JoeKuoD6Init[]   =   { 1, 3, 3, 5, 29, 55, 63, 177, 305, 41, 111, 1065, 1127, 113, 2815, 12979, 0 };
            const std::uint32_t dim5023JoeKuoD6Init[]   =   { 1, 3, 5, 7, 23, 39, 17, 179, 267, 917, 511, 3923, 915, 14173, 10689, 50749, 0 };
            const std::uint32_t dim5024JoeKuoD6Init[]   =   { 1, 1, 5, 3, 9, 45, 15, 157, 495, 625, 407, 2769, 3267, 7593, 17957, 54597, 0 };
            const std::uint32_t dim5025JoeKuoD6Init[]   =   { 1, 3, 3, 11, 21, 13, 5, 207, 107, 965, 1803, 1541, 3487, 3483, 109, 26923, 0 };
            const std::uint32_t dim5026JoeKuoD6Init[]   =   { 1, 1, 5, 11, 25, 49, 99, 135, 109, 371, 1307, 1815, 1095, 2329, 27101, 52269, 0 };
            const std::uint32_t dim5027JoeKuoD6Init[]   =   { 1, 3, 5, 5, 13, 9, 109, 79, 151, 47, 311, 3873, 3645, 3773, 1083, 31599, 0 };
            const std::uint32_t dim5028JoeKuoD6Init[]   =   { 1, 3, 5, 15, 1, 9, 87, 21, 145, 583, 159, 2435, 587, 10123, 24803, 19993, 0 };
            const std::uint32_t dim5029JoeKuoD6Init[]   =   { 1, 3, 1, 1, 23, 11, 5, 45, 373, 1011, 1353, 277, 7051, 3845, 12391, 25313, 0 };
            const std::uint32_t dim5030JoeKuoD6Init[]   =   { 1, 1, 1, 9, 13, 13, 109, 251, 97, 483, 1723, 2555, 813, 9345, 11351, 44705, 0 };
            const std::uint32_t dim5031JoeKuoD6Init[]   =   { 1, 3, 5, 7, 21, 49, 63, 13, 119, 813, 1559, 983, 499, 15159, 24163, 59903, 0 };
            const std::uint32_t dim5032JoeKuoD6Init[]   =   { 1, 1, 3, 5, 27, 33, 27, 165, 207, 693, 1401, 1357, 7637, 337, 10163, 43273, 0 };
            const std::uint32_t dim5033JoeKuoD6Init[]   =   { 1, 1, 5, 13, 29, 7, 71, 187, 1, 655, 1829, 2645, 6969, 5435, 28415, 33199, 0 };
            const std::uint32_t dim5034JoeKuoD6Init[]   =   { 1, 1, 1, 13, 17, 21, 13, 141, 41, 267, 1165, 1893, 3455, 10737, 16693, 33065, 0 };
            const std::uint32_t dim5035JoeKuoD6Init[]   =   { 1, 1, 5, 1, 7, 27, 7, 67, 107, 11, 763, 2529, 3023, 15745, 17023, 51911, 0 };
            const std::uint32_t dim5036JoeKuoD6Init[]   =   { 1, 3, 3, 3, 7, 57, 123, 249, 309, 511, 1655, 1379, 725, 7325, 20261, 65039, 0 };
            const std::uint32_t dim5037JoeKuoD6Init[]   =   { 1, 1, 5, 11, 3, 27, 23, 27, 285, 771, 2017, 1727, 4847, 2665, 30655, 47625, 0 };
            const std::uint32_t dim5038JoeKuoD6Init[]   =   { 1, 3, 7, 7, 17, 3, 93, 133, 427, 1021, 1135, 341, 6711, 11713, 24157, 1561, 0 };
            const std::uint32_t dim5039JoeKuoD6Init[]   =   { 1, 1, 3, 7, 15, 55, 11, 247, 65, 115, 1967, 535, 841, 15131, 28381, 31337, 0 };
            const std::uint32_t dim5040JoeKuoD6Init[]   =   { 1, 3, 1, 7, 9, 45, 73, 151, 127, 125, 767, 2003, 6893, 3875, 451, 30275, 0 };
            const std::uint32_t dim5041JoeKuoD6Init[]   =   { 1, 1, 7, 3, 5, 55, 127, 123, 163, 763, 1165, 1637, 6267, 7215, 23403, 20961, 0 };
            const std::uint32_t dim5042JoeKuoD6Init[]   =   { 1, 1, 1, 13, 1, 21, 65, 141, 369, 413, 1675, 27, 7357, 6929, 18083, 829, 0 };
            const std::uint32_t dim5043JoeKuoD6Init[]   =   { 1, 3, 5, 13, 1, 17, 97, 107, 249, 931, 47, 3537, 2245, 9827, 13673, 23217, 0 };
            const std::uint32_t dim5044JoeKuoD6Init[]   =   { 1, 1, 1, 11, 13, 19, 43, 31, 51, 727, 1001, 927, 771, 11853, 5761, 60537, 0 };
            const std::uint32_t dim5045JoeKuoD6Init[]   =   { 1, 3, 1, 7, 23, 27, 115, 5, 201, 431, 1021, 585, 6069, 12511, 6129, 2105, 0 };
            const std::uint32_t dim5046JoeKuoD6Init[]   =   { 1, 1, 3, 11, 3, 25, 75, 129, 389, 131, 223, 2263, 5377, 5561, 15633, 39527, 0 };
            const std::uint32_t dim5047JoeKuoD6Init[]   =   { 1, 3, 3, 1, 27, 43, 101, 55, 319, 549, 1971, 2255, 353, 93, 25661, 59077, 0 };
            const std::uint32_t dim5048JoeKuoD6Init[]   =   { 1, 1, 5, 11, 29, 57, 27, 135, 341, 913, 1637, 1781, 457, 11293, 1013, 53863, 0 };
            const std::uint32_t dim5049JoeKuoD6Init[]   =   { 1, 1, 1, 11, 3, 51, 79, 251, 443, 651, 393, 3635, 7397, 5443, 4225, 991, 0 };
            const std::uint32_t dim5050JoeKuoD6Init[]   =   { 1, 3, 7, 13, 31, 9, 3, 109, 427, 735, 891, 2789, 2169, 6459, 355, 43177, 0 };
            const std::uint32_t dim5051JoeKuoD6Init[]   =   { 1, 3, 3, 3, 13, 7, 93, 195, 293, 37, 75, 2467, 933, 8017, 9925, 61397, 0 };
            const std::uint32_t dim5052JoeKuoD6Init[]   =   { 1, 1, 5, 7, 25, 15, 69, 199, 161, 769, 387, 1491, 4553, 4173, 25631, 37089, 0 };
            const std::uint32_t dim5053JoeKuoD6Init[]   =   { 1, 3, 1, 3, 7, 59, 53, 93, 103, 413, 531, 887, 6149, 2901, 22611, 27135, 0 };
            const std::uint32_t dim5054JoeKuoD6Init[]   =   { 1, 1, 1, 13, 31, 39, 71, 215, 385, 821, 1603, 3043, 4967, 10953, 11543, 64433, 0 };
            const std::uint32_t dim5055JoeKuoD6Init[]   =   { 1, 3, 1, 7, 7, 63, 5, 143, 1, 339, 1165, 3809, 4257, 12879, 21581, 21307, 0 };
            const std::uint32_t dim5056JoeKuoD6Init[]   =   { 1, 1, 1, 15, 1, 35, 67, 227, 277, 879, 513, 3423, 6153, 11573, 12809, 34335, 0 };
            const std::uint32_t dim5057JoeKuoD6Init[]   =   { 1, 3, 7, 9, 9, 39, 47, 17, 101, 179, 631, 1307, 481, 871, 16807, 39811, 0 };
            const std::uint32_t dim5058JoeKuoD6Init[]   =   { 1, 3, 1, 1, 13, 25, 53, 179, 285, 267, 407, 3781, 3267, 3545, 525, 15733, 0 };
            const std::uint32_t dim5059JoeKuoD6Init[]   =   { 1, 1, 1, 13, 11, 35, 45, 181, 319, 767, 283, 3021, 5405, 403, 3587, 7291, 0 };
            const std::uint32_t dim5060JoeKuoD6Init[]   =   { 1, 1, 7, 3, 5, 9, 67, 129, 101, 117, 267, 1925, 1209, 13095, 7123, 62941, 0 };
            const std::uint32_t dim5061JoeKuoD6Init[]   =   { 1, 1, 7, 3, 5, 63, 109, 199, 95, 421, 193, 3519, 6551, 955, 1679, 16627, 0 };
            const std::uint32_t dim5062JoeKuoD6Init[]   =   { 1, 1, 5, 13, 1, 47, 71, 157, 343, 653, 981, 1335, 3737, 7185, 28861, 22883, 0 };
            const std::uint32_t dim5063JoeKuoD6Init[]   =   { 1, 1, 3, 15, 7, 63, 7, 81, 481, 5, 1159, 1361, 4167, 2575, 7437, 16917, 0 };
            const std::uint32_t dim5064JoeKuoD6Init[]   =   { 1, 3, 7, 1, 27, 17, 61, 193, 317, 841, 1149, 955, 5161, 4275, 1955, 15665, 0 };
            const std::uint32_t dim5065JoeKuoD6Init[]   =   { 1, 1, 1, 7, 19, 63, 77, 57, 367, 237, 579, 3701, 5763, 4951, 24151, 45215, 0 };
            const std::uint32_t dim5066JoeKuoD6Init[]   =   { 1, 1, 5, 11, 29, 7, 119, 155, 431, 999, 757, 2433, 5811, 3709, 29573, 23639, 0 };
            const std::uint32_t dim5067JoeKuoD6Init[]   =   { 1, 3, 3, 3, 15, 35, 125, 13, 275, 507, 1719, 1537, 2349, 12909, 8107, 9845, 0 };
            const std::uint32_t dim5068JoeKuoD6Init[]   =   { 1, 3, 1, 13, 27, 27, 11, 69, 15, 1017, 207, 625, 809, 2921, 8939, 30293, 0 };
            const std::uint32_t dim5069JoeKuoD6Init[]   =   { 1, 1, 7, 11, 31, 51, 113, 193, 69, 845, 73, 919, 3523, 3987, 23665, 36527, 0 };
            const std::uint32_t dim5070JoeKuoD6Init[]   =   { 1, 3, 7, 11, 21, 31, 103, 29, 5, 81, 1081, 3847, 4697, 8857, 30769, 40053, 0 };
            const std::uint32_t dim5071JoeKuoD6Init[]   =   { 1, 1, 1, 1, 5, 11, 5, 169, 13, 899, 769, 3823, 5405, 5991, 3821, 27767, 0 };
            const std::uint32_t dim5072JoeKuoD6Init[]   =   { 1, 1, 3, 15, 1, 35, 9, 83, 23, 701, 1807, 1681, 4009, 127, 31751, 38059, 0 };
            const std::uint32_t dim5073JoeKuoD6Init[]   =   { 1, 3, 3, 7, 9, 61, 73, 111, 193, 607, 2001, 413, 3751, 16337, 16597, 23959, 0 };
            const std::uint32_t dim5074JoeKuoD6Init[]   =   { 1, 1, 7, 7, 21, 29, 53, 253, 187, 507, 1191, 3521, 463, 2167, 23785, 19867, 0 };
            const std::uint32_t dim5075JoeKuoD6Init[]   =   { 1, 3, 5, 3, 19, 43, 101, 93, 257, 61, 1589, 3883, 1975, 7283, 5253, 23257, 0 };
            const std::uint32_t dim5076JoeKuoD6Init[]   =   { 1, 3, 1, 9, 1, 63, 25, 101, 377, 571, 1701, 3385, 243, 12051, 32619, 10459, 0 };
            const std::uint32_t dim5077JoeKuoD6Init[]   =   { 1, 1, 1, 5, 17, 11, 37, 197, 205, 879, 625, 959, 7389, 7857, 20615, 20405, 0 };
            const std::uint32_t dim5078JoeKuoD6Init[]   =   { 1, 3, 5, 5, 27, 41, 9, 109, 197, 623, 1045, 63, 7977, 11355, 28613, 5131, 0 };
            const std::uint32_t dim5079JoeKuoD6Init[]   =   { 1, 1, 5, 11, 5, 29, 27, 85, 131, 247, 433, 3981, 2677, 15415, 869, 6045, 0 };
            const std::uint32_t dim5080JoeKuoD6Init[]   =   { 1, 3, 1, 13, 9, 49, 25, 79, 135, 719, 93, 631, 2149, 5929, 29833, 38673, 0 };
            const std::uint32_t dim5081JoeKuoD6Init[]   =   { 1, 3, 7, 11, 15, 13, 37, 233, 227, 205, 1579, 65, 1429, 13499, 26355, 63821, 0 };
            const std::uint32_t dim5082JoeKuoD6Init[]   =   { 1, 1, 5, 11, 21, 19, 7, 183, 409, 275, 899, 3665, 6207, 849, 24339, 1617, 0 };
            const std::uint32_t dim5083JoeKuoD6Init[]   =   { 1, 3, 1, 3, 21, 61, 23, 125, 463, 489, 1265, 2975, 3907, 11881, 7533, 43331, 0 };
            const std::uint32_t dim5084JoeKuoD6Init[]   =   { 1, 3, 1, 15, 15, 51, 83, 31, 175, 47, 1791, 3651, 6735, 5013, 723, 24141, 0 };
            const std::uint32_t dim5085JoeKuoD6Init[]   =   { 1, 3, 1, 9, 17, 41, 57, 43, 469, 911, 1251, 2105, 3133, 3437, 10097, 26687, 0 };
            const std::uint32_t dim5086JoeKuoD6Init[]   =   { 1, 1, 3, 3, 9, 9, 125, 201, 141, 943, 1509, 1239, 6575, 8707, 363, 23309, 0 };
            const std::uint32_t dim5087JoeKuoD6Init[]   =   { 1, 1, 5, 3, 19, 37, 43, 141, 413, 149, 1449, 1003, 4473, 12395, 4101, 61201, 0 };
            const std::uint32_t dim5088JoeKuoD6Init[]   =   { 1, 1, 5, 11, 17, 37, 41, 33, 57, 627, 325, 1895, 1773, 1339, 24859, 587, 0 };
            const std::uint32_t dim5089JoeKuoD6Init[]   =   { 1, 1, 1, 3, 5, 49, 127, 109, 361, 853, 1437, 3451, 4031, 5379, 27463, 47425, 0 };
            const std::uint32_t dim5090JoeKuoD6Init[]   =   { 1, 3, 5, 7, 9, 57, 71, 219, 347, 791, 797, 73, 6241, 12717, 24429, 40977, 0 };
            const std::uint32_t dim5091JoeKuoD6Init[]   =   { 1, 1, 5, 9, 27, 43, 43, 227, 433, 413, 1109, 2589, 4535, 8947, 8121, 43479, 0 };
            const std::uint32_t dim5092JoeKuoD6Init[]   =   { 1, 3, 7, 1, 9, 21, 81, 23, 157, 313, 197, 2845, 8059, 15957, 28657, 28093, 0 };
            const std::uint32_t dim5093JoeKuoD6Init[]   =   { 1, 3, 1, 11, 15, 17, 115, 27, 421, 743, 1885, 2089, 5011, 7137, 7395, 36853, 0 };
            const std::uint32_t dim5094JoeKuoD6Init[]   =   { 1, 1, 5, 15, 5, 53, 69, 255, 63, 29, 1011, 3201, 1467, 15441, 26255, 62895, 0 };
            const std::uint32_t dim5095JoeKuoD6Init[]   =   { 1, 3, 1, 11, 3, 47, 35, 195, 149, 849, 1317, 439, 3539, 845, 15295, 42183, 0 };
            const std::uint32_t dim5096JoeKuoD6Init[]   =   { 1, 1, 5, 15, 15, 37, 67, 105, 495, 985, 1777, 3137, 8039, 11795, 29771, 35045, 0 };
            const std::uint32_t dim5097JoeKuoD6Init[]   =   { 1, 1, 3, 1, 25, 17, 67, 227, 229, 419, 1319, 3325, 1293, 8585, 28425, 34013, 0 };
            const std::uint32_t dim5098JoeKuoD6Init[]   =   { 1, 1, 5, 1, 27, 51, 71, 197, 375, 407, 259, 4005, 3309, 5475, 13421, 60065, 0 };
            const std::uint32_t dim5099JoeKuoD6Init[]   =   { 1, 3, 1, 5, 11, 17, 89, 45, 311, 425, 1629, 773, 7267, 8699, 27547, 37081, 0 };
            const std::uint32_t dim5100JoeKuoD6Init[]   =   { 1, 3, 1, 7, 9, 25, 101, 105, 489, 217, 103, 1959, 4049, 5793, 31201, 11947, 0 };
            const std::uint32_t dim5101JoeKuoD6Init[]   =   { 1, 1, 5, 5, 19, 3, 63, 55, 431, 49, 273, 3253, 5357, 13801, 9735, 21883, 0 };
            const std::uint32_t dim5102JoeKuoD6Init[]   =   { 1, 1, 1, 11, 13, 3, 75, 201, 477, 201, 1875, 657, 6217, 8651, 2207, 16421, 0 };
            const std::uint32_t dim5103JoeKuoD6Init[]   =   { 1, 1, 5, 13, 5, 31, 75, 113, 25, 171, 1147, 3089, 7095, 4405, 26155, 42323, 0 };
            const std::uint32_t dim5104JoeKuoD6Init[]   =   { 1, 3, 5, 5, 5, 49, 99, 171, 445, 1023, 1793, 3159, 5809, 12509, 31723, 60411, 0 };
            const std::uint32_t dim5105JoeKuoD6Init[]   =   { 1, 3, 7, 3, 23, 51, 111, 27, 103, 159, 433, 293, 1741, 3599, 4067, 40667, 0 };
            const std::uint32_t dim5106JoeKuoD6Init[]   =   { 1, 3, 3, 13, 11, 9, 11, 21, 453, 35, 1649, 1261, 3539, 14081, 5581, 57105, 0 };
            const std::uint32_t dim5107JoeKuoD6Init[]   =   { 1, 3, 3, 13, 7, 9, 113, 87, 391, 647, 223, 1345, 4481, 9855, 20129, 10807, 0 };
            const std::uint32_t dim5108JoeKuoD6Init[]   =   { 1, 3, 7, 15, 3, 61, 15, 117, 97, 495, 985, 819, 181, 1363, 13111, 35857, 0 };
            const std::uint32_t dim5109JoeKuoD6Init[]   =   { 1, 3, 1, 9, 3, 27, 125, 151, 217, 961, 707, 2647, 5307, 621, 12581, 13941, 0 };
            const std::uint32_t dim5110JoeKuoD6Init[]   =   { 1, 3, 1, 11, 17, 37, 35, 211, 179, 29, 627, 3623, 6429, 16237, 24699, 14385, 0 };
            const std::uint32_t dim5111JoeKuoD6Init[]   =   { 1, 3, 3, 9, 3, 57, 35, 3, 85, 1017, 1739, 2241, 7297, 15637, 27085, 41237, 0 };
            const std::uint32_t dim5112JoeKuoD6Init[]   =   { 1, 1, 3, 7, 7, 13, 5, 85, 505, 51, 409, 867, 677, 12451, 13633, 47883, 0 };
            const std::uint32_t dim5113JoeKuoD6Init[]   =   { 1, 3, 5, 13, 5, 51, 37, 79, 237, 133, 1331, 3263, 349, 4971, 16067, 62485, 0 };
            const std::uint32_t dim5114JoeKuoD6Init[]   =   { 1, 1, 7, 11, 29, 41, 101, 219, 391, 1023, 1681, 3163, 4071, 14665, 11041, 14523, 0 };
            const std::uint32_t dim5115JoeKuoD6Init[]   =   { 1, 1, 3, 3, 13, 55, 37, 119, 471, 665, 1315, 3071, 5993, 12005, 13549, 63425, 0 };
            const std::uint32_t dim5116JoeKuoD6Init[]   =   { 1, 3, 5, 7, 5, 25, 59, 71, 77, 841, 91, 1841, 6997, 1139, 11843, 52209, 0 };
            const std::uint32_t dim5117JoeKuoD6Init[]   =   { 1, 3, 7, 15, 17, 25, 85, 173, 373, 459, 1713, 1055, 5337, 9921, 15213, 44235, 0 };
            const std::uint32_t dim5118JoeKuoD6Init[]   =   { 1, 1, 1, 15, 7, 11, 89, 237, 131, 565, 745, 457, 4447, 5581, 11053, 43819, 0 };
            const std::uint32_t dim5119JoeKuoD6Init[]   =   { 1, 3, 5, 1, 29, 21, 11, 7, 125, 851, 2023, 3321, 1885, 67, 8809, 43291, 0 };
            const std::uint32_t dim5120JoeKuoD6Init[]   =   { 1, 3, 5, 11, 11, 43, 41, 97, 353, 813, 85, 2453, 769, 11709, 4697, 2849, 0 };
            const std::uint32_t dim5121JoeKuoD6Init[]   =   { 1, 1, 5, 5, 21, 29, 87, 179, 157, 981, 129, 2139, 6841, 5479, 27111, 20749, 0 };
            const std::uint32_t dim5122JoeKuoD6Init[]   =   { 1, 1, 3, 9, 31, 59, 61, 15, 423, 33, 467, 1817, 6535, 7341, 31061, 20937, 0 };
            const std::uint32_t dim5123JoeKuoD6Init[]   =   { 1, 1, 7, 3, 1, 21, 127, 135, 321, 699, 727, 3079, 753, 3971, 5611, 28345, 0 };
            const std::uint32_t dim5124JoeKuoD6Init[]   =   { 1, 3, 7, 11, 27, 3, 39, 63, 389, 433, 43, 1443, 6241, 10769, 20485, 58823, 0 };
            const std::uint32_t dim5125JoeKuoD6Init[]   =   { 1, 1, 1, 11, 3, 13, 5, 57, 503, 707, 677, 3355, 6691, 8841, 20041, 11867, 0 };
            const std::uint32_t dim5126JoeKuoD6Init[]   =   { 1, 1, 3, 11, 31, 39, 107, 221, 81, 125, 1439, 2429, 2109, 3931, 31007, 10915, 0 };
            const std::uint32_t dim5127JoeKuoD6Init[]   =   { 1, 3, 3, 9, 17, 53, 13, 121, 127, 15, 1825, 1909, 5951, 13503, 31565, 56163, 0 };
            const std::uint32_t dim5128JoeKuoD6Init[]   =   { 1, 1, 1, 1, 19, 55, 3, 153, 385, 277, 1297, 3655, 6027, 3057, 11341, 46989, 0 };
            const std::uint32_t dim5129JoeKuoD6Init[]   =   { 1, 1, 5, 9, 3, 55, 37, 223, 353, 141, 1917, 3827, 2255, 7617, 10971, 10641, 0 };
            const std::uint32_t dim5130JoeKuoD6Init[]   =   { 1, 3, 7, 9, 29, 41, 71, 19, 137, 243, 2047, 395, 6981, 15887, 9479, 60199, 0 };
            const std::uint32_t dim5131JoeKuoD6Init[]   =   { 1, 1, 1, 9, 17, 43, 51, 191, 405, 727, 485, 987, 1855, 15801, 22529, 10165, 0 };
            const std::uint32_t dim5132JoeKuoD6Init[]   =   { 1, 3, 1, 7, 27, 31, 69, 255, 153, 793, 1353, 1981, 83, 11387, 6747, 23379, 0 };
            const std::uint32_t dim5133JoeKuoD6Init[]   =   { 1, 1, 5, 5, 31, 49, 83, 157, 63, 647, 1367, 3995, 5899, 8429, 18317, 3471, 0 };
            const std::uint32_t dim5134JoeKuoD6Init[]   =   { 1, 3, 5, 13, 19, 15, 99, 13, 143, 887, 529, 2855, 573, 9799, 13585, 59263, 0 };
            const std::uint32_t dim5135JoeKuoD6Init[]   =   { 1, 3, 5, 3, 13, 47, 103, 87, 11, 381, 397, 899, 71, 15539, 13005, 38297, 0 };
            const std::uint32_t dim5136JoeKuoD6Init[]   =   { 1, 1, 1, 3, 1, 53, 45, 141, 1, 941, 261, 3291, 5177, 9843, 6309, 62799, 0 };
            const std::uint32_t dim5137JoeKuoD6Init[]   =   { 1, 1, 5, 9, 29, 31, 107, 57, 135, 229, 1147, 247, 265, 12757, 21365, 7219, 0 };
            const std::uint32_t dim5138JoeKuoD6Init[]   =   { 1, 1, 1, 3, 1, 49, 55, 247, 495, 449, 141, 1349, 7393, 2589, 23587, 1097, 0 };
            const std::uint32_t dim5139JoeKuoD6Init[]   =   { 1, 3, 5, 1, 9, 11, 73, 153, 89, 575, 1805, 137, 435, 3687, 32169, 24275, 0 };
            const std::uint32_t dim5140JoeKuoD6Init[]   =   { 1, 1, 7, 15, 25, 61, 51, 21, 109, 139, 611, 3907, 6721, 5081, 6665, 51463, 0 };
            const std::uint32_t dim5141JoeKuoD6Init[]   =   { 1, 1, 1, 9, 13, 23, 59, 203, 33, 1013, 1533, 291, 6171, 15463, 8581, 9497, 0 };
            const std::uint32_t dim5142JoeKuoD6Init[]   =   { 1, 3, 3, 9, 7, 25, 51, 189, 49, 265, 1163, 1141, 2467, 7839, 7083, 65527, 0 };
            const std::uint32_t dim5143JoeKuoD6Init[]   =   { 1, 1, 3, 9, 19, 33, 77, 9, 181, 919, 623, 1521, 7853, 2199, 24115, 60607, 0 };
            const std::uint32_t dim5144JoeKuoD6Init[]   =   { 1, 1, 3, 11, 9, 11, 27, 57, 355, 313, 151, 3391, 4869, 12541, 30031, 29455, 0 };
            const std::uint32_t dim5145JoeKuoD6Init[]   =   { 1, 3, 5, 9, 17, 13, 91, 123, 235, 841, 1113, 1451, 501, 3863, 32483, 9445, 0 };
            const std::uint32_t dim5146JoeKuoD6Init[]   =   { 1, 3, 7, 3, 13, 25, 87, 243, 449, 293, 1279, 3571, 2693, 13459, 5895, 38127, 0 };
            const std::uint32_t dim5147JoeKuoD6Init[]   =   { 1, 1, 3, 15, 27, 61, 7, 57, 255, 971, 131, 2585, 2187, 7191, 17779, 34587, 0 };
            const std::uint32_t dim5148JoeKuoD6Init[]   =   { 1, 3, 3, 7, 23, 29, 55, 41, 463, 873, 1781, 2851, 4731, 9819, 25587, 32199, 0 };
            const std::uint32_t dim5149JoeKuoD6Init[]   =   { 1, 1, 1, 9, 29, 39, 25, 143, 171, 141, 223, 467, 4417, 9575, 23159, 33819, 0 };
            const std::uint32_t dim5150JoeKuoD6Init[]   =   { 1, 1, 5, 13, 19, 61, 19, 75, 25, 361, 585, 1627, 2231, 1831, 24885, 37917, 0 };
            const std::uint32_t dim5151JoeKuoD6Init[]   =   { 1, 3, 7, 7, 23, 19, 59, 55, 323, 55, 143, 131, 27, 15363, 26423, 43963, 0 };
            const std::uint32_t dim5152JoeKuoD6Init[]   =   { 1, 1, 5, 5, 25, 9, 33, 17, 427, 481, 315, 3999, 4757, 4545, 7695, 56733, 0 };
            const std::uint32_t dim5153JoeKuoD6Init[]   =   { 1, 3, 5, 13, 5, 59, 45, 117, 115, 263, 1441, 3307, 1085, 3875, 25869, 19725, 0 };
            const std::uint32_t dim5154JoeKuoD6Init[]   =   { 1, 3, 3, 15, 13, 39, 31, 243, 293, 345, 343, 1911, 6123, 12577, 32081, 59993, 0 };
            const std::uint32_t dim5155JoeKuoD6Init[]   =   { 1, 3, 5, 13, 17, 37, 105, 201, 205, 929, 435, 1467, 8063, 6963, 13709, 53275, 0 };
            const std::uint32_t dim5156JoeKuoD6Init[]   =   { 1, 3, 7, 15, 31, 3, 65, 221, 191, 413, 427, 2579, 377, 2793, 26943, 61299, 0 };
            const std::uint32_t dim5157JoeKuoD6Init[]   =   { 1, 3, 5, 3, 11, 61, 75, 107, 53, 689, 1845, 859, 333, 889, 27607, 48795, 0 };
            const std::uint32_t dim5158JoeKuoD6Init[]   =   { 1, 1, 5, 7, 1, 11, 37, 181, 323, 187, 1511, 25, 5517, 11957, 7093, 429, 0 };
            const std::uint32_t dim5159JoeKuoD6Init[]   =   { 1, 3, 3, 1, 25, 31, 125, 139, 433, 583, 683, 587, 5389, 1225, 26047, 18717, 0 };
            const std::uint32_t dim5160JoeKuoD6Init[]   =   { 1, 3, 1, 15, 23, 33, 23, 147, 279, 513, 157, 4023, 2669, 7543, 2111, 9191, 0 };
            const std::uint32_t dim5161JoeKuoD6Init[]   =   { 1, 3, 1, 1, 5, 39, 55, 127, 257, 649, 347, 3001, 2215, 15579, 29665, 10337, 0 };
            const std::uint32_t dim5162JoeKuoD6Init[]   =   { 1, 1, 1, 15, 19, 55, 105, 183, 505, 1003, 1311, 2253, 1861, 3561, 19581, 46183, 0 };
            const std::uint32_t dim5163JoeKuoD6Init[]   =   { 1, 3, 1, 9, 23, 5, 127, 215, 195, 817, 719, 1285, 919, 8627, 20427, 2723, 0 };
            const std::uint32_t dim5164JoeKuoD6Init[]   =   { 1, 1, 1, 5, 15, 31, 43, 131, 377, 57, 1531, 915, 2871, 1805, 19765, 60529, 0 };
            const std::uint32_t dim5165JoeKuoD6Init[]   =   { 1, 3, 3, 3, 15, 1, 93, 55, 477, 221, 643, 1319, 959, 475, 14015, 48823, 0 };
            const std::uint32_t dim5166JoeKuoD6Init[]   =   { 1, 3, 3, 7, 19, 13, 13, 191, 421, 751, 1103, 2129, 1973, 14935, 26485, 41269, 0 };
            const std::uint32_t dim5167JoeKuoD6Init[]   =   { 1, 1, 5, 13, 17, 43, 81, 83, 67, 643, 1799, 1157, 4365, 2815, 29871, 5351, 0 };
            const std::uint32_t dim5168JoeKuoD6Init[]   =   { 1, 3, 1, 9, 21, 31, 87, 177, 25, 403, 1357, 4047, 959, 5133, 7307, 4333, 0 };
            const std::uint32_t dim5169JoeKuoD6Init[]   =   { 1, 1, 7, 7, 29, 39, 27, 139, 159, 529, 1323, 3823, 4569, 12711, 30263, 10961, 0 };
            const std::uint32_t dim5170JoeKuoD6Init[]   =   { 1, 3, 1, 13, 27, 15, 59, 1, 107, 723, 497, 43, 143, 16119, 29177, 5653, 0 };
            const std::uint32_t dim5171JoeKuoD6Init[]   =   { 1, 1, 5, 9, 15, 41, 23, 109, 101, 639, 277, 1687, 1311, 1995, 5403, 6867, 0 };
            const std::uint32_t dim5172JoeKuoD6Init[]   =   { 1, 1, 5, 3, 13, 1, 95, 177, 379, 545, 789, 3479, 4135, 445, 5869, 38923, 0 };
            const std::uint32_t dim5173JoeKuoD6Init[]   =   { 1, 1, 3, 9, 21, 31, 23, 65, 209, 383, 271, 367, 6605, 1169, 27267, 9331, 0 };
            const std::uint32_t dim5174JoeKuoD6Init[]   =   { 1, 1, 1, 1, 27, 39, 121, 29, 155, 465, 947, 2675, 6753, 11647, 29781, 30251, 0 };
            const std::uint32_t dim5175JoeKuoD6Init[]   =   { 1, 3, 1, 5, 7, 45, 7, 21, 223, 363, 1021, 751, 2257, 14423, 19629, 64867, 0 };
            const std::uint32_t dim5176JoeKuoD6Init[]   =   { 1, 3, 1, 9, 31, 53, 13, 99, 49, 389, 867, 327, 4145, 3265, 15423, 14985, 0 };
            const std::uint32_t dim5177JoeKuoD6Init[]   =   { 1, 1, 1, 15, 11, 11, 27, 41, 333, 161, 1343, 2023, 3789, 13563, 16957, 26849, 0 };
            const std::uint32_t dim5178JoeKuoD6Init[]   =   { 1, 3, 7, 1, 7, 51, 7, 163, 239, 393, 231, 3985, 309, 875, 837, 24791, 0 };
            const std::uint32_t dim5179JoeKuoD6Init[]   =   { 1, 1, 1, 7, 1, 43, 105, 7, 351, 755, 1781, 1925, 4961, 2961, 13427, 44317, 0 };
            const std::uint32_t dim5180JoeKuoD6Init[]   =   { 1, 3, 1, 9, 17, 39, 81, 75, 201, 931, 1547, 1857, 7251, 11687, 14437, 12603, 0 };
            const std::uint32_t dim5181JoeKuoD6Init[]   =   { 1, 3, 3, 15, 15, 23, 95, 7, 193, 9, 1749, 809, 5083, 14645, 24893, 35979, 0 };
            const std::uint32_t dim5182JoeKuoD6Init[]   =   { 1, 1, 7, 1, 9, 9, 127, 149, 433, 985, 1347, 3379, 2881, 681, 20777, 30703, 0 };
            const std::uint32_t dim5183JoeKuoD6Init[]   =   { 1, 3, 1, 11, 1, 27, 121, 111, 251, 45, 1341, 1709, 3733, 11297, 29063, 57119, 0 };
            const std::uint32_t dim5184JoeKuoD6Init[]   =   { 1, 3, 3, 1, 19, 3, 77, 127, 187, 831, 1125, 3119, 4665, 9857, 5301, 36755, 0 };
            const std::uint32_t dim5185JoeKuoD6Init[]   =   { 1, 3, 3, 3, 29, 29, 61, 225, 257, 635, 665, 1279, 3019, 2401, 8253, 40251, 0 };
            const std::uint32_t dim5186JoeKuoD6Init[]   =   { 1, 1, 7, 9, 29, 43, 47, 95, 221, 823, 257, 1485, 5183, 225, 27675, 60479, 0 };
            const std::uint32_t dim5187JoeKuoD6Init[]   =   { 1, 1, 5, 3, 15, 49, 25, 69, 101, 393, 901, 305, 4917, 13479, 30209, 9199, 0 };
            const std::uint32_t dim5188JoeKuoD6Init[]   =   { 1, 1, 3, 15, 1, 9, 47, 243, 403, 341, 143, 1365, 1817, 6017, 3853, 58625, 0 };
            const std::uint32_t dim5189JoeKuoD6Init[]   =   { 1, 3, 3, 11, 9, 49, 93, 149, 39, 177, 1863, 1027, 659, 9253, 2131, 26943, 0 };
            const std::uint32_t dim5190JoeKuoD6Init[]   =   { 1, 3, 1, 3, 25, 1, 43, 255, 217, 353, 957, 39, 4607, 15761, 24291, 33619, 0 };
            const std::uint32_t dim5191JoeKuoD6Init[]   =   { 1, 1, 1, 7, 29, 51, 71, 237, 1, 703, 19, 213, 6429, 11783, 22049, 30597, 0 };
            const std::uint32_t dim5192JoeKuoD6Init[]   =   { 1, 3, 1, 7, 31, 63, 105, 203, 473, 731, 257, 91, 5749, 4099, 30125, 40171, 0 };
            const std::uint32_t dim5193JoeKuoD6Init[]   =   { 1, 3, 7, 9, 7, 29, 119, 181, 225, 743, 1031, 55, 3997, 16221, 11663, 14847, 0 };
            const std::uint32_t dim5194JoeKuoD6Init[]   =   { 1, 3, 3, 11, 5, 21, 43, 17, 473, 981, 125, 2077, 6141, 4757, 7585, 29207, 0 };
            const std::uint32_t dim5195JoeKuoD6Init[]   =   { 1, 1, 7, 1, 27, 61, 27, 45, 267, 483, 119, 767, 957, 3411, 2653, 53967, 0 };
            const std::uint32_t dim5196JoeKuoD6Init[]   =   { 1, 1, 1, 3, 9, 41, 43, 17, 485, 253, 825, 3605, 5919, 9285, 1815, 6095, 0 };
            const std::uint32_t dim5197JoeKuoD6Init[]   =   { 1, 1, 1, 11, 7, 5, 53, 107, 309, 609, 1389, 2035, 861, 15565, 9375, 42363, 0 };
            const std::uint32_t dim5198JoeKuoD6Init[]   =   { 1, 3, 5, 3, 27, 57, 7, 177, 183, 227, 865, 183, 2903, 6325, 4393, 5257, 0 };
            const std::uint32_t dim5199JoeKuoD6Init[]   =   { 1, 3, 1, 5, 21, 29, 79, 107, 365, 427, 813, 3563, 7713, 3865, 4289, 28555, 0 };
            const std::uint32_t dim5200JoeKuoD6Init[]   =   { 1, 3, 5, 7, 11, 27, 1, 197, 425, 769, 1737, 3627, 1273, 4469, 11967, 823, 0 };
            const std::uint32_t dim5201JoeKuoD6Init[]   =   { 1, 1, 1, 13, 3, 31, 127, 159, 471, 367, 2047, 949, 1591, 12429, 21497, 27153, 0 };
            const std::uint32_t dim5202JoeKuoD6Init[]   =   { 1, 3, 1, 3, 3, 31, 31, 87, 243, 413, 1777, 1361, 4575, 1147, 17451, 33985, 0 };
            const std::uint32_t dim5203JoeKuoD6Init[]   =   { 1, 3, 3, 5, 13, 47, 45, 3, 165, 329, 743, 397, 2479, 4999, 12921, 26689, 0 };
            const std::uint32_t dim5204JoeKuoD6Init[]   =   { 1, 1, 5, 7, 17, 59, 25, 117, 217, 601, 235, 2691, 5569, 7853, 31063, 28281, 0 };
            const std::uint32_t dim5205JoeKuoD6Init[]   =   { 1, 3, 1, 11, 11, 39, 71, 77, 481, 39, 363, 1921, 3263, 12849, 13325, 41803, 0 };
            const std::uint32_t dim5206JoeKuoD6Init[]   =   { 1, 3, 7, 5, 19, 1, 59, 197, 239, 787, 1657, 1449, 4245, 1317, 19609, 53583, 0 };
            const std::uint32_t dim5207JoeKuoD6Init[]   =   { 1, 1, 7, 1, 13, 33, 81, 53, 223, 323, 477, 2421, 4045, 1855, 5823, 9661, 0 };
            const std::uint32_t dim5208JoeKuoD6Init[]   =   { 1, 3, 1, 7, 1, 3, 121, 19, 329, 569, 481, 3443, 499, 12407, 19625, 4627, 0 };
            const std::uint32_t dim5209JoeKuoD6Init[]   =   { 1, 1, 1, 7, 3, 33, 91, 241, 69, 581, 1635, 1025, 4677, 14651, 5229, 19555, 0 };
            const std::uint32_t dim5210JoeKuoD6Init[]   =   { 1, 3, 1, 15, 9, 11, 99, 47, 489, 755, 601, 1221, 4251, 4377, 20567, 33839, 0 };
            const std::uint32_t dim5211JoeKuoD6Init[]   =   { 1, 3, 3, 5, 21, 21, 127, 151, 499, 971, 1627, 609, 2365, 3183, 7413, 697, 0 };
            const std::uint32_t dim5212JoeKuoD6Init[]   =   { 1, 3, 7, 13, 5, 35, 61, 121, 51, 297, 29, 1825, 495, 1299, 12741, 3253, 0 };
            const std::uint32_t dim5213JoeKuoD6Init[]   =   { 1, 1, 1, 1, 13, 15, 49, 205, 235, 9, 849, 1101, 4533, 10221, 32419, 50151, 0 };
            const std::uint32_t dim5214JoeKuoD6Init[]   =   { 1, 1, 3, 13, 29, 31, 57, 77, 217, 195, 1951, 189, 981, 6169, 22677, 64415, 0 };
            const std::uint32_t dim5215JoeKuoD6Init[]   =   { 1, 3, 1, 5, 15, 37, 25, 233, 43, 843, 1205, 153, 6339, 3767, 16725, 32699, 0 };
            const std::uint32_t dim5216JoeKuoD6Init[]   =   { 1, 3, 3, 1, 19, 37, 11, 217, 461, 897, 1181, 2815, 295, 15153, 25351, 57211, 0 };
            const std::uint32_t dim5217JoeKuoD6Init[]   =   { 1, 3, 5, 11, 15, 9, 5, 179, 353, 769, 1457, 2919, 1201, 14871, 29549, 52265, 0 };
            const std::uint32_t dim5218JoeKuoD6Init[]   =   { 1, 1, 3, 3, 5, 51, 127, 221, 329, 543, 1537, 2701, 2709, 9311, 2715, 42669, 0 };
            const std::uint32_t dim5219JoeKuoD6Init[]   =   { 1, 3, 5, 15, 5, 41, 79, 233, 445, 265, 2001, 935, 3133, 3977, 3601, 21389, 0 };
            const std::uint32_t dim5220JoeKuoD6Init[]   =   { 1, 3, 5, 11, 3, 7, 115, 45, 311, 827, 1897, 3399, 4251, 5341, 22621, 25519, 0 };
            const std::uint32_t dim5221JoeKuoD6Init[]   =   { 1, 3, 7, 1, 11, 57, 117, 103, 401, 505, 1683, 2161, 4363, 11189, 20263, 13065, 0 };
            const std::uint32_t dim5222JoeKuoD6Init[]   =   { 1, 1, 1, 7, 23, 29, 31, 77, 63, 179, 195, 2747, 579, 11701, 5101, 11497, 0 };
            const std::uint32_t dim5223JoeKuoD6Init[]   =   { 1, 3, 7, 3, 9, 33, 81, 165, 433, 545, 1893, 3709, 3813, 6615, 1485, 6395, 0 };
            const std::uint32_t dim5224JoeKuoD6Init[]   =   { 1, 3, 1, 15, 9, 5, 27, 157, 389, 683, 1919, 509, 455, 3865, 2303, 6993, 0 };
            const std::uint32_t dim5225JoeKuoD6Init[]   =   { 1, 3, 3, 9, 5, 5, 3, 5, 299, 59, 539, 1199, 2443, 10821, 3359, 44345, 0 };
            const std::uint32_t dim5226JoeKuoD6Init[]   =   { 1, 3, 5, 9, 21, 37, 87, 35, 501, 943, 1313, 3929, 351, 9851, 22971, 35659, 0 };
            const std::uint32_t dim5227JoeKuoD6Init[]   =   { 1, 3, 7, 11, 11, 33, 77, 175, 411, 315, 1797, 2731, 4611, 1809, 22027, 50595, 0 };
            const std::uint32_t dim5228JoeKuoD6Init[]   =   { 1, 3, 7, 13, 15, 11, 13, 189, 209, 1015, 1869, 1593, 6887, 8571, 7217, 2641, 0 };
            const std::uint32_t dim5229JoeKuoD6Init[]   =   { 1, 1, 3, 13, 29, 15, 119, 127, 329, 275, 865, 1693, 225, 15735, 11071, 37127, 0 };
            const std::uint32_t dim5230JoeKuoD6Init[]   =   { 1, 3, 7, 13, 9, 31, 85, 25, 281, 401, 1923, 2391, 3875, 2079, 2055, 53275, 0 };
            const std::uint32_t dim5231JoeKuoD6Init[]   =   { 1, 3, 1, 5, 23, 57, 79, 127, 209, 901, 315, 1165, 3393, 15095, 1981, 34993, 0 };
            const std::uint32_t dim5232JoeKuoD6Init[]   =   { 1, 3, 7, 7, 25, 13, 15, 223, 157, 335, 1061, 395, 6895, 6283, 18375, 4887, 0 };
            const std::uint32_t dim5233JoeKuoD6Init[]   =   { 1, 3, 7, 13, 9, 15, 99, 201, 105, 643, 117, 3027, 641, 13353, 4343, 11875, 0 };
            const std::uint32_t dim5234JoeKuoD6Init[]   =   { 1, 1, 3, 11, 5, 51, 5, 77, 281, 207, 1201, 1187, 8107, 6625, 7517, 34377, 0 };
            const std::uint32_t dim5235JoeKuoD6Init[]   =   { 1, 1, 1, 5, 29, 61, 3, 181, 297, 151, 565, 2713, 6611, 8665, 32425, 50399, 0 };
            const std::uint32_t dim5236JoeKuoD6Init[]   =   { 1, 3, 1, 5, 1, 61, 41, 245, 95, 647, 49, 2195, 5927, 15531, 28547, 51075, 0 };
            const std::uint32_t dim5237JoeKuoD6Init[]   =   { 1, 3, 3, 15, 15, 63, 123, 63, 77, 813, 423, 715, 91, 3793, 20901, 54927, 0 };
            const std::uint32_t dim5238JoeKuoD6Init[]   =   { 1, 3, 7, 9, 15, 35, 31, 161, 127, 13, 1667, 1225, 5279, 15487, 18769, 24887, 0 };
            const std::uint32_t dim5239JoeKuoD6Init[]   =   { 1, 1, 3, 5, 27, 25, 61, 21, 447, 175, 1419, 2691, 1993, 13059, 30809, 38325, 0 };
            const std::uint32_t dim5240JoeKuoD6Init[]   =   { 1, 3, 1, 3, 15, 21, 15, 193, 233, 435, 1993, 4003, 4581, 13837, 16535, 43781, 0 };
            const std::uint32_t dim5241JoeKuoD6Init[]   =   { 1, 1, 1, 5, 1, 11, 21, 253, 59, 59, 497, 77, 2165, 8197, 5933, 25743, 0 };
            const std::uint32_t dim5242JoeKuoD6Init[]   =   { 1, 1, 3, 9, 25, 61, 29, 217, 95, 269, 799, 409, 801, 421, 19065, 53443, 0 };
            const std::uint32_t dim5243JoeKuoD6Init[]   =   { 1, 1, 7, 1, 1, 41, 71, 59, 191, 867, 223, 1467, 6679, 16031, 4451, 15313, 0 };
            const std::uint32_t dim5244JoeKuoD6Init[]   =   { 1, 1, 1, 11, 13, 27, 7, 241, 167, 969, 1267, 2953, 3769, 2415, 30065, 39483, 0 };
            const std::uint32_t dim5245JoeKuoD6Init[]   =   { 1, 1, 1, 3, 25, 61, 103, 23, 53, 799, 989, 3859, 7299, 13613, 12007, 37535, 0 };
            const std::uint32_t dim5246JoeKuoD6Init[]   =   { 1, 1, 7, 1, 29, 19, 121, 57, 355, 663, 643, 3723, 1775, 10363, 1389, 16039, 0 };
            const std::uint32_t dim5247JoeKuoD6Init[]   =   { 1, 3, 7, 3, 21, 55, 51, 67, 363, 843, 1187, 1983, 7757, 5413, 26575, 53329, 0 };
            const std::uint32_t dim5248JoeKuoD6Init[]   =   { 1, 3, 1, 3, 31, 55, 73, 55, 75, 533, 197, 1463, 2933, 6033, 24397, 41579, 0 };
            const std::uint32_t dim5249JoeKuoD6Init[]   =   { 1, 3, 1, 11, 9, 15, 107, 141, 473, 825, 901, 937, 7433, 13119, 20047, 6695, 0 };
            const std::uint32_t dim5250JoeKuoD6Init[]   =   { 1, 3, 5, 7, 19, 27, 3, 149, 507, 137, 1025, 1841, 33, 3113, 15101, 28187, 0 };
            const std::uint32_t dim5251JoeKuoD6Init[]   =   { 1, 3, 5, 7, 31, 27, 53, 45, 177, 129, 1241, 1525, 991, 4141, 17681, 39435, 0 };
            const std::uint32_t dim5252JoeKuoD6Init[]   =   { 1, 1, 1, 15, 31, 57, 29, 137, 395, 563, 101, 3367, 1277, 5431, 1169, 44321, 0 };
            const std::uint32_t dim5253JoeKuoD6Init[]   =   { 1, 3, 5, 7, 21, 15, 123, 181, 113, 313, 1763, 1429, 2985, 715, 26129, 549, 0 };
            const std::uint32_t dim5254JoeKuoD6Init[]   =   { 1, 3, 3, 1, 15, 27, 27, 139, 507, 79, 1999, 2505, 485, 7011, 13369, 7159, 0 };
            const std::uint32_t dim5255JoeKuoD6Init[]   =   { 1, 3, 3, 11, 27, 53, 109, 179, 399, 657, 697, 421, 5467, 4273, 7837, 11631, 0 };
            const std::uint32_t dim5256JoeKuoD6Init[]   =   { 1, 1, 1, 15, 1, 57, 91, 199, 443, 569, 1945, 2531, 6349, 4851, 3931, 20537, 0 };
            const std::uint32_t dim5257JoeKuoD6Init[]   =   { 1, 1, 3, 13, 3, 3, 107, 237, 261, 377, 135, 2809, 7239, 1613, 24035, 26053, 0 };
            const std::uint32_t dim5258JoeKuoD6Init[]   =   { 1, 3, 3, 5, 3, 59, 65, 197, 411, 363, 1729, 967, 3963, 4535, 111, 7273, 0 };
            const std::uint32_t dim5259JoeKuoD6Init[]   =   { 1, 1, 7, 3, 13, 39, 105, 235, 203, 1015, 1031, 3127, 1209, 10817, 22177, 44117, 0 };
            const std::uint32_t dim5260JoeKuoD6Init[]   =   { 1, 3, 3, 13, 19, 21, 123, 31, 59, 185, 1007, 1115, 1965, 13087, 18489, 34063, 0 };
            const std::uint32_t dim5261JoeKuoD6Init[]   =   { 1, 1, 7, 5, 27, 7, 33, 159, 245, 57, 2003, 3229, 2095, 4939, 31355, 23121, 0 };
            const std::uint32_t dim5262JoeKuoD6Init[]   =   { 1, 3, 3, 9, 9, 41, 49, 203, 397, 915, 821, 3685, 2269, 11159, 25441, 46377, 0 };
            const std::uint32_t dim5263JoeKuoD6Init[]   =   { 1, 3, 7, 5, 29, 33, 29, 227, 361, 961, 1905, 1149, 2799, 8115, 28235, 25685, 0 };
            const std::uint32_t dim5264JoeKuoD6Init[]   =   { 1, 3, 1, 1, 19, 13, 73, 103, 11, 183, 853, 2425, 3809, 2391, 18615, 32735, 0 };
            const std::uint32_t dim5265JoeKuoD6Init[]   =   { 1, 1, 3, 3, 21, 57, 47, 57, 157, 43, 1085, 3319, 461, 11499, 6809, 10435, 0 };
            const std::uint32_t dim5266JoeKuoD6Init[]   =   { 1, 1, 5, 5, 17, 21, 55, 17, 421, 865, 159, 1643, 4523, 1485, 11937, 8287, 0 };
            const std::uint32_t dim5267JoeKuoD6Init[]   =   { 1, 1, 3, 11, 7, 43, 39, 37, 187, 797, 1273, 1227, 2683, 1249, 3375, 44499, 0 };
            const std::uint32_t dim5268JoeKuoD6Init[]   =   { 1, 1, 5, 11, 17, 35, 27, 73, 97, 59, 921, 2171, 7577, 2847, 93, 35911, 0 };
            const std::uint32_t dim5269JoeKuoD6Init[]   =   { 1, 1, 5, 1, 5, 17, 117, 189, 357, 581, 1945, 2141, 1679, 12019, 11249, 6809, 0 };
            const std::uint32_t dim5270JoeKuoD6Init[]   =   { 1, 1, 5, 7, 15, 53, 9, 191, 153, 257, 533, 493, 2389, 4657, 20757, 57275, 0 };
            const std::uint32_t dim5271JoeKuoD6Init[]   =   { 1, 1, 1, 11, 13, 35, 85, 37, 501, 525, 543, 4057, 2001, 6183, 949, 18465, 0 };
            const std::uint32_t dim5272JoeKuoD6Init[]   =   { 1, 1, 1, 3, 15, 7, 39, 169, 359, 671, 731, 1523, 211, 1233, 29515, 57787, 0 };
            const std::uint32_t dim5273JoeKuoD6Init[]   =   { 1, 1, 3, 7, 27, 7, 41, 15, 71, 733, 1919, 401, 1915, 4815, 10571, 839, 0 };
            const std::uint32_t dim5274JoeKuoD6Init[]   =   { 1, 1, 7, 13, 27, 61, 5, 25, 293, 779, 477, 1537, 6695, 7435, 1281, 64369, 0 };
            const std::uint32_t dim5275JoeKuoD6Init[]   =   { 1, 1, 7, 7, 19, 11, 101, 45, 449, 883, 1181, 3521, 6019, 16305, 23429, 43789, 0 };
            const std::uint32_t dim5276JoeKuoD6Init[]   =   { 1, 1, 7, 5, 1, 49, 121, 89, 275, 367, 461, 1717, 2733, 4403, 9123, 35217, 0 };
            const std::uint32_t dim5277JoeKuoD6Init[]   =   { 1, 1, 7, 1, 1, 37, 41, 221, 281, 531, 357, 3783, 3561, 8135, 18405, 56045, 0 };
            const std::uint32_t dim5278JoeKuoD6Init[]   =   { 1, 3, 5, 7, 29, 9, 127, 37, 13, 519, 1059, 3973, 7253, 15159, 19337, 57103, 0 };
            const std::uint32_t dim5279JoeKuoD6Init[]   =   { 1, 3, 3, 15, 3, 41, 91, 7, 63, 747, 1649, 3367, 5945, 3603, 28465, 511, 0 };
            const std::uint32_t dim5280JoeKuoD6Init[]   =   { 1, 3, 3, 15, 27, 19, 67, 179, 505, 131, 149, 1753, 3603, 1135, 15811, 5305, 0 };
            const std::uint32_t dim5281JoeKuoD6Init[]   =   { 1, 1, 1, 5, 5, 63, 71, 235, 151, 651, 1383, 249, 3223, 14559, 26809, 4551, 0 };
            const std::uint32_t dim5282JoeKuoD6Init[]   =   { 1, 3, 3, 9, 29, 41, 67, 111, 175, 515, 1123, 1707, 6653, 8233, 22775, 61029, 0 };
            const std::uint32_t dim5283JoeKuoD6Init[]   =   { 1, 3, 3, 9, 23, 1, 75, 145, 159, 785, 537, 1995, 2241, 8641, 30709, 41373, 0 };
            const std::uint32_t dim5284JoeKuoD6Init[]   =   { 1, 1, 5, 9, 21, 1, 87, 233, 401, 643, 197, 3437, 8163, 6363, 6537, 17283, 0 };
            const std::uint32_t dim5285JoeKuoD6Init[]   =   { 1, 3, 5, 3, 23, 19, 55, 243, 405, 369, 1221, 1959, 5455, 11729, 26117, 9097, 0 };
            const std::uint32_t dim5286JoeKuoD6Init[]   =   { 1, 1, 3, 13, 3, 57, 71, 235, 125, 263, 873, 1079, 2627, 1343, 1979, 49519, 0 };
            const std::uint32_t dim5287JoeKuoD6Init[]   =   { 1, 3, 1, 11, 21, 15, 27, 7, 425, 935, 305, 2593, 4437, 9517, 26207, 4229, 0 };
            const std::uint32_t dim5288JoeKuoD6Init[]   =   { 1, 1, 3, 13, 11, 53, 1, 149, 97, 939, 147, 3365, 5023, 607, 2083, 8715, 0 };
            const std::uint32_t dim5289JoeKuoD6Init[]   =   { 1, 1, 5, 3, 13, 13, 113, 51, 263, 837, 1145, 3621, 5697, 2867, 7975, 22839, 0 };
            const std::uint32_t dim5290JoeKuoD6Init[]   =   { 1, 1, 3, 15, 31, 9, 91, 231, 399, 295, 1935, 4021, 7669, 3867, 28015, 9865, 0 };
            const std::uint32_t dim5291JoeKuoD6Init[]   =   { 1, 1, 1, 1, 13, 59, 51, 35, 407, 733, 1629, 2429, 291, 11923, 32129, 28847, 0 };
            const std::uint32_t dim5292JoeKuoD6Init[]   =   { 1, 3, 3, 11, 25, 21, 13, 117, 31, 547, 327, 2801, 2247, 4051, 27523, 4257, 0 };
            const std::uint32_t dim5293JoeKuoD6Init[]   =   { 1, 1, 7, 7, 15, 33, 15, 17, 255, 363, 1013, 1463, 7537, 14093, 21883, 35389, 0 };
            const std::uint32_t dim5294JoeKuoD6Init[]   =   { 1, 1, 5, 9, 11, 61, 7, 161, 121, 413, 515, 413, 4439, 15405, 30265, 23939, 0 };
            const std::uint32_t dim5295JoeKuoD6Init[]   =   { 1, 3, 7, 7, 11, 15, 5, 181, 315, 231, 1567, 2985, 1653, 12251, 269, 37317, 0 };
            const std::uint32_t dim5296JoeKuoD6Init[]   =   { 1, 3, 1, 11, 3, 15, 91, 45, 489, 571, 11, 1239, 7705, 4303, 12535, 21359, 0 };
            const std::uint32_t dim5297JoeKuoD6Init[]   =   { 1, 1, 7, 15, 29, 43, 81, 63, 483, 851, 389, 1719, 6111, 15293, 2513, 44397, 0 };
            const std::uint32_t dim5298JoeKuoD6Init[]   =   { 1, 1, 5, 15, 25, 33, 97, 131, 183, 269, 1903, 2733, 7197, 4507, 24471, 36871, 0 };
            const std::uint32_t dim5299JoeKuoD6Init[]   =   { 1, 3, 3, 13, 17, 33, 73, 83, 247, 207, 79, 1139, 581, 12147, 3539, 45423, 0 };
            const std::uint32_t dim5300JoeKuoD6Init[]   =   { 1, 1, 1, 15, 29, 49, 79, 151, 267, 393, 1995, 105, 2873, 3981, 19147, 53987, 0 };
            const std::uint32_t dim5301JoeKuoD6Init[]   =   { 1, 1, 5, 1, 31, 25, 39, 203, 459, 181, 661, 717, 6235, 13413, 1197, 40665, 0 };
            const std::uint32_t dim5302JoeKuoD6Init[]   =   { 1, 1, 5, 9, 19, 33, 65, 239, 463, 133, 461, 3601, 7755, 1771, 20683, 7417, 0 };
            const std::uint32_t dim5303JoeKuoD6Init[]   =   { 1, 1, 1, 1, 25, 19, 25, 155, 431, 33, 341, 959, 5679, 1205, 2599, 37499, 0 };
            const std::uint32_t dim5304JoeKuoD6Init[]   =   { 1, 1, 3, 5, 25, 5, 83, 87, 91, 991, 1833, 4063, 147, 14497, 25725, 4617, 0 };
            const std::uint32_t dim5305JoeKuoD6Init[]   =   { 1, 3, 5, 7, 31, 7, 73, 51, 339, 313, 1593, 2089, 7387, 15759, 3249, 7953, 0 };
            const std::uint32_t dim5306JoeKuoD6Init[]   =   { 1, 3, 7, 1, 27, 49, 35, 11, 21, 45, 1689, 1665, 4591, 3713, 12781, 4805, 0 };
            const std::uint32_t dim5307JoeKuoD6Init[]   =   { 1, 1, 3, 9, 29, 51, 73, 51, 303, 179, 67, 3917, 7615, 6131, 26225, 55991, 0 };
            const std::uint32_t dim5308JoeKuoD6Init[]   =   { 1, 3, 7, 11, 9, 63, 29, 47, 153, 883, 1859, 1913, 3563, 11451, 6333, 51367, 0 };
            const std::uint32_t dim5309JoeKuoD6Init[]   =   { 1, 3, 1, 3, 5, 25, 69, 87, 389, 613, 989, 3557, 1339, 12503, 14505, 63209, 0 };
            const std::uint32_t dim5310JoeKuoD6Init[]   =   { 1, 1, 3, 1, 5, 13, 37, 163, 499, 163, 2025, 1467, 5059, 8479, 2889, 62957, 0 };
            const std::uint32_t dim5311JoeKuoD6Init[]   =   { 1, 1, 7, 9, 23, 31, 109, 49, 73, 197, 337, 2763, 4789, 8983, 9691, 32155, 0 };
            const std::uint32_t dim5312JoeKuoD6Init[]   =   { 1, 3, 1, 3, 31, 25, 121, 91, 371, 339, 833, 2217, 4997, 9425, 10685, 60037, 0 };
            const std::uint32_t dim5313JoeKuoD6Init[]   =   { 1, 1, 7, 11, 31, 3, 105, 125, 255, 175, 803, 1787, 6231, 4441, 5031, 29737, 0 };
            const std::uint32_t dim5314JoeKuoD6Init[]   =   { 1, 1, 1, 11, 21, 63, 75, 209, 393, 437, 495, 2397, 4759, 15703, 29869, 62685, 0 };
            const std::uint32_t dim5315JoeKuoD6Init[]   =   { 1, 1, 7, 7, 25, 33, 117, 7, 293, 623, 2001, 2409, 2487, 14803, 3329, 38277, 0 };
            const std::uint32_t dim5316JoeKuoD6Init[]   =   { 1, 1, 7, 9, 31, 51, 75, 151, 487, 85, 639, 3529, 4491, 1957, 22099, 20263, 0 };
            const std::uint32_t dim5317JoeKuoD6Init[]   =   { 1, 1, 7, 5, 3, 29, 11, 1, 255, 555, 1269, 779, 1525, 7689, 25847, 39347, 0 };
            const std::uint32_t dim5318JoeKuoD6Init[]   =   { 1, 1, 7, 7, 19, 21, 9, 123, 3, 943, 1627, 2979, 919, 4565, 31435, 59789, 0 };
            const std::uint32_t dim5319JoeKuoD6Init[]   =   { 1, 3, 7, 5, 29, 13, 57, 221, 9, 893, 1685, 1879, 4575, 7369, 26191, 6067, 0 };
            const std::uint32_t dim5320JoeKuoD6Init[]   =   { 1, 3, 7, 9, 13, 11, 9, 27, 313, 751, 1377, 1121, 3799, 1673, 16305, 30665, 0 };
            const std::uint32_t dim5321JoeKuoD6Init[]   =   { 1, 3, 3, 13, 23, 17, 59, 47, 499, 525, 681, 3195, 1611, 7003, 7325, 53019, 0 };
            const std::uint32_t dim5322JoeKuoD6Init[]   =   { 1, 3, 1, 7, 23, 51, 59, 127, 67, 263, 1305, 2479, 637, 9441, 6329, 12857, 0 };
            const std::uint32_t dim5323JoeKuoD6Init[]   =   { 1, 1, 7, 7, 9, 3, 51, 193, 205, 503, 19, 2513, 7489, 9241, 15371, 20875, 0 };
            const std::uint32_t dim5324JoeKuoD6Init[]   =   { 1, 3, 3, 1, 1, 57, 17, 181, 23, 549, 769, 2325, 3669, 7017, 25601, 64479, 0 };
            const std::uint32_t dim5325JoeKuoD6Init[]   =   { 1, 3, 1, 15, 5, 55, 53, 13, 327, 447, 1031, 1599, 3639, 15305, 1387, 16035, 0 };
            const std::uint32_t dim5326JoeKuoD6Init[]   =   { 1, 3, 7, 15, 9, 41, 53, 113, 97, 99, 1377, 4047, 3713, 8891, 5601, 5853, 0 };
            const std::uint32_t dim5327JoeKuoD6Init[]   =   { 1, 1, 7, 9, 9, 7, 29, 249, 411, 315, 181, 2153, 6135, 6947, 27595, 15553, 0 };
            const std::uint32_t dim5328JoeKuoD6Init[]   =   { 1, 1, 7, 11, 3, 57, 35, 55, 165, 313, 577, 3049, 4259, 4231, 7225, 58973, 0 };
            const std::uint32_t dim5329JoeKuoD6Init[]   =   { 1, 1, 1, 1, 15, 43, 53, 143, 157, 843, 465, 3897, 4797, 12305, 28807, 46381, 0 };
            const std::uint32_t dim5330JoeKuoD6Init[]   =   { 1, 3, 7, 9, 17, 3, 99, 61, 475, 507, 831, 2207, 367, 27, 23205, 2303, 0 };
            const std::uint32_t dim5331JoeKuoD6Init[]   =   { 1, 1, 3, 11, 27, 29, 99, 237, 43, 955, 361, 3231, 1863, 7973, 8969, 58663, 0 };
            const std::uint32_t dim5332JoeKuoD6Init[]   =   { 1, 3, 1, 7, 15, 15, 11, 251, 135, 261, 675, 3723, 7675, 7993, 1725, 41149, 0 };
            const std::uint32_t dim5333JoeKuoD6Init[]   =   { 1, 3, 3, 9, 29, 11, 105, 37, 151, 215, 1911, 4051, 5427, 11019, 9073, 33129, 0 };
            const std::uint32_t dim5334JoeKuoD6Init[]   =   { 1, 3, 3, 1, 19, 7, 103, 81, 371, 253, 1043, 1231, 6497, 10377, 2349, 29047, 0 };
            const std::uint32_t dim5335JoeKuoD6Init[]   =   { 1, 3, 7, 9, 15, 11, 85, 61, 507, 629, 811, 3883, 1435, 13035, 31913, 2153, 0 };
            const std::uint32_t dim5336JoeKuoD6Init[]   =   { 1, 1, 5, 11, 13, 7, 63, 147, 117, 223, 1217, 3317, 3275, 6851, 2917, 55901, 0 };
            const std::uint32_t dim5337JoeKuoD6Init[]   =   { 1, 3, 3, 9, 7, 21, 1, 63, 117, 297, 405, 797, 337, 10173, 8327, 29157, 0 };
            const std::uint32_t dim5338JoeKuoD6Init[]   =   { 1, 1, 7, 11, 31, 63, 97, 191, 259, 421, 1829, 2117, 4203, 11919, 18001, 55791, 0 };
            const std::uint32_t dim5339JoeKuoD6Init[]   =   { 1, 3, 7, 9, 21, 13, 125, 247, 133, 611, 463, 227, 7815, 8877, 17961, 3641, 0 };
            const std::uint32_t dim5340JoeKuoD6Init[]   =   { 1, 1, 7, 9, 27, 21, 97, 165, 371, 715, 491, 3929, 3067, 12501, 5511, 18217, 0 };
            const std::uint32_t dim5341JoeKuoD6Init[]   =   { 1, 3, 3, 15, 27, 17, 81, 161, 263, 273, 135, 1159, 7535, 4581, 16065, 11493, 0 };
            const std::uint32_t dim5342JoeKuoD6Init[]   =   { 1, 3, 3, 7, 11, 59, 111, 47, 381, 413, 243, 2173, 4957, 2451, 15669, 22071, 0 };
            const std::uint32_t dim5343JoeKuoD6Init[]   =   { 1, 3, 7, 5, 3, 31, 65, 131, 111, 141, 1891, 2983, 3331, 769, 24075, 40865, 0 };
            const std::uint32_t dim5344JoeKuoD6Init[]   =   { 1, 3, 7, 11, 11, 63, 7, 213, 333, 111, 1235, 961, 3749, 9123, 5067, 9657, 0 };
            const std::uint32_t dim5345JoeKuoD6Init[]   =   { 1, 3, 3, 1, 9, 33, 1, 225, 37, 951, 1995, 3215, 3117, 3723, 15013, 64525, 0 };
            const std::uint32_t dim5346JoeKuoD6Init[]   =   { 1, 3, 3, 13, 29, 19, 103, 65, 67, 423, 1679, 3791, 5551, 11711, 195, 52291, 0 };
            const std::uint32_t dim5347JoeKuoD6Init[]   =   { 1, 3, 1, 15, 31, 7, 65, 249, 489, 287, 1385, 1075, 1357, 13593, 20853, 46221, 0 };
            const std::uint32_t dim5348JoeKuoD6Init[]   =   { 1, 1, 1, 13, 23, 45, 29, 175, 147, 101, 1007, 1867, 5387, 12683, 29609, 55861, 0 };
            const std::uint32_t dim5349JoeKuoD6Init[]   =   { 1, 3, 5, 13, 21, 31, 85, 187, 183, 179, 1337, 481, 71, 6117, 2177, 27915, 0 };
            const std::uint32_t dim5350JoeKuoD6Init[]   =   { 1, 3, 5, 1, 15, 5, 11, 141, 205, 177, 891, 3591, 4371, 889, 12957, 61083, 0 };
            const std::uint32_t dim5351JoeKuoD6Init[]   =   { 1, 3, 7, 7, 11, 39, 81, 241, 13, 757, 521, 3029, 2345, 12385, 20683, 64053, 0 };
            const std::uint32_t dim5352JoeKuoD6Init[]   =   { 1, 1, 5, 13, 7, 3, 77, 211, 215, 97, 1409, 1021, 1267, 4785, 27231, 2877, 0 };
            const std::uint32_t dim5353JoeKuoD6Init[]   =   { 1, 3, 5, 3, 11, 57, 93, 39, 415, 179, 1033, 3267, 5383, 10451, 27117, 10711, 0 };
            const std::uint32_t dim5354JoeKuoD6Init[]   =   { 1, 1, 1, 1, 3, 45, 93, 179, 453, 995, 1423, 3849, 4381, 15789, 20789, 18775, 0 };
            const std::uint32_t dim5355JoeKuoD6Init[]   =   { 1, 3, 1, 3, 13, 25, 33, 165, 351, 887, 1109, 195, 8131, 3061, 16743, 22997, 0 };
            const std::uint32_t dim5356JoeKuoD6Init[]   =   { 1, 3, 1, 5, 23, 35, 93, 155, 333, 603, 1571, 229, 2979, 6295, 20793, 40901, 0 };
            const std::uint32_t dim5357JoeKuoD6Init[]   =   { 1, 3, 3, 11, 29, 57, 101, 61, 487, 719, 1009, 1933, 7815, 15329, 12489, 26105, 0 };
            const std::uint32_t dim5358JoeKuoD6Init[]   =   { 1, 3, 3, 9, 23, 59, 73, 13, 141, 815, 1819, 3557, 2555, 5901, 23039, 62321, 0 };
            const std::uint32_t dim5359JoeKuoD6Init[]   =   { 1, 1, 3, 5, 19, 49, 27, 139, 35, 995, 565, 323, 6439, 15679, 27017, 30889, 0 };
            const std::uint32_t dim5360JoeKuoD6Init[]   =   { 1, 3, 7, 3, 1, 3, 27, 153, 235, 59, 989, 2763, 4197, 3931, 31227, 27129, 0 };
            const std::uint32_t dim5361JoeKuoD6Init[]   =   { 1, 3, 1, 15, 23, 45, 71, 205, 465, 451, 347, 1909, 3287, 8363, 9081, 35641, 0 };
            const std::uint32_t dim5362JoeKuoD6Init[]   =   { 1, 1, 5, 1, 25, 29, 17, 201, 463, 903, 1729, 3435, 2483, 10835, 14315, 52505, 0 };
            const std::uint32_t dim5363JoeKuoD6Init[]   =   { 1, 1, 1, 15, 13, 23, 3, 175, 273, 305, 1945, 3319, 7777, 9411, 4209, 4047, 0 };
            const std::uint32_t dim5364JoeKuoD6Init[]   =   { 1, 1, 5, 15, 25, 5, 71, 35, 307, 89, 301, 3465, 1497, 13467, 21911, 13611, 0 };
            const std::uint32_t dim5365JoeKuoD6Init[]   =   { 1, 3, 1, 7, 11, 7, 33, 241, 349, 751, 633, 3281, 6733, 13833, 23605, 34307, 0 };
            const std::uint32_t dim5366JoeKuoD6Init[]   =   { 1, 1, 1, 15, 17, 27, 45, 13, 259, 843, 1207, 1735, 4063, 6259, 1751, 45107, 0 };
            const std::uint32_t dim5367JoeKuoD6Init[]   =   { 1, 1, 5, 15, 29, 51, 73, 95, 5, 31, 933, 423, 5505, 2193, 14919, 2715, 0 };
            const std::uint32_t dim5368JoeKuoD6Init[]   =   { 1, 3, 1, 3, 23, 5, 29, 7, 271, 485, 827, 1159, 77, 16337, 27933, 18741, 0 };
            const std::uint32_t dim5369JoeKuoD6Init[]   =   { 1, 3, 7, 9, 23, 33, 47, 191, 59, 301, 1277, 3745, 7837, 799, 2861, 25853, 0 };
            const std::uint32_t dim5370JoeKuoD6Init[]   =   { 1, 3, 7, 13, 13, 39, 33, 91, 279, 855, 1917, 3601, 3971, 6193, 16951, 6115, 0 };
            const std::uint32_t dim5371JoeKuoD6Init[]   =   { 1, 1, 3, 13, 15, 59, 89, 239, 313, 545, 431, 3823, 5741, 14981, 2647, 42813, 0 };
            const std::uint32_t dim5372JoeKuoD6Init[]   =   { 1, 1, 1, 3, 17, 21, 45, 37, 343, 737, 1795, 2659, 2897, 7683, 15191, 1393, 0 };
            const std::uint32_t dim5373JoeKuoD6Init[]   =   { 1, 1, 3, 3, 19, 55, 27, 201, 459, 953, 1531, 671, 5667, 11695, 149, 14605, 0 };
            const std::uint32_t dim5374JoeKuoD6Init[]   =   { 1, 3, 7, 13, 9, 63, 67, 229, 69, 819, 859, 2035, 5725, 13403, 24197, 2599, 0 };
            const std::uint32_t dim5375JoeKuoD6Init[]   =   { 1, 1, 7, 7, 1, 59, 45, 105, 327, 779, 59, 791, 7593, 8189, 28161, 13339, 0 };
            const std::uint32_t dim5376JoeKuoD6Init[]   =   { 1, 3, 3, 15, 25, 55, 125, 189, 327, 733, 115, 3541, 5227, 12143, 32719, 15785, 0 };
            const std::uint32_t dim5377JoeKuoD6Init[]   =   { 1, 3, 3, 7, 19, 51, 35, 63, 507, 89, 1441, 2369, 4927, 7953, 10193, 8331, 0 };
            const std::uint32_t dim5378JoeKuoD6Init[]   =   { 1, 1, 5, 5, 21, 1, 41, 49, 217, 1001, 1649, 2789, 5267, 1525, 3811, 40785, 0 };
            const std::uint32_t dim5379JoeKuoD6Init[]   =   { 1, 1, 7, 15, 31, 21, 33, 183, 425, 393, 367, 3253, 3047, 465, 28229, 44743, 0 };
            const std::uint32_t dim5380JoeKuoD6Init[]   =   { 1, 3, 7, 5, 1, 23, 11, 71, 269, 707, 5, 2931, 1959, 15089, 9299, 43927, 0 };
            const std::uint32_t dim5381JoeKuoD6Init[]   =   { 1, 3, 5, 15, 21, 51, 31, 15, 49, 481, 297, 3871, 751, 10661, 26401, 62923, 0 };
            const std::uint32_t dim5382JoeKuoD6Init[]   =   { 1, 3, 1, 7, 17, 27, 35, 255, 205, 865, 1659, 1921, 5457, 11633, 2825, 13549, 0 };
            const std::uint32_t dim5383JoeKuoD6Init[]   =   { 1, 1, 5, 15, 17, 35, 83, 237, 437, 7, 2001, 2225, 2601, 10841, 7953, 20651, 0 };
            const std::uint32_t dim5384JoeKuoD6Init[]   =   { 1, 1, 1, 3, 3, 37, 43, 135, 451, 203, 1319, 261, 3889, 14489, 9635, 52545, 0 };
            const std::uint32_t dim5385JoeKuoD6Init[]   =   { 1, 3, 3, 13, 15, 41, 95, 207, 43, 997, 207, 3459, 5995, 5187, 15851, 28551, 0 };
            const std::uint32_t dim5386JoeKuoD6Init[]   =   { 1, 1, 1, 5, 23, 57, 49, 101, 303, 921, 745, 1407, 7071, 2765, 18703, 32671, 0 };
            const std::uint32_t dim5387JoeKuoD6Init[]   =   { 1, 1, 7, 13, 9, 59, 65, 157, 209, 295, 107, 3175, 3401, 1197, 1875, 9033, 0 };
            const std::uint32_t dim5388JoeKuoD6Init[]   =   { 1, 1, 3, 3, 17, 9, 101, 75, 177, 905, 1013, 397, 3421, 6475, 15897, 11269, 0 };
            const std::uint32_t dim5389JoeKuoD6Init[]   =   { 1, 3, 1, 5, 29, 53, 105, 83, 383, 137, 1169, 1245, 6973, 8701, 317, 10073, 0 };
            const std::uint32_t dim5390JoeKuoD6Init[]   =   { 1, 1, 1, 3, 15, 55, 69, 219, 507, 707, 945, 397, 779, 4157, 10333, 7869, 0 };
            const std::uint32_t dim5391JoeKuoD6Init[]   =   { 1, 3, 1, 3, 9, 21, 125, 153, 107, 969, 1979, 651, 1199, 11419, 17043, 32269, 0 };
            const std::uint32_t dim5392JoeKuoD6Init[]   =   { 1, 1, 1, 7, 1, 29, 71, 127, 209, 853, 1515, 1169, 5055, 9981, 30291, 29569, 0 };
            const std::uint32_t dim5393JoeKuoD6Init[]   =   { 1, 3, 1, 11, 1, 1, 109, 251, 329, 633, 2021, 1237, 2147, 11471, 26025, 19649, 0 };
            const std::uint32_t dim5394JoeKuoD6Init[]   =   { 1, 1, 5, 1, 5, 7, 77, 175, 251, 143, 711, 1241, 2133, 9993, 9203, 24949, 0 };
            const std::uint32_t dim5395JoeKuoD6Init[]   =   { 1, 3, 5, 11, 19, 11, 101, 83, 91, 595, 753, 2389, 1887, 11569, 29759, 55785, 0 };
            const std::uint32_t dim5396JoeKuoD6Init[]   =   { 1, 1, 1, 3, 29, 47, 49, 249, 495, 451, 1887, 2547, 543, 2755, 17207, 24379, 0 };
            const std::uint32_t dim5397JoeKuoD6Init[]   =   { 1, 3, 7, 7, 19, 15, 95, 143, 109, 221, 2041, 3593, 4571, 14547, 14217, 16711, 0 };
            const std::uint32_t dim5398JoeKuoD6Init[]   =   { 1, 3, 5, 13, 27, 55, 31, 209, 39, 989, 1435, 1665, 7265, 14127, 13517, 37647, 0 };
            const std::uint32_t dim5399JoeKuoD6Init[]   =   { 1, 1, 3, 7, 1, 49, 63, 71, 249, 371, 435, 3591, 2677, 143, 28897, 38981, 0 };
            const std::uint32_t dim5400JoeKuoD6Init[]   =   { 1, 1, 7, 7, 21, 9, 53, 221, 23, 515, 1971, 3759, 3511, 10207, 12929, 42021, 0 };
            const std::uint32_t dim5401JoeKuoD6Init[]   =   { 1, 3, 1, 13, 25, 21, 3, 85, 421, 19, 663, 3219, 3541, 13021, 5765, 39623, 0 };
            const std::uint32_t dim5402JoeKuoD6Init[]   =   { 1, 3, 1, 7, 11, 5, 125, 169, 293, 715, 1111, 2965, 4815, 6047, 27207, 23093, 0 };
            const std::uint32_t dim5403JoeKuoD6Init[]   =   { 1, 1, 5, 13, 11, 15, 37, 201, 457, 551, 821, 25, 435, 14307, 25855, 1811, 0 };
            const std::uint32_t dim5404JoeKuoD6Init[]   =   { 1, 3, 3, 9, 27, 15, 1, 253, 217, 549, 1013, 2277, 4171, 3813, 19857, 8641, 0 };
            const std::uint32_t dim5405JoeKuoD6Init[]   =   { 1, 3, 5, 5, 29, 37, 71, 49, 163, 949, 425, 2459, 945, 13125, 13981, 21669, 0 };
            const std::uint32_t dim5406JoeKuoD6Init[]   =   { 1, 3, 3, 9, 17, 23, 53, 235, 83, 887, 439, 1939, 7601, 15275, 15739, 17623, 0 };
            const std::uint32_t dim5407JoeKuoD6Init[]   =   { 1, 3, 5, 13, 7, 51, 73, 67, 167, 849, 2021, 2977, 6591, 3721, 5827, 40897, 0 };
            const std::uint32_t dim5408JoeKuoD6Init[]   =   { 1, 1, 5, 11, 27, 19, 81, 181, 383, 23, 1061, 3327, 1671, 7113, 7435, 17591, 0 };
            const std::uint32_t dim5409JoeKuoD6Init[]   =   { 1, 3, 3, 7, 25, 33, 73, 23, 103, 821, 917, 1425, 4739, 7227, 12365, 29509, 0 };
            const std::uint32_t dim5410JoeKuoD6Init[]   =   { 1, 1, 1, 7, 3, 37, 81, 231, 135, 663, 1983, 399, 6881, 14991, 4957, 20913, 0 };
            const std::uint32_t dim5411JoeKuoD6Init[]   =   { 1, 3, 7, 15, 25, 41, 65, 215, 301, 471, 1669, 65, 227, 9307, 29867, 9503, 0 };
            const std::uint32_t dim5412JoeKuoD6Init[]   =   { 1, 1, 7, 3, 25, 47, 31, 63, 53, 995, 33, 1297, 3423, 12301, 16255, 14467, 0 };
            const std::uint32_t dim5413JoeKuoD6Init[]   =   { 1, 3, 1, 1, 31, 25, 79, 131, 353, 169, 1425, 2257, 2631, 1559, 793, 48383, 0 };
            const std::uint32_t dim5414JoeKuoD6Init[]   =   { 1, 3, 3, 5, 31, 9, 93, 35, 503, 243, 595, 2939, 771, 7333, 13429, 59457, 0 };
            const std::uint32_t dim5415JoeKuoD6Init[]   =   { 1, 3, 1, 7, 5, 51, 21, 237, 453, 743, 775, 2207, 453, 12077, 12283, 9735, 0 };
            const std::uint32_t dim5416JoeKuoD6Init[]   =   { 1, 3, 1, 15, 5, 47, 59, 239, 87, 97, 885, 3191, 2547, 13227, 7433, 4989, 0 };
            const std::uint32_t dim5417JoeKuoD6Init[]   =   { 1, 3, 5, 15, 21, 33, 41, 155, 509, 317, 517, 1101, 133, 1897, 8235, 57673, 0 };
            const std::uint32_t dim5418JoeKuoD6Init[]   =   { 1, 1, 5, 15, 7, 9, 59, 155, 415, 831, 1173, 1263, 5451, 7181, 7233, 51483, 0 };
            const std::uint32_t dim5419JoeKuoD6Init[]   =   { 1, 1, 7, 3, 31, 43, 71, 39, 155, 529, 895, 827, 3203, 4625, 32185, 53507, 0 };
            const std::uint32_t dim5420JoeKuoD6Init[]   =   { 1, 3, 1, 11, 15, 17, 85, 141, 277, 439, 1775, 4015, 4457, 281, 22455, 47591, 0 };
            const std::uint32_t dim5421JoeKuoD6Init[]   =   { 1, 3, 5, 11, 25, 41, 93, 39, 51, 655, 1347, 3109, 2479, 9057, 18939, 26217, 0 };
            const std::uint32_t dim5422JoeKuoD6Init[]   =   { 1, 3, 3, 11, 31, 41, 7, 189, 241, 443, 65, 1723, 4817, 13405, 9641, 63965, 0 };
            const std::uint32_t dim5423JoeKuoD6Init[]   =   { 1, 1, 5, 3, 19, 29, 111, 11, 399, 277, 425, 1331, 5365, 14521, 16449, 29411, 0 };
            const std::uint32_t dim5424JoeKuoD6Init[]   =   { 1, 1, 3, 9, 25, 53, 91, 175, 481, 307, 1025, 71, 7425, 10667, 4053, 25605, 0 };
            const std::uint32_t dim5425JoeKuoD6Init[]   =   { 1, 3, 7, 7, 3, 13, 75, 175, 467, 363, 1889, 1759, 1155, 5511, 13047, 39637, 0 };
            const std::uint32_t dim5426JoeKuoD6Init[]   =   { 1, 3, 7, 9, 5, 21, 65, 43, 223, 97, 835, 2253, 3313, 9817, 23015, 55365, 0 };
            const std::uint32_t dim5427JoeKuoD6Init[]   =   { 1, 1, 1, 13, 9, 63, 95, 61, 417, 713, 1469, 1815, 795, 13609, 1567, 33535, 0 };
            const std::uint32_t dim5428JoeKuoD6Init[]   =   { 1, 3, 7, 1, 25, 45, 41, 27, 53, 407, 1633, 1317, 6267, 3293, 8899, 45235, 0 };
            const std::uint32_t dim5429JoeKuoD6Init[]   =   { 1, 3, 5, 11, 23, 47, 91, 211, 41, 775, 1301, 1407, 7931, 4491, 7579, 62321, 0 };
            const std::uint32_t dim5430JoeKuoD6Init[]   =   { 1, 1, 1, 7, 23, 15, 57, 31, 437, 293, 1999, 2589, 5453, 2519, 15533, 26949, 0 };
            const std::uint32_t dim5431JoeKuoD6Init[]   =   { 1, 3, 1, 9, 1, 27, 41, 165, 129, 297, 1887, 1171, 201, 5817, 24503, 38911, 0 };
            const std::uint32_t dim5432JoeKuoD6Init[]   =   { 1, 3, 1, 7, 1, 11, 63, 225, 191, 623, 1281, 3275, 167, 14697, 4905, 47289, 0 };
            const std::uint32_t dim5433JoeKuoD6Init[]   =   { 1, 3, 7, 7, 15, 47, 87, 177, 303, 391, 355, 3997, 7557, 6201, 20531, 22483, 0 };
            const std::uint32_t dim5434JoeKuoD6Init[]   =   { 1, 3, 3, 15, 17, 31, 111, 87, 61, 477, 1581, 3787, 5919, 10511, 2607, 62951, 0 };
            const std::uint32_t dim5435JoeKuoD6Init[]   =   { 1, 3, 3, 9, 29, 19, 63, 27, 205, 915, 1131, 3821, 673, 2875, 12703, 14367, 0 };
            const std::uint32_t dim5436JoeKuoD6Init[]   =   { 1, 3, 7, 1, 21, 19, 25, 97, 281, 635, 629, 181, 5207, 11133, 3687, 3489, 0 };
            const std::uint32_t dim5437JoeKuoD6Init[]   =   { 1, 3, 3, 9, 5, 63, 3, 21, 385, 713, 1805, 3583, 2807, 15455, 13057, 39771, 0 };
            const std::uint32_t dim5438JoeKuoD6Init[]   =   { 1, 3, 5, 9, 3, 59, 1, 253, 123, 405, 575, 3911, 4609, 11869, 23593, 947, 0 };
            const std::uint32_t dim5439JoeKuoD6Init[]   =   { 1, 1, 7, 5, 21, 27, 101, 221, 413, 153, 1647, 3637, 803, 5697, 20761, 61137, 0 };
            const std::uint32_t dim5440JoeKuoD6Init[]   =   { 1, 3, 7, 13, 31, 35, 111, 253, 187, 499, 465, 157, 5551, 10417, 323, 34913, 0 };
            const std::uint32_t dim5441JoeKuoD6Init[]   =   { 1, 1, 1, 7, 11, 41, 29, 65, 393, 69, 1373, 2291, 7807, 13159, 13735, 31001, 0 };
            const std::uint32_t dim5442JoeKuoD6Init[]   =   { 1, 3, 7, 13, 31, 49, 1, 35, 377, 11, 427, 2803, 1725, 9165, 22633, 63985, 0 };
            const std::uint32_t dim5443JoeKuoD6Init[]   =   { 1, 3, 7, 13, 3, 41, 27, 43, 269, 599, 1035, 3681, 309, 6011, 1065, 27901, 0 };
            const std::uint32_t dim5444JoeKuoD6Init[]   =   { 1, 3, 5, 13, 1, 19, 105, 143, 425, 883, 1669, 155, 189, 8573, 10759, 25507, 0 };
            const std::uint32_t dim5445JoeKuoD6Init[]   =   { 1, 3, 5, 1, 15, 37, 115, 9, 149, 79, 1733, 1045, 1849, 3289, 13957, 63171, 0 };
            const std::uint32_t dim5446JoeKuoD6Init[]   =   { 1, 1, 3, 9, 17, 27, 49, 201, 155, 901, 47, 1585, 4419, 8117, 25425, 14699, 0 };
            const std::uint32_t dim5447JoeKuoD6Init[]   =   { 1, 1, 7, 13, 19, 55, 19, 21, 427, 77, 1295, 1471, 6271, 7985, 19337, 12701, 0 };
            const std::uint32_t dim5448JoeKuoD6Init[]   =   { 1, 1, 1, 1, 11, 49, 101, 53, 175, 157, 839, 2713, 6149, 6391, 8089, 27739, 0 };
            const std::uint32_t dim5449JoeKuoD6Init[]   =   { 1, 3, 1, 1, 5, 21, 121, 199, 107, 221, 993, 1737, 409, 2545, 9287, 54605, 0 };
            const std::uint32_t dim5450JoeKuoD6Init[]   =   { 1, 1, 1, 3, 25, 25, 51, 121, 371, 861, 967, 3257, 6221, 11701, 27897, 42509, 0 };
            const std::uint32_t dim5451JoeKuoD6Init[]   =   { 1, 1, 1, 3, 17, 25, 101, 191, 313, 817, 815, 1855, 7999, 12649, 23385, 26081, 0 };
            const std::uint32_t dim5452JoeKuoD6Init[]   =   { 1, 1, 5, 1, 25, 55, 51, 237, 63, 943, 455, 619, 2381, 9773, 14575, 34205, 0 };
            const std::uint32_t dim5453JoeKuoD6Init[]   =   { 1, 3, 3, 3, 13, 49, 101, 37, 457, 727, 1009, 2389, 4841, 16303, 9599, 17773, 0 };
            const std::uint32_t dim5454JoeKuoD6Init[]   =   { 1, 1, 7, 9, 19, 59, 111, 205, 19, 229, 1755, 1169, 7767, 13335, 19669, 33269, 0 };
            const std::uint32_t dim5455JoeKuoD6Init[]   =   { 1, 3, 1, 15, 29, 1, 51, 167, 7, 415, 1295, 3165, 1241, 12859, 5531, 20083, 0 };
            const std::uint32_t dim5456JoeKuoD6Init[]   =   { 1, 1, 3, 7, 7, 51, 31, 221, 57, 643, 1461, 3951, 6237, 5757, 1907, 40471, 0 };
            const std::uint32_t dim5457JoeKuoD6Init[]   =   { 1, 3, 3, 5, 23, 39, 49, 177, 183, 117, 1379, 3803, 771, 12723, 22291, 32667, 0 };
            const std::uint32_t dim5458JoeKuoD6Init[]   =   { 1, 1, 3, 13, 27, 17, 39, 27, 313, 141, 1421, 2967, 2213, 1915, 23219, 15113, 0 };
            const std::uint32_t dim5459JoeKuoD6Init[]   =   { 1, 1, 1, 11, 5, 55, 51, 55, 389, 895, 57, 1447, 1497, 2799, 19585, 11587, 0 };
            const std::uint32_t dim5460JoeKuoD6Init[]   =   { 1, 1, 5, 13, 11, 55, 91, 77, 69, 131, 93, 1383, 3321, 10487, 15087, 8539, 0 };
            const std::uint32_t dim5461JoeKuoD6Init[]   =   { 1, 1, 3, 9, 23, 49, 107, 131, 363, 733, 1189, 3575, 7815, 10071, 20291, 7533, 0 };
            const std::uint32_t dim5462JoeKuoD6Init[]   =   { 1, 1, 3, 15, 31, 31, 73, 15, 199, 17, 761, 3271, 1419, 12985, 32717, 37317, 0 };
            const std::uint32_t dim5463JoeKuoD6Init[]   =   { 1, 3, 1, 13, 23, 9, 3, 59, 109, 729, 1321, 4023, 7041, 14445, 22205, 8993, 0 };
            const std::uint32_t dim5464JoeKuoD6Init[]   =   { 1, 1, 3, 15, 19, 43, 99, 59, 491, 479, 715, 2235, 7493, 889, 31465, 1375, 0 };
            const std::uint32_t dim5465JoeKuoD6Init[]   =   { 1, 3, 3, 15, 9, 47, 35, 115, 227, 615, 605, 1143, 5923, 10939, 9497, 24911, 0 };
            const std::uint32_t dim5466JoeKuoD6Init[]   =   { 1, 1, 3, 15, 23, 53, 111, 87, 423, 497, 85, 3525, 7341, 8885, 21543, 30083, 0 };
            const std::uint32_t dim5467JoeKuoD6Init[]   =   { 1, 1, 5, 3, 21, 5, 117, 157, 407, 743, 715, 1883, 4425, 10187, 6395, 43673, 0 };
            const std::uint32_t dim5468JoeKuoD6Init[]   =   { 1, 3, 3, 3, 31, 39, 119, 77, 269, 891, 1391, 3085, 2881, 10639, 3391, 44911, 0 };
            const std::uint32_t dim5469JoeKuoD6Init[]   =   { 1, 3, 7, 5, 7, 5, 115, 91, 5, 107, 1401, 1409, 1811, 737, 5399, 9119, 0 };
            const std::uint32_t dim5470JoeKuoD6Init[]   =   { 1, 1, 5, 9, 17, 45, 107, 15, 397, 299, 1219, 1675, 963, 10111, 31679, 13809, 0 };
            const std::uint32_t dim5471JoeKuoD6Init[]   =   { 1, 1, 3, 7, 29, 17, 43, 95, 261, 601, 1091, 3633, 1357, 13461, 16583, 12183, 0 };
            const std::uint32_t dim5472JoeKuoD6Init[]   =   { 1, 1, 5, 1, 19, 55, 5, 195, 187, 427, 421, 1717, 4223, 2943, 23147, 32985, 0 };
            const std::uint32_t dim5473JoeKuoD6Init[]   =   { 1, 3, 1, 3, 3, 23, 69, 95, 347, 273, 1223, 3061, 1587, 4707, 32415, 53991, 0 };
            const std::uint32_t dim5474JoeKuoD6Init[]   =   { 1, 1, 7, 13, 15, 13, 29, 151, 325, 949, 2029, 813, 5339, 14165, 1159, 56917, 0 };
            const std::uint32_t dim5475JoeKuoD6Init[]   =   { 1, 1, 1, 13, 9, 33, 67, 109, 215, 313, 1407, 3543, 2403, 5051, 20367, 13527, 0 };
            const std::uint32_t dim5476JoeKuoD6Init[]   =   { 1, 3, 1, 9, 5, 1, 9, 195, 497, 495, 1107, 745, 1647, 10637, 1933, 44965, 0 };
            const std::uint32_t dim5477JoeKuoD6Init[]   =   { 1, 1, 3, 9, 13, 19, 49, 183, 497, 519, 1433, 519, 4317, 2359, 10349, 63789, 0 };
            const std::uint32_t dim5478JoeKuoD6Init[]   =   { 1, 3, 5, 9, 29, 45, 55, 163, 189, 533, 275, 237, 5453, 8895, 6377, 14117, 0 };
            const std::uint32_t dim5479JoeKuoD6Init[]   =   { 1, 3, 7, 5, 25, 3, 111, 241, 139, 383, 689, 3481, 2557, 11163, 5275, 14671, 0 };
            const std::uint32_t dim5480JoeKuoD6Init[]   =   { 1, 3, 3, 9, 3, 5, 5, 141, 507, 331, 645, 1957, 5857, 2083, 24717, 11131, 0 };
            const std::uint32_t dim5481JoeKuoD6Init[]   =   { 1, 1, 5, 1, 11, 49, 113, 45, 491, 945, 1467, 3485, 6369, 15983, 14489, 12679, 0 };
            const std::uint32_t dim5482JoeKuoD6Init[]   =   { 1, 3, 7, 9, 11, 41, 77, 127, 147, 635, 1757, 587, 7423, 4233, 14875, 30531, 0 };
            const std::uint32_t dim5483JoeKuoD6Init[]   =   { 1, 3, 3, 9, 17, 29, 21, 249, 155, 441, 1443, 2093, 1967, 2117, 5815, 3857, 0 };
            const std::uint32_t dim5484JoeKuoD6Init[]   =   { 1, 3, 5, 3, 11, 55, 75, 157, 105, 507, 309, 3737, 2645, 7547, 29373, 62775, 0 };
            const std::uint32_t dim5485JoeKuoD6Init[]   =   { 1, 1, 3, 3, 11, 29, 49, 241, 21, 653, 1273, 715, 8123, 14241, 25257, 1681, 0 };
            const std::uint32_t dim5486JoeKuoD6Init[]   =   { 1, 1, 7, 5, 11, 31, 33, 215, 243, 369, 247, 3365, 4065, 9389, 32457, 58393, 0 };
            const std::uint32_t dim5487JoeKuoD6Init[]   =   { 1, 3, 5, 3, 31, 55, 51, 201, 439, 835, 1805, 25, 7987, 10611, 26893, 43663, 0 };
            const std::uint32_t dim5488JoeKuoD6Init[]   =   { 1, 1, 5, 9, 27, 51, 29, 31, 17, 163, 71, 603, 3083, 12439, 11043, 6471, 0 };
            const std::uint32_t dim5489JoeKuoD6Init[]   =   { 1, 1, 5, 7, 13, 1, 91, 109, 213, 721, 1345, 3037, 3047, 5209, 15559, 17467, 0 };
            const std::uint32_t dim5490JoeKuoD6Init[]   =   { 1, 1, 3, 9, 19, 37, 93, 185, 107, 859, 501, 3843, 1631, 4389, 2215, 52225, 0 };
            const std::uint32_t dim5491JoeKuoD6Init[]   =   { 1, 1, 3, 3, 25, 5, 119, 17, 33, 841, 997, 439, 6135, 7405, 8445, 40087, 0 };
            const std::uint32_t dim5492JoeKuoD6Init[]   =   { 1, 1, 7, 15, 19, 17, 101, 43, 423, 647, 29, 1143, 3259, 7807, 15929, 809, 0 };
            const std::uint32_t dim5493JoeKuoD6Init[]   =   { 1, 1, 7, 13, 21, 57, 83, 101, 183, 309, 171, 3173, 7919, 7263, 29403, 11055, 0 };
            const std::uint32_t dim5494JoeKuoD6Init[]   =   { 1, 1, 1, 13, 3, 1, 57, 15, 435, 713, 459, 847, 3115, 191, 19809, 43037, 0 };
            const std::uint32_t dim5495JoeKuoD6Init[]   =   { 1, 1, 7, 7, 17, 45, 91, 117, 157, 647, 121, 4091, 3611, 14169, 19883, 9069, 0 };
            const std::uint32_t dim5496JoeKuoD6Init[]   =   { 1, 1, 7, 7, 1, 47, 21, 253, 419, 157, 549, 2105, 4475, 3127, 3939, 5809, 0 };
            const std::uint32_t dim5497JoeKuoD6Init[]   =   { 1, 1, 5, 7, 15, 7, 71, 195, 87, 757, 77, 1391, 151, 12995, 26403, 17789, 0 };
            const std::uint32_t dim5498JoeKuoD6Init[]   =   { 1, 1, 1, 15, 15, 3, 79, 43, 475, 263, 1195, 2385, 5955, 7039, 15625, 19263, 0 };
            const std::uint32_t dim5499JoeKuoD6Init[]   =   { 1, 1, 5, 13, 13, 29, 5, 29, 489, 929, 2027, 2771, 6899, 14173, 13747, 1019, 0 };
            const std::uint32_t dim5500JoeKuoD6Init[]   =   { 1, 1, 7, 1, 5, 45, 37, 85, 221, 871, 627, 3445, 4853, 4243, 21651, 30201, 0 };
            const std::uint32_t dim5501JoeKuoD6Init[]   =   { 1, 3, 7, 11, 9, 49, 73, 245, 161, 321, 579, 2641, 6653, 5513, 11555, 53091, 0 };
            const std::uint32_t dim5502JoeKuoD6Init[]   =   { 1, 1, 7, 7, 25, 63, 101, 179, 497, 113, 9, 549, 5341, 6097, 13305, 52421, 0 };
            const std::uint32_t dim5503JoeKuoD6Init[]   =   { 1, 3, 3, 7, 21, 7, 89, 79, 137, 651, 189, 3025, 1403, 4559, 32611, 1857, 0 };
            const std::uint32_t dim5504JoeKuoD6Init[]   =   { 1, 3, 1, 13, 27, 55, 61, 135, 81, 195, 799, 3477, 4873, 2691, 29769, 59033, 0 };
            const std::uint32_t dim5505JoeKuoD6Init[]   =   { 1, 3, 3, 15, 29, 11, 7, 11, 151, 649, 1511, 2327, 6921, 12911, 3571, 35039, 0 };
            const std::uint32_t dim5506JoeKuoD6Init[]   =   { 1, 1, 5, 11, 25, 19, 49, 133, 455, 373, 1827, 3619, 2127, 3365, 11327, 52785, 0 };
            const std::uint32_t dim5507JoeKuoD6Init[]   =   { 1, 3, 5, 1, 9, 19, 107, 171, 205, 93, 1557, 2693, 4297, 4415, 20407, 19221, 0 };
            const std::uint32_t dim5508JoeKuoD6Init[]   =   { 1, 3, 3, 11, 15, 45, 37, 143, 61, 759, 2047, 2465, 3923, 9477, 30831, 46377, 0 };
            const std::uint32_t dim5509JoeKuoD6Init[]   =   { 1, 3, 7, 11, 17, 51, 117, 129, 77, 579, 1167, 1575, 1967, 10099, 22137, 31431, 0 };
            const std::uint32_t dim5510JoeKuoD6Init[]   =   { 1, 1, 5, 13, 31, 61, 67, 37, 49, 283, 235, 783, 7353, 5149, 12245, 18725, 0 };
            const std::uint32_t dim5511JoeKuoD6Init[]   =   { 1, 1, 5, 3, 17, 33, 35, 83, 359, 253, 1911, 913, 6481, 4635, 24223, 19693, 0 };
            const std::uint32_t dim5512JoeKuoD6Init[]   =   { 1, 1, 1, 13, 19, 15, 81, 131, 417, 969, 1911, 2829, 3097, 5333, 11175, 52269, 0 };
            const std::uint32_t dim5513JoeKuoD6Init[]   =   { 1, 3, 7, 15, 5, 39, 19, 205, 329, 83, 1473, 3259, 6409, 12297, 30557, 40917, 0 };
            const std::uint32_t dim5514JoeKuoD6Init[]   =   { 1, 3, 1, 15, 17, 33, 123, 185, 501, 299, 621, 929, 5797, 10539, 12321, 61043, 0 };
            const std::uint32_t dim5515JoeKuoD6Init[]   =   { 1, 3, 3, 1, 7, 51, 119, 19, 17, 203, 373, 2145, 2367, 9965, 28071, 50083, 0 };
            const std::uint32_t dim5516JoeKuoD6Init[]   =   { 1, 1, 1, 5, 1, 35, 43, 243, 91, 793, 1299, 2705, 7987, 1291, 10147, 17863, 0 };
            const std::uint32_t dim5517JoeKuoD6Init[]   =   { 1, 3, 5, 15, 27, 13, 99, 33, 179, 479, 897, 1113, 1639, 12321, 23987, 36219, 0 };
            const std::uint32_t dim5518JoeKuoD6Init[]   =   { 1, 1, 5, 9, 29, 41, 85, 9, 389, 583, 293, 1727, 2575, 13767, 15443, 40027, 0 };
            const std::uint32_t dim5519JoeKuoD6Init[]   =   { 1, 1, 7, 11, 29, 33, 93, 115, 51, 747, 1569, 3557, 869, 1991, 29877, 44131, 0 };
            const std::uint32_t dim5520JoeKuoD6Init[]   =   { 1, 3, 7, 7, 29, 11, 33, 137, 411, 689, 1815, 1789, 6557, 5973, 19445, 49449, 0 };
            const std::uint32_t dim5521JoeKuoD6Init[]   =   { 1, 1, 5, 1, 17, 3, 77, 55, 351, 325, 983, 3935, 819, 14127, 18893, 62553, 0 };
            const std::uint32_t dim5522JoeKuoD6Init[]   =   { 1, 3, 3, 1, 15, 33, 25, 159, 135, 385, 837, 3615, 1649, 1687, 3421, 47579, 0 };
            const std::uint32_t dim5523JoeKuoD6Init[]   =   { 1, 3, 1, 7, 17, 25, 125, 169, 469, 919, 1789, 863, 2827, 949, 21347, 10517, 0 };
            const std::uint32_t dim5524JoeKuoD6Init[]   =   { 1, 3, 1, 11, 27, 19, 45, 255, 175, 483, 1073, 3779, 611, 2809, 179, 19767, 0 };
            const std::uint32_t dim5525JoeKuoD6Init[]   =   { 1, 1, 3, 1, 21, 61, 47, 171, 179, 85, 61, 1209, 4005, 11439, 8477, 27229, 0 };
            const std::uint32_t dim5526JoeKuoD6Init[]   =   { 1, 1, 1, 1, 3, 1, 43, 159, 261, 411, 1449, 1621, 3681, 3465, 24029, 3493, 0 };
            const std::uint32_t dim5527JoeKuoD6Init[]   =   { 1, 3, 1, 11, 5, 13, 9, 23, 369, 769, 363, 3329, 409, 13151, 30269, 9621, 0 };
            const std::uint32_t dim5528JoeKuoD6Init[]   =   { 1, 1, 5, 1, 13, 39, 121, 39, 295, 981, 1151, 4039, 8179, 5007, 25527, 1249, 0 };
            const std::uint32_t dim5529JoeKuoD6Init[]   =   { 1, 3, 7, 5, 17, 21, 47, 233, 211, 349, 643, 109, 7553, 11453, 30967, 30959, 0 };
            const std::uint32_t dim5530JoeKuoD6Init[]   =   { 1, 1, 5, 3, 31, 39, 105, 137, 487, 855, 107, 1567, 2385, 2889, 25777, 33709, 0 };
            const std::uint32_t dim5531JoeKuoD6Init[]   =   { 1, 1, 1, 9, 1, 7, 9, 69, 465, 965, 355, 299, 3327, 14997, 14599, 2241, 0 };
            const std::uint32_t dim5532JoeKuoD6Init[]   =   { 1, 3, 5, 11, 5, 39, 69, 203, 367, 611, 199, 3931, 5039, 8683, 8675, 49151, 0 };
            const std::uint32_t dim5533JoeKuoD6Init[]   =   { 1, 1, 7, 13, 31, 35, 101, 213, 273, 827, 203, 2773, 4131, 1397, 15311, 62903, 0 };
            const std::uint32_t dim5534JoeKuoD6Init[]   =   { 1, 3, 7, 9, 23, 41, 33, 213, 411, 965, 563, 3035, 247, 15019, 20429, 61081, 0 };
            const std::uint32_t dim5535JoeKuoD6Init[]   =   { 1, 1, 5, 5, 5, 1, 1, 203, 27, 199, 67, 1301, 7831, 12839, 2777, 6325, 0 };
            const std::uint32_t dim5536JoeKuoD6Init[]   =   { 1, 3, 1, 11, 27, 3, 11, 173, 9, 121, 1701, 2741, 29, 16319, 15849, 11989, 0 };
            const std::uint32_t dim5537JoeKuoD6Init[]   =   { 1, 1, 5, 13, 17, 49, 125, 153, 261, 603, 1617, 3967, 6083, 7745, 19683, 49885, 0 };
            const std::uint32_t dim5538JoeKuoD6Init[]   =   { 1, 3, 3, 7, 23, 13, 39, 169, 135, 361, 579, 1443, 7615, 2389, 5669, 651, 0 };
            const std::uint32_t dim5539JoeKuoD6Init[]   =   { 1, 3, 5, 9, 31, 19, 81, 83, 483, 93, 1895, 2285, 7771, 8281, 8353, 39677, 0 };
            const std::uint32_t dim5540JoeKuoD6Init[]   =   { 1, 1, 7, 7, 23, 51, 127, 25, 101, 611, 1095, 3013, 2685, 8153, 22629, 53355, 0 };
            const std::uint32_t dim5541JoeKuoD6Init[]   =   { 1, 1, 1, 11, 11, 37, 35, 127, 317, 877, 1591, 401, 4121, 9945, 12121, 28257, 0 };
            const std::uint32_t dim5542JoeKuoD6Init[]   =   { 1, 3, 5, 11, 23, 9, 43, 135, 37, 405, 2009, 2903, 3065, 6591, 8473, 58231, 0 };
            const std::uint32_t dim5543JoeKuoD6Init[]   =   { 1, 1, 3, 11, 21, 45, 21, 205, 425, 891, 357, 2609, 495, 7541, 2161, 37853, 0 };
            const std::uint32_t dim5544JoeKuoD6Init[]   =   { 1, 3, 1, 1, 25, 9, 113, 243, 317, 491, 997, 2023, 5869, 13643, 11483, 6733, 0 };
            const std::uint32_t dim5545JoeKuoD6Init[]   =   { 1, 3, 1, 15, 13, 3, 75, 25, 409, 421, 1817, 857, 4575, 12559, 1211, 62177, 0 };
            const std::uint32_t dim5546JoeKuoD6Init[]   =   { 1, 1, 3, 7, 17, 35, 115, 195, 217, 223, 1195, 749, 5619, 7265, 7369, 46907, 0 };
            const std::uint32_t dim5547JoeKuoD6Init[]   =   { 1, 1, 1, 13, 5, 57, 117, 161, 121, 533, 987, 3959, 5047, 15213, 15811, 41841, 0 };
            const std::uint32_t dim5548JoeKuoD6Init[]   =   { 1, 3, 7, 1, 19, 55, 97, 191, 217, 75, 1881, 3351, 3737, 12179, 22875, 28767, 0 };
            const std::uint32_t dim5549JoeKuoD6Init[]   =   { 1, 3, 1, 9, 15, 41, 9, 97, 491, 31, 1191, 963, 875, 8259, 2723, 9503, 0 };
            const std::uint32_t dim5550JoeKuoD6Init[]   =   { 1, 3, 7, 9, 3, 17, 21, 71, 1, 523, 2031, 3469, 3181, 8707, 6093, 8837, 0 };
            const std::uint32_t dim5551JoeKuoD6Init[]   =   { 1, 3, 5, 3, 5, 1, 11, 91, 33, 37, 643, 85, 4325, 4293, 8351, 28311, 0 };
            const std::uint32_t dim5552JoeKuoD6Init[]   =   { 1, 3, 7, 5, 15, 45, 47, 183, 391, 113, 493, 3607, 2541, 13521, 31613, 36049, 0 };
            const std::uint32_t dim5553JoeKuoD6Init[]   =   { 1, 1, 3, 9, 15, 33, 115, 69, 289, 217, 1875, 1339, 4995, 9073, 6909, 15977, 0 };
            const std::uint32_t dim5554JoeKuoD6Init[]   =   { 1, 1, 7, 3, 9, 29, 39, 219, 119, 369, 893, 1293, 4511, 15703, 11093, 30259, 0 };
            const std::uint32_t dim5555JoeKuoD6Init[]   =   { 1, 1, 5, 13, 19, 9, 17, 75, 149, 415, 35, 97, 563, 1689, 18311, 54291, 0 };
            const std::uint32_t dim5556JoeKuoD6Init[]   =   { 1, 1, 7, 3, 17, 15, 71, 29, 25, 883, 1801, 1675, 5585, 9413, 3813, 26673, 0 };
            const std::uint32_t dim5557JoeKuoD6Init[]   =   { 1, 1, 3, 15, 5, 13, 31, 41, 311, 411, 573, 281, 8075, 7163, 11817, 29121, 0 };
            const std::uint32_t dim5558JoeKuoD6Init[]   =   { 1, 1, 7, 9, 7, 57, 15, 141, 337, 123, 269, 3737, 6455, 2539, 13655, 59809, 0 };
            const std::uint32_t dim5559JoeKuoD6Init[]   =   { 1, 3, 1, 15, 15, 23, 111, 51, 429, 483, 1567, 1317, 8057, 1609, 30181, 35687, 0 };
            const std::uint32_t dim5560JoeKuoD6Init[]   =   { 1, 3, 7, 9, 25, 43, 67, 13, 319, 587, 1827, 443, 2031, 8563, 16173, 58667, 0 };
            const std::uint32_t dim5561JoeKuoD6Init[]   =   { 1, 3, 5, 13, 11, 63, 89, 105, 377, 257, 7, 4077, 5091, 5125, 25, 39033, 0 };
            const std::uint32_t dim5562JoeKuoD6Init[]   =   { 1, 3, 3, 1, 9, 29, 7, 87, 239, 469, 1851, 1711, 5797, 7137, 11405, 20175, 0 };
            const std::uint32_t dim5563JoeKuoD6Init[]   =   { 1, 3, 3, 1, 13, 17, 101, 209, 301, 95, 1181, 3091, 4451, 1241, 17057, 335, 0 };
            const std::uint32_t dim5564JoeKuoD6Init[]   =   { 1, 1, 1, 9, 31, 7, 81, 161, 391, 677, 115, 141, 5375, 7279, 1887, 1645, 0 };
            const std::uint32_t dim5565JoeKuoD6Init[]   =   { 1, 1, 1, 11, 27, 61, 3, 195, 189, 409, 1747, 331, 2931, 9535, 1369, 47233, 0 };
            const std::uint32_t dim5566JoeKuoD6Init[]   =   { 1, 3, 5, 15, 7, 15, 105, 255, 491, 689, 97, 1131, 3459, 7147, 27541, 62307, 0 };
            const std::uint32_t dim5567JoeKuoD6Init[]   =   { 1, 3, 5, 9, 5, 23, 1, 209, 233, 717, 1919, 1835, 5073, 10403, 28979, 1945, 0 };
            const std::uint32_t dim5568JoeKuoD6Init[]   =   { 1, 1, 3, 9, 3, 35, 107, 209, 255, 447, 227, 273, 443, 9367, 24105, 34095, 0 };
            const std::uint32_t dim5569JoeKuoD6Init[]   =   { 1, 1, 3, 11, 3, 33, 5, 165, 83, 787, 1555, 31, 4351, 16301, 27453, 56739, 0 };
            const std::uint32_t dim5570JoeKuoD6Init[]   =   { 1, 1, 5, 5, 29, 9, 127, 253, 281, 487, 441, 1129, 2811, 9113, 28855, 57117, 0 };
            const std::uint32_t dim5571JoeKuoD6Init[]   =   { 1, 1, 1, 13, 13, 1, 17, 143, 121, 917, 1571, 3777, 2297, 3691, 3001, 42327, 0 };
            const std::uint32_t dim5572JoeKuoD6Init[]   =   { 1, 1, 5, 1, 25, 7, 41, 245, 241, 929, 1203, 3755, 7113, 9333, 22549, 12253, 0 };
            const std::uint32_t dim5573JoeKuoD6Init[]   =   { 1, 3, 1, 11, 1, 13, 69, 73, 285, 975, 1331, 3411, 7777, 3489, 2763, 44297, 0 };
            const std::uint32_t dim5574JoeKuoD6Init[]   =   { 1, 3, 5, 11, 3, 37, 21, 105, 153, 307, 989, 627, 3127, 6169, 10573, 22139, 0 };
            const std::uint32_t dim5575JoeKuoD6Init[]   =   { 1, 3, 5, 15, 11, 11, 39, 21, 355, 437, 547, 2283, 6443, 5561, 6367, 53899, 0 };
            const std::uint32_t dim5576JoeKuoD6Init[]   =   { 1, 1, 1, 9, 25, 51, 97, 175, 131, 207, 1367, 2561, 7455, 8289, 5877, 4383, 0 };
            const std::uint32_t dim5577JoeKuoD6Init[]   =   { 1, 3, 7, 1, 29, 17, 7, 1, 43, 831, 591, 2145, 975, 909, 23107, 43987, 0 };
            const std::uint32_t dim5578JoeKuoD6Init[]   =   { 1, 3, 5, 13, 5, 47, 65, 65, 439, 807, 271, 1615, 1873, 10905, 30537, 3337, 0 };
            const std::uint32_t dim5579JoeKuoD6Init[]   =   { 1, 1, 1, 13, 29, 1, 53, 5, 307, 347, 1059, 545, 1129, 11883, 5969, 50433, 0 };
            const std::uint32_t dim5580JoeKuoD6Init[]   =   { 1, 1, 3, 5, 31, 29, 63, 201, 255, 803, 677, 1499, 1691, 14037, 18251, 6881, 0 };
            const std::uint32_t dim5581JoeKuoD6Init[]   =   { 1, 3, 1, 5, 5, 13, 13, 121, 505, 855, 467, 2803, 3297, 4689, 18443, 60757, 0 };
            const std::uint32_t dim5582JoeKuoD6Init[]   =   { 1, 1, 5, 13, 11, 19, 11, 201, 101, 431, 693, 1267, 6909, 7759, 2265, 6125, 0 };
            const std::uint32_t dim5583JoeKuoD6Init[]   =   { 1, 1, 7, 13, 9, 3, 37, 209, 269, 27, 1041, 2587, 4667, 11077, 27009, 27967, 0 };
            const std::uint32_t dim5584JoeKuoD6Init[]   =   { 1, 1, 5, 5, 1, 5, 127, 179, 463, 949, 1525, 231, 1201, 3283, 9929, 46677, 0 };
            const std::uint32_t dim5585JoeKuoD6Init[]   =   { 1, 3, 1, 15, 9, 11, 89, 129, 331, 833, 1415, 229, 2059, 13145, 30525, 33773, 0 };
            const std::uint32_t dim5586JoeKuoD6Init[]   =   { 1, 1, 7, 15, 7, 43, 95, 177, 313, 989, 483, 825, 1885, 4535, 8213, 39835, 0 };
            const std::uint32_t dim5587JoeKuoD6Init[]   =   { 1, 1, 7, 3, 19, 27, 45, 163, 17, 523, 1565, 3753, 7433, 14117, 8499, 40177, 0 };
            const std::uint32_t dim5588JoeKuoD6Init[]   =   { 1, 3, 3, 15, 23, 45, 95, 31, 55, 469, 383, 237, 6287, 5561, 20901, 48259, 0 };
            const std::uint32_t dim5589JoeKuoD6Init[]   =   { 1, 1, 3, 1, 23, 61, 101, 185, 35, 553, 463, 1169, 2875, 12491, 14327, 47999, 0 };
            const std::uint32_t dim5590JoeKuoD6Init[]   =   { 1, 3, 3, 13, 23, 29, 77, 21, 19, 3, 769, 1943, 2081, 9135, 29767, 11367, 0 };
            const std::uint32_t dim5591JoeKuoD6Init[]   =   { 1, 1, 5, 15, 5, 11, 59, 163, 355, 993, 375, 3181, 2675, 8515, 17007, 38467, 0 };
            const std::uint32_t dim5592JoeKuoD6Init[]   =   { 1, 1, 5, 13, 19, 5, 107, 83, 123, 843, 413, 2137, 7531, 3833, 6149, 55925, 0 };
            const std::uint32_t dim5593JoeKuoD6Init[]   =   { 1, 3, 1, 13, 23, 9, 41, 145, 265, 591, 1899, 3145, 5255, 13653, 12245, 25367, 0 };
            const std::uint32_t dim5594JoeKuoD6Init[]   =   { 1, 1, 3, 15, 1, 45, 119, 79, 121, 137, 1945, 2041, 2409, 1377, 29501, 29885, 0 };
            const std::uint32_t dim5595JoeKuoD6Init[]   =   { 1, 1, 7, 11, 27, 57, 75, 183, 341, 237, 1909, 2785, 5973, 9965, 21729, 45089, 0 };
            const std::uint32_t dim5596JoeKuoD6Init[]   =   { 1, 3, 5, 7, 21, 1, 41, 189, 131, 1021, 1375, 1463, 5985, 12499, 4115, 9131, 0 };
            const std::uint32_t dim5597JoeKuoD6Init[]   =   { 1, 3, 7, 15, 21, 19, 59, 171, 339, 841, 1725, 2909, 6437, 2499, 17191, 43275, 0 };
            const std::uint32_t dim5598JoeKuoD6Init[]   =   { 1, 3, 1, 1, 15, 55, 31, 199, 351, 183, 1819, 1873, 7877, 12407, 7881, 1663, 0 };
            const std::uint32_t dim5599JoeKuoD6Init[]   =   { 1, 1, 3, 15, 1, 61, 111, 61, 115, 243, 1281, 3195, 1229, 10973, 189, 36049, 0 };
            const std::uint32_t dim5600JoeKuoD6Init[]   =   { 1, 1, 3, 15, 13, 13, 3, 49, 61, 839, 1615, 1853, 3619, 7805, 25441, 8789, 0 };
            const std::uint32_t dim5601JoeKuoD6Init[]   =   { 1, 3, 1, 9, 27, 43, 7, 193, 397, 869, 1079, 1785, 6535, 1801, 29363, 59269, 0 };
            const std::uint32_t dim5602JoeKuoD6Init[]   =   { 1, 3, 5, 5, 31, 57, 37, 53, 41, 871, 809, 1235, 1011, 12979, 8749, 52151, 0 };
            const std::uint32_t dim5603JoeKuoD6Init[]   =   { 1, 1, 7, 13, 25, 59, 69, 117, 463, 587, 513, 297, 6991, 5905, 25737, 37249, 0 };
            const std::uint32_t dim5604JoeKuoD6Init[]   =   { 1, 1, 5, 1, 27, 19, 121, 97, 349, 793, 1971, 3057, 4781, 15841, 22625, 58637, 0 };
            const std::uint32_t dim5605JoeKuoD6Init[]   =   { 1, 1, 5, 5, 25, 31, 11, 133, 411, 239, 1071, 3473, 1733, 7175, 31841, 46665, 0 };
            const std::uint32_t dim5606JoeKuoD6Init[]   =   { 1, 3, 3, 13, 19, 25, 99, 175, 271, 175, 1755, 3597, 4615, 15207, 25573, 16089, 0 };
            const std::uint32_t dim5607JoeKuoD6Init[]   =   { 1, 1, 7, 11, 17, 19, 119, 91, 505, 791, 55, 2979, 7463, 10147, 23647, 33283, 0 };
            const std::uint32_t dim5608JoeKuoD6Init[]   =   { 1, 3, 1, 1, 21, 11, 43, 173, 239, 839, 1533, 1559, 549, 15621, 22133, 46387, 0 };
            const std::uint32_t dim5609JoeKuoD6Init[]   =   { 1, 1, 3, 13, 31, 15, 73, 15, 209, 267, 701, 2899, 1163, 10093, 7727, 44211, 0 };
            const std::uint32_t dim5610JoeKuoD6Init[]   =   { 1, 3, 1, 11, 29, 21, 5, 39, 421, 375, 411, 3693, 3901, 8507, 10883, 16189, 0 };
            const std::uint32_t dim5611JoeKuoD6Init[]   =   { 1, 3, 1, 7, 13, 13, 73, 167, 149, 677, 1435, 621, 2511, 13813, 13129, 55327, 0 };
            const std::uint32_t dim5612JoeKuoD6Init[]   =   { 1, 3, 5, 15, 7, 59, 83, 221, 77, 357, 281, 2689, 5629, 5837, 1701, 30811, 0 };
            const std::uint32_t dim5613JoeKuoD6Init[]   =   { 1, 3, 3, 11, 17, 1, 43, 95, 473, 981, 1487, 1337, 905, 3307, 22357, 181, 0 };
            const std::uint32_t dim5614JoeKuoD6Init[]   =   { 1, 1, 3, 7, 1, 27, 9, 3, 489, 1, 1265, 2463, 539, 12769, 825, 6149, 0 };
            const std::uint32_t dim5615JoeKuoD6Init[]   =   { 1, 3, 3, 3, 11, 27, 81, 237, 411, 241, 1613, 931, 6397, 4325, 29651, 49003, 0 };
            const std::uint32_t dim5616JoeKuoD6Init[]   =   { 1, 3, 3, 13, 1, 19, 55, 73, 47, 203, 1661, 1245, 6847, 2457, 25427, 33069, 0 };
            const std::uint32_t dim5617JoeKuoD6Init[]   =   { 1, 3, 7, 3, 7, 47, 11, 165, 391, 457, 301, 1213, 1913, 14531, 7847, 14811, 0 };
            const std::uint32_t dim5618JoeKuoD6Init[]   =   { 1, 3, 1, 9, 1, 9, 57, 203, 15, 733, 1131, 2751, 5869, 3165, 21497, 28881, 0 };
            const std::uint32_t dim5619JoeKuoD6Init[]   =   { 1, 3, 1, 5, 9, 7, 29, 85, 71, 571, 469, 2395, 2819, 8443, 2281, 50489, 0 };
            const std::uint32_t dim5620JoeKuoD6Init[]   =   { 1, 3, 5, 11, 13, 63, 47, 47, 349, 21, 861, 2217, 2945, 6967, 6605, 16459, 0 };
            const std::uint32_t dim5621JoeKuoD6Init[]   =   { 1, 1, 7, 5, 13, 3, 41, 53, 409, 289, 1225, 2965, 5283, 1785, 14443, 51755, 0 };
            const std::uint32_t dim5622JoeKuoD6Init[]   =   { 1, 3, 7, 13, 19, 1, 29, 191, 119, 37, 697, 1909, 481, 14157, 13425, 60581, 0 };
            const std::uint32_t dim5623JoeKuoD6Init[]   =   { 1, 3, 1, 13, 1, 15, 105, 79, 505, 681, 1741, 3683, 5775, 7479, 11387, 1321, 0 };
            const std::uint32_t dim5624JoeKuoD6Init[]   =   { 1, 1, 1, 11, 9, 35, 77, 73, 351, 217, 2029, 2845, 5143, 5677, 15465, 33123, 0 };
            const std::uint32_t dim5625JoeKuoD6Init[]   =   { 1, 1, 3, 3, 19, 49, 63, 109, 335, 743, 741, 1673, 3311, 3139, 25197, 13793, 0 };
            const std::uint32_t dim5626JoeKuoD6Init[]   =   { 1, 3, 1, 3, 29, 63, 79, 1, 493, 13, 1487, 4015, 6983, 1433, 26023, 55591, 0 };
            const std::uint32_t dim5627JoeKuoD6Init[]   =   { 1, 3, 3, 11, 1, 25, 57, 207, 309, 201, 1513, 1749, 3785, 9217, 11531, 40597, 0 };
            const std::uint32_t dim5628JoeKuoD6Init[]   =   { 1, 3, 7, 13, 3, 23, 69, 253, 311, 773, 807, 1063, 745, 4843, 25221, 55885, 0 };
            const std::uint32_t dim5629JoeKuoD6Init[]   =   { 1, 1, 3, 11, 29, 47, 67, 183, 11, 259, 5, 1935, 2295, 8105, 19139, 11707, 0 };
            const std::uint32_t dim5630JoeKuoD6Init[]   =   { 1, 1, 3, 3, 23, 3, 53, 165, 255, 501, 1547, 3649, 5631, 13307, 8869, 5595, 0 };
            const std::uint32_t dim5631JoeKuoD6Init[]   =   { 1, 1, 3, 5, 7, 29, 37, 223, 289, 925, 959, 309, 1479, 3141, 18661, 52123, 0 };
            const std::uint32_t dim5632JoeKuoD6Init[]   =   { 1, 3, 1, 1, 7, 59, 101, 219, 91, 793, 1103, 1485, 7547, 12889, 19097, 15613, 0 };
            const std::uint32_t dim5633JoeKuoD6Init[]   =   { 1, 1, 5, 15, 1, 17, 79, 83, 131, 683, 1611, 1635, 5405, 9621, 29489, 4801, 0 };
            const std::uint32_t dim5634JoeKuoD6Init[]   =   { 1, 1, 5, 7, 31, 63, 59, 125, 401, 261, 1445, 33, 187, 12913, 8639, 48413, 0 };
            const std::uint32_t dim5635JoeKuoD6Init[]   =   { 1, 3, 3, 13, 27, 37, 27, 99, 379, 851, 1311, 4051, 5483, 13935, 29679, 30905, 0 };
            const std::uint32_t dim5636JoeKuoD6Init[]   =   { 1, 1, 3, 1, 7, 57, 79, 23, 97, 561, 1083, 2327, 1545, 5387, 12119, 29717, 0 };
            const std::uint32_t dim5637JoeKuoD6Init[]   =   { 1, 1, 7, 7, 9, 41, 63, 165, 315, 247, 89, 2055, 7399, 1399, 2057, 39851, 0 };
            const std::uint32_t dim5638JoeKuoD6Init[]   =   { 1, 1, 1, 15, 9, 23, 7, 15, 457, 669, 661, 3269, 915, 3475, 15845, 59769, 0 };
            const std::uint32_t dim5639JoeKuoD6Init[]   =   { 1, 3, 7, 15, 17, 53, 83, 5, 457, 103, 1297, 2413, 1095, 7711, 27935, 56357, 0 };
            const std::uint32_t dim5640JoeKuoD6Init[]   =   { 1, 1, 3, 5, 17, 3, 81, 23, 165, 341, 781, 3583, 1751, 6763, 13937, 35331, 0 };
            const std::uint32_t dim5641JoeKuoD6Init[]   =   { 1, 1, 5, 11, 31, 21, 7, 63, 369, 867, 573, 45, 2781, 4507, 21553, 51933, 0 };
            const std::uint32_t dim5642JoeKuoD6Init[]   =   { 1, 1, 5, 15, 1, 37, 85, 133, 489, 733, 1471, 2089, 979, 7723, 7339, 59595, 0 };
            const std::uint32_t dim5643JoeKuoD6Init[]   =   { 1, 1, 1, 1, 7, 3, 3, 77, 137, 1009, 481, 1343, 397, 15865, 21701, 37509, 0 };
            const std::uint32_t dim5644JoeKuoD6Init[]   =   { 1, 3, 7, 5, 17, 57, 19, 245, 249, 289, 1847, 3057, 4905, 5905, 32459, 41305, 0 };
            const std::uint32_t dim5645JoeKuoD6Init[]   =   { 1, 1, 5, 1, 23, 23, 1, 177, 115, 337, 983, 421, 3135, 6319, 27109, 59641, 0 };
            const std::uint32_t dim5646JoeKuoD6Init[]   =   { 1, 3, 1, 5, 25, 1, 63, 73, 61, 967, 1567, 2645, 7347, 11877, 28777, 38507, 0 };
            const std::uint32_t dim5647JoeKuoD6Init[]   =   { 1, 1, 3, 9, 5, 41, 39, 101, 339, 337, 1079, 3861, 5049, 5601, 14377, 34093, 0 };
            const std::uint32_t dim5648JoeKuoD6Init[]   =   { 1, 3, 7, 7, 3, 47, 95, 157, 167, 1011, 1117, 3669, 7993, 11735, 8505, 64713, 0 };
            const std::uint32_t dim5649JoeKuoD6Init[]   =   { 1, 3, 1, 9, 3, 33, 11, 33, 65, 329, 401, 2659, 2851, 3903, 29791, 41613, 0 };
            const std::uint32_t dim5650JoeKuoD6Init[]   =   { 1, 1, 1, 15, 15, 17, 9, 69, 359, 41, 1475, 1919, 5829, 2189, 21295, 33255, 0 };
            const std::uint32_t dim5651JoeKuoD6Init[]   =   { 1, 3, 1, 3, 9, 23, 73, 247, 399, 775, 419, 3033, 865, 12595, 16345, 15079, 0 };
            const std::uint32_t dim5652JoeKuoD6Init[]   =   { 1, 3, 1, 5, 1, 17, 33, 23, 419, 585, 673, 929, 6955, 10247, 12647, 29107, 0 };
            const std::uint32_t dim5653JoeKuoD6Init[]   =   { 1, 3, 3, 13, 9, 33, 11, 13, 127, 529, 1219, 2401, 6459, 14745, 5123, 53023, 0 };
            const std::uint32_t dim5654JoeKuoD6Init[]   =   { 1, 3, 5, 11, 23, 11, 5, 19, 281, 121, 1671, 2171, 4545, 10691, 24875, 28849, 0 };
            const std::uint32_t dim5655JoeKuoD6Init[]   =   { 1, 3, 1, 3, 13, 25, 85, 131, 127, 977, 1599, 3319, 3107, 3185, 4879, 3455, 0 };
            const std::uint32_t dim5656JoeKuoD6Init[]   =   { 1, 1, 5, 1, 3, 13, 77, 15, 133, 185, 1319, 727, 2181, 12175, 28017, 28023, 0 };
            const std::uint32_t dim5657JoeKuoD6Init[]   =   { 1, 3, 7, 5, 29, 51, 113, 203, 331, 847, 1, 3445, 3669, 7711, 13647, 58651, 0 };
            const std::uint32_t dim5658JoeKuoD6Init[]   =   { 1, 3, 1, 3, 31, 27, 35, 199, 491, 839, 1275, 3385, 4743, 821, 26259, 11345, 0 };
            const std::uint32_t dim5659JoeKuoD6Init[]   =   { 1, 1, 7, 9, 21, 47, 9, 67, 119, 985, 127, 1987, 5451, 6403, 26183, 8349, 0 };
            const std::uint32_t dim5660JoeKuoD6Init[]   =   { 1, 3, 5, 1, 19, 3, 91, 217, 301, 595, 1789, 735, 4993, 229, 18033, 59625, 0 };
            const std::uint32_t dim5661JoeKuoD6Init[]   =   { 1, 3, 3, 3, 11, 25, 103, 211, 117, 9, 773, 1521, 2265, 8277, 23179, 22433, 0 };
            const std::uint32_t dim5662JoeKuoD6Init[]   =   { 1, 1, 7, 9, 3, 27, 63, 255, 175, 699, 293, 2409, 3155, 285, 8663, 53503, 0 };
            const std::uint32_t dim5663JoeKuoD6Init[]   =   { 1, 1, 5, 7, 27, 23, 63, 213, 323, 697, 1541, 3497, 2985, 12389, 11155, 26217, 0 };
            const std::uint32_t dim5664JoeKuoD6Init[]   =   { 1, 3, 1, 3, 31, 7, 47, 207, 185, 873, 1063, 1055, 205, 12469, 23505, 56245, 0 };
            const std::uint32_t dim5665JoeKuoD6Init[]   =   { 1, 3, 7, 13, 31, 17, 47, 95, 91, 483, 1997, 3273, 445, 2601, 15219, 10997, 0 };
            const std::uint32_t dim5666JoeKuoD6Init[]   =   { 1, 3, 3, 5, 29, 45, 29, 83, 457, 823, 1395, 1411, 1879, 9409, 11609, 32001, 0 };
            const std::uint32_t dim5667JoeKuoD6Init[]   =   { 1, 3, 5, 11, 21, 11, 43, 73, 159, 137, 29, 1957, 815, 5077, 16127, 42199, 0 };
            const std::uint32_t dim5668JoeKuoD6Init[]   =   { 1, 3, 5, 13, 9, 59, 47, 215, 293, 807, 309, 1951, 2285, 9287, 1019, 49501, 0 };
            const std::uint32_t dim5669JoeKuoD6Init[]   =   { 1, 1, 7, 13, 31, 7, 95, 189, 233, 363, 1039, 1675, 1715, 9049, 8537, 31051, 0 };
            const std::uint32_t dim5670JoeKuoD6Init[]   =   { 1, 3, 7, 9, 23, 35, 125, 251, 107, 401, 1113, 3585, 6331, 2363, 27889, 28877, 0 };
            const std::uint32_t dim5671JoeKuoD6Init[]   =   { 1, 1, 7, 13, 9, 1, 13, 69, 257, 369, 547, 1595, 1823, 9553, 25653, 31181, 0 };
            const std::uint32_t dim5672JoeKuoD6Init[]   =   { 1, 1, 7, 11, 9, 43, 3, 93, 69, 1019, 1935, 3297, 47, 7101, 1037, 63473, 0 };
            const std::uint32_t dim5673JoeKuoD6Init[]   =   { 1, 1, 7, 5, 21, 9, 97, 105, 405, 893, 1673, 3783, 2965, 7329, 4549, 25433, 0 };
            const std::uint32_t dim5674JoeKuoD6Init[]   =   { 1, 1, 5, 13, 5, 17, 31, 123, 415, 173, 1333, 2245, 1557, 16011, 28321, 4039, 0 };
            const std::uint32_t dim5675JoeKuoD6Init[]   =   { 1, 1, 5, 9, 15, 3, 27, 79, 511, 39, 945, 49, 3231, 9199, 21327, 11183, 0 };
            const std::uint32_t dim5676JoeKuoD6Init[]   =   { 1, 3, 3, 9, 3, 15, 115, 141, 387, 341, 953, 399, 6109, 12037, 21079, 26745, 0 };
            const std::uint32_t dim5677JoeKuoD6Init[]   =   { 1, 3, 3, 1, 5, 5, 31, 195, 477, 755, 687, 3811, 805, 679, 20687, 46299, 0 };
            const std::uint32_t dim5678JoeKuoD6Init[]   =   { 1, 1, 7, 15, 1, 31, 67, 159, 205, 141, 1667, 3077, 451, 13161, 16211, 6887, 0 };
            const std::uint32_t dim5679JoeKuoD6Init[]   =   { 1, 3, 3, 1, 7, 43, 87, 5, 49, 205, 231, 3957, 2947, 13199, 15743, 4681, 0 };
            const std::uint32_t dim5680JoeKuoD6Init[]   =   { 1, 3, 3, 15, 25, 37, 95, 11, 439, 553, 59, 1241, 7407, 13467, 22403, 44441, 0 };
            const std::uint32_t dim5681JoeKuoD6Init[]   =   { 1, 1, 1, 3, 21, 3, 127, 239, 491, 139, 1411, 3417, 4247, 6247, 13809, 31609, 0 };
            const std::uint32_t dim5682JoeKuoD6Init[]   =   { 1, 1, 5, 1, 9, 13, 5, 155, 109, 593, 119, 4091, 1911, 8301, 4239, 50081, 0 };
            const std::uint32_t dim5683JoeKuoD6Init[]   =   { 1, 3, 5, 13, 27, 3, 99, 225, 253, 169, 801, 3741, 1905, 12073, 31831, 17997, 0 };
            const std::uint32_t dim5684JoeKuoD6Init[]   =   { 1, 3, 7, 15, 9, 23, 93, 171, 453, 983, 1657, 1133, 6381, 5229, 32303, 17439, 0 };
            const std::uint32_t dim5685JoeKuoD6Init[]   =   { 1, 1, 7, 11, 7, 5, 125, 141, 63, 763, 1293, 1007, 4579, 1479, 11977, 59261, 0 };
            const std::uint32_t dim5686JoeKuoD6Init[]   =   { 1, 3, 1, 7, 1, 15, 49, 41, 367, 639, 1933, 401, 2335, 2441, 13653, 55555, 0 };
            const std::uint32_t dim5687JoeKuoD6Init[]   =   { 1, 3, 1, 7, 15, 23, 5, 213, 45, 721, 543, 2133, 4525, 9719, 28053, 54075, 0 };
            const std::uint32_t dim5688JoeKuoD6Init[]   =   { 1, 3, 7, 3, 11, 7, 23, 35, 169, 829, 1957, 2423, 3583, 4951, 28957, 29753, 0 };
            const std::uint32_t dim5689JoeKuoD6Init[]   =   { 1, 1, 3, 3, 1, 5, 19, 235, 175, 969, 229, 2335, 7215, 10195, 7487, 64191, 0 };
            const std::uint32_t dim5690JoeKuoD6Init[]   =   { 1, 1, 7, 3, 27, 1, 73, 49, 445, 863, 69, 3555, 993, 9553, 31941, 29901, 0 };
            const std::uint32_t dim5691JoeKuoD6Init[]   =   { 1, 3, 5, 11, 9, 25, 59, 177, 23, 997, 1041, 1135, 3879, 767, 2263, 51267, 0 };
            const std::uint32_t dim5692JoeKuoD6Init[]   =   { 1, 1, 7, 3, 1, 63, 49, 51, 237, 569, 1293, 1143, 3125, 16315, 17009, 24821, 0 };
            const std::uint32_t dim5693JoeKuoD6Init[]   =   { 1, 3, 3, 15, 11, 17, 121, 25, 349, 833, 557, 1975, 5405, 15189, 31243, 53541, 0 };
            const std::uint32_t dim5694JoeKuoD6Init[]   =   { 1, 3, 7, 9, 11, 15, 39, 15, 75, 87, 55, 2069, 3291, 507, 16925, 57751, 0 };
            const std::uint32_t dim5695JoeKuoD6Init[]   =   { 1, 1, 3, 15, 1, 21, 61, 139, 357, 931, 647, 947, 2291, 15557, 6739, 5881, 0 };
            const std::uint32_t dim5696JoeKuoD6Init[]   =   { 1, 3, 1, 9, 1, 47, 73, 59, 115, 497, 733, 1777, 905, 16181, 4351, 7345, 0 };
            const std::uint32_t dim5697JoeKuoD6Init[]   =   { 1, 3, 3, 7, 5, 21, 67, 113, 71, 743, 757, 1851, 7899, 10315, 15437, 61803, 0 };
            const std::uint32_t dim5698JoeKuoD6Init[]   =   { 1, 3, 7, 1, 9, 23, 77, 131, 395, 767, 1229, 2629, 5731, 11907, 32217, 18473, 0 };
            const std::uint32_t dim5699JoeKuoD6Init[]   =   { 1, 3, 5, 15, 1, 23, 123, 207, 291, 565, 1211, 501, 2111, 11381, 5171, 54841, 0 };
            const std::uint32_t dim5700JoeKuoD6Init[]   =   { 1, 1, 1, 15, 21, 13, 3, 175, 405, 109, 1353, 2495, 7619, 14971, 28179, 34737, 0 };
            const std::uint32_t dim5701JoeKuoD6Init[]   =   { 1, 3, 5, 3, 17, 25, 53, 71, 229, 729, 1953, 3119, 7747, 1551, 23417, 35563, 0 };
            const std::uint32_t dim5702JoeKuoD6Init[]   =   { 1, 1, 7, 7, 11, 31, 81, 43, 149, 537, 1253, 2759, 431, 4813, 8375, 46329, 0 };
            const std::uint32_t dim5703JoeKuoD6Init[]   =   { 1, 1, 1, 5, 11, 27, 61, 199, 239, 889, 723, 2353, 5663, 7385, 28165, 14675, 0 };
            const std::uint32_t dim5704JoeKuoD6Init[]   =   { 1, 3, 1, 7, 3, 3, 83, 247, 247, 57, 579, 1163, 2615, 4051, 2809, 46413, 0 };
            const std::uint32_t dim5705JoeKuoD6Init[]   =   { 1, 1, 3, 11, 13, 47, 11, 235, 475, 35, 843, 2329, 3519, 8899, 14533, 24889, 0 };
            const std::uint32_t dim5706JoeKuoD6Init[]   =   { 1, 3, 1, 1, 7, 31, 15, 101, 327, 499, 471, 1001, 339, 11863, 24787, 47191, 0 };
            const std::uint32_t dim5707JoeKuoD6Init[]   =   { 1, 1, 7, 1, 3, 55, 93, 43, 11, 65, 289, 1249, 5325, 13867, 29841, 34333, 0 };
            const std::uint32_t dim5708JoeKuoD6Init[]   =   { 1, 3, 3, 1, 25, 61, 87, 113, 115, 265, 1007, 1129, 7633, 6109, 5733, 22649, 0 };
            const std::uint32_t dim5709JoeKuoD6Init[]   =   { 1, 3, 1, 11, 31, 59, 127, 83, 33, 419, 1037, 3777, 6383, 2711, 2113, 17233, 0 };
            const std::uint32_t dim5710JoeKuoD6Init[]   =   { 1, 1, 5, 13, 11, 17, 73, 41, 257, 223, 359, 3821, 4617, 1943, 11331, 40153, 0 };
            const std::uint32_t dim5711JoeKuoD6Init[]   =   { 1, 1, 1, 1, 9, 25, 43, 179, 17, 1021, 1323, 761, 5861, 11547, 26017, 5165, 0 };
            const std::uint32_t dim5712JoeKuoD6Init[]   =   { 1, 3, 5, 3, 29, 21, 53, 111, 213, 717, 1101, 3215, 3021, 16343, 23387, 33439, 0 };
            const std::uint32_t dim5713JoeKuoD6Init[]   =   { 1, 3, 5, 13, 29, 11, 21, 89, 107, 111, 1121, 2785, 3493, 9873, 13, 40863, 0 };
            const std::uint32_t dim5714JoeKuoD6Init[]   =   { 1, 1, 5, 13, 15, 15, 111, 219, 59, 43, 333, 3581, 1311, 2799, 23987, 21637, 0 };
            const std::uint32_t dim5715JoeKuoD6Init[]   =   { 1, 3, 1, 11, 21, 57, 115, 247, 499, 525, 1629, 3679, 2109, 6607, 27435, 1745, 71201, 0 };
            const std::uint32_t dim5716JoeKuoD6Init[]   =   { 1, 3, 3, 3, 31, 17, 113, 165, 189, 361, 103, 1775, 3001, 3865, 30591, 2873, 17129, 0 };
            const std::uint32_t dim5717JoeKuoD6Init[]   =   { 1, 1, 5, 5, 15, 47, 47, 85, 247, 471, 713, 3571, 2407, 9811, 8187, 32133, 8541, 0 };
            const std::uint32_t dim5718JoeKuoD6Init[]   =   { 1, 3, 3, 1, 15, 1, 59, 151, 469, 351, 671, 2925, 7207, 5061, 28691, 4363, 50767, 0 };
            const std::uint32_t dim5719JoeKuoD6Init[]   =   { 1, 1, 5, 7, 11, 35, 67, 45, 193, 3, 627, 3333, 6497, 12307, 28807, 13997, 108645, 0 };
            const std::uint32_t dim5720JoeKuoD6Init[]   =   { 1, 3, 1, 1, 17, 63, 125, 185, 485, 759, 717, 1993, 6707, 3993, 2181, 8173, 18057, 0 };
            const std::uint32_t dim5721JoeKuoD6Init[]   =   { 1, 1, 3, 13, 7, 15, 113, 207, 103, 191, 1895, 2595, 3873, 12021, 19259, 12553, 119119, 0 };
            const std::uint32_t dim5722JoeKuoD6Init[]   =   { 1, 3, 7, 1, 17, 11, 101, 209, 315, 9, 901, 2303, 7623, 7459, 26391, 45143, 5753, 0 };
            const std::uint32_t dim5723JoeKuoD6Init[]   =   { 1, 1, 5, 15, 1, 5, 71, 155, 167, 89, 145, 3483, 2385, 15205, 9193, 20637, 58473, 0 };
            const std::uint32_t dim5724JoeKuoD6Init[]   =   { 1, 1, 5, 7, 25, 55, 57, 51, 333, 299, 1721, 1667, 6513, 10191, 29405, 21923, 76593, 0 };
            const std::uint32_t dim5725JoeKuoD6Init[]   =   { 1, 1, 5, 1, 7, 37, 107, 91, 241, 137, 627, 2749, 5573, 11243, 26197, 4545, 105599, 0 };
            const std::uint32_t dim5726JoeKuoD6Init[]   =   { 1, 3, 1, 5, 25, 37, 73, 61, 57, 249, 1953, 1385, 6479, 3701, 10693, 617, 62535, 0 };
            const std::uint32_t dim5727JoeKuoD6Init[]   =   { 1, 1, 1, 15, 5, 63, 41, 151, 395, 681, 227, 3027, 8123, 15091, 15475, 35671, 21129, 0 };
            const std::uint32_t dim5728JoeKuoD6Init[]   =   { 1, 3, 5, 11, 29, 21, 15, 233, 103, 463, 1829, 2257, 1717, 2249, 9599, 5097, 55705, 0 };
            const std::uint32_t dim5729JoeKuoD6Init[]   =   { 1, 3, 5, 1, 29, 3, 35, 151, 193, 105, 1107, 827, 7169, 1843, 15225, 29025, 43165, 0 };
            const std::uint32_t dim5730JoeKuoD6Init[]   =   { 1, 1, 7, 15, 17, 51, 93, 199, 205, 41, 113, 1081, 1571, 11471, 11057, 16149, 66905, 0 };
            const std::uint32_t dim5731JoeKuoD6Init[]   =   { 1, 1, 3, 11, 5, 25, 107, 195, 51, 675, 1683, 3739, 1653, 611, 23249, 53157, 127785, 0 };
            const std::uint32_t dim5732JoeKuoD6Init[]   =   { 1, 1, 7, 5, 7, 3, 25, 145, 453, 735, 441, 77, 8171, 9281, 22749, 36973, 106237, 0 };
            const std::uint32_t dim5733JoeKuoD6Init[]   =   { 1, 1, 3, 13, 13, 5, 95, 33, 223, 369, 453, 2031, 3531, 6931, 8977, 54109, 115487, 0 };
            const std::uint32_t dim5734JoeKuoD6Init[]   =   { 1, 1, 7, 7, 1, 61, 33, 183, 245, 623, 529, 1831, 1867, 2845, 8311, 10143, 67897, 0 };
            const std::uint32_t dim5735JoeKuoD6Init[]   =   { 1, 3, 7, 11, 27, 23, 93, 9, 61, 451, 67, 1695, 4227, 2415, 19249, 44765, 24611, 0 };
            const std::uint32_t dim5736JoeKuoD6Init[]   =   { 1, 3, 3, 11, 29, 57, 65, 117, 349, 149, 363, 1095, 4989, 3071, 17519, 18079, 7277, 0 };
            const std::uint32_t dim5737JoeKuoD6Init[]   =   { 1, 3, 5, 9, 1, 7, 59, 87, 307, 111, 1291, 789, 7361, 6477, 11229, 36785, 33303, 0 };
            const std::uint32_t dim5738JoeKuoD6Init[]   =   { 1, 3, 5, 1, 19, 47, 53, 81, 127, 849, 1479, 1459, 1889, 15087, 22115, 20587, 121005, 0 };
            const std::uint32_t dim5739JoeKuoD6Init[]   =   { 1, 1, 7, 15, 31, 31, 71, 55, 253, 927, 277, 2087, 1313, 3721, 22729, 34709, 9821, 0 };
            const std::uint32_t dim5740JoeKuoD6Init[]   =   { 1, 3, 5, 13, 13, 63, 73, 41, 165, 315, 1907, 2005, 691, 725, 22685, 8673, 76011, 0 };
            const std::uint32_t dim5741JoeKuoD6Init[]   =   { 1, 1, 5, 9, 23, 61, 47, 167, 279, 683, 683, 1261, 4037, 15251, 9421, 45359, 38001, 0 };
            const std::uint32_t dim5742JoeKuoD6Init[]   =   { 1, 1, 7, 3, 17, 33, 69, 139, 235, 709, 1475, 2483, 7559, 8581, 23965, 31153, 5097, 0 };
            const std::uint32_t dim5743JoeKuoD6Init[]   =   { 1, 1, 7, 15, 23, 61, 43, 5, 433, 531, 761, 2749, 2881, 5225, 13491, 16479, 50203, 0 };
            const std::uint32_t dim5744JoeKuoD6Init[]   =   { 1, 1, 3, 9, 29, 7, 9, 23, 339, 315, 1723, 779, 2983, 6571, 16025, 63055, 111103, 0 };
            const std::uint32_t dim5745JoeKuoD6Init[]   =   { 1, 1, 7, 13, 23, 55, 71, 121, 297, 193, 41, 3165, 4419, 5853, 28127, 56151, 16597, 0 };
            const std::uint32_t dim5746JoeKuoD6Init[]   =   { 1, 1, 5, 7, 7, 23, 93, 11, 261, 297, 1769, 1239, 2579, 531, 4423, 7891, 21729, 0 };
            const std::uint32_t dim5747JoeKuoD6Init[]   =   { 1, 3, 5, 1, 13, 35, 83, 85, 125, 887, 161, 3311, 7261, 9557, 28975, 28643, 21479, 0 };
            const std::uint32_t dim5748JoeKuoD6Init[]   =   { 1, 3, 5, 3, 27, 5, 47, 175, 287, 867, 141, 3079, 7583, 4997, 18271, 24097, 96319, 0 };
            const std::uint32_t dim5749JoeKuoD6Init[]   =   { 1, 3, 5, 1, 21, 51, 47, 67, 211, 281, 1861, 1169, 6403, 4229, 3995, 9921, 41515, 0 };
            const std::uint32_t dim5750JoeKuoD6Init[]   =   { 1, 3, 3, 11, 23, 23, 81, 55, 441, 211, 169, 3197, 7213, 7205, 15, 11771, 129091, 0 };
            const std::uint32_t dim5751JoeKuoD6Init[]   =   { 1, 3, 7, 3, 23, 39, 23, 163, 253, 1005, 1775, 3393, 7659, 8065, 30021, 61065, 35171, 0 };
            const std::uint32_t dim5752JoeKuoD6Init[]   =   { 1, 3, 1, 1, 29, 29, 39, 143, 191, 711, 1077, 13, 4137, 15425, 11139, 1269, 71915, 0 };
            const std::uint32_t dim5753JoeKuoD6Init[]   =   { 1, 3, 3, 5, 11, 41, 101, 127, 301, 335, 45, 2065, 5835, 7801, 2639, 5735, 63445, 0 };
            const std::uint32_t dim5754JoeKuoD6Init[]   =   { 1, 3, 5, 9, 3, 39, 51, 53, 489, 663, 951, 3931, 3075, 753, 22179, 20573, 10775, 0 };
            const std::uint32_t dim5755JoeKuoD6Init[]   =   { 1, 3, 3, 15, 13, 31, 1, 237, 79, 587, 395, 591, 607, 13105, 21301, 26829, 112181, 0 };
            const std::uint32_t dim5756JoeKuoD6Init[]   =   { 1, 1, 7, 7, 5, 55, 31, 117, 247, 229, 247, 307, 3821, 6483, 31317, 22975, 40535, 0 };
            const std::uint32_t dim5757JoeKuoD6Init[]   =   { 1, 3, 7, 15, 15, 59, 101, 17, 437, 373, 1727, 471, 2783, 7825, 24555, 58765, 5097, 0 };
            const std::uint32_t dim5758JoeKuoD6Init[]   =   { 1, 1, 3, 9, 31, 27, 71, 147, 71, 871, 793, 2363, 3213, 13383, 29801, 53187, 70021, 0 };
            const std::uint32_t dim5759JoeKuoD6Init[]   =   { 1, 3, 1, 1, 19, 47, 121, 61, 303, 565, 1371, 3703, 2201, 6835, 26041, 56039, 80227, 0 };
            const std::uint32_t dim5760JoeKuoD6Init[]   =   { 1, 1, 5, 5, 3, 45, 91, 61, 257, 947, 1449, 4031, 4925, 8627, 11909, 9529, 3429, 0 };
            const std::uint32_t dim5761JoeKuoD6Init[]   =   { 1, 1, 1, 7, 9, 63, 69, 233, 141, 361, 1443, 2157, 2877, 643, 2779, 8109, 126911, 0 };
            const std::uint32_t dim5762JoeKuoD6Init[]   =   { 1, 1, 5, 1, 5, 3, 67, 157, 21, 1, 361, 35, 1475, 12877, 22169, 6653, 85005, 0 };
            const std::uint32_t dim5763JoeKuoD6Init[]   =   { 1, 1, 7, 9, 25, 1, 7, 175, 47, 963, 405, 3955, 3905, 8429, 8483, 62037, 11323, 0 };
            const std::uint32_t dim5764JoeKuoD6Init[]   =   { 1, 1, 5, 11, 29, 23, 77, 211, 319, 745, 1935, 2429, 1687, 2173, 1571, 19457, 117777, 0 };
            const std::uint32_t dim5765JoeKuoD6Init[]   =   { 1, 1, 7, 5, 15, 57, 121, 189, 303, 79, 527, 1801, 71, 9857, 14197, 59007, 75341, 0 };
            const std::uint32_t dim5766JoeKuoD6Init[]   =   { 1, 3, 3, 5, 25, 3, 19, 141, 155, 157, 287, 769, 5789, 8443, 31823, 1019, 79111, 0 };
            const std::uint32_t dim5767JoeKuoD6Init[]   =   { 1, 1, 5, 11, 27, 27, 117, 141, 355, 1023, 869, 995, 6311, 6573, 11721, 1565, 35517, 0 };
            const std::uint32_t dim5768JoeKuoD6Init[]   =   { 1, 1, 1, 9, 1, 33, 107, 51, 41, 889, 1191, 1055, 503, 14779, 6641, 58117, 74157, 0 };
            const std::uint32_t dim5769JoeKuoD6Init[]   =   { 1, 1, 7, 5, 13, 39, 39, 33, 293, 75, 963, 3379, 1847, 12371, 9005, 38107, 69753, 0 };
            const std::uint32_t dim5770JoeKuoD6Init[]   =   { 1, 1, 5, 5, 7, 37, 19, 241, 427, 635, 1711, 3835, 773, 10525, 17207, 1675, 127255, 0 };
            const std::uint32_t dim5771JoeKuoD6Init[]   =   { 1, 1, 3, 7, 17, 19, 11, 113, 191, 947, 1133, 3173, 213, 10125, 1373, 56797, 111011, 0 };
            const std::uint32_t dim5772JoeKuoD6Init[]   =   { 1, 3, 1, 1, 29, 45, 65, 237, 223, 695, 697, 3197, 6887, 8079, 22099, 12079, 54847, 0 };
            const std::uint32_t dim5773JoeKuoD6Init[]   =   { 1, 3, 3, 7, 5, 47, 19, 215, 341, 863, 1879, 571, 7113, 2465, 23407, 52555, 44375, 0 };
            const std::uint32_t dim5774JoeKuoD6Init[]   =   { 1, 3, 5, 11, 25, 31, 109, 73, 429, 553, 1905, 1753, 6733, 4433, 13785, 32041, 27115, 0 };
            const std::uint32_t dim5775JoeKuoD6Init[]   =   { 1, 1, 1, 3, 27, 5, 97, 47, 343, 977, 1241, 721, 3355, 3559, 28349, 56389, 63103, 0 };
            const std::uint32_t dim5776JoeKuoD6Init[]   =   { 1, 3, 3, 9, 21, 53, 57, 211, 73, 155, 1855, 715, 3179, 5963, 10061, 35141, 63131, 0 };
            const std::uint32_t dim5777JoeKuoD6Init[]   =   { 1, 3, 1, 15, 21, 25, 51, 73, 31, 25, 1385, 637, 6585, 49, 2105, 6829, 9353, 0 };
            const std::uint32_t dim5778JoeKuoD6Init[]   =   { 1, 1, 7, 5, 11, 55, 31, 69, 145, 637, 1131, 2175, 3547, 13031, 2131, 12361, 74737, 0 };
            const std::uint32_t dim5779JoeKuoD6Init[]   =   { 1, 3, 3, 5, 31, 7, 119, 119, 309, 925, 895, 3813, 1131, 4765, 17865, 48707, 113577, 0 };
            const std::uint32_t dim5780JoeKuoD6Init[]   =   { 1, 3, 3, 9, 13, 33, 127, 177, 323, 727, 1881, 775, 7329, 11881, 28309, 987, 116093, 0 };
            const std::uint32_t dim5781JoeKuoD6Init[]   =   { 1, 1, 3, 5, 31, 55, 39, 41, 511, 157, 1655, 2991, 3633, 8521, 27049, 18771, 54015, 0 };
            const std::uint32_t dim5782JoeKuoD6Init[]   =   { 1, 3, 5, 13, 11, 45, 113, 185, 375, 661, 1331, 4013, 5521, 1037, 23365, 30239, 76957, 0 };
            const std::uint32_t dim5783JoeKuoD6Init[]   =   { 1, 3, 3, 7, 19, 7, 23, 17, 435, 913, 1985, 353, 6049, 7549, 3371, 60867, 41099, 0 };
            const std::uint32_t dim5784JoeKuoD6Init[]   =   { 1, 3, 3, 15, 17, 9, 53, 127, 149, 849, 1181, 2237, 1345, 539, 19715, 26277, 125445, 0 };
            const std::uint32_t dim5785JoeKuoD6Init[]   =   { 1, 1, 1, 3, 1, 9, 67, 79, 79, 795, 1793, 3167, 5917, 5323, 22043, 22007, 3917, 0 };
            const std::uint32_t dim5786JoeKuoD6Init[]   =   { 1, 3, 5, 9, 15, 19, 59, 37, 141, 145, 413, 1095, 7709, 669, 27061, 40171, 101499, 0 };
            const std::uint32_t dim5787JoeKuoD6Init[]   =   { 1, 3, 1, 1, 9, 49, 109, 7, 119, 861, 875, 1049, 4125, 6113, 15699, 6105, 48799, 0 };
            const std::uint32_t dim5788JoeKuoD6Init[]   =   { 1, 1, 3, 9, 11, 29, 43, 175, 371, 357, 1181, 3933, 43, 4559, 10333, 23603, 83095, 0 };
            const std::uint32_t dim5789JoeKuoD6Init[]   =   { 1, 3, 3, 9, 9, 7, 57, 61, 409, 143, 591, 761, 4107, 8117, 1051, 4471, 91771, 0 };
            const std::uint32_t dim5790JoeKuoD6Init[]   =   { 1, 1, 3, 11, 3, 53, 119, 21, 213, 219, 51, 3491, 7143, 937, 24693, 3211, 99463, 0 };
            const std::uint32_t dim5791JoeKuoD6Init[]   =   { 1, 1, 3, 3, 1, 47, 53, 153, 211, 523, 1637, 3351, 3753, 12489, 31825, 27613, 96431, 0 };
            const std::uint32_t dim5792JoeKuoD6Init[]   =   { 1, 1, 5, 15, 23, 57, 81, 231, 147, 9, 1043, 3157, 1463, 4835, 22435, 57407, 59615, 0 };
            const std::uint32_t dim5793JoeKuoD6Init[]   =   { 1, 3, 3, 13, 15, 63, 111, 5, 449, 957, 1175, 2887, 7741, 8975, 28775, 4067, 69283, 0 };
            const std::uint32_t dim5794JoeKuoD6Init[]   =   { 1, 3, 1, 1, 5, 61, 109, 211, 349, 179, 951, 153, 3147, 7555, 27037, 59829, 16077, 0 };
            const std::uint32_t dim5795JoeKuoD6Init[]   =   { 1, 3, 3, 7, 15, 33, 53, 61, 309, 991, 227, 3437, 3983, 14559, 13065, 46387, 49105, 0 };
            const std::uint32_t dim5796JoeKuoD6Init[]   =   { 1, 3, 5, 3, 25, 23, 97, 139, 315, 601, 1179, 1083, 6799, 1813, 15511, 60433, 65641, 0 };
            const std::uint32_t dim5797JoeKuoD6Init[]   =   { 1, 1, 7, 1, 11, 43, 87, 87, 173, 161, 91, 3011, 1869, 2313, 13691, 3509, 39433, 0 };
            const std::uint32_t dim5798JoeKuoD6Init[]   =   { 1, 3, 5, 7, 15, 5, 39, 251, 269, 819, 815, 2283, 5635, 6953, 27017, 65143, 45281, 0 };
            const std::uint32_t dim5799JoeKuoD6Init[]   =   { 1, 3, 7, 9, 1, 37, 9, 57, 467, 37, 1743, 4031, 3751, 8105, 23789, 46847, 21911, 0 };
            const std::uint32_t dim5800JoeKuoD6Init[]   =   { 1, 1, 7, 1, 23, 47, 63, 99, 59, 951, 1837, 2829, 161, 857, 4045, 9945, 53487, 0 };
            const std::uint32_t dim5801JoeKuoD6Init[]   =   { 1, 3, 7, 7, 11, 47, 43, 99, 279, 945, 1189, 2091, 4597, 183, 15527, 7151, 112403, 0 };
            const std::uint32_t dim5802JoeKuoD6Init[]   =   { 1, 3, 3, 15, 9, 53, 63, 135, 119, 95, 131, 2461, 157, 10631, 20847, 51699, 58865, 0 };
            const std::uint32_t dim5803JoeKuoD6Init[]   =   { 1, 1, 3, 1, 25, 3, 115, 29, 303, 361, 1529, 3993, 5899, 11501, 4463, 47121, 75333, 0 };
            const std::uint32_t dim5804JoeKuoD6Init[]   =   { 1, 3, 1, 15, 9, 39, 31, 199, 305, 279, 15, 611, 561, 6593, 3189, 1863, 61875, 0 };
            const std::uint32_t dim5805JoeKuoD6Init[]   =   { 1, 3, 5, 15, 5, 49, 87, 17, 87, 5, 1179, 1351, 7647, 7529, 15901, 30351, 31959, 0 };
            const std::uint32_t dim5806JoeKuoD6Init[]   =   { 1, 3, 3, 9, 31, 57, 127, 239, 349, 773, 547, 2649, 1309, 8071, 10741, 57645, 14423, 0 };
            const std::uint32_t dim5807JoeKuoD6Init[]   =   { 1, 1, 5, 9, 5, 15, 59, 185, 315, 411, 1425, 3905, 853, 12393, 21, 15195, 114291, 0 };
            const std::uint32_t dim5808JoeKuoD6Init[]   =   { 1, 3, 1, 5, 29, 47, 19, 203, 319, 673, 1169, 2413, 5295, 6251, 19883, 2725, 28937, 0 };
            const std::uint32_t dim5809JoeKuoD6Init[]   =   { 1, 3, 1, 5, 21, 55, 19, 185, 103, 827, 117, 341, 3315, 5625, 345, 63845, 49081, 0 };
            const std::uint32_t dim5810JoeKuoD6Init[]   =   { 1, 1, 7, 9, 27, 51, 105, 15, 243, 735, 1221, 1641, 293, 14423, 5363, 60873, 66223, 0 };
            const std::uint32_t dim5811JoeKuoD6Init[]   =   { 1, 1, 5, 1, 19, 5, 109, 131, 131, 67, 231, 2907, 4389, 5079, 20503, 59045, 33625, 0 };
            const std::uint32_t dim5812JoeKuoD6Init[]   =   { 1, 3, 1, 5, 5, 15, 79, 67, 287, 225, 519, 1543, 2389, 671, 7767, 62625, 61639, 0 };
            const std::uint32_t dim5813JoeKuoD6Init[]   =   { 1, 1, 1, 9, 25, 35, 83, 15, 291, 207, 1757, 3691, 5669, 11255, 27939, 57813, 46251, 0 };
            const std::uint32_t dim5814JoeKuoD6Init[]   =   { 1, 3, 1, 1, 29, 3, 83, 109, 323, 179, 1855, 3205, 7665, 16201, 13863, 16347, 98977, 0 };
            const std::uint32_t dim5815JoeKuoD6Init[]   =   { 1, 3, 1, 13, 17, 1, 101, 183, 153, 985, 125, 999, 855, 15897, 19491, 8953, 23277, 0 };
            const std::uint32_t dim5816JoeKuoD6Init[]   =   { 1, 1, 7, 11, 9, 33, 45, 229, 411, 155, 537, 3037, 1785, 11719, 8589, 16617, 47339, 0 };
            const std::uint32_t dim5817JoeKuoD6Init[]   =   { 1, 1, 5, 5, 9, 11, 7, 163, 305, 621, 1647, 2609, 7901, 14421, 23447, 1205, 52681, 0 };
            const std::uint32_t dim5818JoeKuoD6Init[]   =   { 1, 3, 3, 1, 7, 29, 39, 227, 419, 561, 129, 3299, 3123, 4243, 18689, 12335, 71783, 0 };
            const std::uint32_t dim5819JoeKuoD6Init[]   =   { 1, 3, 1, 9, 11, 61, 65, 207, 123, 763, 485, 1943, 3617, 415, 22397, 58597, 128017, 0 };
            const std::uint32_t dim5820JoeKuoD6Init[]   =   { 1, 1, 5, 13, 25, 43, 115, 73, 269, 137, 1765, 705, 1705, 16137, 22751, 60021, 4333, 0 };
            const std::uint32_t dim5821JoeKuoD6Init[]   =   { 1, 1, 5, 13, 3, 57, 9, 141, 75, 695, 597, 3435, 1085, 4905, 19625, 16061, 12111, 0 };
            const std::uint32_t dim5822JoeKuoD6Init[]   =   { 1, 1, 5, 9, 29, 13, 119, 251, 353, 421, 1955, 3503, 2605, 2587, 12503, 46419, 128815, 0 };
            const std::uint32_t dim5823JoeKuoD6Init[]   =   { 1, 3, 5, 7, 7, 29, 67, 25, 37, 327, 1607, 1899, 1691, 5801, 17441, 9755, 24993, 0 };
            const std::uint32_t dim5824JoeKuoD6Init[]   =   { 1, 1, 3, 11, 17, 29, 121, 201, 371, 597, 213, 2361, 6615, 169, 24801, 56175, 129241, 0 };
            const std::uint32_t dim5825JoeKuoD6Init[]   =   { 1, 3, 5, 1, 31, 63, 85, 77, 151, 599, 103, 677, 4431, 12897, 6373, 40349, 100819, 0 };
            const std::uint32_t dim5826JoeKuoD6Init[]   =   { 1, 3, 5, 9, 25, 9, 119, 219, 379, 939, 1907, 945, 5819, 7433, 32519, 56493, 50441, 0 };
            const std::uint32_t dim5827JoeKuoD6Init[]   =   { 1, 1, 3, 9, 13, 1, 63, 189, 135, 839, 1821, 2247, 2547, 965, 6847, 63335, 32921, 0 };
            const std::uint32_t dim5828JoeKuoD6Init[]   =   { 1, 3, 5, 13, 21, 25, 111, 37, 319, 469, 1999, 1637, 8167, 2641, 24615, 63713, 115923, 0 };
            const std::uint32_t dim5829JoeKuoD6Init[]   =   { 1, 3, 5, 9, 9, 27, 1, 63, 275, 223, 1675, 3833, 7377, 9755, 6279, 37161, 108805, 0 };
            const std::uint32_t dim5830JoeKuoD6Init[]   =   { 1, 3, 3, 13, 29, 23, 21, 73, 401, 863, 701, 2527, 4557, 5549, 22493, 6651, 39167, 0 };
            const std::uint32_t dim5831JoeKuoD6Init[]   =   { 1, 1, 3, 15, 25, 21, 97, 25, 83, 925, 2029, 3789, 3241, 7617, 13699, 31123, 124619, 0 };
            const std::uint32_t dim5832JoeKuoD6Init[]   =   { 1, 3, 7, 5, 23, 7, 95, 227, 123, 215, 359, 2099, 4505, 8477, 32665, 18211, 99679, 0 };
            const std::uint32_t dim5833JoeKuoD6Init[]   =   { 1, 3, 1, 9, 11, 57, 75, 17, 105, 175, 831, 1033, 5425, 8419, 16163, 23901, 33889, 0 };
            const std::uint32_t dim5834JoeKuoD6Init[]   =   { 1, 1, 7, 1, 17, 49, 71, 23, 129, 413, 333, 2547, 4627, 14961, 16745, 53649, 73059, 0 };
            const std::uint32_t dim5835JoeKuoD6Init[]   =   { 1, 3, 5, 3, 13, 33, 121, 147, 443, 187, 1949, 319, 8141, 14359, 11203, 53569, 70415, 0 };
            const std::uint32_t dim5836JoeKuoD6Init[]   =   { 1, 3, 1, 11, 15, 1, 23, 29, 509, 985, 1217, 3755, 385, 3697, 24631, 37619, 62435, 0 };
            const std::uint32_t dim5837JoeKuoD6Init[]   =   { 1, 3, 3, 3, 17, 11, 107, 37, 227, 913, 259, 2799, 3249, 2347, 9703, 52741, 101187, 0 };
            const std::uint32_t dim5838JoeKuoD6Init[]   =   { 1, 1, 5, 13, 25, 25, 47, 77, 405, 415, 1947, 1675, 5079, 1333, 10059, 32033, 88975, 0 };
            const std::uint32_t dim5839JoeKuoD6Init[]   =   { 1, 3, 5, 9, 27, 7, 19, 241, 445, 205, 333, 285, 7997, 6339, 29643, 10229, 29965, 0 };
            const std::uint32_t dim5840JoeKuoD6Init[]   =   { 1, 3, 5, 11, 17, 9, 91, 223, 173, 1013, 779, 3967, 781, 5471, 4309, 24795, 99203, 0 };
            const std::uint32_t dim5841JoeKuoD6Init[]   =   { 1, 1, 1, 3, 19, 53, 7, 159, 351, 515, 223, 3375, 1, 4985, 16729, 43333, 85917, 0 };
            const std::uint32_t dim5842JoeKuoD6Init[]   =   { 1, 3, 3, 1, 19, 35, 95, 69, 19, 157, 1177, 579, 7109, 3499, 3219, 26641, 49491, 0 };
            const std::uint32_t dim5843JoeKuoD6Init[]   =   { 1, 3, 3, 5, 25, 21, 125, 5, 39, 857, 615, 2925, 2005, 5503, 25523, 36711, 30939, 0 };
            const std::uint32_t dim5844JoeKuoD6Init[]   =   { 1, 3, 1, 5, 11, 33, 29, 5, 425, 125, 939, 1641, 321, 1023, 12551, 4587, 116617, 0 };
            const std::uint32_t dim5845JoeKuoD6Init[]   =   { 1, 3, 3, 13, 9, 59, 93, 137, 103, 517, 1555, 13, 7965, 13629, 14339, 37425, 65891, 0 };
            const std::uint32_t dim5846JoeKuoD6Init[]   =   { 1, 3, 7, 1, 31, 31, 87, 237, 365, 951, 267, 2019, 5085, 6133, 29371, 50319, 94313, 0 };
            const std::uint32_t dim5847JoeKuoD6Init[]   =   { 1, 3, 5, 7, 17, 19, 23, 225, 501, 189, 1291, 603, 6873, 8633, 11425, 30565, 26355, 0 };
            const std::uint32_t dim5848JoeKuoD6Init[]   =   { 1, 3, 7, 11, 23, 17, 91, 111, 415, 225, 1287, 2081, 4683, 12069, 3627, 32281, 17995, 0 };
            const std::uint32_t dim5849JoeKuoD6Init[]   =   { 1, 1, 5, 15, 25, 59, 75, 203, 179, 405, 1711, 3147, 7483, 5583, 3729, 11765, 61019, 0 };
            const std::uint32_t dim5850JoeKuoD6Init[]   =   { 1, 3, 3, 9, 3, 43, 65, 7, 269, 33, 829, 1789, 967, 13119, 26329, 16937, 18533, 0 };
            const std::uint32_t dim5851JoeKuoD6Init[]   =   { 1, 1, 3, 15, 11, 39, 73, 11, 31, 143, 1913, 1227, 1363, 11831, 28687, 50489, 106373, 0 };
            const std::uint32_t dim5852JoeKuoD6Init[]   =   { 1, 1, 3, 3, 25, 19, 15, 11, 349, 1011, 421, 3193, 3665, 6149, 20729, 6997, 51437, 0 };
            const std::uint32_t dim5853JoeKuoD6Init[]   =   { 1, 3, 5, 9, 13, 63, 73, 55, 417, 223, 1753, 2913, 4809, 3947, 10769, 5751, 93867, 0 };
            const std::uint32_t dim5854JoeKuoD6Init[]   =   { 1, 3, 7, 13, 31, 39, 39, 133, 483, 839, 1137, 3303, 7285, 4309, 24079, 60529, 103337, 0 };
            const std::uint32_t dim5855JoeKuoD6Init[]   =   { 1, 1, 3, 7, 1, 55, 3, 253, 435, 589, 1949, 1461, 513, 381, 29455, 4263, 16831, 0 };
            const std::uint32_t dim5856JoeKuoD6Init[]   =   { 1, 1, 1, 15, 25, 19, 77, 101, 299, 187, 1021, 1533, 8021, 4165, 2277, 18927, 110439, 0 };
            const std::uint32_t dim5857JoeKuoD6Init[]   =   { 1, 1, 1, 11, 9, 35, 71, 159, 409, 527, 15, 4073, 5749, 8563, 2503, 53015, 111581, 0 };
            const std::uint32_t dim5858JoeKuoD6Init[]   =   { 1, 1, 7, 5, 21, 47, 113, 23, 477, 559, 543, 409, 4701, 11479, 30761, 8373, 87777, 0 };
            const std::uint32_t dim5859JoeKuoD6Init[]   =   { 1, 3, 5, 13, 9, 27, 25, 137, 81, 37, 799, 857, 3539, 4471, 15753, 59015, 48589, 0 };
            const std::uint32_t dim5860JoeKuoD6Init[]   =   { 1, 1, 3, 7, 11, 57, 103, 83, 209, 71, 193, 3251, 4839, 13959, 32009, 6471, 23631, 0 };
            const std::uint32_t dim5861JoeKuoD6Init[]   =   { 1, 1, 7, 11, 25, 33, 85, 31, 371, 253, 1667, 1627, 6159, 10039, 15177, 52121, 39475, 0 };
            const std::uint32_t dim5862JoeKuoD6Init[]   =   { 1, 1, 5, 9, 13, 55, 37, 13, 95, 113, 1895, 1525, 1907, 6361, 5863, 27767, 108143, 0 };
            const std::uint32_t dim5863JoeKuoD6Init[]   =   { 1, 1, 3, 13, 21, 5, 53, 39, 485, 171, 1355, 2117, 3127, 6467, 31697, 45343, 111477, 0 };
            const std::uint32_t dim5864JoeKuoD6Init[]   =   { 1, 1, 7, 15, 13, 57, 11, 231, 329, 703, 1823, 2983, 215, 2835, 19719, 56637, 126169, 0 };
            const std::uint32_t dim5865JoeKuoD6Init[]   =   { 1, 3, 5, 15, 13, 51, 13, 173, 301, 867, 127, 2391, 2795, 4945, 13293, 49947, 10765, 0 };
            const std::uint32_t dim5866JoeKuoD6Init[]   =   { 1, 3, 3, 9, 23, 5, 29, 165, 467, 599, 1181, 3213, 4069, 5473, 8937, 51495, 42611, 0 };
            const std::uint32_t dim5867JoeKuoD6Init[]   =   { 1, 1, 7, 15, 5, 5, 31, 125, 397, 519, 1465, 115, 7877, 7025, 14213, 50343, 85827, 0 };
            const std::uint32_t dim5868JoeKuoD6Init[]   =   { 1, 3, 7, 3, 25, 59, 95, 103, 101, 347, 95, 3, 1251, 15109, 12615, 7511, 56789, 0 };
            const std::uint32_t dim5869JoeKuoD6Init[]   =   { 1, 3, 5, 9, 13, 59, 71, 19, 107, 73, 345, 3177, 6519, 2407, 18033, 31075, 113185, 0 };
            const std::uint32_t dim5870JoeKuoD6Init[]   =   { 1, 1, 1, 3, 27, 37, 5, 219, 169, 149, 355, 549, 1811, 11351, 22627, 53931, 88619, 0 };
            const std::uint32_t dim5871JoeKuoD6Init[]   =   { 1, 3, 1, 3, 27, 7, 9, 97, 399, 947, 1393, 3917, 5439, 15845, 19465, 30123, 69099, 0 };
            const std::uint32_t dim5872JoeKuoD6Init[]   =   { 1, 1, 7, 9, 13, 25, 107, 45, 111, 409, 967, 3359, 2499, 1703, 20763, 45187, 16265, 0 };
            const std::uint32_t dim5873JoeKuoD6Init[]   =   { 1, 1, 1, 13, 5, 49, 43, 249, 49, 947, 597, 1773, 2387, 2693, 15297, 57969, 53385, 0 };
            const std::uint32_t dim5874JoeKuoD6Init[]   =   { 1, 1, 7, 15, 27, 25, 27, 121, 421, 781, 143, 817, 7335, 14211, 139, 55601, 56671, 0 };
            const std::uint32_t dim5875JoeKuoD6Init[]   =   { 1, 3, 1, 5, 29, 47, 77, 23, 413, 931, 785, 1221, 769, 13131, 26955, 56441, 85745, 0 };
            const std::uint32_t dim5876JoeKuoD6Init[]   =   { 1, 1, 1, 11, 27, 3, 53, 21, 467, 43, 1533, 1053, 691, 6369, 8325, 51087, 71261, 0 };
            const std::uint32_t dim5877JoeKuoD6Init[]   =   { 1, 1, 3, 15, 7, 9, 43, 225, 293, 143, 1049, 3095, 6119, 3165, 9913, 26023, 62657, 0 };
            const std::uint32_t dim5878JoeKuoD6Init[]   =   { 1, 3, 7, 9, 11, 39, 99, 193, 217, 941, 259, 3811, 6757, 281, 10377, 46961, 48949, 0 };
            const std::uint32_t dim5879JoeKuoD6Init[]   =   { 1, 1, 1, 1, 25, 1, 99, 61, 495, 861, 2013, 487, 2821, 12921, 30111, 27213, 97363, 0 };
            const std::uint32_t dim5880JoeKuoD6Init[]   =   { 1, 1, 5, 9, 23, 33, 103, 237, 161, 721, 2021, 159, 995, 475, 20615, 30961, 31767, 0 };
            const std::uint32_t dim5881JoeKuoD6Init[]   =   { 1, 3, 1, 1, 5, 59, 63, 139, 451, 789, 1285, 655, 5501, 273, 21061, 35937, 20811, 0 };
            const std::uint32_t dim5882JoeKuoD6Init[]   =   { 1, 3, 3, 9, 9, 15, 121, 233, 287, 929, 1605, 1243, 417, 1695, 29903, 28699, 85981, 0 };
            const std::uint32_t dim5883JoeKuoD6Init[]   =   { 1, 3, 3, 5, 7, 25, 27, 253, 469, 255, 285, 2467, 4897, 4079, 29759, 50351, 76451, 0 };
            const std::uint32_t dim5884JoeKuoD6Init[]   =   { 1, 1, 3, 3, 5, 33, 29, 209, 291, 967, 1429, 1953, 5957, 14065, 8875, 32675, 4629, 0 };
            const std::uint32_t dim5885JoeKuoD6Init[]   =   { 1, 3, 5, 9, 7, 31, 97, 21, 177, 485, 1115, 4051, 6683, 7761, 30181, 37531, 51789, 0 };
            const std::uint32_t dim5886JoeKuoD6Init[]   =   { 1, 1, 7, 3, 25, 51, 23, 183, 57, 699, 1245, 2519, 2783, 4457, 6381, 43199, 40071, 0 };
            const std::uint32_t dim5887JoeKuoD6Init[]   =   { 1, 3, 5, 5, 19, 55, 45, 101, 299, 461, 1009, 319, 7335, 7769, 5479, 61113, 7937, 0 };
            const std::uint32_t dim5888JoeKuoD6Init[]   =   { 1, 1, 7, 3, 29, 21, 55, 55, 437, 771, 363, 683, 4299, 15569, 13813, 40663, 86285, 0 };
            const std::uint32_t dim5889JoeKuoD6Init[]   =   { 1, 1, 1, 13, 31, 35, 93, 175, 451, 387, 1145, 3367, 3833, 13495, 11019, 48925, 85721, 0 };
            const std::uint32_t dim5890JoeKuoD6Init[]   =   { 1, 1, 7, 15, 31, 21, 55, 205, 117, 895, 535, 2627, 1473, 10779, 24493, 42999, 130805, 0 };
            const std::uint32_t dim5891JoeKuoD6Init[]   =   { 1, 1, 3, 13, 27, 11, 45, 37, 193, 237, 1505, 1405, 3613, 9565, 3037, 53643, 85211, 0 };
            const std::uint32_t dim5892JoeKuoD6Init[]   =   { 1, 1, 3, 13, 9, 17, 19, 27, 117, 503, 65, 1033, 7891, 4005, 9229, 20999, 96601, 0 };
            const std::uint32_t dim5893JoeKuoD6Init[]   =   { 1, 3, 3, 5, 17, 3, 71, 79, 145, 985, 935, 3997, 6239, 12511, 13895, 65031, 126383, 0 };
            const std::uint32_t dim5894JoeKuoD6Init[]   =   { 1, 1, 5, 1, 23, 55, 3, 105, 71, 243, 1479, 111, 7103, 10753, 26193, 35833, 14583, 0 };
            const std::uint32_t dim5895JoeKuoD6Init[]   =   { 1, 3, 3, 3, 15, 3, 73, 125, 267, 29, 1775, 1437, 8091, 10891, 25731, 54381, 12821, 0 };
            const std::uint32_t dim5896JoeKuoD6Init[]   =   { 1, 1, 1, 3, 23, 15, 67, 123, 401, 347, 807, 1097, 31, 11209, 8727, 58149, 129099, 0 };
            const std::uint32_t dim5897JoeKuoD6Init[]   =   { 1, 3, 3, 7, 7, 61, 49, 129, 423, 535, 135, 3587, 233, 4509, 23209, 59203, 41297, 0 };
            const std::uint32_t dim5898JoeKuoD6Init[]   =   { 1, 3, 1, 7, 5, 29, 65, 31, 335, 855, 835, 1421, 3081, 14219, 16321, 48269, 41603, 0 };
            const std::uint32_t dim5899JoeKuoD6Init[]   =   { 1, 1, 1, 13, 3, 21, 5, 117, 163, 603, 1519, 3789, 7873, 10981, 4615, 9165, 83929, 0 };
            const std::uint32_t dim5900JoeKuoD6Init[]   =   { 1, 3, 5, 11, 15, 21, 75, 151, 193, 757, 647, 1603, 333, 10515, 22771, 55459, 3315, 0 };
            const std::uint32_t dim5901JoeKuoD6Init[]   =   { 1, 1, 7, 1, 27, 3, 63, 197, 271, 175, 1599, 2119, 1031, 8671, 10893, 35641, 94535, 0 };
            const std::uint32_t dim5902JoeKuoD6Init[]   =   { 1, 1, 1, 15, 1, 59, 93, 17, 5, 213, 1663, 941, 435, 8107, 1963, 34951, 106181, 0 };
            const std::uint32_t dim5903JoeKuoD6Init[]   =   { 1, 1, 5, 11, 13, 35, 111, 97, 267, 737, 2023, 1301, 7407, 11249, 31785, 31933, 20673, 0 };
            const std::uint32_t dim5904JoeKuoD6Init[]   =   { 1, 3, 3, 15, 5, 15, 29, 63, 189, 687, 27, 2005, 7129, 11377, 23175, 42389, 30933, 0 };
            const std::uint32_t dim5905JoeKuoD6Init[]   =   { 1, 1, 1, 9, 13, 63, 7, 155, 67, 291, 1419, 755, 2623, 4749, 22971, 7545, 55711, 0 };
            const std::uint32_t dim5906JoeKuoD6Init[]   =   { 1, 3, 7, 7, 23, 29, 83, 151, 213, 201, 157, 3051, 6553, 6401, 15931, 47941, 22869, 0 };
            const std::uint32_t dim5907JoeKuoD6Init[]   =   { 1, 3, 5, 5, 7, 45, 33, 155, 225, 25, 49, 2419, 4241, 6835, 11401, 50725, 118343, 0 };
            const std::uint32_t dim5908JoeKuoD6Init[]   =   { 1, 1, 3, 13, 31, 27, 37, 41, 19, 375, 1771, 1789, 2313, 2577, 12615, 22715, 22179, 0 };
            const std::uint32_t dim5909JoeKuoD6Init[]   =   { 1, 3, 1, 11, 17, 53, 55, 229, 235, 837, 143, 3583, 2789, 5471, 6515, 44565, 8619, 0 };
            const std::uint32_t dim5910JoeKuoD6Init[]   =   { 1, 1, 5, 15, 5, 17, 23, 95, 217, 551, 353, 27, 3973, 2547, 27903, 50611, 72277, 0 };
            const std::uint32_t dim5911JoeKuoD6Init[]   =   { 1, 1, 3, 7, 5, 13, 41, 111, 157, 215, 1327, 3073, 1871, 11875, 24239, 40527, 97637, 0 };
            const std::uint32_t dim5912JoeKuoD6Init[]   =   { 1, 3, 1, 1, 29, 63, 111, 187, 369, 395, 1197, 3229, 4353, 14715, 29671, 50503, 89321, 0 };
            const std::uint32_t dim5913JoeKuoD6Init[]   =   { 1, 3, 1, 1, 5, 63, 11, 39, 171, 209, 463, 3421, 3451, 4453, 14397, 2219, 98261, 0 };
            const std::uint32_t dim5914JoeKuoD6Init[]   =   { 1, 3, 3, 5, 1, 1, 13, 101, 67, 815, 1521, 1543, 7221, 7337, 10765, 30029, 47881, 0 };
            const std::uint32_t dim5915JoeKuoD6Init[]   =   { 1, 1, 5, 7, 9, 9, 33, 197, 439, 893, 961, 11, 4319, 14265, 24839, 33581, 35531, 0 };
            const std::uint32_t dim5916JoeKuoD6Init[]   =   { 1, 3, 3, 15, 29, 35, 43, 229, 313, 369, 955, 1069, 2939, 12623, 20373, 1533, 9105, 0 };
            const std::uint32_t dim5917JoeKuoD6Init[]   =   { 1, 3, 1, 7, 21, 7, 127, 243, 103, 353, 859, 3789, 4369, 12063, 22369, 14531, 94289, 0 };
            const std::uint32_t dim5918JoeKuoD6Init[]   =   { 1, 3, 5, 15, 1, 27, 65, 127, 229, 99, 627, 2693, 7173, 7305, 29971, 7097, 10113, 0 };
            const std::uint32_t dim5919JoeKuoD6Init[]   =   { 1, 1, 5, 15, 3, 47, 61, 29, 155, 725, 1727, 2667, 7003, 16277, 21983, 21365, 129365, 0 };
            const std::uint32_t dim5920JoeKuoD6Init[]   =   { 1, 1, 5, 7, 27, 61, 115, 133, 137, 661, 1201, 2151, 367, 3567, 12885, 62143, 53955, 0 };
            const std::uint32_t dim5921JoeKuoD6Init[]   =   { 1, 1, 1, 11, 9, 41, 113, 103, 469, 687, 1541, 3679, 6833, 10493, 32747, 39909, 121445, 0 };
            const std::uint32_t dim5922JoeKuoD6Init[]   =   { 1, 1, 7, 5, 5, 5, 91, 91, 5, 405, 529, 3999, 6783, 2387, 16621, 12919, 8659, 0 };
            const std::uint32_t dim5923JoeKuoD6Init[]   =   { 1, 1, 7, 13, 21, 47, 125, 155, 83, 913, 1833, 4027, 6657, 7031, 31231, 58201, 88943, 0 };
            const std::uint32_t dim5924JoeKuoD6Init[]   =   { 1, 3, 7, 3, 17, 55, 25, 29, 181, 205, 1173, 1081, 6475, 5037, 18461, 22487, 114131, 0 };
            const std::uint32_t dim5925JoeKuoD6Init[]   =   { 1, 1, 7, 7, 25, 63, 101, 103, 171, 191, 1863, 3441, 2515, 14179, 30123, 19145, 31669, 0 };
            const std::uint32_t dim5926JoeKuoD6Init[]   =   { 1, 3, 7, 11, 29, 49, 73, 163, 415, 821, 1809, 723, 7049, 14565, 4829, 19395, 61131, 0 };
            const std::uint32_t dim5927JoeKuoD6Init[]   =   { 1, 1, 7, 9, 5, 25, 103, 167, 381, 757, 813, 471, 3021, 6619, 20929, 38133, 129505, 0 };
            const std::uint32_t dim5928JoeKuoD6Init[]   =   { 1, 1, 5, 13, 25, 61, 59, 199, 257, 999, 169, 3289, 7181, 2049, 2185, 39045, 102703, 0 };
            const std::uint32_t dim5929JoeKuoD6Init[]   =   { 1, 1, 3, 1, 21, 1, 111, 125, 289, 33, 701, 3491, 5569, 8055, 23149, 26793, 102563, 0 };
            const std::uint32_t dim5930JoeKuoD6Init[]   =   { 1, 1, 7, 3, 25, 15, 105, 235, 307, 201, 1947, 699, 2519, 10615, 29345, 17061, 112949, 0 };
            const std::uint32_t dim5931JoeKuoD6Init[]   =   { 1, 3, 3, 15, 19, 1, 93, 173, 399, 13, 269, 1189, 523, 5145, 32731, 54087, 94123, 0 };
            const std::uint32_t dim5932JoeKuoD6Init[]   =   { 1, 3, 1, 15, 9, 41, 59, 79, 217, 833, 1993, 2429, 3599, 6919, 30911, 12615, 67947, 0 };
            const std::uint32_t dim5933JoeKuoD6Init[]   =   { 1, 3, 3, 13, 31, 9, 95, 37, 343, 955, 1363, 3851, 4091, 13165, 15241, 14853, 35747, 0 };
            const std::uint32_t dim5934JoeKuoD6Init[]   =   { 1, 1, 3, 5, 27, 39, 37, 217, 385, 473, 1997, 2247, 7353, 1503, 9003, 15055, 27289, 0 };
            const std::uint32_t dim5935JoeKuoD6Init[]   =   { 1, 3, 7, 11, 1, 13, 21, 243, 375, 91, 1295, 1661, 203, 15251, 15355, 16065, 24183, 0 };
            const std::uint32_t dim5936JoeKuoD6Init[]   =   { 1, 3, 1, 13, 11, 45, 85, 5, 275, 741, 1395, 4011, 7987, 16087, 24113, 50555, 128147, 0 };
            const std::uint32_t dim5937JoeKuoD6Init[]   =   { 1, 1, 1, 7, 3, 11, 13, 189, 55, 151, 395, 657, 807, 11973, 26297, 13043, 109641, 0 };
            const std::uint32_t dim5938JoeKuoD6Init[]   =   { 1, 1, 7, 13, 31, 19, 33, 235, 491, 647, 1115, 2299, 6381, 7525, 2237, 36197, 126457, 0 };
            const std::uint32_t dim5939JoeKuoD6Init[]   =   { 1, 3, 5, 1, 21, 15, 53, 231, 77, 347, 969, 141, 4501, 9429, 1815, 50887, 74581, 0 };
            const std::uint32_t dim5940JoeKuoD6Init[]   =   { 1, 1, 1, 9, 29, 43, 47, 103, 327, 131, 927, 441, 7517, 7277, 21065, 409, 50351, 0 };
            const std::uint32_t dim5941JoeKuoD6Init[]   =   { 1, 1, 5, 1, 11, 13, 103, 157, 239, 69, 1347, 477, 5017, 9723, 28133, 65135, 12359, 0 };
            const std::uint32_t dim5942JoeKuoD6Init[]   =   { 1, 1, 1, 13, 17, 63, 117, 189, 323, 565, 927, 1727, 5337, 13243, 5739, 31241, 14209, 0 };
            const std::uint32_t dim5943JoeKuoD6Init[]   =   { 1, 1, 3, 9, 29, 9, 103, 61, 467, 217, 1367, 2405, 5355, 5743, 31469, 30149, 98775, 0 };
            const std::uint32_t dim5944JoeKuoD6Init[]   =   { 1, 1, 1, 15, 23, 23, 17, 229, 103, 583, 179, 115, 7081, 9437, 32623, 62639, 72391, 0 };
            const std::uint32_t dim5945JoeKuoD6Init[]   =   { 1, 1, 5, 11, 11, 39, 97, 209, 115, 107, 593, 2347, 1445, 6179, 32011, 8435, 65847, 0 };
            const std::uint32_t dim5946JoeKuoD6Init[]   =   { 1, 3, 7, 3, 29, 27, 55, 111, 27, 731, 995, 1871, 5017, 1485, 11313, 2559, 6561, 0 };
            const std::uint32_t dim5947JoeKuoD6Init[]   =   { 1, 3, 1, 3, 27, 9, 103, 247, 83, 197, 517, 1629, 2189, 7255, 183, 35111, 15077, 0 };
            const std::uint32_t dim5948JoeKuoD6Init[]   =   { 1, 3, 7, 5, 31, 37, 87, 223, 343, 331, 1361, 3371, 2007, 13235, 10897, 63839, 109837, 0 };
            const std::uint32_t dim5949JoeKuoD6Init[]   =   { 1, 1, 7, 11, 17, 5, 41, 197, 489, 625, 1595, 2663, 5941, 14029, 30999, 16781, 116001, 0 };
            const std::uint32_t dim5950JoeKuoD6Init[]   =   { 1, 3, 3, 7, 19, 19, 61, 175, 125, 609, 1391, 147, 3001, 4189, 10133, 24031, 46219, 0 };
            const std::uint32_t dim5951JoeKuoD6Init[]   =   { 1, 1, 3, 13, 13, 57, 117, 181, 299, 939, 583, 3151, 829, 6561, 30449, 12211, 107879, 0 };
            const std::uint32_t dim5952JoeKuoD6Init[]   =   { 1, 1, 5, 11, 23, 45, 87, 115, 259, 613, 1001, 171, 57, 13789, 22173, 56837, 26263, 0 };
            const std::uint32_t dim5953JoeKuoD6Init[]   =   { 1, 1, 3, 3, 7, 43, 45, 131, 87, 251, 1411, 2737, 2739, 4595, 12561, 12043, 82885, 0 };
            const std::uint32_t dim5954JoeKuoD6Init[]   =   { 1, 3, 3, 7, 19, 39, 87, 223, 461, 37, 283, 3937, 6193, 10887, 11509, 41131, 38359, 0 };
            const std::uint32_t dim5955JoeKuoD6Init[]   =   { 1, 3, 1, 11, 11, 37, 25, 133, 105, 1013, 925, 3301, 239, 16295, 4831, 8649, 125767, 0 };
            const std::uint32_t dim5956JoeKuoD6Init[]   =   { 1, 3, 3, 11, 25, 11, 41, 155, 1, 717, 1587, 635, 279, 1803, 14817, 28669, 88835, 0 };
            const std::uint32_t dim5957JoeKuoD6Init[]   =   { 1, 3, 3, 11, 29, 17, 39, 51, 13, 871, 1197, 2561, 6671, 8465, 22709, 15933, 15923, 0 };
            const std::uint32_t dim5958JoeKuoD6Init[]   =   { 1, 3, 7, 1, 13, 17, 57, 43, 267, 261, 901, 241, 3767, 15053, 11017, 36321, 72497, 0 };
            const std::uint32_t dim5959JoeKuoD6Init[]   =   { 1, 3, 1, 15, 23, 13, 17, 63, 171, 919, 1387, 2673, 7605, 8523, 14807, 21187, 56057, 0 };
            const std::uint32_t dim5960JoeKuoD6Init[]   =   { 1, 3, 7, 15, 23, 41, 85, 95, 53, 629, 1877, 3167, 2411, 9619, 24621, 31213, 30069, 0 };
            const std::uint32_t dim5961JoeKuoD6Init[]   =   { 1, 1, 5, 3, 3, 25, 99, 39, 321, 549, 599, 1279, 2401, 2335, 8227, 59429, 94549, 0 };
            const std::uint32_t dim5962JoeKuoD6Init[]   =   { 1, 3, 3, 11, 9, 21, 29, 55, 477, 19, 1275, 29, 2253, 11421, 30401, 57059, 93219, 0 };
            const std::uint32_t dim5963JoeKuoD6Init[]   =   { 1, 1, 7, 1, 27, 13, 117, 249, 463, 769, 281, 515, 7467, 11507, 1621, 39765, 31109, 0 };
            const std::uint32_t dim5964JoeKuoD6Init[]   =   { 1, 3, 5, 7, 19, 7, 77, 107, 23, 895, 1013, 2701, 3805, 7327, 27247, 6119, 102395, 0 };
            const std::uint32_t dim5965JoeKuoD6Init[]   =   { 1, 1, 3, 13, 21, 49, 99, 15, 163, 641, 1703, 3061, 163, 4265, 32571, 13957, 75005, 0 };
            const std::uint32_t dim5966JoeKuoD6Init[]   =   { 1, 1, 5, 11, 27, 17, 87, 169, 427, 959, 361, 1023, 5727, 16279, 1099, 39081, 67215, 0 };
            const std::uint32_t dim5967JoeKuoD6Init[]   =   { 1, 3, 3, 9, 23, 13, 1, 91, 173, 325, 1881, 1385, 8023, 935, 9221, 19673, 36949, 0 };
            const std::uint32_t dim5968JoeKuoD6Init[]   =   { 1, 3, 1, 7, 7, 25, 119, 189, 107, 249, 811, 973, 6499, 101, 11281, 55227, 32361, 0 };
            const std::uint32_t dim5969JoeKuoD6Init[]   =   { 1, 1, 5, 13, 19, 37, 117, 95, 463, 587, 1419, 445, 4019, 7257, 29757, 50773, 52247, 0 };
            const std::uint32_t dim5970JoeKuoD6Init[]   =   { 1, 1, 1, 1, 17, 57, 81, 57, 43, 789, 1035, 625, 1707, 9683, 3681, 12411, 110623, 0 };
            const std::uint32_t dim5971JoeKuoD6Init[]   =   { 1, 1, 7, 5, 7, 57, 49, 91, 459, 513, 1869, 3377, 139, 10037, 24091, 54247, 41279, 0 };
            const std::uint32_t dim5972JoeKuoD6Init[]   =   { 1, 3, 3, 9, 9, 33, 29, 51, 355, 415, 1907, 809, 6543, 349, 18507, 12919, 41667, 0 };
            const std::uint32_t dim5973JoeKuoD6Init[]   =   { 1, 1, 5, 11, 3, 17, 73, 201, 121, 909, 1623, 799, 3271, 9051, 5717, 15169, 127861, 0 };
            const std::uint32_t dim5974JoeKuoD6Init[]   =   { 1, 1, 7, 7, 23, 31, 1, 155, 475, 87, 2001, 2459, 1285, 5931, 6803, 56757, 71671, 0 };
            const std::uint32_t dim5975JoeKuoD6Init[]   =   { 1, 1, 5, 13, 5, 1, 21, 109, 263, 841, 723, 1539, 7529, 433, 23721, 33195, 57001, 0 };
            const std::uint32_t dim5976JoeKuoD6Init[]   =   { 1, 3, 3, 13, 29, 55, 105, 231, 405, 265, 671, 351, 4693, 9033, 21963, 52073, 125131, 0 };
            const std::uint32_t dim5977JoeKuoD6Init[]   =   { 1, 3, 1, 13, 25, 51, 55, 227, 245, 983, 251, 2553, 2017, 1381, 31461, 3953, 75775, 0 };
            const std::uint32_t dim5978JoeKuoD6Init[]   =   { 1, 1, 1, 11, 31, 11, 91, 91, 287, 749, 1019, 4055, 3237, 6965, 14765, 1663, 82987, 0 };
            const std::uint32_t dim5979JoeKuoD6Init[]   =   { 1, 1, 7, 3, 11, 15, 67, 161, 79, 729, 1115, 3713, 2715, 9361, 9365, 26093, 63409, 0 };
            const std::uint32_t dim5980JoeKuoD6Init[]   =   { 1, 3, 1, 7, 1, 51, 125, 15, 457, 433, 405, 2329, 157, 4817, 25867, 38177, 45319, 0 };
            const std::uint32_t dim5981JoeKuoD6Init[]   =   { 1, 3, 7, 9, 25, 57, 5, 233, 481, 781, 1313, 3179, 7219, 8717, 14825, 16079, 127149, 0 };
            const std::uint32_t dim5982JoeKuoD6Init[]   =   { 1, 1, 7, 15, 27, 51, 5, 65, 77, 313, 1751, 1489, 4307, 10541, 11345, 52577, 18143, 0 };
            const std::uint32_t dim5983JoeKuoD6Init[]   =   { 1, 1, 1, 15, 21, 5, 113, 71, 411, 327, 1681, 1023, 5661, 15815, 5387, 10351, 21121, 0 };
            const std::uint32_t dim5984JoeKuoD6Init[]   =   { 1, 1, 5, 5, 29, 55, 25, 255, 69, 879, 501, 1915, 3731, 633, 12197, 5249, 31129, 0 };
            const std::uint32_t dim5985JoeKuoD6Init[]   =   { 1, 3, 5, 7, 3, 23, 107, 163, 485, 853, 359, 3069, 4353, 371, 6027, 53239, 105541, 0 };
            const std::uint32_t dim5986JoeKuoD6Init[]   =   { 1, 3, 5, 15, 7, 41, 9, 47, 33, 327, 621, 147, 577, 29, 14623, 3403, 9791, 0 };
            const std::uint32_t dim5987JoeKuoD6Init[]   =   { 1, 3, 3, 15, 29, 47, 41, 149, 477, 127, 573, 877, 3101, 5963, 28457, 14231, 67425, 0 };
            const std::uint32_t dim5988JoeKuoD6Init[]   =   { 1, 1, 1, 15, 31, 7, 55, 191, 101, 259, 1071, 219, 2233, 3583, 21969, 32745, 80529, 0 };
            const std::uint32_t dim5989JoeKuoD6Init[]   =   { 1, 3, 7, 13, 17, 53, 115, 69, 241, 71, 1475, 191, 509, 3721, 15537, 53773, 18005, 0 };
            const std::uint32_t dim5990JoeKuoD6Init[]   =   { 1, 1, 3, 9, 5, 57, 13, 95, 103, 871, 2043, 2239, 7833, 10727, 6513, 55273, 3781, 0 };
            const std::uint32_t dim5991JoeKuoD6Init[]   =   { 1, 1, 5, 5, 9, 11, 55, 151, 239, 537, 135, 2779, 7393, 15393, 11097, 58593, 100745, 0 };
            const std::uint32_t dim5992JoeKuoD6Init[]   =   { 1, 1, 1, 9, 15, 39, 29, 105, 441, 181, 1113, 2125, 8145, 11045, 6589, 33603, 83377, 0 };
            const std::uint32_t dim5993JoeKuoD6Init[]   =   { 1, 3, 1, 1, 11, 63, 69, 153, 225, 845, 675, 407, 4691, 13383, 27359, 38881, 5509, 0 };
            const std::uint32_t dim5994JoeKuoD6Init[]   =   { 1, 3, 7, 11, 23, 31, 69, 3, 41, 57, 683, 887, 6861, 12161, 14537, 27293, 113001, 0 };
            const std::uint32_t dim5995JoeKuoD6Init[]   =   { 1, 1, 1, 11, 5, 1, 101, 175, 437, 3, 1477, 1005, 6607, 7429, 7213, 4025, 66479, 0 };
            const std::uint32_t dim5996JoeKuoD6Init[]   =   { 1, 1, 7, 5, 19, 7, 99, 131, 273, 977, 1717, 3831, 175, 5673, 12577, 36787, 30945, 0 };
            const std::uint32_t dim5997JoeKuoD6Init[]   =   { 1, 3, 1, 1, 15, 37, 105, 195, 61, 869, 255, 2625, 7401, 9361, 13217, 52811, 130811, 0 };
            const std::uint32_t dim5998JoeKuoD6Init[]   =   { 1, 3, 5, 3, 29, 27, 105, 23, 511, 813, 1311, 2859, 1647, 1949, 1329, 27589, 125209, 0 };
            const std::uint32_t dim5999JoeKuoD6Init[]   =   { 1, 3, 3, 1, 21, 11, 119, 247, 123, 401, 409, 1845, 2133, 10793, 221, 43217, 14069, 0 };
            const std::uint32_t dim6000JoeKuoD6Init[]   =   { 1, 1, 5, 1, 29, 21, 51, 73, 501, 861, 725, 249, 4249, 8029, 15767, 11985, 18637, 0 };
            const std::uint32_t dim6001JoeKuoD6Init[]   =   { 1, 1, 5, 11, 19, 39, 97, 65, 13, 283, 489, 2307, 5239, 4161, 18639, 60035, 22405, 0 };
            const std::uint32_t dim6002JoeKuoD6Init[]   =   { 1, 3, 5, 1, 3, 7, 109, 27, 429, 663, 1569, 3001, 3453, 8627, 9719, 23941, 110451, 0 };
            const std::uint32_t dim6003JoeKuoD6Init[]   =   { 1, 3, 7, 5, 17, 13, 125, 209, 347, 95, 1937, 1419, 5661, 7171, 20607, 9777, 68343, 0 };
            const std::uint32_t dim6004JoeKuoD6Init[]   =   { 1, 1, 1, 1, 7, 41, 43, 229, 57, 49, 1863, 2819, 3735, 915, 1571, 11603, 116275, 0 };
            const std::uint32_t dim6005JoeKuoD6Init[]   =   { 1, 1, 7, 9, 21, 27, 5, 199, 181, 521, 303, 1097, 5427, 8899, 30325, 55457, 16189, 0 };
            const std::uint32_t dim6006JoeKuoD6Init[]   =   { 1, 3, 3, 7, 19, 41, 3, 205, 279, 223, 971, 633, 2617, 13191, 10193, 23375, 62563, 0 };
            const std::uint32_t dim6007JoeKuoD6Init[]   =   { 1, 3, 3, 13, 23, 59, 85, 25, 253, 405, 65, 1625, 4401, 4679, 14381, 57833, 30001, 0 };
            const std::uint32_t dim6008JoeKuoD6Init[]   =   { 1, 3, 3, 3, 13, 35, 11, 157, 123, 397, 119, 2513, 1919, 14583, 5469, 11463, 94711, 0 };
            const std::uint32_t dim6009JoeKuoD6Init[]   =   { 1, 1, 1, 7, 17, 37, 83, 211, 451, 939, 449, 13, 6671, 1457, 19855, 15053, 52327, 0 };
            const std::uint32_t dim6010JoeKuoD6Init[]   =   { 1, 1, 5, 3, 9, 57, 39, 183, 331, 451, 1391, 1865, 7801, 14293, 29069, 705, 109497, 0 };
            const std::uint32_t dim6011JoeKuoD6Init[]   =   { 1, 3, 7, 7, 23, 21, 85, 81, 255, 9, 1685, 2879, 6327, 12675, 31657, 38877, 74131, 0 };
            const std::uint32_t dim6012JoeKuoD6Init[]   =   { 1, 1, 5, 9, 25, 19, 41, 195, 31, 555, 927, 1445, 593, 11067, 10819, 17205, 82037, 0 };
            const std::uint32_t dim6013JoeKuoD6Init[]   =   { 1, 3, 1, 13, 1, 35, 29, 71, 323, 705, 53, 3885, 6223, 1319, 30853, 59935, 35949, 0 };
            const std::uint32_t dim6014JoeKuoD6Init[]   =   { 1, 1, 7, 3, 27, 63, 67, 31, 149, 61, 1611, 77, 4271, 3161, 12493, 38341, 53837, 0 };
            const std::uint32_t dim6015JoeKuoD6Init[]   =   { 1, 1, 1, 15, 27, 53, 31, 249, 429, 925, 1485, 1855, 4421, 5703, 10097, 14827, 36685, 0 };
            const std::uint32_t dim6016JoeKuoD6Init[]   =   { 1, 3, 7, 13, 7, 63, 53, 9, 317, 485, 1679, 3631, 3745, 5643, 21615, 45129, 48027, 0 };
            const std::uint32_t dim6017JoeKuoD6Init[]   =   { 1, 1, 1, 1, 17, 43, 19, 163, 441, 847, 937, 959, 6649, 13071, 1065, 55193, 129509, 0 };
            const std::uint32_t dim6018JoeKuoD6Init[]   =   { 1, 1, 1, 11, 29, 47, 9, 215, 397, 637, 961, 3139, 2007, 12603, 27657, 22825, 72873, 0 };
            const std::uint32_t dim6019JoeKuoD6Init[]   =   { 1, 3, 3, 15, 7, 45, 55, 163, 259, 899, 951, 3245, 4191, 15813, 20195, 8361, 54025, 0 };
            const std::uint32_t dim6020JoeKuoD6Init[]   =   { 1, 1, 5, 11, 3, 17, 13, 223, 289, 255, 875, 2937, 1593, 9729, 21569, 63199, 83875, 0 };
            const std::uint32_t dim6021JoeKuoD6Init[]   =   { 1, 1, 1, 15, 19, 31, 17, 129, 267, 9, 2015, 3233, 6799, 12891, 18473, 37865, 19547, 0 };
            const std::uint32_t dim6022JoeKuoD6Init[]   =   { 1, 1, 5, 5, 5, 29, 81, 37, 357, 539, 1525, 2839, 8041, 5569, 4423, 8907, 35461, 0 };
            const std::uint32_t dim6023JoeKuoD6Init[]   =   { 1, 1, 5, 5, 29, 11, 85, 61, 333, 521, 1111, 3627, 325, 9805, 17889, 25655, 39537, 0 };
            const std::uint32_t dim6024JoeKuoD6Init[]   =   { 1, 3, 5, 11, 11, 53, 81, 25, 79, 253, 1963, 287, 7487, 15045, 21431, 35417, 102391, 0 };
            const std::uint32_t dim6025JoeKuoD6Init[]   =   { 1, 1, 1, 5, 11, 33, 45, 45, 425, 773, 1817, 4077, 1471, 11655, 683, 7115, 92651, 0 };
            const std::uint32_t dim6026JoeKuoD6Init[]   =   { 1, 1, 3, 3, 21, 13, 101, 215, 311, 853, 41, 1007, 5511, 2581, 25565, 13155, 117225, 0 };
            const std::uint32_t dim6027JoeKuoD6Init[]   =   { 1, 1, 3, 11, 19, 9, 125, 59, 273, 691, 499, 1547, 567, 10259, 21963, 48725, 3601, 0 };
            const std::uint32_t dim6028JoeKuoD6Init[]   =   { 1, 1, 3, 7, 27, 31, 39, 125, 317, 625, 1329, 3947, 3943, 6889, 2811, 34055, 1449, 0 };
            const std::uint32_t dim6029JoeKuoD6Init[]   =   { 1, 1, 1, 3, 29, 45, 73, 239, 319, 611, 647, 1839, 5277, 7807, 3107, 14683, 20203, 0 };
            const std::uint32_t dim6030JoeKuoD6Init[]   =   { 1, 3, 3, 3, 5, 5, 107, 139, 103, 809, 1343, 4041, 3273, 1789, 16205, 47873, 27803, 0 };
            const std::uint32_t dim6031JoeKuoD6Init[]   =   { 1, 3, 1, 9, 21, 23, 13, 131, 105, 741, 1773, 981, 5633, 14609, 12281, 50343, 14317, 0 };
            const std::uint32_t dim6032JoeKuoD6Init[]   =   { 1, 1, 1, 5, 11, 5, 125, 171, 109, 555, 159, 905, 691, 12401, 22817, 41411, 70113, 0 };
            const std::uint32_t dim6033JoeKuoD6Init[]   =   { 1, 3, 3, 9, 31, 37, 109, 231, 59, 615, 799, 319, 2459, 4521, 8525, 4827, 22969, 0 };
            const std::uint32_t dim6034JoeKuoD6Init[]   =   { 1, 3, 1, 5, 11, 7, 49, 237, 345, 473, 981, 2073, 6525, 8805, 13403, 3659, 69897, 0 };
            const std::uint32_t dim6035JoeKuoD6Init[]   =   { 1, 3, 1, 5, 9, 37, 13, 203, 141, 573, 745, 2613, 5589, 607, 24483, 38427, 95775, 0 };
            const std::uint32_t dim6036JoeKuoD6Init[]   =   { 1, 1, 3, 1, 23, 61, 75, 57, 299, 191, 805, 2993, 5175, 12037, 13649, 58831, 48791, 0 };
            const std::uint32_t dim6037JoeKuoD6Init[]   =   { 1, 3, 7, 13, 31, 57, 13, 219, 185, 717, 1607, 3785, 4719, 11583, 29285, 48207, 92021, 0 };
            const std::uint32_t dim6038JoeKuoD6Init[]   =   { 1, 3, 7, 15, 23, 35, 23, 69, 411, 773, 1549, 1087, 1685, 15703, 27193, 62675, 43505, 0 };
            const std::uint32_t dim6039JoeKuoD6Init[]   =   { 1, 1, 5, 3, 25, 19, 97, 75, 493, 549, 1655, 2881, 4989, 2765, 4797, 43143, 113955, 0 };
            const std::uint32_t dim6040JoeKuoD6Init[]   =   { 1, 1, 5, 7, 21, 5, 65, 37, 383, 133, 1907, 3747, 1525, 5803, 19977, 50551, 23157, 0 };
            const std::uint32_t dim6041JoeKuoD6Init[]   =   { 1, 1, 1, 11, 15, 61, 59, 109, 489, 901, 1787, 1611, 6101, 10653, 3071, 35643, 56227, 0 };
            const std::uint32_t dim6042JoeKuoD6Init[]   =   { 1, 3, 1, 5, 15, 25, 121, 111, 25, 251, 1467, 1795, 1631, 13753, 32391, 14831, 90739, 0 };
            const std::uint32_t dim6043JoeKuoD6Init[]   =   { 1, 1, 1, 13, 23, 55, 119, 147, 45, 871, 1389, 1929, 1023, 16131, 10041, 40055, 23337, 0 };
            const std::uint32_t dim6044JoeKuoD6Init[]   =   { 1, 3, 1, 15, 27, 33, 23, 41, 463, 603, 1633, 3445, 2007, 5999, 11175, 18343, 13159, 0 };
            const std::uint32_t dim6045JoeKuoD6Init[]   =   { 1, 3, 1, 9, 17, 15, 107, 63, 493, 411, 293, 3669, 6143, 3057, 8253, 25491, 58907, 0 };
            const std::uint32_t dim6046JoeKuoD6Init[]   =   { 1, 3, 5, 11, 1, 43, 5, 117, 127, 813, 1881, 3711, 2567, 7819, 5809, 64471, 104221, 0 };
            const std::uint32_t dim6047JoeKuoD6Init[]   =   { 1, 3, 5, 9, 25, 27, 49, 93, 77, 705, 1773, 1745, 4605, 16137, 14621, 62893, 81637, 0 };
            const std::uint32_t dim6048JoeKuoD6Init[]   =   { 1, 3, 1, 15, 9, 29, 41, 101, 291, 763, 1475, 3185, 3661, 10351, 26645, 50375, 59373, 0 };
            const std::uint32_t dim6049JoeKuoD6Init[]   =   { 1, 1, 5, 15, 9, 31, 107, 159, 125, 471, 1023, 2361, 4805, 8073, 21563, 14903, 77801, 0 };
            const std::uint32_t dim6050JoeKuoD6Init[]   =   { 1, 3, 7, 1, 27, 17, 75, 129, 71, 697, 551, 1969, 6597, 13821, 2605, 61783, 74791, 0 };
            const std::uint32_t dim6051JoeKuoD6Init[]   =   { 1, 1, 7, 15, 17, 27, 49, 47, 59, 47, 1671, 2535, 1299, 2387, 24349, 23661, 91123, 0 };
            const std::uint32_t dim6052JoeKuoD6Init[]   =   { 1, 1, 5, 15, 21, 61, 45, 37, 415, 189, 143, 351, 1815, 3479, 2399, 56753, 123893, 0 };
            const std::uint32_t dim6053JoeKuoD6Init[]   =   { 1, 1, 3, 7, 7, 19, 93, 249, 335, 305, 1437, 1329, 2693, 13201, 9589, 61513, 115995, 0 };
            const std::uint32_t dim6054JoeKuoD6Init[]   =   { 1, 1, 1, 11, 21, 57, 33, 205, 235, 253, 751, 259, 6029, 9811, 10231, 36899, 78035, 0 };
            const std::uint32_t dim6055JoeKuoD6Init[]   =   { 1, 1, 1, 11, 13, 25, 115, 195, 111, 913, 1851, 3283, 6083, 11717, 2773, 40727, 493, 0 };
            const std::uint32_t dim6056JoeKuoD6Init[]   =   { 1, 3, 3, 9, 9, 17, 83, 137, 465, 671, 1277, 325, 2767, 12413, 21977, 47525, 23041, 0 };
            const std::uint32_t dim6057JoeKuoD6Init[]   =   { 1, 1, 1, 11, 15, 47, 65, 219, 271, 197, 297, 3195, 1325, 9991, 26385, 46055, 43151, 0 };
            const std::uint32_t dim6058JoeKuoD6Init[]   =   { 1, 1, 1, 13, 31, 21, 39, 89, 127, 629, 367, 2935, 6259, 6627, 15691, 55781, 97251, 0 };
            const std::uint32_t dim6059JoeKuoD6Init[]   =   { 1, 1, 7, 13, 11, 45, 65, 75, 211, 785, 1221, 2087, 7751, 15619, 25489, 28195, 69007, 0 };
            const std::uint32_t dim6060JoeKuoD6Init[]   =   { 1, 3, 5, 15, 27, 37, 75, 111, 487, 219, 233, 583, 6433, 15105, 355, 28331, 21105, 0 };
            const std::uint32_t dim6061JoeKuoD6Init[]   =   { 1, 3, 3, 15, 31, 53, 33, 95, 27, 197, 1727, 1467, 7115, 15479, 26873, 31075, 12793, 0 };
            const std::uint32_t dim6062JoeKuoD6Init[]   =   { 1, 3, 7, 1, 19, 3, 19, 105, 225, 599, 737, 107, 7951, 10193, 31699, 59207, 85619, 0 };
            const std::uint32_t dim6063JoeKuoD6Init[]   =   { 1, 3, 1, 3, 7, 17, 73, 191, 247, 421, 537, 1473, 189, 4219, 29993, 25491, 21189, 0 };
            const std::uint32_t dim6064JoeKuoD6Init[]   =   { 1, 3, 7, 7, 13, 21, 33, 95, 147, 699, 943, 2275, 4093, 6067, 9063, 25503, 111085, 0 };
            const std::uint32_t dim6065JoeKuoD6Init[]   =   { 1, 1, 7, 9, 13, 47, 123, 121, 347, 467, 225, 957, 2329, 14075, 29843, 61753, 97179, 0 };
            const std::uint32_t dim6066JoeKuoD6Init[]   =   { 1, 3, 3, 7, 17, 55, 37, 167, 215, 819, 163, 1747, 4485, 15991, 28011, 36351, 106495, 0 };
            const std::uint32_t dim6067JoeKuoD6Init[]   =   { 1, 1, 3, 9, 25, 5, 83, 199, 209, 395, 1757, 1967, 5739, 2573, 13989, 32145, 4847, 0 };
            const std::uint32_t dim6068JoeKuoD6Init[]   =   { 1, 3, 3, 13, 11, 21, 25, 223, 239, 569, 1877, 299, 8089, 3697, 801, 64775, 26827, 0 };
            const std::uint32_t dim6069JoeKuoD6Init[]   =   { 1, 3, 5, 7, 17, 9, 127, 9, 65, 919, 1073, 2661, 1337, 10065, 30099, 30929, 90067, 0 };
            const std::uint32_t dim6070JoeKuoD6Init[]   =   { 1, 3, 1, 13, 25, 41, 35, 251, 279, 351, 111, 3917, 2815, 7989, 9895, 54859, 126355, 0 };
            const std::uint32_t dim6071JoeKuoD6Init[]   =   { 1, 1, 3, 7, 17, 61, 13, 73, 335, 831, 703, 37, 2765, 13169, 12513, 56301, 13907, 0 };
            const std::uint32_t dim6072JoeKuoD6Init[]   =   { 1, 1, 5, 13, 11, 15, 33, 45, 505, 127, 1723, 17, 4927, 11453, 28859, 9671, 80041, 0 };
            const std::uint32_t dim6073JoeKuoD6Init[]   =   { 1, 3, 1, 5, 9, 1, 25, 147, 281, 601, 243, 2687, 5533, 6725, 11075, 34807, 24619, 0 };
            const std::uint32_t dim6074JoeKuoD6Init[]   =   { 1, 1, 3, 1, 7, 21, 71, 31, 485, 561, 1361, 1237, 8171, 15885, 7941, 4583, 32851, 0 };
            const std::uint32_t dim6075JoeKuoD6Init[]   =   { 1, 3, 7, 1, 5, 35, 95, 155, 283, 959, 577, 1343, 4269, 13481, 30819, 40273, 8711, 0 };
            const std::uint32_t dim6076JoeKuoD6Init[]   =   { 1, 3, 7, 3, 1, 53, 77, 45, 215, 537, 1045, 77, 2791, 3553, 13273, 23819, 62263, 0 };
            const std::uint32_t dim6077JoeKuoD6Init[]   =   { 1, 3, 1, 15, 29, 59, 7, 145, 85, 3, 251, 2691, 7547, 11241, 32295, 24645, 75739, 0 };
            const std::uint32_t dim6078JoeKuoD6Init[]   =   { 1, 1, 5, 9, 19, 9, 39, 163, 303, 233, 2039, 2027, 7169, 2773, 28649, 38317, 66761, 0 };
            const std::uint32_t dim6079JoeKuoD6Init[]   =   { 1, 3, 7, 5, 21, 27, 93, 227, 131, 1019, 1619, 1497, 4043, 1131, 25761, 20173, 99957, 0 };
            const std::uint32_t dim6080JoeKuoD6Init[]   =   { 1, 3, 7, 5, 19, 33, 15, 173, 435, 399, 531, 2001, 3221, 12627, 10153, 24421, 61805, 0 };
            const std::uint32_t dim6081JoeKuoD6Init[]   =   { 1, 3, 1, 9, 11, 3, 69, 105, 289, 183, 1103, 831, 2297, 1613, 18801, 54395, 54243, 0 };
            const std::uint32_t dim6082JoeKuoD6Init[]   =   { 1, 3, 3, 9, 3, 53, 113, 183, 79, 355, 1629, 1061, 3713, 4563, 14365, 43529, 56073, 0 };
            const std::uint32_t dim6083JoeKuoD6Init[]   =   { 1, 3, 7, 11, 31, 39, 107, 139, 187, 873, 225, 33, 4943, 15837, 225, 6407, 85967, 0 };
            const std::uint32_t dim6084JoeKuoD6Init[]   =   { 1, 3, 1, 11, 17, 47, 93, 233, 119, 699, 1429, 2845, 2061, 8887, 20665, 45497, 33107, 0 };
            const std::uint32_t dim6085JoeKuoD6Init[]   =   { 1, 3, 5, 1, 25, 11, 55, 75, 91, 1009, 1887, 3167, 515, 15929, 11659, 57953, 63401, 0 };
            const std::uint32_t dim6086JoeKuoD6Init[]   =   { 1, 1, 3, 15, 27, 59, 103, 53, 353, 553, 2021, 1543, 2785, 9373, 14609, 21213, 19911, 0 };
            const std::uint32_t dim6087JoeKuoD6Init[]   =   { 1, 3, 7, 9, 3, 1, 101, 133, 437, 773, 1399, 1067, 7419, 1793, 16589, 3483, 42065, 0 };
            const std::uint32_t dim6088JoeKuoD6Init[]   =   { 1, 3, 7, 1, 25, 57, 127, 113, 65, 577, 1865, 1527, 6485, 11273, 15803, 39625, 75219, 0 };
            const std::uint32_t dim6089JoeKuoD6Init[]   =   { 1, 3, 5, 9, 7, 63, 29, 89, 155, 45, 1029, 2407, 6783, 4749, 4849, 26639, 54059, 0 };
            const std::uint32_t dim6090JoeKuoD6Init[]   =   { 1, 3, 7, 9, 25, 13, 113, 41, 267, 767, 1071, 1689, 269, 14437, 21255, 39473, 65771, 0 };
            const std::uint32_t dim6091JoeKuoD6Init[]   =   { 1, 3, 1, 15, 5, 3, 77, 43, 391, 763, 59, 1027, 6263, 3715, 31061, 43311, 130725, 0 };
            const std::uint32_t dim6092JoeKuoD6Init[]   =   { 1, 3, 7, 7, 21, 51, 127, 71, 229, 171, 397, 1099, 871, 2717, 1643, 17363, 125979, 0 };
            const std::uint32_t dim6093JoeKuoD6Init[]   =   { 1, 1, 5, 15, 25, 11, 11, 113, 203, 795, 1703, 3901, 1113, 12819, 25345, 46691, 112313, 0 };
            const std::uint32_t dim6094JoeKuoD6Init[]   =   { 1, 3, 7, 5, 1, 59, 91, 81, 325, 483, 595, 1491, 7455, 6699, 199, 35597, 59851, 0 };
            const std::uint32_t dim6095JoeKuoD6Init[]   =   { 1, 3, 5, 1, 3, 33, 43, 195, 201, 575, 1395, 1305, 7001, 2023, 22419, 15233, 120355, 0 };
            const std::uint32_t dim6096JoeKuoD6Init[]   =   { 1, 1, 3, 3, 15, 37, 81, 59, 87, 675, 199, 3231, 4473, 5023, 16753, 51475, 102113, 0 };
            const std::uint32_t dim6097JoeKuoD6Init[]   =   { 1, 1, 7, 9, 13, 39, 65, 9, 51, 565, 1171, 119, 7875, 12149, 6565, 56849, 123235, 0 };
            const std::uint32_t dim6098JoeKuoD6Init[]   =   { 1, 3, 3, 7, 15, 45, 53, 93, 111, 533, 1849, 643, 2265, 10241, 24741, 11559, 74333, 0 };
            const std::uint32_t dim6099JoeKuoD6Init[]   =   { 1, 3, 1, 1, 11, 61, 75, 51, 5, 199, 535, 279, 5821, 6005, 2907, 32521, 74121, 0 };
            const std::uint32_t dim6100JoeKuoD6Init[]   =   { 1, 1, 3, 15, 3, 21, 29, 193, 71, 993, 1719, 1865, 6135, 7683, 12171, 29275, 14539, 0 };
            const std::uint32_t dim6101JoeKuoD6Init[]   =   { 1, 1, 1, 7, 7, 13, 1, 61, 315, 431, 1145, 2067, 5745, 1641, 1047, 55111, 129477, 0 };
            const std::uint32_t dim6102JoeKuoD6Init[]   =   { 1, 1, 5, 1, 21, 43, 115, 193, 153, 573, 1181, 3947, 7809, 11317, 30649, 56891, 47741, 0 };
            const std::uint32_t dim6103JoeKuoD6Init[]   =   { 1, 1, 5, 7, 19, 15, 61, 239, 109, 683, 395, 2869, 3103, 1531, 12019, 45159, 37525, 0 };
            const std::uint32_t dim6104JoeKuoD6Init[]   =   { 1, 1, 5, 7, 29, 55, 45, 7, 353, 659, 591, 3371, 5777, 8475, 2743, 47483, 11983, 0 };
            const std::uint32_t dim6105JoeKuoD6Init[]   =   { 1, 3, 1, 3, 13, 17, 39, 195, 43, 5, 1749, 2559, 5843, 8719, 21421, 58511, 105637, 0 };
            const std::uint32_t dim6106JoeKuoD6Init[]   =   { 1, 3, 5, 5, 5, 21, 29, 63, 387, 301, 567, 3325, 2109, 403, 23053, 24851, 14493, 0 };
            const std::uint32_t dim6107JoeKuoD6Init[]   =   { 1, 1, 3, 3, 17, 57, 107, 131, 85, 855, 1101, 3199, 7159, 14739, 4197, 27943, 113009, 0 };
            const std::uint32_t dim6108JoeKuoD6Init[]   =   { 1, 1, 3, 11, 1, 61, 31, 79, 33, 123, 1509, 507, 6679, 2279, 8465, 37279, 17553, 0 };
            const std::uint32_t dim6109JoeKuoD6Init[]   =   { 1, 3, 1, 15, 7, 33, 11, 71, 217, 609, 1661, 3437, 5497, 13365, 6247, 649, 26407, 0 };
            const std::uint32_t dim6110JoeKuoD6Init[]   =   { 1, 1, 3, 1, 19, 45, 49, 125, 5, 455, 1669, 4083, 253, 10101, 27327, 16401, 120399, 0 };
            const std::uint32_t dim6111JoeKuoD6Init[]   =   { 1, 3, 1, 1, 27, 19, 117, 137, 261, 341, 1697, 457, 7553, 12169, 30049, 49281, 36937, 0 };
            const std::uint32_t dim6112JoeKuoD6Init[]   =   { 1, 1, 1, 3, 9, 49, 33, 13, 461, 545, 1537, 2623, 883, 10921, 5583, 58997, 114183, 0 };
            const std::uint32_t dim6113JoeKuoD6Init[]   =   { 1, 1, 7, 9, 29, 53, 29, 165, 205, 989, 1347, 2343, 7505, 7609, 18503, 51677, 105993, 0 };
            const std::uint32_t dim6114JoeKuoD6Init[]   =   { 1, 1, 1, 13, 1, 29, 59, 121, 297, 659, 1965, 1765, 5255, 10971, 32613, 18763, 41983, 0 };
            const std::uint32_t dim6115JoeKuoD6Init[]   =   { 1, 3, 7, 11, 21, 41, 19, 47, 125, 485, 475, 2745, 4075, 8101, 31227, 4679, 115473, 0 };
            const std::uint32_t dim6116JoeKuoD6Init[]   =   { 1, 3, 3, 7, 21, 23, 55, 65, 223, 1001, 317, 1459, 183, 5139, 26553, 41471, 116373, 0 };
            const std::uint32_t dim6117JoeKuoD6Init[]   =   { 1, 1, 7, 3, 1, 9, 29, 139, 343, 913, 1993, 3139, 3791, 5869, 6057, 23863, 35737, 0 };
            const std::uint32_t dim6118JoeKuoD6Init[]   =   { 1, 3, 3, 3, 7, 21, 77, 197, 239, 467, 35, 591, 1061, 3417, 31811, 38825, 124981, 0 };
            const std::uint32_t dim6119JoeKuoD6Init[]   =   { 1, 3, 3, 1, 21, 29, 5, 213, 417, 111, 1681, 1409, 2899, 16233, 1053, 51235, 87767, 0 };
            const std::uint32_t dim6120JoeKuoD6Init[]   =   { 1, 1, 5, 3, 13, 47, 61, 203, 223, 73, 1947, 3613, 5885, 13567, 7593, 34329, 68597, 0 };
            const std::uint32_t dim6121JoeKuoD6Init[]   =   { 1, 3, 1, 1, 17, 9, 11, 187, 361, 973, 781, 1835, 1539, 12917, 21725, 48279, 115037, 0 };
            const std::uint32_t dim6122JoeKuoD6Init[]   =   { 1, 3, 1, 1, 9, 25, 117, 157, 433, 395, 403, 2183, 3327, 5427, 7505, 2673, 77137, 0 };
            const std::uint32_t dim6123JoeKuoD6Init[]   =   { 1, 1, 7, 15, 31, 15, 27, 155, 441, 837, 1877, 3829, 5139, 16331, 31183, 15803, 95699, 0 };
            const std::uint32_t dim6124JoeKuoD6Init[]   =   { 1, 1, 7, 15, 5, 51, 77, 179, 289, 727, 1763, 2529, 6715, 3967, 29267, 27293, 67953, 0 };
            const std::uint32_t dim6125JoeKuoD6Init[]   =   { 1, 3, 7, 13, 7, 3, 3, 17, 311, 547, 1465, 1413, 3937, 2725, 24523, 12321, 109763, 0 };
            const std::uint32_t dim6126JoeKuoD6Init[]   =   { 1, 3, 5, 15, 9, 5, 87, 135, 281, 97, 2021, 1903, 8007, 10321, 27989, 18993, 110407, 0 };
            const std::uint32_t dim6127JoeKuoD6Init[]   =   { 1, 1, 1, 13, 25, 61, 89, 107, 233, 823, 1375, 3531, 1757, 1577, 29457, 1461, 17217, 0 };
            const std::uint32_t dim6128JoeKuoD6Init[]   =   { 1, 1, 1, 13, 17, 17, 27, 193, 485, 759, 145, 3943, 4183, 14119, 11217, 3793, 1935, 0 };
            const std::uint32_t dim6129JoeKuoD6Init[]   =   { 1, 1, 1, 3, 13, 31, 101, 227, 311, 363, 1925, 1525, 5275, 2385, 15093, 48769, 121189, 0 };
            const std::uint32_t dim6130JoeKuoD6Init[]   =   { 1, 1, 5, 13, 11, 61, 89, 141, 117, 229, 417, 3935, 7249, 13869, 30591, 62763, 67521, 0 };
            const std::uint32_t dim6131JoeKuoD6Init[]   =   { 1, 1, 3, 15, 7, 59, 105, 239, 453, 221, 1101, 395, 2031, 8941, 23155, 7077, 125593, 0 };
            const std::uint32_t dim6132JoeKuoD6Init[]   =   { 1, 1, 1, 11, 7, 55, 99, 31, 305, 371, 1035, 577, 4473, 577, 371, 46093, 69157, 0 };
            const std::uint32_t dim6133JoeKuoD6Init[]   =   { 1, 3, 1, 9, 9, 33, 35, 245, 95, 47, 1623, 2965, 6849, 7269, 5321, 31641, 73321, 0 };
            const std::uint32_t dim6134JoeKuoD6Init[]   =   { 1, 1, 1, 15, 21, 61, 65, 65, 159, 151, 625, 2281, 2993, 1311, 29757, 24703, 71029, 0 };
            const std::uint32_t dim6135JoeKuoD6Init[]   =   { 1, 3, 5, 15, 29, 59, 29, 69, 351, 901, 631, 3501, 7031, 703, 20805, 36437, 94931, 0 };
            const std::uint32_t dim6136JoeKuoD6Init[]   =   { 1, 3, 7, 1, 21, 11, 19, 125, 237, 807, 1651, 2389, 7347, 11759, 27151, 38669, 965, 0 };
            const std::uint32_t dim6137JoeKuoD6Init[]   =   { 1, 1, 5, 1, 15, 41, 1, 105, 89, 127, 895, 29, 2339, 15951, 18633, 2781, 67269, 0 };
            const std::uint32_t dim6138JoeKuoD6Init[]   =   { 1, 1, 5, 15, 25, 7, 3, 33, 375, 447, 203, 2579, 6145, 14015, 9939, 52777, 123181, 0 };
            const std::uint32_t dim6139JoeKuoD6Init[]   =   { 1, 3, 1, 15, 29, 7, 7, 27, 451, 869, 107, 2457, 5557, 11601, 28957, 36181, 41419, 0 };
            const std::uint32_t dim6140JoeKuoD6Init[]   =   { 1, 1, 1, 7, 1, 57, 33, 213, 329, 763, 815, 169, 623, 155, 20529, 20603, 73311, 0 };
            const std::uint32_t dim6141JoeKuoD6Init[]   =   { 1, 3, 5, 7, 25, 21, 7, 217, 159, 89, 1373, 1735, 705, 4093, 13083, 3855, 55875, 0 };
            const std::uint32_t dim6142JoeKuoD6Init[]   =   { 1, 3, 1, 1, 29, 33, 105, 127, 95, 543, 235, 67, 691, 5015, 22139, 18251, 89945, 0 };
            const std::uint32_t dim6143JoeKuoD6Init[]   =   { 1, 1, 3, 11, 27, 53, 105, 83, 337, 331, 1571, 1145, 745, 1845, 17881, 17697, 88139, 0 };
            const std::uint32_t dim6144JoeKuoD6Init[]   =   { 1, 3, 7, 15, 19, 37, 119, 35, 35, 463, 1925, 1665, 673, 12193, 12137, 62371, 10957, 0 };
            const std::uint32_t dim6145JoeKuoD6Init[]   =   { 1, 3, 3, 3, 19, 21, 113, 29, 459, 467, 623, 2661, 857, 16265, 27509, 46555, 18867, 0 };
            const std::uint32_t dim6146JoeKuoD6Init[]   =   { 1, 3, 7, 5, 17, 49, 123, 41, 85, 673, 41, 1871, 7649, 8687, 28269, 64423, 93675, 0 };
            const std::uint32_t dim6147JoeKuoD6Init[]   =   { 1, 3, 3, 3, 7, 23, 101, 171, 181, 527, 65, 2387, 6629, 6089, 17387, 46551, 36143, 0 };
            const std::uint32_t dim6148JoeKuoD6Init[]   =   { 1, 1, 5, 1, 13, 51, 21, 251, 139, 429, 1993, 3767, 1089, 5459, 19407, 41747, 41033, 0 };
            const std::uint32_t dim6149JoeKuoD6Init[]   =   { 1, 1, 1, 11, 15, 9, 81, 91, 73, 969, 1513, 2067, 7959, 2605, 26641, 37631, 124571, 0 };
            const std::uint32_t dim6150JoeKuoD6Init[]   =   { 1, 1, 3, 15, 29, 15, 5, 57, 247, 901, 527, 3325, 5859, 11299, 9871, 63947, 125247, 0 };
            const std::uint32_t dim6151JoeKuoD6Init[]   =   { 1, 3, 1, 5, 1, 35, 75, 21, 307, 43, 1111, 3299, 1647, 3585, 31045, 18217, 95169, 0 };
            const std::uint32_t dim6152JoeKuoD6Init[]   =   { 1, 3, 1, 7, 23, 35, 11, 103, 3, 461, 1915, 4019, 453, 13111, 26941, 43091, 22917, 0 };
            const std::uint32_t dim6153JoeKuoD6Init[]   =   { 1, 1, 5, 5, 1, 61, 121, 167, 475, 5, 1749, 887, 2237, 5055, 7077, 29453, 17691, 0 };
            const std::uint32_t dim6154JoeKuoD6Init[]   =   { 1, 3, 3, 15, 15, 15, 9, 15, 171, 787, 1965, 577, 4507, 7325, 20901, 8557, 111909, 0 };
            const std::uint32_t dim6155JoeKuoD6Init[]   =   { 1, 3, 5, 1, 27, 15, 123, 141, 63, 55, 599, 4095, 1245, 13919, 27485, 49977, 74551, 0 };
            const std::uint32_t dim6156JoeKuoD6Init[]   =   { 1, 3, 5, 9, 21, 61, 79, 119, 7, 573, 1923, 2775, 3127, 12689, 12135, 53429, 130163, 0 };
            const std::uint32_t dim6157JoeKuoD6Init[]   =   { 1, 3, 3, 13, 27, 41, 67, 249, 447, 277, 311, 775, 8187, 10161, 12953, 22885, 121247, 0 };
            const std::uint32_t dim6158JoeKuoD6Init[]   =   { 1, 3, 5, 9, 21, 55, 115, 65, 45, 395, 481, 2063, 6493, 4199, 19219, 27119, 62255, 0 };
            const std::uint32_t dim6159JoeKuoD6Init[]   =   { 1, 1, 3, 13, 7, 41, 3, 127, 383, 923, 1725, 1033, 7731, 11971, 3089, 46459, 98369, 0 };
            const std::uint32_t dim6160JoeKuoD6Init[]   =   { 1, 1, 3, 11, 13, 39, 39, 149, 309, 311, 1491, 807, 2109, 363, 14637, 65429, 124731, 0 };
            const std::uint32_t dim6161JoeKuoD6Init[]   =   { 1, 1, 7, 13, 13, 35, 67, 81, 493, 859, 1177, 237, 4605, 15319, 16669, 16661, 21385, 0 };
            const std::uint32_t dim6162JoeKuoD6Init[]   =   { 1, 1, 3, 7, 7, 39, 57, 103, 239, 753, 221, 1611, 1557, 13317, 27453, 10245, 33839, 0 };
            const std::uint32_t dim6163JoeKuoD6Init[]   =   { 1, 1, 5, 13, 27, 53, 97, 41, 123, 253, 535, 1839, 5827, 7587, 1261, 20313, 65961, 0 };
            const std::uint32_t dim6164JoeKuoD6Init[]   =   { 1, 1, 7, 1, 11, 47, 93, 135, 223, 591, 1087, 3329, 3293, 14207, 6187, 54789, 23781, 0 };
            const std::uint32_t dim6165JoeKuoD6Init[]   =   { 1, 3, 7, 7, 25, 21, 97, 105, 269, 515, 1805, 3711, 3295, 7307, 21065, 65205, 116969, 0 };
            const std::uint32_t dim6166JoeKuoD6Init[]   =   { 1, 3, 1, 11, 25, 37, 21, 89, 109, 581, 1055, 2393, 1291, 1115, 25545, 36383, 93605, 0 };
            const std::uint32_t dim6167JoeKuoD6Init[]   =   { 1, 3, 7, 1, 27, 13, 113, 11, 395, 473, 943, 4045, 5507, 15051, 25203, 2971, 31961, 0 };
            const std::uint32_t dim6168JoeKuoD6Init[]   =   { 1, 1, 5, 5, 27, 35, 57, 219, 67, 949, 659, 203, 5235, 6509, 13731, 61533, 54963, 0 };
            const std::uint32_t dim6169JoeKuoD6Init[]   =   { 1, 3, 1, 1, 15, 39, 85, 13, 347, 99, 25, 3595, 3081, 13617, 14373, 58909, 102181, 0 };
            const std::uint32_t dim6170JoeKuoD6Init[]   =   { 1, 1, 7, 13, 3, 25, 97, 91, 287, 389, 665, 2981, 2301, 12625, 4495, 57489, 68677, 0 };
            const std::uint32_t dim6171JoeKuoD6Init[]   =   { 1, 1, 5, 1, 15, 57, 77, 55, 299, 713, 1457, 3699, 2807, 5549, 467, 47367, 8163, 0 };
            const std::uint32_t dim6172JoeKuoD6Init[]   =   { 1, 1, 7, 3, 23, 45, 91, 251, 501, 193, 1121, 2359, 4781, 12797, 13713, 55171, 927, 0 };
            const std::uint32_t dim6173JoeKuoD6Init[]   =   { 1, 3, 3, 7, 7, 31, 87, 163, 249, 163, 937, 1293, 4827, 10299, 31935, 58787, 80589, 0 };
            const std::uint32_t dim6174JoeKuoD6Init[]   =   { 1, 3, 1, 9, 7, 1, 73, 65, 475, 791, 1429, 3319, 7149, 433, 10373, 44061, 121195, 0 };
            const std::uint32_t dim6175JoeKuoD6Init[]   =   { 1, 1, 5, 9, 9, 61, 27, 249, 435, 437, 1329, 2163, 5859, 13663, 623, 55569, 94283, 0 };
            const std::uint32_t dim6176JoeKuoD6Init[]   =   { 1, 3, 7, 11, 1, 29, 117, 195, 399, 999, 1705, 1325, 6043, 9823, 27335, 30377, 16627, 0 };
            const std::uint32_t dim6177JoeKuoD6Init[]   =   { 1, 1, 1, 15, 5, 11, 63, 185, 15, 741, 1061, 2961, 3455, 5, 26587, 54081, 18107, 0 };
            const std::uint32_t dim6178JoeKuoD6Init[]   =   { 1, 1, 5, 7, 29, 57, 17, 203, 501, 177, 49, 2773, 8069, 12513, 14437, 64489, 58661, 0 };
            const std::uint32_t dim6179JoeKuoD6Init[]   =   { 1, 3, 3, 9, 11, 23, 121, 3, 415, 447, 1773, 135, 5901, 4951, 2683, 437, 126251, 0 };
            const std::uint32_t dim6180JoeKuoD6Init[]   =   { 1, 3, 3, 1, 7, 23, 17, 23, 115, 591, 1075, 3133, 49, 15183, 10615, 37857, 122609, 0 };
            const std::uint32_t dim6181JoeKuoD6Init[]   =   { 1, 1, 3, 3, 13, 49, 63, 37, 275, 763, 1135, 2913, 1563, 11037, 6693, 18799, 32089, 0 };
            const std::uint32_t dim6182JoeKuoD6Init[]   =   { 1, 3, 5, 11, 7, 29, 59, 45, 227, 941, 1947, 2733, 797, 10485, 7071, 14741, 11451, 0 };
            const std::uint32_t dim6183JoeKuoD6Init[]   =   { 1, 1, 1, 9, 21, 19, 77, 97, 75, 991, 187, 1003, 5619, 11013, 3931, 19907, 79723, 0 };
            const std::uint32_t dim6184JoeKuoD6Init[]   =   { 1, 1, 7, 13, 1, 57, 61, 177, 443, 227, 1347, 2665, 2011, 12329, 14137, 37795, 63331, 0 };
            const std::uint32_t dim6185JoeKuoD6Init[]   =   { 1, 3, 3, 9, 31, 59, 87, 93, 485, 635, 901, 1845, 6153, 10797, 1289, 8989, 41717, 0 };
            const std::uint32_t dim6186JoeKuoD6Init[]   =   { 1, 1, 1, 1, 3, 7, 85, 17, 67, 309, 1891, 435, 303, 8011, 32127, 54309, 21457, 0 };
            const std::uint32_t dim6187JoeKuoD6Init[]   =   { 1, 3, 7, 1, 29, 27, 41, 239, 293, 717, 1331, 917, 6145, 7131, 28199, 35093, 103683, 0 };
            const std::uint32_t dim6188JoeKuoD6Init[]   =   { 1, 3, 7, 3, 21, 63, 65, 233, 257, 789, 1095, 505, 4557, 16259, 7397, 24815, 89529, 0 };
            const std::uint32_t dim6189JoeKuoD6Init[]   =   { 1, 3, 3, 11, 29, 41, 55, 17, 335, 715, 779, 2121, 6393, 8887, 32753, 45647, 82665, 0 };
            const std::uint32_t dim6190JoeKuoD6Init[]   =   { 1, 1, 1, 11, 27, 47, 71, 13, 141, 283, 967, 3359, 4309, 6661, 20481, 23175, 50835, 0 };
            const std::uint32_t dim6191JoeKuoD6Init[]   =   { 1, 3, 3, 7, 3, 25, 19, 241, 409, 573, 1565, 3355, 1307, 12205, 18017, 8271, 117007, 0 };
            const std::uint32_t dim6192JoeKuoD6Init[]   =   { 1, 3, 3, 9, 21, 39, 21, 253, 439, 963, 341, 3637, 2275, 1845, 11015, 481, 83369, 0 };
            const std::uint32_t dim6193JoeKuoD6Init[]   =   { 1, 3, 7, 9, 31, 29, 29, 163, 111, 983, 571, 713, 2621, 11569, 13341, 28341, 130381, 0 };
            const std::uint32_t dim6194JoeKuoD6Init[]   =   { 1, 3, 7, 7, 11, 35, 89, 49, 81, 115, 113, 1857, 3527, 14819, 6909, 14659, 23557, 0 };
            const std::uint32_t dim6195JoeKuoD6Init[]   =   { 1, 3, 3, 15, 29, 41, 85, 241, 317, 737, 213, 1667, 5789, 16321, 13991, 36165, 124151, 0 };
            const std::uint32_t dim6196JoeKuoD6Init[]   =   { 1, 3, 1, 3, 31, 1, 75, 99, 495, 241, 1499, 1535, 2033, 2135, 6699, 58893, 37031, 0 };
            const std::uint32_t dim6197JoeKuoD6Init[]   =   { 1, 1, 7, 9, 25, 15, 101, 23, 477, 563, 1691, 2655, 2321, 2323, 4255, 22055, 99661, 0 };
            const std::uint32_t dim6198JoeKuoD6Init[]   =   { 1, 3, 7, 5, 7, 7, 49, 221, 51, 83, 279, 2205, 2939, 2119, 14073, 32839, 108075, 0 };
            const std::uint32_t dim6199JoeKuoD6Init[]   =   { 1, 3, 5, 11, 17, 39, 3, 127, 87, 501, 799, 401, 4439, 9895, 13017, 64975, 67177, 0 };
            const std::uint32_t dim6200JoeKuoD6Init[]   =   { 1, 3, 3, 9, 17, 41, 59, 95, 283, 309, 83, 1293, 6385, 5783, 30115, 33997, 12531, 0 };
            const std::uint32_t dim6201JoeKuoD6Init[]   =   { 1, 3, 5, 3, 7, 31, 69, 171, 225, 409, 1237, 3343, 835, 8039, 16723, 37203, 129047, 0 };
            const std::uint32_t dim6202JoeKuoD6Init[]   =   { 1, 3, 3, 15, 17, 23, 107, 1, 105, 135, 1245, 993, 4101, 7325, 7425, 17379, 98121, 0 };
            const std::uint32_t dim6203JoeKuoD6Init[]   =   { 1, 1, 7, 9, 27, 5, 67, 111, 75, 531, 243, 2239, 2527, 4513, 27059, 40533, 88169, 0 };
            const std::uint32_t dim6204JoeKuoD6Init[]   =   { 1, 3, 5, 7, 21, 63, 57, 15, 75, 679, 1729, 1845, 6259, 8531, 18691, 49321, 101599, 0 };
            const std::uint32_t dim6205JoeKuoD6Init[]   =   { 1, 1, 5, 9, 3, 35, 7, 201, 351, 885, 669, 2339, 5009, 279, 26469, 54597, 67933, 0 };
            const std::uint32_t dim6206JoeKuoD6Init[]   =   { 1, 3, 5, 13, 27, 5, 85, 161, 141, 733, 1017, 2021, 6951, 15595, 21817, 17243, 88607, 0 };
            const std::uint32_t dim6207JoeKuoD6Init[]   =   { 1, 3, 5, 1, 11, 31, 117, 97, 175, 629, 995, 1207, 2941, 5825, 5319, 48191, 9505, 0 };
            const std::uint32_t dim6208JoeKuoD6Init[]   =   { 1, 3, 3, 7, 25, 39, 45, 79, 21, 607, 1593, 1749, 7951, 10425, 17491, 16617, 56903, 0 };
            const std::uint32_t dim6209JoeKuoD6Init[]   =   { 1, 1, 1, 5, 15, 41, 107, 115, 79, 693, 919, 3513, 6793, 6541, 5545, 58583, 27963, 0 };
            const std::uint32_t dim6210JoeKuoD6Init[]   =   { 1, 3, 7, 11, 21, 19, 123, 1, 441, 531, 359, 2117, 2465, 11389, 13489, 32755, 4577, 0 };
            const std::uint32_t dim6211JoeKuoD6Init[]   =   { 1, 1, 5, 13, 7, 7, 7, 127, 201, 377, 1423, 269, 2611, 3339, 19153, 25659, 33069, 0 };
            const std::uint32_t dim6212JoeKuoD6Init[]   =   { 1, 3, 7, 1, 13, 35, 45, 5, 313, 739, 1779, 2983, 1815, 8817, 14239, 3921, 57975, 0 };
            const std::uint32_t dim6213JoeKuoD6Init[]   =   { 1, 3, 1, 11, 9, 39, 33, 111, 39, 255, 159, 2345, 2193, 11475, 12841, 47579, 90309, 0 };
            const std::uint32_t dim6214JoeKuoD6Init[]   =   { 1, 1, 1, 3, 27, 49, 85, 157, 243, 247, 1473, 323, 4631, 1787, 15193, 5533, 104999, 0 };
            const std::uint32_t dim6215JoeKuoD6Init[]   =   { 1, 1, 7, 9, 11, 29, 23, 219, 57, 339, 1797, 409, 6025, 10569, 27409, 15147, 130281, 0 };
            const std::uint32_t dim6216JoeKuoD6Init[]   =   { 1, 1, 7, 1, 31, 31, 113, 229, 63, 877, 319, 2655, 3335, 7743, 19593, 10089, 28215, 0 };
            const std::uint32_t dim6217JoeKuoD6Init[]   =   { 1, 1, 3, 11, 23, 3, 71, 235, 329, 751, 159, 2579, 5363, 12681, 20233, 53855, 16407, 0 };
            const std::uint32_t dim6218JoeKuoD6Init[]   =   { 1, 1, 5, 1, 7, 61, 21, 235, 379, 849, 61, 2969, 6399, 2655, 21635, 16955, 58675, 0 };
            const std::uint32_t dim6219JoeKuoD6Init[]   =   { 1, 3, 7, 7, 29, 15, 5, 11, 143, 699, 1875, 2115, 6633, 6195, 5829, 53633, 111221, 0 };
            const std::uint32_t dim6220JoeKuoD6Init[]   =   { 1, 3, 7, 11, 19, 41, 17, 219, 483, 829, 1233, 3183, 6283, 2363, 25245, 63075, 82733, 0 };
            const std::uint32_t dim6221JoeKuoD6Init[]   =   { 1, 3, 7, 13, 21, 17, 1, 207, 443, 575, 521, 2585, 6875, 14871, 14739, 10211, 127435, 0 };
            const std::uint32_t dim6222JoeKuoD6Init[]   =   { 1, 3, 7, 7, 15, 39, 99, 197, 219, 259, 1723, 3737, 6625, 849, 887, 41293, 53825, 0 };
            const std::uint32_t dim6223JoeKuoD6Init[]   =   { 1, 3, 3, 3, 5, 3, 75, 155, 189, 935, 85, 2273, 1375, 4217, 10709, 58047, 81689, 0 };
            const std::uint32_t dim6224JoeKuoD6Init[]   =   { 1, 3, 5, 5, 27, 27, 107, 229, 179, 887, 91, 421, 7313, 6495, 451, 43859, 40033, 0 };
            const std::uint32_t dim6225JoeKuoD6Init[]   =   { 1, 3, 5, 11, 25, 49, 121, 73, 169, 311, 1387, 1037, 6519, 9317, 26975, 50627, 46805, 0 };
            const std::uint32_t dim6226JoeKuoD6Init[]   =   { 1, 1, 5, 11, 17, 21, 19, 125, 387, 697, 1017, 1759, 7295, 9869, 28241, 9367, 119255, 0 };
            const std::uint32_t dim6227JoeKuoD6Init[]   =   { 1, 1, 7, 5, 29, 27, 87, 187, 95, 625, 933, 1751, 5253, 313, 30841, 16349, 67347, 0 };
            const std::uint32_t dim6228JoeKuoD6Init[]   =   { 1, 1, 3, 3, 15, 51, 23, 101, 183, 267, 243, 711, 983, 12461, 17801, 1429, 47273, 0 };
            const std::uint32_t dim6229JoeKuoD6Init[]   =   { 1, 1, 1, 3, 17, 3, 73, 67, 49, 449, 879, 2559, 401, 11983, 13697, 12023, 78855, 0 };
            const std::uint32_t dim6230JoeKuoD6Init[]   =   { 1, 3, 7, 15, 25, 25, 43, 81, 141, 161, 595, 621, 1165, 10869, 22875, 6741, 90017, 0 };
            const std::uint32_t dim6231JoeKuoD6Init[]   =   { 1, 3, 5, 11, 13, 57, 53, 219, 145, 937, 769, 1961, 4725, 3335, 12623, 8335, 46305, 0 };
            const std::uint32_t dim6232JoeKuoD6Init[]   =   { 1, 1, 3, 5, 7, 39, 19, 101, 313, 583, 483, 2515, 125, 5211, 2559, 11937, 126717, 0 };
            const std::uint32_t dim6233JoeKuoD6Init[]   =   { 1, 3, 1, 7, 7, 1, 117, 49, 231, 133, 381, 697, 927, 8263, 26529, 64881, 25059, 0 };
            const std::uint32_t dim6234JoeKuoD6Init[]   =   { 1, 1, 1, 15, 11, 25, 77, 149, 233, 215, 1239, 3045, 99, 11183, 30279, 32271, 100943, 0 };
            const std::uint32_t dim6235JoeKuoD6Init[]   =   { 1, 1, 5, 7, 31, 25, 1, 51, 221, 607, 1733, 2145, 6765, 7011, 16927, 29257, 2445, 0 };
            const std::uint32_t dim6236JoeKuoD6Init[]   =   { 1, 3, 5, 1, 19, 23, 123, 93, 381, 295, 765, 2335, 8025, 14003, 4801, 54243, 57297, 0 };
            const std::uint32_t dim6237JoeKuoD6Init[]   =   { 1, 1, 7, 9, 9, 31, 63, 191, 495, 527, 251, 2119, 1663, 209, 7445, 1441, 4075, 0 };
            const std::uint32_t dim6238JoeKuoD6Init[]   =   { 1, 3, 5, 5, 13, 17, 97, 79, 369, 55, 677, 2031, 7315, 4769, 31659, 21975, 22061, 0 };
            const std::uint32_t dim6239JoeKuoD6Init[]   =   { 1, 3, 3, 7, 3, 63, 121, 243, 39, 917, 1917, 297, 7241, 1565, 31675, 14443, 67239, 0 };
            const std::uint32_t dim6240JoeKuoD6Init[]   =   { 1, 3, 7, 1, 13, 25, 51, 65, 145, 475, 1853, 4023, 5121, 14411, 15993, 42165, 13615, 0 };
            const std::uint32_t dim6241JoeKuoD6Init[]   =   { 1, 3, 3, 1, 3, 51, 75, 29, 169, 311, 1309, 2929, 7669, 1507, 14605, 32667, 103861, 0 };
            const std::uint32_t dim6242JoeKuoD6Init[]   =   { 1, 3, 7, 1, 23, 37, 89, 211, 137, 495, 1469, 3425, 1167, 12429, 27301, 46857, 83007, 0 };
            const std::uint32_t dim6243JoeKuoD6Init[]   =   { 1, 3, 7, 7, 27, 37, 33, 129, 73, 23, 761, 119, 6217, 4749, 20835, 47477, 33665, 0 };
            const std::uint32_t dim6244JoeKuoD6Init[]   =   { 1, 1, 3, 5, 29, 35, 79, 21, 183, 933, 43, 3149, 5273, 12159, 20695, 5387, 23569, 0 };
            const std::uint32_t dim6245JoeKuoD6Init[]   =   { 1, 1, 5, 5, 3, 11, 57, 205, 349, 657, 1509, 3693, 5495, 11865, 13861, 62215, 94141, 0 };
            const std::uint32_t dim6246JoeKuoD6Init[]   =   { 1, 3, 1, 7, 17, 43, 117, 119, 75, 849, 1247, 643, 2691, 2289, 9759, 18683, 68649, 0 };
            const std::uint32_t dim6247JoeKuoD6Init[]   =   { 1, 1, 1, 15, 5, 55, 89, 177, 427, 701, 735, 2993, 5293, 15395, 567, 5501, 102393, 0 };
            const std::uint32_t dim6248JoeKuoD6Init[]   =   { 1, 3, 3, 15, 5, 37, 73, 111, 9, 141, 407, 1579, 6691, 11843, 6377, 64181, 97347, 0 };
            const std::uint32_t dim6249JoeKuoD6Init[]   =   { 1, 1, 5, 1, 9, 17, 71, 127, 285, 929, 1243, 2605, 359, 14589, 32603, 39879, 115901, 0 };
            const std::uint32_t dim6250JoeKuoD6Init[]   =   { 1, 3, 7, 15, 3, 27, 91, 121, 47, 631, 1589, 385, 5997, 14077, 21285, 33895, 36985, 0 };
            const std::uint32_t dim6251JoeKuoD6Init[]   =   { 1, 3, 3, 9, 1, 47, 89, 79, 213, 27, 547, 1703, 4035, 13205, 4341, 21895, 34247, 0 };
            const std::uint32_t dim6252JoeKuoD6Init[]   =   { 1, 3, 5, 7, 9, 9, 47, 89, 231, 857, 297, 2949, 2715, 1275, 14427, 20227, 21569, 0 };
            const std::uint32_t dim6253JoeKuoD6Init[]   =   { 1, 3, 1, 3, 15, 57, 61, 183, 377, 477, 1135, 1729, 2863, 8607, 29241, 34983, 84443, 0 };
            const std::uint32_t dim6254JoeKuoD6Init[]   =   { 1, 1, 7, 7, 5, 53, 91, 149, 71, 41, 1025, 3945, 3989, 15853, 20903, 26943, 99841, 0 };
            const std::uint32_t dim6255JoeKuoD6Init[]   =   { 1, 3, 3, 3, 29, 21, 59, 217, 483, 257, 331, 657, 2935, 945, 9821, 42501, 98087, 0 };
            const std::uint32_t dim6256JoeKuoD6Init[]   =   { 1, 3, 5, 3, 17, 39, 123, 103, 109, 957, 853, 3821, 555, 10869, 27673, 38315, 83105, 0 };
            const std::uint32_t dim6257JoeKuoD6Init[]   =   { 1, 3, 1, 3, 27, 7, 97, 57, 429, 53, 1791, 1405, 4113, 8435, 12845, 21567, 91559, 0 };
            const std::uint32_t dim6258JoeKuoD6Init[]   =   { 1, 3, 3, 1, 17, 61, 125, 77, 225, 395, 945, 3213, 1363, 15947, 27049, 4389, 64037, 0 };
            const std::uint32_t dim6259JoeKuoD6Init[]   =   { 1, 1, 1, 3, 15, 51, 15, 189, 449, 989, 939, 985, 6929, 13779, 25011, 22277, 72543, 0 };
            const std::uint32_t dim6260JoeKuoD6Init[]   =   { 1, 3, 3, 1, 25, 53, 5, 219, 195, 703, 163, 1405, 821, 6797, 14329, 1675, 96653, 0 };
            const std::uint32_t dim6261JoeKuoD6Init[]   =   { 1, 1, 7, 13, 7, 1, 45, 135, 369, 125, 711, 2509, 131, 13663, 29769, 19497, 116779, 0 };
            const std::uint32_t dim6262JoeKuoD6Init[]   =   { 1, 1, 7, 15, 23, 25, 7, 225, 435, 835, 1981, 2537, 5727, 15961, 30089, 58905, 100339, 0 };
            const std::uint32_t dim6263JoeKuoD6Init[]   =   { 1, 3, 7, 3, 19, 9, 79, 63, 371, 419, 1357, 3649, 7987, 14541, 6631, 50555, 84217, 0 };
            const std::uint32_t dim6264JoeKuoD6Init[]   =   { 1, 3, 3, 9, 7, 61, 11, 157, 99, 95, 945, 2803, 1703, 117, 12891, 21817, 84259, 0 };
            const std::uint32_t dim6265JoeKuoD6Init[]   =   { 1, 3, 7, 7, 25, 37, 111, 99, 65, 599, 1313, 2557, 5489, 3625, 7429, 19309, 78111, 0 };
            const std::uint32_t dim6266JoeKuoD6Init[]   =   { 1, 3, 1, 1, 19, 15, 85, 253, 347, 315, 1349, 983, 2507, 4155, 15311, 43535, 101409, 0 };
            const std::uint32_t dim6267JoeKuoD6Init[]   =   { 1, 3, 3, 3, 1, 55, 3, 57, 375, 107, 177, 1673, 6871, 7137, 10297, 65363, 42293, 0 };
            const std::uint32_t dim6268JoeKuoD6Init[]   =   { 1, 1, 1, 3, 9, 5, 83, 45, 139, 893, 63, 2859, 6333, 15591, 18491, 26387, 25573, 0 };
            const std::uint32_t dim6269JoeKuoD6Init[]   =   { 1, 1, 7, 15, 1, 39, 113, 127, 503, 617, 1367, 1855, 185, 4233, 5787, 8265, 42097, 0 };
            const std::uint32_t dim6270JoeKuoD6Init[]   =   { 1, 1, 3, 11, 11, 41, 119, 165, 331, 625, 81, 2495, 7247, 9139, 15269, 31447, 128425, 0 };
            const std::uint32_t dim6271JoeKuoD6Init[]   =   { 1, 1, 5, 5, 17, 35, 39, 1, 91, 563, 1841, 2975, 1233, 3837, 22145, 36719, 104503, 0 };
            const std::uint32_t dim6272JoeKuoD6Init[]   =   { 1, 1, 7, 3, 23, 35, 77, 69, 271, 487, 921, 2597, 8011, 13037, 6001, 20519, 32673, 0 };
            const std::uint32_t dim6273JoeKuoD6Init[]   =   { 1, 1, 1, 1, 29, 17, 11, 145, 473, 877, 813, 727, 6805, 3563, 13371, 22169, 17239, 0 };
            const std::uint32_t dim6274JoeKuoD6Init[]   =   { 1, 1, 1, 13, 17, 13, 1, 125, 313, 423, 1079, 2401, 2325, 2219, 24071, 25613, 34163, 0 };
            const std::uint32_t dim6275JoeKuoD6Init[]   =   { 1, 1, 5, 7, 29, 33, 53, 215, 11, 555, 555, 1965, 3643, 5433, 12923, 59655, 25339, 0 };
            const std::uint32_t dim6276JoeKuoD6Init[]   =   { 1, 3, 3, 3, 23, 37, 119, 117, 459, 359, 1849, 1019, 433, 15391, 5625, 52649, 81313, 0 };
            const std::uint32_t dim6277JoeKuoD6Init[]   =   { 1, 3, 3, 1, 21, 31, 121, 161, 113, 667, 863, 105, 3805, 14459, 28235, 24543, 89755, 0 };
            const std::uint32_t dim6278JoeKuoD6Init[]   =   { 1, 1, 5, 15, 17, 37, 15, 111, 511, 477, 611, 955, 2591, 16137, 14179, 30995, 129575, 0 };
            const std::uint32_t dim6279JoeKuoD6Init[]   =   { 1, 3, 3, 3, 21, 49, 25, 37, 287, 263, 851, 1015, 8133, 9429, 10959, 64483, 82533, 0 };
            const std::uint32_t dim6280JoeKuoD6Init[]   =   { 1, 1, 5, 1, 25, 19, 49, 159, 155, 443, 975, 1413, 321, 7871, 22935, 57303, 124027, 0 };
            const std::uint32_t dim6281JoeKuoD6Init[]   =   { 1, 3, 1, 1, 19, 45, 47, 89, 409, 509, 1249, 2445, 2053, 3781, 7517, 61869, 125137, 0 };
            const std::uint32_t dim6282JoeKuoD6Init[]   =   { 1, 1, 5, 13, 27, 57, 45, 43, 361, 329, 1321, 771, 4665, 12245, 18993, 15121, 127485, 0 };
            const std::uint32_t dim6283JoeKuoD6Init[]   =   { 1, 3, 3, 7, 3, 41, 127, 75, 485, 821, 497, 2649, 6423, 12419, 31421, 9441, 63645, 0 };
            const std::uint32_t dim6284JoeKuoD6Init[]   =   { 1, 1, 3, 5, 19, 61, 91, 35, 311, 287, 449, 3955, 5805, 5631, 25613, 55409, 104545, 0 };
            const std::uint32_t dim6285JoeKuoD6Init[]   =   { 1, 3, 7, 11, 27, 19, 27, 53, 19, 35, 1687, 3923, 3379, 10435, 15053, 12343, 89077, 0 };
            const std::uint32_t dim6286JoeKuoD6Init[]   =   { 1, 3, 5, 13, 31, 41, 15, 239, 349, 533, 1771, 737, 6503, 14355, 18781, 27805, 79049, 0 };
            const std::uint32_t dim6287JoeKuoD6Init[]   =   { 1, 3, 1, 3, 13, 11, 69, 227, 169, 873, 533, 2217, 1047, 12415, 12271, 22447, 14163, 0 };
            const std::uint32_t dim6288JoeKuoD6Init[]   =   { 1, 1, 3, 9, 7, 31, 23, 155, 133, 305, 1569, 521, 201, 10339, 16999, 29163, 32817, 0 };
            const std::uint32_t dim6289JoeKuoD6Init[]   =   { 1, 1, 1, 5, 31, 57, 43, 223, 121, 803, 357, 1855, 4321, 10245, 25725, 2543, 47395, 0 };
            const std::uint32_t dim6290JoeKuoD6Init[]   =   { 1, 3, 5, 9, 3, 5, 47, 189, 217, 899, 1455, 691, 1277, 7861, 3627, 14895, 41109, 0 };
            const std::uint32_t dim6291JoeKuoD6Init[]   =   { 1, 3, 7, 3, 29, 9, 37, 63, 453, 709, 921, 771, 8069, 239, 22639, 59937, 10635, 0 };
            const std::uint32_t dim6292JoeKuoD6Init[]   =   { 1, 3, 7, 1, 11, 51, 79, 131, 225, 757, 549, 1605, 3921, 1849, 16307, 29809, 120597, 0 };
            const std::uint32_t dim6293JoeKuoD6Init[]   =   { 1, 3, 7, 7, 1, 45, 33, 185, 23, 881, 1941, 4093, 4741, 11633, 2059, 32007, 11103, 0 };
            const std::uint32_t dim6294JoeKuoD6Init[]   =   { 1, 3, 5, 11, 17, 21, 43, 205, 363, 559, 697, 4057, 631, 6697, 883, 61705, 102791, 0 };
            const std::uint32_t dim6295JoeKuoD6Init[]   =   { 1, 1, 7, 9, 29, 35, 109, 85, 373, 321, 415, 2969, 6163, 6999, 9999, 36435, 125267, 0 };
            const std::uint32_t dim6296JoeKuoD6Init[]   =   { 1, 1, 7, 11, 25, 9, 113, 91, 337, 889, 947, 2093, 5289, 1367, 13297, 36155, 21825, 0 };
            const std::uint32_t dim6297JoeKuoD6Init[]   =   { 1, 1, 3, 9, 17, 25, 35, 79, 275, 687, 335, 1181, 7327, 3729, 1561, 27441, 114355, 0 };
            const std::uint32_t dim6298JoeKuoD6Init[]   =   { 1, 3, 3, 11, 25, 41, 27, 89, 115, 361, 871, 1497, 5735, 6365, 1737, 14277, 63847, 0 };
            const std::uint32_t dim6299JoeKuoD6Init[]   =   { 1, 3, 7, 7, 1, 63, 31, 73, 289, 67, 277, 1821, 4883, 10795, 11755, 15471, 105871, 0 };
            const std::uint32_t dim6300JoeKuoD6Init[]   =   { 1, 3, 7, 9, 23, 17, 37, 179, 409, 957, 373, 2393, 2363, 6735, 28737, 41927, 115735, 0 };
            const std::uint32_t dim6301JoeKuoD6Init[]   =   { 1, 1, 3, 9, 15, 43, 111, 61, 455, 181, 1643, 3063, 4311, 13705, 29993, 21731, 25243, 0 };
            const std::uint32_t dim6302JoeKuoD6Init[]   =   { 1, 1, 1, 15, 13, 13, 69, 187, 91, 395, 209, 3477, 4649, 7727, 30557, 14719, 1953, 0 };
            const std::uint32_t dim6303JoeKuoD6Init[]   =   { 1, 1, 1, 15, 9, 39, 119, 193, 459, 135, 567, 25, 4583, 8401, 22161, 14771, 74165, 0 };
            const std::uint32_t dim6304JoeKuoD6Init[]   =   { 1, 1, 3, 7, 5, 39, 77, 149, 293, 585, 1245, 3615, 357, 11613, 13865, 40227, 41023, 0 };
            const std::uint32_t dim6305JoeKuoD6Init[]   =   { 1, 1, 7, 9, 9, 37, 5, 177, 121, 181, 771, 733, 7683, 4855, 13629, 8349, 46137, 0 };
            const std::uint32_t dim6306JoeKuoD6Init[]   =   { 1, 1, 3, 13, 3, 37, 73, 69, 281, 109, 563, 1427, 5127, 8957, 16749, 41489, 49531, 0 };
            const std::uint32_t dim6307JoeKuoD6Init[]   =   { 1, 1, 7, 11, 29, 63, 79, 127, 95, 809, 1175, 1567, 6353, 7505, 26551, 5073, 53733, 0 };
            const std::uint32_t dim6308JoeKuoD6Init[]   =   { 1, 1, 1, 5, 25, 41, 59, 103, 59, 365, 1111, 3909, 3749, 14889, 3639, 10435, 45407, 0 };
            const std::uint32_t dim6309JoeKuoD6Init[]   =   { 1, 1, 1, 5, 3, 61, 93, 199, 97, 779, 67, 241, 6197, 6785, 16869, 7573, 46745, 0 };
            const std::uint32_t dim6310JoeKuoD6Init[]   =   { 1, 1, 5, 9, 27, 29, 21, 69, 165, 661, 1245, 1265, 2979, 9685, 17781, 23329, 48029, 0 };
            const std::uint32_t dim6311JoeKuoD6Init[]   =   { 1, 1, 1, 7, 7, 23, 39, 197, 169, 561, 499, 2197, 4371, 157, 6837, 44635, 94861, 0 };
            const std::uint32_t dim6312JoeKuoD6Init[]   =   { 1, 1, 5, 13, 7, 5, 9, 207, 321, 243, 899, 2967, 3553, 15413, 8961, 55039, 6459, 0 };
            const std::uint32_t dim6313JoeKuoD6Init[]   =   { 1, 3, 5, 3, 13, 25, 33, 145, 45, 979, 33, 2211, 7003, 11147, 11327, 55151, 30697, 0 };
            const std::uint32_t dim6314JoeKuoD6Init[]   =   { 1, 1, 3, 13, 7, 51, 25, 229, 231, 115, 1815, 3867, 1533, 15259, 8067, 64803, 87535, 0 };
            const std::uint32_t dim6315JoeKuoD6Init[]   =   { 1, 1, 3, 3, 21, 51, 101, 49, 227, 393, 1659, 955, 545, 7395, 31563, 5499, 130541, 0 };
            const std::uint32_t dim6316JoeKuoD6Init[]   =   { 1, 3, 1, 1, 21, 41, 57, 161, 269, 35, 893, 1817, 857, 7027, 973, 12529, 46659, 0 };
            const std::uint32_t dim6317JoeKuoD6Init[]   =   { 1, 1, 3, 7, 17, 35, 23, 29, 335, 725, 453, 1051, 6019, 7595, 29451, 1853, 116615, 0 };
            const std::uint32_t dim6318JoeKuoD6Init[]   =   { 1, 3, 3, 1, 3, 55, 73, 187, 213, 329, 997, 703, 5829, 7903, 1081, 33359, 119123, 0 };
            const std::uint32_t dim6319JoeKuoD6Init[]   =   { 1, 3, 3, 15, 29, 55, 15, 17, 245, 117, 1735, 767, 4457, 8803, 17621, 26925, 72487, 0 };
            const std::uint32_t dim6320JoeKuoD6Init[]   =   { 1, 3, 5, 3, 25, 7, 119, 139, 159, 199, 317, 3875, 8115, 7581, 29239, 50225, 48459, 0 };
            const std::uint32_t dim6321JoeKuoD6Init[]   =   { 1, 3, 7, 11, 11, 41, 107, 225, 395, 545, 259, 2379, 6709, 11669, 14545, 43663, 69979, 0 };
            const std::uint32_t dim6322JoeKuoD6Init[]   =   { 1, 3, 5, 13, 23, 45, 73, 137, 447, 305, 117, 2659, 7989, 233, 31991, 60495, 571, 0 };
            const std::uint32_t dim6323JoeKuoD6Init[]   =   { 1, 3, 7, 9, 1, 37, 31, 1, 433, 701, 159, 3811, 4529, 6697, 7121, 31107, 61555, 0 };
            const std::uint32_t dim6324JoeKuoD6Init[]   =   { 1, 3, 5, 5, 13, 21, 81, 63, 95, 741, 1189, 1567, 1223, 12371, 28435, 10537, 53785, 0 };
            const std::uint32_t dim6325JoeKuoD6Init[]   =   { 1, 1, 1, 11, 17, 31, 67, 121, 281, 593, 561, 1759, 387, 9639, 28595, 22473, 4935, 0 };
            const std::uint32_t dim6326JoeKuoD6Init[]   =   { 1, 3, 7, 3, 5, 43, 59, 151, 351, 263, 297, 423, 1681, 3785, 15171, 7145, 57531, 0 };
            const std::uint32_t dim6327JoeKuoD6Init[]   =   { 1, 3, 7, 15, 9, 35, 105, 189, 261, 175, 1669, 1289, 5401, 12801, 19585, 48169, 93195, 0 };
            const std::uint32_t dim6328JoeKuoD6Init[]   =   { 1, 1, 7, 1, 31, 41, 23, 237, 151, 549, 1079, 2933, 5509, 15593, 1791, 15757, 44607, 0 };
            const std::uint32_t dim6329JoeKuoD6Init[]   =   { 1, 1, 1, 3, 29, 1, 59, 115, 13, 999, 1179, 3561, 2749, 10059, 12861, 6797, 11793, 0 };
            const std::uint32_t dim6330JoeKuoD6Init[]   =   { 1, 3, 3, 7, 11, 5, 23, 217, 101, 775, 1497, 4047, 2427, 5117, 9683, 28895, 27557, 0 };
            const std::uint32_t dim6331JoeKuoD6Init[]   =   { 1, 3, 7, 5, 31, 55, 99, 65, 55, 587, 1271, 2277, 7947, 12995, 13149, 4463, 37625, 0 };
            const std::uint32_t dim6332JoeKuoD6Init[]   =   { 1, 1, 7, 11, 3, 63, 23, 191, 125, 365, 1153, 2657, 6763, 4557, 21643, 26885, 36753, 0 };
            const std::uint32_t dim6333JoeKuoD6Init[]   =   { 1, 1, 1, 15, 25, 15, 111, 135, 507, 745, 1947, 2545, 4329, 14325, 8187, 52021, 63401, 0 };
            const std::uint32_t dim6334JoeKuoD6Init[]   =   { 1, 1, 3, 3, 27, 25, 19, 211, 393, 467, 1015, 2495, 7135, 495, 10385, 26961, 49325, 0 };
            const std::uint32_t dim6335JoeKuoD6Init[]   =   { 1, 1, 3, 5, 15, 35, 3, 203, 337, 337, 703, 1989, 6869, 6055, 21095, 4749, 125669, 0 };
            const std::uint32_t dim6336JoeKuoD6Init[]   =   { 1, 1, 5, 1, 31, 39, 57, 101, 419, 717, 1489, 199, 5729, 3003, 2607, 64593, 11515, 0 };
            const std::uint32_t dim6337JoeKuoD6Init[]   =   { 1, 3, 7, 13, 15, 3, 33, 61, 17, 433, 1097, 957, 5351, 3043, 3679, 44881, 126909, 0 };
            const std::uint32_t dim6338JoeKuoD6Init[]   =   { 1, 1, 3, 11, 5, 1, 121, 175, 119, 367, 399, 2527, 2157, 2667, 31069, 24797, 119621, 0 };
            const std::uint32_t dim6339JoeKuoD6Init[]   =   { 1, 3, 1, 7, 27, 47, 115, 229, 455, 775, 73, 837, 1181, 3457, 4057, 33907, 67151, 0 };
            const std::uint32_t dim6340JoeKuoD6Init[]   =   { 1, 3, 3, 1, 7, 51, 71, 177, 463, 921, 393, 3137, 1225, 5709, 303, 20597, 77581, 0 };
            const std::uint32_t dim6341JoeKuoD6Init[]   =   { 1, 3, 5, 3, 31, 1, 93, 53, 177, 433, 1471, 2191, 4471, 9211, 19397, 57727, 60367, 0 };
            const std::uint32_t dim6342JoeKuoD6Init[]   =   { 1, 1, 3, 11, 29, 55, 121, 89, 67, 869, 1631, 2657, 7357, 7159, 22449, 16357, 20077, 0 };
            const std::uint32_t dim6343JoeKuoD6Init[]   =   { 1, 3, 7, 15, 11, 39, 127, 63, 211, 359, 971, 1221, 1909, 9963, 7827, 60923, 98495, 0 };
            const std::uint32_t dim6344JoeKuoD6Init[]   =   { 1, 1, 7, 9, 23, 47, 47, 85, 307, 471, 1287, 3825, 5451, 15151, 15647, 63043, 92443, 0 };
            const std::uint32_t dim6345JoeKuoD6Init[]   =   { 1, 3, 7, 5, 19, 11, 11, 27, 307, 695, 99, 1037, 1997, 13673, 591, 8183, 82197, 0 };
            const std::uint32_t dim6346JoeKuoD6Init[]   =   { 1, 3, 5, 5, 3, 53, 109, 227, 503, 855, 1269, 3903, 5049, 10647, 21751, 58707, 78311, 0 };
            const std::uint32_t dim6347JoeKuoD6Init[]   =   { 1, 1, 3, 11, 31, 3, 51, 211, 285, 919, 487, 3393, 3463, 2271, 8053, 56791, 33763, 0 };
            const std::uint32_t dim6348JoeKuoD6Init[]   =   { 1, 3, 3, 5, 21, 15, 5, 5, 327, 809, 915, 1365, 7323, 4247, 31603, 26261, 80389, 0 };
            const std::uint32_t dim6349JoeKuoD6Init[]   =   { 1, 3, 7, 7, 15, 33, 31, 221, 291, 815, 1307, 929, 3249, 14573, 13613, 59509, 59741, 0 };
            const std::uint32_t dim6350JoeKuoD6Init[]   =   { 1, 3, 7, 15, 19, 41, 61, 27, 353, 965, 1901, 87, 2669, 12757, 29723, 47165, 16521, 0 };
            const std::uint32_t dim6351JoeKuoD6Init[]   =   { 1, 3, 5, 3, 11, 43, 97, 215, 361, 901, 1425, 4063, 5327, 14119, 457, 43145, 107401, 0 };
            const std::uint32_t dim6352JoeKuoD6Init[]   =   { 1, 1, 3, 15, 19, 37, 101, 69, 131, 927, 897, 477, 7641, 4299, 21213, 26017, 123801, 0 };
            const std::uint32_t dim6353JoeKuoD6Init[]   =   { 1, 3, 7, 7, 19, 5, 11, 51, 277, 985, 1071, 3437, 6595, 9547, 11855, 64249, 30957, 0 };
            const std::uint32_t dim6354JoeKuoD6Init[]   =   { 1, 1, 7, 9, 21, 41, 89, 113, 61, 235, 685, 1419, 7619, 9863, 21221, 28685, 53409, 0 };
            const std::uint32_t dim6355JoeKuoD6Init[]   =   { 1, 1, 1, 1, 27, 1, 19, 3, 473, 827, 269, 1659, 2621, 12347, 13359, 64687, 99293, 0 };
            const std::uint32_t dim6356JoeKuoD6Init[]   =   { 1, 3, 7, 7, 29, 37, 61, 49, 215, 883, 625, 2671, 3743, 4517, 2075, 64865, 58611, 0 };
            const std::uint32_t dim6357JoeKuoD6Init[]   =   { 1, 3, 3, 7, 15, 11, 35, 37, 255, 781, 613, 3587, 7643, 13081, 32467, 14427, 15235, 0 };
            const std::uint32_t dim6358JoeKuoD6Init[]   =   { 1, 1, 1, 11, 31, 47, 107, 65, 489, 377, 425, 3453, 2901, 9999, 7687, 13311, 103947, 0 };
            const std::uint32_t dim6359JoeKuoD6Init[]   =   { 1, 3, 3, 7, 9, 17, 7, 107, 33, 545, 407, 3335, 7563, 14315, 32725, 8483, 69093, 0 };
            const std::uint32_t dim6360JoeKuoD6Init[]   =   { 1, 1, 1, 5, 17, 9, 87, 229, 417, 769, 423, 569, 7073, 8705, 24487, 63743, 69807, 0 };
            const std::uint32_t dim6361JoeKuoD6Init[]   =   { 1, 3, 1, 9, 1, 29, 75, 25, 483, 259, 1941, 1533, 8147, 14127, 24087, 37475, 130961, 0 };
            const std::uint32_t dim6362JoeKuoD6Init[]   =   { 1, 3, 3, 11, 15, 15, 51, 45, 215, 283, 1687, 185, 4521, 12205, 13041, 33283, 77007, 0 };
            const std::uint32_t dim6363JoeKuoD6Init[]   =   { 1, 1, 3, 3, 5, 47, 107, 67, 325, 87, 1831, 2845, 1645, 1741, 10811, 8983, 58515, 0 };
            const std::uint32_t dim6364JoeKuoD6Init[]   =   { 1, 3, 1, 13, 19, 17, 1, 151, 411, 915, 1739, 3781, 4939, 15767, 25897, 7205, 17285, 0 };
            const std::uint32_t dim6365JoeKuoD6Init[]   =   { 1, 3, 5, 15, 19, 1, 125, 33, 321, 325, 639, 4013, 967, 4347, 19743, 13445, 61229, 0 };
            const std::uint32_t dim6366JoeKuoD6Init[]   =   { 1, 3, 3, 13, 13, 37, 71, 85, 51, 775, 973, 739, 4341, 15707, 12221, 24321, 48073, 0 };
            const std::uint32_t dim6367JoeKuoD6Init[]   =   { 1, 1, 7, 13, 15, 13, 9, 211, 331, 429, 1323, 3027, 1091, 13311, 289, 57789, 93261, 0 };
            const std::uint32_t dim6368JoeKuoD6Init[]   =   { 1, 1, 1, 1, 27, 7, 13, 27, 67, 573, 455, 2353, 113, 11831, 9069, 4503, 89291, 0 };
            const std::uint32_t dim6369JoeKuoD6Init[]   =   { 1, 1, 1, 7, 21, 63, 47, 39, 419, 991, 1623, 11, 3153, 12633, 9425, 65087, 44935, 0 };
            const std::uint32_t dim6370JoeKuoD6Init[]   =   { 1, 3, 1, 7, 23, 11, 15, 11, 99, 543, 1739, 3955, 5883, 12469, 7529, 14177, 1945, 0 };
            const std::uint32_t dim6371JoeKuoD6Init[]   =   { 1, 3, 1, 3, 5, 17, 31, 251, 387, 311, 725, 3827, 6835, 5065, 3141, 43441, 87955, 0 };
            const std::uint32_t dim6372JoeKuoD6Init[]   =   { 1, 1, 1, 11, 25, 7, 75, 135, 67, 589, 889, 3429, 155, 9081, 28653, 8059, 57251, 0 };
            const std::uint32_t dim6373JoeKuoD6Init[]   =   { 1, 3, 5, 15, 21, 15, 103, 149, 311, 407, 1391, 717, 1765, 14887, 14381, 37483, 29587, 0 };
            const std::uint32_t dim6374JoeKuoD6Init[]   =   { 1, 3, 5, 5, 19, 31, 93, 5, 507, 193, 1735, 3841, 7895, 9853, 10317, 14867, 49529, 0 };
            const std::uint32_t dim6375JoeKuoD6Init[]   =   { 1, 3, 7, 7, 19, 3, 99, 201, 479, 313, 693, 3435, 5453, 1157, 23127, 49005, 20167, 0 };
            const std::uint32_t dim6376JoeKuoD6Init[]   =   { 1, 3, 7, 9, 15, 21, 123, 41, 19, 281, 1837, 2589, 1003, 1993, 18345, 10039, 89325, 0 };
            const std::uint32_t dim6377JoeKuoD6Init[]   =   { 1, 3, 5, 1, 19, 21, 77, 151, 145, 951, 2017, 609, 5847, 4475, 12439, 6357, 108277, 0 };
            const std::uint32_t dim6378JoeKuoD6Init[]   =   { 1, 1, 1, 9, 17, 21, 91, 91, 111, 951, 497, 1759, 503, 12787, 25117, 24323, 96447, 0 };
            const std::uint32_t dim6379JoeKuoD6Init[]   =   { 1, 1, 3, 11, 13, 9, 73, 205, 329, 243, 1187, 829, 2821, 5563, 14391, 771, 116441, 0 };
            const std::uint32_t dim6380JoeKuoD6Init[]   =   { 1, 1, 1, 1, 11, 57, 39, 221, 41, 521, 1541, 3515, 2367, 4179, 21039, 52943, 11627, 0 };
            const std::uint32_t dim6381JoeKuoD6Init[]   =   { 1, 3, 3, 3, 23, 13, 103, 125, 67, 217, 863, 3755, 213, 12657, 31399, 3771, 54107, 0 };
            const std::uint32_t dim6382JoeKuoD6Init[]   =   { 1, 3, 3, 7, 3, 9, 107, 217, 497, 935, 519, 3041, 323, 14895, 5695, 28789, 36085, 0 };
            const std::uint32_t dim6383JoeKuoD6Init[]   =   { 1, 1, 5, 11, 23, 33, 81, 23, 167, 3, 1683, 2279, 5365, 847, 14717, 9689, 64481, 0 };
            const std::uint32_t dim6384JoeKuoD6Init[]   =   { 1, 3, 1, 7, 1, 15, 107, 93, 429, 363, 1745, 1459, 5879, 8351, 17527, 44001, 70293, 0 };
            const std::uint32_t dim6385JoeKuoD6Init[]   =   { 1, 3, 3, 9, 27, 55, 125, 211, 141, 827, 1239, 663, 4803, 11067, 32039, 28091, 56421, 0 };
            const std::uint32_t dim6386JoeKuoD6Init[]   =   { 1, 3, 5, 5, 7, 13, 125, 231, 427, 483, 967, 549, 3105, 13919, 3017, 39207, 23253, 0 };
            const std::uint32_t dim6387JoeKuoD6Init[]   =   { 1, 3, 7, 3, 21, 29, 79, 67, 39, 451, 157, 337, 3585, 3621, 9545, 31205, 63201, 0 };
            const std::uint32_t dim6388JoeKuoD6Init[]   =   { 1, 3, 1, 1, 29, 25, 77, 57, 167, 899, 95, 2487, 3743, 5381, 3637, 56289, 39453, 0 };
            const std::uint32_t dim6389JoeKuoD6Init[]   =   { 1, 1, 1, 9, 29, 19, 41, 97, 75, 199, 1709, 483, 4099, 3113, 10953, 20659, 109273, 0 };
            const std::uint32_t dim6390JoeKuoD6Init[]   =   { 1, 3, 5, 15, 13, 9, 83, 43, 111, 789, 965, 4061, 1239, 14577, 10113, 26359, 52609, 0 };
            const std::uint32_t dim6391JoeKuoD6Init[]   =   { 1, 3, 5, 5, 11, 39, 113, 31, 457, 119, 725, 831, 4143, 5675, 27431, 12431, 94977, 0 };
            const std::uint32_t dim6392JoeKuoD6Init[]   =   { 1, 1, 3, 3, 25, 17, 93, 253, 307, 625, 143, 1061, 4415, 3563, 3313, 53527, 29537, 0 };
            const std::uint32_t dim6393JoeKuoD6Init[]   =   { 1, 3, 5, 3, 29, 41, 43, 109, 147, 919, 1675, 465, 6101, 12251, 28915, 15397, 85233, 0 };
            const std::uint32_t dim6394JoeKuoD6Init[]   =   { 1, 1, 1, 1, 31, 25, 59, 187, 439, 561, 559, 413, 1917, 9319, 27475, 49715, 32953, 0 };
            const std::uint32_t dim6395JoeKuoD6Init[]   =   { 1, 1, 7, 13, 23, 31, 95, 231, 141, 207, 1373, 2173, 2905, 169, 23825, 55071, 6147, 0 };
            const std::uint32_t dim6396JoeKuoD6Init[]   =   { 1, 1, 7, 13, 15, 39, 43, 117, 321, 297, 661, 2941, 7359, 11675, 15483, 24093, 7269, 0 };
            const std::uint32_t dim6397JoeKuoD6Init[]   =   { 1, 3, 3, 13, 9, 59, 51, 49, 81, 563, 745, 1843, 295, 4689, 19847, 42137, 63197, 0 };
            const std::uint32_t dim6398JoeKuoD6Init[]   =   { 1, 3, 1, 9, 5, 33, 21, 199, 509, 927, 1777, 1349, 3593, 1065, 24943, 55667, 73539, 0 };
            const std::uint32_t dim6399JoeKuoD6Init[]   =   { 1, 3, 1, 11, 17, 15, 91, 21, 59, 587, 1207, 543, 6669, 10861, 24755, 1789, 91249, 0 };
            const std::uint32_t dim6400JoeKuoD6Init[]   =   { 1, 3, 7, 15, 13, 47, 57, 147, 381, 1021, 921, 1347, 3847, 5969, 9075, 39081, 127241, 0 };
            const std::uint32_t dim6401JoeKuoD6Init[]   =   { 1, 3, 3, 15, 19, 15, 1, 97, 203, 409, 1745, 1217, 2199, 7945, 24361, 41771, 123127, 0 };
            const std::uint32_t dim6402JoeKuoD6Init[]   =   { 1, 3, 3, 5, 17, 17, 43, 255, 179, 717, 1993, 645, 6527, 1533, 32719, 27481, 122425, 0 };
            const std::uint32_t dim6403JoeKuoD6Init[]   =   { 1, 3, 5, 9, 13, 59, 15, 157, 373, 937, 27, 3325, 2297, 89, 10861, 48615, 16083, 0 };
            const std::uint32_t dim6404JoeKuoD6Init[]   =   { 1, 3, 1, 3, 19, 27, 109, 243, 189, 17, 99, 1879, 695, 11329, 12467, 6053, 41749, 0 };
            const std::uint32_t dim6405JoeKuoD6Init[]   =   { 1, 1, 5, 5, 23, 41, 103, 69, 171, 917, 1303, 2101, 617, 10017, 26525, 11009, 66137, 0 };
            const std::uint32_t dim6406JoeKuoD6Init[]   =   { 1, 1, 1, 9, 21, 45, 47, 171, 455, 257, 411, 4021, 6995, 12881, 4793, 51193, 60775, 0 };
            const std::uint32_t dim6407JoeKuoD6Init[]   =   { 1, 3, 7, 5, 25, 31, 89, 53, 321, 593, 1795, 2435, 3833, 2767, 17241, 63373, 25457, 0 };
            const std::uint32_t dim6408JoeKuoD6Init[]   =   { 1, 3, 1, 1, 3, 45, 19, 255, 179, 991, 1407, 3683, 1435, 6803, 12215, 12835, 2005, 0 };
            const std::uint32_t dim6409JoeKuoD6Init[]   =   { 1, 3, 7, 3, 17, 5, 117, 251, 71, 983, 1391, 3499, 5119, 7257, 7325, 16565, 6321, 0 };
            const std::uint32_t dim6410JoeKuoD6Init[]   =   { 1, 3, 5, 7, 5, 49, 47, 201, 297, 485, 1879, 2205, 4903, 13619, 22537, 5479, 121625, 0 };
            const std::uint32_t dim6411JoeKuoD6Init[]   =   { 1, 1, 3, 5, 27, 27, 87, 61, 145, 943, 343, 1639, 6307, 4549, 20765, 33479, 113697, 0 };
            const std::uint32_t dim6412JoeKuoD6Init[]   =   { 1, 1, 3, 9, 17, 5, 101, 129, 305, 653, 1901, 3901, 6361, 2369, 7449, 55259, 75215, 0 };
            const std::uint32_t dim6413JoeKuoD6Init[]   =   { 1, 1, 7, 5, 31, 45, 117, 55, 335, 827, 1309, 2603, 2111, 11005, 14747, 56999, 97373, 0 };
            const std::uint32_t dim6414JoeKuoD6Init[]   =   { 1, 1, 7, 11, 29, 29, 81, 175, 169, 453, 293, 2589, 1057, 15795, 32397, 65433, 79455, 0 };
            const std::uint32_t dim6415JoeKuoD6Init[]   =   { 1, 1, 1, 5, 11, 7, 13, 249, 29, 407, 1289, 2385, 8113, 15327, 4029, 32005, 105901, 0 };
            const std::uint32_t dim6416JoeKuoD6Init[]   =   { 1, 1, 5, 5, 7, 61, 103, 141, 109, 391, 631, 821, 1479, 14771, 25057, 1415, 8081, 0 };
            const std::uint32_t dim6417JoeKuoD6Init[]   =   { 1, 3, 1, 1, 9, 37, 17, 231, 501, 745, 1695, 45, 7797, 2945, 5529, 34747, 39069, 0 };
            const std::uint32_t dim6418JoeKuoD6Init[]   =   { 1, 1, 7, 9, 21, 59, 103, 103, 33, 875, 723, 3477, 4729, 7311, 29979, 60901, 72187, 0 };
            const std::uint32_t dim6419JoeKuoD6Init[]   =   { 1, 3, 3, 3, 15, 63, 93, 237, 203, 635, 1189, 2035, 6499, 9943, 9133, 62977, 29657, 0 };
            const std::uint32_t dim6420JoeKuoD6Init[]   =   { 1, 1, 1, 9, 3, 11, 63, 207, 95, 563, 775, 3009, 7125, 13141, 4489, 16343, 120951, 0 };
            const std::uint32_t dim6421JoeKuoD6Init[]   =   { 1, 1, 3, 1, 21, 57, 15, 217, 185, 305, 463, 1597, 6529, 4989, 14011, 11265, 131031, 0 };
            const std::uint32_t dim6422JoeKuoD6Init[]   =   { 1, 3, 5, 15, 17, 61, 35, 127, 411, 579, 1349, 615, 3293, 8475, 9773, 30635, 117639, 0 };
            const std::uint32_t dim6423JoeKuoD6Init[]   =   { 1, 1, 7, 9, 11, 3, 55, 105, 305, 223, 1899, 2217, 1261, 9831, 23693, 3013, 30489, 0 };
            const std::uint32_t dim6424JoeKuoD6Init[]   =   { 1, 3, 7, 15, 15, 29, 1, 99, 67, 293, 499, 1941, 5303, 1329, 24547, 14065, 7927, 0 };
            const std::uint32_t dim6425JoeKuoD6Init[]   =   { 1, 1, 5, 11, 17, 55, 71, 49, 499, 435, 985, 2803, 6139, 1503, 24167, 47181, 102529, 0 };
            const std::uint32_t dim6426JoeKuoD6Init[]   =   { 1, 3, 5, 1, 19, 53, 71, 17, 63, 469, 1871, 2051, 357, 11661, 5689, 36373, 13379, 0 };
            const std::uint32_t dim6427JoeKuoD6Init[]   =   { 1, 1, 5, 1, 27, 47, 23, 247, 59, 381, 1895, 2453, 3665, 5487, 24081, 50501, 91659, 0 };
            const std::uint32_t dim6428JoeKuoD6Init[]   =   { 1, 1, 5, 7, 29, 19, 3, 33, 83, 301, 133, 3603, 5133, 16171, 22905, 36271, 10405, 0 };
            const std::uint32_t dim6429JoeKuoD6Init[]   =   { 1, 3, 7, 9, 11, 23, 57, 87, 9, 731, 631, 3703, 2593, 12851, 7115, 8801, 108919, 0 };
            const std::uint32_t dim6430JoeKuoD6Init[]   =   { 1, 3, 3, 3, 23, 35, 33, 99, 343, 837, 231, 3921, 6975, 15093, 15049, 64623, 123523, 0 };
            const std::uint32_t dim6431JoeKuoD6Init[]   =   { 1, 1, 7, 11, 15, 61, 113, 103, 501, 57, 1345, 3155, 2965, 4433, 10605, 43765, 42169, 0 };
            const std::uint32_t dim6432JoeKuoD6Init[]   =   { 1, 1, 7, 13, 7, 53, 91, 121, 229, 127, 103, 833, 7829, 1571, 10847, 20861, 101155, 0 };
            const std::uint32_t dim6433JoeKuoD6Init[]   =   { 1, 3, 7, 1, 9, 25, 71, 103, 37, 473, 1133, 1129, 1651, 6965, 6937, 16597, 20439, 0 };
            const std::uint32_t dim6434JoeKuoD6Init[]   =   { 1, 1, 5, 9, 1, 9, 47, 131, 285, 967, 1869, 1075, 8127, 135, 15575, 38569, 123729, 0 };
            const std::uint32_t dim6435JoeKuoD6Init[]   =   { 1, 1, 7, 9, 5, 31, 33, 227, 347, 41, 2025, 3755, 857, 7805, 13121, 38307, 125825, 0 };
            const std::uint32_t dim6436JoeKuoD6Init[]   =   { 1, 3, 5, 7, 11, 11, 19, 55, 23, 627, 1477, 3093, 2779, 7653, 7165, 23053, 76123, 0 };
            const std::uint32_t dim6437JoeKuoD6Init[]   =   { 1, 1, 3, 1, 3, 47, 83, 89, 177, 381, 1247, 141, 7051, 6443, 27369, 34323, 43063, 0 };
            const std::uint32_t dim6438JoeKuoD6Init[]   =   { 1, 1, 7, 7, 13, 15, 55, 223, 351, 525, 1051, 3009, 5443, 11499, 8335, 37949, 69149, 0 };
            const std::uint32_t dim6439JoeKuoD6Init[]   =   { 1, 1, 1, 3, 13, 61, 89, 33, 129, 921, 1905, 201, 3141, 5531, 135, 34103, 56883, 0 };
            const std::uint32_t dim6440JoeKuoD6Init[]   =   { 1, 1, 5, 13, 17, 27, 13, 163, 169, 471, 1263, 1421, 7015, 7927, 21027, 58001, 26739, 0 };
            const std::uint32_t dim6441JoeKuoD6Init[]   =   { 1, 1, 1, 15, 19, 49, 109, 207, 245, 49, 1271, 3635, 2561, 5091, 24415, 59195, 67701, 0 };
            const std::uint32_t dim6442JoeKuoD6Init[]   =   { 1, 3, 5, 7, 27, 57, 99, 155, 461, 595, 1859, 1727, 857, 4993, 31733, 42141, 10035, 0 };
            const std::uint32_t dim6443JoeKuoD6Init[]   =   { 1, 1, 1, 15, 11, 11, 85, 9, 251, 375, 155, 379, 7501, 12559, 32583, 36317, 4675, 0 };
            const std::uint32_t dim6444JoeKuoD6Init[]   =   { 1, 1, 5, 13, 19, 57, 81, 69, 201, 293, 593, 3169, 4519, 9057, 16685, 12847, 123797, 0 };
            const std::uint32_t dim6445JoeKuoD6Init[]   =   { 1, 3, 1, 5, 5, 1, 19, 243, 345, 661, 561, 3549, 2541, 5887, 25879, 41467, 72799, 0 };
            const std::uint32_t dim6446JoeKuoD6Init[]   =   { 1, 1, 5, 13, 15, 51, 67, 61, 79, 89, 447, 1471, 4915, 10637, 10901, 48157, 103545, 0 };
            const std::uint32_t dim6447JoeKuoD6Init[]   =   { 1, 3, 5, 13, 31, 25, 73, 129, 435, 659, 1851, 3595, 753, 7717, 10927, 30115, 109221, 0 };
            const std::uint32_t dim6448JoeKuoD6Init[]   =   { 1, 1, 1, 3, 25, 3, 121, 43, 349, 205, 1209, 2671, 6445, 8755, 7171, 58631, 74319, 0 };
            const std::uint32_t dim6449JoeKuoD6Init[]   =   { 1, 1, 3, 1, 11, 15, 83, 37, 483, 65, 759, 1835, 3883, 1693, 30051, 61077, 1187, 0 };
            const std::uint32_t dim6450JoeKuoD6Init[]   =   { 1, 3, 7, 15, 29, 23, 85, 77, 139, 903, 1821, 943, 6453, 1523, 18539, 49039, 110787, 0 };
            const std::uint32_t dim6451JoeKuoD6Init[]   =   { 1, 1, 7, 15, 15, 17, 69, 253, 507, 921, 523, 79, 747, 4011, 25795, 42029, 88309, 0 };
            const std::uint32_t dim6452JoeKuoD6Init[]   =   { 1, 1, 7, 3, 25, 47, 119, 83, 313, 45, 985, 145, 205, 3407, 9013, 64517, 115811, 0 };
            const std::uint32_t dim6453JoeKuoD6Init[]   =   { 1, 1, 7, 1, 29, 21, 9, 123, 97, 545, 1987, 2979, 6901, 12667, 23325, 63635, 70593, 0 };
            const std::uint32_t dim6454JoeKuoD6Init[]   =   { 1, 3, 7, 3, 23, 45, 81, 255, 41, 29, 1493, 4065, 3201, 10479, 17193, 39999, 55493, 0 };
            const std::uint32_t dim6455JoeKuoD6Init[]   =   { 1, 3, 1, 3, 9, 43, 43, 135, 235, 603, 481, 3139, 2729, 14759, 7269, 7995, 110351, 0 };
            const std::uint32_t dim6456JoeKuoD6Init[]   =   { 1, 3, 1, 11, 17, 35, 113, 93, 417, 967, 755, 659, 3115, 16163, 22997, 38205, 126961, 0 };
            const std::uint32_t dim6457JoeKuoD6Init[]   =   { 1, 1, 7, 11, 29, 57, 81, 235, 93, 869, 475, 825, 6269, 15819, 14977, 53057, 116021, 0 };
            const std::uint32_t dim6458JoeKuoD6Init[]   =   { 1, 1, 7, 13, 5, 61, 5, 241, 245, 673, 1651, 3367, 2355, 713, 20107, 30133, 735, 0 };
            const std::uint32_t dim6459JoeKuoD6Init[]   =   { 1, 1, 5, 9, 21, 3, 121, 241, 129, 703, 1435, 1943, 5087, 13123, 30023, 58287, 50377, 0 };
            const std::uint32_t dim6460JoeKuoD6Init[]   =   { 1, 1, 1, 15, 23, 27, 67, 197, 123, 629, 169, 3303, 1679, 11051, 16875, 28055, 12379, 0 };
            const std::uint32_t dim6461JoeKuoD6Init[]   =   { 1, 1, 3, 3, 7, 63, 97, 43, 89, 739, 779, 2893, 7763, 6351, 26135, 44647, 127987, 0 };
            const std::uint32_t dim6462JoeKuoD6Init[]   =   { 1, 3, 3, 9, 31, 59, 95, 131, 131, 321, 1125, 127, 4865, 145, 26237, 47871, 114549, 0 };
            const std::uint32_t dim6463JoeKuoD6Init[]   =   { 1, 3, 3, 13, 21, 3, 33, 17, 445, 693, 1599, 2517, 1679, 2237, 15053, 30983, 106755, 0 };
            const std::uint32_t dim6464JoeKuoD6Init[]   =   { 1, 1, 5, 13, 31, 37, 49, 67, 403, 27, 575, 1795, 3385, 1067, 585, 60277, 123189, 0 };
            const std::uint32_t dim6465JoeKuoD6Init[]   =   { 1, 3, 1, 15, 13, 35, 23, 247, 493, 305, 363, 451, 4011, 3679, 18281, 31751, 127933, 0 };
            const std::uint32_t dim6466JoeKuoD6Init[]   =   { 1, 1, 7, 5, 21, 45, 123, 253, 469, 267, 985, 2349, 3427, 7653, 25685, 13747, 531, 0 };
            const std::uint32_t dim6467JoeKuoD6Init[]   =   { 1, 1, 5, 11, 7, 59, 105, 209, 27, 847, 593, 3775, 6165, 1655, 29867, 28465, 92193, 0 };
            const std::uint32_t dim6468JoeKuoD6Init[]   =   { 1, 3, 1, 11, 7, 25, 101, 81, 233, 311, 9, 2735, 3951, 485, 10105, 24489, 649, 0 };
            const std::uint32_t dim6469JoeKuoD6Init[]   =   { 1, 3, 1, 7, 27, 5, 115, 243, 295, 659, 215, 1787, 5131, 2513, 29201, 21195, 103383, 0 };
            const std::uint32_t dim6470JoeKuoD6Init[]   =   { 1, 3, 5, 13, 29, 21, 7, 57, 345, 467, 1297, 207, 5115, 335, 6153, 32959, 125697, 0 };
            const std::uint32_t dim6471JoeKuoD6Init[]   =   { 1, 1, 1, 9, 3, 63, 63, 5, 373, 123, 1265, 2365, 1623, 1561, 14805, 17487, 104787, 0 };
            const std::uint32_t dim6472JoeKuoD6Init[]   =   { 1, 3, 1, 5, 15, 13, 55, 69, 251, 341, 463, 2611, 4793, 12157, 4669, 11613, 128705, 0 };
            const std::uint32_t dim6473JoeKuoD6Init[]   =   { 1, 3, 7, 13, 19, 7, 93, 149, 453, 693, 1731, 861, 6971, 943, 18891, 56547, 34411, 0 };
            const std::uint32_t dim6474JoeKuoD6Init[]   =   { 1, 1, 7, 1, 27, 49, 27, 9, 281, 121, 581, 393, 2583, 1159, 26989, 39955, 100765, 0 };
            const std::uint32_t dim6475JoeKuoD6Init[]   =   { 1, 1, 3, 9, 3, 43, 97, 207, 311, 617, 1987, 2559, 2101, 15791, 30085, 40713, 41909, 0 };
            const std::uint32_t dim6476JoeKuoD6Init[]   =   { 1, 3, 1, 3, 15, 19, 53, 183, 375, 867, 397, 3203, 4207, 5381, 25065, 60357, 88739, 0 };
            const std::uint32_t dim6477JoeKuoD6Init[]   =   { 1, 3, 3, 3, 27, 51, 85, 231, 19, 559, 567, 4049, 4875, 14201, 11623, 39763, 57339, 0 };
            const std::uint32_t dim6478JoeKuoD6Init[]   =   { 1, 1, 5, 1, 19, 7, 81, 249, 41, 789, 985, 3725, 4053, 4255, 9861, 1609, 29511, 0 };
            const std::uint32_t dim6479JoeKuoD6Init[]   =   { 1, 3, 5, 5, 21, 13, 49, 41, 367, 283, 1161, 2753, 4733, 3691, 27931, 53055, 83625, 0 };
            const std::uint32_t dim6480JoeKuoD6Init[]   =   { 1, 3, 5, 11, 29, 47, 95, 51, 265, 85, 385, 833, 7957, 14985, 7017, 41937, 41377, 0 };
            const std::uint32_t dim6481JoeKuoD6Init[]   =   { 1, 1, 7, 5, 1, 23, 17, 191, 185, 323, 515, 3183, 7685, 7361, 21143, 5227, 110297, 0 };
            const std::uint32_t dim6482JoeKuoD6Init[]   =   { 1, 3, 3, 7, 11, 39, 31, 97, 237, 497, 1649, 3529, 6153, 5055, 29021, 35125, 121581, 0 };
            const std::uint32_t dim6483JoeKuoD6Init[]   =   { 1, 3, 5, 3, 17, 47, 105, 75, 55, 343, 595, 2447, 5575, 10673, 32015, 37541, 127867, 0 };
            const std::uint32_t dim6484JoeKuoD6Init[]   =   { 1, 3, 1, 7, 19, 39, 31, 135, 167, 979, 219, 1353, 489, 9667, 27107, 55565, 72291, 0 };
            const std::uint32_t dim6485JoeKuoD6Init[]   =   { 1, 1, 3, 13, 31, 49, 87, 93, 235, 577, 1551, 2663, 387, 1129, 26683, 31285, 15913, 0 };
            const std::uint32_t dim6486JoeKuoD6Init[]   =   { 1, 3, 3, 7, 15, 29, 61, 33, 115, 511, 1781, 2029, 4265, 6745, 1467, 34415, 40907, 0 };
            const std::uint32_t dim6487JoeKuoD6Init[]   =   { 1, 1, 7, 5, 1, 55, 13, 129, 167, 937, 79, 2047, 3589, 1979, 4153, 15229, 85745, 0 };
            const std::uint32_t dim6488JoeKuoD6Init[]   =   { 1, 1, 7, 15, 15, 25, 89, 129, 31, 435, 1359, 49, 2659, 2829, 8741, 25215, 4239, 0 };
            const std::uint32_t dim6489JoeKuoD6Init[]   =   { 1, 3, 5, 3, 11, 39, 95, 239, 187, 615, 1481, 3509, 1133, 13497, 24833, 59635, 45695, 0 };
            const std::uint32_t dim6490JoeKuoD6Init[]   =   { 1, 1, 5, 3, 19, 17, 17, 235, 315, 943, 883, 1381, 7129, 15709, 9847, 41183, 116071, 0 };
            const std::uint32_t dim6491JoeKuoD6Init[]   =   { 1, 1, 1, 3, 9, 63, 109, 209, 309, 1015, 1391, 2617, 1481, 6483, 4151, 28063, 49887, 0 };
            const std::uint32_t dim6492JoeKuoD6Init[]   =   { 1, 1, 5, 13, 23, 37, 31, 89, 501, 461, 41, 931, 7863, 15499, 25635, 16995, 41651, 0 };
            const std::uint32_t dim6493JoeKuoD6Init[]   =   { 1, 1, 1, 9, 29, 29, 125, 161, 219, 439, 1465, 1615, 7483, 7497, 1121, 49693, 30269, 0 };
            const std::uint32_t dim6494JoeKuoD6Init[]   =   { 1, 3, 1, 5, 7, 43, 27, 161, 431, 375, 419, 2995, 527, 8207, 747, 18491, 15351, 0 };
            const std::uint32_t dim6495JoeKuoD6Init[]   =   { 1, 1, 3, 13, 25, 21, 67, 177, 9, 453, 1171, 65, 2845, 16147, 12699, 30905, 122255, 0 };
            const std::uint32_t dim6496JoeKuoD6Init[]   =   { 1, 3, 1, 5, 29, 47, 77, 251, 473, 385, 947, 3239, 5375, 13617, 10639, 36005, 95821, 0 };
            const std::uint32_t dim6497JoeKuoD6Init[]   =   { 1, 3, 1, 15, 13, 1, 75, 223, 509, 19, 175, 1541, 637, 5711, 1097, 44901, 35277, 0 };
            const std::uint32_t dim6498JoeKuoD6Init[]   =   { 1, 3, 3, 7, 3, 27, 17, 151, 39, 583, 391, 2739, 7339, 2051, 17005, 49573, 85969, 0 };
            const std::uint32_t dim6499JoeKuoD6Init[]   =   { 1, 3, 1, 11, 3, 25, 119, 125, 17, 629, 201, 2347, 2923, 1273, 14871, 58299, 97667, 0 };
            const std::uint32_t dim6500JoeKuoD6Init[]   =   { 1, 1, 7, 1, 31, 39, 11, 121, 339, 667, 1863, 3479, 1895, 11319, 5683, 64969, 9261, 0 };
            const std::uint32_t dim6501JoeKuoD6Init[]   =   { 1, 1, 5, 9, 27, 61, 101, 221, 221, 583, 287, 707, 5931, 4225, 29537, 46097, 114361, 0 };
            const std::uint32_t dim6502JoeKuoD6Init[]   =   { 1, 1, 1, 9, 23, 47, 1, 35, 85, 1021, 151, 3153, 3867, 971, 31573, 4745, 107639, 0 };
            const std::uint32_t dim6503JoeKuoD6Init[]   =   { 1, 1, 7, 13, 15, 15, 63, 37, 291, 907, 411, 1571, 6415, 7443, 26635, 27945, 130909, 0 };
            const std::uint32_t dim6504JoeKuoD6Init[]   =   { 1, 3, 1, 9, 21, 13, 77, 147, 485, 107, 235, 481, 2389, 957, 11493, 53033, 46373, 0 };
            const std::uint32_t dim6505JoeKuoD6Init[]   =   { 1, 3, 5, 7, 3, 55, 125, 237, 205, 411, 1911, 4053, 5983, 15489, 29333, 44727, 62167, 0 };
            const std::uint32_t dim6506JoeKuoD6Init[]   =   { 1, 1, 3, 3, 17, 3, 59, 239, 209, 495, 447, 3427, 3425, 2347, 10057, 26147, 52243, 0 };
            const std::uint32_t dim6507JoeKuoD6Init[]   =   { 1, 1, 3, 1, 11, 31, 3, 139, 441, 997, 295, 1267, 2181, 6047, 32419, 62657, 24921, 0 };
            const std::uint32_t dim6508JoeKuoD6Init[]   =   { 1, 3, 7, 15, 5, 3, 11, 9, 211, 701, 1987, 2611, 6195, 14379, 22919, 15785, 52149, 0 };
            const std::uint32_t dim6509JoeKuoD6Init[]   =   { 1, 1, 7, 9, 7, 27, 35, 253, 343, 679, 103, 1217, 3983, 8677, 17671, 41347, 89355, 0 };
            const std::uint32_t dim6510JoeKuoD6Init[]   =   { 1, 1, 1, 5, 7, 55, 111, 115, 231, 999, 773, 2111, 3617, 2469, 16967, 60735, 24557, 0 };
            const std::uint32_t dim6511JoeKuoD6Init[]   =   { 1, 3, 5, 1, 29, 5, 77, 217, 131, 307, 473, 3595, 2713, 6503, 18459, 57245, 91897, 0 };
            const std::uint32_t dim6512JoeKuoD6Init[]   =   { 1, 3, 5, 13, 9, 33, 93, 31, 59, 343, 1337, 1971, 7593, 15629, 22693, 19885, 4139, 0 };
            const std::uint32_t dim6513JoeKuoD6Init[]   =   { 1, 3, 3, 3, 21, 33, 115, 205, 373, 587, 739, 669, 8065, 5339, 16507, 29455, 15863, 0 };
            const std::uint32_t dim6514JoeKuoD6Init[]   =   { 1, 3, 5, 11, 9, 43, 45, 41, 91, 87, 19, 1523, 5059, 9403, 6739, 36893, 6395, 0 };
            const std::uint32_t dim6515JoeKuoD6Init[]   =   { 1, 1, 5, 15, 19, 43, 81, 3, 401, 621, 1839, 1443, 179, 8085, 27021, 7757, 95011, 0 };
            const std::uint32_t dim6516JoeKuoD6Init[]   =   { 1, 3, 5, 15, 19, 21, 45, 167, 77, 977, 309, 431, 3437, 8327, 12895, 50521, 68473, 0 };
            const std::uint32_t dim6517JoeKuoD6Init[]   =   { 1, 3, 3, 15, 7, 21, 49, 169, 327, 271, 7, 785, 1767, 14747, 7083, 65223, 24213, 0 };
            const std::uint32_t dim6518JoeKuoD6Init[]   =   { 1, 1, 5, 9, 9, 51, 101, 197, 507, 839, 1413, 3131, 331, 15725, 32293, 60433, 86759, 0 };
            const std::uint32_t dim6519JoeKuoD6Init[]   =   { 1, 1, 7, 1, 17, 39, 127, 201, 341, 607, 1565, 1615, 1367, 16043, 28265, 29139, 63813, 0 };
            const std::uint32_t dim6520JoeKuoD6Init[]   =   { 1, 3, 5, 7, 9, 1, 107, 73, 121, 649, 1385, 3203, 2897, 8479, 28519, 34041, 1359, 0 };
            const std::uint32_t dim6521JoeKuoD6Init[]   =   { 1, 1, 7, 7, 21, 55, 19, 13, 415, 647, 2015, 107, 4167, 5033, 16849, 41407, 94387, 0 };
            const std::uint32_t dim6522JoeKuoD6Init[]   =   { 1, 3, 5, 13, 31, 27, 107, 95, 425, 679, 55, 3521, 6737, 11459, 19995, 64189, 44323, 0 };
            const std::uint32_t dim6523JoeKuoD6Init[]   =   { 1, 1, 3, 9, 17, 47, 29, 167, 17, 63, 5, 2505, 6483, 14089, 7127, 7907, 68555, 0 };
            const std::uint32_t dim6524JoeKuoD6Init[]   =   { 1, 1, 5, 3, 29, 3, 87, 107, 227, 893, 1821, 341, 5481, 13317, 10637, 8611, 28625, 0 };
            const std::uint32_t dim6525JoeKuoD6Init[]   =   { 1, 1, 1, 13, 11, 19, 59, 157, 397, 103, 1821, 3913, 3083, 6053, 1015, 25475, 94813, 0 };
            const std::uint32_t dim6526JoeKuoD6Init[]   =   { 1, 3, 1, 3, 15, 45, 1, 209, 335, 1015, 539, 2959, 1711, 2567, 30169, 147, 25383, 0 };
            const std::uint32_t dim6527JoeKuoD6Init[]   =   { 1, 3, 7, 1, 17, 5, 99, 121, 91, 531, 865, 1667, 5615, 4729, 7473, 21445, 37925, 0 };
            const std::uint32_t dim6528JoeKuoD6Init[]   =   { 1, 1, 7, 13, 3, 51, 27, 115, 439, 761, 1121, 1503, 3047, 2127, 29253, 48147, 10813, 0 };
            const std::uint32_t dim6529JoeKuoD6Init[]   =   { 1, 3, 7, 15, 1, 51, 33, 161, 509, 159, 1705, 3365, 7953, 14027, 3873, 29609, 33101, 0 };
            const std::uint32_t dim6530JoeKuoD6Init[]   =   { 1, 1, 5, 15, 15, 53, 119, 115, 433, 75, 497, 1259, 1681, 7715, 24767, 34647, 82007, 0 };
            const std::uint32_t dim6531JoeKuoD6Init[]   =   { 1, 1, 5, 3, 27, 63, 41, 181, 393, 439, 95, 2765, 7617, 817, 1311, 18595, 16921, 0 };
            const std::uint32_t dim6532JoeKuoD6Init[]   =   { 1, 3, 1, 15, 31, 7, 57, 89, 371, 745, 475, 3211, 6893, 10681, 18547, 28373, 127787, 0 };
            const std::uint32_t dim6533JoeKuoD6Init[]   =   { 1, 3, 5, 13, 5, 55, 45, 167, 147, 833, 765, 1153, 4037, 8503, 10751, 49541, 77489, 0 };
            const std::uint32_t dim6534JoeKuoD6Init[]   =   { 1, 3, 1, 11, 11, 7, 45, 167, 431, 759, 1035, 1367, 1649, 11711, 4915, 58915, 72479, 0 };
            const std::uint32_t dim6535JoeKuoD6Init[]   =   { 1, 1, 5, 1, 11, 3, 15, 135, 427, 637, 879, 1667, 6139, 14759, 25665, 13083, 67961, 0 };
            const std::uint32_t dim6536JoeKuoD6Init[]   =   { 1, 3, 3, 9, 1, 3, 73, 167, 269, 51, 1481, 3659, 7863, 7187, 3951, 10711, 5909, 0 };
            const std::uint32_t dim6537JoeKuoD6Init[]   =   { 1, 1, 3, 3, 9, 53, 101, 209, 109, 691, 1641, 919, 1083, 6247, 23041, 44681, 130105, 0 };
            const std::uint32_t dim6538JoeKuoD6Init[]   =   { 1, 3, 7, 5, 21, 55, 127, 9, 437, 225, 1599, 2575, 5407, 8099, 20009, 40339, 110581, 0 };
            const std::uint32_t dim6539JoeKuoD6Init[]   =   { 1, 3, 3, 13, 7, 41, 15, 137, 363, 337, 995, 1215, 3651, 11011, 27209, 53927, 78065, 0 };
            const std::uint32_t dim6540JoeKuoD6Init[]   =   { 1, 1, 1, 7, 11, 17, 27, 9, 481, 79, 905, 1297, 811, 10221, 463, 12979, 114731, 0 };
            const std::uint32_t dim6541JoeKuoD6Init[]   =   { 1, 1, 3, 13, 7, 59, 105, 79, 253, 699, 139, 3823, 4939, 12955, 32069, 7255, 18159, 0 };
            const std::uint32_t dim6542JoeKuoD6Init[]   =   { 1, 3, 5, 7, 29, 7, 79, 79, 147, 921, 425, 1423, 5967, 6397, 17393, 30009, 84075, 0 };
            const std::uint32_t dim6543JoeKuoD6Init[]   =   { 1, 3, 7, 13, 23, 45, 51, 141, 237, 443, 1101, 309, 4533, 7479, 22415, 31517, 120407, 0 };
            const std::uint32_t dim6544JoeKuoD6Init[]   =   { 1, 1, 5, 13, 3, 19, 97, 185, 59, 179, 1343, 2537, 3165, 16295, 25005, 49769, 78007, 0 };
            const std::uint32_t dim6545JoeKuoD6Init[]   =   { 1, 3, 7, 15, 11, 53, 127, 195, 309, 121, 1741, 1415, 225, 15645, 16365, 38729, 70061, 0 };
            const std::uint32_t dim6546JoeKuoD6Init[]   =   { 1, 3, 7, 11, 29, 35, 47, 109, 179, 3, 849, 2305, 3035, 15289, 31569, 28851, 90057, 0 };
            const std::uint32_t dim6547JoeKuoD6Init[]   =   { 1, 1, 7, 1, 13, 27, 93, 119, 439, 45, 623, 1263, 6595, 6669, 12981, 64721, 130109, 0 };
            const std::uint32_t dim6548JoeKuoD6Init[]   =   { 1, 1, 7, 13, 5, 43, 43, 99, 395, 417, 795, 3991, 5601, 13115, 12803, 52247, 39245, 0 };
            const std::uint32_t dim6549JoeKuoD6Init[]   =   { 1, 3, 3, 3, 15, 61, 85, 91, 407, 391, 359, 3885, 1925, 4873, 169, 41727, 129471, 0 };
            const std::uint32_t dim6550JoeKuoD6Init[]   =   { 1, 3, 3, 9, 11, 47, 3, 33, 355, 853, 1329, 1347, 1995, 8197, 10015, 787, 66773, 0 };
            const std::uint32_t dim6551JoeKuoD6Init[]   =   { 1, 3, 3, 13, 31, 31, 49, 195, 55, 185, 1743, 3523, 1781, 8469, 7623, 55933, 74953, 0 };
            const std::uint32_t dim6552JoeKuoD6Init[]   =   { 1, 3, 5, 15, 29, 31, 5, 45, 149, 71, 2033, 3171, 4601, 9941, 15005, 55709, 74403, 0 };
            const std::uint32_t dim6553JoeKuoD6Init[]   =   { 1, 3, 5, 3, 1, 27, 105, 7, 139, 805, 1877, 915, 1843, 11897, 29485, 19275, 44711, 0 };
            const std::uint32_t dim6554JoeKuoD6Init[]   =   { 1, 1, 5, 7, 25, 57, 111, 57, 401, 935, 1685, 2985, 2015, 13501, 14581, 53579, 117011, 0 };
            const std::uint32_t dim6555JoeKuoD6Init[]   =   { 1, 1, 5, 11, 13, 47, 63, 137, 145, 77, 1727, 2629, 7377, 6311, 537, 13703, 129503, 0 };
            const std::uint32_t dim6556JoeKuoD6Init[]   =   { 1, 1, 7, 9, 5, 49, 67, 51, 163, 989, 845, 7, 2141, 14467, 3197, 57581, 121087, 0 };
            const std::uint32_t dim6557JoeKuoD6Init[]   =   { 1, 1, 5, 3, 31, 49, 57, 103, 171, 491, 1109, 1255, 4353, 11927, 29525, 16685, 48469, 0 };
            const std::uint32_t dim6558JoeKuoD6Init[]   =   { 1, 1, 1, 3, 7, 29, 17, 111, 339, 747, 763, 179, 7747, 2483, 18415, 45301, 25155, 0 };
            const std::uint32_t dim6559JoeKuoD6Init[]   =   { 1, 1, 7, 7, 1, 41, 71, 109, 401, 815, 1311, 3933, 1349, 13327, 20847, 44391, 49721, 0 };
            const std::uint32_t dim6560JoeKuoD6Init[]   =   { 1, 1, 1, 15, 27, 57, 39, 129, 391, 701, 619, 3925, 701, 403, 11821, 30517, 22035, 0 };
            const std::uint32_t dim6561JoeKuoD6Init[]   =   { 1, 1, 5, 11, 21, 49, 109, 101, 497, 417, 73, 2727, 2899, 2777, 22161, 35561, 70211, 0 };
            const std::uint32_t dim6562JoeKuoD6Init[]   =   { 1, 1, 3, 3, 15, 43, 1, 159, 41, 833, 55, 2415, 5009, 9663, 31295, 29397, 3187, 0 };
            const std::uint32_t dim6563JoeKuoD6Init[]   =   { 1, 1, 3, 7, 27, 5, 113, 187, 453, 753, 1649, 1605, 2405, 11791, 4239, 20915, 54033, 0 };
            const std::uint32_t dim6564JoeKuoD6Init[]   =   { 1, 3, 1, 11, 1, 57, 49, 229, 283, 113, 345, 785, 8009, 11977, 30169, 63787, 32011, 0 };
            const std::uint32_t dim6565JoeKuoD6Init[]   =   { 1, 1, 7, 3, 5, 59, 57, 91, 327, 685, 219, 1949, 3095, 8389, 2035, 11903, 73461, 0 };
            const std::uint32_t dim6566JoeKuoD6Init[]   =   { 1, 1, 3, 3, 19, 59, 19, 37, 453, 1, 1811, 3263, 1807, 16147, 24861, 14003, 31747, 0 };
            const std::uint32_t dim6567JoeKuoD6Init[]   =   { 1, 1, 3, 11, 1, 53, 93, 203, 429, 629, 1931, 1487, 3301, 8805, 4901, 2459, 98555, 0 };
            const std::uint32_t dim6568JoeKuoD6Init[]   =   { 1, 1, 7, 5, 21, 5, 37, 135, 159, 749, 1589, 2631, 8145, 7279, 28397, 47113, 82309, 0 };
            const std::uint32_t dim6569JoeKuoD6Init[]   =   { 1, 1, 5, 15, 25, 61, 19, 51, 217, 495, 109, 1179, 2743, 12107, 12509, 13003, 94375, 0 };
            const std::uint32_t dim6570JoeKuoD6Init[]   =   { 1, 3, 3, 15, 11, 7, 67, 165, 57, 925, 427, 2549, 7189, 5917, 13113, 30933, 62703, 0 };
            const std::uint32_t dim6571JoeKuoD6Init[]   =   { 1, 1, 5, 5, 9, 5, 43, 5, 485, 159, 757, 3979, 4963, 3389, 29731, 48477, 113429, 0 };
            const std::uint32_t dim6572JoeKuoD6Init[]   =   { 1, 3, 5, 1, 5, 5, 81, 163, 493, 357, 2005, 1093, 5951, 1045, 10569, 40321, 56881, 0 };
            const std::uint32_t dim6573JoeKuoD6Init[]   =   { 1, 3, 1, 5, 7, 29, 11, 7, 7, 13, 1641, 1031, 4025, 16337, 24333, 9589, 37779, 0 };
            const std::uint32_t dim6574JoeKuoD6Init[]   =   { 1, 3, 5, 11, 15, 3, 69, 19, 141, 79, 749, 391, 4505, 6939, 3079, 3647, 22363, 0 };
            const std::uint32_t dim6575JoeKuoD6Init[]   =   { 1, 3, 3, 3, 29, 3, 7, 189, 183, 513, 1225, 239, 4203, 9197, 23507, 33089, 124433, 0 };
            const std::uint32_t dim6576JoeKuoD6Init[]   =   { 1, 3, 3, 13, 27, 37, 81, 221, 287, 891, 1197, 3501, 539, 2053, 20509, 48635, 50269, 0 };
            const std::uint32_t dim6577JoeKuoD6Init[]   =   { 1, 1, 5, 7, 13, 3, 35, 79, 3, 885, 343, 3527, 1043, 7197, 6973, 8515, 39315, 0 };
            const std::uint32_t dim6578JoeKuoD6Init[]   =   { 1, 3, 3, 9, 21, 53, 79, 225, 229, 759, 457, 293, 953, 12857, 20483, 3677, 93839, 0 };
            const std::uint32_t dim6579JoeKuoD6Init[]   =   { 1, 3, 5, 3, 5, 17, 45, 107, 153, 279, 761, 1923, 7013, 2989, 10137, 19107, 126897, 0 };
            const std::uint32_t dim6580JoeKuoD6Init[]   =   { 1, 3, 1, 3, 23, 53, 91, 1, 133, 729, 13, 2017, 6933, 7405, 1255, 49509, 105571, 0 };
            const std::uint32_t dim6581JoeKuoD6Init[]   =   { 1, 3, 5, 1, 9, 45, 35, 153, 209, 289, 1779, 2557, 315, 981, 15347, 30391, 16027, 0 };
            const std::uint32_t dim6582JoeKuoD6Init[]   =   { 1, 3, 3, 5, 17, 3, 51, 105, 263, 959, 1255, 1177, 8143, 10541, 7687, 38731, 93561, 0 };
            const std::uint32_t dim6583JoeKuoD6Init[]   =   { 1, 1, 1, 13, 19, 1, 15, 135, 447, 847, 663, 3893, 3539, 6833, 13265, 62923, 8375, 0 };
            const std::uint32_t dim6584JoeKuoD6Init[]   =   { 1, 3, 1, 15, 31, 11, 105, 1, 91, 523, 1583, 3493, 2665, 117, 10757, 29845, 127201, 0 };
            const std::uint32_t dim6585JoeKuoD6Init[]   =   { 1, 1, 1, 3, 29, 49, 9, 103, 309, 605, 1751, 1981, 833, 3653, 14001, 16545, 58513, 0 };
            const std::uint32_t dim6586JoeKuoD6Init[]   =   { 1, 1, 5, 9, 1, 19, 117, 71, 237, 765, 249, 1983, 2289, 6019, 26505, 31427, 64333, 0 };
            const std::uint32_t dim6587JoeKuoD6Init[]   =   { 1, 1, 3, 11, 15, 31, 5, 207, 347, 143, 11, 1987, 3569, 2051, 31051, 22193, 93289, 0 };
            const std::uint32_t dim6588JoeKuoD6Init[]   =   { 1, 1, 3, 5, 13, 15, 5, 73, 457, 611, 673, 2675, 8071, 13245, 19443, 14399, 99599, 0 };
            const std::uint32_t dim6589JoeKuoD6Init[]   =   { 1, 1, 1, 9, 11, 5, 103, 231, 31, 457, 1031, 2257, 3159, 8323, 31585, 26163, 45159, 0 };
            const std::uint32_t dim6590JoeKuoD6Init[]   =   { 1, 3, 1, 11, 29, 51, 29, 7, 89, 331, 783, 951, 6353, 15421, 12801, 8337, 119171, 0 };
            const std::uint32_t dim6591JoeKuoD6Init[]   =   { 1, 1, 3, 13, 23, 57, 63, 43, 505, 1, 657, 4005, 6327, 7545, 15455, 27097, 53649, 0 };
            const std::uint32_t dim6592JoeKuoD6Init[]   =   { 1, 1, 1, 5, 31, 7, 51, 107, 175, 461, 1893, 305, 157, 4819, 18549, 33087, 9499, 0 };
            const std::uint32_t dim6593JoeKuoD6Init[]   =   { 1, 3, 1, 3, 19, 45, 37, 9, 459, 143, 1327, 3611, 1899, 15109, 30151, 17911, 13233, 0 };
            const std::uint32_t dim6594JoeKuoD6Init[]   =   { 1, 1, 5, 15, 19, 49, 11, 227, 375, 661, 665, 259, 3659, 13723, 28239, 48159, 59209, 0 };
            const std::uint32_t dim6595JoeKuoD6Init[]   =   { 1, 3, 7, 7, 17, 49, 77, 161, 505, 713, 1521, 935, 3629, 5033, 26717, 47199, 3693, 0 };
            const std::uint32_t dim6596JoeKuoD6Init[]   =   { 1, 3, 5, 9, 17, 61, 1, 201, 259, 179, 1637, 2485, 4995, 2813, 19923, 43739, 32183, 0 };
            const std::uint32_t dim6597JoeKuoD6Init[]   =   { 1, 1, 3, 5, 1, 23, 125, 61, 225, 703, 2011, 1013, 6651, 14029, 27375, 23301, 80269, 0 };
            const std::uint32_t dim6598JoeKuoD6Init[]   =   { 1, 1, 3, 9, 11, 57, 37, 49, 321, 443, 1055, 1989, 4755, 8467, 22001, 18647, 112617, 0 };
            const std::uint32_t dim6599JoeKuoD6Init[]   =   { 1, 3, 1, 5, 5, 39, 21, 139, 101, 583, 1881, 2599, 4185, 15679, 22215, 19093, 76737, 0 };
            const std::uint32_t dim6600JoeKuoD6Init[]   =   { 1, 3, 1, 11, 31, 51, 85, 91, 159, 421, 2005, 1075, 7757, 12653, 25489, 3545, 62961, 0 };
            const std::uint32_t dim6601JoeKuoD6Init[]   =   { 1, 1, 1, 15, 27, 57, 75, 151, 357, 571, 395, 299, 5607, 12865, 2149, 21059, 120753, 0 };
            const std::uint32_t dim6602JoeKuoD6Init[]   =   { 1, 1, 1, 3, 15, 57, 63, 171, 265, 709, 1089, 677, 7243, 10207, 9789, 38431, 130415, 0 };
            const std::uint32_t dim6603JoeKuoD6Init[]   =   { 1, 3, 7, 5, 21, 9, 73, 149, 197, 773, 773, 3931, 4135, 5671, 2733, 57173, 90693, 0 };
            const std::uint32_t dim6604JoeKuoD6Init[]   =   { 1, 1, 5, 1, 23, 1, 47, 201, 33, 167, 1643, 4009, 2687, 5725, 28733, 27859, 55163, 0 };
            const std::uint32_t dim6605JoeKuoD6Init[]   =   { 1, 1, 5, 15, 25, 11, 57, 139, 471, 625, 1067, 3647, 6213, 15605, 23537, 5005, 32593, 0 };
            const std::uint32_t dim6606JoeKuoD6Init[]   =   { 1, 3, 1, 11, 17, 11, 25, 163, 199, 21, 1775, 3721, 2845, 15769, 2381, 27643, 19909, 0 };
            const std::uint32_t dim6607JoeKuoD6Init[]   =   { 1, 3, 5, 5, 21, 41, 23, 125, 401, 483, 535, 925, 7065, 1727, 3761, 8485, 3519, 0 };
            const std::uint32_t dim6608JoeKuoD6Init[]   =   { 1, 1, 3, 15, 27, 31, 11, 7, 93, 237, 611, 3635, 4747, 9751, 20607, 20473, 73935, 0 };
            const std::uint32_t dim6609JoeKuoD6Init[]   =   { 1, 1, 7, 3, 15, 19, 69, 169, 387, 291, 1981, 635, 3387, 15817, 20357, 47537, 107311, 0 };
            const std::uint32_t dim6610JoeKuoD6Init[]   =   { 1, 3, 7, 15, 13, 59, 31, 235, 399, 343, 1265, 2975, 6839, 13335, 5397, 58915, 31313, 0 };
            const std::uint32_t dim6611JoeKuoD6Init[]   =   { 1, 1, 7, 1, 3, 35, 81, 243, 387, 421, 1533, 799, 2615, 13219, 9041, 26967, 22677, 0 };
            const std::uint32_t dim6612JoeKuoD6Init[]   =   { 1, 1, 7, 15, 17, 41, 89, 115, 67, 569, 1647, 1831, 5533, 4629, 1413, 20037, 97343, 0 };
            const std::uint32_t dim6613JoeKuoD6Init[]   =   { 1, 1, 5, 1, 23, 41, 11, 149, 319, 377, 439, 1237, 4819, 14303, 14657, 61711, 129235, 0 };
            const std::uint32_t dim6614JoeKuoD6Init[]   =   { 1, 3, 3, 7, 9, 11, 79, 219, 249, 607, 1453, 2931, 3407, 13725, 28289, 42869, 96759, 0 };
            const std::uint32_t dim6615JoeKuoD6Init[]   =   { 1, 1, 5, 11, 7, 9, 101, 51, 11, 893, 697, 1221, 4237, 1873, 11191, 25517, 119861, 0 };
            const std::uint32_t dim6616JoeKuoD6Init[]   =   { 1, 1, 3, 11, 23, 23, 19, 245, 485, 317, 1945, 2339, 193, 9389, 30709, 33927, 95089, 0 };
            const std::uint32_t dim6617JoeKuoD6Init[]   =   { 1, 1, 3, 1, 27, 55, 5, 81, 63, 185, 223, 3639, 6093, 10053, 1793, 11885, 29307, 0 };
            const std::uint32_t dim6618JoeKuoD6Init[]   =   { 1, 1, 7, 13, 15, 41, 33, 133, 467, 457, 213, 3687, 1313, 2555, 19487, 44257, 108667, 0 };
            const std::uint32_t dim6619JoeKuoD6Init[]   =   { 1, 1, 3, 5, 31, 51, 53, 115, 449, 273, 1043, 2743, 1759, 2013, 28171, 57091, 76837, 0 };
            const std::uint32_t dim6620JoeKuoD6Init[]   =   { 1, 1, 5, 15, 21, 43, 11, 215, 151, 253, 913, 1889, 2799, 13787, 3869, 54413, 50991, 0 };
            const std::uint32_t dim6621JoeKuoD6Init[]   =   { 1, 1, 3, 13, 29, 19, 81, 123, 461, 203, 81, 555, 6601, 15689, 12637, 41467, 105343, 0 };
            const std::uint32_t dim6622JoeKuoD6Init[]   =   { 1, 1, 3, 13, 7, 21, 75, 111, 47, 481, 1519, 3299, 6199, 3501, 31323, 29215, 45607, 0 };
            const std::uint32_t dim6623JoeKuoD6Init[]   =   { 1, 3, 1, 3, 17, 51, 45, 223, 321, 233, 267, 3333, 3803, 3099, 4601, 29061, 88441, 0 };
            const std::uint32_t dim6624JoeKuoD6Init[]   =   { 1, 1, 5, 13, 23, 27, 7, 57, 273, 893, 773, 239, 6357, 15875, 5497, 21775, 108291, 0 };
            const std::uint32_t dim6625JoeKuoD6Init[]   =   { 1, 3, 1, 15, 25, 17, 11, 229, 175, 909, 691, 3507, 5247, 2933, 1741, 35059, 62841, 0 };
            const std::uint32_t dim6626JoeKuoD6Init[]   =   { 1, 3, 5, 1, 29, 7, 11, 69, 345, 87, 99, 3243, 5669, 11053, 1185, 6979, 117069, 0 };
            const std::uint32_t dim6627JoeKuoD6Init[]   =   { 1, 3, 5, 11, 13, 33, 23, 183, 89, 475, 643, 2773, 7899, 15219, 133, 5073, 129355, 0 };
            const std::uint32_t dim6628JoeKuoD6Init[]   =   { 1, 3, 7, 9, 23, 17, 31, 53, 455, 193, 1695, 2557, 1645, 12675, 27857, 50447, 121335, 0 };
            const std::uint32_t dim6629JoeKuoD6Init[]   =   { 1, 1, 3, 11, 15, 19, 41, 57, 305, 235, 1131, 1165, 1857, 13667, 19285, 29755, 118885, 0 };
            const std::uint32_t dim6630JoeKuoD6Init[]   =   { 1, 3, 7, 3, 9, 43, 107, 3, 275, 673, 677, 3769, 3097, 5497, 24911, 4617, 80505, 0 };
            const std::uint32_t dim6631JoeKuoD6Init[]   =   { 1, 1, 7, 9, 21, 39, 107, 155, 471, 753, 579, 2929, 4951, 4245, 25035, 41795, 86955, 0 };
            const std::uint32_t dim6632JoeKuoD6Init[]   =   { 1, 3, 1, 7, 31, 51, 27, 165, 147, 751, 709, 399, 45, 947, 9893, 32721, 122127, 0 };
            const std::uint32_t dim6633JoeKuoD6Init[]   =   { 1, 3, 3, 1, 31, 31, 73, 59, 351, 293, 845, 3139, 4177, 3537, 9465, 20689, 65837, 0 };
            const std::uint32_t dim6634JoeKuoD6Init[]   =   { 1, 3, 5, 9, 27, 29, 13, 115, 417, 435, 465, 1291, 5225, 11687, 29207, 39895, 55443, 0 };
            const std::uint32_t dim6635JoeKuoD6Init[]   =   { 1, 3, 3, 15, 29, 49, 111, 179, 221, 565, 787, 1811, 4055, 7863, 27273, 32975, 26985, 0 };
            const std::uint32_t dim6636JoeKuoD6Init[]   =   { 1, 1, 1, 7, 15, 49, 121, 145, 277, 27, 149, 965, 4903, 3497, 32333, 37217, 105073, 0 };
            const std::uint32_t dim6637JoeKuoD6Init[]   =   { 1, 1, 7, 1, 23, 29, 31, 77, 353, 349, 755, 2081, 4291, 567, 641, 41751, 20397, 0 };
            const std::uint32_t dim6638JoeKuoD6Init[]   =   { 1, 1, 5, 3, 25, 31, 97, 3, 405, 607, 965, 2981, 3217, 14695, 25977, 22457, 113539, 0 };
            const std::uint32_t dim6639JoeKuoD6Init[]   =   { 1, 3, 3, 15, 25, 3, 91, 125, 269, 825, 1163, 2181, 4247, 6813, 4699, 35091, 87771, 0 };
            const std::uint32_t dim6640JoeKuoD6Init[]   =   { 1, 1, 5, 9, 25, 23, 113, 145, 71, 31, 1115, 3729, 6793, 11869, 26509, 18779, 99499, 0 };
            const std::uint32_t dim6641JoeKuoD6Init[]   =   { 1, 1, 1, 9, 31, 51, 77, 217, 247, 599, 1541, 3217, 1383, 5203, 27971, 23647, 71823, 0 };
            const std::uint32_t dim6642JoeKuoD6Init[]   =   { 1, 1, 5, 7, 17, 35, 113, 73, 475, 511, 35, 1961, 5311, 2257, 1935, 58963, 94349, 0 };
            const std::uint32_t dim6643JoeKuoD6Init[]   =   { 1, 3, 1, 7, 27, 31, 67, 253, 95, 883, 1213, 855, 3429, 15049, 26715, 56099, 101797, 0 };
            const std::uint32_t dim6644JoeKuoD6Init[]   =   { 1, 1, 3, 5, 9, 9, 61, 57, 511, 537, 1803, 949, 1327, 3921, 11297, 13807, 64629, 0 };
            const std::uint32_t dim6645JoeKuoD6Init[]   =   { 1, 1, 5, 1, 31, 57, 105, 161, 309, 283, 1291, 2737, 7141, 7497, 25893, 14453, 35375, 0 };
            const std::uint32_t dim6646JoeKuoD6Init[]   =   { 1, 1, 3, 1, 21, 3, 77, 37, 13, 211, 1863, 1895, 8035, 5801, 25981, 12317, 48375, 0 };
            const std::uint32_t dim6647JoeKuoD6Init[]   =   { 1, 3, 7, 7, 25, 45, 13, 77, 185, 553, 1501, 1349, 5951, 15581, 32657, 18467, 128363, 0 };
            const std::uint32_t dim6648JoeKuoD6Init[]   =   { 1, 3, 5, 9, 23, 63, 105, 239, 213, 935, 1331, 3653, 2775, 6591, 6067, 34597, 19217, 0 };
            const std::uint32_t dim6649JoeKuoD6Init[]   =   { 1, 3, 7, 13, 15, 19, 79, 91, 391, 637, 1685, 2263, 3507, 2025, 2111, 15875, 14831, 0 };
            const std::uint32_t dim6650JoeKuoD6Init[]   =   { 1, 3, 3, 5, 7, 29, 81, 69, 511, 399, 343, 737, 2833, 1021, 10471, 18689, 36181, 0 };
            const std::uint32_t dim6651JoeKuoD6Init[]   =   { 1, 1, 5, 11, 21, 17, 39, 137, 145, 857, 583, 789, 8057, 15995, 32113, 64163, 37153, 0 };
            const std::uint32_t dim6652JoeKuoD6Init[]   =   { 1, 3, 3, 11, 9, 61, 87, 131, 487, 667, 1295, 493, 4629, 7719, 18157, 49715, 2051, 0 };
            const std::uint32_t dim6653JoeKuoD6Init[]   =   { 1, 3, 5, 9, 19, 5, 85, 3, 491, 353, 571, 2829, 4411, 343, 24781, 62325, 123959, 0 };
            const std::uint32_t dim6654JoeKuoD6Init[]   =   { 1, 1, 7, 13, 13, 39, 11, 31, 413, 285, 27, 2433, 3307, 6165, 26565, 40065, 102655, 0 };
            const std::uint32_t dim6655JoeKuoD6Init[]   =   { 1, 1, 5, 11, 25, 45, 7, 97, 9, 973, 1833, 2537, 1457, 7389, 24087, 38061, 122805, 0 };
            const std::uint32_t dim6656JoeKuoD6Init[]   =   { 1, 3, 5, 3, 21, 63, 77, 21, 249, 525, 1145, 1421, 8011, 3357, 15051, 30293, 127017, 0 };
            const std::uint32_t dim6657JoeKuoD6Init[]   =   { 1, 1, 5, 3, 13, 53, 81, 185, 303, 307, 1579, 841, 2277, 607, 10899, 34209, 215, 0 };
            const std::uint32_t dim6658JoeKuoD6Init[]   =   { 1, 3, 3, 13, 17, 1, 125, 145, 205, 763, 127, 1865, 4129, 849, 27247, 29845, 36515, 0 };
            const std::uint32_t dim6659JoeKuoD6Init[]   =   { 1, 3, 7, 13, 5, 59, 19, 71, 227, 111, 365, 1309, 5857, 6035, 32379, 11303, 127329, 0 };
            const std::uint32_t dim6660JoeKuoD6Init[]   =   { 1, 1, 1, 1, 19, 61, 79, 253, 459, 23, 725, 3615, 4583, 429, 13215, 31879, 4523, 0 };
            const std::uint32_t dim6661JoeKuoD6Init[]   =   { 1, 1, 1, 7, 19, 13, 53, 41, 243, 107, 1767, 983, 3483, 2249, 2209, 58895, 14805, 0 };
            const std::uint32_t dim6662JoeKuoD6Init[]   =   { 1, 1, 1, 9, 5, 63, 31, 85, 119, 307, 633, 3295, 841, 3495, 22965, 57587, 108271, 0 };
            const std::uint32_t dim6663JoeKuoD6Init[]   =   { 1, 3, 5, 9, 17, 13, 57, 49, 97, 613, 405, 2637, 3229, 14253, 4663, 61345, 33415, 0 };
            const std::uint32_t dim6664JoeKuoD6Init[]   =   { 1, 3, 1, 1, 17, 37, 63, 3, 5, 375, 1073, 3971, 665, 4445, 153, 20437, 38513, 0 };
            const std::uint32_t dim6665JoeKuoD6Init[]   =   { 1, 3, 3, 15, 5, 9, 77, 161, 409, 461, 443, 567, 5581, 8623, 27735, 9041, 5517, 0 };
            const std::uint32_t dim6666JoeKuoD6Init[]   =   { 1, 3, 5, 13, 13, 5, 19, 53, 263, 155, 557, 3973, 6841, 4829, 30751, 30025, 121973, 0 };
            const std::uint32_t dim6667JoeKuoD6Init[]   =   { 1, 3, 7, 9, 27, 37, 49, 243, 107, 1013, 1743, 1509, 4465, 15415, 4741, 41409, 72695, 0 };
            const std::uint32_t dim6668JoeKuoD6Init[]   =   { 1, 1, 3, 5, 11, 49, 39, 45, 21, 463, 875, 3681, 1901, 15325, 24553, 51369, 82227, 0 };
            const std::uint32_t dim6669JoeKuoD6Init[]   =   { 1, 1, 3, 15, 11, 35, 21, 91, 383, 149, 1815, 911, 4633, 12027, 12413, 22307, 120049, 0 };
            const std::uint32_t dim6670JoeKuoD6Init[]   =   { 1, 3, 5, 7, 7, 3, 15, 83, 477, 687, 145, 1705, 6893, 5233, 20171, 43337, 72603, 0 };
            const std::uint32_t dim6671JoeKuoD6Init[]   =   { 1, 1, 3, 9, 25, 35, 19, 173, 67, 5, 561, 2139, 4557, 4911, 26273, 38409, 22801, 0 };
            const std::uint32_t dim6672JoeKuoD6Init[]   =   { 1, 1, 3, 13, 15, 39, 85, 91, 91, 187, 1851, 1181, 4049, 16353, 26525, 43703, 19415, 0 };
            const std::uint32_t dim6673JoeKuoD6Init[]   =   { 1, 3, 1, 9, 13, 41, 77, 179, 415, 705, 693, 3017, 5847, 16191, 11435, 28979, 51839, 0 };
            const std::uint32_t dim6674JoeKuoD6Init[]   =   { 1, 1, 3, 5, 23, 15, 3, 159, 269, 67, 625, 4043, 4701, 1599, 6467, 10949, 80073, 0 };
            const std::uint32_t dim6675JoeKuoD6Init[]   =   { 1, 3, 3, 15, 7, 43, 81, 157, 393, 321, 1875, 2801, 4359, 11703, 1063, 64015, 109997, 0 };
            const std::uint32_t dim6676JoeKuoD6Init[]   =   { 1, 1, 7, 3, 25, 21, 37, 123, 133, 691, 973, 3115, 2291, 10519, 13339, 22751, 85445, 0 };
            const std::uint32_t dim6677JoeKuoD6Init[]   =   { 1, 3, 1, 1, 21, 21, 9, 23, 431, 679, 1873, 289, 4503, 3939, 14417, 36081, 18709, 0 };
            const std::uint32_t dim6678JoeKuoD6Init[]   =   { 1, 3, 5, 5, 1, 53, 109, 133, 33, 279, 727, 2233, 3065, 8557, 7487, 25797, 109177, 0 };
            const std::uint32_t dim6679JoeKuoD6Init[]   =   { 1, 1, 7, 7, 1, 9, 47, 127, 179, 757, 1985, 547, 169, 13393, 22669, 58795, 92897, 0 };
            const std::uint32_t dim6680JoeKuoD6Init[]   =   { 1, 3, 5, 11, 17, 21, 95, 219, 263, 579, 1493, 3283, 5461, 1235, 1749, 33325, 36033, 0 };
            const std::uint32_t dim6681JoeKuoD6Init[]   =   { 1, 1, 3, 11, 21, 49, 45, 143, 511, 983, 1933, 965, 7905, 1925, 27857, 40723, 68251, 0 };
            const std::uint32_t dim6682JoeKuoD6Init[]   =   { 1, 3, 7, 3, 27, 9, 73, 7, 441, 877, 107, 1599, 4795, 7251, 6819, 7671, 21137, 0 };
            const std::uint32_t dim6683JoeKuoD6Init[]   =   { 1, 1, 3, 3, 21, 25, 49, 43, 247, 949, 627, 2859, 2507, 4787, 11269, 53221, 126387, 0 };
            const std::uint32_t dim6684JoeKuoD6Init[]   =   { 1, 1, 5, 3, 5, 53, 127, 65, 353, 521, 1701, 2981, 3201, 611, 13475, 58015, 2605, 0 };
            const std::uint32_t dim6685JoeKuoD6Init[]   =   { 1, 1, 5, 13, 9, 39, 55, 103, 53, 281, 705, 2433, 6179, 3381, 31973, 30267, 91307, 0 };
            const std::uint32_t dim6686JoeKuoD6Init[]   =   { 1, 1, 7, 13, 31, 23, 29, 161, 347, 449, 123, 3427, 5731, 12691, 15175, 20487, 74695, 0 };
            const std::uint32_t dim6687JoeKuoD6Init[]   =   { 1, 3, 3, 15, 13, 19, 83, 137, 437, 317, 921, 913, 7979, 6665, 5313, 1435, 60271, 0 };
            const std::uint32_t dim6688JoeKuoD6Init[]   =   { 1, 3, 5, 7, 19, 23, 31, 131, 421, 95, 1999, 897, 4839, 1815, 12387, 45009, 2609, 0 };
            const std::uint32_t dim6689JoeKuoD6Init[]   =   { 1, 1, 1, 7, 3, 53, 121, 33, 47, 283, 813, 3841, 4449, 2543, 15211, 59285, 42551, 0 };
            const std::uint32_t dim6690JoeKuoD6Init[]   =   { 1, 3, 1, 13, 9, 43, 37, 167, 93, 417, 213, 2721, 3395, 2089, 13743, 32925, 91147, 0 };
            const std::uint32_t dim6691JoeKuoD6Init[]   =   { 1, 3, 7, 5, 31, 25, 97, 25, 19, 11, 543, 1889, 455, 5765, 9517, 56963, 131069, 0 };
            const std::uint32_t dim6692JoeKuoD6Init[]   =   { 1, 3, 1, 7, 3, 7, 87, 61, 209, 39, 1303, 1637, 6687, 8001, 5003, 47911, 110657, 0 };
            const std::uint32_t dim6693JoeKuoD6Init[]   =   { 1, 1, 5, 3, 11, 25, 99, 77, 379, 843, 1423, 2933, 7535, 4181, 32223, 49327, 48041, 0 };
            const std::uint32_t dim6694JoeKuoD6Init[]   =   { 1, 3, 3, 13, 9, 7, 85, 59, 47, 777, 401, 2449, 2795, 11289, 25023, 7725, 73887, 0 };
            const std::uint32_t dim6695JoeKuoD6Init[]   =   { 1, 1, 3, 5, 11, 51, 93, 57, 369, 871, 1175, 2705, 1253, 5169, 24691, 14243, 119667, 0 };
            const std::uint32_t dim6696JoeKuoD6Init[]   =   { 1, 3, 1, 3, 5, 7, 33, 171, 359, 115, 1909, 2003, 1413, 13829, 3471, 36185, 118399, 0 };
            const std::uint32_t dim6697JoeKuoD6Init[]   =   { 1, 1, 1, 11, 5, 49, 97, 145, 415, 731, 671, 2309, 7211, 11359, 22757, 15415, 70951, 0 };
            const std::uint32_t dim6698JoeKuoD6Init[]   =   { 1, 1, 3, 5, 7, 51, 61, 101, 375, 575, 1321, 2835, 7569, 9599, 4707, 7655, 53417, 0 };
            const std::uint32_t dim6699JoeKuoD6Init[]   =   { 1, 3, 1, 15, 9, 63, 25, 117, 203, 5, 1345, 2571, 5273, 2059, 4689, 27237, 23199, 0 };
            const std::uint32_t dim6700JoeKuoD6Init[]   =   { 1, 1, 3, 15, 15, 23, 69, 49, 349, 995, 5, 1565, 903, 10165, 9565, 6343, 16653, 0 };
            const std::uint32_t dim6701JoeKuoD6Init[]   =   { 1, 1, 3, 9, 21, 15, 69, 9, 463, 69, 1447, 2347, 5125, 7479, 18257, 14405, 51321, 0 };
            const std::uint32_t dim6702JoeKuoD6Init[]   =   { 1, 1, 7, 11, 23, 57, 57, 179, 17, 129, 999, 777, 6281, 1693, 31885, 31085, 29237, 0 };
            const std::uint32_t dim6703JoeKuoD6Init[]   =   { 1, 3, 5, 1, 25, 55, 15, 21, 199, 271, 1645, 1719, 2023, 10049, 15215, 11959, 44875, 0 };
            const std::uint32_t dim6704JoeKuoD6Init[]   =   { 1, 3, 1, 3, 29, 43, 83, 11, 281, 27, 429, 685, 7189, 9151, 8665, 9553, 115293, 0 };
            const std::uint32_t dim6705JoeKuoD6Init[]   =   { 1, 3, 1, 7, 17, 43, 125, 11, 189, 803, 713, 683, 7285, 4455, 18195, 45333, 32281, 0 };
            const std::uint32_t dim6706JoeKuoD6Init[]   =   { 1, 3, 3, 3, 11, 55, 21, 59, 173, 283, 709, 1561, 5391, 5097, 24725, 19217, 13769, 0 };
            const std::uint32_t dim6707JoeKuoD6Init[]   =   { 1, 3, 5, 13, 7, 29, 117, 207, 415, 525, 567, 1741, 3553, 6729, 433, 17619, 45971, 0 };
            const std::uint32_t dim6708JoeKuoD6Init[]   =   { 1, 1, 7, 7, 3, 23, 43, 43, 213, 823, 609, 1037, 3797, 4733, 30717, 61067, 89581, 0 };
            const std::uint32_t dim6709JoeKuoD6Init[]   =   { 1, 3, 5, 7, 11, 7, 7, 241, 379, 217, 739, 2815, 2549, 14297, 10283, 1509, 80613, 0 };
            const std::uint32_t dim6710JoeKuoD6Init[]   =   { 1, 1, 1, 1, 17, 45, 53, 229, 193, 893, 1881, 227, 6751, 7135, 20823, 36939, 27667, 0 };
            const std::uint32_t dim6711JoeKuoD6Init[]   =   { 1, 3, 3, 1, 15, 39, 27, 217, 101, 949, 1963, 2213, 2357, 4129, 11925, 841, 59259, 0 };
            const std::uint32_t dim6712JoeKuoD6Init[]   =   { 1, 1, 3, 3, 5, 53, 59, 255, 421, 1009, 683, 2171, 6691, 12489, 20865, 29363, 70611, 0 };
            const std::uint32_t dim6713JoeKuoD6Init[]   =   { 1, 1, 7, 15, 7, 31, 105, 141, 153, 401, 549, 3045, 5443, 11147, 18159, 24283, 21859, 0 };
            const std::uint32_t dim6714JoeKuoD6Init[]   =   { 1, 3, 7, 1, 11, 17, 17, 231, 175, 603, 1915, 111, 3203, 10627, 9687, 47235, 87057, 0 };
            const std::uint32_t dim6715JoeKuoD6Init[]   =   { 1, 1, 1, 11, 19, 21, 115, 41, 45, 727, 1523, 739, 3025, 10321, 27353, 63139, 16051, 0 };
            const std::uint32_t dim6716JoeKuoD6Init[]   =   { 1, 3, 7, 11, 13, 9, 33, 121, 237, 565, 2043, 2131, 3079, 12575, 2187, 14427, 85939, 0 };
            const std::uint32_t dim6717JoeKuoD6Init[]   =   { 1, 3, 1, 15, 21, 19, 91, 227, 485, 49, 101, 15, 1903, 4039, 23819, 40001, 66405, 0 };
            const std::uint32_t dim6718JoeKuoD6Init[]   =   { 1, 3, 1, 5, 15, 25, 65, 25, 393, 287, 1435, 1851, 6437, 5983, 13769, 37847, 120907, 0 };
            const std::uint32_t dim6719JoeKuoD6Init[]   =   { 1, 3, 7, 15, 15, 21, 97, 37, 359, 155, 807, 1421, 517, 13135, 2955, 56979, 52299, 0 };
            const std::uint32_t dim6720JoeKuoD6Init[]   =   { 1, 1, 5, 1, 27, 53, 79, 27, 467, 605, 267, 1193, 31, 6177, 12369, 32621, 38319, 0 };
            const std::uint32_t dim6721JoeKuoD6Init[]   =   { 1, 1, 1, 11, 27, 15, 15, 231, 205, 677, 331, 133, 3313, 7193, 8059, 36449, 21671, 0 };
            const std::uint32_t dim6722JoeKuoD6Init[]   =   { 1, 3, 3, 11, 19, 57, 113, 83, 399, 801, 1843, 2119, 2779, 14061, 30901, 28745, 120903, 0 };
            const std::uint32_t dim6723JoeKuoD6Init[]   =   { 1, 1, 1, 11, 5, 27, 121, 247, 467, 251, 1487, 251, 897, 3171, 28383, 22473, 1709, 0 };
            const std::uint32_t dim6724JoeKuoD6Init[]   =   { 1, 1, 1, 15, 7, 59, 123, 165, 123, 373, 167, 1323, 5239, 9027, 13791, 55593, 78785, 0 };
            const std::uint32_t dim6725JoeKuoD6Init[]   =   { 1, 3, 1, 11, 31, 11, 81, 229, 123, 183, 461, 1751, 5713, 2615, 27795, 1657, 39253, 0 };
            const std::uint32_t dim6726JoeKuoD6Init[]   =   { 1, 1, 7, 1, 21, 45, 107, 3, 283, 149, 549, 3731, 6435, 3595, 32753, 16079, 84257, 0 };
            const std::uint32_t dim6727JoeKuoD6Init[]   =   { 1, 3, 3, 15, 19, 9, 81, 37, 51, 341, 909, 985, 1503, 12787, 16129, 37789, 113515, 0 };
            const std::uint32_t dim6728JoeKuoD6Init[]   =   { 1, 3, 5, 13, 3, 33, 127, 219, 369, 341, 1191, 1305, 567, 2339, 31221, 49435, 114927, 0 };
            const std::uint32_t dim6729JoeKuoD6Init[]   =   { 1, 1, 7, 15, 29, 47, 103, 107, 257, 15, 2029, 2133, 2129, 11235, 29553, 49139, 33809, 0 };
            const std::uint32_t dim6730JoeKuoD6Init[]   =   { 1, 3, 3, 13, 23, 33, 105, 43, 155, 815, 1087, 2261, 2781, 3461, 7371, 4479, 123093, 0 };
            const std::uint32_t dim6731JoeKuoD6Init[]   =   { 1, 1, 1, 13, 17, 7, 89, 107, 143, 349, 637, 3651, 4153, 12131, 28393, 45781, 84133, 0 };
            const std::uint32_t dim6732JoeKuoD6Init[]   =   { 1, 3, 5, 11, 31, 47, 105, 101, 267, 403, 1853, 3977, 3277, 1737, 15503, 47365, 14361, 0 };
            const std::uint32_t dim6733JoeKuoD6Init[]   =   { 1, 1, 1, 13, 1, 63, 125, 107, 123, 183, 1027, 3491, 3597, 15949, 5779, 34665, 81257, 0 };
            const std::uint32_t dim6734JoeKuoD6Init[]   =   { 1, 3, 1, 9, 13, 5, 125, 41, 389, 73, 1487, 1983, 957, 12645, 13983, 7675, 72711, 0 };
            const std::uint32_t dim6735JoeKuoD6Init[]   =   { 1, 3, 7, 5, 17, 5, 25, 63, 211, 591, 261, 2345, 3883, 4403, 773, 43963, 93509, 0 };
            const std::uint32_t dim6736JoeKuoD6Init[]   =   { 1, 3, 3, 1, 11, 35, 15, 251, 225, 643, 537, 3769, 7593, 6113, 1377, 52185, 81459, 0 };
            const std::uint32_t dim6737JoeKuoD6Init[]   =   { 1, 3, 5, 15, 27, 27, 51, 35, 389, 853, 1437, 2803, 5739, 1887, 15099, 3299, 111827, 0 };
            const std::uint32_t dim6738JoeKuoD6Init[]   =   { 1, 1, 3, 15, 25, 63, 31, 201, 79, 131, 31, 3929, 4195, 13045, 8681, 48121, 110723, 0 };
            const std::uint32_t dim6739JoeKuoD6Init[]   =   { 1, 1, 5, 7, 11, 43, 101, 57, 69, 271, 189, 3087, 4893, 11365, 6945, 14285, 41961, 0 };
            const std::uint32_t dim6740JoeKuoD6Init[]   =   { 1, 1, 7, 9, 21, 61, 41, 123, 25, 947, 1619, 2895, 7879, 12397, 17405, 48139, 71519, 0 };
            const std::uint32_t dim6741JoeKuoD6Init[]   =   { 1, 3, 1, 15, 1, 27, 113, 225, 441, 855, 541, 357, 3111, 4867, 20571, 30627, 70123, 0 };
            const std::uint32_t dim6742JoeKuoD6Init[]   =   { 1, 3, 5, 3, 5, 33, 103, 1, 21, 93, 383, 407, 5145, 7857, 20289, 51943, 16223, 0 };
            const std::uint32_t dim6743JoeKuoD6Init[]   =   { 1, 1, 7, 15, 1, 13, 41, 215, 463, 417, 513, 3417, 1755, 16165, 7271, 3101, 54353, 0 };
            const std::uint32_t dim6744JoeKuoD6Init[]   =   { 1, 3, 3, 13, 19, 29, 5, 205, 245, 927, 1249, 773, 3653, 9959, 357, 40863, 37289, 0 };
            const std::uint32_t dim6745JoeKuoD6Init[]   =   { 1, 3, 3, 7, 3, 5, 85, 241, 29, 627, 1963, 3133, 1369, 503, 11449, 4699, 2573, 0 };
            const std::uint32_t dim6746JoeKuoD6Init[]   =   { 1, 1, 7, 15, 3, 35, 47, 157, 413, 437, 1627, 3953, 947, 12721, 22209, 34303, 81237, 0 };
            const std::uint32_t dim6747JoeKuoD6Init[]   =   { 1, 1, 5, 5, 1, 45, 47, 245, 253, 349, 1853, 3481, 6105, 7267, 3159, 38833, 117889, 0 };
            const std::uint32_t dim6748JoeKuoD6Init[]   =   { 1, 3, 7, 15, 23, 43, 25, 181, 121, 681, 479, 1239, 6155, 3317, 9419, 28717, 44643, 0 };
            const std::uint32_t dim6749JoeKuoD6Init[]   =   { 1, 3, 3, 15, 31, 43, 111, 99, 405, 991, 301, 1689, 7107, 16131, 16703, 24059, 40345, 0 };
            const std::uint32_t dim6750JoeKuoD6Init[]   =   { 1, 1, 3, 9, 25, 5, 107, 91, 117, 351, 1595, 163, 3007, 13743, 24535, 38671, 29745, 0 };
            const std::uint32_t dim6751JoeKuoD6Init[]   =   { 1, 3, 3, 5, 27, 47, 15, 195, 119, 919, 665, 1903, 1981, 7753, 21709, 33699, 15963, 0 };
            const std::uint32_t dim6752JoeKuoD6Init[]   =   { 1, 3, 1, 11, 23, 23, 75, 115, 477, 105, 541, 1111, 209, 13939, 17129, 7565, 75415, 0 };
            const std::uint32_t dim6753JoeKuoD6Init[]   =   { 1, 1, 1, 11, 7, 61, 123, 201, 305, 713, 779, 2059, 4899, 13733, 20529, 15617, 39833, 0 };
            const std::uint32_t dim6754JoeKuoD6Init[]   =   { 1, 1, 7, 11, 21, 7, 63, 113, 213, 871, 375, 29, 1925, 15237, 7091, 12229, 8457, 0 };
            const std::uint32_t dim6755JoeKuoD6Init[]   =   { 1, 1, 1, 7, 19, 57, 83, 91, 297, 255, 1993, 63, 5337, 4569, 21243, 40867, 46969, 0 };
            const std::uint32_t dim6756JoeKuoD6Init[]   =   { 1, 1, 3, 7, 13, 63, 91, 191, 281, 259, 1367, 3505, 5885, 10557, 12423, 56303, 14731, 0 };
            const std::uint32_t dim6757JoeKuoD6Init[]   =   { 1, 1, 5, 15, 27, 15, 29, 67, 115, 287, 253, 1497, 3739, 2183, 14427, 44931, 11547, 0 };
            const std::uint32_t dim6758JoeKuoD6Init[]   =   { 1, 3, 1, 9, 25, 61, 25, 113, 137, 819, 781, 3741, 2457, 7817, 31209, 20707, 93007, 0 };
            const std::uint32_t dim6759JoeKuoD6Init[]   =   { 1, 1, 7, 3, 5, 13, 23, 3, 365, 77, 1117, 3061, 4707, 3013, 27899, 10887, 78677, 0 };
            const std::uint32_t dim6760JoeKuoD6Init[]   =   { 1, 3, 1, 15, 1, 39, 85, 107, 483, 83, 603, 3121, 1995, 5241, 32319, 9515, 94551, 0 };
            const std::uint32_t dim6761JoeKuoD6Init[]   =   { 1, 1, 7, 3, 27, 13, 105, 41, 285, 237, 1589, 517, 2009, 10833, 1459, 26217, 50759, 0 };
            const std::uint32_t dim6762JoeKuoD6Init[]   =   { 1, 1, 3, 11, 27, 1, 127, 83, 355, 107, 1003, 657, 4997, 4123, 13151, 56601, 122307, 0 };
            const std::uint32_t dim6763JoeKuoD6Init[]   =   { 1, 1, 1, 7, 13, 17, 93, 75, 481, 473, 131, 1359, 4859, 1319, 23919, 50079, 128849, 0 };
            const std::uint32_t dim6764JoeKuoD6Init[]   =   { 1, 1, 3, 7, 9, 33, 111, 229, 11, 283, 1089, 3049, 1635, 959, 19109, 62821, 105391, 0 };
            const std::uint32_t dim6765JoeKuoD6Init[]   =   { 1, 3, 1, 3, 9, 47, 49, 169, 343, 929, 1379, 1985, 5867, 6053, 12179, 39727, 116053, 0 };
            const std::uint32_t dim6766JoeKuoD6Init[]   =   { 1, 3, 3, 15, 27, 39, 61, 113, 439, 719, 1313, 3701, 4793, 10275, 2943, 32405, 95457, 0 };
            const std::uint32_t dim6767JoeKuoD6Init[]   =   { 1, 1, 1, 1, 27, 49, 121, 171, 319, 365, 1593, 1655, 63, 6257, 18097, 35285, 112245, 0 };
            const std::uint32_t dim6768JoeKuoD6Init[]   =   { 1, 3, 1, 1, 19, 33, 89, 235, 281, 519, 1867, 525, 4475, 12059, 26611, 14789, 59541, 0 };
            const std::uint32_t dim6769JoeKuoD6Init[]   =   { 1, 3, 1, 15, 1, 51, 65, 71, 131, 599, 117, 2459, 7421, 7157, 24393, 48139, 53701, 0 };
            const std::uint32_t dim6770JoeKuoD6Init[]   =   { 1, 1, 7, 7, 1, 41, 57, 191, 207, 329, 43, 1235, 5671, 12243, 22549, 40751, 104513, 0 };
            const std::uint32_t dim6771JoeKuoD6Init[]   =   { 1, 3, 5, 13, 15, 21, 55, 187, 283, 209, 1511, 1329, 6665, 15953, 4521, 16879, 57625, 0 };
            const std::uint32_t dim6772JoeKuoD6Init[]   =   { 1, 1, 5, 3, 3, 53, 75, 123, 291, 663, 1893, 3669, 4903, 8575, 27971, 46977, 56357, 0 };
            const std::uint32_t dim6773JoeKuoD6Init[]   =   { 1, 3, 1, 5, 27, 41, 19, 199, 489, 197, 439, 3299, 6315, 6957, 15809, 35297, 5559, 0 };
            const std::uint32_t dim6774JoeKuoD6Init[]   =   { 1, 3, 5, 1, 3, 25, 109, 191, 33, 543, 125, 2309, 429, 14059, 3149, 45747, 47357, 0 };
            const std::uint32_t dim6775JoeKuoD6Init[]   =   { 1, 1, 3, 11, 15, 61, 109, 103, 305, 1, 1479, 2781, 6521, 8921, 23681, 9583, 87257, 0 };
            const std::uint32_t dim6776JoeKuoD6Init[]   =   { 1, 1, 7, 15, 5, 19, 121, 139, 177, 967, 1363, 705, 211, 11877, 22457, 34563, 7801, 0 };
            const std::uint32_t dim6777JoeKuoD6Init[]   =   { 1, 1, 7, 13, 9, 21, 103, 95, 483, 567, 5, 2095, 4659, 2447, 23521, 27273, 85867, 0 };
            const std::uint32_t dim6778JoeKuoD6Init[]   =   { 1, 3, 5, 15, 23, 55, 13, 237, 275, 113, 1431, 2931, 5165, 5317, 5625, 51865, 42177, 0 };
            const std::uint32_t dim6779JoeKuoD6Init[]   =   { 1, 3, 3, 7, 1, 23, 15, 171, 303, 43, 1137, 1255, 3843, 9049, 1799, 7075, 2115, 0 };
            const std::uint32_t dim6780JoeKuoD6Init[]   =   { 1, 1, 7, 5, 23, 53, 75, 129, 1, 511, 793, 265, 6535, 9641, 25173, 9449, 46949, 0 };
            const std::uint32_t dim6781JoeKuoD6Init[]   =   { 1, 3, 3, 1, 19, 39, 51, 173, 5, 281, 2047, 4065, 3225, 14587, 16947, 1459, 87227, 0 };
            const std::uint32_t dim6782JoeKuoD6Init[]   =   { 1, 3, 7, 13, 13, 53, 39, 115, 403, 37, 1533, 2727, 2229, 8291, 18687, 59553, 37629, 0 };
            const std::uint32_t dim6783JoeKuoD6Init[]   =   { 1, 3, 1, 9, 3, 55, 63, 191, 147, 321, 1287, 2419, 6881, 2249, 11141, 54839, 50263, 0 };
            const std::uint32_t dim6784JoeKuoD6Init[]   =   { 1, 1, 5, 3, 9, 61, 85, 139, 1, 409, 633, 53, 163, 14677, 13043, 12253, 106939, 0 };
            const std::uint32_t dim6785JoeKuoD6Init[]   =   { 1, 1, 7, 3, 19, 3, 7, 165, 497, 621, 1563, 1267, 8113, 2383, 17205, 13337, 102547, 0 };
            const std::uint32_t dim6786JoeKuoD6Init[]   =   { 1, 3, 3, 13, 15, 29, 23, 31, 481, 535, 471, 2125, 331, 9421, 29799, 27097, 5307, 0 };
            const std::uint32_t dim6787JoeKuoD6Init[]   =   { 1, 1, 1, 1, 31, 45, 47, 139, 235, 509, 889, 685, 1855, 13599, 24431, 62105, 109509, 0 };
            const std::uint32_t dim6788JoeKuoD6Init[]   =   { 1, 3, 1, 7, 3, 13, 25, 197, 111, 45, 1815, 1031, 4803, 349, 32369, 40837, 111529, 0 };
            const std::uint32_t dim6789JoeKuoD6Init[]   =   { 1, 1, 7, 1, 27, 9, 3, 73, 403, 321, 967, 2713, 6953, 16123, 8611, 48651, 120635, 0 };
            const std::uint32_t dim6790JoeKuoD6Init[]   =   { 1, 3, 5, 3, 3, 25, 69, 231, 249, 393, 1141, 1721, 7071, 3711, 15627, 21815, 104735, 0 };
            const std::uint32_t dim6791JoeKuoD6Init[]   =   { 1, 3, 1, 11, 19, 63, 77, 5, 55, 481, 1021, 119, 3941, 1227, 10997, 29513, 18923, 0 };
            const std::uint32_t dim6792JoeKuoD6Init[]   =   { 1, 3, 7, 5, 1, 11, 13, 99, 365, 797, 1993, 699, 3091, 11401, 3659, 15339, 90395, 0 };
            const std::uint32_t dim6793JoeKuoD6Init[]   =   { 1, 3, 5, 7, 31, 43, 55, 143, 273, 379, 1189, 1689, 4811, 5159, 3281, 63819, 57065, 0 };
            const std::uint32_t dim6794JoeKuoD6Init[]   =   { 1, 1, 1, 13, 9, 25, 9, 3, 461, 281, 959, 2439, 3187, 4837, 13857, 20221, 29733, 0 };
            const std::uint32_t dim6795JoeKuoD6Init[]   =   { 1, 1, 7, 11, 31, 17, 13, 101, 81, 921, 1329, 2421, 2747, 9435, 23313, 7093, 7547, 0 };
            const std::uint32_t dim6796JoeKuoD6Init[]   =   { 1, 1, 3, 3, 9, 51, 67, 95, 511, 1011, 1519, 4089, 5001, 1351, 15367, 50665, 92111, 0 };
            const std::uint32_t dim6797JoeKuoD6Init[]   =   { 1, 1, 5, 13, 27, 43, 115, 77, 439, 589, 31, 915, 7027, 697, 25143, 1443, 59093, 0 };
            const std::uint32_t dim6798JoeKuoD6Init[]   =   { 1, 1, 7, 3, 17, 5, 107, 117, 133, 649, 1309, 2979, 969, 9789, 12597, 24507, 106825, 0 };
            const std::uint32_t dim6799JoeKuoD6Init[]   =   { 1, 1, 7, 13, 1, 27, 97, 35, 431, 183, 199, 2619, 515, 89, 20281, 30291, 97977, 0 };
            const std::uint32_t dim6800JoeKuoD6Init[]   =   { 1, 1, 7, 1, 31, 9, 35, 11, 359, 21, 1875, 3227, 1307, 15691, 17343, 21163, 84671, 0 };
            const std::uint32_t dim6801JoeKuoD6Init[]   =   { 1, 3, 1, 11, 29, 21, 47, 137, 441, 841, 1641, 3283, 1371, 8835, 16287, 45009, 13779, 0 };
            const std::uint32_t dim6802JoeKuoD6Init[]   =   { 1, 1, 3, 9, 23, 53, 1, 99, 473, 649, 447, 2589, 5667, 15579, 6497, 44321, 46993, 0 };
            const std::uint32_t dim6803JoeKuoD6Init[]   =   { 1, 1, 7, 9, 31, 63, 95, 81, 197, 373, 1027, 3959, 7189, 13369, 17287, 53643, 12673, 0 };
            const std::uint32_t dim6804JoeKuoD6Init[]   =   { 1, 3, 1, 5, 25, 61, 79, 183, 489, 725, 1077, 1147, 113, 7357, 27505, 529, 61855, 0 };
            const std::uint32_t dim6805JoeKuoD6Init[]   =   { 1, 1, 7, 11, 19, 35, 73, 223, 125, 765, 1303, 2887, 7861, 14839, 9537, 27027, 94327, 0 };
            const std::uint32_t dim6806JoeKuoD6Init[]   =   { 1, 3, 1, 3, 17, 35, 63, 233, 317, 133, 1837, 3339, 4351, 10071, 5005, 13245, 34327, 0 };
            const std::uint32_t dim6807JoeKuoD6Init[]   =   { 1, 3, 1, 3, 17, 13, 59, 113, 247, 1015, 1831, 3391, 6337, 6853, 7145, 64309, 40109, 0 };
            const std::uint32_t dim6808JoeKuoD6Init[]   =   { 1, 3, 5, 13, 15, 23, 65, 203, 241, 545, 1521, 1253, 3171, 7777, 21145, 565, 87813, 0 };
            const std::uint32_t dim6809JoeKuoD6Init[]   =   { 1, 1, 5, 15, 31, 9, 9, 145, 409, 155, 409, 2935, 5817, 11427, 32617, 38167, 69465, 0 };
            const std::uint32_t dim6810JoeKuoD6Init[]   =   { 1, 1, 5, 11, 19, 31, 43, 85, 97, 931, 687, 1501, 3991, 2215, 11091, 64735, 56999, 0 };
            const std::uint32_t dim6811JoeKuoD6Init[]   =   { 1, 1, 1, 3, 7, 11, 101, 21, 345, 829, 531, 1475, 6617, 1187, 26885, 32135, 9733, 0 };
            const std::uint32_t dim6812JoeKuoD6Init[]   =   { 1, 3, 5, 11, 7, 49, 79, 197, 57, 15, 1845, 1485, 6167, 10887, 17083, 59367, 7411, 0 };
            const std::uint32_t dim6813JoeKuoD6Init[]   =   { 1, 3, 7, 5, 9, 33, 7, 91, 311, 847, 1435, 3573, 3693, 5369, 26817, 30105, 115337, 0 };
            const std::uint32_t dim6814JoeKuoD6Init[]   =   { 1, 3, 1, 9, 25, 43, 65, 69, 225, 337, 575, 1979, 5555, 8499, 8127, 33035, 52549, 0 };
            const std::uint32_t dim6815JoeKuoD6Init[]   =   { 1, 1, 3, 11, 17, 29, 71, 99, 379, 145, 1067, 2561, 7635, 5647, 32491, 56621, 93603, 0 };
            const std::uint32_t dim6816JoeKuoD6Init[]   =   { 1, 1, 5, 13, 25, 43, 75, 237, 407, 393, 1219, 3651, 7719, 11685, 26123, 62767, 1043, 0 };
            const std::uint32_t dim6817JoeKuoD6Init[]   =   { 1, 1, 7, 15, 13, 59, 9, 163, 273, 225, 873, 3201, 633, 6121, 18777, 58763, 77731, 0 };
            const std::uint32_t dim6818JoeKuoD6Init[]   =   { 1, 3, 7, 7, 3, 7, 99, 155, 279, 991, 799, 753, 7205, 9567, 23643, 38263, 19083, 0 };
            const std::uint32_t dim6819JoeKuoD6Init[]   =   { 1, 3, 7, 11, 11, 29, 65, 3, 207, 575, 253, 2407, 7935, 11323, 23239, 1923, 47737, 0 };
            const std::uint32_t dim6820JoeKuoD6Init[]   =   { 1, 1, 5, 9, 25, 47, 1, 25, 397, 1009, 193, 4031, 3023, 2029, 10561, 32363, 104405, 0 };
            const std::uint32_t dim6821JoeKuoD6Init[]   =   { 1, 3, 7, 9, 19, 55, 63, 179, 385, 97, 461, 3393, 8137, 8929, 17621, 9611, 58925, 0 };
            const std::uint32_t dim6822JoeKuoD6Init[]   =   { 1, 1, 1, 7, 1, 17, 127, 45, 157, 529, 809, 3545, 5173, 5083, 13325, 52295, 91261, 0 };
            const std::uint32_t dim6823JoeKuoD6Init[]   =   { 1, 1, 7, 9, 25, 49, 99, 79, 157, 535, 1569, 2195, 1725, 1187, 18423, 47957, 10043, 0 };
            const std::uint32_t dim6824JoeKuoD6Init[]   =   { 1, 1, 3, 7, 3, 31, 83, 45, 199, 665, 1261, 3497, 7885, 5761, 17187, 12041, 12867, 0 };
            const std::uint32_t dim6825JoeKuoD6Init[]   =   { 1, 3, 1, 7, 3, 55, 73, 215, 41, 1011, 1883, 1051, 7293, 1881, 27435, 29459, 130933, 0 };
            const std::uint32_t dim6826JoeKuoD6Init[]   =   { 1, 1, 3, 9, 21, 31, 113, 209, 35, 771, 365, 3151, 787, 3845, 26555, 13823, 36951, 0 };
            const std::uint32_t dim6827JoeKuoD6Init[]   =   { 1, 3, 7, 15, 13, 21, 119, 91, 15, 251, 1337, 2715, 1665, 3451, 8309, 11033, 127159, 0 };
            const std::uint32_t dim6828JoeKuoD6Init[]   =   { 1, 3, 1, 9, 9, 63, 5, 145, 357, 9, 859, 1565, 1141, 14689, 25121, 41337, 83357, 0 };
            const std::uint32_t dim6829JoeKuoD6Init[]   =   { 1, 1, 7, 11, 13, 63, 57, 151, 33, 595, 2025, 571, 4713, 11019, 26771, 16221, 92439, 0 };
            const std::uint32_t dim6830JoeKuoD6Init[]   =   { 1, 3, 3, 15, 29, 49, 93, 131, 167, 835, 33, 263, 93, 8475, 16139, 61237, 95081, 0 };
            const std::uint32_t dim6831JoeKuoD6Init[]   =   { 1, 1, 7, 13, 1, 57, 43, 91, 485, 841, 1415, 3083, 2665, 8521, 9825, 59955, 21763, 0 };
            const std::uint32_t dim6832JoeKuoD6Init[]   =   { 1, 1, 1, 1, 29, 47, 63, 107, 439, 847, 537, 2011, 7571, 3699, 23961, 54887, 92681, 0 };
            const std::uint32_t dim6833JoeKuoD6Init[]   =   { 1, 3, 7, 5, 27, 41, 105, 161, 95, 821, 451, 2627, 4687, 1899, 18851, 35167, 6869, 0 };
            const std::uint32_t dim6834JoeKuoD6Init[]   =   { 1, 1, 1, 11, 7, 7, 13, 163, 399, 471, 1587, 2561, 1241, 5365, 27189, 49883, 68101, 0 };
            const std::uint32_t dim6835JoeKuoD6Init[]   =   { 1, 3, 7, 9, 19, 5, 119, 251, 151, 359, 235, 2387, 3919, 7135, 17591, 1053, 6265, 0 };
            const std::uint32_t dim6836JoeKuoD6Init[]   =   { 1, 1, 5, 9, 13, 25, 43, 23, 453, 693, 517, 1235, 1045, 4299, 27877, 3733, 72269, 0 };
            const std::uint32_t dim6837JoeKuoD6Init[]   =   { 1, 1, 7, 1, 27, 43, 103, 249, 487, 67, 855, 3239, 2157, 8121, 4701, 37803, 49971, 0 };
            const std::uint32_t dim6838JoeKuoD6Init[]   =   { 1, 1, 3, 13, 1, 37, 125, 115, 365, 57, 1419, 4085, 7039, 10079, 14991, 48861, 61979, 0 };
            const std::uint32_t dim6839JoeKuoD6Init[]   =   { 1, 1, 5, 5, 3, 35, 109, 19, 219, 653, 1219, 1625, 6847, 11271, 4525, 56341, 57801, 0 };
            const std::uint32_t dim6840JoeKuoD6Init[]   =   { 1, 3, 7, 5, 31, 19, 37, 73, 185, 13, 1723, 1139, 5919, 11717, 27161, 13635, 51765, 0 };
            const std::uint32_t dim6841JoeKuoD6Init[]   =   { 1, 1, 1, 1, 19, 61, 53, 111, 215, 189, 1199, 591, 943, 2111, 17171, 15621, 128459, 0 };
            const std::uint32_t dim6842JoeKuoD6Init[]   =   { 1, 1, 7, 9, 17, 61, 101, 159, 85, 537, 15, 1427, 6139, 4091, 32639, 28655, 115385, 0 };
            const std::uint32_t dim6843JoeKuoD6Init[]   =   { 1, 1, 7, 5, 23, 31, 125, 7, 151, 967, 1079, 4059, 3287, 11673, 19307, 49469, 65981, 0 };
            const std::uint32_t dim6844JoeKuoD6Init[]   =   { 1, 3, 3, 1, 29, 59, 95, 119, 31, 427, 1653, 721, 5509, 6385, 17043, 45133, 74155, 0 };
            const std::uint32_t dim6845JoeKuoD6Init[]   =   { 1, 1, 3, 9, 13, 61, 35, 189, 1, 559, 119, 3719, 4137, 1369, 19147, 10923, 43909, 0 };
            const std::uint32_t dim6846JoeKuoD6Init[]   =   { 1, 3, 3, 13, 1, 41, 31, 185, 451, 379, 29, 153, 4121, 13153, 4171, 36993, 109241, 0 };
            const std::uint32_t dim6847JoeKuoD6Init[]   =   { 1, 1, 1, 9, 15, 41, 99, 17, 21, 93, 649, 2765, 6955, 10843, 12547, 64989, 63713, 0 };
            const std::uint32_t dim6848JoeKuoD6Init[]   =   { 1, 1, 7, 5, 5, 5, 73, 187, 473, 235, 1907, 409, 7335, 4429, 7493, 20703, 14505, 0 };
            const std::uint32_t dim6849JoeKuoD6Init[]   =   { 1, 1, 3, 11, 27, 59, 17, 103, 337, 117, 1241, 951, 3701, 10407, 16741, 46531, 56485, 0 };
            const std::uint32_t dim6850JoeKuoD6Init[]   =   { 1, 1, 3, 15, 11, 51, 111, 189, 137, 939, 97, 1563, 851, 13949, 1375, 41463, 61445, 0 };
            const std::uint32_t dim6851JoeKuoD6Init[]   =   { 1, 1, 7, 9, 19, 39, 117, 173, 165, 547, 483, 361, 6819, 15093, 13631, 29785, 29593, 0 };
            const std::uint32_t dim6852JoeKuoD6Init[]   =   { 1, 3, 3, 5, 15, 39, 41, 249, 455, 79, 233, 3133, 405, 9487, 23161, 32751, 117743, 0 };
            const std::uint32_t dim6853JoeKuoD6Init[]   =   { 1, 1, 5, 15, 7, 63, 7, 57, 127, 349, 1913, 1145, 3371, 3733, 30971, 35717, 60935, 0 };
            const std::uint32_t dim6854JoeKuoD6Init[]   =   { 1, 1, 7, 11, 7, 57, 49, 63, 51, 233, 855, 2125, 6961, 15011, 28503, 40549, 47175, 0 };
            const std::uint32_t dim6855JoeKuoD6Init[]   =   { 1, 3, 7, 1, 25, 49, 35, 39, 237, 545, 1637, 1401, 3279, 10499, 14463, 34973, 29485, 0 };
            const std::uint32_t dim6856JoeKuoD6Init[]   =   { 1, 3, 3, 13, 7, 13, 79, 141, 55, 277, 843, 3087, 2339, 6855, 10635, 13021, 11273, 0 };
            const std::uint32_t dim6857JoeKuoD6Init[]   =   { 1, 3, 1, 1, 11, 39, 51, 255, 119, 691, 559, 3287, 5485, 791, 19283, 51027, 8061, 0 };
            const std::uint32_t dim6858JoeKuoD6Init[]   =   { 1, 3, 7, 7, 3, 59, 119, 241, 185, 81, 1843, 2313, 7471, 15689, 2271, 59781, 107439, 0 };
            const std::uint32_t dim6859JoeKuoD6Init[]   =   { 1, 3, 3, 3, 17, 63, 93, 217, 329, 39, 583, 3031, 4315, 4623, 12557, 42063, 11877, 0 };
            const std::uint32_t dim6860JoeKuoD6Init[]   =   { 1, 1, 1, 1, 15, 57, 37, 233, 387, 639, 37, 425, 637, 1577, 16449, 33665, 80417, 0 };
            const std::uint32_t dim6861JoeKuoD6Init[]   =   { 1, 1, 1, 15, 25, 1, 67, 159, 423, 961, 959, 417, 5657, 8417, 8127, 29251, 105893, 0 };
            const std::uint32_t dim6862JoeKuoD6Init[]   =   { 1, 3, 5, 15, 31, 9, 87, 217, 259, 771, 1663, 2899, 1531, 7849, 1961, 61487, 55399, 0 };
            const std::uint32_t dim6863JoeKuoD6Init[]   =   { 1, 1, 3, 9, 21, 13, 39, 107, 89, 811, 449, 2569, 4617, 8977, 1649, 37721, 48943, 0 };
            const std::uint32_t dim6864JoeKuoD6Init[]   =   { 1, 3, 7, 15, 15, 59, 63, 195, 287, 677, 269, 1715, 3545, 3269, 5231, 46433, 25921, 0 };
            const std::uint32_t dim6865JoeKuoD6Init[]   =   { 1, 1, 5, 7, 19, 27, 57, 221, 243, 47, 1791, 2309, 2751, 4403, 7083, 34223, 64905, 0 };
            const std::uint32_t dim6866JoeKuoD6Init[]   =   { 1, 1, 1, 15, 1, 63, 119, 155, 383, 649, 429, 3857, 7309, 9823, 9539, 8933, 128573, 0 };
            const std::uint32_t dim6867JoeKuoD6Init[]   =   { 1, 3, 7, 11, 17, 19, 99, 19, 321, 415, 1501, 2123, 6119, 9705, 11397, 39521, 34327, 0 };
            const std::uint32_t dim6868JoeKuoD6Init[]   =   { 1, 1, 5, 15, 29, 37, 9, 95, 417, 19, 1637, 2949, 4961, 10743, 9619, 16045, 48083, 0 };
            const std::uint32_t dim6869JoeKuoD6Init[]   =   { 1, 1, 1, 11, 21, 17, 57, 23, 247, 201, 1781, 779, 2207, 2511, 4829, 13847, 77593, 0 };
            const std::uint32_t dim6870JoeKuoD6Init[]   =   { 1, 3, 1, 13, 7, 1, 95, 87, 223, 73, 1129, 383, 1355, 4965, 29645, 63465, 76281, 0 };
            const std::uint32_t dim6871JoeKuoD6Init[]   =   { 1, 3, 3, 13, 3, 47, 33, 123, 155, 621, 1019, 1817, 4083, 4723, 24701, 47503, 18007, 0 };
            const std::uint32_t dim6872JoeKuoD6Init[]   =   { 1, 1, 7, 15, 13, 41, 73, 93, 379, 923, 1183, 2475, 5901, 10599, 10053, 9941, 112107, 0 };
            const std::uint32_t dim6873JoeKuoD6Init[]   =   { 1, 1, 3, 3, 13, 35, 59, 231, 45, 1011, 1101, 2467, 2703, 10305, 12575, 7587, 25737, 0 };
            const std::uint32_t dim6874JoeKuoD6Init[]   =   { 1, 3, 7, 1, 21, 31, 9, 55, 373, 779, 397, 1551, 5139, 16339, 1769, 10413, 74059, 0 };
            const std::uint32_t dim6875JoeKuoD6Init[]   =   { 1, 1, 7, 15, 7, 3, 67, 179, 411, 217, 1219, 13, 1577, 13463, 12263, 41465, 83001, 0 };
            const std::uint32_t dim6876JoeKuoD6Init[]   =   { 1, 3, 7, 1, 21, 53, 7, 187, 395, 777, 391, 737, 47, 12681, 16749, 26507, 49415, 0 };
            const std::uint32_t dim6877JoeKuoD6Init[]   =   { 1, 1, 5, 7, 5, 57, 93, 53, 419, 731, 825, 487, 45, 9199, 20947, 56067, 45343, 0 };
            const std::uint32_t dim6878JoeKuoD6Init[]   =   { 1, 3, 3, 9, 31, 41, 35, 133, 63, 293, 1503, 51, 3111, 15711, 15051, 1965, 64951, 0 };
            const std::uint32_t dim6879JoeKuoD6Init[]   =   { 1, 1, 5, 9, 9, 47, 53, 229, 405, 621, 1795, 1923, 6609, 6983, 1695, 18021, 71893, 0 };
            const std::uint32_t dim6880JoeKuoD6Init[]   =   { 1, 1, 5, 9, 23, 13, 107, 13, 149, 759, 1113, 1329, 1747, 14159, 16705, 61841, 82955, 0 };
            const std::uint32_t dim6881JoeKuoD6Init[]   =   { 1, 3, 3, 9, 25, 49, 31, 145, 481, 609, 1847, 1485, 6345, 7859, 21231, 37303, 69975, 0 };
            const std::uint32_t dim6882JoeKuoD6Init[]   =   { 1, 3, 1, 15, 13, 49, 59, 221, 27, 517, 431, 3961, 6401, 8483, 10161, 37453, 128237, 0 };
            const std::uint32_t dim6883JoeKuoD6Init[]   =   { 1, 1, 3, 1, 3, 55, 37, 111, 263, 735, 655, 2831, 2219, 9449, 8413, 49585, 91355, 0 };
            const std::uint32_t dim6884JoeKuoD6Init[]   =   { 1, 3, 7, 1, 31, 33, 7, 55, 261, 977, 1215, 1967, 7297, 14815, 27009, 35001, 89671, 0 };
            const std::uint32_t dim6885JoeKuoD6Init[]   =   { 1, 1, 7, 11, 13, 21, 33, 151, 195, 373, 181, 1631, 355, 7857, 12555, 7531, 50417, 0 };
            const std::uint32_t dim6886JoeKuoD6Init[]   =   { 1, 3, 1, 15, 19, 25, 79, 195, 237, 385, 1531, 2509, 4371, 16103, 3575, 62265, 124251, 0 };
            const std::uint32_t dim6887JoeKuoD6Init[]   =   { 1, 3, 1, 11, 5, 61, 21, 159, 51, 37, 845, 3075, 8039, 14269, 10505, 36369, 73793, 0 };
            const std::uint32_t dim6888JoeKuoD6Init[]   =   { 1, 3, 5, 9, 11, 43, 67, 57, 271, 451, 989, 3705, 2481, 10717, 10861, 63785, 10183, 0 };
            const std::uint32_t dim6889JoeKuoD6Init[]   =   { 1, 3, 3, 5, 13, 29, 119, 171, 439, 459, 479, 3173, 3781, 11131, 6827, 53925, 119939, 0 };
            const std::uint32_t dim6890JoeKuoD6Init[]   =   { 1, 3, 7, 3, 27, 21, 1, 167, 79, 305, 1283, 1903, 5483, 5727, 17911, 16075, 97629, 0 };
            const std::uint32_t dim6891JoeKuoD6Init[]   =   { 1, 3, 1, 3, 23, 21, 29, 185, 227, 295, 915, 2033, 6269, 2089, 20785, 15207, 115675, 0 };
            const std::uint32_t dim6892JoeKuoD6Init[]   =   { 1, 3, 7, 15, 11, 15, 65, 103, 249, 27, 1805, 2079, 4797, 2535, 16865, 61449, 90923, 0 };
            const std::uint32_t dim6893JoeKuoD6Init[]   =   { 1, 3, 7, 9, 27, 41, 77, 181, 457, 677, 633, 1601, 8085, 2431, 7957, 55913, 38677, 0 };
            const std::uint32_t dim6894JoeKuoD6Init[]   =   { 1, 1, 5, 7, 11, 37, 3, 221, 79, 895, 1023, 653, 3925, 12755, 19729, 18221, 91123, 0 };
            const std::uint32_t dim6895JoeKuoD6Init[]   =   { 1, 3, 1, 5, 23, 61, 119, 191, 425, 41, 853, 3497, 6915, 1927, 5513, 55303, 4895, 0 };
            const std::uint32_t dim6896JoeKuoD6Init[]   =   { 1, 3, 5, 3, 7, 35, 47, 243, 167, 821, 267, 2149, 5797, 6329, 32495, 51037, 18313, 0 };
            const std::uint32_t dim6897JoeKuoD6Init[]   =   { 1, 1, 7, 9, 23, 29, 79, 205, 115, 839, 1217, 479, 1601, 9681, 1, 35293, 28731, 0 };
            const std::uint32_t dim6898JoeKuoD6Init[]   =   { 1, 3, 3, 5, 31, 17, 31, 161, 35, 953, 377, 451, 7985, 11371, 15115, 60131, 27033, 0 };
            const std::uint32_t dim6899JoeKuoD6Init[]   =   { 1, 1, 3, 9, 15, 19, 43, 215, 327, 429, 145, 1837, 725, 14775, 10465, 7367, 21271, 0 };
            const std::uint32_t dim6900JoeKuoD6Init[]   =   { 1, 3, 7, 13, 31, 17, 85, 49, 487, 795, 1679, 599, 3783, 3195, 2683, 53475, 38603, 0 };
            const std::uint32_t dim6901JoeKuoD6Init[]   =   { 1, 1, 1, 7, 19, 11, 71, 143, 443, 199, 1117, 3445, 6429, 12037, 13751, 43609, 101563, 0 };
            const std::uint32_t dim6902JoeKuoD6Init[]   =   { 1, 3, 5, 7, 29, 63, 65, 87, 305, 721, 851, 2235, 4987, 3051, 23015, 1281, 15755, 0 };
            const std::uint32_t dim6903JoeKuoD6Init[]   =   { 1, 1, 3, 9, 17, 3, 57, 47, 223, 305, 1409, 235, 4379, 5779, 27695, 22535, 9387, 0 };
            const std::uint32_t dim6904JoeKuoD6Init[]   =   { 1, 1, 3, 11, 25, 33, 75, 141, 155, 699, 85, 1729, 2551, 7101, 7739, 18025, 100819, 0 };
            const std::uint32_t dim6905JoeKuoD6Init[]   =   { 1, 3, 3, 13, 5, 45, 63, 83, 141, 383, 1931, 3343, 7397, 4823, 28893, 41279, 67805, 0 };
            const std::uint32_t dim6906JoeKuoD6Init[]   =   { 1, 3, 5, 7, 19, 29, 97, 67, 177, 583, 1783, 4007, 5087, 805, 30999, 23197, 117553, 0 };
            const std::uint32_t dim6907JoeKuoD6Init[]   =   { 1, 3, 5, 1, 25, 41, 33, 109, 511, 449, 653, 995, 5881, 2163, 13689, 54385, 97419, 0 };
            const std::uint32_t dim6908JoeKuoD6Init[]   =   { 1, 3, 3, 13, 25, 17, 49, 77, 497, 659, 783, 3513, 3735, 3541, 573, 50237, 99247, 0 };
            const std::uint32_t dim6909JoeKuoD6Init[]   =   { 1, 3, 1, 7, 17, 13, 37, 169, 19, 965, 289, 455, 6855, 11233, 7553, 7007, 57389, 0 };
            const std::uint32_t dim6910JoeKuoD6Init[]   =   { 1, 1, 7, 11, 5, 15, 11, 177, 75, 243, 453, 3861, 3091, 4625, 12489, 11537, 74199, 0 };
            const std::uint32_t dim6911JoeKuoD6Init[]   =   { 1, 1, 5, 13, 17, 21, 23, 57, 343, 985, 1755, 3947, 3899, 11847, 19321, 62295, 51265, 0 };
            const std::uint32_t dim6912JoeKuoD6Init[]   =   { 1, 1, 3, 9, 19, 37, 31, 243, 433, 725, 535, 3733, 33, 7885, 1425, 41919, 66507, 0 };
            const std::uint32_t dim6913JoeKuoD6Init[]   =   { 1, 3, 5, 11, 15, 11, 25, 255, 93, 33, 71, 2389, 1855, 317, 12773, 13311, 81927, 0 };
            const std::uint32_t dim6914JoeKuoD6Init[]   =   { 1, 3, 1, 3, 7, 55, 21, 175, 357, 235, 1679, 931, 2051, 14213, 20539, 38049, 122513, 0 };
            const std::uint32_t dim6915JoeKuoD6Init[]   =   { 1, 1, 5, 15, 5, 51, 127, 79, 297, 135, 1423, 2783, 7229, 14451, 27619, 7299, 49189, 0 };
            const std::uint32_t dim6916JoeKuoD6Init[]   =   { 1, 1, 1, 3, 5, 13, 9, 209, 455, 483, 1745, 323, 789, 7645, 26373, 61659, 23671, 0 };
            const std::uint32_t dim6917JoeKuoD6Init[]   =   { 1, 1, 1, 9, 23, 63, 99, 91, 377, 275, 275, 3005, 1563, 5945, 23825, 33211, 52753, 0 };
            const std::uint32_t dim6918JoeKuoD6Init[]   =   { 1, 1, 1, 1, 31, 55, 31, 109, 481, 581, 771, 197, 6155, 3465, 8451, 25925, 41159, 0 };
            const std::uint32_t dim6919JoeKuoD6Init[]   =   { 1, 3, 7, 13, 5, 33, 113, 161, 265, 493, 1723, 513, 5111, 10177, 21755, 5321, 58831, 0 };
            const std::uint32_t dim6920JoeKuoD6Init[]   =   { 1, 1, 7, 1, 21, 33, 117, 183, 89, 689, 1253, 2215, 6565, 3079, 16343, 22427, 96447, 0 };
            const std::uint32_t dim6921JoeKuoD6Init[]   =   { 1, 1, 1, 5, 15, 61, 5, 139, 111, 463, 573, 1907, 4615, 14975, 5715, 51017, 69827, 0 };
            const std::uint32_t dim6922JoeKuoD6Init[]   =   { 1, 1, 1, 13, 3, 3, 117, 249, 25, 361, 1177, 2901, 1601, 11381, 18981, 44811, 47117, 0 };
            const std::uint32_t dim6923JoeKuoD6Init[]   =   { 1, 1, 5, 3, 29, 5, 49, 221, 247, 57, 553, 1889, 479, 15581, 7035, 7293, 53065, 0 };
            const std::uint32_t dim6924JoeKuoD6Init[]   =   { 1, 3, 3, 3, 15, 49, 91, 187, 213, 981, 1417, 211, 3719, 13693, 17671, 16691, 57147, 0 };
            const std::uint32_t dim6925JoeKuoD6Init[]   =   { 1, 1, 7, 9, 7, 17, 109, 185, 459, 769, 1783, 899, 885, 2291, 30023, 26315, 7337, 0 };
            const std::uint32_t dim6926JoeKuoD6Init[]   =   { 1, 1, 5, 11, 11, 31, 73, 191, 95, 25, 1953, 1387, 1077, 7547, 9661, 57739, 76799, 0 };
            const std::uint32_t dim6927JoeKuoD6Init[]   =   { 1, 1, 7, 13, 23, 41, 69, 177, 407, 699, 1055, 3653, 1239, 8113, 12823, 1803, 117815, 0 };
            const std::uint32_t dim6928JoeKuoD6Init[]   =   { 1, 1, 1, 15, 1, 55, 71, 133, 401, 593, 605, 2855, 4569, 3533, 14141, 65457, 125655, 0 };
            const std::uint32_t dim6929JoeKuoD6Init[]   =   { 1, 1, 7, 9, 31, 55, 53, 11, 65, 17, 561, 925, 1561, 8929, 19859, 57111, 12777, 0 };
            const std::uint32_t dim6930JoeKuoD6Init[]   =   { 1, 3, 3, 11, 7, 59, 125, 205, 473, 655, 1429, 337, 6829, 7551, 27873, 11667, 39231, 0 };
            const std::uint32_t dim6931JoeKuoD6Init[]   =   { 1, 3, 3, 9, 13, 23, 25, 161, 443, 545, 1967, 1895, 6929, 5975, 17801, 41769, 30429, 0 };
            const std::uint32_t dim6932JoeKuoD6Init[]   =   { 1, 3, 7, 13, 15, 1, 99, 43, 45, 451, 21, 639, 7121, 4781, 2813, 419, 17761, 0 };
            const std::uint32_t dim6933JoeKuoD6Init[]   =   { 1, 1, 5, 13, 11, 9, 53, 83, 443, 441, 1601, 3177, 1913, 12211, 25835, 1733, 4793, 0 };
            const std::uint32_t dim6934JoeKuoD6Init[]   =   { 1, 3, 3, 1, 13, 15, 11, 187, 471, 699, 1751, 3279, 2305, 15259, 31541, 21357, 73763, 0 };
            const std::uint32_t dim6935JoeKuoD6Init[]   =   { 1, 3, 5, 9, 23, 11, 125, 57, 261, 479, 879, 719, 3221, 2943, 10593, 11521, 83979, 0 };
            const std::uint32_t dim6936JoeKuoD6Init[]   =   { 1, 3, 7, 13, 3, 39, 119, 135, 85, 417, 1675, 971, 7577, 12709, 20407, 26105, 97021, 0 };
            const std::uint32_t dim6937JoeKuoD6Init[]   =   { 1, 1, 5, 11, 15, 63, 83, 141, 281, 663, 1745, 2775, 5605, 9127, 553, 7177, 115969, 0 };
            const std::uint32_t dim6938JoeKuoD6Init[]   =   { 1, 1, 7, 1, 19, 47, 7, 165, 87, 95, 361, 1879, 6351, 2861, 9103, 37489, 24525, 0 };
            const std::uint32_t dim6939JoeKuoD6Init[]   =   { 1, 3, 3, 11, 9, 21, 51, 149, 375, 967, 1583, 1427, 1223, 11611, 7481, 36619, 128429, 0 };
            const std::uint32_t dim6940JoeKuoD6Init[]   =   { 1, 1, 5, 1, 3, 31, 7, 217, 453, 565, 1517, 2847, 6937, 1197, 24339, 44311, 66843, 0 };
            const std::uint32_t dim6941JoeKuoD6Init[]   =   { 1, 1, 5, 3, 3, 17, 127, 59, 3, 905, 531, 1179, 3559, 5175, 24627, 60941, 129457, 0 };
            const std::uint32_t dim6942JoeKuoD6Init[]   =   { 1, 1, 1, 7, 15, 15, 1, 31, 373, 643, 279, 3831, 4881, 9763, 17641, 43219, 83109, 0 };
            const std::uint32_t dim6943JoeKuoD6Init[]   =   { 1, 3, 3, 9, 5, 21, 41, 71, 371, 201, 573, 1481, 3631, 10783, 6679, 1089, 117347, 0 };
            const std::uint32_t dim6944JoeKuoD6Init[]   =   { 1, 1, 7, 7, 5, 25, 73, 63, 173, 197, 147, 981, 1491, 1597, 11733, 14285, 74021, 0 };
            const std::uint32_t dim6945JoeKuoD6Init[]   =   { 1, 1, 5, 11, 17, 15, 3, 175, 391, 503, 1745, 319, 791, 5607, 18173, 37319, 92025, 0 };
            const std::uint32_t dim6946JoeKuoD6Init[]   =   { 1, 3, 1, 1, 9, 37, 43, 81, 439, 951, 805, 251, 4625, 15617, 13715, 62263, 3827, 0 };
            const std::uint32_t dim6947JoeKuoD6Init[]   =   { 1, 3, 1, 1, 25, 21, 67, 191, 499, 205, 1355, 105, 1637, 563, 22291, 9045, 6545, 0 };
            const std::uint32_t dim6948JoeKuoD6Init[]   =   { 1, 1, 5, 5, 9, 3, 75, 75, 287, 303, 1767, 1789, 3437, 4637, 9605, 2537, 64935, 0 };
            const std::uint32_t dim6949JoeKuoD6Init[]   =   { 1, 1, 3, 3, 1, 51, 27, 155, 375, 149, 885, 187, 1551, 13109, 27011, 57301, 41047, 0 };
            const std::uint32_t dim6950JoeKuoD6Init[]   =   { 1, 1, 7, 5, 21, 23, 1, 81, 163, 231, 2039, 1519, 1279, 15379, 25549, 6711, 81499, 0 };
            const std::uint32_t dim6951JoeKuoD6Init[]   =   { 1, 1, 3, 5, 3, 37, 71, 243, 165, 365, 379, 351, 4649, 4287, 13395, 30329, 78383, 0 };
            const std::uint32_t dim6952JoeKuoD6Init[]   =   { 1, 3, 1, 1, 25, 63, 27, 215, 223, 699, 2029, 3737, 5947, 7287, 20813, 4931, 19345, 0 };
            const std::uint32_t dim6953JoeKuoD6Init[]   =   { 1, 1, 3, 15, 21, 7, 25, 187, 219, 53, 1749, 1797, 3533, 14307, 53, 11095, 75469, 0 };
            const std::uint32_t dim6954JoeKuoD6Init[]   =   { 1, 1, 3, 13, 27, 31, 91, 121, 481, 291, 915, 535, 4291, 5271, 12181, 55921, 125917, 0 };
            const std::uint32_t dim6955JoeKuoD6Init[]   =   { 1, 3, 1, 1, 3, 29, 21, 251, 361, 747, 997, 2989, 1809, 7235, 17855, 31027, 100689, 0 };
            const std::uint32_t dim6956JoeKuoD6Init[]   =   { 1, 3, 7, 1, 21, 13, 49, 93, 183, 673, 881, 1931, 7009, 2565, 26021, 53815, 19807, 0 };
            const std::uint32_t dim6957JoeKuoD6Init[]   =   { 1, 1, 7, 13, 9, 23, 47, 237, 487, 843, 1357, 919, 1753, 903, 2911, 31527, 73027, 0 };
            const std::uint32_t dim6958JoeKuoD6Init[]   =   { 1, 1, 1, 1, 25, 33, 97, 241, 421, 375, 73, 2541, 6231, 14659, 15335, 5915, 110791, 0 };
            const std::uint32_t dim6959JoeKuoD6Init[]   =   { 1, 3, 3, 7, 21, 17, 97, 125, 7, 271, 167, 475, 4887, 1847, 30173, 25913, 36659, 0 };
            const std::uint32_t dim6960JoeKuoD6Init[]   =   { 1, 1, 3, 15, 15, 37, 67, 5, 463, 423, 823, 941, 1551, 14175, 15377, 6017, 118297, 0 };
            const std::uint32_t dim6961JoeKuoD6Init[]   =   { 1, 1, 1, 7, 31, 51, 71, 127, 73, 517, 881, 3205, 6219, 11213, 14783, 64275, 70033, 0 };
            const std::uint32_t dim6962JoeKuoD6Init[]   =   { 1, 3, 1, 5, 17, 17, 57, 107, 359, 999, 1415, 757, 4743, 7775, 14111, 20075, 73269, 0 };
            const std::uint32_t dim6963JoeKuoD6Init[]   =   { 1, 3, 5, 3, 21, 57, 87, 43, 307, 777, 717, 3329, 4159, 12545, 31355, 31329, 41377, 0 };
            const std::uint32_t dim6964JoeKuoD6Init[]   =   { 1, 3, 7, 15, 25, 43, 19, 147, 487, 517, 977, 3625, 2311, 14173, 15167, 56563, 110417, 0 };
            const std::uint32_t dim6965JoeKuoD6Init[]   =   { 1, 3, 3, 11, 23, 1, 67, 157, 461, 169, 231, 1977, 5657, 865, 711, 24213, 76895, 0 };
            const std::uint32_t dim6966JoeKuoD6Init[]   =   { 1, 1, 7, 13, 5, 37, 51, 165, 331, 97, 431, 3819, 1379, 12083, 27521, 19689, 100119, 0 };
            const std::uint32_t dim6967JoeKuoD6Init[]   =   { 1, 1, 7, 15, 29, 21, 59, 193, 397, 467, 951, 3037, 2955, 13235, 20981, 63865, 30069, 0 };
            const std::uint32_t dim6968JoeKuoD6Init[]   =   { 1, 3, 3, 5, 7, 49, 41, 143, 319, 71, 353, 2159, 3043, 15317, 24095, 12017, 64393, 0 };
            const std::uint32_t dim6969JoeKuoD6Init[]   =   { 1, 1, 5, 13, 25, 45, 57, 153, 311, 805, 953, 1763, 5655, 3961, 12085, 58761, 76533, 0 };
            const std::uint32_t dim6970JoeKuoD6Init[]   =   { 1, 1, 3, 15, 29, 19, 71, 107, 203, 221, 1173, 1597, 1179, 9649, 21659, 10463, 8195, 0 };
            const std::uint32_t dim6971JoeKuoD6Init[]   =   { 1, 1, 3, 9, 31, 29, 53, 151, 247, 577, 543, 459, 8141, 5613, 12029, 24199, 118603, 0 };
            const std::uint32_t dim6972JoeKuoD6Init[]   =   { 1, 3, 1, 5, 1, 55, 103, 23, 405, 5, 181, 3805, 1103, 13389, 6725, 48733, 99639, 0 };
            const std::uint32_t dim6973JoeKuoD6Init[]   =   { 1, 1, 5, 9, 1, 47, 115, 231, 151, 885, 427, 2849, 361, 12969, 705, 41711, 53587, 0 };
            const std::uint32_t dim6974JoeKuoD6Init[]   =   { 1, 1, 3, 11, 9, 3, 11, 231, 77, 775, 657, 2721, 3431, 11919, 10425, 29405, 91561, 0 };
            const std::uint32_t dim6975JoeKuoD6Init[]   =   { 1, 1, 1, 5, 5, 7, 79, 41, 181, 333, 963, 3117, 7703, 2259, 16671, 51139, 27997, 0 };
            const std::uint32_t dim6976JoeKuoD6Init[]   =   { 1, 3, 7, 7, 13, 55, 59, 157, 377, 711, 1475, 1509, 1375, 6825, 13729, 28613, 109199, 0 };
            const std::uint32_t dim6977JoeKuoD6Init[]   =   { 1, 3, 3, 3, 13, 11, 51, 1, 67, 609, 467, 2161, 7693, 9019, 1847, 27969, 74863, 0 };
            const std::uint32_t dim6978JoeKuoD6Init[]   =   { 1, 1, 3, 3, 11, 33, 87, 217, 239, 505, 1451, 2801, 1417, 695, 29883, 15877, 99969, 0 };
            const std::uint32_t dim6979JoeKuoD6Init[]   =   { 1, 3, 3, 5, 3, 61, 9, 171, 57, 547, 2003, 2335, 2259, 3205, 5639, 21721, 25893, 0 };
            const std::uint32_t dim6980JoeKuoD6Init[]   =   { 1, 3, 1, 3, 19, 15, 83, 69, 47, 897, 627, 2839, 7123, 8567, 14707, 13159, 125139, 0 };
            const std::uint32_t dim6981JoeKuoD6Init[]   =   { 1, 3, 7, 11, 1, 59, 53, 33, 135, 1009, 1829, 3011, 1245, 421, 28909, 45517, 55071, 0 };
            const std::uint32_t dim6982JoeKuoD6Init[]   =   { 1, 1, 5, 9, 3, 27, 11, 243, 235, 683, 1329, 3145, 2141, 14027, 3707, 5933, 51965, 0 };
            const std::uint32_t dim6983JoeKuoD6Init[]   =   { 1, 1, 5, 7, 13, 63, 79, 105, 27, 195, 1657, 3107, 1245, 1681, 29619, 10589, 78197, 0 };
            const std::uint32_t dim6984JoeKuoD6Init[]   =   { 1, 3, 3, 7, 21, 1, 5, 79, 73, 125, 1587, 3053, 5977, 10745, 28343, 39023, 56201, 0 };
            const std::uint32_t dim6985JoeKuoD6Init[]   =   { 1, 1, 3, 15, 23, 21, 39, 41, 173, 913, 1267, 1323, 2967, 1979, 16763, 53753, 21905, 0 };
            const std::uint32_t dim6986JoeKuoD6Init[]   =   { 1, 1, 5, 7, 11, 11, 117, 151, 409, 345, 1461, 1703, 687, 557, 31651, 35507, 54909, 0 };
            const std::uint32_t dim6987JoeKuoD6Init[]   =   { 1, 1, 1, 15, 15, 49, 55, 223, 289, 765, 1737, 1117, 3717, 15465, 31949, 55061, 97091, 0 };
            const std::uint32_t dim6988JoeKuoD6Init[]   =   { 1, 1, 5, 9, 21, 29, 99, 13, 119, 35, 1461, 61, 5155, 6785, 15957, 11295, 52203, 0 };
            const std::uint32_t dim6989JoeKuoD6Init[]   =   { 1, 3, 5, 7, 23, 39, 73, 161, 465, 715, 153, 3529, 2243, 13773, 16573, 26233, 130263, 0 };
            const std::uint32_t dim6990JoeKuoD6Init[]   =   { 1, 3, 7, 9, 11, 51, 5, 149, 501, 119, 2047, 3417, 3955, 15055, 31633, 473, 127305, 0 };
            const std::uint32_t dim6991JoeKuoD6Init[]   =   { 1, 1, 1, 9, 31, 57, 91, 119, 215, 11, 1013, 3969, 1285, 11521, 8039, 36737, 86365, 0 };
            const std::uint32_t dim6992JoeKuoD6Init[]   =   { 1, 1, 5, 3, 7, 17, 9, 27, 59, 883, 541, 3027, 6219, 1091, 2453, 38247, 21323, 0 };
            const std::uint32_t dim6993JoeKuoD6Init[]   =   { 1, 1, 1, 1, 25, 39, 55, 249, 61, 313, 467, 1763, 4067, 8367, 32431, 44463, 66439, 0 };
            const std::uint32_t dim6994JoeKuoD6Init[]   =   { 1, 3, 3, 1, 13, 3, 37, 209, 21, 653, 1971, 3649, 6165, 3789, 12793, 56327, 60351, 0 };
            const std::uint32_t dim6995JoeKuoD6Init[]   =   { 1, 1, 7, 9, 31, 33, 21, 51, 313, 631, 515, 1761, 4149, 2601, 12481, 25975, 94061, 0 };
            const std::uint32_t dim6996JoeKuoD6Init[]   =   { 1, 1, 7, 15, 3, 7, 55, 129, 297, 735, 779, 633, 3265, 11713, 3893, 61197, 113991, 0 };
            const std::uint32_t dim6997JoeKuoD6Init[]   =   { 1, 3, 5, 13, 1, 15, 27, 253, 435, 595, 1163, 2753, 7399, 15225, 26215, 59753, 74933, 0 };
            const std::uint32_t dim6998JoeKuoD6Init[]   =   { 1, 1, 7, 7, 15, 23, 111, 43, 467, 957, 1687, 2893, 2315, 2025, 1475, 9061, 101611, 0 };
            const std::uint32_t dim6999JoeKuoD6Init[]   =   { 1, 1, 3, 3, 29, 41, 53, 169, 125, 415, 361, 869, 3399, 8821, 18193, 38575, 73979, 0 };
            const std::uint32_t dim7000JoeKuoD6Init[]   =   { 1, 1, 1, 15, 3, 5, 27, 5, 293, 765, 1809, 1961, 955, 12441, 10915, 2363, 49617, 0 };
            const std::uint32_t dim7001JoeKuoD6Init[]   =   { 1, 1, 5, 15, 19, 11, 3, 91, 59, 323, 545, 1177, 7967, 2729, 14085, 3283, 79859, 0 };
            const std::uint32_t dim7002JoeKuoD6Init[]   =   { 1, 1, 7, 13, 11, 17, 29, 163, 295, 951, 311, 3471, 1339, 10719, 701, 32377, 41685, 0 };
            const std::uint32_t dim7003JoeKuoD6Init[]   =   { 1, 3, 5, 7, 21, 19, 81, 247, 495, 767, 251, 3455, 6383, 7221, 19943, 64865, 33193, 0 };
            const std::uint32_t dim7004JoeKuoD6Init[]   =   { 1, 1, 7, 15, 23, 41, 63, 195, 311, 619, 211, 743, 889, 7627, 12527, 15865, 40103, 0 };
            const std::uint32_t dim7005JoeKuoD6Init[]   =   { 1, 1, 3, 1, 23, 23, 57, 221, 153, 27, 939, 3949, 411, 6357, 31985, 939, 91001, 0 };
            const std::uint32_t dim7006JoeKuoD6Init[]   =   { 1, 3, 5, 15, 7, 5, 35, 135, 245, 921, 307, 823, 775, 4891, 24575, 53503, 48147, 0 };
            const std::uint32_t dim7007JoeKuoD6Init[]   =   { 1, 1, 5, 7, 9, 31, 23, 139, 477, 495, 287, 807, 1855, 8321, 13963, 52197, 78509, 0 };
            const std::uint32_t dim7008JoeKuoD6Init[]   =   { 1, 3, 3, 3, 29, 59, 33, 83, 211, 65, 623, 1269, 1745, 16383, 10759, 57199, 14035, 0 };
            const std::uint32_t dim7009JoeKuoD6Init[]   =   { 1, 3, 3, 15, 25, 55, 69, 171, 411, 937, 731, 2275, 2597, 4133, 5089, 50507, 39989, 0 };
            const std::uint32_t dim7010JoeKuoD6Init[]   =   { 1, 3, 1, 9, 5, 47, 51, 21, 171, 913, 233, 43, 2673, 471, 27077, 57039, 32579, 0 };
            const std::uint32_t dim7011JoeKuoD6Init[]   =   { 1, 3, 5, 3, 29, 35, 5, 105, 233, 379, 77, 1775, 2409, 4597, 19879, 12691, 49739, 0 };
            const std::uint32_t dim7012JoeKuoD6Init[]   =   { 1, 3, 7, 13, 17, 29, 117, 177, 163, 927, 45, 3227, 7263, 5551, 9219, 32101, 122473, 0 };
            const std::uint32_t dim7013JoeKuoD6Init[]   =   { 1, 1, 7, 5, 31, 39, 75, 147, 311, 991, 1431, 3821, 6891, 9637, 17887, 661, 23067, 0 };
            const std::uint32_t dim7014JoeKuoD6Init[]   =   { 1, 3, 5, 13, 31, 53, 69, 79, 153, 329, 207, 479, 2395, 6505, 29553, 52023, 31531, 0 };
            const std::uint32_t dim7015JoeKuoD6Init[]   =   { 1, 3, 1, 7, 15, 7, 87, 233, 25, 275, 981, 1207, 3083, 16349, 30185, 60611, 120607, 0 };
            const std::uint32_t dim7016JoeKuoD6Init[]   =   { 1, 1, 5, 3, 21, 7, 47, 173, 291, 965, 65, 545, 7465, 4471, 2249, 34281, 107217, 0 };
            const std::uint32_t dim7017JoeKuoD6Init[]   =   { 1, 1, 3, 11, 19, 53, 17, 243, 193, 297, 1937, 1513, 4979, 14867, 15497, 10049, 9135, 0 };
            const std::uint32_t dim7018JoeKuoD6Init[]   =   { 1, 3, 1, 3, 25, 39, 29, 63, 231, 145, 247, 1745, 3439, 8635, 26687, 18595, 67123, 0 };
            const std::uint32_t dim7019JoeKuoD6Init[]   =   { 1, 1, 7, 9, 29, 33, 89, 175, 429, 675, 891, 1739, 3567, 5453, 30427, 33671, 83395, 0 };
            const std::uint32_t dim7020JoeKuoD6Init[]   =   { 1, 3, 1, 5, 31, 25, 69, 237, 235, 307, 1217, 3805, 153, 13387, 6209, 14179, 128725, 0 };
            const std::uint32_t dim7021JoeKuoD6Init[]   =   { 1, 1, 3, 3, 19, 45, 117, 135, 67, 601, 369, 3369, 5505, 2049, 24099, 22515, 96575, 0 };
            const std::uint32_t dim7022JoeKuoD6Init[]   =   { 1, 1, 1, 3, 3, 45, 29, 255, 327, 77, 1103, 4067, 2875, 6487, 5903, 26625, 19631, 0 };
            const std::uint32_t dim7023JoeKuoD6Init[]   =   { 1, 3, 5, 1, 31, 63, 115, 7, 255, 855, 913, 1779, 7001, 14387, 26765, 51987, 3191, 0 };
            const std::uint32_t dim7024JoeKuoD6Init[]   =   { 1, 1, 3, 11, 15, 43, 71, 247, 303, 231, 445, 3963, 3699, 11851, 18941, 43465, 63431, 0 };
            const std::uint32_t dim7025JoeKuoD6Init[]   =   { 1, 1, 3, 5, 31, 33, 93, 127, 267, 399, 653, 1997, 5005, 14535, 4813, 64065, 2159, 0 };
            const std::uint32_t dim7026JoeKuoD6Init[]   =   { 1, 3, 7, 13, 31, 39, 61, 155, 141, 515, 1217, 161, 4309, 3697, 22445, 43599, 43329, 0 };
            const std::uint32_t dim7027JoeKuoD6Init[]   =   { 1, 3, 3, 3, 7, 51, 103, 147, 511, 971, 195, 3731, 6629, 12125, 12053, 34951, 60059, 0 };
            const std::uint32_t dim7028JoeKuoD6Init[]   =   { 1, 1, 5, 11, 21, 49, 99, 31, 55, 309, 1805, 2253, 7095, 15265, 28445, 54813, 48615, 0 };
            const std::uint32_t dim7029JoeKuoD6Init[]   =   { 1, 3, 1, 15, 9, 41, 61, 125, 65, 143, 1567, 3259, 6757, 653, 31601, 63127, 52179, 0 };
            const std::uint32_t dim7030JoeKuoD6Init[]   =   { 1, 1, 5, 3, 29, 5, 19, 197, 153, 447, 7, 1713, 469, 6043, 1259, 63641, 29171, 0 };
            const std::uint32_t dim7031JoeKuoD6Init[]   =   { 1, 3, 3, 7, 3, 41, 95, 245, 445, 15, 607, 565, 2361, 2673, 21077, 20153, 6199, 0 };
            const std::uint32_t dim7032JoeKuoD6Init[]   =   { 1, 1, 5, 1, 5, 59, 93, 127, 485, 663, 683, 635, 1599, 16377, 31819, 6539, 27789, 0 };
            const std::uint32_t dim7033JoeKuoD6Init[]   =   { 1, 3, 1, 3, 31, 3, 11, 215, 441, 1005, 1815, 3945, 5109, 5539, 23935, 62671, 90731, 0 };
            const std::uint32_t dim7034JoeKuoD6Init[]   =   { 1, 3, 3, 1, 13, 47, 19, 229, 191, 427, 1141, 2321, 7105, 1587, 26347, 63265, 23377, 0 };
            const std::uint32_t dim7035JoeKuoD6Init[]   =   { 1, 1, 5, 15, 31, 55, 61, 93, 89, 945, 1203, 3631, 4457, 15097, 32019, 41747, 46009, 0 };
            const std::uint32_t dim7036JoeKuoD6Init[]   =   { 1, 1, 5, 13, 5, 33, 69, 59, 93, 247, 503, 421, 1923, 9855, 9825, 14257, 98663, 0 };
            const std::uint32_t dim7037JoeKuoD6Init[]   =   { 1, 3, 1, 13, 27, 21, 91, 39, 131, 571, 1527, 2715, 2061, 627, 19705, 47165, 84345, 0 };
            const std::uint32_t dim7038JoeKuoD6Init[]   =   { 1, 1, 1, 7, 3, 3, 7, 251, 225, 959, 1017, 2423, 6163, 1549, 7473, 3193, 104259, 0 };
            const std::uint32_t dim7039JoeKuoD6Init[]   =   { 1, 3, 3, 1, 5, 5, 115, 221, 505, 649, 1525, 2459, 167, 1899, 23939, 29253, 122835, 0 };
            const std::uint32_t dim7040JoeKuoD6Init[]   =   { 1, 3, 1, 5, 15, 9, 123, 221, 133, 43, 31, 1211, 4737, 5001, 20065, 6369, 93865, 0 };
            const std::uint32_t dim7041JoeKuoD6Init[]   =   { 1, 1, 5, 11, 11, 5, 23, 29, 333, 133, 1469, 1895, 5879, 15599, 2131, 25005, 96271, 0 };
            const std::uint32_t dim7042JoeKuoD6Init[]   =   { 1, 1, 3, 11, 25, 11, 19, 57, 397, 645, 1233, 2433, 6371, 10577, 15489, 60709, 3957, 0 };
            const std::uint32_t dim7043JoeKuoD6Init[]   =   { 1, 3, 1, 1, 19, 3, 33, 131, 429, 835, 1363, 2213, 3185, 14385, 8831, 43159, 32975, 0 };
            const std::uint32_t dim7044JoeKuoD6Init[]   =   { 1, 1, 5, 5, 23, 11, 127, 139, 213, 259, 897, 1913, 5737, 1287, 26617, 4885, 30193, 0 };
            const std::uint32_t dim7045JoeKuoD6Init[]   =   { 1, 3, 5, 13, 3, 27, 99, 31, 11, 27, 1003, 2473, 7055, 12923, 4269, 41433, 90637, 0 };
            const std::uint32_t dim7046JoeKuoD6Init[]   =   { 1, 3, 1, 7, 17, 25, 95, 151, 199, 237, 207, 1879, 2943, 9845, 3765, 53533, 111191, 0 };
            const std::uint32_t dim7047JoeKuoD6Init[]   =   { 1, 3, 1, 9, 19, 27, 5, 249, 85, 185, 1883, 1401, 2041, 12721, 20593, 30993, 2601, 0 };
            const std::uint32_t dim7048JoeKuoD6Init[]   =   { 1, 3, 3, 9, 23, 1, 15, 133, 387, 779, 707, 2723, 4485, 989, 27125, 37295, 125319, 0 };
            const std::uint32_t dim7049JoeKuoD6Init[]   =   { 1, 1, 7, 3, 9, 41, 81, 151, 349, 941, 357, 3817, 7123, 10079, 27519, 107, 102281, 0 };
            const std::uint32_t dim7050JoeKuoD6Init[]   =   { 1, 1, 1, 1, 13, 5, 111, 167, 73, 85, 1185, 1213, 333, 153, 13101, 38087, 39389, 0 };
            const std::uint32_t dim7051JoeKuoD6Init[]   =   { 1, 3, 3, 15, 11, 41, 99, 231, 377, 539, 1335, 1059, 5373, 9611, 27927, 29801, 85749, 0 };
            const std::uint32_t dim7052JoeKuoD6Init[]   =   { 1, 3, 1, 9, 19, 37, 125, 27, 15, 699, 1867, 2711, 1589, 1675, 32007, 61339, 96919, 0 };
            const std::uint32_t dim7053JoeKuoD6Init[]   =   { 1, 3, 3, 3, 3, 27, 21, 159, 249, 783, 1517, 2923, 2609, 1207, 13705, 57371, 43603, 0 };
            const std::uint32_t dim7054JoeKuoD6Init[]   =   { 1, 1, 5, 15, 17, 55, 77, 1, 401, 897, 987, 345, 5283, 5827, 17755, 44371, 13253, 0 };
            const std::uint32_t dim7055JoeKuoD6Init[]   =   { 1, 3, 1, 7, 3, 3, 99, 237, 487, 405, 771, 3503, 1199, 4779, 26893, 45821, 46383, 0 };
            const std::uint32_t dim7056JoeKuoD6Init[]   =   { 1, 1, 7, 3, 9, 47, 81, 27, 459, 989, 1891, 3997, 4081, 4075, 15079, 65081, 125185, 0 };
            const std::uint32_t dim7057JoeKuoD6Init[]   =   { 1, 3, 5, 9, 25, 23, 71, 251, 251, 197, 353, 3553, 2165, 2953, 3733, 52369, 100641, 0 };
            const std::uint32_t dim7058JoeKuoD6Init[]   =   { 1, 1, 1, 5, 25, 43, 63, 187, 495, 345, 1547, 2293, 7327, 7797, 14001, 61865, 40329, 0 };
            const std::uint32_t dim7059JoeKuoD6Init[]   =   { 1, 1, 5, 15, 25, 37, 67, 23, 315, 801, 71, 1235, 7293, 7207, 30929, 9417, 94735, 0 };
            const std::uint32_t dim7060JoeKuoD6Init[]   =   { 1, 1, 1, 3, 23, 29, 87, 171, 337, 457, 1597, 3933, 4151, 1237, 19563, 56997, 81497, 0 };
            const std::uint32_t dim7061JoeKuoD6Init[]   =   { 1, 3, 3, 11, 3, 33, 79, 239, 277, 611, 205, 2283, 7459, 425, 21999, 26491, 58681, 0 };
            const std::uint32_t dim7062JoeKuoD6Init[]   =   { 1, 1, 7, 1, 5, 37, 53, 93, 205, 97, 779, 3623, 7777, 521, 21915, 46539, 128811, 0 };
            const std::uint32_t dim7063JoeKuoD6Init[]   =   { 1, 1, 5, 7, 19, 7, 39, 183, 299, 193, 1351, 3867, 5709, 11655, 1231, 15555, 128023, 0 };
            const std::uint32_t dim7064JoeKuoD6Init[]   =   { 1, 3, 7, 11, 31, 13, 113, 57, 197, 841, 921, 2087, 2195, 8279, 8353, 1955, 22121, 0 };
            const std::uint32_t dim7065JoeKuoD6Init[]   =   { 1, 3, 3, 11, 21, 55, 61, 105, 357, 747, 363, 3511, 2547, 16283, 25747, 56041, 33695, 0 };
            const std::uint32_t dim7066JoeKuoD6Init[]   =   { 1, 3, 3, 13, 27, 13, 5, 27, 93, 691, 1869, 2331, 3131, 14411, 2355, 37195, 129273, 0 };
            const std::uint32_t dim7067JoeKuoD6Init[]   =   { 1, 3, 3, 7, 27, 9, 11, 165, 435, 811, 215, 1617, 347, 4289, 29373, 15749, 91445, 0 };
            const std::uint32_t dim7068JoeKuoD6Init[]   =   { 1, 1, 7, 13, 29, 3, 95, 53, 457, 633, 959, 3705, 7461, 9307, 21963, 51599, 6751, 0 };
            const std::uint32_t dim7069JoeKuoD6Init[]   =   { 1, 1, 1, 15, 29, 25, 95, 1, 125, 61, 683, 2067, 6485, 9095, 5571, 61281, 70865, 0 };
            const std::uint32_t dim7070JoeKuoD6Init[]   =   { 1, 1, 7, 7, 1, 35, 119, 107, 247, 991, 237, 1865, 3961, 12583, 11417, 14913, 90897, 0 };
            const std::uint32_t dim7071JoeKuoD6Init[]   =   { 1, 3, 7, 15, 11, 51, 73, 193, 289, 381, 1767, 3803, 3197, 3797, 15059, 19393, 98947, 0 };
            const std::uint32_t dim7072JoeKuoD6Init[]   =   { 1, 1, 5, 3, 13, 7, 91, 223, 347, 59, 1721, 1501, 6391, 4141, 14495, 47283, 47237, 0 };
            const std::uint32_t dim7073JoeKuoD6Init[]   =   { 1, 3, 7, 11, 17, 39, 43, 247, 35, 423, 1859, 3199, 5343, 7061, 8609, 6819, 88575, 0 };
            const std::uint32_t dim7074JoeKuoD6Init[]   =   { 1, 1, 5, 13, 31, 27, 57, 19, 499, 1007, 1965, 795, 1231, 12755, 24631, 53343, 82305, 0 };
            const std::uint32_t dim7075JoeKuoD6Init[]   =   { 1, 1, 1, 9, 13, 23, 127, 161, 245, 467, 2025, 2545, 3085, 13035, 27087, 14461, 35971, 0 };
            const std::uint32_t dim7076JoeKuoD6Init[]   =   { 1, 3, 5, 1, 7, 3, 99, 159, 75, 341, 1755, 2337, 5981, 5055, 19445, 30043, 61427, 0 };
            const std::uint32_t dim7077JoeKuoD6Init[]   =   { 1, 1, 1, 7, 13, 33, 41, 73, 267, 21, 961, 3509, 6839, 13215, 8471, 46735, 93071, 0 };
            const std::uint32_t dim7078JoeKuoD6Init[]   =   { 1, 3, 7, 7, 3, 25, 81, 239, 357, 445, 1483, 389, 3891, 5131, 21357, 34757, 111063, 0 };
            const std::uint32_t dim7079JoeKuoD6Init[]   =   { 1, 3, 7, 1, 1, 37, 119, 121, 195, 935, 1711, 2049, 7001, 7117, 9957, 7309, 102293, 0 };
            const std::uint32_t dim7080JoeKuoD6Init[]   =   { 1, 1, 7, 11, 1, 49, 107, 95, 149, 329, 289, 1121, 7217, 15091, 19071, 13801, 13, 0 };
            const std::uint32_t dim7081JoeKuoD6Init[]   =   { 1, 1, 1, 13, 17, 17, 7, 105, 81, 1017, 1867, 1567, 5133, 7325, 19797, 16301, 40471, 0 };
            const std::uint32_t dim7082JoeKuoD6Init[]   =   { 1, 3, 5, 5, 27, 45, 117, 135, 499, 53, 973, 121, 53, 8771, 11893, 35827, 57691, 0 };
            const std::uint32_t dim7083JoeKuoD6Init[]   =   { 1, 1, 1, 1, 7, 23, 11, 163, 17, 871, 129, 2959, 5583, 12253, 1419, 28367, 32539, 0 };
            const std::uint32_t dim7084JoeKuoD6Init[]   =   { 1, 1, 3, 5, 23, 31, 127, 33, 115, 799, 331, 1873, 1729, 1383, 23601, 51145, 72027, 0 };
            const std::uint32_t dim7085JoeKuoD6Init[]   =   { 1, 1, 1, 9, 15, 49, 105, 163, 51, 539, 451, 3983, 6509, 1073, 30757, 13971, 51371, 0 };
            const std::uint32_t dim7086JoeKuoD6Init[]   =   { 1, 1, 7, 1, 1, 57, 71, 135, 5, 171, 983, 951, 777, 9257, 3607, 3239, 76237, 0 };
            const std::uint32_t dim7087JoeKuoD6Init[]   =   { 1, 1, 7, 7, 21, 17, 49, 175, 9, 807, 289, 2777, 7309, 14911, 28349, 43871, 96019, 0 };
            const std::uint32_t dim7088JoeKuoD6Init[]   =   { 1, 3, 1, 13, 5, 7, 83, 215, 297, 319, 347, 633, 7285, 8293, 18811, 31065, 114077, 0 };
            const std::uint32_t dim7089JoeKuoD6Init[]   =   { 1, 3, 1, 11, 3, 29, 91, 231, 161, 601, 355, 2719, 2941, 6065, 21849, 58051, 46515, 0 };
            const std::uint32_t dim7090JoeKuoD6Init[]   =   { 1, 1, 3, 9, 25, 41, 111, 135, 71, 755, 29, 131, 1339, 5053, 15713, 14557, 106777, 0 };
            const std::uint32_t dim7091JoeKuoD6Init[]   =   { 1, 1, 7, 13, 21, 59, 13, 45, 503, 71, 1611, 4021, 2359, 11653, 7261, 14537, 33031, 0 };
            const std::uint32_t dim7092JoeKuoD6Init[]   =   { 1, 1, 1, 11, 5, 31, 1, 181, 37, 527, 1345, 1979, 4899, 3289, 25181, 49959, 44609, 0 };
            const std::uint32_t dim7093JoeKuoD6Init[]   =   { 1, 3, 3, 13, 21, 25, 33, 105, 57, 637, 841, 1595, 3881, 5053, 9441, 58717, 127255, 0 };
            const std::uint32_t dim7094JoeKuoD6Init[]   =   { 1, 3, 5, 7, 23, 57, 9, 117, 281, 769, 1573, 2857, 1139, 6413, 14001, 21097, 55215, 0 };
            const std::uint32_t dim7095JoeKuoD6Init[]   =   { 1, 1, 7, 7, 3, 5, 75, 149, 269, 353, 437, 61, 2451, 11987, 17243, 5649, 105107, 0 };
            const std::uint32_t dim7096JoeKuoD6Init[]   =   { 1, 1, 3, 3, 25, 61, 53, 21, 113, 57, 1415, 2825, 11, 14977, 6159, 4181, 96765, 0 };
            const std::uint32_t dim7097JoeKuoD6Init[]   =   { 1, 1, 7, 5, 15, 25, 121, 159, 71, 773, 601, 147, 6507, 16171, 16607, 32017, 77845, 0 };
            const std::uint32_t dim7098JoeKuoD6Init[]   =   { 1, 3, 1, 1, 27, 19, 59, 109, 347, 991, 165, 683, 6147, 493, 22017, 19069, 52857, 0 };
            const std::uint32_t dim7099JoeKuoD6Init[]   =   { 1, 1, 5, 5, 21, 1, 93, 115, 407, 15, 421, 1305, 3495, 14287, 31831, 65347, 35339, 0 };
            const std::uint32_t dim7100JoeKuoD6Init[]   =   { 1, 3, 5, 11, 29, 35, 87, 27, 453, 769, 1991, 2757, 2607, 9225, 293, 49441, 18185, 0 };
            const std::uint32_t dim7101JoeKuoD6Init[]   =   { 1, 1, 5, 3, 23, 41, 67, 195, 499, 903, 197, 1121, 4691, 9277, 29225, 34597, 37395, 0 };
            const std::uint32_t dim7102JoeKuoD6Init[]   =   { 1, 1, 7, 7, 21, 7, 65, 245, 241, 909, 1063, 2271, 1979, 10287, 1747, 61523, 72969, 0 };
            const std::uint32_t dim7103JoeKuoD6Init[]   =   { 1, 3, 1, 13, 23, 25, 3, 89, 385, 481, 1463, 3431, 6907, 1129, 3519, 35789, 82585, 0 };
            const std::uint32_t dim7104JoeKuoD6Init[]   =   { 1, 3, 5, 3, 31, 17, 11, 209, 77, 991, 885, 3341, 6895, 3429, 21611, 38555, 35475, 0 };
            const std::uint32_t dim7105JoeKuoD6Init[]   =   { 1, 1, 3, 1, 9, 61, 27, 219, 433, 787, 281, 1155, 2915, 4449, 30881, 34461, 15357, 0 };
            const std::uint32_t dim7106JoeKuoD6Init[]   =   { 1, 1, 3, 15, 27, 55, 51, 101, 117, 799, 1475, 4013, 5145, 14991, 27847, 49537, 57339, 0 };
            const std::uint32_t dim7107JoeKuoD6Init[]   =   { 1, 3, 7, 13, 13, 9, 13, 167, 283, 883, 1501, 2635, 1463, 3353, 14961, 30349, 62043, 0 };
            const std::uint32_t dim7108JoeKuoD6Init[]   =   { 1, 1, 7, 3, 3, 47, 119, 37, 389, 655, 701, 2471, 5749, 6645, 845, 27065, 82299, 0 };
            const std::uint32_t dim7109JoeKuoD6Init[]   =   { 1, 1, 7, 15, 27, 5, 95, 195, 227, 991, 1137, 3715, 4901, 9459, 1917, 43857, 126505, 0 };
            const std::uint32_t dim7110JoeKuoD6Init[]   =   { 1, 3, 7, 5, 29, 35, 45, 165, 361, 257, 641, 1265, 6533, 11333, 26081, 12621, 66909, 0 };
            const std::uint32_t dim7111JoeKuoD6Init[]   =   { 1, 1, 1, 11, 19, 55, 73, 137, 29, 355, 725, 1161, 6717, 2035, 19769, 43531, 72577, 0 };
            const std::uint32_t dim7112JoeKuoD6Init[]   =   { 1, 3, 7, 5, 19, 3, 99, 17, 387, 621, 137, 117, 6567, 7667, 14979, 17981, 68319, 0 };
            const std::uint32_t dim7113JoeKuoD6Init[]   =   { 1, 1, 5, 5, 7, 53, 31, 33, 245, 371, 691, 2763, 95, 16369, 7853, 29839, 34957, 0 };
            const std::uint32_t dim7114JoeKuoD6Init[]   =   { 1, 1, 3, 1, 9, 1, 83, 177, 17, 141, 1739, 1791, 3849, 3093, 22271, 53755, 7817, 0 };
            const std::uint32_t dim7115JoeKuoD6Init[]   =   { 1, 3, 3, 1, 3, 51, 71, 69, 439, 987, 807, 3353, 4747, 16031, 29591, 61091, 95675, 0 };
            const std::uint32_t dim7116JoeKuoD6Init[]   =   { 1, 3, 5, 1, 17, 47, 51, 211, 7, 5, 1751, 1735, 1647, 13389, 13861, 49427, 13577, 0 };
            const std::uint32_t dim7117JoeKuoD6Init[]   =   { 1, 3, 7, 5, 11, 23, 17, 55, 11, 61, 809, 927, 6533, 1509, 29261, 21555, 55075, 0 };
            const std::uint32_t dim7118JoeKuoD6Init[]   =   { 1, 3, 1, 1, 15, 51, 37, 47, 183, 117, 597, 3225, 1435, 13359, 19127, 17339, 17345, 0 };
            const std::uint32_t dim7119JoeKuoD6Init[]   =   { 1, 1, 5, 3, 5, 11, 33, 179, 295, 129, 29, 713, 1561, 27, 21087, 50305, 39253, 0 };
            const std::uint32_t dim7120JoeKuoD6Init[]   =   { 1, 1, 5, 7, 17, 25, 105, 241, 41, 915, 1223, 2625, 617, 10983, 10749, 2137, 101831, 0 };
            const std::uint32_t dim7121JoeKuoD6Init[]   =   { 1, 3, 5, 7, 15, 15, 85, 23, 193, 625, 1803, 2903, 1935, 523, 8377, 12165, 105851, 0 };
            const std::uint32_t dim7122JoeKuoD6Init[]   =   { 1, 3, 3, 7, 3, 35, 5, 107, 191, 855, 405, 1659, 5523, 5011, 6401, 45187, 31345, 0 };
            const std::uint32_t dim7123JoeKuoD6Init[]   =   { 1, 3, 3, 1, 9, 21, 103, 75, 501, 669, 547, 3685, 411, 2663, 14743, 13869, 124389, 0 };
            const std::uint32_t dim7124JoeKuoD6Init[]   =   { 1, 3, 5, 13, 15, 37, 39, 79, 19, 165, 1685, 1367, 5951, 12303, 13423, 51083, 119933, 0 };
            const std::uint32_t dim7125JoeKuoD6Init[]   =   { 1, 1, 3, 1, 7, 25, 1, 221, 415, 591, 859, 1457, 1789, 2269, 15947, 31913, 86397, 0 };
            const std::uint32_t dim7126JoeKuoD6Init[]   =   { 1, 3, 7, 15, 11, 49, 15, 171, 45, 925, 407, 1719, 4505, 5695, 17397, 28849, 77, 0 };
            const std::uint32_t dim7127JoeKuoD6Init[]   =   { 1, 1, 3, 11, 21, 33, 91, 115, 263, 141, 753, 3335, 7695, 1981, 6029, 22629, 2467, 0 };
            const std::uint32_t dim7128JoeKuoD6Init[]   =   { 1, 3, 5, 3, 25, 5, 21, 67, 429, 323, 223, 2395, 761, 14817, 12387, 37905, 19551, 0 };
            const std::uint32_t dim7129JoeKuoD6Init[]   =   { 1, 3, 1, 15, 31, 43, 35, 255, 73, 533, 1093, 965, 557, 607, 6913, 35283, 12261, 0 };
            const std::uint32_t dim7130JoeKuoD6Init[]   =   { 1, 3, 1, 15, 25, 13, 39, 83, 77, 269, 1205, 1577, 4095, 6669, 8643, 48807, 98227, 0 };
            const std::uint32_t dim7131JoeKuoD6Init[]   =   { 1, 3, 3, 7, 31, 57, 25, 177, 441, 973, 1255, 675, 5579, 4899, 27925, 52555, 70845, 0 };
            const std::uint32_t dim7132JoeKuoD6Init[]   =   { 1, 3, 1, 5, 13, 47, 15, 75, 387, 461, 1909, 841, 7, 9567, 913, 41411, 12565, 0 };
            const std::uint32_t dim7133JoeKuoD6Init[]   =   { 1, 1, 5, 7, 5, 21, 17, 189, 319, 645, 403, 2723, 6747, 15471, 26533, 12709, 49417, 0 };
            const std::uint32_t dim7134JoeKuoD6Init[]   =   { 1, 1, 5, 7, 7, 41, 99, 179, 137, 435, 1061, 3987, 4583, 4101, 23781, 54263, 36695, 0 };
            const std::uint32_t dim7135JoeKuoD6Init[]   =   { 1, 3, 1, 11, 19, 37, 125, 177, 111, 921, 1003, 1433, 1399, 3991, 28193, 40471, 97041, 0 };
            const std::uint32_t dim7136JoeKuoD6Init[]   =   { 1, 1, 7, 1, 5, 33, 7, 139, 127, 413, 1171, 2237, 265, 10145, 18793, 28957, 25037, 0 };
            const std::uint32_t dim7137JoeKuoD6Init[]   =   { 1, 3, 1, 1, 25, 37, 13, 17, 471, 195, 1645, 3165, 5635, 8433, 28507, 453, 107709, 0 };
            const std::uint32_t dim7138JoeKuoD6Init[]   =   { 1, 3, 3, 11, 1, 55, 119, 97, 243, 371, 95, 97, 7833, 777, 12177, 1861, 56323, 0 };
            const std::uint32_t dim7139JoeKuoD6Init[]   =   { 1, 1, 7, 5, 7, 29, 59, 219, 405, 411, 275, 111, 4899, 10367, 24331, 57295, 47065, 0 };
            const std::uint32_t dim7140JoeKuoD6Init[]   =   { 1, 1, 3, 3, 19, 23, 91, 111, 221, 195, 1013, 3001, 3227, 6359, 30383, 49699, 49157, 0 };
            const std::uint32_t dim7141JoeKuoD6Init[]   =   { 1, 1, 5, 7, 1, 21, 125, 23, 177, 291, 249, 861, 1899, 14101, 5079, 5211, 14373, 0 };
            const std::uint32_t dim7142JoeKuoD6Init[]   =   { 1, 1, 7, 11, 11, 59, 33, 41, 291, 919, 253, 609, 1657, 14633, 15189, 22245, 99815, 0 };
            const std::uint32_t dim7143JoeKuoD6Init[]   =   { 1, 3, 5, 3, 23, 49, 71, 137, 393, 343, 1845, 343, 5853, 6639, 17435, 62143, 76041, 0 };
            const std::uint32_t dim7144JoeKuoD6Init[]   =   { 1, 1, 5, 3, 9, 27, 55, 193, 25, 965, 1453, 2739, 3785, 12497, 29607, 11111, 25145, 0 };
            const std::uint32_t dim7145JoeKuoD6Init[]   =   { 1, 1, 1, 1, 29, 11, 111, 73, 491, 629, 405, 2779, 5313, 589, 1459, 47555, 67945, 0 };
            const std::uint32_t dim7146JoeKuoD6Init[]   =   { 1, 3, 1, 7, 13, 21, 99, 75, 79, 963, 207, 1725, 6875, 8359, 10573, 45219, 130463, 0 };
            const std::uint32_t dim7147JoeKuoD6Init[]   =   { 1, 3, 7, 13, 1, 17, 105, 227, 487, 891, 1053, 1333, 7651, 5415, 18661, 22085, 82055, 0 };
            const std::uint32_t dim7148JoeKuoD6Init[]   =   { 1, 1, 3, 3, 31, 27, 91, 93, 383, 331, 965, 3035, 4931, 13265, 9729, 28985, 118227, 0 };
            const std::uint32_t dim7149JoeKuoD6Init[]   =   { 1, 3, 1, 1, 11, 9, 59, 191, 253, 909, 301, 3811, 255, 14937, 28627, 54509, 95993, 0 };
            const std::uint32_t dim7150JoeKuoD6Init[]   =   { 1, 3, 3, 5, 11, 5, 105, 77, 323, 713, 637, 1857, 2697, 12473, 12261, 2933, 101287, 0 };
            const std::uint32_t dim7151JoeKuoD6Init[]   =   { 1, 3, 3, 11, 9, 63, 19, 19, 213, 859, 1479, 2849, 1067, 5749, 13511, 14933, 11125, 0 };
            const std::uint32_t dim7152JoeKuoD6Init[]   =   { 1, 1, 5, 9, 19, 19, 13, 49, 237, 511, 533, 543, 575, 8095, 27335, 18847, 18173, 0 };
            const std::uint32_t dim7153JoeKuoD6Init[]   =   { 1, 3, 5, 5, 9, 53, 47, 157, 35, 827, 637, 2327, 787, 5269, 5145, 10135, 111273, 0 };
            const std::uint32_t dim7154JoeKuoD6Init[]   =   { 1, 3, 3, 7, 27, 41, 69, 173, 53, 655, 809, 481, 6999, 3101, 20781, 2481, 94957, 0 };
            const std::uint32_t dim7155JoeKuoD6Init[]   =   { 1, 1, 5, 11, 17, 23, 95, 201, 363, 613, 863, 1365, 1131, 15417, 20705, 8283, 55235, 0 };
            const std::uint32_t dim7156JoeKuoD6Init[]   =   { 1, 1, 5, 13, 3, 15, 37, 219, 291, 595, 1665, 1861, 1953, 15385, 20569, 46085, 15163, 0 };
            const std::uint32_t dim7157JoeKuoD6Init[]   =   { 1, 3, 3, 11, 23, 43, 125, 133, 85, 45, 819, 243, 7325, 8723, 1499, 58139, 120353, 0 };
            const std::uint32_t dim7158JoeKuoD6Init[]   =   { 1, 1, 1, 11, 21, 49, 91, 145, 175, 619, 1817, 3533, 8155, 7521, 30361, 45431, 130175, 0 };
            const std::uint32_t dim7159JoeKuoD6Init[]   =   { 1, 1, 3, 1, 11, 59, 57, 51, 37, 903, 1221, 3813, 8043, 14165, 31503, 7905, 61515, 0 };
            const std::uint32_t dim7160JoeKuoD6Init[]   =   { 1, 1, 1, 1, 15, 9, 115, 175, 285, 839, 97, 3119, 719, 15283, 22947, 25417, 40665, 0 };
            const std::uint32_t dim7161JoeKuoD6Init[]   =   { 1, 3, 1, 7, 5, 49, 127, 111, 373, 747, 393, 2351, 4577, 15227, 23149, 16901, 80253, 0 };
            const std::uint32_t dim7162JoeKuoD6Init[]   =   { 1, 1, 5, 3, 15, 5, 95, 197, 251, 275, 831, 1389, 3907, 12343, 11599, 24369, 65361, 0 };
            const std::uint32_t dim7163JoeKuoD6Init[]   =   { 1, 3, 7, 5, 25, 37, 11, 75, 417, 789, 745, 811, 2189, 15381, 4785, 41657, 2897, 0 };
            const std::uint32_t dim7164JoeKuoD6Init[]   =   { 1, 3, 1, 13, 29, 55, 55, 33, 279, 383, 1645, 975, 4683, 1357, 1149, 30271, 90527, 0 };
            const std::uint32_t dim7165JoeKuoD6Init[]   =   { 1, 3, 5, 3, 5, 3, 79, 61, 371, 225, 141, 369, 1037, 12249, 29431, 37253, 9899, 0 };
            const std::uint32_t dim7166JoeKuoD6Init[]   =   { 1, 1, 3, 13, 13, 7, 127, 147, 507, 119, 1085, 1949, 6289, 10179, 10107, 55989, 74395, 0 };
            const std::uint32_t dim7167JoeKuoD6Init[]   =   { 1, 3, 1, 7, 21, 35, 53, 209, 103, 365, 683, 553, 4977, 14371, 24037, 11453, 45369, 0 };
            const std::uint32_t dim7168JoeKuoD6Init[]   =   { 1, 1, 5, 11, 27, 39, 41, 145, 437, 55, 893, 2375, 4977, 5451, 21225, 46815, 1423, 0 };
            const std::uint32_t dim7169JoeKuoD6Init[]   =   { 1, 3, 5, 1, 23, 53, 113, 75, 209, 323, 1975, 3809, 1829, 14625, 3821, 53773, 129173, 0 };
            const std::uint32_t dim7170JoeKuoD6Init[]   =   { 1, 1, 5, 3, 7, 51, 97, 73, 289, 481, 339, 1375, 3101, 4395, 13933, 33267, 68115, 0 };
            const std::uint32_t dim7171JoeKuoD6Init[]   =   { 1, 3, 5, 1, 5, 45, 83, 57, 3, 667, 109, 3979, 6447, 8603, 20147, 49291, 18023, 0 };
            const std::uint32_t dim7172JoeKuoD6Init[]   =   { 1, 3, 7, 1, 11, 7, 45, 233, 65, 745, 1009, 2979, 5965, 10681, 3499, 23077, 87479, 0 };
            const std::uint32_t dim7173JoeKuoD6Init[]   =   { 1, 3, 3, 3, 13, 25, 25, 189, 197, 83, 1429, 2857, 2877, 8577, 24811, 33049, 46009, 0 };
            const std::uint32_t dim7174JoeKuoD6Init[]   =   { 1, 1, 1, 7, 11, 47, 47, 255, 89, 625, 449, 3747, 2035, 3509, 4901, 2961, 14073, 0 };
            const std::uint32_t dim7175JoeKuoD6Init[]   =   { 1, 1, 1, 13, 9, 55, 35, 47, 389, 573, 847, 1037, 1345, 5487, 7575, 57435, 77303, 0 };
            const std::uint32_t dim7176JoeKuoD6Init[]   =   { 1, 1, 5, 11, 25, 51, 113, 109, 79, 339, 95, 2049, 5881, 13209, 20041, 26419, 110319, 0 };
            const std::uint32_t dim7177JoeKuoD6Init[]   =   { 1, 1, 7, 1, 27, 15, 93, 145, 253, 917, 1211, 2221, 1087, 14209, 32097, 20083, 67841, 0 };
            const std::uint32_t dim7178JoeKuoD6Init[]   =   { 1, 1, 3, 15, 13, 19, 67, 107, 75, 919, 2047, 3675, 6231, 1243, 14335, 35939, 17281, 0 };
            const std::uint32_t dim7179JoeKuoD6Init[]   =   { 1, 3, 7, 5, 27, 47, 53, 239, 475, 231, 1645, 825, 4039, 15985, 10853, 32951, 34985, 0 };
            const std::uint32_t dim7180JoeKuoD6Init[]   =   { 1, 1, 7, 5, 15, 61, 107, 93, 51, 221, 717, 2859, 7885, 9571, 11841, 45143, 33723, 0 };
            const std::uint32_t dim7181JoeKuoD6Init[]   =   { 1, 1, 7, 7, 9, 25, 63, 25, 47, 55, 2041, 3965, 215, 14857, 31669, 54775, 42157, 0 };
            const std::uint32_t dim7182JoeKuoD6Init[]   =   { 1, 3, 5, 1, 5, 45, 123, 109, 471, 599, 479, 475, 3499, 11963, 23709, 18851, 66861, 0 };
            const std::uint32_t dim7183JoeKuoD6Init[]   =   { 1, 3, 3, 3, 5, 29, 71, 81, 315, 329, 1471, 3995, 623, 5871, 11171, 15645, 97251, 0 };
            const std::uint32_t dim7184JoeKuoD6Init[]   =   { 1, 1, 7, 11, 15, 15, 101, 173, 445, 871, 765, 1121, 1937, 13055, 7309, 54175, 85559, 0 };
            const std::uint32_t dim7185JoeKuoD6Init[]   =   { 1, 3, 5, 7, 7, 13, 43, 237, 361, 981, 19, 3113, 4681, 3313, 19147, 35193, 87281, 0 };
            const std::uint32_t dim7186JoeKuoD6Init[]   =   { 1, 3, 5, 3, 27, 13, 37, 51, 233, 573, 1599, 2807, 7149, 12083, 28927, 7797, 130879, 0 };
            const std::uint32_t dim7187JoeKuoD6Init[]   =   { 1, 1, 1, 13, 31, 63, 127, 89, 209, 717, 1075, 3887, 1427, 87, 18565, 39973, 55025, 0 };
            const std::uint32_t dim7188JoeKuoD6Init[]   =   { 1, 3, 1, 5, 15, 11, 121, 247, 273, 613, 1857, 2059, 7399, 13951, 9025, 39523, 68121, 0 };
            const std::uint32_t dim7189JoeKuoD6Init[]   =   { 1, 3, 7, 13, 31, 9, 61, 143, 375, 433, 471, 1315, 5299, 1167, 10099, 11445, 51693, 0 };
            const std::uint32_t dim7190JoeKuoD6Init[]   =   { 1, 1, 7, 9, 25, 31, 125, 5, 13, 595, 621, 3551, 7959, 10643, 14345, 37683, 118377, 0 };
            const std::uint32_t dim7191JoeKuoD6Init[]   =   { 1, 1, 5, 11, 1, 33, 45, 31, 447, 229, 893, 3777, 4101, 2505, 4855, 14057, 20133, 0 };
            const std::uint32_t dim7192JoeKuoD6Init[]   =   { 1, 1, 1, 1, 7, 23, 89, 53, 483, 873, 521, 2115, 1461, 11241, 1003, 28749, 68227, 0 };
            const std::uint32_t dim7193JoeKuoD6Init[]   =   { 1, 3, 5, 5, 3, 17, 23, 219, 281, 975, 895, 4043, 6505, 5991, 27401, 38791, 89239, 0 };
            const std::uint32_t dim7194JoeKuoD6Init[]   =   { 1, 1, 1, 7, 29, 41, 63, 151, 195, 495, 469, 305, 7437, 1107, 31147, 30755, 116551, 0 };
            const std::uint32_t dim7195JoeKuoD6Init[]   =   { 1, 3, 7, 3, 13, 25, 33, 193, 23, 135, 3, 513, 4169, 15355, 2255, 32167, 68691, 0 };
            const std::uint32_t dim7196JoeKuoD6Init[]   =   { 1, 3, 3, 11, 29, 19, 125, 177, 83, 361, 393, 663, 1859, 1333, 17507, 10661, 72387, 0 };
            const std::uint32_t dim7197JoeKuoD6Init[]   =   { 1, 1, 5, 11, 23, 13, 61, 33, 149, 145, 995, 649, 7587, 6743, 25225, 54997, 10193, 0 };
            const std::uint32_t dim7198JoeKuoD6Init[]   =   { 1, 1, 7, 13, 29, 51, 107, 79, 467, 881, 1227, 1083, 3277, 2559, 26819, 57311, 48095, 0 };
            const std::uint32_t dim7199JoeKuoD6Init[]   =   { 1, 3, 1, 1, 1, 19, 23, 25, 239, 703, 119, 2525, 8079, 5433, 8989, 42517, 116755, 0 };
            const std::uint32_t dim7200JoeKuoD6Init[]   =   { 1, 1, 7, 11, 31, 9, 9, 113, 381, 363, 447, 3751, 7523, 15995, 3853, 42069, 81455, 0 };
            const std::uint32_t dim7201JoeKuoD6Init[]   =   { 1, 1, 5, 9, 29, 41, 103, 179, 477, 527, 1593, 3003, 1095, 6823, 6911, 44987, 32445, 0 };
            const std::uint32_t dim7202JoeKuoD6Init[]   =   { 1, 1, 7, 15, 5, 31, 55, 181, 149, 127, 1745, 2753, 801, 285, 20199, 33707, 118397, 0 };
            const std::uint32_t dim7203JoeKuoD6Init[]   =   { 1, 3, 7, 7, 11, 29, 89, 215, 351, 303, 1519, 2593, 2045, 14699, 1657, 40799, 39641, 0 };
            const std::uint32_t dim7204JoeKuoD6Init[]   =   { 1, 1, 7, 13, 3, 35, 73, 111, 15, 803, 1819, 3453, 3611, 8337, 14239, 14875, 83983, 0 };
            const std::uint32_t dim7205JoeKuoD6Init[]   =   { 1, 1, 5, 15, 15, 49, 27, 101, 149, 3, 717, 2229, 7397, 6579, 10965, 35997, 28823, 0 };
            const std::uint32_t dim7206JoeKuoD6Init[]   =   { 1, 1, 5, 7, 3, 17, 49, 245, 343, 657, 15, 749, 6413, 10811, 2909, 47309, 34613, 0 };
            const std::uint32_t dim7207JoeKuoD6Init[]   =   { 1, 3, 5, 15, 13, 35, 67, 99, 481, 379, 2003, 3367, 3065, 5845, 7799, 43931, 15263, 0 };
            const std::uint32_t dim7208JoeKuoD6Init[]   =   { 1, 1, 5, 13, 21, 49, 81, 77, 395, 919, 1931, 661, 123, 9965, 10487, 55131, 1567, 0 };
            const std::uint32_t dim7209JoeKuoD6Init[]   =   { 1, 3, 5, 11, 23, 39, 41, 121, 159, 473, 191, 1983, 6411, 10503, 10523, 40601, 64153, 0 };
            const std::uint32_t dim7210JoeKuoD6Init[]   =   { 1, 1, 5, 7, 9, 37, 73, 207, 497, 789, 1671, 325, 1697, 11281, 31185, 4961, 124431, 0 };
            const std::uint32_t dim7211JoeKuoD6Init[]   =   { 1, 1, 5, 15, 7, 51, 71, 91, 449, 707, 621, 2427, 627, 1747, 12779, 17569, 98289, 0 };
            const std::uint32_t dim7212JoeKuoD6Init[]   =   { 1, 1, 5, 5, 31, 3, 89, 163, 77, 647, 1747, 2965, 1669, 3311, 17651, 8111, 30739, 0 };
            const std::uint32_t dim7213JoeKuoD6Init[]   =   { 1, 1, 3, 11, 15, 31, 77, 173, 405, 913, 459, 2955, 6153, 13391, 20439, 64433, 12371, 0 };
            const std::uint32_t dim7214JoeKuoD6Init[]   =   { 1, 1, 3, 11, 13, 55, 29, 37, 379, 689, 407, 1373, 397, 5027, 15497, 25687, 48193, 0 };
            const std::uint32_t dim7215JoeKuoD6Init[]   =   { 1, 3, 3, 15, 13, 7, 81, 207, 395, 901, 779, 1683, 2491, 3807, 31979, 32403, 81113, 0 };
            const std::uint32_t dim7216JoeKuoD6Init[]   =   { 1, 3, 3, 13, 29, 31, 25, 81, 459, 991, 793, 3285, 2775, 16199, 11423, 52597, 86041, 0 };
            const std::uint32_t dim7217JoeKuoD6Init[]   =   { 1, 3, 3, 13, 17, 17, 101, 183, 19, 735, 671, 1097, 2461, 9863, 25985, 31915, 73047, 0 };
            const std::uint32_t dim7218JoeKuoD6Init[]   =   { 1, 3, 3, 3, 3, 11, 71, 63, 429, 899, 351, 1275, 3907, 14241, 19135, 14875, 43325, 0 };
            const std::uint32_t dim7219JoeKuoD6Init[]   =   { 1, 1, 7, 11, 11, 61, 15, 213, 411, 13, 1409, 1741, 5257, 8729, 28351, 6381, 77501, 0 };
            const std::uint32_t dim7220JoeKuoD6Init[]   =   { 1, 1, 7, 7, 29, 27, 51, 217, 411, 261, 599, 3027, 7871, 9133, 32423, 44275, 34701, 0 };
            const std::uint32_t dim7221JoeKuoD6Init[]   =   { 1, 3, 7, 7, 1, 1, 127, 209, 151, 845, 1421, 3115, 7775, 10133, 6163, 41165, 91187, 0 };
            const std::uint32_t dim7222JoeKuoD6Init[]   =   { 1, 3, 1, 9, 1, 35, 75, 3, 81, 477, 131, 1383, 1377, 6857, 3863, 12583, 7855, 0 };
            const std::uint32_t dim7223JoeKuoD6Init[]   =   { 1, 3, 1, 3, 3, 11, 1, 167, 347, 317, 557, 3763, 7175, 13341, 759, 23275, 78039, 0 };
            const std::uint32_t dim7224JoeKuoD6Init[]   =   { 1, 3, 5, 11, 19, 53, 85, 139, 67, 757, 487, 919, 6001, 16031, 24959, 28013, 65771, 0 };
            const std::uint32_t dim7225JoeKuoD6Init[]   =   { 1, 1, 1, 1, 23, 9, 83, 55, 249, 305, 1305, 109, 5559, 5129, 30973, 19889, 6691, 0 };
            const std::uint32_t dim7226JoeKuoD6Init[]   =   { 1, 1, 1, 3, 21, 19, 85, 89, 213, 847, 861, 1651, 6613, 6001, 8157, 2555, 98673, 0 };
            const std::uint32_t dim7227JoeKuoD6Init[]   =   { 1, 1, 1, 15, 25, 15, 125, 133, 177, 295, 549, 1763, 2811, 4381, 1079, 7813, 87909, 0 };
            const std::uint32_t dim7228JoeKuoD6Init[]   =   { 1, 1, 1, 5, 5, 17, 25, 225, 353, 997, 1565, 2225, 7265, 16227, 28209, 9011, 97193, 0 };
            const std::uint32_t dim7229JoeKuoD6Init[]   =   { 1, 3, 7, 15, 13, 13, 35, 239, 331, 965, 1547, 1627, 6409, 7745, 30899, 36915, 59293, 0 };
            const std::uint32_t dim7230JoeKuoD6Init[]   =   { 1, 1, 1, 13, 27, 45, 23, 179, 193, 801, 381, 3783, 3551, 11855, 11041, 49911, 62101, 0 };
            const std::uint32_t dim7231JoeKuoD6Init[]   =   { 1, 1, 7, 3, 3, 31, 61, 5, 421, 939, 1637, 217, 389, 1797, 32141, 28817, 6997, 0 };
            const std::uint32_t dim7232JoeKuoD6Init[]   =   { 1, 3, 3, 5, 21, 31, 83, 65, 421, 577, 1137, 2561, 2943, 4171, 2803, 23325, 92315, 0 };
            const std::uint32_t dim7233JoeKuoD6Init[]   =   { 1, 1, 3, 3, 27, 33, 75, 81, 477, 3, 1903, 773, 5551, 10069, 7285, 58103, 98311, 0 };
            const std::uint32_t dim7234JoeKuoD6Init[]   =   { 1, 3, 7, 15, 1, 17, 95, 209, 65, 747, 1633, 581, 7395, 1393, 21795, 15735, 129757, 0 };
            const std::uint32_t dim7235JoeKuoD6Init[]   =   { 1, 3, 5, 3, 17, 3, 9, 131, 51, 693, 1571, 1865, 8137, 915, 13345, 35137, 59005, 0 };
            const std::uint32_t dim7236JoeKuoD6Init[]   =   { 1, 1, 3, 7, 23, 27, 61, 163, 449, 87, 717, 1075, 4309, 4887, 11741, 24549, 96729, 0 };
            const std::uint32_t dim7237JoeKuoD6Init[]   =   { 1, 3, 7, 13, 21, 5, 3, 97, 191, 999, 1193, 1215, 5907, 10491, 2281, 6455, 68625, 0 };
            const std::uint32_t dim7238JoeKuoD6Init[]   =   { 1, 1, 5, 7, 9, 9, 101, 5, 375, 137, 1473, 1265, 5307, 259, 20699, 25367, 129393, 0 };
            const std::uint32_t dim7239JoeKuoD6Init[]   =   { 1, 3, 7, 7, 21, 1, 77, 65, 23, 139, 945, 491, 1069, 253, 12335, 26861, 129467, 0 };
            const std::uint32_t dim7240JoeKuoD6Init[]   =   { 1, 1, 3, 9, 15, 33, 85, 225, 45, 311, 281, 1601, 7325, 12265, 2591, 51955, 130681, 0 };
            const std::uint32_t dim7241JoeKuoD6Init[]   =   { 1, 1, 1, 3, 27, 33, 17, 89, 495, 91, 527, 3347, 7883, 9481, 28731, 54729, 15265, 0 };
            const std::uint32_t dim7242JoeKuoD6Init[]   =   { 1, 1, 3, 3, 9, 47, 115, 161, 299, 493, 1857, 3597, 7175, 15603, 11523, 33837, 57557, 0 };
            const std::uint32_t dim7243JoeKuoD6Init[]   =   { 1, 3, 7, 3, 15, 47, 127, 195, 391, 869, 99, 429, 7125, 10413, 5063, 61845, 71843, 0 };
            const std::uint32_t dim7244JoeKuoD6Init[]   =   { 1, 3, 3, 1, 7, 31, 27, 69, 7, 83, 315, 2749, 5693, 13377, 28091, 13065, 111029, 0 };
            const std::uint32_t dim7245JoeKuoD6Init[]   =   { 1, 1, 3, 15, 15, 45, 125, 229, 459, 611, 1167, 3375, 3587, 81, 9275, 45327, 39749, 0 };
            const std::uint32_t dim7246JoeKuoD6Init[]   =   { 1, 3, 7, 11, 9, 3, 43, 161, 221, 209, 51, 1475, 3577, 13973, 15285, 35553, 83935, 0 };
            const std::uint32_t dim7247JoeKuoD6Init[]   =   { 1, 1, 7, 9, 15, 55, 25, 119, 39, 537, 317, 1331, 2161, 1791, 19221, 63459, 124595, 0 };
            const std::uint32_t dim7248JoeKuoD6Init[]   =   { 1, 1, 1, 11, 9, 7, 113, 187, 295, 67, 1795, 113, 119, 9127, 32119, 7719, 67591, 0 };
            const std::uint32_t dim7249JoeKuoD6Init[]   =   { 1, 3, 7, 13, 1, 53, 17, 19, 331, 711, 359, 2945, 5847, 7237, 23617, 17411, 2203, 0 };
            const std::uint32_t dim7250JoeKuoD6Init[]   =   { 1, 3, 3, 7, 21, 63, 115, 159, 225, 161, 1255, 2381, 7411, 95, 1625, 30493, 56685, 0 };
            const std::uint32_t dim7251JoeKuoD6Init[]   =   { 1, 1, 5, 9, 13, 57, 5, 107, 195, 271, 677, 2081, 6027, 11091, 14171, 19007, 102119, 0 };
            const std::uint32_t dim7252JoeKuoD6Init[]   =   { 1, 3, 3, 3, 19, 13, 31, 155, 209, 89, 955, 523, 615, 5319, 16079, 9289, 49135, 0 };
            const std::uint32_t dim7253JoeKuoD6Init[]   =   { 1, 3, 1, 13, 1, 31, 69, 143, 329, 813, 635, 891, 2967, 5563, 19643, 35813, 14345, 0 };
            const std::uint32_t dim7254JoeKuoD6Init[]   =   { 1, 1, 5, 5, 17, 47, 97, 49, 123, 997, 15, 3685, 3925, 4973, 11195, 17115, 63709, 0 };
            const std::uint32_t dim7255JoeKuoD6Init[]   =   { 1, 1, 7, 13, 13, 17, 99, 149, 309, 281, 329, 905, 6487, 4495, 31831, 24413, 26431, 0 };
            const std::uint32_t dim7256JoeKuoD6Init[]   =   { 1, 1, 5, 5, 5, 47, 113, 115, 61, 157, 955, 2323, 4445, 229, 24049, 14753, 15189, 0 };
            const std::uint32_t dim7257JoeKuoD6Init[]   =   { 1, 3, 7, 15, 25, 21, 13, 137, 377, 45, 629, 1339, 8037, 5073, 24741, 48589, 28953, 0 };
            const std::uint32_t dim7258JoeKuoD6Init[]   =   { 1, 3, 3, 9, 3, 41, 7, 101, 333, 59, 1213, 1871, 3993, 11261, 4403, 42785, 58753, 0 };
            const std::uint32_t dim7259JoeKuoD6Init[]   =   { 1, 3, 1, 7, 5, 33, 87, 73, 317, 575, 1459, 905, 1033, 14179, 19595, 30269, 103853, 0 };
            const std::uint32_t dim7260JoeKuoD6Init[]   =   { 1, 1, 1, 1, 19, 49, 63, 181, 227, 401, 695, 1811, 2383, 3835, 14379, 30685, 114731, 0 };
            const std::uint32_t dim7261JoeKuoD6Init[]   =   { 1, 1, 5, 15, 9, 41, 35, 91, 357, 659, 155, 3725, 6509, 405, 25449, 37719, 6013, 0 };
            const std::uint32_t dim7262JoeKuoD6Init[]   =   { 1, 1, 7, 3, 11, 59, 33, 151, 291, 393, 741, 3961, 2787, 993, 10361, 11737, 42047, 0 };
            const std::uint32_t dim7263JoeKuoD6Init[]   =   { 1, 3, 7, 3, 15, 15, 55, 59, 419, 203, 55, 801, 2719, 15487, 13213, 58473, 50315, 0 };
            const std::uint32_t dim7264JoeKuoD6Init[]   =   { 1, 3, 7, 13, 17, 21, 113, 111, 159, 163, 711, 1135, 1133, 15519, 30515, 55777, 25025, 0 };
            const std::uint32_t dim7265JoeKuoD6Init[]   =   { 1, 1, 3, 5, 13, 25, 23, 3, 93, 873, 559, 1815, 3381, 5311, 14365, 34349, 17333, 0 };
            const std::uint32_t dim7266JoeKuoD6Init[]   =   { 1, 3, 5, 7, 15, 43, 85, 33, 23, 903, 1247, 3279, 1393, 12059, 19251, 19389, 5097, 0 };
            const std::uint32_t dim7267JoeKuoD6Init[]   =   { 1, 3, 1, 11, 21, 59, 3, 153, 403, 95, 1939, 2679, 419, 9035, 31219, 2897, 15727, 0 };
            const std::uint32_t dim7268JoeKuoD6Init[]   =   { 1, 3, 5, 1, 11, 21, 35, 169, 453, 15, 791, 3931, 1021, 16321, 6033, 10639, 16173, 0 };
            const std::uint32_t dim7269JoeKuoD6Init[]   =   { 1, 3, 1, 11, 7, 57, 39, 61, 381, 465, 451, 2863, 575, 5597, 31041, 8625, 82373, 0 };
            const std::uint32_t dim7270JoeKuoD6Init[]   =   { 1, 1, 3, 5, 13, 5, 63, 1, 75, 245, 1305, 285, 3367, 10107, 5853, 35275, 128255, 0 };
            const std::uint32_t dim7271JoeKuoD6Init[]   =   { 1, 1, 1, 3, 1, 57, 21, 91, 139, 669, 765, 1867, 2153, 10347, 26119, 35517, 4725, 0 };
            const std::uint32_t dim7272JoeKuoD6Init[]   =   { 1, 3, 5, 1, 21, 41, 59, 247, 473, 1015, 975, 485, 2161, 11941, 10341, 35245, 55587, 0 };
            const std::uint32_t dim7273JoeKuoD6Init[]   =   { 1, 1, 5, 9, 7, 59, 33, 149, 97, 619, 393, 3613, 6037, 10895, 19461, 15975, 47919, 0 };
            const std::uint32_t dim7274JoeKuoD6Init[]   =   { 1, 3, 3, 15, 7, 17, 95, 13, 147, 361, 915, 2585, 4483, 3159, 12255, 44685, 116163, 0 };
            const std::uint32_t dim7275JoeKuoD6Init[]   =   { 1, 3, 1, 15, 27, 31, 75, 31, 423, 233, 1453, 2815, 3633, 6531, 25721, 29649, 80645, 0 };
            const std::uint32_t dim7276JoeKuoD6Init[]   =   { 1, 3, 3, 3, 19, 7, 73, 33, 163, 495, 1483, 2277, 6455, 6523, 9331, 21869, 52175, 0 };
            const std::uint32_t dim7277JoeKuoD6Init[]   =   { 1, 3, 5, 13, 5, 1, 63, 35, 335, 189, 713, 2997, 3277, 10049, 4681, 16753, 17107, 0 };
            const std::uint32_t dim7278JoeKuoD6Init[]   =   { 1, 3, 5, 9, 3, 55, 29, 171, 395, 585, 671, 1875, 4449, 12895, 5455, 11023, 106189, 0 };
            const std::uint32_t dim7279JoeKuoD6Init[]   =   { 1, 3, 5, 3, 25, 53, 33, 169, 109, 285, 787, 861, 5549, 5171, 15293, 2977, 14559, 0 };
            const std::uint32_t dim7280JoeKuoD6Init[]   =   { 1, 3, 7, 1, 21, 25, 97, 115, 1, 999, 1033, 3471, 129, 16093, 495, 16859, 34615, 0 };
            const std::uint32_t dim7281JoeKuoD6Init[]   =   { 1, 3, 5, 9, 13, 5, 109, 41, 57, 957, 231, 3771, 2917, 15649, 8869, 14857, 64943, 0 };
            const std::uint32_t dim7282JoeKuoD6Init[]   =   { 1, 1, 7, 7, 21, 41, 101, 59, 167, 441, 997, 2951, 7891, 16325, 12669, 53829, 100705, 0 };
            const std::uint32_t dim7283JoeKuoD6Init[]   =   { 1, 1, 7, 9, 19, 59, 23, 141, 193, 237, 1067, 1823, 3351, 3239, 3135, 9275, 37069, 0 };
            const std::uint32_t dim7284JoeKuoD6Init[]   =   { 1, 3, 3, 9, 3, 17, 95, 73, 19, 231, 779, 3065, 2245, 2967, 24971, 62589, 16729, 0 };
            const std::uint32_t dim7285JoeKuoD6Init[]   =   { 1, 3, 3, 13, 25, 19, 117, 147, 443, 123, 157, 2037, 327, 14715, 5693, 54641, 33325, 0 };
            const std::uint32_t dim7286JoeKuoD6Init[]   =   { 1, 3, 1, 9, 21, 21, 21, 125, 49, 787, 767, 2831, 511, 2461, 31537, 27155, 44053, 0 };
            const std::uint32_t dim7287JoeKuoD6Init[]   =   { 1, 3, 7, 9, 31, 19, 125, 67, 119, 465, 287, 1869, 3979, 15723, 21069, 8581, 66939, 0 };
            const std::uint32_t dim7288JoeKuoD6Init[]   =   { 1, 1, 1, 11, 7, 37, 123, 237, 353, 499, 113, 3829, 217, 4751, 7385, 20343, 83699, 0 };
            const std::uint32_t dim7289JoeKuoD6Init[]   =   { 1, 3, 7, 13, 9, 3, 53, 27, 487, 87, 35, 2645, 3481, 14409, 27875, 31695, 78489, 0 };
            const std::uint32_t dim7290JoeKuoD6Init[]   =   { 1, 3, 3, 13, 9, 43, 67, 51, 153, 83, 591, 1991, 1787, 11973, 7273, 34801, 47199, 0 };
            const std::uint32_t dim7291JoeKuoD6Init[]   =   { 1, 3, 7, 1, 15, 53, 71, 11, 205, 853, 2011, 581, 1281, 7819, 23083, 33731, 74951, 0 };
            const std::uint32_t dim7292JoeKuoD6Init[]   =   { 1, 1, 5, 5, 17, 63, 109, 219, 225, 997, 1251, 3287, 1441, 13489, 22723, 45191, 50249, 0 };
            const std::uint32_t dim7293JoeKuoD6Init[]   =   { 1, 1, 5, 3, 13, 1, 43, 53, 293, 685, 1369, 1515, 7479, 3233, 20007, 65235, 102467, 0 };
            const std::uint32_t dim7294JoeKuoD6Init[]   =   { 1, 3, 5, 7, 29, 45, 63, 45, 219, 445, 2047, 317, 7553, 325, 1465, 949, 35163, 0 };
            const std::uint32_t dim7295JoeKuoD6Init[]   =   { 1, 1, 3, 9, 7, 31, 73, 211, 501, 233, 1495, 701, 5857, 10763, 9743, 10289, 23801, 0 };
            const std::uint32_t dim7296JoeKuoD6Init[]   =   { 1, 3, 7, 3, 23, 47, 99, 61, 179, 833, 1425, 1275, 4467, 4367, 5567, 23513, 68677, 0 };
            const std::uint32_t dim7297JoeKuoD6Init[]   =   { 1, 1, 5, 5, 27, 33, 119, 229, 329, 51, 1025, 3167, 3405, 4039, 4135, 6655, 43771, 0 };
            const std::uint32_t dim7298JoeKuoD6Init[]   =   { 1, 3, 7, 15, 5, 49, 91, 55, 425, 15, 2003, 1571, 3539, 10375, 29645, 5889, 51887, 0 };
            const std::uint32_t dim7299JoeKuoD6Init[]   =   { 1, 1, 7, 3, 13, 55, 85, 91, 181, 723, 1941, 75, 4443, 11507, 7027, 14189, 50685, 0 };
            const std::uint32_t dim7300JoeKuoD6Init[]   =   { 1, 3, 5, 5, 29, 49, 13, 3, 97, 165, 41, 3039, 3325, 2161, 775, 38501, 42381, 0 };
            const std::uint32_t dim7301JoeKuoD6Init[]   =   { 1, 1, 5, 11, 9, 57, 47, 109, 9, 585, 375, 1839, 937, 6877, 29847, 60163, 103081, 0 };
            const std::uint32_t dim7302JoeKuoD6Init[]   =   { 1, 1, 3, 13, 5, 47, 11, 195, 253, 235, 275, 2313, 163, 14683, 5681, 13381, 84553, 0 };
            const std::uint32_t dim7303JoeKuoD6Init[]   =   { 1, 3, 3, 15, 15, 1, 93, 157, 437, 557, 307, 1179, 6857, 3101, 16723, 50579, 69603, 0 };
            const std::uint32_t dim7304JoeKuoD6Init[]   =   { 1, 1, 5, 9, 11, 29, 23, 219, 337, 689, 1155, 2007, 6853, 6749, 20127, 13199, 48433, 0 };
            const std::uint32_t dim7305JoeKuoD6Init[]   =   { 1, 1, 1, 13, 1, 61, 73, 213, 335, 539, 903, 2719, 775, 2775, 29109, 33367, 3281, 0 };
            const std::uint32_t dim7306JoeKuoD6Init[]   =   { 1, 3, 1, 5, 15, 31, 65, 231, 439, 623, 1871, 2299, 5365, 10333, 9147, 2781, 63813, 0 };
            const std::uint32_t dim7307JoeKuoD6Init[]   =   { 1, 1, 3, 1, 1, 25, 23, 229, 173, 279, 181, 1299, 2893, 15475, 12473, 46097, 123387, 0 };
            const std::uint32_t dim7308JoeKuoD6Init[]   =   { 1, 1, 7, 13, 7, 43, 17, 187, 467, 113, 1293, 2013, 6091, 14621, 22195, 24079, 45379, 0 };
            const std::uint32_t dim7309JoeKuoD6Init[]   =   { 1, 3, 1, 7, 1, 7, 119, 159, 377, 11, 705, 2853, 3767, 13739, 23375, 25563, 73987, 0 };
            const std::uint32_t dim7310JoeKuoD6Init[]   =   { 1, 1, 3, 15, 21, 13, 111, 119, 401, 1005, 777, 1699, 2431, 15139, 27887, 28415, 71519, 0 };
            const std::uint32_t dim7311JoeKuoD6Init[]   =   { 1, 1, 7, 9, 1, 49, 19, 171, 297, 77, 1343, 1249, 5769, 13889, 21401, 24915, 17641, 0 };
            const std::uint32_t dim7312JoeKuoD6Init[]   =   { 1, 1, 7, 11, 31, 45, 51, 231, 123, 817, 13, 791, 6235, 2787, 475, 1717, 5071, 0 };
            const std::uint32_t dim7313JoeKuoD6Init[]   =   { 1, 3, 3, 13, 5, 9, 21, 129, 253, 731, 785, 2275, 7343, 7841, 5477, 8973, 101033, 0 };
            const std::uint32_t dim7314JoeKuoD6Init[]   =   { 1, 1, 7, 13, 23, 1, 119, 221, 293, 709, 2031, 3019, 1529, 2007, 10823, 43193, 82661, 0 };
            const std::uint32_t dim7315JoeKuoD6Init[]   =   { 1, 3, 1, 11, 29, 29, 87, 79, 415, 679, 1899, 3453, 7355, 8627, 28225, 41857, 106645, 0 };
            const std::uint32_t dim7316JoeKuoD6Init[]   =   { 1, 1, 5, 15, 9, 13, 21, 241, 491, 927, 999, 2131, 3501, 11063, 28595, 54691, 21297, 0 };
            const std::uint32_t dim7317JoeKuoD6Init[]   =   { 1, 1, 1, 3, 5, 41, 85, 89, 483, 309, 791, 825, 3043, 2715, 16573, 6551, 77875, 0 };
            const std::uint32_t dim7318JoeKuoD6Init[]   =   { 1, 3, 1, 1, 25, 21, 107, 123, 79, 1019, 821, 1251, 4943, 1429, 17843, 37013, 53285, 0 };
            const std::uint32_t dim7319JoeKuoD6Init[]   =   { 1, 1, 5, 3, 7, 5, 35, 123, 445, 315, 627, 2543, 1261, 13737, 15991, 36591, 18309, 0 };
            const std::uint32_t dim7320JoeKuoD6Init[]   =   { 1, 3, 3, 5, 25, 43, 65, 249, 309, 1023, 737, 1933, 4735, 7725, 12063, 53023, 126677, 0 };
            const std::uint32_t dim7321JoeKuoD6Init[]   =   { 1, 3, 1, 9, 13, 37, 77, 61, 179, 275, 277, 1431, 2869, 14563, 665, 60553, 7661, 0 };
            const std::uint32_t dim7322JoeKuoD6Init[]   =   { 1, 3, 5, 3, 29, 1, 127, 73, 363, 311, 1591, 3863, 6481, 4725, 8287, 61311, 39011, 0 };
            const std::uint32_t dim7323JoeKuoD6Init[]   =   { 1, 3, 1, 7, 13, 23, 115, 215, 385, 563, 1033, 2343, 5023, 11013, 12131, 26997, 48645, 0 };
            const std::uint32_t dim7324JoeKuoD6Init[]   =   { 1, 1, 5, 13, 3, 59, 41, 155, 263, 507, 1175, 2967, 7929, 8237, 11841, 15365, 51881, 0 };
            const std::uint32_t dim7325JoeKuoD6Init[]   =   { 1, 1, 3, 11, 19, 35, 89, 115, 121, 315, 1697, 2121, 1867, 6865, 23639, 26525, 44687, 0 };
            const std::uint32_t dim7326JoeKuoD6Init[]   =   { 1, 3, 5, 15, 9, 5, 125, 183, 149, 447, 309, 1743, 6089, 369, 16153, 63799, 57657, 0 };
            const std::uint32_t dim7327JoeKuoD6Init[]   =   { 1, 1, 1, 7, 7, 39, 89, 139, 457, 741, 1613, 2883, 5057, 12495, 18669, 55469, 97941, 0 };
            const std::uint32_t dim7328JoeKuoD6Init[]   =   { 1, 1, 5, 7, 29, 39, 97, 9, 481, 667, 1353, 3387, 2813, 16205, 8353, 22121, 92965, 0 };
            const std::uint32_t dim7329JoeKuoD6Init[]   =   { 1, 3, 7, 9, 11, 55, 79, 159, 349, 717, 829, 3157, 1457, 6199, 5861, 2553, 20387, 0 };
            const std::uint32_t dim7330JoeKuoD6Init[]   =   { 1, 1, 1, 11, 3, 51, 113, 53, 287, 109, 1717, 2405, 7207, 4473, 11145, 2549, 591, 0 };
            const std::uint32_t dim7331JoeKuoD6Init[]   =   { 1, 1, 3, 13, 3, 61, 31, 141, 217, 487, 299, 2755, 3389, 10053, 1105, 21129, 74203, 0 };
            const std::uint32_t dim7332JoeKuoD6Init[]   =   { 1, 1, 1, 3, 11, 55, 7, 113, 413, 449, 787, 3279, 5123, 16025, 15005, 12175, 6795, 0 };
            const std::uint32_t dim7333JoeKuoD6Init[]   =   { 1, 3, 1, 1, 25, 23, 107, 191, 3, 3, 49, 1083, 3275, 10385, 7989, 53739, 25505, 0 };
            const std::uint32_t dim7334JoeKuoD6Init[]   =   { 1, 1, 5, 13, 7, 17, 59, 13, 471, 147, 1627, 2119, 3555, 15555, 10333, 49363, 80959, 0 };
            const std::uint32_t dim7335JoeKuoD6Init[]   =   { 1, 1, 1, 15, 23, 33, 61, 191, 207, 939, 45, 2781, 71, 9661, 28433, 13089, 76419, 0 };
            const std::uint32_t dim7336JoeKuoD6Init[]   =   { 1, 3, 3, 7, 29, 47, 111, 19, 315, 381, 851, 1303, 2627, 6255, 30369, 37723, 12949, 0 };
            const std::uint32_t dim7337JoeKuoD6Init[]   =   { 1, 1, 1, 13, 31, 43, 3, 193, 5, 99, 769, 2523, 1949, 129, 9693, 60535, 67059, 0 };
            const std::uint32_t dim7338JoeKuoD6Init[]   =   { 1, 1, 3, 15, 5, 33, 73, 149, 253, 985, 863, 1551, 4369, 5911, 8269, 35463, 117055, 0 };
            const std::uint32_t dim7339JoeKuoD6Init[]   =   { 1, 3, 1, 5, 27, 57, 3, 105, 253, 731, 119, 3287, 613, 4627, 22003, 56027, 123005, 0 };
            const std::uint32_t dim7340JoeKuoD6Init[]   =   { 1, 1, 3, 3, 27, 47, 67, 147, 495, 865, 1233, 3707, 2511, 2951, 7367, 15625, 86417, 0 };
            const std::uint32_t dim7341JoeKuoD6Init[]   =   { 1, 1, 7, 1, 7, 7, 13, 255, 457, 529, 953, 1481, 5565, 12495, 4723, 41615, 121829, 0 };
            const std::uint32_t dim7342JoeKuoD6Init[]   =   { 1, 3, 5, 11, 1, 51, 91, 153, 323, 609, 1353, 2995, 4035, 13835, 28619, 46217, 4967, 0 };
            const std::uint32_t dim7343JoeKuoD6Init[]   =   { 1, 1, 5, 7, 25, 59, 81, 101, 185, 709, 1249, 2285, 6579, 8655, 17563, 9707, 63845, 0 };
            const std::uint32_t dim7344JoeKuoD6Init[]   =   { 1, 3, 3, 9, 31, 25, 17, 19, 111, 627, 1187, 2621, 6529, 9457, 25027, 18069, 47559, 0 };
            const std::uint32_t dim7345JoeKuoD6Init[]   =   { 1, 3, 7, 15, 7, 15, 103, 201, 391, 1023, 817, 535, 2713, 1317, 13469, 56043, 70847, 0 };
            const std::uint32_t dim7346JoeKuoD6Init[]   =   { 1, 1, 3, 7, 17, 57, 35, 99, 439, 367, 27, 2695, 3519, 8337, 14047, 58489, 69, 0 };
            const std::uint32_t dim7347JoeKuoD6Init[]   =   { 1, 1, 1, 3, 17, 23, 71, 189, 57, 39, 715, 1779, 3081, 14657, 21895, 59203, 31005, 0 };
            const std::uint32_t dim7348JoeKuoD6Init[]   =   { 1, 1, 7, 13, 1, 47, 69, 159, 353, 517, 271, 973, 5077, 15707, 11095, 19671, 3389, 0 };
            const std::uint32_t dim7349JoeKuoD6Init[]   =   { 1, 1, 7, 13, 25, 55, 115, 21, 43, 939, 1697, 101, 4751, 1993, 2389, 28353, 45251, 0 };
            const std::uint32_t dim7350JoeKuoD6Init[]   =   { 1, 3, 1, 15, 11, 57, 17, 49, 121, 419, 909, 121, 5047, 4235, 13051, 21529, 42097, 0 };
            const std::uint32_t dim7351JoeKuoD6Init[]   =   { 1, 1, 1, 3, 19, 37, 31, 233, 251, 175, 929, 1527, 7527, 3605, 17075, 61053, 56235, 0 };
            const std::uint32_t dim7352JoeKuoD6Init[]   =   { 1, 1, 1, 3, 9, 5, 117, 131, 251, 475, 1695, 1381, 2445, 5921, 14921, 937, 80791, 0 };
            const std::uint32_t dim7353JoeKuoD6Init[]   =   { 1, 1, 3, 9, 11, 5, 31, 215, 37, 567, 1537, 2183, 3291, 1601, 14025, 48807, 7243, 0 };
            const std::uint32_t dim7354JoeKuoD6Init[]   =   { 1, 3, 1, 9, 7, 13, 81, 249, 321, 473, 1419, 3977, 7037, 14191, 10865, 56131, 43225, 0 };
            const std::uint32_t dim7355JoeKuoD6Init[]   =   { 1, 1, 1, 13, 15, 23, 31, 69, 449, 491, 1461, 729, 7955, 4003, 16817, 37273, 72025, 0 };
            const std::uint32_t dim7356JoeKuoD6Init[]   =   { 1, 1, 5, 13, 7, 41, 93, 169, 347, 1013, 301, 2813, 1455, 13187, 10769, 60807, 46333, 0 };
            const std::uint32_t dim7357JoeKuoD6Init[]   =   { 1, 1, 5, 3, 23, 15, 1, 161, 29, 35, 415, 235, 93, 14543, 29585, 29657, 36489, 0 };
            const std::uint32_t dim7358JoeKuoD6Init[]   =   { 1, 3, 1, 3, 31, 63, 39, 235, 153, 549, 43, 147, 2317, 3537, 25561, 58287, 58725, 0 };
            const std::uint32_t dim7359JoeKuoD6Init[]   =   { 1, 1, 3, 5, 5, 11, 59, 97, 349, 307, 501, 1701, 4243, 13717, 17419, 23387, 29533, 0 };
            const std::uint32_t dim7360JoeKuoD6Init[]   =   { 1, 3, 1, 7, 7, 19, 33, 243, 67, 353, 2023, 3111, 7173, 10979, 28117, 40175, 45337, 0 };
            const std::uint32_t dim7361JoeKuoD6Init[]   =   { 1, 1, 1, 5, 15, 59, 55, 135, 107, 543, 1743, 2695, 3293, 111, 32629, 8249, 52273, 0 };
            const std::uint32_t dim7362JoeKuoD6Init[]   =   { 1, 3, 5, 13, 15, 57, 39, 79, 5, 451, 571, 1445, 1393, 2125, 31713, 59655, 20897, 0 };
            const std::uint32_t dim7363JoeKuoD6Init[]   =   { 1, 1, 3, 11, 29, 61, 1, 37, 173, 513, 1779, 2649, 3289, 4679, 2039, 47587, 28973, 0 };
            const std::uint32_t dim7364JoeKuoD6Init[]   =   { 1, 1, 5, 5, 15, 19, 17, 143, 387, 359, 275, 625, 7383, 15537, 10311, 40005, 20729, 0 };
            const std::uint32_t dim7365JoeKuoD6Init[]   =   { 1, 1, 3, 9, 7, 23, 71, 179, 85, 447, 345, 3459, 2857, 8331, 5489, 62207, 64933, 0 };
            const std::uint32_t dim7366JoeKuoD6Init[]   =   { 1, 1, 1, 1, 11, 61, 47, 131, 213, 611, 701, 713, 1269, 9563, 25223, 50697, 88679, 0 };
            const std::uint32_t dim7367JoeKuoD6Init[]   =   { 1, 1, 5, 15, 21, 5, 77, 59, 455, 243, 459, 2809, 13, 9325, 32047, 3939, 48389, 0 };
            const std::uint32_t dim7368JoeKuoD6Init[]   =   { 1, 3, 7, 1, 21, 53, 111, 225, 407, 119, 713, 3635, 1539, 15321, 29827, 36069, 74483, 0 };
            const std::uint32_t dim7369JoeKuoD6Init[]   =   { 1, 1, 5, 13, 7, 45, 75, 43, 191, 715, 169, 759, 33, 11329, 1069, 36103, 28055, 0 };
            const std::uint32_t dim7370JoeKuoD6Init[]   =   { 1, 3, 7, 5, 7, 13, 7, 35, 27, 391, 517, 1439, 5699, 1067, 23857, 7293, 66167, 0 };
            const std::uint32_t dim7371JoeKuoD6Init[]   =   { 1, 1, 7, 11, 3, 31, 1, 83, 299, 345, 65, 669, 1529, 7569, 28959, 50561, 69493, 0 };
            const std::uint32_t dim7372JoeKuoD6Init[]   =   { 1, 3, 1, 5, 25, 25, 43, 149, 83, 225, 1589, 1691, 7777, 773, 10421, 49523, 23533, 0 };
            const std::uint32_t dim7373JoeKuoD6Init[]   =   { 1, 1, 5, 11, 25, 29, 81, 11, 497, 43, 951, 2551, 821, 13805, 12315, 61299, 81397, 0 };
            const std::uint32_t dim7374JoeKuoD6Init[]   =   { 1, 3, 1, 9, 29, 23, 109, 123, 235, 255, 1519, 3289, 7761, 14575, 11851, 1719, 51655, 0 };
            const std::uint32_t dim7375JoeKuoD6Init[]   =   { 1, 3, 5, 15, 21, 49, 13, 43, 87, 517, 687, 1457, 1501, 15959, 31907, 13771, 69379, 0 };
            const std::uint32_t dim7376JoeKuoD6Init[]   =   { 1, 1, 5, 3, 21, 11, 87, 9, 343, 317, 845, 1663, 7933, 14063, 24915, 31487, 17445, 0 };
            const std::uint32_t dim7377JoeKuoD6Init[]   =   { 1, 1, 3, 13, 21, 31, 87, 99, 185, 333, 993, 3899, 971, 2851, 23643, 195, 66957, 0 };
            const std::uint32_t dim7378JoeKuoD6Init[]   =   { 1, 1, 1, 15, 19, 47, 23, 1, 67, 57, 165, 3903, 421, 10561, 11621, 13815, 10349, 0 };
            const std::uint32_t dim7379JoeKuoD6Init[]   =   { 1, 3, 5, 11, 9, 19, 73, 17, 229, 913, 459, 3809, 2667, 9775, 3693, 52945, 90837, 0 };
            const std::uint32_t dim7380JoeKuoD6Init[]   =   { 1, 1, 5, 15, 3, 25, 109, 131, 507, 637, 1615, 859, 6785, 14891, 24801, 39095, 79557, 0 };
            const std::uint32_t dim7381JoeKuoD6Init[]   =   { 1, 1, 5, 7, 1, 51, 71, 251, 19, 799, 835, 1119, 2349, 15083, 16509, 55621, 123501, 0 };
            const std::uint32_t dim7382JoeKuoD6Init[]   =   { 1, 3, 5, 9, 13, 39, 127, 1, 233, 37, 735, 3307, 5163, 4529, 5961, 12893, 103641, 0 };
            const std::uint32_t dim7383JoeKuoD6Init[]   =   { 1, 1, 7, 5, 23, 15, 49, 123, 511, 201, 2025, 289, 3847, 15755, 24279, 52543, 42017, 0 };
            const std::uint32_t dim7384JoeKuoD6Init[]   =   { 1, 1, 5, 3, 9, 61, 19, 37, 3, 361, 1065, 2971, 2517, 1259, 27359, 3823, 60181, 0 };
            const std::uint32_t dim7385JoeKuoD6Init[]   =   { 1, 3, 1, 7, 15, 17, 57, 249, 57, 979, 147, 2407, 2579, 3159, 8467, 8433, 72873, 0 };
            const std::uint32_t dim7386JoeKuoD6Init[]   =   { 1, 1, 3, 1, 25, 7, 47, 117, 449, 321, 143, 3867, 165, 7961, 27597, 10033, 2437, 0 };
            const std::uint32_t dim7387JoeKuoD6Init[]   =   { 1, 3, 5, 13, 19, 49, 1, 83, 477, 549, 509, 2911, 1559, 14017, 10469, 62171, 82829, 0 };
            const std::uint32_t dim7388JoeKuoD6Init[]   =   { 1, 3, 3, 7, 27, 21, 15, 63, 31, 45, 1223, 3903, 5469, 11983, 29627, 27453, 32019, 0 };
            const std::uint32_t dim7389JoeKuoD6Init[]   =   { 1, 1, 7, 7, 9, 9, 7, 77, 349, 467, 61, 3465, 6921, 15761, 15179, 38649, 2469, 0 };
            const std::uint32_t dim7390JoeKuoD6Init[]   =   { 1, 3, 1, 13, 9, 59, 55, 67, 271, 617, 643, 4071, 7963, 8153, 5121, 43917, 26219, 0 };
            const std::uint32_t dim7391JoeKuoD6Init[]   =   { 1, 1, 3, 7, 29, 21, 63, 103, 327, 623, 931, 1511, 3125, 229, 28949, 61315, 72667, 0 };
            const std::uint32_t dim7392JoeKuoD6Init[]   =   { 1, 3, 7, 1, 19, 37, 49, 63, 403, 885, 161, 121, 1447, 9227, 15019, 50049, 26939, 0 };
            const std::uint32_t dim7393JoeKuoD6Init[]   =   { 1, 3, 3, 3, 23, 57, 95, 79, 485, 173, 93, 835, 7161, 11247, 3485, 5759, 36393, 0 };
            const std::uint32_t dim7394JoeKuoD6Init[]   =   { 1, 3, 7, 13, 23, 33, 5, 97, 235, 531, 313, 2925, 2223, 847, 18591, 15477, 3129, 0 };
            const std::uint32_t dim7395JoeKuoD6Init[]   =   { 1, 1, 3, 13, 25, 25, 101, 183, 477, 947, 1251, 2631, 7987, 13417, 23759, 55305, 123817, 0 };
            const std::uint32_t dim7396JoeKuoD6Init[]   =   { 1, 1, 5, 9, 27, 63, 49, 137, 179, 861, 33, 2375, 3827, 6485, 19689, 7867, 124429, 0 };
            const std::uint32_t dim7397JoeKuoD6Init[]   =   { 1, 3, 7, 3, 15, 43, 63, 103, 45, 947, 1837, 833, 7055, 7487, 19669, 12045, 78377, 0 };
            const std::uint32_t dim7398JoeKuoD6Init[]   =   { 1, 3, 5, 3, 29, 35, 57, 19, 471, 985, 1147, 741, 5403, 10057, 25375, 50889, 82719, 0 };
            const std::uint32_t dim7399JoeKuoD6Init[]   =   { 1, 3, 3, 1, 17, 19, 111, 13, 121, 821, 1831, 4043, 123, 9529, 1511, 10917, 105961, 0 };
            const std::uint32_t dim7400JoeKuoD6Init[]   =   { 1, 1, 3, 11, 1, 43, 23, 75, 345, 9, 1379, 2157, 5887, 1197, 14849, 17103, 91925, 0 };
            const std::uint32_t dim7401JoeKuoD6Init[]   =   { 1, 1, 3, 3, 19, 11, 1, 179, 343, 1023, 1801, 915, 255, 519, 5787, 32913, 43471, 0 };
            const std::uint32_t dim7402JoeKuoD6Init[]   =   { 1, 3, 5, 5, 3, 3, 3, 211, 461, 55, 851, 3165, 2903, 15077, 8537, 2037, 109057, 0 };
            const std::uint32_t dim7403JoeKuoD6Init[]   =   { 1, 1, 7, 15, 7, 7, 43, 249, 27, 511, 1369, 735, 6093, 12575, 26675, 21745, 117053, 0 };
            const std::uint32_t dim7404JoeKuoD6Init[]   =   { 1, 1, 5, 7, 21, 53, 45, 83, 415, 645, 325, 4027, 5181, 8485, 1917, 55623, 45203, 0 };
            const std::uint32_t dim7405JoeKuoD6Init[]   =   { 1, 1, 3, 15, 7, 1, 121, 221, 387, 403, 1877, 1671, 2113, 2379, 5667, 39867, 8079, 0 };
            const std::uint32_t dim7406JoeKuoD6Init[]   =   { 1, 1, 1, 7, 5, 29, 35, 77, 197, 661, 1859, 2539, 4045, 13497, 305, 44987, 31215, 0 };
            const std::uint32_t dim7407JoeKuoD6Init[]   =   { 1, 1, 5, 5, 13, 37, 13, 85, 287, 347, 579, 2283, 7911, 5463, 21141, 9035, 105067, 0 };
            const std::uint32_t dim7408JoeKuoD6Init[]   =   { 1, 1, 1, 9, 17, 17, 63, 97, 57, 629, 1917, 1133, 779, 12365, 17127, 52549, 18755, 0 };
            const std::uint32_t dim7409JoeKuoD6Init[]   =   { 1, 1, 7, 11, 7, 17, 65, 137, 485, 841, 653, 2921, 4935, 16273, 23333, 7399, 43129, 0 };
            const std::uint32_t dim7410JoeKuoD6Init[]   =   { 1, 3, 1, 11, 31, 55, 93, 225, 319, 35, 947, 1909, 7733, 8303, 20739, 55713, 6633, 0 };
            const std::uint32_t dim7411JoeKuoD6Init[]   =   { 1, 1, 1, 3, 11, 25, 1, 165, 305, 275, 607, 3845, 5203, 1989, 13803, 597, 39751, 0 };
            const std::uint32_t dim7412JoeKuoD6Init[]   =   { 1, 1, 5, 11, 31, 43, 83, 237, 453, 59, 457, 741, 411, 15895, 18891, 30133, 66767, 0 };
            const std::uint32_t dim7413JoeKuoD6Init[]   =   { 1, 3, 5, 11, 3, 23, 65, 81, 299, 527, 1057, 2731, 3839, 6023, 28887, 64929, 41405, 0 };
            const std::uint32_t dim7414JoeKuoD6Init[]   =   { 1, 3, 1, 1, 3, 5, 11, 169, 123, 957, 1495, 1717, 4079, 13239, 28339, 33677, 30591, 0 };
            const std::uint32_t dim7415JoeKuoD6Init[]   =   { 1, 1, 7, 15, 3, 1, 37, 245, 169, 273, 2039, 415, 6555, 13131, 11181, 62179, 36885, 0 };
            const std::uint32_t dim7416JoeKuoD6Init[]   =   { 1, 1, 3, 11, 1, 55, 19, 19, 425, 113, 1367, 2101, 5581, 985, 2475, 53983, 68999, 0 };
            const std::uint32_t dim7417JoeKuoD6Init[]   =   { 1, 1, 5, 9, 5, 33, 101, 193, 303, 579, 1265, 2791, 479, 12083, 17609, 31801, 113089, 0 };
            const std::uint32_t dim7418JoeKuoD6Init[]   =   { 1, 1, 3, 3, 17, 61, 59, 249, 81, 821, 1, 431, 5327, 8675, 23469, 15349, 67711, 0 };
            const std::uint32_t dim7419JoeKuoD6Init[]   =   { 1, 1, 7, 9, 31, 51, 89, 19, 469, 843, 561, 559, 4823, 7803, 31699, 44537, 56835, 0 };
            const std::uint32_t dim7420JoeKuoD6Init[]   =   { 1, 3, 7, 9, 11, 57, 27, 43, 469, 655, 433, 3081, 6719, 6651, 30823, 61503, 110711, 0 };
            const std::uint32_t dim7421JoeKuoD6Init[]   =   { 1, 3, 5, 11, 9, 53, 25, 147, 61, 533, 1369, 879, 7935, 13829, 26655, 17327, 52983, 0 };
            const std::uint32_t dim7422JoeKuoD6Init[]   =   { 1, 3, 7, 11, 15, 27, 97, 175, 435, 53, 75, 807, 549, 5277, 1831, 19421, 55669, 0 };
            const std::uint32_t dim7423JoeKuoD6Init[]   =   { 1, 1, 7, 15, 23, 5, 99, 133, 485, 587, 65, 2585, 7667, 2783, 19437, 52769, 1587, 0 };
            const std::uint32_t dim7424JoeKuoD6Init[]   =   { 1, 1, 7, 7, 13, 39, 111, 165, 489, 355, 1963, 333, 2993, 5233, 9173, 18951, 93737, 0 };
            const std::uint32_t dim7425JoeKuoD6Init[]   =   { 1, 1, 5, 7, 1, 29, 67, 135, 427, 91, 53, 3109, 3745, 9529, 17567, 42361, 84577, 0 };
            const std::uint32_t dim7426JoeKuoD6Init[]   =   { 1, 3, 5, 1, 31, 35, 59, 181, 87, 345, 1975, 781, 603, 16365, 19453, 9933, 112739, 0 };
            const std::uint32_t dim7427JoeKuoD6Init[]   =   { 1, 3, 3, 1, 31, 41, 127, 35, 263, 403, 1811, 383, 1523, 8477, 5973, 41569, 99309, 0 };
            const std::uint32_t dim7428JoeKuoD6Init[]   =   { 1, 3, 7, 7, 5, 25, 11, 201, 231, 679, 519, 2481, 7415, 12397, 21265, 49419, 13903, 0 };
            const std::uint32_t dim7429JoeKuoD6Init[]   =   { 1, 1, 7, 5, 1, 11, 63, 221, 327, 509, 419, 871, 7891, 11835, 11099, 10669, 43853, 0 };
            const std::uint32_t dim7430JoeKuoD6Init[]   =   { 1, 1, 5, 11, 19, 11, 37, 105, 265, 513, 1013, 707, 6083, 14571, 17573, 7645, 5363, 0 };
            const std::uint32_t dim7431JoeKuoD6Init[]   =   { 1, 1, 1, 13, 19, 19, 67, 93, 113, 509, 1013, 4037, 1939, 7015, 24487, 57183, 123463, 0 };
            const std::uint32_t dim7432JoeKuoD6Init[]   =   { 1, 1, 1, 1, 21, 17, 95, 25, 261, 1005, 685, 691, 4467, 14723, 24043, 32287, 19651, 0 };
            const std::uint32_t dim7433JoeKuoD6Init[]   =   { 1, 3, 1, 15, 15, 15, 57, 191, 27, 719, 229, 1977, 241, 9021, 21335, 30967, 81207, 0 };
            const std::uint32_t dim7434JoeKuoD6Init[]   =   { 1, 3, 1, 9, 23, 61, 103, 67, 361, 925, 811, 1007, 5707, 11479, 5907, 3897, 65141, 0 };
            const std::uint32_t dim7435JoeKuoD6Init[]   =   { 1, 3, 5, 9, 17, 61, 11, 15, 351, 715, 939, 2141, 4857, 8397, 9693, 26845, 120007, 0 };
            const std::uint32_t dim7436JoeKuoD6Init[]   =   { 1, 3, 1, 5, 19, 55, 99, 19, 291, 309, 287, 1969, 4341, 7579, 30909, 37277, 54927, 0 };
            const std::uint32_t dim7437JoeKuoD6Init[]   =   { 1, 3, 7, 3, 19, 29, 43, 163, 367, 753, 1733, 1463, 7927, 10671, 16817, 41229, 113887, 0 };
            const std::uint32_t dim7438JoeKuoD6Init[]   =   { 1, 3, 7, 1, 11, 51, 39, 207, 283, 73, 1423, 2473, 7593, 3581, 30179, 6369, 112217, 0 };
            const std::uint32_t dim7439JoeKuoD6Init[]   =   { 1, 1, 3, 15, 15, 25, 43, 5, 271, 611, 959, 537, 303, 3659, 18073, 8147, 81531, 0 };
            const std::uint32_t dim7440JoeKuoD6Init[]   =   { 1, 3, 7, 1, 27, 55, 77, 11, 367, 209, 1967, 3409, 935, 5309, 18857, 46225, 8367, 0 };
            const std::uint32_t dim7441JoeKuoD6Init[]   =   { 1, 1, 5, 11, 11, 63, 75, 73, 43, 869, 2021, 3285, 269, 9113, 32699, 2091, 17327, 0 };
            const std::uint32_t dim7442JoeKuoD6Init[]   =   { 1, 1, 5, 11, 9, 25, 31, 245, 109, 805, 1645, 3607, 817, 9571, 12767, 65441, 129977, 0 };
            const std::uint32_t dim7443JoeKuoD6Init[]   =   { 1, 3, 7, 5, 11, 61, 67, 223, 433, 387, 935, 1615, 7915, 6133, 24087, 55323, 100619, 0 };
            const std::uint32_t dim7444JoeKuoD6Init[]   =   { 1, 1, 1, 15, 25, 61, 7, 39, 311, 353, 183, 33, 2591, 4951, 31377, 9081, 9707, 0 };
            const std::uint32_t dim7445JoeKuoD6Init[]   =   { 1, 1, 3, 3, 1, 9, 65, 229, 185, 47, 1255, 1365, 2231, 6843, 26927, 27195, 60651, 0 };
            const std::uint32_t dim7446JoeKuoD6Init[]   =   { 1, 1, 7, 5, 7, 25, 91, 133, 159, 737, 1767, 3117, 7321, 6159, 3361, 27793, 33473, 0 };
            const std::uint32_t dim7447JoeKuoD6Init[]   =   { 1, 3, 7, 3, 11, 7, 5, 125, 369, 951, 1277, 65, 7703, 1817, 11773, 25657, 67045, 0 };
            const std::uint32_t dim7448JoeKuoD6Init[]   =   { 1, 1, 3, 9, 21, 27, 21, 41, 131, 605, 1, 119, 1553, 1361, 31973, 43135, 119321, 0 };
            const std::uint32_t dim7449JoeKuoD6Init[]   =   { 1, 3, 7, 1, 25, 63, 55, 173, 323, 403, 1401, 1367, 3455, 15335, 13045, 20759, 8309, 0 };
            const std::uint32_t dim7450JoeKuoD6Init[]   =   { 1, 1, 3, 5, 3, 61, 59, 7, 39, 439, 721, 2829, 3035, 2293, 32015, 28509, 104831, 0 };
            const std::uint32_t dim7451JoeKuoD6Init[]   =   { 1, 3, 5, 1, 29, 35, 71, 87, 351, 917, 1661, 547, 4501, 7107, 5493, 17833, 130729, 0 };
            const std::uint32_t dim7452JoeKuoD6Init[]   =   { 1, 1, 5, 5, 7, 5, 69, 57, 319, 595, 1749, 3789, 1437, 6327, 24089, 7387, 125109, 0 };
            const std::uint32_t dim7453JoeKuoD6Init[]   =   { 1, 3, 5, 9, 15, 53, 95, 59, 217, 37, 1561, 401, 5259, 4361, 1049, 3437, 30559, 0 };
            const std::uint32_t dim7454JoeKuoD6Init[]   =   { 1, 3, 7, 13, 15, 15, 107, 167, 475, 157, 1565, 2219, 1891, 1433, 11829, 43433, 48111, 0 };
            const std::uint32_t dim7455JoeKuoD6Init[]   =   { 1, 1, 1, 3, 11, 41, 25, 211, 243, 355, 1831, 2093, 2747, 2523, 9885, 9503, 120089, 0 };
            const std::uint32_t dim7456JoeKuoD6Init[]   =   { 1, 3, 7, 5, 11, 3, 1, 231, 243, 541, 341, 887, 3567, 14759, 26763, 35705, 29417, 0 };
            const std::uint32_t dim7457JoeKuoD6Init[]   =   { 1, 1, 7, 13, 17, 35, 117, 177, 81, 361, 1425, 2437, 6821, 1061, 15019, 19135, 106007, 0 };
            const std::uint32_t dim7458JoeKuoD6Init[]   =   { 1, 3, 3, 11, 19, 5, 39, 23, 367, 9, 879, 3583, 2527, 14375, 28359, 27393, 55041, 0 };
            const std::uint32_t dim7459JoeKuoD6Init[]   =   { 1, 1, 7, 11, 9, 41, 63, 125, 33, 337, 587, 3939, 2635, 4559, 1007, 38991, 35651, 0 };
            const std::uint32_t dim7460JoeKuoD6Init[]   =   { 1, 1, 3, 1, 19, 11, 83, 13, 227, 649, 415, 1661, 3285, 55, 3683, 22319, 2127, 0 };
            const std::uint32_t dim7461JoeKuoD6Init[]   =   { 1, 3, 7, 13, 19, 49, 113, 129, 83, 5, 19, 1095, 6561, 11049, 3805, 11355, 84265, 0 };
            const std::uint32_t dim7462JoeKuoD6Init[]   =   { 1, 3, 1, 9, 19, 41, 111, 193, 429, 319, 67, 1717, 1819, 12959, 31449, 21035, 113161, 0 };
            const std::uint32_t dim7463JoeKuoD6Init[]   =   { 1, 1, 5, 11, 19, 19, 115, 237, 145, 681, 1525, 2215, 7915, 15529, 7533, 45981, 85461, 0 };
            const std::uint32_t dim7464JoeKuoD6Init[]   =   { 1, 1, 1, 1, 25, 3, 73, 207, 15, 69, 43, 1643, 7707, 12505, 27101, 40735, 6091, 0 };
            const std::uint32_t dim7465JoeKuoD6Init[]   =   { 1, 1, 5, 11, 21, 61, 119, 7, 37, 147, 1379, 3165, 6555, 3867, 24027, 45161, 93015, 0 };
            const std::uint32_t dim7466JoeKuoD6Init[]   =   { 1, 1, 3, 9, 9, 25, 51, 125, 511, 209, 75, 2849, 2299, 2901, 25157, 13079, 67733, 0 };
            const std::uint32_t dim7467JoeKuoD6Init[]   =   { 1, 3, 7, 9, 31, 49, 99, 21, 89, 1, 1391, 1741, 2733, 7283, 12087, 9287, 39713, 0 };
            const std::uint32_t dim7468JoeKuoD6Init[]   =   { 1, 1, 5, 5, 1, 5, 89, 109, 499, 343, 431, 401, 2023, 5541, 16615, 40059, 119195, 0 };
            const std::uint32_t dim7469JoeKuoD6Init[]   =   { 1, 3, 5, 15, 27, 27, 9, 159, 395, 31, 865, 2793, 55, 10961, 23123, 63731, 54385, 0 };
            const std::uint32_t dim7470JoeKuoD6Init[]   =   { 1, 3, 7, 1, 11, 47, 123, 239, 399, 383, 1497, 4075, 4659, 2911, 2101, 8295, 115717, 0 };
            const std::uint32_t dim7471JoeKuoD6Init[]   =   { 1, 1, 3, 1, 11, 63, 125, 171, 65, 15, 349, 753, 2981, 6713, 6219, 14093, 78797, 0 };
            const std::uint32_t dim7472JoeKuoD6Init[]   =   { 1, 1, 1, 13, 9, 15, 1, 113, 221, 867, 1907, 103, 1411, 27, 22743, 377, 116907, 0 };
            const std::uint32_t dim7473JoeKuoD6Init[]   =   { 1, 3, 1, 5, 27, 5, 27, 245, 221, 575, 2009, 1561, 4263, 11843, 28331, 12865, 10483, 0 };
            const std::uint32_t dim7474JoeKuoD6Init[]   =   { 1, 3, 7, 9, 1, 51, 119, 241, 439, 913, 1191, 2343, 2055, 10247, 18283, 40175, 63321, 0 };
            const std::uint32_t dim7475JoeKuoD6Init[]   =   { 1, 1, 3, 15, 21, 59, 45, 151, 485, 293, 981, 3523, 7689, 2789, 5003, 62383, 126221, 0 };
            const std::uint32_t dim7476JoeKuoD6Init[]   =   { 1, 1, 1, 1, 13, 15, 39, 201, 405, 513, 1721, 2077, 5995, 2433, 20421, 12695, 20393, 0 };
            const std::uint32_t dim7477JoeKuoD6Init[]   =   { 1, 3, 5, 15, 11, 35, 113, 133, 187, 583, 577, 291, 7563, 12959, 9383, 44255, 81763, 0 };
            const std::uint32_t dim7478JoeKuoD6Init[]   =   { 1, 3, 7, 15, 9, 55, 57, 227, 189, 595, 1311, 1131, 1323, 11347, 12777, 50963, 13827, 0 };
            const std::uint32_t dim7479JoeKuoD6Init[]   =   { 1, 3, 5, 3, 11, 49, 77, 157, 107, 959, 761, 1457, 7121, 3027, 9269, 26291, 125261, 0 };
            const std::uint32_t dim7480JoeKuoD6Init[]   =   { 1, 1, 5, 9, 23, 53, 125, 211, 303, 433, 1103, 41, 2643, 5325, 11885, 23825, 80415, 0 };
            const std::uint32_t dim7481JoeKuoD6Init[]   =   { 1, 1, 7, 1, 29, 25, 51, 107, 209, 165, 707, 1855, 7429, 1583, 5941, 47509, 90105, 0 };
            const std::uint32_t dim7482JoeKuoD6Init[]   =   { 1, 1, 3, 3, 1, 15, 121, 165, 181, 259, 1949, 3049, 3545, 3093, 5967, 49207, 37129, 0 };
            const std::uint32_t dim7483JoeKuoD6Init[]   =   { 1, 1, 5, 13, 9, 59, 93, 87, 57, 343, 389, 1995, 4001, 11495, 12909, 13491, 61759, 0 };
            const std::uint32_t dim7484JoeKuoD6Init[]   =   { 1, 3, 1, 5, 11, 27, 27, 133, 459, 733, 1845, 1795, 4613, 3397, 12313, 52839, 129583, 0 };
            const std::uint32_t dim7485JoeKuoD6Init[]   =   { 1, 3, 5, 3, 19, 1, 7, 145, 255, 337, 1649, 1473, 4113, 4425, 12233, 55477, 69157, 0 };
            const std::uint32_t dim7486JoeKuoD6Init[]   =   { 1, 1, 3, 1, 25, 27, 93, 59, 415, 437, 25, 1565, 319, 8981, 2453, 53579, 45033, 0 };
            const std::uint32_t dim7487JoeKuoD6Init[]   =   { 1, 3, 7, 1, 27, 49, 47, 233, 341, 101, 2017, 2827, 8085, 237, 6363, 61139, 88903, 0 };
            const std::uint32_t dim7488JoeKuoD6Init[]   =   { 1, 1, 1, 5, 23, 47, 65, 251, 423, 957, 1751, 3541, 5405, 1335, 22703, 12587, 60201, 0 };
            const std::uint32_t dim7489JoeKuoD6Init[]   =   { 1, 1, 3, 3, 5, 51, 85, 195, 423, 519, 1797, 3821, 5915, 12257, 5377, 62733, 41197, 0 };
            const std::uint32_t dim7490JoeKuoD6Init[]   =   { 1, 3, 7, 15, 3, 47, 97, 1, 5, 175, 1449, 1609, 6873, 12017, 5579, 2665, 58389, 0 };
            const std::uint32_t dim7491JoeKuoD6Init[]   =   { 1, 3, 3, 15, 19, 37, 35, 29, 79, 767, 21, 1279, 1997, 11611, 14381, 35607, 127701, 0 };
            const std::uint32_t dim7492JoeKuoD6Init[]   =   { 1, 3, 7, 7, 7, 43, 47, 33, 69, 155, 703, 1373, 1589, 6997, 8627, 50647, 16989, 0 };
            const std::uint32_t dim7493JoeKuoD6Init[]   =   { 1, 3, 1, 5, 13, 33, 69, 133, 399, 361, 1633, 321, 2077, 8857, 13419, 23227, 40003, 0 };
            const std::uint32_t dim7494JoeKuoD6Init[]   =   { 1, 1, 1, 15, 15, 9, 45, 181, 427, 1005, 341, 1697, 6423, 5727, 7163, 10401, 38957, 0 };
            const std::uint32_t dim7495JoeKuoD6Init[]   =   { 1, 1, 7, 1, 17, 5, 17, 95, 279, 171, 825, 2459, 5243, 10683, 1849, 32809, 8995, 0 };
            const std::uint32_t dim7496JoeKuoD6Init[]   =   { 1, 3, 5, 15, 27, 47, 103, 69, 69, 255, 961, 2173, 5297, 5987, 5863, 14311, 117569, 0 };
            const std::uint32_t dim7497JoeKuoD6Init[]   =   { 1, 1, 1, 11, 21, 27, 61, 239, 183, 1013, 1955, 3171, 4183, 965, 14885, 49605, 87851, 0 };
            const std::uint32_t dim7498JoeKuoD6Init[]   =   { 1, 1, 7, 9, 9, 53, 99, 211, 267, 803, 1545, 4011, 7613, 13889, 28277, 6817, 26515, 0 };
            const std::uint32_t dim7499JoeKuoD6Init[]   =   { 1, 1, 3, 9, 1, 19, 33, 227, 461, 679, 499, 1069, 837, 12129, 20779, 12937, 104367, 0 };
            const std::uint32_t dim7500JoeKuoD6Init[]   =   { 1, 3, 3, 15, 7, 3, 29, 245, 179, 1015, 1651, 3753, 4185, 15357, 17379, 52835, 51953, 0 };
            const std::uint32_t dim7501JoeKuoD6Init[]   =   { 1, 3, 3, 3, 3, 25, 95, 239, 263, 427, 1749, 183, 5251, 361, 32549, 24331, 30789, 0 };
            const std::uint32_t dim7502JoeKuoD6Init[]   =   { 1, 1, 7, 1, 5, 3, 79, 9, 403, 195, 1433, 385, 8105, 7893, 16415, 23253, 127837, 0 };
            const std::uint32_t dim7503JoeKuoD6Init[]   =   { 1, 3, 7, 3, 23, 45, 115, 27, 473, 241, 361, 1787, 4247, 13451, 5627, 32923, 29375, 0 };
            const std::uint32_t dim7504JoeKuoD6Init[]   =   { 1, 3, 7, 1, 5, 55, 43, 37, 481, 899, 51, 2459, 5005, 12365, 19261, 32797, 45843, 0 };
            const std::uint32_t dim7505JoeKuoD6Init[]   =   { 1, 3, 7, 5, 9, 41, 83, 163, 241, 899, 567, 231, 4897, 15175, 10329, 6625, 95927, 0 };
            const std::uint32_t dim7506JoeKuoD6Init[]   =   { 1, 3, 1, 1, 7, 51, 61, 55, 253, 315, 1893, 2635, 4061, 257, 14147, 36639, 24893, 0 };
            const std::uint32_t dim7507JoeKuoD6Init[]   =   { 1, 1, 5, 1, 13, 63, 115, 119, 205, 309, 277, 2191, 341, 4715, 13111, 58043, 51241, 0 };
            const std::uint32_t dim7508JoeKuoD6Init[]   =   { 1, 3, 1, 15, 17, 23, 89, 121, 205, 15, 295, 667, 421, 14071, 27719, 1335, 9887, 0 };
            const std::uint32_t dim7509JoeKuoD6Init[]   =   { 1, 3, 5, 5, 17, 49, 5, 93, 251, 613, 1029, 945, 1547, 10479, 20183, 26787, 120441, 0 };
            const std::uint32_t dim7510JoeKuoD6Init[]   =   { 1, 3, 3, 15, 17, 11, 63, 97, 499, 313, 881, 2233, 4287, 5141, 13841, 40725, 49285, 0 };
            const std::uint32_t dim7511JoeKuoD6Init[]   =   { 1, 3, 3, 11, 19, 33, 105, 203, 325, 337, 353, 1923, 7157, 8623, 23881, 4513, 71495, 0 };
            const std::uint32_t dim7512JoeKuoD6Init[]   =   { 1, 1, 5, 1, 3, 15, 119, 43, 85, 869, 1597, 2433, 845, 5065, 12813, 64849, 58491, 0 };
            const std::uint32_t dim7513JoeKuoD6Init[]   =   { 1, 3, 7, 7, 25, 63, 119, 93, 303, 665, 571, 1795, 5853, 13527, 12715, 36483, 57723, 0 };
            const std::uint32_t dim7514JoeKuoD6Init[]   =   { 1, 3, 7, 13, 19, 43, 55, 85, 189, 627, 1457, 3185, 3491, 1913, 13399, 30681, 69015, 0 };
            const std::uint32_t dim7515JoeKuoD6Init[]   =   { 1, 3, 5, 9, 5, 41, 51, 65, 147, 425, 569, 1317, 1557, 7631, 17243, 37847, 51161, 0 };
            const std::uint32_t dim7516JoeKuoD6Init[]   =   { 1, 1, 3, 7, 29, 39, 61, 127, 489, 89, 749, 2073, 195, 14367, 13533, 27403, 16365, 0 };
            const std::uint32_t dim7517JoeKuoD6Init[]   =   { 1, 3, 7, 15, 13, 35, 45, 157, 373, 415, 725, 779, 3559, 7489, 11369, 36501, 60761, 0 };
            const std::uint32_t dim7518JoeKuoD6Init[]   =   { 1, 3, 1, 3, 13, 45, 25, 215, 385, 709, 499, 3861, 761, 15597, 3335, 37013, 13173, 0 };
            const std::uint32_t dim7519JoeKuoD6Init[]   =   { 1, 1, 7, 1, 13, 49, 89, 135, 175, 1015, 67, 957, 4893, 9843, 13027, 14709, 59721, 0 };
            const std::uint32_t dim7520JoeKuoD6Init[]   =   { 1, 3, 3, 11, 19, 37, 109, 143, 135, 535, 1543, 3991, 189, 6739, 28087, 18845, 41819, 0 };
            const std::uint32_t dim7521JoeKuoD6Init[]   =   { 1, 1, 7, 5, 1, 7, 11, 5, 211, 251, 1593, 2527, 3539, 10471, 25595, 60119, 89213, 0 };
            const std::uint32_t dim7522JoeKuoD6Init[]   =   { 1, 1, 5, 7, 13, 51, 121, 167, 299, 403, 977, 521, 279, 15521, 15901, 935, 14065, 0 };
            const std::uint32_t dim7523JoeKuoD6Init[]   =   { 1, 1, 7, 13, 7, 21, 27, 205, 377, 801, 1365, 1567, 6651, 139, 14229, 30827, 50429, 0 };
            const std::uint32_t dim7524JoeKuoD6Init[]   =   { 1, 1, 1, 1, 17, 11, 75, 87, 217, 413, 1923, 1765, 2037, 14061, 12433, 30671, 24883, 0 };
            const std::uint32_t dim7525JoeKuoD6Init[]   =   { 1, 1, 5, 13, 17, 51, 91, 241, 95, 505, 349, 2689, 1117, 4435, 1713, 44501, 125619, 0 };
            const std::uint32_t dim7526JoeKuoD6Init[]   =   { 1, 1, 3, 15, 11, 21, 25, 59, 511, 353, 799, 91, 4517, 16005, 17061, 21841, 46311, 0 };
            const std::uint32_t dim7527JoeKuoD6Init[]   =   { 1, 1, 1, 5, 19, 53, 109, 177, 213, 373, 761, 453, 5753, 69, 3503, 49411, 111105, 0 };
            const std::uint32_t dim7528JoeKuoD6Init[]   =   { 1, 3, 1, 5, 21, 27, 103, 167, 109, 55, 1849, 3999, 7801, 4185, 9789, 7515, 124983, 0 };
            const std::uint32_t dim7529JoeKuoD6Init[]   =   { 1, 3, 7, 7, 25, 9, 65, 127, 141, 169, 1079, 3377, 691, 5119, 6629, 3517, 28963, 0 };
            const std::uint32_t dim7530JoeKuoD6Init[]   =   { 1, 1, 3, 11, 15, 61, 127, 35, 87, 891, 1459, 483, 6763, 16173, 5633, 6939, 63411, 0 };
            const std::uint32_t dim7531JoeKuoD6Init[]   =   { 1, 3, 5, 3, 7, 63, 111, 85, 415, 273, 1705, 4045, 5551, 2377, 29025, 16831, 90203, 0 };
            const std::uint32_t dim7532JoeKuoD6Init[]   =   { 1, 3, 5, 13, 7, 23, 103, 227, 477, 985, 1059, 1489, 7233, 1917, 10409, 38759, 86761, 0 };
            const std::uint32_t dim7533JoeKuoD6Init[]   =   { 1, 3, 5, 7, 31, 33, 75, 41, 355, 577, 225, 5, 897, 15653, 27415, 83, 14911, 0 };
            const std::uint32_t dim7534JoeKuoD6Init[]   =   { 1, 3, 5, 5, 23, 13, 5, 43, 165, 53, 149, 2005, 4545, 477, 17885, 21343, 35751, 0 };
            const std::uint32_t dim7535JoeKuoD6Init[]   =   { 1, 3, 3, 3, 25, 51, 33, 203, 291, 835, 241, 3255, 3709, 3573, 9859, 33027, 122801, 0 };
            const std::uint32_t dim7536JoeKuoD6Init[]   =   { 1, 3, 5, 7, 13, 7, 3, 141, 455, 67, 2003, 3411, 4717, 157, 29491, 14429, 44849, 0 };
            const std::uint32_t dim7537JoeKuoD6Init[]   =   { 1, 1, 1, 11, 3, 33, 101, 93, 219, 371, 1191, 1521, 1663, 8485, 24815, 38283, 120867, 0 };
            const std::uint32_t dim7538JoeKuoD6Init[]   =   { 1, 1, 3, 9, 25, 61, 71, 173, 69, 181, 1525, 2129, 2979, 19, 13489, 627, 72619, 0 };
            const std::uint32_t dim7539JoeKuoD6Init[]   =   { 1, 3, 1, 7, 25, 33, 39, 247, 221, 7, 683, 1837, 8037, 9125, 4259, 63049, 63021, 0 };
            const std::uint32_t dim7540JoeKuoD6Init[]   =   { 1, 3, 3, 9, 17, 15, 9, 189, 357, 707, 521, 711, 8189, 12945, 29675, 11851, 126813, 0 };
            const std::uint32_t dim7541JoeKuoD6Init[]   =   { 1, 3, 1, 1, 23, 3, 57, 133, 245, 301, 957, 239, 3139, 7949, 27133, 18229, 93015, 0 };
            const std::uint32_t dim7542JoeKuoD6Init[]   =   { 1, 1, 3, 1, 29, 23, 35, 87, 231, 257, 1997, 271, 3019, 3409, 10613, 42245, 111309, 0 };
            const std::uint32_t dim7543JoeKuoD6Init[]   =   { 1, 1, 3, 3, 1, 21, 17, 37, 393, 943, 791, 3101, 6715, 11907, 25369, 9061, 75381, 0 };
            const std::uint32_t dim7544JoeKuoD6Init[]   =   { 1, 1, 7, 7, 17, 31, 25, 7, 183, 819, 1265, 3343, 6845, 2039, 3779, 41861, 38309, 0 };
            const std::uint32_t dim7545JoeKuoD6Init[]   =   { 1, 1, 1, 5, 17, 25, 1, 41, 173, 995, 863, 3515, 1779, 2159, 28223, 64661, 40697, 0 };
            const std::uint32_t dim7546JoeKuoD6Init[]   =   { 1, 1, 3, 15, 29, 49, 81, 241, 511, 817, 1301, 3593, 6759, 7483, 8859, 30339, 106137, 0 };
            const std::uint32_t dim7547JoeKuoD6Init[]   =   { 1, 3, 1, 11, 17, 61, 95, 231, 3, 693, 37, 1091, 3111, 11941, 17475, 8073, 62373, 0 };
            const std::uint32_t dim7548JoeKuoD6Init[]   =   { 1, 1, 1, 3, 7, 25, 93, 7, 291, 957, 859, 2519, 241, 10963, 10403, 933, 50599, 0 };
            const std::uint32_t dim7549JoeKuoD6Init[]   =   { 1, 1, 7, 1, 7, 33, 121, 91, 369, 333, 229, 4073, 6063, 6491, 31711, 65061, 107843, 0 };
            const std::uint32_t dim7550JoeKuoD6Init[]   =   { 1, 1, 5, 15, 17, 1, 117, 195, 445, 547, 867, 2893, 4835, 6513, 29091, 60367, 33409, 0 };
            const std::uint32_t dim7551JoeKuoD6Init[]   =   { 1, 3, 3, 7, 15, 5, 125, 131, 165, 127, 207, 853, 5927, 3605, 17083, 44481, 111333, 0 };
            const std::uint32_t dim7552JoeKuoD6Init[]   =   { 1, 1, 1, 9, 3, 43, 75, 191, 319, 889, 1513, 3301, 1535, 4693, 10367, 12491, 43175, 0 };
            const std::uint32_t dim7553JoeKuoD6Init[]   =   { 1, 3, 5, 5, 29, 19, 75, 221, 393, 977, 1373, 1571, 7377, 1763, 18073, 11381, 101241, 0 };
            const std::uint32_t dim7554JoeKuoD6Init[]   =   { 1, 3, 1, 15, 3, 15, 73, 91, 165, 213, 1077, 1267, 2411, 15807, 3979, 12731, 86597, 0 };
            const std::uint32_t dim7555JoeKuoD6Init[]   =   { 1, 1, 3, 7, 3, 21, 5, 135, 95, 337, 1853, 1675, 2449, 12535, 18505, 60127, 76949, 0 };
            const std::uint32_t dim7556JoeKuoD6Init[]   =   { 1, 1, 7, 3, 15, 11, 63, 127, 329, 169, 1569, 675, 4801, 5859, 3243, 25811, 77841, 0 };
            const std::uint32_t dim7557JoeKuoD6Init[]   =   { 1, 1, 1, 9, 19, 13, 73, 119, 105, 537, 951, 1033, 5303, 5775, 815, 19277, 57607, 0 };
            const std::uint32_t dim7558JoeKuoD6Init[]   =   { 1, 3, 5, 5, 23, 21, 91, 231, 117, 1007, 1603, 841, 2595, 11223, 17171, 25963, 17049, 0 };
            const std::uint32_t dim7559JoeKuoD6Init[]   =   { 1, 1, 5, 11, 15, 43, 7, 229, 55, 129, 599, 993, 563, 15677, 16703, 36253, 17847, 0 };
            const std::uint32_t dim7560JoeKuoD6Init[]   =   { 1, 3, 1, 9, 25, 3, 109, 21, 87, 721, 1927, 3219, 3395, 3267, 9117, 13591, 89267, 0 };
            const std::uint32_t dim7561JoeKuoD6Init[]   =   { 1, 1, 1, 15, 11, 17, 47, 49, 125, 925, 333, 945, 2411, 10907, 12021, 47857, 84303, 0 };
            const std::uint32_t dim7562JoeKuoD6Init[]   =   { 1, 1, 1, 1, 23, 11, 99, 215, 105, 417, 823, 1289, 421, 12285, 17711, 35389, 1935, 0 };
            const std::uint32_t dim7563JoeKuoD6Init[]   =   { 1, 1, 1, 15, 27, 7, 23, 141, 7, 929, 147, 681, 5473, 4173, 28645, 42053, 83573, 0 };
            const std::uint32_t dim7564JoeKuoD6Init[]   =   { 1, 1, 1, 11, 5, 61, 71, 65, 287, 697, 1183, 3257, 7251, 14011, 21349, 42445, 4701, 0 };
            const std::uint32_t dim7565JoeKuoD6Init[]   =   { 1, 3, 5, 9, 5, 23, 45, 217, 369, 189, 1495, 107, 425, 10467, 4909, 64293, 17885, 0 };
            const std::uint32_t dim7566JoeKuoD6Init[]   =   { 1, 1, 3, 11, 21, 45, 75, 65, 57, 893, 783, 3429, 409, 13617, 483, 62489, 2919, 0 };
            const std::uint32_t dim7567JoeKuoD6Init[]   =   { 1, 1, 7, 3, 5, 61, 51, 255, 501, 839, 367, 1165, 7055, 8139, 23891, 18807, 20739, 0 };
            const std::uint32_t dim7568JoeKuoD6Init[]   =   { 1, 1, 3, 7, 23, 15, 97, 139, 323, 463, 921, 1529, 6655, 8697, 23577, 56761, 62023, 0 };
            const std::uint32_t dim7569JoeKuoD6Init[]   =   { 1, 1, 5, 11, 13, 11, 57, 225, 277, 713, 1427, 95, 1135, 7721, 30731, 32625, 107891, 0 };
            const std::uint32_t dim7570JoeKuoD6Init[]   =   { 1, 1, 5, 7, 23, 35, 39, 91, 291, 609, 919, 3325, 6843, 7659, 5603, 37471, 41495, 0 };
            const std::uint32_t dim7571JoeKuoD6Init[]   =   { 1, 1, 1, 1, 25, 11, 117, 15, 389, 589, 1345, 423, 6531, 9903, 20243, 9523, 22991, 0 };
            const std::uint32_t dim7572JoeKuoD6Init[]   =   { 1, 3, 5, 15, 29, 7, 57, 113, 387, 883, 1141, 3295, 2973, 4129, 16973, 33429, 109997, 0 };
            const std::uint32_t dim7573JoeKuoD6Init[]   =   { 1, 3, 5, 3, 25, 1, 73, 207, 353, 203, 1479, 985, 6373, 3079, 28403, 63675, 21787, 0 };
            const std::uint32_t dim7574JoeKuoD6Init[]   =   { 1, 3, 1, 5, 31, 39, 107, 197, 359, 45, 203, 559, 4721, 6579, 11305, 12957, 10061, 0 };
            const std::uint32_t dim7575JoeKuoD6Init[]   =   { 1, 3, 7, 15, 9, 3, 55, 153, 373, 981, 575, 827, 4757, 15743, 14295, 43875, 17847, 0 };
            const std::uint32_t dim7576JoeKuoD6Init[]   =   { 1, 3, 5, 1, 17, 1, 93, 87, 207, 997, 1695, 3643, 6973, 9507, 29309, 58531, 6849, 0 };
            const std::uint32_t dim7577JoeKuoD6Init[]   =   { 1, 3, 1, 11, 3, 39, 17, 241, 83, 931, 39, 3839, 6437, 5159, 28869, 61859, 96873, 0 };
            const std::uint32_t dim7578JoeKuoD6Init[]   =   { 1, 1, 5, 13, 29, 43, 71, 159, 261, 563, 695, 1205, 2273, 8077, 12569, 17187, 54369, 0 };
            const std::uint32_t dim7579JoeKuoD6Init[]   =   { 1, 3, 7, 5, 11, 57, 17, 31, 311, 1001, 1419, 3899, 6679, 15531, 28877, 28221, 105413, 0 };
            const std::uint32_t dim7580JoeKuoD6Init[]   =   { 1, 3, 3, 13, 23, 29, 127, 19, 345, 1003, 1571, 2219, 3199, 9903, 18701, 31865, 108879, 0 };
            const std::uint32_t dim7581JoeKuoD6Init[]   =   { 1, 3, 7, 13, 23, 51, 95, 43, 35, 439, 25, 323, 2365, 12407, 27525, 57795, 74495, 0 };
            const std::uint32_t dim7582JoeKuoD6Init[]   =   { 1, 1, 1, 1, 17, 43, 57, 185, 439, 929, 69, 813, 6205, 3139, 3853, 56967, 19073, 0 };
            const std::uint32_t dim7583JoeKuoD6Init[]   =   { 1, 3, 7, 1, 27, 5, 43, 211, 395, 113, 1675, 1505, 6171, 5169, 9991, 21641, 27101, 0 };
            const std::uint32_t dim7584JoeKuoD6Init[]   =   { 1, 3, 3, 1, 17, 41, 59, 131, 131, 339, 955, 1145, 5301, 4585, 20441, 43227, 23123, 0 };
            const std::uint32_t dim7585JoeKuoD6Init[]   =   { 1, 1, 7, 9, 9, 55, 61, 31, 71, 229, 963, 3247, 4677, 9595, 21715, 36391, 86997, 0 };
            const std::uint32_t dim7586JoeKuoD6Init[]   =   { 1, 1, 7, 5, 9, 17, 55, 179, 27, 229, 79, 1335, 5887, 1003, 22085, 34377, 51367, 0 };
            const std::uint32_t dim7587JoeKuoD6Init[]   =   { 1, 1, 1, 5, 11, 45, 15, 219, 411, 27, 1003, 1553, 303, 13571, 13985, 6801, 52407, 0 };
            const std::uint32_t dim7588JoeKuoD6Init[]   =   { 1, 3, 3, 7, 7, 55, 111, 255, 453, 409, 1863, 1449, 4103, 8725, 26923, 5017, 43657, 0 };
            const std::uint32_t dim7589JoeKuoD6Init[]   =   { 1, 1, 1, 15, 23, 3, 95, 57, 29, 727, 1111, 3309, 1089, 471, 16099, 11517, 51563, 0 };
            const std::uint32_t dim7590JoeKuoD6Init[]   =   { 1, 3, 1, 15, 17, 57, 83, 163, 251, 987, 1159, 2079, 3463, 13109, 7443, 8665, 123397, 0 };
            const std::uint32_t dim7591JoeKuoD6Init[]   =   { 1, 1, 7, 1, 27, 13, 35, 209, 471, 843, 1029, 1383, 5413, 2085, 13431, 26557, 47033, 0 };
            const std::uint32_t dim7592JoeKuoD6Init[]   =   { 1, 3, 1, 1, 21, 21, 83, 135, 303, 27, 1407, 1751, 331, 9207, 31891, 59287, 120687, 0 };
            const std::uint32_t dim7593JoeKuoD6Init[]   =   { 1, 1, 1, 9, 11, 35, 103, 157, 1, 855, 175, 3203, 4381, 3113, 27589, 4567, 31897, 0 };
            const std::uint32_t dim7594JoeKuoD6Init[]   =   { 1, 1, 3, 5, 21, 5, 123, 161, 301, 101, 909, 947, 6893, 15459, 29139, 49377, 94901, 0 };
            const std::uint32_t dim7595JoeKuoD6Init[]   =   { 1, 3, 7, 7, 21, 27, 5, 69, 427, 409, 1389, 3737, 847, 2775, 603, 1001, 87651, 0 };
            const std::uint32_t dim7596JoeKuoD6Init[]   =   { 1, 1, 3, 5, 1, 57, 109, 89, 99, 593, 581, 3527, 1557, 4971, 27523, 26909, 35787, 0 };
            const std::uint32_t dim7597JoeKuoD6Init[]   =   { 1, 1, 7, 3, 31, 19, 83, 65, 239, 919, 15, 2289, 4117, 9127, 6033, 49667, 89343, 0 };
            const std::uint32_t dim7598JoeKuoD6Init[]   =   { 1, 3, 7, 7, 9, 31, 87, 117, 195, 681, 1711, 1753, 2221, 10053, 1985, 6273, 21801, 0 };
            const std::uint32_t dim7599JoeKuoD6Init[]   =   { 1, 3, 1, 7, 21, 61, 53, 231, 309, 115, 1729, 3883, 6085, 4825, 31455, 50097, 59779, 0 };
            const std::uint32_t dim7600JoeKuoD6Init[]   =   { 1, 1, 1, 9, 29, 25, 45, 91, 145, 927, 147, 371, 2603, 12537, 17267, 59895, 128009, 0 };
            const std::uint32_t dim7601JoeKuoD6Init[]   =   { 1, 1, 1, 1, 15, 41, 63, 43, 167, 215, 15, 3387, 1811, 12391, 25721, 6961, 13701, 0 };
            const std::uint32_t dim7602JoeKuoD6Init[]   =   { 1, 1, 7, 1, 27, 63, 25, 85, 337, 799, 87, 2237, 4085, 14529, 11493, 60149, 86399, 0 };
            const std::uint32_t dim7603JoeKuoD6Init[]   =   { 1, 3, 1, 11, 1, 41, 103, 145, 279, 805, 1201, 823, 5411, 4227, 25999, 14373, 36295, 0 };
            const std::uint32_t dim7604JoeKuoD6Init[]   =   { 1, 1, 7, 3, 27, 51, 83, 105, 155, 657, 1879, 3869, 2559, 2939, 19785, 47167, 34503, 0 };
            const std::uint32_t dim7605JoeKuoD6Init[]   =   { 1, 3, 1, 5, 3, 31, 47, 241, 257, 15, 983, 4095, 3745, 3901, 1639, 5421, 81585, 0 };
            const std::uint32_t dim7606JoeKuoD6Init[]   =   { 1, 3, 3, 5, 31, 13, 127, 125, 175, 577, 1103, 3573, 6229, 13969, 6267, 19067, 3933, 0 };
            const std::uint32_t dim7607JoeKuoD6Init[]   =   { 1, 1, 7, 1, 31, 17, 15, 15, 411, 553, 1929, 3731, 1955, 11749, 21991, 39189, 124427, 0 };
            const std::uint32_t dim7608JoeKuoD6Init[]   =   { 1, 3, 5, 5, 19, 63, 93, 201, 491, 599, 1093, 767, 3411, 13087, 23569, 42981, 35757, 0 };
            const std::uint32_t dim7609JoeKuoD6Init[]   =   { 1, 1, 1, 15, 27, 7, 51, 101, 429, 939, 111, 781, 2055, 14227, 17821, 42097, 32485, 0 };
            const std::uint32_t dim7610JoeKuoD6Init[]   =   { 1, 3, 7, 13, 11, 21, 3, 161, 353, 389, 285, 2633, 6245, 7089, 21907, 40765, 88869, 0 };
            const std::uint32_t dim7611JoeKuoD6Init[]   =   { 1, 1, 5, 9, 7, 27, 101, 203, 243, 897, 1375, 1619, 5275, 12935, 22103, 38005, 65603, 0 };
            const std::uint32_t dim7612JoeKuoD6Init[]   =   { 1, 1, 5, 9, 13, 25, 15, 21, 447, 7, 947, 1613, 5055, 129, 18057, 58551, 6603, 0 };
            const std::uint32_t dim7613JoeKuoD6Init[]   =   { 1, 3, 7, 15, 17, 41, 11, 55, 103, 339, 349, 1813, 7423, 11837, 20641, 51951, 61615, 0 };
            const std::uint32_t dim7614JoeKuoD6Init[]   =   { 1, 3, 3, 15, 21, 59, 113, 3, 123, 689, 465, 3039, 4109, 3241, 30317, 65053, 117845, 0 };
            const std::uint32_t dim7615JoeKuoD6Init[]   =   { 1, 3, 3, 1, 31, 33, 73, 155, 245, 401, 473, 51, 1387, 489, 10573, 55401, 106733, 0 };
            const std::uint32_t dim7616JoeKuoD6Init[]   =   { 1, 3, 3, 1, 31, 37, 15, 139, 127, 201, 229, 1753, 7287, 9045, 18321, 63485, 26399, 0 };
            const std::uint32_t dim7617JoeKuoD6Init[]   =   { 1, 3, 5, 5, 5, 23, 93, 3, 125, 715, 1827, 419, 1213, 9031, 25139, 20771, 41345, 0 };
            const std::uint32_t dim7618JoeKuoD6Init[]   =   { 1, 3, 5, 15, 23, 15, 13, 145, 105, 477, 1131, 2699, 1929, 10447, 9655, 26791, 80101, 0 };
            const std::uint32_t dim7619JoeKuoD6Init[]   =   { 1, 1, 1, 13, 1, 35, 75, 73, 269, 851, 737, 1909, 6805, 11359, 28991, 52435, 83767, 0 };
            const std::uint32_t dim7620JoeKuoD6Init[]   =   { 1, 1, 7, 5, 11, 31, 31, 91, 111, 161, 1865, 2545, 133, 12215, 8957, 20671, 92975, 0 };
            const std::uint32_t dim7621JoeKuoD6Init[]   =   { 1, 1, 7, 5, 25, 53, 55, 121, 53, 457, 831, 2493, 339, 10955, 30783, 9095, 97921, 0 };
            const std::uint32_t dim7622JoeKuoD6Init[]   =   { 1, 1, 5, 3, 25, 33, 81, 51, 211, 737, 1865, 4039, 6931, 8473, 22459, 24885, 96355, 0 };
            const std::uint32_t dim7623JoeKuoD6Init[]   =   { 1, 3, 7, 13, 23, 5, 101, 171, 65, 793, 443, 411, 7629, 14791, 28633, 9055, 123763, 0 };
            const std::uint32_t dim7624JoeKuoD6Init[]   =   { 1, 3, 3, 1, 11, 7, 99, 79, 461, 481, 1689, 3777, 2125, 4783, 13061, 19537, 68109, 0 };
            const std::uint32_t dim7625JoeKuoD6Init[]   =   { 1, 1, 3, 11, 31, 53, 109, 7, 49, 925, 1017, 2371, 1537, 13557, 75, 40677, 49181, 0 };
            const std::uint32_t dim7626JoeKuoD6Init[]   =   { 1, 3, 3, 3, 9, 1, 95, 113, 189, 389, 377, 393, 6523, 3183, 6461, 30201, 66549, 0 };
            const std::uint32_t dim7627JoeKuoD6Init[]   =   { 1, 1, 7, 15, 13, 19, 41, 171, 475, 157, 949, 3245, 5581, 2783, 25263, 53023, 11155, 0 };
            const std::uint32_t dim7628JoeKuoD6Init[]   =   { 1, 3, 5, 7, 29, 63, 61, 65, 315, 595, 905, 899, 5059, 4243, 27287, 14023, 64213, 0 };
            const std::uint32_t dim7629JoeKuoD6Init[]   =   { 1, 3, 1, 3, 15, 37, 109, 161, 9, 867, 1023, 2513, 4593, 7747, 1505, 4801, 127091, 0 };
            const std::uint32_t dim7630JoeKuoD6Init[]   =   { 1, 3, 1, 7, 11, 59, 75, 129, 469, 695, 63, 2757, 6357, 8675, 6193, 23439, 66445, 0 };
            const std::uint32_t dim7631JoeKuoD6Init[]   =   { 1, 1, 3, 13, 17, 9, 47, 91, 161, 265, 139, 129, 6707, 9659, 8917, 54757, 77835, 0 };
            const std::uint32_t dim7632JoeKuoD6Init[]   =   { 1, 1, 3, 13, 19, 37, 113, 255, 99, 913, 1445, 487, 337, 1001, 16395, 37141, 66595, 0 };
            const std::uint32_t dim7633JoeKuoD6Init[]   =   { 1, 1, 1, 15, 3, 63, 69, 43, 185, 293, 1137, 2061, 2377, 8741, 26817, 5833, 7807, 0 };
            const std::uint32_t dim7634JoeKuoD6Init[]   =   { 1, 1, 1, 5, 3, 29, 39, 33, 263, 355, 597, 539, 5055, 13075, 8977, 19829, 88171, 0 };
            const std::uint32_t dim7635JoeKuoD6Init[]   =   { 1, 3, 7, 9, 17, 49, 125, 101, 447, 597, 1337, 559, 2807, 7925, 12421, 17427, 34815, 0 };
            const std::uint32_t dim7636JoeKuoD6Init[]   =   { 1, 3, 1, 9, 11, 57, 31, 163, 503, 925, 911, 3721, 2515, 8429, 25749, 55209, 90105, 0 };
            const std::uint32_t dim7637JoeKuoD6Init[]   =   { 1, 3, 5, 3, 21, 57, 119, 233, 319, 745, 563, 3057, 2683, 7063, 11513, 49157, 64561, 0 };
            const std::uint32_t dim7638JoeKuoD6Init[]   =   { 1, 1, 3, 9, 15, 21, 93, 99, 227, 479, 965, 51, 6941, 9887, 32409, 23171, 98387, 0 };
            const std::uint32_t dim7639JoeKuoD6Init[]   =   { 1, 3, 5, 5, 19, 1, 47, 49, 233, 931, 971, 2369, 2827, 1291, 18653, 725, 19791, 0 };
            const std::uint32_t dim7640JoeKuoD6Init[]   =   { 1, 1, 5, 15, 3, 7, 71, 251, 341, 861, 1203, 793, 7627, 10929, 10717, 10677, 49743, 0 };
            const std::uint32_t dim7641JoeKuoD6Init[]   =   { 1, 3, 1, 7, 3, 43, 9, 187, 247, 621, 1069, 2875, 1525, 4221, 18813, 35807, 117609, 0 };
            const std::uint32_t dim7642JoeKuoD6Init[]   =   { 1, 3, 3, 3, 29, 39, 83, 201, 205, 337, 231, 547, 2893, 2483, 6197, 26869, 18921, 0 };
            const std::uint32_t dim7643JoeKuoD6Init[]   =   { 1, 1, 7, 3, 23, 29, 33, 137, 491, 691, 979, 65, 5711, 11685, 5137, 37993, 37075, 0 };
            const std::uint32_t dim7644JoeKuoD6Init[]   =   { 1, 3, 3, 1, 11, 3, 99, 119, 203, 901, 1887, 879, 7547, 4613, 31233, 13279, 105089, 0 };
            const std::uint32_t dim7645JoeKuoD6Init[]   =   { 1, 1, 1, 13, 25, 23, 111, 167, 313, 141, 127, 1223, 5711, 4101, 10977, 34695, 128303, 0 };
            const std::uint32_t dim7646JoeKuoD6Init[]   =   { 1, 1, 7, 15, 5, 3, 89, 151, 289, 769, 539, 2883, 8121, 15403, 22345, 63765, 117015, 0 };
            const std::uint32_t dim7647JoeKuoD6Init[]   =   { 1, 1, 1, 13, 15, 9, 71, 95, 37, 705, 1575, 3735, 7445, 2027, 27523, 53321, 106085, 0 };
            const std::uint32_t dim7648JoeKuoD6Init[]   =   { 1, 3, 5, 7, 5, 29, 7, 25, 181, 491, 1173, 1947, 3321, 9233, 17265, 26999, 97783, 0 };
            const std::uint32_t dim7649JoeKuoD6Init[]   =   { 1, 1, 3, 15, 1, 63, 111, 113, 279, 123, 345, 1529, 2725, 8643, 8551, 30073, 26689, 0 };
            const std::uint32_t dim7650JoeKuoD6Init[]   =   { 1, 3, 7, 7, 5, 55, 117, 211, 293, 851, 1491, 3265, 4009, 14949, 10297, 16219, 69983, 0 };
            const std::uint32_t dim7651JoeKuoD6Init[]   =   { 1, 1, 3, 11, 23, 45, 35, 91, 97, 191, 417, 3545, 1733, 3955, 10763, 10229, 75027, 0 };
            const std::uint32_t dim7652JoeKuoD6Init[]   =   { 1, 1, 3, 13, 3, 61, 69, 205, 379, 627, 295, 3979, 85, 11305, 2493, 35583, 3133, 0 };
            const std::uint32_t dim7653JoeKuoD6Init[]   =   { 1, 3, 5, 9, 5, 63, 67, 201, 351, 367, 1009, 739, 5409, 8715, 28939, 31511, 34599, 0 };
            const std::uint32_t dim7654JoeKuoD6Init[]   =   { 1, 1, 1, 5, 3, 25, 21, 25, 477, 301, 623, 157, 563, 9457, 24515, 30135, 107165, 0 };
            const std::uint32_t dim7655JoeKuoD6Init[]   =   { 1, 1, 3, 15, 5, 41, 49, 171, 469, 427, 857, 2165, 1437, 2151, 24061, 63243, 105331, 0 };
            const std::uint32_t dim7656JoeKuoD6Init[]   =   { 1, 3, 5, 11, 21, 25, 59, 167, 29, 653, 1503, 2223, 3889, 4605, 28381, 36075, 74907, 0 };
            const std::uint32_t dim7657JoeKuoD6Init[]   =   { 1, 3, 7, 7, 17, 55, 73, 127, 33, 319, 1565, 2761, 6473, 2187, 19939, 56687, 112137, 0 };
            const std::uint32_t dim7658JoeKuoD6Init[]   =   { 1, 1, 1, 9, 7, 53, 105, 3, 299, 15, 1009, 607, 6885, 12875, 20719, 16841, 70471, 0 };
            const std::uint32_t dim7659JoeKuoD6Init[]   =   { 1, 3, 5, 9, 7, 33, 23, 163, 279, 739, 1541, 3017, 2309, 11827, 3875, 44337, 82063, 0 };
            const std::uint32_t dim7660JoeKuoD6Init[]   =   { 1, 1, 1, 5, 19, 53, 109, 193, 331, 339, 477, 4093, 5177, 13527, 25731, 64137, 81411, 0 };
            const std::uint32_t dim7661JoeKuoD6Init[]   =   { 1, 3, 7, 13, 15, 63, 101, 145, 127, 13, 1431, 3581, 4993, 14287, 12125, 60217, 102563, 0 };
            const std::uint32_t dim7662JoeKuoD6Init[]   =   { 1, 3, 1, 7, 17, 27, 127, 81, 223, 763, 761, 2061, 1031, 12251, 14141, 23587, 124813, 0 };
            const std::uint32_t dim7663JoeKuoD6Init[]   =   { 1, 3, 5, 13, 27, 21, 9, 249, 285, 875, 65, 4075, 6749, 13417, 3079, 29343, 87075, 0 };
            const std::uint32_t dim7664JoeKuoD6Init[]   =   { 1, 3, 5, 13, 1, 31, 61, 21, 169, 145, 1681, 1229, 5059, 13555, 21373, 35597, 70669, 0 };
            const std::uint32_t dim7665JoeKuoD6Init[]   =   { 1, 3, 7, 15, 23, 31, 43, 237, 139, 9, 1905, 3197, 801, 14205, 13323, 18717, 88523, 0 };
            const std::uint32_t dim7666JoeKuoD6Init[]   =   { 1, 1, 1, 11, 1, 7, 21, 83, 15, 459, 537, 4029, 6973, 4019, 1, 35147, 16329, 0 };
            const std::uint32_t dim7667JoeKuoD6Init[]   =   { 1, 3, 7, 15, 23, 11, 17, 101, 235, 683, 913, 3529, 4363, 13899, 3603, 27741, 74143, 0 };
            const std::uint32_t dim7668JoeKuoD6Init[]   =   { 1, 1, 7, 7, 3, 3, 91, 107, 499, 723, 315, 2805, 5909, 11041, 18281, 54981, 76041, 0 };
            const std::uint32_t dim7669JoeKuoD6Init[]   =   { 1, 3, 7, 9, 15, 7, 93, 171, 275, 647, 655, 3565, 2199, 14795, 21945, 9373, 122299, 0 };
            const std::uint32_t dim7670JoeKuoD6Init[]   =   { 1, 1, 1, 5, 27, 53, 73, 27, 431, 707, 53, 1281, 49, 13199, 1973, 18935, 114821, 0 };
            const std::uint32_t dim7671JoeKuoD6Init[]   =   { 1, 1, 3, 3, 25, 1, 17, 159, 217, 413, 1393, 2119, 5611, 7659, 6003, 19927, 22287, 0 };
            const std::uint32_t dim7672JoeKuoD6Init[]   =   { 1, 1, 7, 15, 29, 59, 77, 9, 205, 795, 627, 2167, 2477, 6841, 17663, 34871, 79823, 0 };
            const std::uint32_t dim7673JoeKuoD6Init[]   =   { 1, 3, 5, 9, 13, 35, 79, 237, 11, 335, 789, 2291, 13, 853, 20373, 39049, 407, 0 };
            const std::uint32_t dim7674JoeKuoD6Init[]   =   { 1, 1, 5, 7, 13, 27, 21, 173, 137, 659, 123, 2677, 2153, 14879, 26737, 56291, 47613, 0 };
            const std::uint32_t dim7675JoeKuoD6Init[]   =   { 1, 3, 5, 15, 23, 47, 15, 109, 311, 597, 261, 2407, 8139, 3215, 28169, 60731, 79937, 0 };
            const std::uint32_t dim7676JoeKuoD6Init[]   =   { 1, 3, 3, 5, 11, 61, 71, 29, 189, 741, 1171, 397, 2669, 10627, 20037, 51703, 6697, 0 };
            const std::uint32_t dim7677JoeKuoD6Init[]   =   { 1, 3, 3, 3, 9, 41, 125, 1, 381, 399, 349, 3265, 6337, 8113, 14869, 5305, 83409, 0 };
            const std::uint32_t dim7678JoeKuoD6Init[]   =   { 1, 1, 3, 13, 5, 19, 33, 225, 45, 55, 1809, 1037, 5443, 15719, 9963, 363, 15145, 0 };
            const std::uint32_t dim7679JoeKuoD6Init[]   =   { 1, 3, 7, 1, 31, 25, 103, 29, 207, 169, 305, 913, 7501, 15323, 10575, 13477, 65245, 0 };
            const std::uint32_t dim7680JoeKuoD6Init[]   =   { 1, 3, 3, 15, 13, 23, 69, 255, 333, 157, 279, 1989, 3439, 12955, 13649, 52431, 90009, 0 };
            const std::uint32_t dim7681JoeKuoD6Init[]   =   { 1, 3, 7, 5, 23, 61, 111, 121, 79, 469, 89, 1545, 3405, 12393, 2035, 15989, 84855, 0 };
            const std::uint32_t dim7682JoeKuoD6Init[]   =   { 1, 1, 7, 5, 17, 21, 127, 151, 283, 521, 5, 3023, 5365, 11633, 21177, 42207, 48925, 0 };
            const std::uint32_t dim7683JoeKuoD6Init[]   =   { 1, 3, 7, 5, 21, 21, 61, 17, 415, 879, 1485, 3727, 935, 9899, 23241, 651, 103701, 0 };
            const std::uint32_t dim7684JoeKuoD6Init[]   =   { 1, 3, 5, 15, 31, 47, 19, 245, 249, 467, 253, 1575, 337, 863, 19353, 13153, 125453, 0 };
            const std::uint32_t dim7685JoeKuoD6Init[]   =   { 1, 1, 7, 15, 9, 41, 39, 63, 139, 875, 1011, 1961, 1627, 7461, 28961, 47195, 16239, 0 };
            const std::uint32_t dim7686JoeKuoD6Init[]   =   { 1, 3, 3, 7, 27, 55, 51, 245, 231, 619, 43, 91, 2125, 2685, 23661, 10189, 43085, 0 };
            const std::uint32_t dim7687JoeKuoD6Init[]   =   { 1, 1, 7, 9, 27, 55, 35, 139, 187, 143, 1545, 2685, 3173, 12065, 21607, 42619, 105279, 0 };
            const std::uint32_t dim7688JoeKuoD6Init[]   =   { 1, 1, 5, 3, 29, 63, 15, 197, 49, 995, 389, 1959, 2441, 11509, 31753, 40539, 26989, 0 };
            const std::uint32_t dim7689JoeKuoD6Init[]   =   { 1, 3, 7, 15, 19, 37, 17, 37, 305, 469, 945, 2335, 1493, 13843, 19905, 49031, 107893, 0 };
            const std::uint32_t dim7690JoeKuoD6Init[]   =   { 1, 3, 1, 11, 3, 35, 113, 181, 223, 27, 485, 2435, 3423, 11321, 1687, 45755, 18017, 0 };
            const std::uint32_t dim7691JoeKuoD6Init[]   =   { 1, 3, 3, 13, 17, 47, 109, 145, 287, 769, 1373, 3423, 1251, 14357, 3209, 28363, 97987, 0 };
            const std::uint32_t dim7692JoeKuoD6Init[]   =   { 1, 1, 3, 13, 7, 25, 93, 11, 23, 331, 517, 1705, 1957, 291, 763, 10411, 120367, 0 };
            const std::uint32_t dim7693JoeKuoD6Init[]   =   { 1, 3, 7, 15, 25, 9, 1, 33, 83, 61, 97, 509, 5387, 8701, 14243, 31883, 7375, 0 };
            const std::uint32_t dim7694JoeKuoD6Init[]   =   { 1, 3, 1, 5, 19, 11, 59, 95, 265, 205, 533, 1857, 693, 12469, 24445, 19449, 130623, 0 };
            const std::uint32_t dim7695JoeKuoD6Init[]   =   { 1, 1, 7, 7, 1, 5, 15, 159, 333, 361, 391, 1889, 2645, 15115, 30709, 60515, 13315, 0 };
            const std::uint32_t dim7696JoeKuoD6Init[]   =   { 1, 3, 5, 15, 25, 61, 69, 213, 183, 575, 1573, 3147, 1753, 2387, 23063, 12853, 108507, 0 };
            const std::uint32_t dim7697JoeKuoD6Init[]   =   { 1, 1, 1, 15, 17, 31, 11, 177, 411, 23, 469, 3985, 2159, 2273, 14175, 20425, 107741, 0 };
            const std::uint32_t dim7698JoeKuoD6Init[]   =   { 1, 1, 3, 9, 5, 35, 55, 225, 263, 641, 1393, 1277, 595, 2671, 7039, 64999, 114387, 0 };
            const std::uint32_t dim7699JoeKuoD6Init[]   =   { 1, 1, 3, 3, 11, 23, 1, 161, 77, 755, 1325, 1773, 4291, 13119, 29677, 27295, 81713, 0 };
            const std::uint32_t dim7700JoeKuoD6Init[]   =   { 1, 1, 5, 13, 31, 45, 115, 141, 449, 171, 1413, 2411, 7937, 10859, 19453, 64403, 45169, 0 };
            const std::uint32_t dim7701JoeKuoD6Init[]   =   { 1, 3, 5, 7, 1, 27, 117, 157, 99, 119, 1281, 2633, 5117, 16009, 19545, 7421, 30807, 0 };
            const std::uint32_t dim7702JoeKuoD6Init[]   =   { 1, 1, 3, 13, 19, 11, 61, 239, 331, 731, 1723, 1773, 2623, 15255, 17197, 63793, 100433, 0 };
            const std::uint32_t dim7703JoeKuoD6Init[]   =   { 1, 3, 7, 11, 11, 7, 119, 33, 195, 521, 811, 2599, 3113, 5497, 16751, 2541, 21813, 0 };
            const std::uint32_t dim7704JoeKuoD6Init[]   =   { 1, 1, 1, 15, 23, 47, 25, 73, 429, 213, 557, 1613, 7055, 7211, 2225, 1345, 58033, 0 };
            const std::uint32_t dim7705JoeKuoD6Init[]   =   { 1, 1, 1, 13, 15, 39, 69, 71, 11, 543, 267, 2803, 4853, 9819, 603, 4629, 78343, 0 };
            const std::uint32_t dim7706JoeKuoD6Init[]   =   { 1, 1, 7, 1, 15, 55, 47, 223, 63, 679, 1135, 3225, 3845, 12031, 6761, 20337, 29021, 0 };
            const std::uint32_t dim7707JoeKuoD6Init[]   =   { 1, 1, 3, 3, 3, 51, 127, 103, 43, 379, 169, 2549, 7775, 2553, 27415, 30671, 34043, 0 };
            const std::uint32_t dim7708JoeKuoD6Init[]   =   { 1, 1, 3, 11, 1, 31, 89, 113, 475, 857, 499, 3901, 5343, 8819, 4503, 58757, 60513, 0 };
            const std::uint32_t dim7709JoeKuoD6Init[]   =   { 1, 3, 5, 11, 27, 49, 97, 217, 91, 971, 1835, 3447, 2021, 3747, 20533, 13659, 84007, 0 };
            const std::uint32_t dim7710JoeKuoD6Init[]   =   { 1, 1, 5, 1, 31, 39, 49, 21, 135, 983, 579, 3509, 3611, 15101, 29781, 49941, 14353, 0 };
            const std::uint32_t dim7711JoeKuoD6Init[]   =   { 1, 1, 1, 9, 7, 17, 55, 233, 295, 161, 823, 3823, 4771, 13531, 24197, 42629, 60269, 0 };
            const std::uint32_t dim7712JoeKuoD6Init[]   =   { 1, 1, 3, 15, 23, 5, 101, 167, 55, 297, 1733, 3819, 7041, 9915, 27803, 60359, 10249, 0 };
            const std::uint32_t dim7713JoeKuoD6Init[]   =   { 1, 1, 7, 9, 25, 47, 67, 253, 303, 313, 1389, 3785, 2729, 11471, 27267, 42783, 111595, 0 };
            const std::uint32_t dim7714JoeKuoD6Init[]   =   { 1, 1, 5, 13, 25, 63, 17, 195, 457, 793, 1553, 1673, 6799, 12171, 9003, 22195, 90229, 0 };
            const std::uint32_t dim7715JoeKuoD6Init[]   =   { 1, 1, 3, 15, 11, 43, 43, 221, 423, 985, 873, 599, 1753, 4875, 7149, 34625, 8941, 0 };
            const std::uint32_t dim7716JoeKuoD6Init[]   =   { 1, 3, 5, 11, 1, 7, 109, 163, 309, 477, 1291, 3019, 1933, 14055, 15005, 1141, 66867, 0 };
            const std::uint32_t dim7717JoeKuoD6Init[]   =   { 1, 3, 3, 15, 21, 35, 95, 131, 413, 1009, 147, 2165, 6333, 8313, 20873, 18377, 23579, 0 };
            const std::uint32_t dim7718JoeKuoD6Init[]   =   { 1, 3, 1, 5, 21, 49, 29, 187, 67, 419, 253, 2345, 3179, 12331, 23127, 8799, 102493, 0 };
            const std::uint32_t dim7719JoeKuoD6Init[]   =   { 1, 1, 7, 5, 29, 59, 13, 189, 377, 595, 1893, 527, 7993, 14867, 24671, 14585, 38645, 0 };
            const std::uint32_t dim7720JoeKuoD6Init[]   =   { 1, 3, 5, 13, 3, 11, 99, 69, 253, 833, 1961, 2719, 3953, 8143, 21277, 16257, 26929, 0 };
            const std::uint32_t dim7721JoeKuoD6Init[]   =   { 1, 3, 7, 3, 3, 19, 19, 57, 393, 187, 945, 2107, 669, 14785, 13895, 26907, 92439, 0 };
            const std::uint32_t dim7722JoeKuoD6Init[]   =   { 1, 3, 5, 15, 11, 5, 73, 167, 99, 887, 1213, 2019, 3781, 14345, 30249, 16215, 1893, 0 };
            const std::uint32_t dim7723JoeKuoD6Init[]   =   { 1, 1, 5, 1, 17, 11, 69, 145, 97, 393, 1587, 2513, 1011, 6933, 7945, 41387, 34361, 0 };
            const std::uint32_t dim7724JoeKuoD6Init[]   =   { 1, 1, 5, 1, 5, 59, 57, 1, 501, 855, 1485, 977, 4981, 7631, 31853, 30737, 103023, 0 };
            const std::uint32_t dim7725JoeKuoD6Init[]   =   { 1, 3, 1, 5, 3, 27, 55, 171, 317, 641, 1875, 2523, 1631, 4971, 18743, 25119, 118913, 0 };
            const std::uint32_t dim7726JoeKuoD6Init[]   =   { 1, 1, 3, 15, 7, 39, 73, 209, 125, 29, 1031, 1569, 1793, 5461, 985, 59441, 92997, 0 };
            const std::uint32_t dim7727JoeKuoD6Init[]   =   { 1, 3, 5, 11, 27, 23, 57, 13, 65, 555, 1309, 1149, 5125, 11573, 3835, 57913, 78699, 0 };
            const std::uint32_t dim7728JoeKuoD6Init[]   =   { 1, 3, 7, 5, 29, 7, 51, 131, 443, 623, 1491, 1067, 6647, 6277, 25799, 54843, 90869, 0 };
            const std::uint32_t dim7729JoeKuoD6Init[]   =   { 1, 1, 1, 11, 7, 33, 67, 113, 319, 665, 11, 1225, 3137, 16269, 20101, 40263, 31091, 0 };
            const std::uint32_t dim7730JoeKuoD6Init[]   =   { 1, 3, 5, 15, 7, 5, 101, 153, 165, 173, 97, 1651, 6633, 6071, 29079, 35641, 77305, 0 };
            const std::uint32_t dim7731JoeKuoD6Init[]   =   { 1, 3, 7, 13, 9, 45, 103, 55, 121, 1021, 1841, 315, 8127, 6547, 1093, 7181, 39575, 0 };
            const std::uint32_t dim7732JoeKuoD6Init[]   =   { 1, 3, 3, 11, 15, 17, 27, 55, 341, 443, 377, 681, 3635, 1091, 16719, 49403, 85507, 0 };
            const std::uint32_t dim7733JoeKuoD6Init[]   =   { 1, 3, 5, 5, 29, 53, 51, 213, 273, 475, 981, 549, 539, 14989, 4037, 23911, 45997, 0 };
            const std::uint32_t dim7734JoeKuoD6Init[]   =   { 1, 3, 5, 3, 27, 37, 73, 115, 331, 911, 991, 4049, 6299, 3919, 10231, 31507, 98651, 0 };
            const std::uint32_t dim7735JoeKuoD6Init[]   =   { 1, 1, 5, 13, 21, 13, 1, 175, 137, 837, 1067, 2845, 307, 4399, 15671, 1309, 107409, 0 };
            const std::uint32_t dim7736JoeKuoD6Init[]   =   { 1, 1, 3, 1, 5, 47, 111, 75, 193, 389, 157, 3731, 6237, 5053, 9933, 28413, 32939, 0 };
            const std::uint32_t dim7737JoeKuoD6Init[]   =   { 1, 1, 7, 5, 29, 1, 51, 85, 267, 935, 1021, 3135, 3135, 9263, 32597, 6779, 71473, 0 };
            const std::uint32_t dim7738JoeKuoD6Init[]   =   { 1, 3, 5, 9, 21, 59, 27, 99, 155, 507, 1911, 3501, 4307, 6755, 17127, 29815, 1577, 0 };
            const std::uint32_t dim7739JoeKuoD6Init[]   =   { 1, 1, 5, 1, 15, 63, 45, 105, 125, 299, 689, 3935, 7229, 5007, 25003, 30453, 27819, 0 };
            const std::uint32_t dim7740JoeKuoD6Init[]   =   { 1, 1, 7, 15, 19, 9, 67, 151, 45, 985, 2015, 833, 5435, 15383, 25881, 46735, 56717, 0 };
            const std::uint32_t dim7741JoeKuoD6Init[]   =   { 1, 1, 5, 15, 27, 59, 119, 163, 293, 63, 1251, 1309, 485, 4937, 27207, 47481, 114357, 0 };
            const std::uint32_t dim7742JoeKuoD6Init[]   =   { 1, 3, 5, 13, 23, 11, 111, 87, 329, 467, 1657, 3309, 3421, 12013, 23163, 14105, 88761, 0 };
            const std::uint32_t dim7743JoeKuoD6Init[]   =   { 1, 1, 5, 11, 17, 63, 9, 61, 299, 585, 341, 3375, 3213, 15953, 11455, 5333, 66889, 0 };
            const std::uint32_t dim7744JoeKuoD6Init[]   =   { 1, 3, 5, 5, 5, 35, 57, 235, 137, 543, 77, 2811, 857, 12793, 10791, 55711, 93353, 0 };
            const std::uint32_t dim7745JoeKuoD6Init[]   =   { 1, 3, 7, 3, 23, 37, 19, 81, 321, 23, 1625, 2359, 3569, 4685, 7385, 32677, 18073, 0 };
            const std::uint32_t dim7746JoeKuoD6Init[]   =   { 1, 3, 3, 7, 21, 35, 81, 229, 207, 547, 1397, 2709, 7159, 1265, 16823, 9921, 29159, 0 };
            const std::uint32_t dim7747JoeKuoD6Init[]   =   { 1, 3, 7, 13, 27, 13, 107, 241, 395, 317, 307, 3927, 1153, 15915, 25179, 25173, 21503, 0 };
            const std::uint32_t dim7748JoeKuoD6Init[]   =   { 1, 3, 1, 5, 1, 51, 25, 135, 381, 229, 1491, 2009, 3331, 16165, 8169, 65161, 9335, 0 };
            const std::uint32_t dim7749JoeKuoD6Init[]   =   { 1, 1, 5, 5, 17, 15, 57, 221, 183, 225, 1649, 3701, 299, 12349, 4691, 64479, 82237, 0 };
            const std::uint32_t dim7750JoeKuoD6Init[]   =   { 1, 3, 7, 7, 31, 39, 65, 183, 149, 67, 1697, 3933, 3709, 15501, 12583, 60117, 88691, 0 };
            const std::uint32_t dim7751JoeKuoD6Init[]   =   { 1, 1, 5, 15, 17, 49, 117, 233, 161, 891, 789, 1347, 4887, 10713, 10613, 4389, 42619, 0 };
            const std::uint32_t dim7752JoeKuoD6Init[]   =   { 1, 3, 5, 9, 13, 3, 83, 69, 381, 777, 743, 2843, 7233, 3285, 8931, 48667, 120777, 0 };
            const std::uint32_t dim7753JoeKuoD6Init[]   =   { 1, 3, 1, 3, 11, 7, 55, 107, 165, 533, 1897, 3385, 1069, 12805, 30125, 42729, 123977, 0 };
            const std::uint32_t dim7754JoeKuoD6Init[]   =   { 1, 1, 1, 5, 13, 17, 103, 237, 77, 537, 1843, 2817, 7467, 13647, 15259, 3525, 18313, 0 };
            const std::uint32_t dim7755JoeKuoD6Init[]   =   { 1, 1, 7, 7, 13, 59, 29, 197, 309, 917, 1173, 2605, 4313, 12007, 25611, 60409, 104931, 0 };
            const std::uint32_t dim7756JoeKuoD6Init[]   =   { 1, 3, 3, 3, 27, 57, 7, 207, 491, 467, 1973, 3075, 8043, 3977, 14517, 13179, 47111, 0 };
            const std::uint32_t dim7757JoeKuoD6Init[]   =   { 1, 1, 7, 5, 31, 33, 125, 235, 79, 847, 1893, 3875, 7513, 1435, 24959, 46813, 82053, 0 };
            const std::uint32_t dim7758JoeKuoD6Init[]   =   { 1, 3, 7, 5, 3, 53, 103, 1, 215, 71, 787, 223, 1399, 6793, 11281, 39201, 122119, 0 };
            const std::uint32_t dim7759JoeKuoD6Init[]   =   { 1, 3, 3, 3, 3, 57, 7, 151, 319, 463, 685, 2917, 4037, 14929, 11971, 41827, 57449, 0 };
            const std::uint32_t dim7760JoeKuoD6Init[]   =   { 1, 1, 7, 3, 5, 11, 15, 139, 379, 563, 135, 65, 5633, 7535, 1451, 18289, 62457, 0 };
            const std::uint32_t dim7761JoeKuoD6Init[]   =   { 1, 1, 1, 15, 11, 23, 37, 57, 205, 107, 995, 151, 3279, 2015, 28927, 40731, 95551, 0 };
            const std::uint32_t dim7762JoeKuoD6Init[]   =   { 1, 3, 5, 9, 15, 43, 95, 217, 203, 215, 203, 2207, 8189, 465, 2175, 29285, 25375, 0 };
            const std::uint32_t dim7763JoeKuoD6Init[]   =   { 1, 3, 3, 5, 19, 59, 51, 123, 285, 721, 1335, 1777, 1645, 15811, 16539, 14637, 123323, 0 };
            const std::uint32_t dim7764JoeKuoD6Init[]   =   { 1, 3, 5, 5, 11, 35, 23, 23, 259, 789, 567, 1921, 4743, 6635, 6965, 43025, 43175, 0 };
            const std::uint32_t dim7765JoeKuoD6Init[]   =   { 1, 3, 7, 3, 7, 27, 77, 121, 285, 65, 647, 591, 2553, 7163, 12057, 43675, 24227, 0 };
            const std::uint32_t dim7766JoeKuoD6Init[]   =   { 1, 1, 5, 9, 3, 25, 17, 85, 235, 715, 1913, 2391, 3719, 11029, 18359, 6323, 4703, 0 };
            const std::uint32_t dim7767JoeKuoD6Init[]   =   { 1, 1, 1, 3, 25, 31, 37, 31, 89, 311, 1797, 3409, 6785, 9627, 29721, 58591, 111429, 0 };
            const std::uint32_t dim7768JoeKuoD6Init[]   =   { 1, 3, 1, 5, 9, 37, 47, 45, 419, 115, 1009, 1359, 65, 1161, 15673, 16075, 63895, 0 };
            const std::uint32_t dim7769JoeKuoD6Init[]   =   { 1, 1, 3, 5, 25, 47, 27, 87, 441, 547, 1801, 3589, 3773, 12215, 14509, 12669, 99983, 0 };
            const std::uint32_t dim7770JoeKuoD6Init[]   =   { 1, 1, 1, 3, 19, 33, 51, 91, 447, 577, 491, 539, 3177, 7033, 21633, 51737, 47089, 0 };
            const std::uint32_t dim7771JoeKuoD6Init[]   =   { 1, 1, 3, 15, 23, 53, 93, 113, 143, 973, 999, 2355, 1489, 3451, 29821, 23769, 74633, 0 };
            const std::uint32_t dim7772JoeKuoD6Init[]   =   { 1, 3, 7, 11, 27, 1, 35, 109, 111, 51, 425, 3203, 2585, 11255, 20939, 281, 92133, 0 };
            const std::uint32_t dim7773JoeKuoD6Init[]   =   { 1, 1, 1, 11, 13, 37, 13, 149, 421, 655, 79, 3093, 6429, 1145, 27663, 52861, 81431, 0 };
            const std::uint32_t dim7774JoeKuoD6Init[]   =   { 1, 1, 5, 13, 19, 23, 105, 39, 97, 239, 469, 1047, 4727, 12009, 8055, 45557, 124219, 0 };
            const std::uint32_t dim7775JoeKuoD6Init[]   =   { 1, 1, 1, 7, 7, 7, 5, 53, 269, 391, 1893, 2263, 2109, 11531, 12109, 31437, 20445, 0 };
            const std::uint32_t dim7776JoeKuoD6Init[]   =   { 1, 1, 3, 11, 9, 35, 69, 209, 93, 455, 1117, 3297, 2597, 15035, 17943, 19955, 829, 0 };
            const std::uint32_t dim7777JoeKuoD6Init[]   =   { 1, 1, 5, 7, 23, 23, 101, 71, 339, 553, 1653, 2997, 1191, 3121, 4575, 49979, 17353, 0 };
            const std::uint32_t dim7778JoeKuoD6Init[]   =   { 1, 3, 3, 13, 13, 9, 51, 181, 33, 185, 111, 589, 3117, 10105, 28811, 31529, 79657, 0 };
            const std::uint32_t dim7779JoeKuoD6Init[]   =   { 1, 1, 5, 3, 9, 57, 103, 65, 211, 473, 519, 3815, 4087, 2767, 10213, 37829, 9523, 0 };
            const std::uint32_t dim7780JoeKuoD6Init[]   =   { 1, 1, 5, 7, 7, 31, 81, 161, 311, 617, 1689, 3133, 57, 14595, 22783, 18475, 85811, 0 };
            const std::uint32_t dim7781JoeKuoD6Init[]   =   { 1, 3, 5, 5, 21, 51, 99, 249, 7, 525, 885, 3981, 2851, 529, 947, 29885, 122901, 0 };
            const std::uint32_t dim7782JoeKuoD6Init[]   =   { 1, 3, 1, 5, 1, 23, 85, 91, 309, 747, 183, 1347, 2399, 15777, 16205, 15687, 117333, 0 };
            const std::uint32_t dim7783JoeKuoD6Init[]   =   { 1, 3, 7, 3, 29, 21, 99, 137, 297, 229, 1063, 2747, 6415, 7791, 4775, 62863, 50849, 0 };
            const std::uint32_t dim7784JoeKuoD6Init[]   =   { 1, 3, 1, 3, 11, 3, 53, 153, 103, 911, 1595, 1899, 1049, 11643, 21105, 61587, 92399, 0 };
            const std::uint32_t dim7785JoeKuoD6Init[]   =   { 1, 1, 5, 15, 29, 55, 99, 101, 181, 453, 1917, 2081, 4687, 4335, 2817, 11861, 103167, 0 };
            const std::uint32_t dim7786JoeKuoD6Init[]   =   { 1, 3, 7, 15, 11, 7, 9, 3, 477, 281, 1141, 453, 4993, 7843, 6169, 49785, 53827, 0 };
            const std::uint32_t dim7787JoeKuoD6Init[]   =   { 1, 3, 7, 11, 25, 61, 77, 159, 83, 95, 1223, 85, 6309, 16145, 18729, 133, 14193, 0 };
            const std::uint32_t dim7788JoeKuoD6Init[]   =   { 1, 3, 3, 1, 7, 27, 97, 183, 263, 59, 915, 3857, 3349, 8123, 11251, 55163, 125703, 0 };
            const std::uint32_t dim7789JoeKuoD6Init[]   =   { 1, 3, 5, 5, 17, 33, 57, 55, 503, 811, 953, 349, 1949, 9127, 31015, 14475, 116769, 0 };
            const std::uint32_t dim7790JoeKuoD6Init[]   =   { 1, 3, 1, 1, 3, 53, 59, 131, 421, 971, 89, 3047, 3513, 13599, 4569, 54525, 54779, 0 };
            const std::uint32_t dim7791JoeKuoD6Init[]   =   { 1, 1, 3, 11, 9, 45, 95, 123, 197, 257, 1073, 1461, 5, 12701, 12559, 34989, 71631, 0 };
            const std::uint32_t dim7792JoeKuoD6Init[]   =   { 1, 3, 3, 7, 1, 27, 55, 191, 447, 561, 1975, 2665, 1341, 8969, 18519, 47389, 70847, 0 };
            const std::uint32_t dim7793JoeKuoD6Init[]   =   { 1, 1, 5, 5, 3, 31, 15, 165, 95, 423, 233, 2309, 7777, 3503, 20105, 3085, 92349, 0 };
            const std::uint32_t dim7794JoeKuoD6Init[]   =   { 1, 3, 1, 13, 23, 61, 7, 55, 157, 1, 83, 515, 2169, 14397, 18149, 56855, 117265, 0 };
            const std::uint32_t dim7795JoeKuoD6Init[]   =   { 1, 3, 3, 3, 3, 59, 69, 95, 127, 241, 65, 3145, 491, 13809, 17529, 20223, 96579, 0 };
            const std::uint32_t dim7796JoeKuoD6Init[]   =   { 1, 1, 1, 5, 13, 43, 117, 163, 305, 955, 2007, 3337, 807, 16019, 5721, 5479, 90937, 0 };
            const std::uint32_t dim7797JoeKuoD6Init[]   =   { 1, 3, 3, 1, 19, 9, 127, 5, 113, 491, 1873, 2127, 7949, 5207, 32531, 775, 131065, 0 };
            const std::uint32_t dim7798JoeKuoD6Init[]   =   { 1, 1, 7, 3, 1, 3, 91, 187, 37, 873, 1039, 4075, 5645, 243, 15127, 45615, 3813, 0 };
            const std::uint32_t dim7799JoeKuoD6Init[]   =   { 1, 1, 3, 11, 3, 37, 67, 59, 439, 763, 213, 1099, 1659, 12783, 30297, 60713, 43497, 0 };
            const std::uint32_t dim7800JoeKuoD6Init[]   =   { 1, 3, 3, 13, 23, 49, 47, 191, 245, 985, 487, 3165, 7803, 2437, 19073, 30605, 119641, 0 };
            const std::uint32_t dim7801JoeKuoD6Init[]   =   { 1, 3, 7, 7, 19, 43, 7, 253, 93, 99, 145, 219, 699, 2433, 3009, 565, 99671, 0 };
            const std::uint32_t dim7802JoeKuoD6Init[]   =   { 1, 1, 3, 13, 7, 5, 9, 23, 219, 155, 925, 3427, 6631, 16353, 4115, 20831, 49525, 0 };
            const std::uint32_t dim7803JoeKuoD6Init[]   =   { 1, 1, 7, 11, 15, 45, 41, 35, 301, 273, 241, 4031, 5441, 8281, 9341, 8499, 73841, 0 };
            const std::uint32_t dim7804JoeKuoD6Init[]   =   { 1, 3, 7, 13, 9, 19, 79, 3, 163, 197, 509, 2301, 6971, 11525, 8805, 33805, 111595, 0 };
            const std::uint32_t dim7805JoeKuoD6Init[]   =   { 1, 3, 3, 1, 15, 45, 69, 253, 155, 639, 1045, 749, 3619, 14871, 18063, 49763, 66687, 0 };
            const std::uint32_t dim7806JoeKuoD6Init[]   =   { 1, 3, 3, 3, 29, 5, 41, 171, 265, 677, 1719, 2623, 1721, 12243, 18741, 39595, 92873, 0 };
            const std::uint32_t dim7807JoeKuoD6Init[]   =   { 1, 3, 5, 7, 27, 23, 69, 61, 453, 399, 1857, 3901, 6565, 15595, 1083, 15065, 91249, 0 };
            const std::uint32_t dim7808JoeKuoD6Init[]   =   { 1, 1, 5, 7, 1, 27, 9, 145, 95, 983, 685, 2079, 5117, 5037, 22695, 53135, 43569, 0 };
            const std::uint32_t dim7809JoeKuoD6Init[]   =   { 1, 1, 3, 5, 5, 7, 69, 59, 331, 409, 179, 333, 1293, 3863, 9473, 12537, 55605, 0 };
            const std::uint32_t dim7810JoeKuoD6Init[]   =   { 1, 3, 5, 1, 1, 19, 1, 49, 317, 769, 91, 2073, 1765, 1197, 15029, 52553, 57361, 0 };
            const std::uint32_t dim7811JoeKuoD6Init[]   =   { 1, 1, 5, 1, 23, 13, 11, 69, 345, 877, 41, 817, 617, 14415, 8337, 53973, 50007, 0 };
            const std::uint32_t dim7812JoeKuoD6Init[]   =   { 1, 1, 7, 3, 19, 27, 69, 103, 115, 893, 219, 2891, 2813, 9933, 26401, 63323, 30909, 0 };
            const std::uint32_t dim7813JoeKuoD6Init[]   =   { 1, 1, 5, 5, 27, 15, 119, 3, 11, 783, 541, 2431, 2395, 3921, 15471, 34657, 100295, 0 };
            const std::uint32_t dim7814JoeKuoD6Init[]   =   { 1, 1, 7, 11, 15, 25, 39, 191, 345, 1001, 1773, 715, 1627, 15957, 30085, 34097, 58747, 0 };
            const std::uint32_t dim7815JoeKuoD6Init[]   =   { 1, 1, 1, 5, 17, 43, 65, 81, 487, 387, 1359, 145, 2231, 6693, 15857, 59539, 79615, 0 };
            const std::uint32_t dim7816JoeKuoD6Init[]   =   { 1, 1, 3, 5, 15, 19, 17, 233, 247, 611, 587, 2587, 2321, 2835, 1477, 41991, 88143, 0 };
            const std::uint32_t dim7817JoeKuoD6Init[]   =   { 1, 3, 3, 15, 27, 15, 53, 61, 359, 989, 283, 3569, 5551, 11849, 20995, 34065, 69407, 0 };
            const std::uint32_t dim7818JoeKuoD6Init[]   =   { 1, 3, 3, 11, 13, 31, 41, 87, 379, 47, 1289, 3143, 4213, 8643, 17065, 10707, 62773, 0 };
            const std::uint32_t dim7819JoeKuoD6Init[]   =   { 1, 3, 7, 1, 9, 61, 59, 121, 453, 663, 27, 793, 4501, 7713, 285, 13279, 11633, 0 };
            const std::uint32_t dim7820JoeKuoD6Init[]   =   { 1, 1, 7, 5, 29, 51, 57, 15, 233, 743, 879, 2317, 3399, 15741, 605, 57529, 87427, 0 };
            const std::uint32_t dim7821JoeKuoD6Init[]   =   { 1, 1, 1, 1, 19, 59, 51, 119, 273, 403, 1649, 3877, 3561, 10931, 21139, 2599, 77957, 0 };
            const std::uint32_t dim7822JoeKuoD6Init[]   =   { 1, 3, 1, 3, 5, 1, 79, 131, 251, 585, 359, 2073, 7041, 13611, 22937, 24645, 72827, 0 };
            const std::uint32_t dim7823JoeKuoD6Init[]   =   { 1, 3, 7, 9, 19, 39, 93, 137, 359, 565, 1123, 1301, 4111, 13683, 1361, 25147, 38315, 0 };
            const std::uint32_t dim7824JoeKuoD6Init[]   =   { 1, 1, 5, 13, 27, 31, 11, 243, 111, 243, 1615, 1649, 2999, 15873, 19161, 57485, 35819, 0 };
            const std::uint32_t dim7825JoeKuoD6Init[]   =   { 1, 3, 3, 5, 25, 57, 61, 207, 219, 969, 303, 1165, 6753, 13473, 10789, 52883, 45205, 0 };
            const std::uint32_t dim7826JoeKuoD6Init[]   =   { 1, 1, 7, 11, 9, 53, 55, 175, 399, 981, 255, 2499, 373, 13131, 26803, 48017, 25599, 0 };
            const std::uint32_t dim7827JoeKuoD6Init[]   =   { 1, 1, 3, 3, 11, 23, 73, 25, 83, 39, 1813, 747, 3287, 795, 11917, 55509, 105057, 0 };
            const std::uint32_t dim7828JoeKuoD6Init[]   =   { 1, 3, 7, 15, 29, 59, 47, 171, 219, 875, 71, 123, 8131, 15595, 12471, 62439, 131, 0 };
            const std::uint32_t dim7829JoeKuoD6Init[]   =   { 1, 3, 5, 13, 9, 27, 119, 233, 323, 943, 375, 3647, 185, 1639, 431, 27225, 130175, 0 };
            const std::uint32_t dim7830JoeKuoD6Init[]   =   { 1, 3, 7, 3, 7, 17, 31, 155, 89, 835, 1015, 2019, 3973, 7087, 16899, 29591, 40797, 0 };
            const std::uint32_t dim7831JoeKuoD6Init[]   =   { 1, 3, 3, 1, 3, 11, 83, 231, 209, 537, 1227, 1519, 1059, 14027, 18591, 34031, 125755, 0 };
            const std::uint32_t dim7832JoeKuoD6Init[]   =   { 1, 3, 3, 1, 7, 39, 19, 99, 169, 961, 385, 1621, 7373, 7459, 8979, 23643, 17101, 0 };
            const std::uint32_t dim7833JoeKuoD6Init[]   =   { 1, 1, 3, 11, 11, 23, 61, 37, 359, 981, 209, 2555, 2673, 6501, 12731, 10735, 97321, 0 };
            const std::uint32_t dim7834JoeKuoD6Init[]   =   { 1, 1, 3, 13, 15, 61, 115, 119, 99, 755, 1933, 345, 3133, 12071, 26657, 7133, 18553, 0 };
            const std::uint32_t dim7835JoeKuoD6Init[]   =   { 1, 3, 1, 5, 17, 7, 29, 119, 445, 911, 89, 19, 6137, 8037, 19527, 22467, 29253, 0 };
            const std::uint32_t dim7836JoeKuoD6Init[]   =   { 1, 1, 3, 11, 31, 21, 119, 21, 249, 371, 343, 4037, 7539, 14473, 23829, 46415, 60911, 0 };
            const std::uint32_t dim7837JoeKuoD6Init[]   =   { 1, 1, 7, 9, 21, 53, 29, 149, 467, 893, 479, 359, 1007, 13955, 9667, 10245, 74761, 0 };
            const std::uint32_t dim7838JoeKuoD6Init[]   =   { 1, 3, 1, 7, 7, 45, 7, 77, 289, 271, 1329, 261, 5675, 8275, 7443, 57945, 117825, 0 };
            const std::uint32_t dim7839JoeKuoD6Init[]   =   { 1, 1, 1, 3, 21, 57, 117, 77, 287, 119, 1073, 915, 2521, 455, 7433, 56953, 84433, 0 };
            const std::uint32_t dim7840JoeKuoD6Init[]   =   { 1, 1, 1, 9, 27, 47, 1, 189, 303, 375, 215, 3117, 4541, 12877, 15523, 32317, 104213, 0 };
            const std::uint32_t dim7841JoeKuoD6Init[]   =   { 1, 1, 3, 1, 13, 39, 37, 249, 371, 159, 1073, 1351, 4703, 2715, 17463, 3945, 51523, 0 };
            const std::uint32_t dim7842JoeKuoD6Init[]   =   { 1, 3, 5, 5, 29, 15, 79, 25, 61, 995, 1081, 3377, 345, 13773, 4205, 20589, 83591, 0 };
            const std::uint32_t dim7843JoeKuoD6Init[]   =   { 1, 1, 3, 1, 9, 1, 41, 39, 389, 509, 561, 3273, 1911, 15271, 22655, 34713, 2045, 0 };
            const std::uint32_t dim7844JoeKuoD6Init[]   =   { 1, 3, 1, 15, 17, 1, 55, 55, 119, 707, 843, 2657, 3687, 11557, 18331, 4935, 110639, 0 };
            const std::uint32_t dim7845JoeKuoD6Init[]   =   { 1, 3, 5, 1, 23, 35, 119, 215, 471, 643, 1581, 1965, 2627, 2991, 3361, 6737, 111657, 0 };
            const std::uint32_t dim7846JoeKuoD6Init[]   =   { 1, 3, 5, 7, 9, 19, 33, 197, 33, 993, 1795, 595, 7113, 14721, 12647, 41035, 13669, 0 };
            const std::uint32_t dim7847JoeKuoD6Init[]   =   { 1, 1, 7, 15, 31, 39, 51, 157, 373, 473, 665, 3541, 6695, 11741, 5617, 17189, 129851, 0 };
            const std::uint32_t dim7848JoeKuoD6Init[]   =   { 1, 3, 3, 7, 15, 37, 33, 175, 391, 159, 717, 593, 113, 9331, 10685, 59003, 26975, 0 };
            const std::uint32_t dim7849JoeKuoD6Init[]   =   { 1, 1, 3, 5, 13, 41, 11, 109, 9, 899, 1503, 901, 6237, 7789, 9963, 14923, 63665, 0 };
            const std::uint32_t dim7850JoeKuoD6Init[]   =   { 1, 3, 7, 7, 25, 61, 3, 231, 235, 29, 1049, 1997, 5371, 9047, 29595, 49239, 108649, 0 };
            const std::uint32_t dim7851JoeKuoD6Init[]   =   { 1, 1, 3, 5, 27, 1, 53, 209, 315, 747, 1803, 11, 1815, 6539, 8839, 18385, 88681, 0 };
            const std::uint32_t dim7852JoeKuoD6Init[]   =   { 1, 1, 5, 13, 25, 55, 117, 197, 13, 689, 751, 1203, 2277, 1763, 23453, 54459, 118023, 0 };
            const std::uint32_t dim7853JoeKuoD6Init[]   =   { 1, 3, 3, 11, 21, 1, 51, 101, 429, 723, 273, 3021, 1491, 9923, 6629, 63741, 98813, 0 };
            const std::uint32_t dim7854JoeKuoD6Init[]   =   { 1, 1, 1, 15, 17, 25, 111, 251, 43, 403, 465, 17, 787, 6045, 32185, 22921, 115851, 0 };
            const std::uint32_t dim7855JoeKuoD6Init[]   =   { 1, 1, 5, 11, 11, 13, 13, 93, 489, 941, 1391, 383, 7735, 1921, 16199, 53099, 25181, 0 };
            const std::uint32_t dim7856JoeKuoD6Init[]   =   { 1, 3, 3, 7, 15, 1, 3, 159, 507, 867, 1589, 2111, 3839, 8989, 12589, 37657, 97055, 0 };
            const std::uint32_t dim7857JoeKuoD6Init[]   =   { 1, 3, 3, 13, 25, 23, 7, 95, 489, 1001, 105, 2737, 5013, 14465, 25383, 57551, 77425, 0 };
            const std::uint32_t dim7858JoeKuoD6Init[]   =   { 1, 3, 5, 3, 3, 7, 81, 15, 255, 297, 1183, 655, 741, 3081, 2141, 34493, 103707, 0 };
            const std::uint32_t dim7859JoeKuoD6Init[]   =   { 1, 1, 7, 9, 27, 57, 49, 121, 21, 239, 829, 2001, 613, 9569, 4419, 20007, 59109, 0 };
            const std::uint32_t dim7860JoeKuoD6Init[]   =   { 1, 3, 7, 1, 3, 21, 109, 255, 45, 333, 915, 1245, 5893, 765, 28289, 53927, 15335, 0 };
            const std::uint32_t dim7861JoeKuoD6Init[]   =   { 1, 3, 3, 7, 5, 35, 33, 79, 111, 509, 347, 3915, 2017, 6461, 11847, 17807, 48601, 0 };
            const std::uint32_t dim7862JoeKuoD6Init[]   =   { 1, 3, 5, 1, 13, 63, 87, 65, 507, 277, 339, 3637, 6289, 719, 9383, 38887, 55061, 0 };
            const std::uint32_t dim7863JoeKuoD6Init[]   =   { 1, 1, 5, 15, 17, 5, 59, 107, 355, 1021, 1849, 1807, 7679, 305, 31533, 1221, 98165, 0 };
            const std::uint32_t dim7864JoeKuoD6Init[]   =   { 1, 1, 1, 13, 19, 7, 37, 63, 267, 399, 1451, 2149, 1003, 13635, 18693, 215, 15887, 0 };
            const std::uint32_t dim7865JoeKuoD6Init[]   =   { 1, 1, 3, 7, 11, 63, 81, 251, 253, 963, 635, 1697, 6393, 9775, 24189, 9099, 106277, 0 };
            const std::uint32_t dim7866JoeKuoD6Init[]   =   { 1, 3, 3, 13, 17, 47, 63, 47, 279, 879, 271, 1655, 1897, 10743, 2607, 16695, 32779, 0 };
            const std::uint32_t dim7867JoeKuoD6Init[]   =   { 1, 3, 5, 15, 3, 1, 121, 181, 303, 973, 19, 3327, 3827, 2197, 31857, 22835, 122611, 0 };
            const std::uint32_t dim7868JoeKuoD6Init[]   =   { 1, 1, 5, 13, 25, 41, 105, 197, 195, 85, 1515, 2735, 7539, 7557, 24297, 38721, 46895, 0 };
            const std::uint32_t dim7869JoeKuoD6Init[]   =   { 1, 1, 1, 1, 15, 63, 33, 7, 43, 971, 781, 1461, 4483, 2113, 32459, 37653, 68017, 0 };
            const std::uint32_t dim7870JoeKuoD6Init[]   =   { 1, 3, 3, 9, 7, 1, 65, 183, 171, 695, 191, 3675, 6749, 6823, 3577, 45031, 81597, 0 };
            const std::uint32_t dim7871JoeKuoD6Init[]   =   { 1, 3, 3, 3, 9, 61, 13, 159, 295, 329, 943, 3293, 79, 14497, 21461, 4667, 96435, 0 };
            const std::uint32_t dim7872JoeKuoD6Init[]   =   { 1, 1, 7, 9, 29, 37, 117, 215, 295, 591, 1139, 3093, 7469, 7995, 13581, 48075, 5943, 0 };
            const std::uint32_t dim7873JoeKuoD6Init[]   =   { 1, 3, 1, 9, 11, 11, 117, 255, 419, 551, 1445, 1987, 1169, 14227, 31095, 36041, 63739, 0 };
            const std::uint32_t dim7874JoeKuoD6Init[]   =   { 1, 1, 7, 15, 17, 25, 81, 27, 87, 463, 1871, 551, 7449, 12231, 28645, 32663, 43037, 0 };
            const std::uint32_t dim7875JoeKuoD6Init[]   =   { 1, 3, 5, 11, 3, 49, 109, 123, 397, 113, 1269, 2433, 4463, 1257, 2127, 6677, 96009, 0 };
            const std::uint32_t dim7876JoeKuoD6Init[]   =   { 1, 1, 1, 11, 27, 19, 83, 123, 297, 867, 941, 3929, 3483, 4641, 32505, 48999, 66169, 0 };
            const std::uint32_t dim7877JoeKuoD6Init[]   =   { 1, 1, 5, 11, 5, 21, 11, 255, 369, 859, 657, 587, 5245, 12973, 22403, 47935, 121375, 0 };
            const std::uint32_t dim7878JoeKuoD6Init[]   =   { 1, 3, 1, 13, 17, 43, 83, 51, 339, 967, 499, 1485, 5203, 10053, 31707, 31443, 75033, 0 };
            const std::uint32_t dim7879JoeKuoD6Init[]   =   { 1, 1, 5, 13, 11, 5, 121, 121, 73, 101, 1751, 3805, 1333, 14043, 26957, 27557, 110899, 0 };
            const std::uint32_t dim7880JoeKuoD6Init[]   =   { 1, 3, 7, 11, 9, 7, 125, 237, 437, 177, 841, 175, 5509, 9157, 3129, 54119, 109315, 0 };
            const std::uint32_t dim7881JoeKuoD6Init[]   =   { 1, 3, 7, 15, 1, 59, 87, 121, 43, 475, 1589, 1267, 1501, 1585, 31705, 33959, 27247, 0 };
            const std::uint32_t dim7882JoeKuoD6Init[]   =   { 1, 1, 5, 3, 27, 63, 117, 205, 169, 701, 1081, 2835, 8049, 11875, 4143, 17663, 90043, 0 };
            const std::uint32_t dim7883JoeKuoD6Init[]   =   { 1, 3, 1, 9, 23, 27, 31, 141, 411, 145, 1177, 3681, 3403, 6943, 10729, 47219, 102713, 0 };
            const std::uint32_t dim7884JoeKuoD6Init[]   =   { 1, 1, 7, 11, 5, 49, 33, 27, 121, 865, 471, 1871, 6945, 10051, 4493, 7121, 65551, 0 };
            const std::uint32_t dim7885JoeKuoD6Init[]   =   { 1, 1, 5, 1, 17, 27, 53, 13, 31, 403, 1319, 1381, 1371, 11693, 18805, 54683, 30137, 0 };
            const std::uint32_t dim7886JoeKuoD6Init[]   =   { 1, 1, 7, 11, 9, 21, 71, 155, 79, 145, 943, 3891, 641, 3163, 28493, 14729, 83391, 0 };
            const std::uint32_t dim7887JoeKuoD6Init[]   =   { 1, 3, 3, 13, 3, 53, 21, 189, 245, 803, 1625, 4005, 1163, 16033, 5549, 14301, 115859, 0 };
            const std::uint32_t dim7888JoeKuoD6Init[]   =   { 1, 3, 1, 5, 17, 59, 61, 31, 293, 677, 1753, 1803, 1671, 14619, 22361, 61453, 78203, 0 };
            const std::uint32_t dim7889JoeKuoD6Init[]   =   { 1, 3, 3, 1, 5, 51, 99, 231, 175, 97, 1335, 689, 1913, 6157, 22757, 52395, 118347, 0 };
            const std::uint32_t dim7890JoeKuoD6Init[]   =   { 1, 3, 3, 7, 25, 11, 113, 19, 289, 507, 1143, 3437, 7965, 12551, 27603, 8423, 46713, 0 };
            const std::uint32_t dim7891JoeKuoD6Init[]   =   { 1, 1, 3, 9, 13, 1, 73, 9, 425, 407, 363, 2915, 4269, 2903, 9251, 17733, 80321, 0 };
            const std::uint32_t dim7892JoeKuoD6Init[]   =   { 1, 1, 3, 11, 31, 47, 37, 211, 433, 237, 1069, 1891, 6175, 9305, 30385, 2497, 94775, 0 };
            const std::uint32_t dim7893JoeKuoD6Init[]   =   { 1, 1, 3, 1, 23, 5, 113, 103, 427, 587, 1863, 1863, 679, 2575, 13059, 16163, 42289, 0 };
            const std::uint32_t dim7894JoeKuoD6Init[]   =   { 1, 1, 5, 3, 7, 17, 45, 33, 209, 609, 1897, 95, 5123, 2239, 5483, 60715, 126497, 0 };
            const std::uint32_t dim7895JoeKuoD6Init[]   =   { 1, 1, 5, 11, 1, 55, 67, 223, 41, 967, 337, 2511, 7879, 1157, 17635, 64081, 421, 0 };
            const std::uint32_t dim7896JoeKuoD6Init[]   =   { 1, 3, 3, 9, 27, 33, 87, 97, 231, 895, 1337, 829, 47, 8481, 14059, 57209, 109159, 0 };
            const std::uint32_t dim7897JoeKuoD6Init[]   =   { 1, 3, 7, 1, 25, 5, 41, 161, 393, 523, 1623, 3761, 1933, 8319, 17309, 46717, 97299, 0 };
            const std::uint32_t dim7898JoeKuoD6Init[]   =   { 1, 1, 1, 11, 5, 55, 19, 191, 41, 791, 1611, 59, 2633, 13873, 25859, 42879, 54807, 0 };
            const std::uint32_t dim7899JoeKuoD6Init[]   =   { 1, 3, 1, 11, 11, 33, 5, 13, 199, 411, 895, 759, 2735, 16225, 31469, 24081, 31857, 0 };
            const std::uint32_t dim7900JoeKuoD6Init[]   =   { 1, 1, 7, 13, 27, 57, 21, 191, 389, 977, 1013, 3493, 6401, 15957, 23181, 52461, 41853, 0 };
            const std::uint32_t dim7901JoeKuoD6Init[]   =   { 1, 3, 7, 5, 23, 19, 117, 117, 427, 923, 1347, 3099, 247, 8879, 5309, 53277, 100625, 0 };
            const std::uint32_t dim7902JoeKuoD6Init[]   =   { 1, 1, 5, 13, 11, 23, 69, 37, 119, 329, 1935, 2851, 5127, 6907, 24651, 11135, 118287, 0 };
            const std::uint32_t dim7903JoeKuoD6Init[]   =   { 1, 1, 3, 15, 23, 1, 69, 107, 253, 771, 1697, 4035, 3219, 15011, 6995, 19255, 39909, 0 };
            const std::uint32_t dim7904JoeKuoD6Init[]   =   { 1, 3, 1, 1, 5, 21, 35, 173, 407, 603, 27, 3589, 2879, 2755, 17679, 6145, 95989, 0 };
            const std::uint32_t dim7905JoeKuoD6Init[]   =   { 1, 1, 5, 13, 31, 23, 61, 139, 341, 593, 1673, 4031, 4809, 1107, 22657, 29073, 53401, 0 };
            const std::uint32_t dim7906JoeKuoD6Init[]   =   { 1, 3, 1, 15, 13, 37, 39, 61, 443, 417, 1125, 1529, 1943, 7317, 2985, 50285, 107069, 0 };
            const std::uint32_t dim7907JoeKuoD6Init[]   =   { 1, 1, 3, 9, 5, 51, 87, 91, 31, 491, 1455, 1685, 2579, 6023, 10989, 64635, 130147, 0 };
            const std::uint32_t dim7908JoeKuoD6Init[]   =   { 1, 3, 5, 5, 31, 23, 15, 163, 357, 161, 1597, 1571, 5039, 13213, 32221, 4405, 88079, 0 };
            const std::uint32_t dim7909JoeKuoD6Init[]   =   { 1, 1, 1, 15, 13, 43, 7, 109, 243, 389, 683, 2671, 8003, 4187, 6507, 11171, 116727, 0 };
            const std::uint32_t dim7910JoeKuoD6Init[]   =   { 1, 3, 7, 1, 17, 31, 53, 5, 227, 755, 1755, 2939, 1789, 8951, 16777, 30203, 79005, 0 };
            const std::uint32_t dim7911JoeKuoD6Init[]   =   { 1, 3, 3, 9, 27, 5, 111, 241, 89, 333, 371, 1035, 5719, 2433, 29343, 50829, 25131, 0 };
            const std::uint32_t dim7912JoeKuoD6Init[]   =   { 1, 1, 3, 13, 7, 37, 125, 69, 79, 397, 1595, 123, 255, 2257, 10881, 27085, 99411, 0 };
            const std::uint32_t dim7913JoeKuoD6Init[]   =   { 1, 1, 3, 15, 1, 35, 61, 73, 507, 775, 1631, 2005, 4277, 8421, 5669, 39221, 19053, 0 };
            const std::uint32_t dim7914JoeKuoD6Init[]   =   { 1, 1, 3, 7, 15, 17, 65, 157, 19, 997, 861, 1249, 4059, 7975, 955, 5833, 97733, 0 };
            const std::uint32_t dim7915JoeKuoD6Init[]   =   { 1, 1, 5, 5, 21, 43, 1, 181, 1, 17, 1337, 3333, 3761, 12283, 20941, 231, 30457, 0 };
            const std::uint32_t dim7916JoeKuoD6Init[]   =   { 1, 3, 3, 7, 7, 23, 105, 101, 101, 757, 1407, 565, 2187, 1529, 29385, 22847, 57675, 0 };
            const std::uint32_t dim7917JoeKuoD6Init[]   =   { 1, 3, 3, 1, 11, 3, 65, 93, 201, 773, 1037, 1325, 673, 6625, 2909, 63435, 114311, 0 };
            const std::uint32_t dim7918JoeKuoD6Init[]   =   { 1, 3, 5, 1, 21, 43, 87, 37, 491, 323, 1093, 2493, 4755, 7225, 12037, 9483, 70351, 0 };
            const std::uint32_t dim7919JoeKuoD6Init[]   =   { 1, 1, 7, 9, 23, 39, 59, 117, 103, 645, 1975, 1177, 55, 325, 23781, 64365, 94915, 0 };
            const std::uint32_t dim7920JoeKuoD6Init[]   =   { 1, 3, 7, 15, 21, 29, 109, 35, 307, 847, 777, 3457, 7899, 17, 24065, 10517, 35651, 0 };
            const std::uint32_t dim7921JoeKuoD6Init[]   =   { 1, 1, 7, 9, 25, 35, 49, 131, 377, 429, 1773, 2107, 6305, 15209, 9567, 17685, 5599, 0 };
            const std::uint32_t dim7922JoeKuoD6Init[]   =   { 1, 1, 3, 11, 13, 27, 47, 125, 483, 229, 921, 2733, 2217, 2615, 24135, 28759, 109411, 0 };
            const std::uint32_t dim7923JoeKuoD6Init[]   =   { 1, 3, 1, 7, 19, 45, 23, 195, 445, 955, 853, 2877, 6889, 9507, 2009, 18747, 50545, 0 };
            const std::uint32_t dim7924JoeKuoD6Init[]   =   { 1, 1, 1, 5, 15, 35, 75, 177, 145, 683, 309, 893, 4999, 827, 26563, 30819, 111115, 0 };
            const std::uint32_t dim7925JoeKuoD6Init[]   =   { 1, 3, 3, 11, 5, 45, 49, 39, 93, 653, 1053, 2553, 863, 12185, 30261, 16459, 121061, 0 };
            const std::uint32_t dim7926JoeKuoD6Init[]   =   { 1, 3, 7, 5, 11, 29, 57, 43, 409, 71, 67, 3537, 263, 13237, 8825, 58411, 44629, 0 };
            const std::uint32_t dim7927JoeKuoD6Init[]   =   { 1, 1, 5, 13, 1, 37, 23, 171, 13, 309, 239, 2023, 6233, 8751, 11371, 5825, 77355, 0 };
            const std::uint32_t dim7928JoeKuoD6Init[]   =   { 1, 3, 1, 13, 5, 1, 47, 217, 369, 609, 453, 879, 4337, 4441, 8785, 51963, 53819, 0 };
            const std::uint32_t dim7929JoeKuoD6Init[]   =   { 1, 3, 5, 5, 23, 1, 67, 147, 27, 121, 1369, 569, 1519, 11585, 18193, 30889, 78055, 0 };
            const std::uint32_t dim7930JoeKuoD6Init[]   =   { 1, 1, 1, 13, 11, 53, 33, 37, 419, 111, 1649, 2495, 6105, 12385, 30865, 3683, 63813, 0 };
            const std::uint32_t dim7931JoeKuoD6Init[]   =   { 1, 3, 3, 5, 17, 35, 107, 235, 471, 735, 1093, 1007, 567, 173, 9623, 39533, 56455, 0 };
            const std::uint32_t dim7932JoeKuoD6Init[]   =   { 1, 1, 7, 15, 27, 13, 123, 211, 407, 857, 801, 3951, 8153, 4427, 15333, 13217, 92675, 0 };
            const std::uint32_t dim7933JoeKuoD6Init[]   =   { 1, 1, 1, 7, 11, 61, 99, 131, 121, 119, 1483, 1485, 3521, 13163, 24899, 56849, 111943, 0 };
            const std::uint32_t dim7934JoeKuoD6Init[]   =   { 1, 3, 3, 1, 19, 1, 29, 139, 127, 557, 1913, 1487, 1381, 185, 11195, 52499, 45059, 0 };
            const std::uint32_t dim7935JoeKuoD6Init[]   =   { 1, 3, 7, 11, 5, 29, 95, 111, 235, 55, 1101, 2631, 1219, 9867, 22209, 3095, 56793, 0 };
            const std::uint32_t dim7936JoeKuoD6Init[]   =   { 1, 3, 7, 1, 31, 61, 37, 125, 241, 985, 1079, 1439, 433, 2779, 8463, 59985, 39667, 0 };
            const std::uint32_t dim7937JoeKuoD6Init[]   =   { 1, 3, 7, 15, 5, 7, 71, 7, 435, 727, 1611, 135, 1421, 8329, 29995, 64243, 58285, 0 };
            const std::uint32_t dim7938JoeKuoD6Init[]   =   { 1, 3, 3, 15, 27, 11, 121, 27, 281, 499, 267, 2651, 7575, 9499, 5051, 49475, 79573, 0 };
            const std::uint32_t dim7939JoeKuoD6Init[]   =   { 1, 3, 3, 15, 29, 47, 11, 183, 235, 537, 79, 2467, 3751, 831, 6725, 52173, 108645, 0 };
            const std::uint32_t dim7940JoeKuoD6Init[]   =   { 1, 3, 5, 13, 23, 31, 23, 19, 477, 511, 727, 183, 5955, 7613, 31979, 8441, 39835, 0 };
            const std::uint32_t dim7941JoeKuoD6Init[]   =   { 1, 1, 5, 7, 17, 31, 53, 133, 387, 787, 1573, 89, 1975, 1825, 19963, 27203, 124923, 0 };
            const std::uint32_t dim7942JoeKuoD6Init[]   =   { 1, 1, 1, 9, 3, 15, 125, 135, 89, 37, 517, 3931, 2013, 2143, 25413, 18421, 6097, 0 };
            const std::uint32_t dim7943JoeKuoD6Init[]   =   { 1, 1, 3, 11, 23, 29, 89, 45, 53, 135, 223, 3523, 7921, 3271, 1819, 40931, 65471, 0 };
            const std::uint32_t dim7944JoeKuoD6Init[]   =   { 1, 1, 1, 13, 17, 3, 121, 25, 509, 61, 1009, 2009, 7813, 8499, 5807, 63171, 75991, 0 };
            const std::uint32_t dim7945JoeKuoD6Init[]   =   { 1, 3, 5, 13, 15, 35, 37, 45, 161, 683, 1665, 59, 6297, 9595, 10193, 46745, 105411, 0 };
            const std::uint32_t dim7946JoeKuoD6Init[]   =   { 1, 3, 1, 7, 21, 19, 85, 107, 3, 845, 673, 1271, 7581, 15971, 27085, 35375, 29027, 0 };
            const std::uint32_t dim7947JoeKuoD6Init[]   =   { 1, 3, 3, 9, 5, 17, 79, 137, 123, 809, 583, 3507, 7559, 2857, 13911, 57083, 8595, 0 };
            const std::uint32_t dim7948JoeKuoD6Init[]   =   { 1, 1, 7, 5, 31, 29, 77, 33, 439, 787, 1223, 2471, 5851, 15891, 27925, 51661, 82645, 0 };
            const std::uint32_t dim7949JoeKuoD6Init[]   =   { 1, 1, 7, 15, 19, 35, 35, 37, 197, 245, 799, 3971, 277, 11289, 20111, 13857, 104571, 0 };
            const std::uint32_t dim7950JoeKuoD6Init[]   =   { 1, 3, 5, 15, 19, 3, 65, 17, 201, 1007, 1665, 107, 2409, 1469, 23265, 24547, 8189, 0 };
            const std::uint32_t dim7951JoeKuoD6Init[]   =   { 1, 3, 1, 13, 29, 45, 109, 243, 43, 383, 631, 265, 6671, 15333, 21931, 30675, 103077, 0 };
            const std::uint32_t dim7952JoeKuoD6Init[]   =   { 1, 1, 5, 1, 25, 25, 77, 189, 109, 777, 1485, 2265, 1403, 2627, 13843, 27263, 14263, 0 };
            const std::uint32_t dim7953JoeKuoD6Init[]   =   { 1, 3, 5, 1, 13, 49, 73, 107, 225, 243, 1253, 3503, 735, 2605, 27165, 45467, 93001, 0 };
            const std::uint32_t dim7954JoeKuoD6Init[]   =   { 1, 1, 5, 9, 15, 17, 1, 33, 69, 321, 1375, 3635, 8131, 6579, 1225, 38699, 17447, 0 };
            const std::uint32_t dim7955JoeKuoD6Init[]   =   { 1, 3, 5, 3, 25, 49, 15, 149, 483, 37, 1929, 1219, 5841, 11975, 805, 31339, 130971, 0 };
            const std::uint32_t dim7956JoeKuoD6Init[]   =   { 1, 3, 3, 3, 15, 29, 3, 143, 291, 593, 1769, 3603, 1693, 151, 27701, 9015, 25847, 0 };
            const std::uint32_t dim7957JoeKuoD6Init[]   =   { 1, 3, 1, 11, 5, 35, 55, 127, 137, 71, 967, 2501, 1023, 2061, 31387, 44011, 130121, 0 };
            const std::uint32_t dim7958JoeKuoD6Init[]   =   { 1, 1, 7, 1, 29, 13, 93, 41, 125, 263, 521, 2633, 4361, 12153, 30647, 55883, 65185, 0 };
            const std::uint32_t dim7959JoeKuoD6Init[]   =   { 1, 3, 7, 9, 23, 19, 61, 197, 139, 463, 1867, 3627, 5185, 8251, 26977, 48027, 66301, 0 };
            const std::uint32_t dim7960JoeKuoD6Init[]   =   { 1, 3, 3, 7, 27, 53, 25, 137, 175, 155, 1843, 2253, 4797, 4989, 32613, 55779, 91625, 0 };
            const std::uint32_t dim7961JoeKuoD6Init[]   =   { 1, 3, 3, 11, 1, 5, 21, 233, 295, 675, 47, 2995, 8075, 8201, 3845, 23925, 82559, 0 };
            const std::uint32_t dim7962JoeKuoD6Init[]   =   { 1, 1, 3, 7, 31, 53, 93, 21, 307, 709, 9, 3061, 3935, 11009, 13411, 3657, 30251, 0 };
            const std::uint32_t dim7963JoeKuoD6Init[]   =   { 1, 3, 7, 13, 13, 25, 51, 205, 391, 897, 275, 333, 6831, 9383, 16101, 14301, 99101, 0 };
            const std::uint32_t dim7964JoeKuoD6Init[]   =   { 1, 1, 5, 15, 17, 47, 119, 7, 189, 765, 753, 2909, 3373, 2379, 20331, 61535, 51345, 0 };
            const std::uint32_t dim7965JoeKuoD6Init[]   =   { 1, 1, 3, 1, 27, 43, 9, 185, 9, 197, 1179, 67, 7689, 9679, 29683, 29905, 29393, 0 };
            const std::uint32_t dim7966JoeKuoD6Init[]   =   { 1, 1, 5, 5, 31, 55, 69, 9, 477, 91, 1705, 1877, 5463, 15401, 13449, 27541, 125521, 0 };
            const std::uint32_t dim7967JoeKuoD6Init[]   =   { 1, 1, 7, 15, 15, 33, 11, 233, 69, 771, 845, 2715, 5293, 10351, 19557, 15319, 36857, 0 };
            const std::uint32_t dim7968JoeKuoD6Init[]   =   { 1, 3, 7, 7, 15, 9, 123, 47, 165, 739, 361, 1675, 2743, 8021, 10241, 48275, 51935, 0 };
            const std::uint32_t dim7969JoeKuoD6Init[]   =   { 1, 1, 5, 1, 9, 25, 99, 83, 487, 627, 343, 3233, 6697, 13197, 19771, 38337, 89139, 0 };
            const std::uint32_t dim7970JoeKuoD6Init[]   =   { 1, 3, 7, 13, 1, 31, 15, 63, 463, 621, 935, 1093, 6043, 14051, 13665, 43413, 104893, 0 };
            const std::uint32_t dim7971JoeKuoD6Init[]   =   { 1, 1, 1, 3, 27, 1, 47, 151, 127, 357, 689, 3263, 141, 4459, 9847, 205, 88493, 0 };
            const std::uint32_t dim7972JoeKuoD6Init[]   =   { 1, 3, 7, 15, 29, 13, 41, 113, 495, 421, 195, 197, 6857, 10555, 22861, 30229, 31707, 0 };
            const std::uint32_t dim7973JoeKuoD6Init[]   =   { 1, 3, 5, 11, 11, 1, 89, 227, 425, 623, 1605, 1901, 7933, 7211, 16301, 3403, 59651, 0 };
            const std::uint32_t dim7974JoeKuoD6Init[]   =   { 1, 1, 3, 3, 27, 41, 37, 89, 395, 903, 1641, 2739, 5599, 11371, 8683, 61125, 105231, 0 };
            const std::uint32_t dim7975JoeKuoD6Init[]   =   { 1, 3, 7, 9, 1, 17, 51, 233, 507, 783, 459, 1187, 7281, 15809, 27637, 6067, 125877, 0 };
            const std::uint32_t dim7976JoeKuoD6Init[]   =   { 1, 3, 1, 3, 13, 57, 5, 199, 261, 357, 1255, 1849, 8013, 10313, 9375, 1271, 64117, 0 };
            const std::uint32_t dim7977JoeKuoD6Init[]   =   { 1, 3, 1, 11, 9, 59, 55, 95, 401, 423, 1657, 513, 3565, 12957, 19243, 53027, 11323, 0 };
            const std::uint32_t dim7978JoeKuoD6Init[]   =   { 1, 3, 7, 13, 27, 35, 121, 215, 397, 991, 191, 3443, 3829, 6107, 5381, 48497, 107997, 0 };
            const std::uint32_t dim7979JoeKuoD6Init[]   =   { 1, 1, 5, 5, 19, 15, 21, 53, 165, 835, 1599, 3245, 5609, 5991, 18141, 28075, 102809, 0 };
            const std::uint32_t dim7980JoeKuoD6Init[]   =   { 1, 3, 5, 9, 25, 21, 71, 15, 453, 475, 915, 3097, 5869, 699, 13883, 34919, 127211, 0 };
            const std::uint32_t dim7981JoeKuoD6Init[]   =   { 1, 1, 3, 7, 21, 53, 27, 207, 373, 703, 593, 17, 6991, 15013, 10125, 34801, 129245, 0 };
            const std::uint32_t dim7982JoeKuoD6Init[]   =   { 1, 3, 3, 13, 17, 9, 89, 95, 291, 681, 1415, 2323, 2885, 11381, 7703, 3691, 51505, 0 };
            const std::uint32_t dim7983JoeKuoD6Init[]   =   { 1, 1, 1, 11, 15, 63, 55, 153, 373, 665, 983, 3987, 5997, 6873, 27031, 65449, 22021, 0 };
            const std::uint32_t dim7984JoeKuoD6Init[]   =   { 1, 1, 5, 5, 1, 55, 119, 61, 159, 889, 225, 709, 1879, 2521, 69, 7815, 18733, 0 };
            const std::uint32_t dim7985JoeKuoD6Init[]   =   { 1, 3, 5, 11, 23, 53, 23, 61, 71, 993, 633, 1829, 3465, 12465, 30205, 40723, 74499, 0 };
            const std::uint32_t dim7986JoeKuoD6Init[]   =   { 1, 3, 3, 1, 17, 37, 19, 43, 55, 133, 1171, 3101, 3963, 5177, 24791, 7255, 10263, 0 };
            const std::uint32_t dim7987JoeKuoD6Init[]   =   { 1, 3, 7, 1, 21, 13, 21, 87, 237, 629, 1167, 3699, 597, 6251, 11545, 34429, 104393, 0 };
            const std::uint32_t dim7988JoeKuoD6Init[]   =   { 1, 1, 7, 1, 11, 53, 105, 111, 463, 869, 549, 2423, 17, 917, 879, 49367, 72235, 0 };
            const std::uint32_t dim7989JoeKuoD6Init[]   =   { 1, 1, 5, 15, 17, 51, 69, 55, 309, 867, 257, 573, 4821, 5245, 28033, 61801, 18253, 0 };
            const std::uint32_t dim7990JoeKuoD6Init[]   =   { 1, 1, 5, 3, 1, 23, 103, 241, 13, 267, 21, 1751, 6637, 12537, 26741, 40651, 94493, 0 };
            const std::uint32_t dim7991JoeKuoD6Init[]   =   { 1, 3, 3, 13, 25, 35, 21, 83, 337, 363, 1111, 1865, 7889, 985, 465, 40287, 64469, 0 };
            const std::uint32_t dim7992JoeKuoD6Init[]   =   { 1, 1, 7, 5, 27, 1, 99, 95, 209, 211, 1445, 1577, 6097, 13813, 22463, 64395, 106383, 0 };
            const std::uint32_t dim7993JoeKuoD6Init[]   =   { 1, 3, 1, 15, 1, 45, 77, 247, 273, 1023, 1377, 1989, 5787, 15267, 24363, 42717, 125617, 0 };
            const std::uint32_t dim7994JoeKuoD6Init[]   =   { 1, 1, 1, 3, 9, 49, 79, 171, 427, 439, 1725, 3179, 6263, 12437, 31353, 22077, 94455, 0 };
            const std::uint32_t dim7995JoeKuoD6Init[]   =   { 1, 3, 5, 11, 11, 45, 57, 97, 409, 935, 967, 2509, 3431, 5707, 19473, 15853, 129059, 0 };
            const std::uint32_t dim7996JoeKuoD6Init[]   =   { 1, 1, 7, 5, 7, 21, 105, 29, 359, 145, 1691, 131, 6721, 10971, 16173, 38193, 37091, 0 };
            const std::uint32_t dim7997JoeKuoD6Init[]   =   { 1, 1, 1, 15, 15, 35, 5, 185, 455, 507, 681, 3355, 2091, 3437, 27231, 28527, 5383, 0 };
            const std::uint32_t dim7998JoeKuoD6Init[]   =   { 1, 3, 5, 3, 7, 29, 33, 127, 57, 495, 1069, 3635, 7461, 9861, 18757, 39039, 92421, 0 };
            const std::uint32_t dim7999JoeKuoD6Init[]   =   { 1, 3, 5, 5, 11, 31, 51, 59, 413, 417, 1577, 2837, 5229, 4501, 18645, 37613, 31325, 0 };
            const std::uint32_t dim8000JoeKuoD6Init[]   =   { 1, 1, 5, 13, 15, 61, 17, 247, 413, 817, 907, 2249, 3901, 11275, 7469, 33403, 30629, 0 };
            const std::uint32_t dim8001JoeKuoD6Init[]   =   { 1, 3, 5, 7, 31, 7, 109, 177, 277, 75, 449, 3029, 7135, 427, 26641, 43157, 47671, 0 };
            const std::uint32_t dim8002JoeKuoD6Init[]   =   { 1, 3, 7, 13, 29, 63, 21, 187, 471, 289, 835, 3885, 6111, 8721, 9841, 24017, 18673, 0 };
            const std::uint32_t dim8003JoeKuoD6Init[]   =   { 1, 1, 5, 13, 25, 37, 15, 35, 227, 623, 47, 189, 3443, 1911, 8579, 50911, 10895, 0 };
            const std::uint32_t dim8004JoeKuoD6Init[]   =   { 1, 3, 1, 1, 29, 53, 89, 101, 251, 203, 821, 2485, 633, 7943, 27563, 58735, 72057, 0 };
            const std::uint32_t dim8005JoeKuoD6Init[]   =   { 1, 3, 7, 9, 23, 61, 121, 199, 19, 165, 131, 1373, 637, 7307, 7109, 42475, 126669, 0 };
            const std::uint32_t dim8006JoeKuoD6Init[]   =   { 1, 3, 7, 13, 7, 5, 125, 173, 365, 65, 565, 751, 3343, 13421, 6177, 39095, 97375, 0 };
            const std::uint32_t dim8007JoeKuoD6Init[]   =   { 1, 1, 7, 3, 1, 59, 65, 39, 307, 793, 887, 3291, 3405, 4497, 19351, 1821, 67861, 0 };
            const std::uint32_t dim8008JoeKuoD6Init[]   =   { 1, 1, 1, 3, 19, 9, 101, 183, 163, 819, 769, 49, 5293, 3715, 4055, 32403, 90763, 0 };
            const std::uint32_t dim8009JoeKuoD6Init[]   =   { 1, 3, 3, 1, 27, 31, 21, 123, 457, 1021, 1791, 2217, 6171, 11445, 15605, 59945, 19663, 0 };
            const std::uint32_t dim8010JoeKuoD6Init[]   =   { 1, 1, 1, 9, 13, 53, 61, 201, 457, 111, 1217, 377, 5871, 4591, 16379, 42817, 129807, 0 };
            const std::uint32_t dim8011JoeKuoD6Init[]   =   { 1, 3, 1, 5, 23, 37, 25, 7, 125, 651, 349, 3727, 1487, 5103, 31407, 40215, 16065, 0 };
            const std::uint32_t dim8012JoeKuoD6Init[]   =   { 1, 1, 3, 11, 19, 29, 1, 193, 13, 287, 331, 985, 5391, 7307, 28075, 9939, 84999, 0 };
            const std::uint32_t dim8013JoeKuoD6Init[]   =   { 1, 1, 1, 11, 21, 37, 117, 241, 229, 957, 2019, 819, 459, 6185, 21533, 64725, 24709, 0 };
            const std::uint32_t dim8014JoeKuoD6Init[]   =   { 1, 3, 5, 13, 11, 25, 107, 245, 175, 519, 629, 537, 2227, 15123, 10619, 32611, 118697, 0 };
            const std::uint32_t dim8015JoeKuoD6Init[]   =   { 1, 3, 1, 11, 5, 53, 119, 253, 489, 181, 1365, 3465, 1323, 949, 3657, 2467, 38545, 0 };
            const std::uint32_t dim8016JoeKuoD6Init[]   =   { 1, 1, 3, 9, 27, 17, 109, 19, 297, 541, 89, 3021, 761, 5577, 907, 21405, 128029, 0 };
            const std::uint32_t dim8017JoeKuoD6Init[]   =   { 1, 1, 3, 9, 31, 9, 61, 149, 267, 707, 671, 2733, 1247, 14623, 6395, 42579, 30845, 0 };
            const std::uint32_t dim8018JoeKuoD6Init[]   =   { 1, 1, 7, 7, 25, 29, 63, 41, 309, 275, 2019, 1373, 1003, 13891, 16571, 16209, 30115, 0 };
            const std::uint32_t dim8019JoeKuoD6Init[]   =   { 1, 3, 7, 1, 5, 21, 53, 97, 475, 799, 1963, 1181, 4187, 8767, 24779, 10403, 98349, 0 };
            const std::uint32_t dim8020JoeKuoD6Init[]   =   { 1, 3, 3, 13, 19, 9, 125, 227, 347, 535, 353, 3087, 769, 9049, 20145, 27433, 23105, 0 };
            const std::uint32_t dim8021JoeKuoD6Init[]   =   { 1, 1, 1, 15, 7, 61, 51, 113, 403, 501, 1767, 2785, 7151, 14517, 17533, 24913, 7121, 0 };
            const std::uint32_t dim8022JoeKuoD6Init[]   =   { 1, 1, 1, 9, 7, 21, 27, 169, 425, 567, 31, 35, 7859, 929, 6545, 33983, 13227, 0 };
            const std::uint32_t dim8023JoeKuoD6Init[]   =   { 1, 1, 5, 15, 11, 15, 69, 33, 127, 1005, 1947, 989, 6333, 15587, 18523, 53547, 115613, 0 };
            const std::uint32_t dim8024JoeKuoD6Init[]   =   { 1, 3, 5, 3, 1, 55, 7, 99, 213, 737, 363, 3167, 3949, 3723, 15777, 23207, 22901, 0 };
            const std::uint32_t dim8025JoeKuoD6Init[]   =   { 1, 1, 1, 9, 9, 29, 121, 85, 467, 811, 1, 3543, 6259, 4477, 31371, 27633, 22995, 0 };
            const std::uint32_t dim8026JoeKuoD6Init[]   =   { 1, 3, 5, 3, 11, 21, 95, 19, 55, 71, 803, 3655, 3749, 5113, 13611, 38097, 20943, 0 };
            const std::uint32_t dim8027JoeKuoD6Init[]   =   { 1, 3, 3, 11, 19, 25, 127, 105, 447, 499, 485, 881, 2649, 10297, 22283, 18305, 128919, 0 };
            const std::uint32_t dim8028JoeKuoD6Init[]   =   { 1, 3, 7, 1, 11, 45, 21, 87, 481, 645, 815, 793, 5763, 3945, 14379, 19623, 103199, 0 };
            const std::uint32_t dim8029JoeKuoD6Init[]   =   { 1, 3, 5, 1, 3, 45, 39, 229, 359, 151, 1079, 3955, 2107, 9593, 6701, 2811, 55215, 0 };
            const std::uint32_t dim8030JoeKuoD6Init[]   =   { 1, 3, 7, 7, 27, 59, 69, 211, 373, 643, 977, 3545, 2647, 10473, 27919, 10719, 24823, 0 };
            const std::uint32_t dim8031JoeKuoD6Init[]   =   { 1, 1, 3, 11, 7, 27, 117, 21, 59, 679, 969, 3813, 2701, 7363, 17525, 31229, 100665, 0 };
            const std::uint32_t dim8032JoeKuoD6Init[]   =   { 1, 3, 3, 5, 29, 53, 113, 141, 197, 991, 81, 2701, 6831, 7949, 16569, 44185, 29631, 0 };
            const std::uint32_t dim8033JoeKuoD6Init[]   =   { 1, 1, 1, 3, 1, 31, 9, 101, 347, 585, 577, 2529, 7461, 11921, 29475, 34505, 74911, 0 };
            const std::uint32_t dim8034JoeKuoD6Init[]   =   { 1, 1, 1, 15, 25, 19, 95, 37, 93, 755, 1891, 2309, 623, 13503, 5811, 45863, 106501, 0 };
            const std::uint32_t dim8035JoeKuoD6Init[]   =   { 1, 1, 5, 3, 15, 23, 51, 225, 87, 679, 1225, 4015, 3971, 163, 3185, 12921, 51267, 0 };
            const std::uint32_t dim8036JoeKuoD6Init[]   =   { 1, 1, 5, 1, 1, 37, 105, 181, 379, 657, 571, 2775, 5905, 8391, 32069, 18713, 125833, 0 };
            const std::uint32_t dim8037JoeKuoD6Init[]   =   { 1, 1, 7, 11, 11, 19, 109, 125, 371, 321, 629, 2165, 2861, 7883, 15503, 37679, 33057, 0 };
            const std::uint32_t dim8038JoeKuoD6Init[]   =   { 1, 1, 3, 5, 7, 5, 21, 5, 169, 321, 1145, 2243, 6143, 2537, 4429, 56493, 39391, 0 };
            const std::uint32_t dim8039JoeKuoD6Init[]   =   { 1, 3, 5, 5, 31, 7, 15, 175, 441, 663, 921, 3113, 2261, 13033, 19135, 28657, 92225, 0 };
            const std::uint32_t dim8040JoeKuoD6Init[]   =   { 1, 3, 1, 11, 13, 9, 25, 57, 297, 3, 1561, 825, 2803, 11327, 2699, 28631, 57277, 0 };
            const std::uint32_t dim8041JoeKuoD6Init[]   =   { 1, 1, 3, 9, 15, 25, 81, 197, 345, 341, 1557, 1375, 2509, 11949, 30201, 6807, 95199, 0 };
            const std::uint32_t dim8042JoeKuoD6Init[]   =   { 1, 3, 5, 3, 15, 23, 91, 147, 277, 59, 495, 1423, 1775, 12065, 8401, 22639, 111199, 0 };
            const std::uint32_t dim8043JoeKuoD6Init[]   =   { 1, 1, 5, 1, 1, 59, 35, 255, 229, 293, 187, 2663, 3967, 6493, 20103, 36703, 108939, 0 };
            const std::uint32_t dim8044JoeKuoD6Init[]   =   { 1, 3, 7, 11, 15, 1, 23, 39, 27, 281, 11, 3119, 2791, 1691, 16521, 39715, 32145, 0 };
            const std::uint32_t dim8045JoeKuoD6Init[]   =   { 1, 3, 5, 5, 9, 53, 43, 49, 107, 1015, 431, 3017, 3317, 9655, 19193, 45621, 56861, 0 };
            const std::uint32_t dim8046JoeKuoD6Init[]   =   { 1, 3, 1, 15, 27, 63, 127, 31, 21, 245, 1503, 3339, 6375, 5411, 12369, 35973, 9473, 0 };
            const std::uint32_t dim8047JoeKuoD6Init[]   =   { 1, 1, 3, 13, 31, 61, 19, 99, 25, 593, 539, 1807, 673, 12339, 23567, 22005, 130341, 0 };
            const std::uint32_t dim8048JoeKuoD6Init[]   =   { 1, 1, 5, 3, 3, 3, 13, 183, 255, 41, 641, 581, 6509, 1891, 19195, 28277, 51725, 0 };
            const std::uint32_t dim8049JoeKuoD6Init[]   =   { 1, 1, 3, 5, 3, 59, 17, 227, 9, 345, 1303, 1535, 3089, 2653, 20647, 63159, 124677, 0 };
            const std::uint32_t dim8050JoeKuoD6Init[]   =   { 1, 3, 1, 11, 25, 19, 117, 29, 221, 461, 1285, 1427, 7183, 3051, 10839, 47491, 92613, 0 };
            const std::uint32_t dim8051JoeKuoD6Init[]   =   { 1, 1, 3, 5, 27, 19, 1, 235, 51, 215, 783, 2325, 1191, 4679, 14365, 35479, 65083, 0 };
            const std::uint32_t dim8052JoeKuoD6Init[]   =   { 1, 3, 3, 5, 27, 17, 79, 185, 259, 369, 1399, 1029, 2219, 10975, 30487, 15247, 39789, 0 };
            const std::uint32_t dim8053JoeKuoD6Init[]   =   { 1, 3, 3, 1, 13, 13, 59, 119, 249, 471, 1433, 1165, 5345, 4431, 375, 64999, 85577, 0 };
            const std::uint32_t dim8054JoeKuoD6Init[]   =   { 1, 1, 1, 3, 1, 19, 13, 243, 35, 675, 321, 3625, 7835, 6403, 651, 48283, 91819, 0 };
            const std::uint32_t dim8055JoeKuoD6Init[]   =   { 1, 3, 3, 1, 27, 13, 73, 159, 145, 59, 287, 2419, 8115, 7923, 18933, 36109, 123879, 0 };
            const std::uint32_t dim8056JoeKuoD6Init[]   =   { 1, 3, 1, 7, 21, 1, 83, 245, 477, 623, 391, 129, 6897, 3447, 11109, 17017, 68277, 0 };
            const std::uint32_t dim8057JoeKuoD6Init[]   =   { 1, 1, 3, 11, 13, 43, 119, 93, 99, 393, 1219, 995, 1881, 7929, 4337, 33579, 103211, 0 };
            const std::uint32_t dim8058JoeKuoD6Init[]   =   { 1, 1, 7, 7, 31, 5, 39, 25, 119, 819, 409, 2395, 151, 12763, 28265, 28909, 35685, 0 };
            const std::uint32_t dim8059JoeKuoD6Init[]   =   { 1, 1, 1, 1, 3, 13, 59, 205, 19, 843, 1691, 955, 1859, 1791, 22083, 37843, 63615, 0 };
            const std::uint32_t dim8060JoeKuoD6Init[]   =   { 1, 1, 1, 3, 11, 63, 41, 243, 103, 875, 1337, 3731, 6317, 12951, 31743, 56935, 55975, 0 };
            const std::uint32_t dim8061JoeKuoD6Init[]   =   { 1, 1, 3, 13, 19, 11, 51, 97, 469, 279, 1621, 3521, 853, 11849, 3331, 27907, 119081, 0 };
            const std::uint32_t dim8062JoeKuoD6Init[]   =   { 1, 1, 5, 1, 23, 55, 9, 141, 449, 41, 167, 2441, 6783, 2785, 3547, 35379, 74973, 0 };
            const std::uint32_t dim8063JoeKuoD6Init[]   =   { 1, 1, 5, 3, 15, 55, 13, 75, 107, 153, 1841, 3991, 3229, 6523, 18541, 21571, 31539, 0 };
            const std::uint32_t dim8064JoeKuoD6Init[]   =   { 1, 3, 1, 1, 27, 37, 35, 201, 401, 867, 1861, 1783, 6255, 14001, 29543, 25843, 39719, 0 };
            const std::uint32_t dim8065JoeKuoD6Init[]   =   { 1, 1, 7, 15, 3, 43, 113, 173, 297, 457, 1369, 4053, 5033, 5513, 27387, 14725, 79937, 0 };
            const std::uint32_t dim8066JoeKuoD6Init[]   =   { 1, 1, 5, 13, 5, 27, 109, 93, 187, 833, 1551, 2899, 1681, 6979, 1289, 3507, 66499, 0 };
            const std::uint32_t dim8067JoeKuoD6Init[]   =   { 1, 1, 3, 11, 11, 47, 121, 29, 129, 807, 2037, 1527, 6083, 14803, 10669, 46047, 70241, 0 };
            const std::uint32_t dim8068JoeKuoD6Init[]   =   { 1, 3, 1, 9, 29, 3, 19, 191, 461, 527, 1389, 3359, 81, 6773, 12185, 49207, 19091, 0 };
            const std::uint32_t dim8069JoeKuoD6Init[]   =   { 1, 3, 7, 7, 5, 47, 33, 27, 445, 1, 149, 343, 4827, 91, 29233, 37775, 89321, 0 };
            const std::uint32_t dim8070JoeKuoD6Init[]   =   { 1, 3, 5, 1, 13, 55, 107, 99, 259, 591, 983, 3863, 1231, 3457, 29645, 10709, 16543, 0 };
            const std::uint32_t dim8071JoeKuoD6Init[]   =   { 1, 3, 7, 9, 29, 5, 9, 165, 337, 187, 219, 97, 6511, 193, 23947, 36329, 35317, 0 };
            const std::uint32_t dim8072JoeKuoD6Init[]   =   { 1, 3, 7, 1, 31, 25, 5, 175, 409, 1021, 1873, 289, 7143, 15341, 31501, 25707, 106453, 0 };
            const std::uint32_t dim8073JoeKuoD6Init[]   =   { 1, 3, 7, 7, 27, 1, 15, 221, 341, 987, 1739, 1183, 8139, 11081, 29721, 42991, 72805, 0 };
            const std::uint32_t dim8074JoeKuoD6Init[]   =   { 1, 1, 1, 9, 11, 1, 13, 17, 501, 543, 1485, 987, 1861, 8527, 1621, 30461, 23057, 0 };
            const std::uint32_t dim8075JoeKuoD6Init[]   =   { 1, 3, 7, 7, 9, 41, 1, 253, 71, 1009, 427, 3347, 6987, 3303, 30535, 33345, 126459, 0 };
            const std::uint32_t dim8076JoeKuoD6Init[]   =   { 1, 1, 1, 7, 11, 11, 15, 11, 305, 559, 1805, 1111, 377, 1495, 13471, 34831, 123125, 0 };
            const std::uint32_t dim8077JoeKuoD6Init[]   =   { 1, 1, 5, 7, 9, 37, 27, 45, 61, 705, 263, 3181, 7077, 5227, 28121, 42865, 3809, 0 };
            const std::uint32_t dim8078JoeKuoD6Init[]   =   { 1, 1, 5, 1, 23, 25, 29, 199, 259, 959, 661, 43, 6157, 1547, 1497, 24077, 129939, 0 };
            const std::uint32_t dim8079JoeKuoD6Init[]   =   { 1, 3, 5, 3, 13, 49, 33, 19, 367, 891, 1777, 3119, 5673, 8383, 14487, 1763, 63495, 0 };
            const std::uint32_t dim8080JoeKuoD6Init[]   =   { 1, 1, 1, 13, 9, 57, 35, 181, 7, 225, 449, 3843, 6257, 4983, 31307, 16559, 27633, 0 };
            const std::uint32_t dim8081JoeKuoD6Init[]   =   { 1, 3, 1, 11, 7, 33, 55, 81, 41, 61, 1711, 3273, 7629, 11283, 9103, 24105, 107547, 0 };
            const std::uint32_t dim8082JoeKuoD6Init[]   =   { 1, 3, 5, 5, 13, 17, 13, 51, 235, 869, 1543, 1249, 7749, 14773, 21751, 53497, 108709, 0 };
            const std::uint32_t dim8083JoeKuoD6Init[]   =   { 1, 1, 3, 9, 3, 63, 89, 43, 23, 479, 115, 3917, 7943, 7323, 5659, 64507, 46941, 0 };
            const std::uint32_t dim8084JoeKuoD6Init[]   =   { 1, 1, 3, 1, 25, 63, 25, 169, 459, 633, 1785, 1059, 5113, 4799, 29281, 24561, 17017, 0 };
            const std::uint32_t dim8085JoeKuoD6Init[]   =   { 1, 1, 3, 3, 15, 3, 11, 173, 493, 5, 1575, 653, 7391, 7453, 8297, 28653, 6213, 0 };
            const std::uint32_t dim8086JoeKuoD6Init[]   =   { 1, 1, 7, 5, 29, 5, 1, 57, 75, 479, 787, 3417, 3349, 111, 17787, 41141, 97597, 0 };
            const std::uint32_t dim8087JoeKuoD6Init[]   =   { 1, 3, 7, 1, 11, 7, 107, 159, 435, 159, 1401, 803, 7065, 5923, 4005, 37271, 113791, 0 };
            const std::uint32_t dim8088JoeKuoD6Init[]   =   { 1, 1, 5, 1, 23, 55, 7, 59, 351, 801, 1279, 3231, 4561, 2857, 20563, 46115, 79489, 0 };
            const std::uint32_t dim8089JoeKuoD6Init[]   =   { 1, 3, 3, 15, 19, 13, 113, 33, 149, 175, 1127, 3815, 4357, 12645, 4449, 61355, 83023, 0 };
            const std::uint32_t dim8090JoeKuoD6Init[]   =   { 1, 1, 7, 15, 3, 17, 41, 57, 243, 319, 1631, 2751, 7853, 5977, 28367, 20023, 56049, 0 };
            const std::uint32_t dim8091JoeKuoD6Init[]   =   { 1, 3, 1, 7, 27, 59, 7, 13, 497, 241, 1827, 2861, 1331, 1759, 6037, 18967, 42849, 0 };
            const std::uint32_t dim8092JoeKuoD6Init[]   =   { 1, 3, 1, 1, 31, 43, 41, 183, 241, 219, 335, 2331, 755, 10589, 29431, 29007, 66667, 0 };
            const std::uint32_t dim8093JoeKuoD6Init[]   =   { 1, 1, 3, 1, 27, 37, 61, 117, 471, 39, 139, 3821, 2945, 7035, 23673, 20167, 56169, 0 };
            const std::uint32_t dim8094JoeKuoD6Init[]   =   { 1, 3, 1, 1, 9, 29, 123, 61, 171, 1015, 1029, 1695, 1039, 11883, 259, 10879, 97709, 0 };
            const std::uint32_t dim8095JoeKuoD6Init[]   =   { 1, 3, 3, 5, 29, 39, 65, 193, 285, 635, 999, 717, 5465, 1849, 4293, 19775, 79121, 0 };
            const std::uint32_t dim8096JoeKuoD6Init[]   =   { 1, 1, 7, 1, 3, 3, 103, 15, 451, 307, 1027, 263, 6585, 11651, 14457, 62695, 38407, 0 };
            const std::uint32_t dim8097JoeKuoD6Init[]   =   { 1, 3, 7, 11, 13, 13, 29, 83, 267, 561, 2041, 13, 3167, 3475, 14735, 34455, 117533, 0 };
            const std::uint32_t dim8098JoeKuoD6Init[]   =   { 1, 3, 1, 15, 5, 1, 35, 225, 151, 637, 1347, 833, 7077, 13145, 10285, 46583, 14351, 0 };
            const std::uint32_t dim8099JoeKuoD6Init[]   =   { 1, 1, 3, 15, 27, 63, 119, 159, 209, 421, 1413, 2727, 1607, 7175, 6133, 29051, 97387, 0 };
            const std::uint32_t dim8100JoeKuoD6Init[]   =   { 1, 1, 3, 5, 9, 29, 35, 93, 353, 903, 1037, 469, 5473, 7193, 21883, 14709, 89023, 0 };
            const std::uint32_t dim8101JoeKuoD6Init[]   =   { 1, 1, 1, 11, 9, 17, 51, 155, 145, 443, 1985, 423, 4721, 15721, 9747, 10303, 21909, 0 };
            const std::uint32_t dim8102JoeKuoD6Init[]   =   { 1, 3, 7, 15, 19, 49, 53, 153, 241, 739, 1585, 3945, 4869, 11, 15845, 17937, 69397, 0 };
            const std::uint32_t dim8103JoeKuoD6Init[]   =   { 1, 1, 5, 7, 19, 53, 43, 211, 327, 723, 1513, 1569, 919, 1771, 11309, 50787, 7459, 0 };
            const std::uint32_t dim8104JoeKuoD6Init[]   =   { 1, 1, 1, 9, 7, 29, 49, 89, 409, 685, 201, 1327, 2807, 13101, 2485, 62909, 102595, 0 };
            const std::uint32_t dim8105JoeKuoD6Init[]   =   { 1, 3, 1, 13, 21, 51, 37, 231, 271, 475, 855, 3703, 4447, 5161, 17937, 14471, 47173, 0 };
            const std::uint32_t dim8106JoeKuoD6Init[]   =   { 1, 1, 7, 3, 9, 7, 121, 197, 71, 147, 1669, 1745, 6589, 15029, 1529, 12625, 121925, 0 };
            const std::uint32_t dim8107JoeKuoD6Init[]   =   { 1, 1, 1, 3, 7, 47, 63, 61, 187, 341, 919, 307, 389, 14141, 12941, 17917, 104289, 0 };
            const std::uint32_t dim8108JoeKuoD6Init[]   =   { 1, 3, 5, 13, 19, 43, 57, 11, 383, 311, 1229, 3527, 3301, 12473, 24377, 16279, 92733, 0 };
            const std::uint32_t dim8109JoeKuoD6Init[]   =   { 1, 3, 3, 5, 25, 35, 63, 23, 131, 481, 809, 3627, 5685, 13695, 14121, 64751, 66181, 0 };
            const std::uint32_t dim8110JoeKuoD6Init[]   =   { 1, 3, 1, 5, 11, 43, 89, 55, 103, 219, 1861, 3223, 5111, 5879, 31399, 1395, 87419, 0 };
            const std::uint32_t dim8111JoeKuoD6Init[]   =   { 1, 3, 1, 11, 21, 27, 123, 205, 47, 923, 7, 1635, 4019, 8431, 28313, 24275, 129617, 0 };
            const std::uint32_t dim8112JoeKuoD6Init[]   =   { 1, 1, 1, 3, 1, 11, 91, 215, 393, 999, 1071, 3225, 4415, 759, 24499, 16109, 33791, 0 };
            const std::uint32_t dim8113JoeKuoD6Init[]   =   { 1, 1, 3, 13, 19, 45, 77, 103, 105, 395, 529, 3631, 8179, 4467, 30263, 39379, 70507, 0 };
            const std::uint32_t dim8114JoeKuoD6Init[]   =   { 1, 3, 3, 9, 17, 45, 101, 219, 433, 971, 471, 1243, 6955, 5941, 20641, 16119, 129383, 0 };
            const std::uint32_t dim8115JoeKuoD6Init[]   =   { 1, 1, 7, 7, 9, 9, 91, 95, 503, 171, 129, 1509, 7179, 5367, 2219, 50445, 112459, 0 };
            const std::uint32_t dim8116JoeKuoD6Init[]   =   { 1, 3, 7, 1, 17, 17, 19, 173, 229, 519, 147, 1835, 3797, 8091, 20335, 33177, 90197, 0 };
            const std::uint32_t dim8117JoeKuoD6Init[]   =   { 1, 3, 3, 5, 23, 29, 107, 205, 43, 969, 799, 1239, 1353, 5221, 15175, 42945, 34043, 0 };
            const std::uint32_t dim8118JoeKuoD6Init[]   =   { 1, 1, 5, 7, 31, 63, 67, 87, 189, 301, 1719, 3937, 965, 2505, 24781, 25133, 91675, 0 };
            const std::uint32_t dim8119JoeKuoD6Init[]   =   { 1, 3, 1, 7, 15, 25, 11, 39, 281, 35, 1149, 1445, 6451, 12069, 20959, 29895, 60059, 0 };
            const std::uint32_t dim8120JoeKuoD6Init[]   =   { 1, 1, 5, 1, 1, 17, 65, 213, 359, 561, 2015, 1629, 3521, 6877, 8099, 62483, 103903, 0 };
            const std::uint32_t dim8121JoeKuoD6Init[]   =   { 1, 1, 7, 9, 7, 49, 1, 227, 49, 823, 1141, 2419, 2697, 13293, 14143, 6323, 16081, 0 };
            const std::uint32_t dim8122JoeKuoD6Init[]   =   { 1, 3, 3, 1, 9, 13, 99, 235, 343, 601, 927, 183, 4545, 14529, 5521, 55571, 90675, 0 };
            const std::uint32_t dim8123JoeKuoD6Init[]   =   { 1, 1, 5, 1, 13, 49, 95, 153, 131, 955, 283, 2951, 3651, 7743, 4285, 42621, 110577, 0 };
            const std::uint32_t dim8124JoeKuoD6Init[]   =   { 1, 1, 1, 9, 19, 59, 97, 181, 67, 357, 497, 287, 3523, 3729, 28981, 59687, 39463, 0 };
            const std::uint32_t dim8125JoeKuoD6Init[]   =   { 1, 1, 3, 7, 5, 19, 107, 55, 393, 225, 1953, 669, 8063, 6537, 15983, 59891, 95079, 0 };
            const std::uint32_t dim8126JoeKuoD6Init[]   =   { 1, 3, 1, 5, 29, 21, 17, 169, 447, 697, 1613, 3483, 3139, 11175, 28865, 12065, 130241, 0 };
            const std::uint32_t dim8127JoeKuoD6Init[]   =   { 1, 3, 5, 7, 5, 49, 35, 181, 85, 505, 1537, 1345, 773, 3255, 27405, 3959, 126377, 0 };
            const std::uint32_t dim8128JoeKuoD6Init[]   =   { 1, 1, 7, 15, 9, 9, 17, 99, 409, 319, 807, 1721, 4023, 2171, 32657, 51663, 23253, 0 };
            const std::uint32_t dim8129JoeKuoD6Init[]   =   { 1, 3, 5, 1, 5, 3, 37, 219, 89, 263, 397, 573, 6147, 9525, 2521, 11153, 94319, 0 };
            const std::uint32_t dim8130JoeKuoD6Init[]   =   { 1, 1, 5, 5, 11, 39, 55, 205, 209, 239, 1443, 2477, 1941, 8337, 2883, 54593, 129859, 0 };
            const std::uint32_t dim8131JoeKuoD6Init[]   =   { 1, 1, 1, 7, 11, 13, 127, 65, 127, 413, 1553, 413, 3395, 9451, 7517, 34103, 57029, 0 };
            const std::uint32_t dim8132JoeKuoD6Init[]   =   { 1, 1, 1, 15, 5, 25, 109, 181, 399, 1023, 277, 3365, 6209, 827, 13933, 27483, 63835, 0 };
            const std::uint32_t dim8133JoeKuoD6Init[]   =   { 1, 1, 3, 3, 21, 57, 95, 127, 481, 365, 197, 3631, 7443, 4925, 31277, 35061, 35875, 0 };
            const std::uint32_t dim8134JoeKuoD6Init[]   =   { 1, 1, 7, 13, 3, 31, 59, 127, 441, 967, 1049, 1281, 3553, 375, 9683, 45755, 18889, 0 };
            const std::uint32_t dim8135JoeKuoD6Init[]   =   { 1, 1, 1, 13, 11, 39, 49, 43, 383, 607, 157, 1887, 3623, 13335, 31949, 49843, 96781, 0 };
            const std::uint32_t dim8136JoeKuoD6Init[]   =   { 1, 3, 7, 13, 19, 35, 21, 9, 299, 425, 1921, 3481, 6849, 4149, 5227, 56737, 27559, 0 };
            const std::uint32_t dim8137JoeKuoD6Init[]   =   { 1, 3, 7, 5, 21, 11, 79, 97, 1, 849, 819, 1133, 3393, 5429, 10621, 38787, 120785, 0 };
            const std::uint32_t dim8138JoeKuoD6Init[]   =   { 1, 1, 1, 13, 21, 29, 3, 239, 399, 619, 759, 2655, 3691, 655, 30979, 15507, 114791, 0 };
            const std::uint32_t dim8139JoeKuoD6Init[]   =   { 1, 3, 5, 3, 1, 61, 79, 43, 273, 965, 1759, 3901, 2437, 1703, 20205, 46291, 23679, 0 };
            const std::uint32_t dim8140JoeKuoD6Init[]   =   { 1, 1, 1, 9, 19, 57, 75, 245, 377, 261, 231, 3683, 6745, 7797, 28471, 56269, 109969, 0 };
            const std::uint32_t dim8141JoeKuoD6Init[]   =   { 1, 3, 1, 11, 9, 55, 53, 87, 33, 431, 1805, 2933, 455, 12479, 16235, 2667, 70105, 0 };
            const std::uint32_t dim8142JoeKuoD6Init[]   =   { 1, 3, 5, 1, 29, 1, 101, 17, 377, 499, 1365, 209, 4819, 15099, 8769, 37003, 53003, 0 };
            const std::uint32_t dim8143JoeKuoD6Init[]   =   { 1, 3, 5, 11, 11, 39, 109, 235, 337, 393, 35, 1071, 7085, 7165, 25143, 24223, 71493, 0 };
            const std::uint32_t dim8144JoeKuoD6Init[]   =   { 1, 3, 1, 5, 13, 49, 9, 205, 305, 943, 799, 2405, 319, 10755, 9785, 32023, 48015, 0 };
            const std::uint32_t dim8145JoeKuoD6Init[]   =   { 1, 3, 1, 9, 29, 35, 123, 101, 73, 747, 1257, 407, 5871, 4271, 14837, 52727, 13339, 0 };
            const std::uint32_t dim8146JoeKuoD6Init[]   =   { 1, 3, 3, 9, 31, 7, 113, 27, 89, 123, 1117, 531, 5531, 7897, 11209, 35267, 123457, 0 };
            const std::uint32_t dim8147JoeKuoD6Init[]   =   { 1, 1, 1, 1, 29, 19, 93, 11, 61, 743, 267, 13, 6561, 7667, 20537, 12675, 10481, 0 };
            const std::uint32_t dim8148JoeKuoD6Init[]   =   { 1, 1, 5, 13, 27, 47, 103, 171, 349, 139, 1709, 961, 783, 7147, 5569, 53395, 80797, 0 };
            const std::uint32_t dim8149JoeKuoD6Init[]   =   { 1, 3, 1, 9, 21, 49, 41, 175, 507, 861, 1157, 1033, 6795, 5795, 603, 12485, 75263, 0 };
            const std::uint32_t dim8150JoeKuoD6Init[]   =   { 1, 1, 5, 7, 23, 3, 21, 165, 123, 951, 785, 2065, 8001, 7009, 22981, 10011, 9807, 0 };
            const std::uint32_t dim8151JoeKuoD6Init[]   =   { 1, 3, 7, 15, 1, 53, 49, 197, 231, 351, 141, 3465, 7907, 10695, 30913, 26753, 71079, 0 };
            const std::uint32_t dim8152JoeKuoD6Init[]   =   { 1, 3, 5, 3, 29, 45, 23, 131, 65, 507, 75, 275, 7287, 187, 1093, 52657, 31533, 0 };
            const std::uint32_t dim8153JoeKuoD6Init[]   =   { 1, 3, 5, 9, 9, 7, 113, 125, 441, 75, 663, 4081, 3147, 1469, 28375, 35747, 122965, 0 };
            const std::uint32_t dim8154JoeKuoD6Init[]   =   { 1, 1, 7, 3, 3, 57, 5, 17, 183, 237, 965, 3709, 4161, 9513, 217, 58835, 78789, 0 };
            const std::uint32_t dim8155JoeKuoD6Init[]   =   { 1, 1, 3, 1, 7, 25, 13, 29, 173, 319, 1723, 57, 2401, 10405, 15541, 52915, 93747, 0 };
            const std::uint32_t dim8156JoeKuoD6Init[]   =   { 1, 1, 7, 5, 1, 31, 11, 61, 341, 97, 1199, 2585, 5909, 3707, 31507, 51233, 2389, 0 };
            const std::uint32_t dim8157JoeKuoD6Init[]   =   { 1, 1, 5, 15, 15, 21, 127, 155, 229, 203, 1303, 3215, 1965, 9481, 31909, 52307, 112207, 0 };
            const std::uint32_t dim8158JoeKuoD6Init[]   =   { 1, 3, 1, 13, 9, 45, 91, 39, 113, 587, 895, 637, 2475, 1695, 9347, 53255, 75797, 0 };
            const std::uint32_t dim8159JoeKuoD6Init[]   =   { 1, 3, 5, 13, 17, 11, 35, 83, 69, 255, 741, 3927, 153, 11001, 29145, 37107, 51873, 0 };
            const std::uint32_t dim8160JoeKuoD6Init[]   =   { 1, 1, 7, 5, 5, 37, 35, 219, 153, 1005, 973, 2555, 893, 5931, 23857, 34631, 74561, 0 };
            const std::uint32_t dim8161JoeKuoD6Init[]   =   { 1, 3, 1, 11, 21, 63, 113, 29, 115, 307, 957, 407, 879, 4819, 2865, 1773, 116825, 0 };
            const std::uint32_t dim8162JoeKuoD6Init[]   =   { 1, 3, 7, 3, 19, 55, 87, 21, 139, 571, 311, 2295, 2729, 6371, 11845, 30223, 19247, 0 };
            const std::uint32_t dim8163JoeKuoD6Init[]   =   { 1, 3, 7, 5, 23, 9, 59, 25, 357, 863, 435, 2509, 5599, 14039, 25731, 41645, 255, 0 };
            const std::uint32_t dim8164JoeKuoD6Init[]   =   { 1, 3, 7, 13, 9, 3, 63, 115, 503, 489, 1585, 813, 5419, 691, 23973, 18677, 59979, 0 };
            const std::uint32_t dim8165JoeKuoD6Init[]   =   { 1, 1, 1, 1, 13, 3, 55, 23, 185, 731, 459, 1497, 433, 16243, 29995, 20777, 59513, 0 };
            const std::uint32_t dim8166JoeKuoD6Init[]   =   { 1, 1, 7, 3, 27, 55, 77, 57, 349, 5, 617, 385, 6225, 7025, 23335, 877, 21973, 0 };
            const std::uint32_t dim8167JoeKuoD6Init[]   =   { 1, 3, 3, 5, 3, 37, 105, 197, 153, 639, 1643, 1093, 801, 4605, 4551, 46081, 7739, 0 };
            const std::uint32_t dim8168JoeKuoD6Init[]   =   { 1, 1, 5, 11, 29, 23, 5, 91, 39, 489, 2029, 887, 4451, 11463, 5641, 56299, 34027, 0 };
            const std::uint32_t dim8169JoeKuoD6Init[]   =   { 1, 1, 7, 3, 17, 11, 25, 161, 317, 701, 155, 1989, 7549, 11529, 9945, 18395, 61251, 0 };
            const std::uint32_t dim8170JoeKuoD6Init[]   =   { 1, 1, 7, 13, 23, 55, 113, 91, 17, 149, 1893, 2793, 8185, 81, 29487, 47925, 51837, 0 };
            const std::uint32_t dim8171JoeKuoD6Init[]   =   { 1, 3, 7, 7, 9, 29, 103, 161, 215, 129, 113, 1987, 919, 9639, 20715, 6541, 15041, 0 };
            const std::uint32_t dim8172JoeKuoD6Init[]   =   { 1, 1, 5, 9, 19, 19, 127, 43, 263, 997, 1687, 3801, 4249, 6309, 25889, 1787, 122771, 0 };
            const std::uint32_t dim8173JoeKuoD6Init[]   =   { 1, 3, 5, 13, 17, 3, 91, 183, 349, 467, 333, 3299, 3085, 12135, 16801, 31471, 37227, 0 };
            const std::uint32_t dim8174JoeKuoD6Init[]   =   { 1, 1, 5, 3, 7, 53, 11, 221, 407, 545, 237, 3631, 1791, 3729, 19737, 921, 57303, 0 };
            const std::uint32_t dim8175JoeKuoD6Init[]   =   { 1, 3, 7, 15, 3, 27, 71, 45, 219, 9, 1135, 2267, 6841, 8637, 30317, 9397, 115425, 0 };
            const std::uint32_t dim8176JoeKuoD6Init[]   =   { 1, 1, 3, 5, 29, 59, 121, 225, 419, 813, 1725, 3969, 3451, 8457, 31803, 57659, 33263, 0 };
            const std::uint32_t dim8177JoeKuoD6Init[]   =   { 1, 3, 3, 3, 17, 3, 65, 249, 423, 293, 1333, 3947, 1477, 4005, 30445, 28171, 95823, 0 };
            const std::uint32_t dim8178JoeKuoD6Init[]   =   { 1, 3, 3, 11, 29, 45, 67, 89, 75, 95, 555, 1823, 2795, 11929, 1995, 30013, 116241, 0 };
            const std::uint32_t dim8179JoeKuoD6Init[]   =   { 1, 3, 3, 3, 23, 35, 87, 221, 385, 275, 803, 387, 7765, 15637, 27953, 20913, 25279, 0 };
            const std::uint32_t dim8180JoeKuoD6Init[]   =   { 1, 3, 7, 15, 15, 43, 21, 179, 393, 95, 1913, 1715, 4467, 15093, 13613, 50775, 37133, 0 };
            const std::uint32_t dim8181JoeKuoD6Init[]   =   { 1, 1, 7, 7, 31, 27, 49, 71, 323, 123, 597, 2395, 4449, 7249, 20197, 19789, 92685, 0 };
            const std::uint32_t dim8182JoeKuoD6Init[]   =   { 1, 1, 5, 13, 31, 37, 89, 225, 357, 201, 1887, 3915, 2165, 10809, 21623, 34375, 110905, 0 };
            const std::uint32_t dim8183JoeKuoD6Init[]   =   { 1, 1, 5, 7, 11, 53, 37, 55, 61, 679, 1465, 1587, 2215, 16237, 14985, 50507, 128637, 0 };
            const std::uint32_t dim8184JoeKuoD6Init[]   =   { 1, 1, 7, 1, 15, 53, 115, 21, 279, 555, 43, 2429, 7251, 2141, 4813, 47047, 119551, 0 };
            const std::uint32_t dim8185JoeKuoD6Init[]   =   { 1, 1, 5, 13, 11, 41, 59, 245, 337, 117, 1125, 4007, 947, 10591, 17795, 48535, 72171, 0 };
            const std::uint32_t dim8186JoeKuoD6Init[]   =   { 1, 1, 5, 15, 27, 41, 71, 43, 505, 539, 975, 1567, 795, 4433, 11689, 53051, 98819, 0 };
            const std::uint32_t dim8187JoeKuoD6Init[]   =   { 1, 1, 7, 9, 1, 57, 57, 137, 323, 311, 759, 3027, 3713, 13, 24133, 21451, 1153, 0 };
            const std::uint32_t dim8188JoeKuoD6Init[]   =   { 1, 1, 5, 15, 31, 49, 23, 123, 271, 549, 1995, 5, 6065, 3797, 1085, 50137, 19741, 0 };
            const std::uint32_t dim8189JoeKuoD6Init[]   =   { 1, 3, 3, 13, 5, 15, 21, 117, 487, 43, 1759, 2899, 4239, 9729, 16711, 31559, 34553, 0 };
            const std::uint32_t dim8190JoeKuoD6Init[]   =   { 1, 1, 5, 13, 5, 23, 83, 49, 147, 267, 923, 1377, 1687, 1793, 30383, 19537, 66989, 0 };
            const std::uint32_t dim8191JoeKuoD6Init[]   =   { 1, 1, 1, 13, 9, 41, 105, 241, 499, 891, 885, 3349, 4703, 5609, 11999, 58025, 69089, 0 };
            const std::uint32_t dim8192JoeKuoD6Init[]   =   { 1, 1, 7, 9, 21, 11, 121, 69, 115, 895, 91, 3745, 41, 12787, 26181, 31399, 30463, 0 };
            const std::uint32_t dim8193JoeKuoD6Init[]   =   { 1, 1, 7, 13, 11, 3, 23, 173, 5, 907, 45, 3465, 2807, 3731, 14347, 27973, 8567, 0 };
            const std::uint32_t dim8194JoeKuoD6Init[]   =   { 1, 3, 7, 5, 27, 47, 43, 25, 499, 57, 649, 705, 6223, 4213, 4549, 23213, 13657, 0 };
            const std::uint32_t dim8195JoeKuoD6Init[]   =   { 1, 1, 7, 11, 21, 35, 5, 79, 295, 359, 1993, 99, 7917, 14917, 2131, 45527, 31451, 0 };
            const std::uint32_t dim8196JoeKuoD6Init[]   =   { 1, 1, 5, 15, 1, 39, 85, 93, 65, 991, 389, 585, 4835, 11671, 10913, 41787, 84953, 0 };
            const std::uint32_t dim8197JoeKuoD6Init[]   =   { 1, 1, 1, 5, 27, 5, 1, 15, 11, 83, 1191, 3945, 4697, 7703, 6929, 6057, 88721, 0 };
            const std::uint32_t dim8198JoeKuoD6Init[]   =   { 1, 1, 3, 7, 27, 39, 71, 181, 191, 997, 419, 1671, 7771, 15305, 18677, 45033, 64745, 0 };
            const std::uint32_t dim8199JoeKuoD6Init[]   =   { 1, 3, 7, 3, 15, 41, 33, 239, 93, 307, 153, 2701, 1549, 5011, 6913, 19257, 55829, 0 };
            const std::uint32_t dim8200JoeKuoD6Init[]   =   { 1, 3, 3, 11, 21, 47, 69, 223, 365, 877, 431, 1629, 4803, 11591, 13973, 56359, 11897, 0 };
            const std::uint32_t dim8201JoeKuoD6Init[]   =   { 1, 3, 7, 7, 1, 59, 63, 129, 251, 873, 603, 2707, 2847, 8739, 31343, 63291, 5607, 0 };
            const std::uint32_t dim8202JoeKuoD6Init[]   =   { 1, 3, 5, 5, 19, 13, 79, 235, 151, 571, 953, 2191, 5973, 4751, 11119, 14439, 97755, 0 };
            const std::uint32_t dim8203JoeKuoD6Init[]   =   { 1, 1, 5, 1, 27, 3, 105, 139, 13, 821, 221, 2025, 7303, 1891, 28193, 45537, 92703, 0 };
            const std::uint32_t dim8204JoeKuoD6Init[]   =   { 1, 3, 7, 9, 13, 63, 27, 149, 51, 121, 587, 3695, 4115, 3955, 22493, 34903, 51669, 0 };
            const std::uint32_t dim8205JoeKuoD6Init[]   =   { 1, 1, 5, 7, 19, 5, 89, 87, 269, 585, 421, 3827, 315, 14739, 109, 43009, 94969, 0 };
            const std::uint32_t dim8206JoeKuoD6Init[]   =   { 1, 1, 5, 15, 9, 53, 125, 83, 159, 917, 1583, 585, 6839, 14957, 20007, 60467, 96309, 0 };
            const std::uint32_t dim8207JoeKuoD6Init[]   =   { 1, 3, 5, 1, 23, 49, 109, 91, 17, 731, 1083, 3153, 1825, 14293, 25639, 44599, 47541, 0 };
            const std::uint32_t dim8208JoeKuoD6Init[]   =   { 1, 1, 3, 7, 21, 51, 45, 25, 367, 925, 799, 1673, 6977, 7155, 829, 25899, 104615, 0 };
            const std::uint32_t dim8209JoeKuoD6Init[]   =   { 1, 3, 3, 13, 13, 49, 95, 239, 195, 353, 1967, 1419, 929, 503, 11717, 9485, 62885, 0 };
            const std::uint32_t dim8210JoeKuoD6Init[]   =   { 1, 1, 1, 15, 3, 41, 109, 91, 327, 789, 1429, 1159, 2801, 4845, 19663, 47737, 11029, 0 };
            const std::uint32_t dim8211JoeKuoD6Init[]   =   { 1, 3, 5, 1, 21, 63, 57, 107, 229, 771, 1911, 647, 6989, 12615, 23191, 64941, 97595, 0 };
            const std::uint32_t dim8212JoeKuoD6Init[]   =   { 1, 1, 1, 15, 5, 13, 15, 109, 459, 447, 1625, 1269, 7629, 7929, 4405, 12143, 40481, 0 };
            const std::uint32_t dim8213JoeKuoD6Init[]   =   { 1, 3, 3, 1, 23, 3, 95, 229, 363, 379, 1149, 1615, 5125, 3645, 27535, 58791, 38091, 0 };
            const std::uint32_t dim8214JoeKuoD6Init[]   =   { 1, 1, 1, 1, 9, 45, 119, 85, 151, 171, 1123, 41, 6517, 8067, 17845, 23301, 95383, 0 };
            const std::uint32_t dim8215JoeKuoD6Init[]   =   { 1, 3, 1, 15, 17, 31, 103, 71, 35, 1019, 1687, 1175, 6119, 14075, 26601, 28873, 36617, 0 };
            const std::uint32_t dim8216JoeKuoD6Init[]   =   { 1, 3, 3, 9, 13, 39, 7, 17, 207, 219, 637, 3025, 1709, 4031, 563, 14865, 129389, 0 };
            const std::uint32_t dim8217JoeKuoD6Init[]   =   { 1, 3, 7, 1, 21, 11, 121, 85, 111, 641, 1163, 3173, 5189, 13261, 19471, 39635, 76545, 0 };
            const std::uint32_t dim8218JoeKuoD6Init[]   =   { 1, 3, 7, 15, 3, 45, 3, 37, 121, 967, 1861, 3257, 3699, 6881, 11905, 8413, 59397, 0 };
            const std::uint32_t dim8219JoeKuoD6Init[]   =   { 1, 3, 3, 13, 25, 53, 85, 181, 1, 979, 2045, 297, 1739, 8139, 17897, 35251, 7193, 0 };
            const std::uint32_t dim8220JoeKuoD6Init[]   =   { 1, 1, 1, 3, 5, 49, 77, 115, 377, 209, 1415, 3747, 485, 803, 2507, 27729, 52201, 0 };
            const std::uint32_t dim8221JoeKuoD6Init[]   =   { 1, 3, 1, 5, 31, 55, 85, 171, 135, 893, 1423, 3693, 6155, 5321, 8297, 39183, 88377, 0 };
            const std::uint32_t dim8222JoeKuoD6Init[]   =   { 1, 3, 3, 15, 1, 35, 73, 239, 181, 101, 509, 2449, 4955, 13049, 27631, 16871, 40151, 0 };
            const std::uint32_t dim8223JoeKuoD6Init[]   =   { 1, 1, 7, 13, 27, 7, 109, 71, 437, 835, 563, 1355, 3681, 7431, 32743, 59693, 125055, 0 };
            const std::uint32_t dim8224JoeKuoD6Init[]   =   { 1, 1, 7, 5, 19, 23, 29, 147, 291, 507, 1943, 2069, 3309, 11569, 1031, 49345, 86735, 0 };
            const std::uint32_t dim8225JoeKuoD6Init[]   =   { 1, 1, 3, 13, 17, 45, 91, 167, 19, 137, 527, 961, 4435, 2277, 6863, 57917, 129407, 0 };
            const std::uint32_t dim8226JoeKuoD6Init[]   =   { 1, 3, 5, 7, 11, 31, 79, 207, 43, 871, 1121, 2929, 6899, 4099, 29533, 45333, 33299, 0 };
            const std::uint32_t dim8227JoeKuoD6Init[]   =   { 1, 1, 7, 5, 5, 49, 13, 95, 475, 91, 337, 3531, 3157, 1331, 32655, 46169, 3549, 0 };
            const std::uint32_t dim8228JoeKuoD6Init[]   =   { 1, 3, 1, 5, 5, 9, 73, 177, 123, 251, 717, 541, 7083, 6907, 1417, 31203, 9755, 0 };
            const std::uint32_t dim8229JoeKuoD6Init[]   =   { 1, 3, 1, 11, 21, 11, 91, 155, 447, 165, 1525, 2073, 5103, 193, 2677, 43673, 70579, 0 };
            const std::uint32_t dim8230JoeKuoD6Init[]   =   { 1, 3, 7, 1, 7, 27, 115, 247, 211, 779, 1999, 209, 3215, 111, 25567, 34641, 130873, 0 };
            const std::uint32_t dim8231JoeKuoD6Init[]   =   { 1, 1, 5, 9, 25, 7, 15, 19, 217, 831, 1577, 2051, 3533, 2337, 7675, 2845, 69135, 0 };
            const std::uint32_t dim8232JoeKuoD6Init[]   =   { 1, 3, 5, 15, 29, 11, 91, 59, 221, 383, 1235, 1261, 2967, 14989, 11455, 6459, 58047, 0 };
            const std::uint32_t dim8233JoeKuoD6Init[]   =   { 1, 3, 5, 1, 3, 35, 5, 127, 99, 981, 493, 3001, 5651, 3125, 27789, 57389, 115631, 0 };
            const std::uint32_t dim8234JoeKuoD6Init[]   =   { 1, 3, 5, 5, 29, 63, 123, 161, 247, 177, 1653, 2665, 3903, 11129, 20961, 49429, 44075, 0 };
            const std::uint32_t dim8235JoeKuoD6Init[]   =   { 1, 3, 1, 1, 13, 9, 57, 167, 291, 765, 1929, 397, 5503, 5601, 6957, 62003, 104631, 0 };
            const std::uint32_t dim8236JoeKuoD6Init[]   =   { 1, 1, 7, 15, 9, 43, 57, 85, 157, 361, 1931, 2183, 8045, 14939, 2169, 25733, 29095, 0 };
            const std::uint32_t dim8237JoeKuoD6Init[]   =   { 1, 1, 3, 15, 13, 35, 47, 123, 13, 667, 1373, 4069, 6259, 13453, 13439, 25349, 99437, 0 };
            const std::uint32_t dim8238JoeKuoD6Init[]   =   { 1, 3, 7, 1, 31, 15, 69, 45, 355, 919, 415, 793, 3987, 8785, 4905, 8177, 123989, 0 };
            const std::uint32_t dim8239JoeKuoD6Init[]   =   { 1, 3, 7, 13, 29, 27, 69, 57, 385, 185, 171, 2499, 3983, 13437, 23585, 21501, 88079, 0 };
            const std::uint32_t dim8240JoeKuoD6Init[]   =   { 1, 1, 5, 11, 27, 3, 77, 99, 221, 997, 1653, 1963, 2251, 15505, 26347, 51933, 100679, 0 };
            const std::uint32_t dim8241JoeKuoD6Init[]   =   { 1, 1, 1, 7, 19, 39, 49, 69, 193, 235, 959, 2823, 2573, 8001, 4389, 13217, 60975, 0 };
            const std::uint32_t dim8242JoeKuoD6Init[]   =   { 1, 1, 7, 5, 1, 3, 3, 189, 199, 293, 1225, 1913, 7271, 2255, 661, 23293, 82069, 0 };
            const std::uint32_t dim8243JoeKuoD6Init[]   =   { 1, 1, 5, 5, 21, 31, 35, 113, 47, 479, 325, 1663, 7409, 8975, 14151, 56317, 79663, 0 };
            const std::uint32_t dim8244JoeKuoD6Init[]   =   { 1, 1, 5, 9, 15, 63, 99, 135, 277, 715, 667, 387, 6929, 12873, 12913, 2599, 84939, 0 };
            const std::uint32_t dim8245JoeKuoD6Init[]   =   { 1, 1, 7, 15, 23, 39, 67, 25, 179, 313, 459, 295, 1103, 1737, 7529, 29463, 104693, 0 };
            const std::uint32_t dim8246JoeKuoD6Init[]   =   { 1, 1, 3, 13, 23, 11, 111, 67, 105, 191, 1967, 3497, 7621, 487, 18545, 59521, 115315, 0 };
            const std::uint32_t dim8247JoeKuoD6Init[]   =   { 1, 1, 1, 7, 25, 45, 83, 61, 231, 569, 155, 2817, 6985, 5289, 6731, 3087, 89749, 0 };
            const std::uint32_t dim8248JoeKuoD6Init[]   =   { 1, 3, 7, 1, 1, 61, 103, 49, 135, 411, 659, 1735, 4461, 8077, 12885, 62791, 114769, 0 };
            const std::uint32_t dim8249JoeKuoD6Init[]   =   { 1, 1, 7, 13, 3, 53, 21, 81, 433, 563, 857, 891, 195, 11669, 24769, 56539, 47601, 0 };
            const std::uint32_t dim8250JoeKuoD6Init[]   =   { 1, 3, 1, 13, 3, 41, 59, 101, 67, 803, 1209, 3267, 1255, 5763, 5483, 36339, 38451, 0 };
            const std::uint32_t dim8251JoeKuoD6Init[]   =   { 1, 3, 5, 3, 25, 51, 53, 213, 329, 11, 483, 81, 2151, 7623, 26309, 15289, 85103, 0 };
            const std::uint32_t dim8252JoeKuoD6Init[]   =   { 1, 3, 3, 13, 23, 17, 9, 161, 417, 207, 39, 3615, 7567, 15207, 20383, 58885, 121765, 0 };
            const std::uint32_t dim8253JoeKuoD6Init[]   =   { 1, 3, 1, 7, 15, 59, 9, 195, 187, 583, 341, 2737, 3891, 331, 18055, 60455, 113271, 0 };
            const std::uint32_t dim8254JoeKuoD6Init[]   =   { 1, 1, 3, 3, 19, 25, 95, 37, 281, 59, 1613, 2733, 5715, 4067, 5509, 5851, 35189, 0 };
            const std::uint32_t dim8255JoeKuoD6Init[]   =   { 1, 3, 1, 3, 31, 43, 125, 107, 341, 109, 1991, 849, 7795, 13607, 20421, 3339, 78979, 0 };
            const std::uint32_t dim8256JoeKuoD6Init[]   =   { 1, 3, 7, 13, 15, 57, 87, 151, 479, 99, 479, 447, 7407, 303, 16397, 15699, 122273, 0 };
            const std::uint32_t dim8257JoeKuoD6Init[]   =   { 1, 1, 3, 1, 27, 61, 79, 195, 5, 839, 1411, 3451, 4627, 13715, 18401, 24325, 44027, 0 };
            const std::uint32_t dim8258JoeKuoD6Init[]   =   { 1, 1, 7, 15, 21, 39, 57, 207, 213, 367, 547, 1203, 6385, 2555, 31465, 15675, 7133, 0 };
            const std::uint32_t dim8259JoeKuoD6Init[]   =   { 1, 1, 5, 15, 27, 3, 75, 123, 337, 1019, 1525, 3065, 1919, 10779, 27409, 6291, 86291, 0 };
            const std::uint32_t dim8260JoeKuoD6Init[]   =   { 1, 1, 7, 11, 15, 27, 67, 145, 125, 521, 647, 2957, 6337, 14973, 24139, 29107, 27151, 0 };
            const std::uint32_t dim8261JoeKuoD6Init[]   =   { 1, 1, 1, 13, 25, 57, 103, 83, 321, 111, 131, 2051, 5267, 4723, 1939, 40389, 4803, 0 };
            const std::uint32_t dim8262JoeKuoD6Init[]   =   { 1, 3, 1, 7, 29, 7, 35, 133, 349, 855, 613, 2563, 2261, 2119, 13939, 24727, 26719, 0 };
            const std::uint32_t dim8263JoeKuoD6Init[]   =   { 1, 3, 3, 1, 11, 61, 25, 177, 427, 1005, 2027, 649, 7871, 7803, 4717, 59207, 57945, 0 };
            const std::uint32_t dim8264JoeKuoD6Init[]   =   { 1, 1, 7, 1, 15, 45, 75, 133, 193, 745, 485, 197, 6001, 13837, 615, 43629, 127321, 0 };
            const std::uint32_t dim8265JoeKuoD6Init[]   =   { 1, 3, 3, 13, 5, 7, 101, 183, 211, 283, 1327, 1395, 8175, 13359, 18361, 54243, 3555, 0 };
            const std::uint32_t dim8266JoeKuoD6Init[]   =   { 1, 1, 7, 13, 7, 43, 19, 41, 319, 701, 795, 1407, 7113, 9149, 31953, 17075, 53975, 0 };
            const std::uint32_t dim8267JoeKuoD6Init[]   =   { 1, 3, 5, 13, 11, 19, 101, 125, 327, 75, 1471, 3465, 2247, 5107, 11519, 45161, 71373, 0 };
            const std::uint32_t dim8268JoeKuoD6Init[]   =   { 1, 3, 7, 13, 23, 59, 53, 57, 137, 575, 59, 3829, 963, 11259, 25771, 29223, 79535, 0 };
            const std::uint32_t dim8269JoeKuoD6Init[]   =   { 1, 3, 3, 11, 17, 31, 111, 147, 499, 441, 1385, 769, 6901, 8349, 1427, 16561, 7485, 0 };
            const std::uint32_t dim8270JoeKuoD6Init[]   =   { 1, 1, 7, 9, 21, 7, 47, 83, 351, 867, 265, 1329, 7853, 6959, 11821, 44947, 42275, 0 };
            const std::uint32_t dim8271JoeKuoD6Init[]   =   { 1, 1, 7, 15, 3, 17, 79, 143, 449, 577, 1007, 1101, 3229, 6861, 23921, 37551, 117309, 0 };
            const std::uint32_t dim8272JoeKuoD6Init[]   =   { 1, 3, 5, 11, 27, 63, 107, 15, 289, 821, 1723, 1945, 1373, 14469, 30985, 55987, 21255, 0 };
            const std::uint32_t dim8273JoeKuoD6Init[]   =   { 1, 3, 5, 3, 21, 39, 79, 85, 485, 733, 2031, 1573, 6873, 12225, 30471, 54233, 26967, 0 };
            const std::uint32_t dim8274JoeKuoD6Init[]   =   { 1, 3, 5, 7, 17, 29, 93, 251, 437, 583, 825, 551, 6545, 10905, 27863, 37037, 52129, 0 };
            const std::uint32_t dim8275JoeKuoD6Init[]   =   { 1, 3, 7, 9, 23, 1, 23, 85, 195, 319, 1759, 3985, 2413, 16205, 22197, 48821, 94907, 0 };
            const std::uint32_t dim8276JoeKuoD6Init[]   =   { 1, 1, 3, 7, 17, 47, 3, 195, 167, 925, 11, 3431, 1767, 5917, 13915, 54565, 64625, 0 };
            const std::uint32_t dim8277JoeKuoD6Init[]   =   { 1, 3, 1, 13, 23, 43, 97, 93, 313, 773, 591, 127, 6005, 11497, 32573, 8173, 92053, 0 };
            const std::uint32_t dim8278JoeKuoD6Init[]   =   { 1, 1, 5, 9, 17, 47, 115, 237, 389, 619, 377, 561, 1333, 6433, 9743, 32673, 98039, 0 };
            const std::uint32_t dim8279JoeKuoD6Init[]   =   { 1, 3, 7, 15, 23, 17, 99, 225, 145, 191, 2041, 581, 841, 9377, 18123, 32773, 66849, 0 };
            const std::uint32_t dim8280JoeKuoD6Init[]   =   { 1, 3, 7, 15, 21, 49, 97, 41, 357, 527, 2019, 2083, 2611, 12449, 20037, 52503, 105991, 0 };
            const std::uint32_t dim8281JoeKuoD6Init[]   =   { 1, 1, 5, 13, 17, 53, 41, 75, 355, 207, 1675, 591, 5797, 9217, 16443, 3205, 81905, 0 };
            const std::uint32_t dim8282JoeKuoD6Init[]   =   { 1, 3, 7, 11, 1, 61, 29, 207, 449, 103, 1527, 2327, 7895, 10137, 25223, 51607, 60809, 0 };
            const std::uint32_t dim8283JoeKuoD6Init[]   =   { 1, 3, 3, 5, 15, 57, 87, 233, 301, 989, 485, 2143, 7411, 5475, 23377, 56005, 59721, 0 };
            const std::uint32_t dim8284JoeKuoD6Init[]   =   { 1, 3, 1, 15, 29, 7, 95, 141, 369, 231, 735, 1103, 1565, 11575, 571, 3257, 62961, 0 };
            const std::uint32_t dim8285JoeKuoD6Init[]   =   { 1, 1, 5, 15, 27, 19, 25, 35, 303, 555, 95, 1323, 6139, 5079, 21763, 59591, 103537, 0 };
            const std::uint32_t dim8286JoeKuoD6Init[]   =   { 1, 1, 1, 13, 25, 23, 85, 151, 135, 349, 1753, 1061, 7697, 1723, 5213, 12581, 103995, 0 };
            const std::uint32_t dim8287JoeKuoD6Init[]   =   { 1, 3, 1, 9, 29, 51, 101, 195, 59, 809, 1527, 2179, 63, 3681, 29823, 57537, 121371, 0 };
            const std::uint32_t dim8288JoeKuoD6Init[]   =   { 1, 1, 7, 11, 27, 61, 85, 213, 245, 261, 1649, 2423, 6127, 5687, 4247, 56061, 109793, 0 };
            const std::uint32_t dim8289JoeKuoD6Init[]   =   { 1, 3, 5, 15, 11, 33, 127, 31, 269, 857, 2027, 2611, 1729, 11783, 16459, 31083, 30671, 0 };
            const std::uint32_t dim8290JoeKuoD6Init[]   =   { 1, 1, 7, 9, 11, 29, 127, 177, 505, 227, 1499, 1309, 6855, 9999, 21815, 32987, 79109, 0 };
            const std::uint32_t dim8291JoeKuoD6Init[]   =   { 1, 3, 7, 11, 7, 21, 107, 1, 493, 459, 867, 3199, 7985, 12957, 28197, 41133, 105985, 0 };
            const std::uint32_t dim8292JoeKuoD6Init[]   =   { 1, 1, 3, 15, 1, 57, 113, 97, 213, 547, 1017, 2961, 461, 16125, 10621, 4243, 58277, 0 };
            const std::uint32_t dim8293JoeKuoD6Init[]   =   { 1, 1, 3, 5, 11, 57, 61, 47, 209, 961, 333, 795, 4491, 15115, 25745, 62633, 66269, 0 };
            const std::uint32_t dim8294JoeKuoD6Init[]   =   { 1, 1, 7, 3, 19, 13, 49, 167, 455, 863, 581, 1407, 4247, 15023, 2247, 19981, 125891, 0 };
            const std::uint32_t dim8295JoeKuoD6Init[]   =   { 1, 1, 7, 15, 17, 55, 27, 35, 33, 349, 879, 1781, 1075, 2475, 30689, 42043, 29423, 0 };
            const std::uint32_t dim8296JoeKuoD6Init[]   =   { 1, 1, 1, 11, 25, 53, 121, 117, 117, 845, 447, 3927, 1951, 8643, 24497, 44833, 99533, 0 };
            const std::uint32_t dim8297JoeKuoD6Init[]   =   { 1, 1, 7, 13, 3, 59, 117, 9, 359, 453, 327, 3419, 5957, 97, 20541, 49441, 5673, 0 };
            const std::uint32_t dim8298JoeKuoD6Init[]   =   { 1, 3, 5, 5, 31, 35, 95, 107, 435, 733, 827, 1361, 6627, 8905, 2681, 25473, 46093, 0 };
            const std::uint32_t dim8299JoeKuoD6Init[]   =   { 1, 3, 3, 5, 7, 23, 75, 137, 231, 915, 637, 2963, 4409, 12799, 31587, 65363, 69539, 0 };
            const std::uint32_t dim8300JoeKuoD6Init[]   =   { 1, 1, 1, 7, 15, 35, 19, 233, 189, 837, 243, 2525, 6185, 565, 8133, 4265, 3089, 0 };
            const std::uint32_t dim8301JoeKuoD6Init[]   =   { 1, 1, 5, 5, 19, 59, 103, 201, 287, 449, 21, 2331, 341, 13145, 18607, 46407, 2767, 0 };
            const std::uint32_t dim8302JoeKuoD6Init[]   =   { 1, 3, 3, 15, 19, 41, 49, 179, 109, 367, 1185, 1045, 1635, 9647, 16613, 25357, 34291, 0 };
            const std::uint32_t dim8303JoeKuoD6Init[]   =   { 1, 3, 5, 1, 13, 11, 89, 25, 159, 637, 1979, 549, 3553, 9163, 227, 50553, 46307, 0 };
            const std::uint32_t dim8304JoeKuoD6Init[]   =   { 1, 1, 3, 1, 17, 33, 73, 239, 261, 751, 1267, 2643, 2549, 8331, 25083, 9715, 67289, 0 };
            const std::uint32_t dim8305JoeKuoD6Init[]   =   { 1, 1, 1, 13, 3, 49, 7, 35, 367, 293, 903, 1045, 569, 6017, 27635, 51833, 32963, 0 };
            const std::uint32_t dim8306JoeKuoD6Init[]   =   { 1, 3, 5, 3, 31, 3, 69, 137, 57, 87, 719, 3977, 3031, 7675, 24605, 8757, 93173, 0 };
            const std::uint32_t dim8307JoeKuoD6Init[]   =   { 1, 3, 3, 1, 7, 45, 97, 35, 233, 69, 1525, 4047, 2599, 13679, 4389, 49079, 121465, 0 };
            const std::uint32_t dim8308JoeKuoD6Init[]   =   { 1, 1, 7, 13, 7, 25, 57, 211, 337, 189, 1825, 2451, 7651, 11277, 27763, 40671, 57223, 0 };
            const std::uint32_t dim8309JoeKuoD6Init[]   =   { 1, 1, 1, 1, 15, 59, 55, 169, 461, 907, 407, 803, 3349, 4727, 20983, 47717, 51647, 0 };
            const std::uint32_t dim8310JoeKuoD6Init[]   =   { 1, 3, 7, 1, 15, 51, 25, 119, 439, 593, 1289, 3959, 5489, 13283, 31837, 8441, 58373, 0 };
            const std::uint32_t dim8311JoeKuoD6Init[]   =   { 1, 3, 1, 9, 5, 1, 81, 45, 13, 537, 1091, 3861, 6781, 5679, 2807, 29757, 40917, 0 };
            const std::uint32_t dim8312JoeKuoD6Init[]   =   { 1, 3, 5, 3, 27, 41, 19, 235, 207, 697, 775, 837, 3431, 3175, 10807, 42775, 67987, 0 };
            const std::uint32_t dim8313JoeKuoD6Init[]   =   { 1, 3, 7, 3, 29, 33, 35, 119, 271, 609, 1747, 2839, 3415, 2275, 30979, 41293, 99341, 0 };
            const std::uint32_t dim8314JoeKuoD6Init[]   =   { 1, 3, 3, 3, 5, 17, 13, 169, 269, 709, 1449, 3169, 1545, 16075, 8937, 39705, 19609, 0 };
            const std::uint32_t dim8315JoeKuoD6Init[]   =   { 1, 3, 5, 15, 29, 13, 1, 199, 65, 385, 977, 797, 1181, 10979, 241, 40393, 73663, 0 };
            const std::uint32_t dim8316JoeKuoD6Init[]   =   { 1, 1, 3, 7, 17, 35, 47, 63, 193, 451, 151, 3415, 99, 14557, 26025, 31361, 112639, 0 };
            const std::uint32_t dim8317JoeKuoD6Init[]   =   { 1, 1, 3, 5, 19, 13, 29, 33, 365, 311, 1241, 217, 6205, 13067, 18585, 21693, 97127, 0 };
            const std::uint32_t dim8318JoeKuoD6Init[]   =   { 1, 1, 3, 15, 19, 7, 87, 25, 91, 13, 1839, 1445, 957, 9779, 25557, 37027, 38987, 0 };
            const std::uint32_t dim8319JoeKuoD6Init[]   =   { 1, 1, 5, 1, 21, 5, 79, 67, 481, 455, 37, 1321, 7723, 1413, 7919, 11035, 5739, 0 };
            const std::uint32_t dim8320JoeKuoD6Init[]   =   { 1, 1, 1, 15, 9, 55, 111, 1, 383, 439, 1037, 4055, 4243, 10443, 26737, 21039, 130847, 0 };
            const std::uint32_t dim8321JoeKuoD6Init[]   =   { 1, 1, 7, 9, 13, 25, 71, 137, 307, 717, 1009, 2477, 3861, 14145, 14549, 59589, 93401, 0 };
            const std::uint32_t dim8322JoeKuoD6Init[]   =   { 1, 1, 7, 5, 29, 63, 77, 49, 471, 267, 1457, 1743, 1915, 14793, 17899, 28011, 92183, 0 };
            const std::uint32_t dim8323JoeKuoD6Init[]   =   { 1, 3, 7, 7, 7, 41, 47, 251, 75, 749, 1915, 1015, 5869, 3211, 24097, 14349, 130571, 0 };
            const std::uint32_t dim8324JoeKuoD6Init[]   =   { 1, 1, 1, 1, 31, 63, 105, 83, 345, 147, 975, 135, 7299, 15801, 19311, 26143, 80293, 0 };
            const std::uint32_t dim8325JoeKuoD6Init[]   =   { 1, 1, 3, 1, 7, 1, 47, 45, 251, 635, 583, 3515, 5233, 6281, 7797, 37949, 75877, 0 };
            const std::uint32_t dim8326JoeKuoD6Init[]   =   { 1, 1, 3, 3, 5, 53, 99, 175, 155, 327, 1841, 211, 2811, 16099, 17255, 34253, 124141, 0 };
            const std::uint32_t dim8327JoeKuoD6Init[]   =   { 1, 3, 1, 3, 13, 27, 81, 217, 115, 245, 101, 1641, 29, 1441, 4829, 28399, 102303, 0 };
            const std::uint32_t dim8328JoeKuoD6Init[]   =   { 1, 3, 1, 5, 11, 55, 31, 91, 337, 203, 987, 977, 4929, 14933, 25149, 20493, 19783, 0 };
            const std::uint32_t dim8329JoeKuoD6Init[]   =   { 1, 1, 5, 9, 9, 37, 103, 211, 349, 165, 1421, 3015, 5133, 4615, 28173, 45787, 10711, 0 };
            const std::uint32_t dim8330JoeKuoD6Init[]   =   { 1, 1, 1, 1, 1, 17, 29, 117, 421, 651, 1617, 1677, 7841, 16303, 8843, 1321, 90701, 0 };
            const std::uint32_t dim8331JoeKuoD6Init[]   =   { 1, 1, 1, 15, 27, 23, 49, 195, 139, 319, 1277, 901, 63, 14677, 21815, 19497, 24883, 0 };
            const std::uint32_t dim8332JoeKuoD6Init[]   =   { 1, 3, 3, 13, 1, 23, 17, 189, 293, 765, 1503, 1485, 7427, 11807, 17629, 61739, 111365, 0 };
            const std::uint32_t dim8333JoeKuoD6Init[]   =   { 1, 1, 5, 5, 15, 41, 25, 53, 221, 449, 1597, 2763, 4119, 6319, 17509, 23493, 104707, 0 };
            const std::uint32_t dim8334JoeKuoD6Init[]   =   { 1, 3, 7, 11, 29, 21, 101, 197, 161, 457, 331, 3817, 5139, 14307, 23225, 55567, 62535, 0 };
            const std::uint32_t dim8335JoeKuoD6Init[]   =   { 1, 1, 7, 5, 9, 57, 39, 101, 5, 847, 1311, 313, 2877, 14811, 21969, 31741, 8075, 0 };
            const std::uint32_t dim8336JoeKuoD6Init[]   =   { 1, 3, 5, 3, 1, 11, 45, 163, 251, 775, 1031, 1957, 1631, 1691, 3191, 6255, 13037, 0 };
            const std::uint32_t dim8337JoeKuoD6Init[]   =   { 1, 1, 3, 13, 7, 11, 95, 97, 409, 835, 707, 1579, 2409, 9451, 15069, 62425, 106499, 0 };
            const std::uint32_t dim8338JoeKuoD6Init[]   =   { 1, 3, 3, 11, 5, 25, 23, 207, 429, 299, 537, 1467, 6309, 891, 15009, 56733, 60397, 0 };
            const std::uint32_t dim8339JoeKuoD6Init[]   =   { 1, 3, 5, 3, 29, 47, 95, 115, 207, 177, 543, 427, 145, 11169, 7441, 10911, 87413, 0 };
            const std::uint32_t dim8340JoeKuoD6Init[]   =   { 1, 3, 7, 11, 25, 53, 15, 225, 115, 295, 919, 39, 513, 9989, 11045, 24015, 102387, 0 };
            const std::uint32_t dim8341JoeKuoD6Init[]   =   { 1, 1, 7, 15, 13, 31, 103, 143, 357, 825, 183, 137, 2671, 9803, 14777, 48333, 79483, 0 };
            const std::uint32_t dim8342JoeKuoD6Init[]   =   { 1, 3, 5, 1, 25, 13, 65, 9, 461, 307, 1289, 1035, 7253, 14223, 16829, 23361, 84987, 0 };
            const std::uint32_t dim8343JoeKuoD6Init[]   =   { 1, 3, 5, 7, 5, 57, 47, 251, 5, 9, 965, 2883, 3105, 13931, 807, 31977, 119035, 0 };
            const std::uint32_t dim8344JoeKuoD6Init[]   =   { 1, 1, 3, 5, 3, 7, 55, 165, 3, 787, 1587, 989, 6049, 14021, 30789, 15283, 92851, 0 };
            const std::uint32_t dim8345JoeKuoD6Init[]   =   { 1, 1, 5, 5, 3, 17, 11, 167, 487, 885, 193, 3485, 8179, 9485, 24913, 40267, 70625, 0 };
            const std::uint32_t dim8346JoeKuoD6Init[]   =   { 1, 1, 7, 1, 27, 31, 9, 139, 73, 137, 783, 321, 691, 6157, 19905, 45525, 84877, 0 };
            const std::uint32_t dim8347JoeKuoD6Init[]   =   { 1, 3, 1, 9, 17, 39, 127, 177, 301, 579, 1065, 3899, 281, 9177, 16295, 51217, 120293, 0 };
            const std::uint32_t dim8348JoeKuoD6Init[]   =   { 1, 1, 7, 9, 31, 59, 17, 93, 247, 779, 847, 1183, 3453, 1073, 18597, 2655, 121633, 0 };
            const std::uint32_t dim8349JoeKuoD6Init[]   =   { 1, 1, 7, 1, 25, 43, 47, 253, 23, 999, 973, 1201, 1061, 5947, 5619, 36311, 1545, 0 };
            const std::uint32_t dim8350JoeKuoD6Init[]   =   { 1, 3, 5, 7, 11, 5, 103, 119, 229, 657, 1993, 1991, 1597, 13165, 19137, 7161, 83487, 0 };
            const std::uint32_t dim8351JoeKuoD6Init[]   =   { 1, 1, 1, 1, 11, 23, 105, 183, 467, 83, 899, 2447, 4949, 4171, 28943, 4829, 13033, 0 };
            const std::uint32_t dim8352JoeKuoD6Init[]   =   { 1, 3, 1, 7, 15, 7, 47, 215, 253, 109, 1975, 3337, 1553, 13575, 16835, 61525, 26423, 0 };
            const std::uint32_t dim8353JoeKuoD6Init[]   =   { 1, 1, 7, 1, 21, 17, 53, 79, 175, 267, 999, 249, 6177, 10453, 12475, 59801, 47351, 0 };
            const std::uint32_t dim8354JoeKuoD6Init[]   =   { 1, 3, 5, 11, 3, 57, 5, 193, 421, 799, 1833, 2635, 6537, 4669, 9597, 40661, 12113, 0 };
            const std::uint32_t dim8355JoeKuoD6Init[]   =   { 1, 1, 7, 11, 9, 11, 69, 103, 139, 167, 159, 2469, 703, 1519, 21553, 62875, 60449, 0 };
            const std::uint32_t dim8356JoeKuoD6Init[]   =   { 1, 1, 5, 3, 9, 11, 17, 183, 499, 301, 1275, 605, 7655, 12141, 7783, 39413, 116263, 0 };
            const std::uint32_t dim8357JoeKuoD6Init[]   =   { 1, 1, 1, 7, 31, 55, 23, 79, 49, 247, 761, 3573, 8187, 4879, 27379, 15725, 81415, 0 };
            const std::uint32_t dim8358JoeKuoD6Init[]   =   { 1, 3, 5, 5, 5, 49, 23, 205, 509, 383, 1165, 3839, 7663, 1539, 19967, 55901, 4351, 0 };
            const std::uint32_t dim8359JoeKuoD6Init[]   =   { 1, 1, 1, 11, 7, 15, 3, 159, 235, 735, 391, 2231, 5043, 9759, 4569, 35601, 71989, 0 };
            const std::uint32_t dim8360JoeKuoD6Init[]   =   { 1, 3, 3, 15, 23, 3, 49, 97, 99, 517, 1097, 3517, 1035, 2319, 27705, 25547, 101555, 0 };
            const std::uint32_t dim8361JoeKuoD6Init[]   =   { 1, 3, 7, 11, 27, 29, 33, 241, 205, 113, 291, 1993, 3277, 13155, 1039, 42367, 130477, 0 };
            const std::uint32_t dim8362JoeKuoD6Init[]   =   { 1, 1, 1, 3, 29, 19, 15, 159, 35, 153, 1177, 3011, 6271, 8203, 8971, 19183, 102871, 0 };
            const std::uint32_t dim8363JoeKuoD6Init[]   =   { 1, 1, 1, 5, 5, 51, 19, 175, 209, 895, 229, 2355, 499, 7877, 4935, 22737, 35587, 0 };
            const std::uint32_t dim8364JoeKuoD6Init[]   =   { 1, 3, 7, 11, 15, 9, 7, 113, 41, 835, 1593, 3933, 7165, 10959, 15487, 30019, 114505, 0 };
            const std::uint32_t dim8365JoeKuoD6Init[]   =   { 1, 1, 7, 5, 31, 21, 27, 11, 421, 165, 1605, 1859, 29, 13051, 3273, 3893, 56089, 0 };
            const std::uint32_t dim8366JoeKuoD6Init[]   =   { 1, 3, 5, 5, 17, 51, 55, 187, 401, 977, 95, 2617, 727, 9609, 5075, 48989, 120299, 0 };
            const std::uint32_t dim8367JoeKuoD6Init[]   =   { 1, 1, 5, 7, 21, 31, 127, 87, 379, 125, 247, 3607, 2555, 11873, 32535, 16677, 122273, 0 };
            const std::uint32_t dim8368JoeKuoD6Init[]   =   { 1, 1, 1, 5, 19, 21, 51, 185, 203, 145, 1073, 167, 235, 12753, 17315, 14683, 44101, 0 };
            const std::uint32_t dim8369JoeKuoD6Init[]   =   { 1, 3, 3, 1, 5, 61, 71, 17, 63, 151, 823, 17, 5315, 4861, 17279, 23049, 84971, 0 };
            const std::uint32_t dim8370JoeKuoD6Init[]   =   { 1, 3, 3, 5, 21, 63, 21, 235, 295, 467, 1661, 2487, 335, 6107, 28709, 55875, 129085, 0 };
            const std::uint32_t dim8371JoeKuoD6Init[]   =   { 1, 3, 3, 5, 1, 55, 35, 187, 5, 687, 1633, 2999, 4513, 10105, 15249, 22591, 102857, 0 };
            const std::uint32_t dim8372JoeKuoD6Init[]   =   { 1, 3, 1, 5, 19, 1, 113, 27, 261, 623, 831, 3011, 4091, 11967, 17191, 17433, 99925, 0 };
            const std::uint32_t dim8373JoeKuoD6Init[]   =   { 1, 3, 5, 5, 25, 59, 81, 249, 463, 523, 183, 3049, 3675, 2705, 28379, 1279, 25579, 0 };
            const std::uint32_t dim8374JoeKuoD6Init[]   =   { 1, 1, 3, 9, 19, 19, 71, 127, 189, 613, 647, 1449, 7755, 1415, 9067, 30683, 79703, 0 };
            const std::uint32_t dim8375JoeKuoD6Init[]   =   { 1, 1, 7, 1, 27, 33, 61, 135, 233, 633, 1969, 2245, 5841, 14069, 6497, 63617, 101483, 0 };
            const std::uint32_t dim8376JoeKuoD6Init[]   =   { 1, 3, 3, 9, 23, 3, 17, 163, 309, 741, 2023, 2647, 5847, 7871, 22311, 38377, 70663, 0 };
            const std::uint32_t dim8377JoeKuoD6Init[]   =   { 1, 3, 5, 15, 31, 33, 51, 243, 209, 273, 1305, 1599, 6115, 6249, 8639, 5903, 17215, 0 };
            const std::uint32_t dim8378JoeKuoD6Init[]   =   { 1, 1, 1, 1, 21, 11, 107, 185, 463, 435, 149, 3789, 6283, 1327, 20893, 10417, 78673, 0 };
            const std::uint32_t dim8379JoeKuoD6Init[]   =   { 1, 1, 1, 13, 5, 53, 121, 129, 493, 419, 1711, 2765, 7673, 8979, 25845, 62759, 9669, 0 };
            const std::uint32_t dim8380JoeKuoD6Init[]   =   { 1, 3, 5, 5, 1, 39, 123, 47, 449, 639, 625, 2355, 511, 1685, 1415, 32417, 76529, 0 };
            const std::uint32_t dim8381JoeKuoD6Init[]   =   { 1, 3, 1, 11, 1, 49, 67, 237, 203, 967, 1401, 2773, 4951, 13889, 14147, 41031, 71897, 0 };
            const std::uint32_t dim8382JoeKuoD6Init[]   =   { 1, 3, 5, 11, 13, 49, 17, 113, 315, 207, 1057, 3395, 6151, 2767, 16571, 1811, 66403, 0 };
            const std::uint32_t dim8383JoeKuoD6Init[]   =   { 1, 1, 7, 7, 29, 63, 49, 115, 327, 987, 1853, 3355, 8139, 2703, 30039, 51343, 86999, 0 };
            const std::uint32_t dim8384JoeKuoD6Init[]   =   { 1, 1, 3, 9, 1, 3, 45, 35, 509, 483, 159, 1795, 8023, 6989, 3755, 20887, 13587, 0 };
            const std::uint32_t dim8385JoeKuoD6Init[]   =   { 1, 1, 3, 7, 1, 27, 39, 159, 283, 843, 317, 3229, 2297, 15031, 22039, 21721, 70583, 0 };
            const std::uint32_t dim8386JoeKuoD6Init[]   =   { 1, 1, 3, 11, 9, 23, 1, 35, 79, 77, 1671, 2583, 647, 12313, 16271, 2959, 108389, 0 };
            const std::uint32_t dim8387JoeKuoD6Init[]   =   { 1, 1, 1, 7, 5, 55, 1, 233, 429, 231, 833, 1279, 7815, 1051, 30627, 4435, 25997, 0 };
            const std::uint32_t dim8388JoeKuoD6Init[]   =   { 1, 3, 1, 15, 19, 53, 9, 165, 307, 437, 551, 2477, 1841, 11799, 18477, 5871, 20065, 0 };
            const std::uint32_t dim8389JoeKuoD6Init[]   =   { 1, 1, 1, 1, 21, 5, 65, 41, 77, 909, 93, 751, 2973, 7341, 30427, 60075, 71457, 0 };
            const std::uint32_t dim8390JoeKuoD6Init[]   =   { 1, 1, 3, 11, 25, 51, 49, 63, 165, 263, 1915, 747, 8053, 6361, 4843, 20189, 110147, 0 };
            const std::uint32_t dim8391JoeKuoD6Init[]   =   { 1, 3, 1, 9, 29, 9, 45, 177, 415, 557, 1555, 2967, 1239, 8115, 12853, 19193, 73681, 0 };
            const std::uint32_t dim8392JoeKuoD6Init[]   =   { 1, 1, 5, 5, 11, 5, 51, 157, 325, 517, 1601, 3911, 1487, 13631, 7483, 61515, 48937, 0 };
            const std::uint32_t dim8393JoeKuoD6Init[]   =   { 1, 3, 7, 5, 29, 31, 107, 47, 437, 837, 1791, 477, 1717, 7, 25855, 48793, 16385, 0 };
            const std::uint32_t dim8394JoeKuoD6Init[]   =   { 1, 1, 1, 3, 29, 49, 31, 255, 233, 935, 1993, 125, 2255, 12785, 2807, 54697, 62591, 0 };
            const std::uint32_t dim8395JoeKuoD6Init[]   =   { 1, 3, 1, 7, 15, 13, 9, 245, 79, 289, 841, 253, 5259, 16123, 29189, 63837, 127915, 0 };
            const std::uint32_t dim8396JoeKuoD6Init[]   =   { 1, 3, 7, 15, 15, 55, 91, 103, 445, 289, 1471, 423, 3387, 15609, 19311, 28993, 23473, 0 };
            const std::uint32_t dim8397JoeKuoD6Init[]   =   { 1, 1, 3, 11, 31, 39, 69, 125, 115, 309, 397, 3417, 5693, 10301, 1489, 25955, 2699, 0 };
            const std::uint32_t dim8398JoeKuoD6Init[]   =   { 1, 3, 3, 5, 13, 21, 51, 207, 239, 311, 1601, 2925, 6285, 9597, 30579, 62957, 6153, 0 };
            const std::uint32_t dim8399JoeKuoD6Init[]   =   { 1, 1, 7, 1, 27, 21, 63, 143, 399, 971, 1385, 1875, 5143, 6423, 6223, 27009, 14237, 0 };
            const std::uint32_t dim8400JoeKuoD6Init[]   =   { 1, 3, 5, 1, 5, 59, 125, 133, 151, 997, 1315, 3007, 8173, 16289, 13409, 839, 103519, 0 };
            const std::uint32_t dim8401JoeKuoD6Init[]   =   { 1, 1, 1, 13, 7, 57, 83, 33, 191, 121, 939, 3927, 6089, 10083, 5903, 52229, 78325, 0 };
            const std::uint32_t dim8402JoeKuoD6Init[]   =   { 1, 1, 3, 5, 9, 61, 43, 107, 279, 135, 1109, 3779, 5305, 15333, 12217, 41257, 20265, 0 };
            const std::uint32_t dim8403JoeKuoD6Init[]   =   { 1, 3, 7, 1, 31, 59, 83, 43, 219, 119, 511, 2973, 4587, 10701, 30959, 21489, 124077, 0 };
            const std::uint32_t dim8404JoeKuoD6Init[]   =   { 1, 1, 7, 9, 17, 3, 59, 151, 281, 209, 1405, 173, 3589, 7679, 29803, 53947, 68291, 0 };
            const std::uint32_t dim8405JoeKuoD6Init[]   =   { 1, 1, 7, 7, 5, 19, 53, 91, 1, 513, 1495, 231, 3627, 1115, 16121, 12953, 108343, 0 };
            const std::uint32_t dim8406JoeKuoD6Init[]   =   { 1, 3, 1, 13, 17, 3, 35, 35, 211, 481, 2029, 1035, 3131, 5653, 18097, 10735, 102453, 0 };
            const std::uint32_t dim8407JoeKuoD6Init[]   =   { 1, 3, 1, 11, 29, 7, 121, 135, 51, 837, 681, 1497, 7435, 2215, 26527, 33029, 93241, 0 };
            const std::uint32_t dim8408JoeKuoD6Init[]   =   { 1, 3, 3, 15, 29, 43, 17, 243, 195, 315, 499, 3801, 5691, 12119, 4061, 51769, 80497, 0 };
            const std::uint32_t dim8409JoeKuoD6Init[]   =   { 1, 1, 3, 1, 11, 1, 113, 11, 387, 579, 275, 2995, 895, 11859, 4017, 1543, 11853, 0 };
            const std::uint32_t dim8410JoeKuoD6Init[]   =   { 1, 1, 7, 9, 31, 27, 63, 217, 97, 275, 435, 1355, 5205, 6587, 32589, 46485, 103587, 0 };
            const std::uint32_t dim8411JoeKuoD6Init[]   =   { 1, 3, 7, 3, 7, 19, 51, 41, 81, 261, 1909, 1475, 425, 3173, 5679, 34701, 34977, 0 };
            const std::uint32_t dim8412JoeKuoD6Init[]   =   { 1, 1, 7, 3, 27, 15, 35, 49, 387, 471, 1997, 3643, 2701, 11853, 21311, 36027, 104357, 0 };
            const std::uint32_t dim8413JoeKuoD6Init[]   =   { 1, 3, 1, 9, 5, 47, 73, 163, 309, 891, 229, 2433, 6715, 6721, 25233, 37043, 29367, 0 };
            const std::uint32_t dim8414JoeKuoD6Init[]   =   { 1, 1, 1, 7, 27, 15, 9, 185, 421, 597, 565, 143, 1531, 15585, 17057, 54309, 82915, 0 };
            const std::uint32_t dim8415JoeKuoD6Init[]   =   { 1, 1, 7, 1, 5, 43, 87, 61, 121, 341, 25, 3795, 7161, 11985, 32197, 789, 69543, 0 };
            const std::uint32_t dim8416JoeKuoD6Init[]   =   { 1, 3, 5, 13, 29, 39, 81, 39, 263, 729, 1833, 365, 1073, 9869, 1845, 52621, 5, 0 };
            const std::uint32_t dim8417JoeKuoD6Init[]   =   { 1, 1, 7, 7, 5, 33, 117, 11, 371, 161, 1303, 629, 2285, 5827, 32355, 43359, 115595, 0 };
            const std::uint32_t dim8418JoeKuoD6Init[]   =   { 1, 3, 5, 5, 13, 57, 63, 9, 243, 533, 173, 2197, 717, 13441, 22131, 17783, 3319, 0 };
            const std::uint32_t dim8419JoeKuoD6Init[]   =   { 1, 1, 7, 11, 15, 31, 87, 255, 183, 273, 805, 2347, 5881, 15401, 273, 17397, 41827, 0 };
            const std::uint32_t dim8420JoeKuoD6Init[]   =   { 1, 3, 1, 13, 7, 17, 121, 49, 47, 121, 333, 3629, 5337, 4117, 2735, 36581, 61345, 0 };
            const std::uint32_t dim8421JoeKuoD6Init[]   =   { 1, 3, 3, 11, 9, 7, 25, 223, 379, 119, 385, 1217, 4803, 2947, 30665, 7733, 77893, 0 };
            const std::uint32_t dim8422JoeKuoD6Init[]   =   { 1, 3, 3, 7, 31, 35, 127, 97, 5, 373, 7, 3035, 843, 5991, 9265, 34289, 42785, 0 };
            const std::uint32_t dim8423JoeKuoD6Init[]   =   { 1, 3, 7, 3, 27, 19, 95, 253, 349, 871, 807, 413, 5847, 10467, 4277, 12429, 75773, 0 };
            const std::uint32_t dim8424JoeKuoD6Init[]   =   { 1, 3, 3, 7, 21, 1, 79, 89, 219, 505, 41, 505, 5159, 12839, 3317, 49873, 73705, 0 };
            const std::uint32_t dim8425JoeKuoD6Init[]   =   { 1, 3, 1, 7, 21, 43, 121, 113, 477, 559, 1831, 3759, 3315, 6367, 7149, 16395, 44703, 0 };
            const std::uint32_t dim8426JoeKuoD6Init[]   =   { 1, 1, 1, 7, 13, 53, 35, 53, 489, 975, 631, 863, 3067, 1905, 21351, 14705, 80041, 0 };
            const std::uint32_t dim8427JoeKuoD6Init[]   =   { 1, 1, 1, 5, 13, 27, 121, 65, 351, 123, 1731, 367, 8061, 5229, 8537, 20897, 130373, 0 };
            const std::uint32_t dim8428JoeKuoD6Init[]   =   { 1, 1, 5, 11, 15, 63, 101, 107, 105, 619, 1771, 3549, 7191, 9083, 16827, 29639, 34219, 0 };
            const std::uint32_t dim8429JoeKuoD6Init[]   =   { 1, 3, 1, 9, 15, 13, 87, 157, 379, 433, 217, 815, 5079, 1797, 26707, 35165, 92305, 0 };
            const std::uint32_t dim8430JoeKuoD6Init[]   =   { 1, 1, 5, 13, 27, 35, 31, 65, 313, 629, 375, 1391, 5373, 3497, 7311, 23105, 45293, 0 };
            const std::uint32_t dim8431JoeKuoD6Init[]   =   { 1, 3, 1, 3, 5, 39, 91, 37, 401, 419, 949, 2431, 3685, 6671, 20789, 8597, 44215, 0 };
            const std::uint32_t dim8432JoeKuoD6Init[]   =   { 1, 1, 7, 11, 7, 15, 3, 181, 363, 913, 309, 2009, 3805, 6651, 27677, 37711, 40813, 0 };
            const std::uint32_t dim8433JoeKuoD6Init[]   =   { 1, 3, 5, 5, 17, 11, 47, 9, 27, 459, 773, 1403, 7069, 12651, 8163, 42425, 126697, 0 };
            const std::uint32_t dim8434JoeKuoD6Init[]   =   { 1, 3, 1, 3, 11, 21, 65, 103, 405, 843, 59, 3653, 1759, 5265, 401, 58019, 124999, 0 };
            const std::uint32_t dim8435JoeKuoD6Init[]   =   { 1, 1, 3, 7, 11, 25, 61, 211, 199, 849, 1835, 1181, 5003, 3873, 23743, 45451, 54901, 0 };
            const std::uint32_t dim8436JoeKuoD6Init[]   =   { 1, 3, 5, 3, 29, 25, 43, 199, 481, 991, 699, 3937, 7601, 1253, 24399, 6625, 93917, 0 };
            const std::uint32_t dim8437JoeKuoD6Init[]   =   { 1, 1, 7, 3, 29, 33, 33, 151, 3, 825, 743, 773, 7825, 8157, 22121, 50095, 16435, 0 };
            const std::uint32_t dim8438JoeKuoD6Init[]   =   { 1, 3, 1, 1, 27, 15, 81, 151, 271, 167, 1755, 1289, 7473, 8525, 12525, 63139, 48787, 0 };
            const std::uint32_t dim8439JoeKuoD6Init[]   =   { 1, 1, 7, 13, 27, 33, 87, 125, 211, 631, 149, 3451, 643, 6975, 2659, 12629, 33187, 0 };
            const std::uint32_t dim8440JoeKuoD6Init[]   =   { 1, 1, 3, 3, 5, 49, 99, 99, 85, 647, 351, 2829, 7005, 7283, 5857, 46157, 52061, 0 };
            const std::uint32_t dim8441JoeKuoD6Init[]   =   { 1, 1, 3, 5, 11, 37, 43, 129, 21, 639, 187, 2279, 8189, 12877, 28707, 7133, 93639, 0 };
            const std::uint32_t dim8442JoeKuoD6Init[]   =   { 1, 1, 3, 7, 19, 13, 35, 51, 77, 811, 1553, 2769, 763, 4965, 4643, 37639, 44229, 0 };
            const std::uint32_t dim8443JoeKuoD6Init[]   =   { 1, 3, 5, 15, 11, 29, 103, 203, 435, 1017, 531, 1453, 1407, 6569, 619, 52103, 45213, 0 };
            const std::uint32_t dim8444JoeKuoD6Init[]   =   { 1, 1, 7, 5, 25, 25, 47, 229, 201, 843, 473, 2637, 2265, 4627, 20013, 41217, 76095, 0 };
            const std::uint32_t dim8445JoeKuoD6Init[]   =   { 1, 3, 3, 15, 23, 61, 109, 31, 57, 595, 1303, 3915, 67, 8205, 3553, 9543, 103385, 0 };
            const std::uint32_t dim8446JoeKuoD6Init[]   =   { 1, 1, 3, 3, 21, 19, 21, 41, 137, 905, 2045, 491, 1783, 151, 20963, 38009, 735, 0 };
            const std::uint32_t dim8447JoeKuoD6Init[]   =   { 1, 1, 7, 11, 13, 33, 95, 251, 179, 211, 1687, 3189, 6213, 3905, 2117, 15153, 4855, 0 };
            const std::uint32_t dim8448JoeKuoD6Init[]   =   { 1, 1, 5, 3, 19, 9, 67, 243, 23, 611, 1007, 1317, 7303, 11065, 21157, 56677, 81683, 0 };
            const std::uint32_t dim8449JoeKuoD6Init[]   =   { 1, 1, 3, 5, 19, 41, 63, 129, 233, 15, 37, 1445, 1095, 11309, 30181, 49199, 85113, 0 };
            const std::uint32_t dim8450JoeKuoD6Init[]   =   { 1, 3, 7, 1, 21, 53, 83, 79, 155, 379, 773, 1823, 1003, 2787, 31107, 36115, 40987, 0 };
            const std::uint32_t dim8451JoeKuoD6Init[]   =   { 1, 3, 3, 5, 3, 19, 7, 247, 417, 573, 407, 3577, 6079, 10275, 29791, 35149, 102565, 0 };
            const std::uint32_t dim8452JoeKuoD6Init[]   =   { 1, 3, 3, 9, 21, 49, 57, 223, 125, 671, 655, 2995, 5849, 5355, 21171, 54857, 114841, 0 };
            const std::uint32_t dim8453JoeKuoD6Init[]   =   { 1, 3, 7, 3, 27, 23, 125, 103, 485, 955, 963, 1865, 2321, 2263, 32497, 47973, 122111, 0 };
            const std::uint32_t dim8454JoeKuoD6Init[]   =   { 1, 1, 3, 15, 3, 1, 37, 19, 287, 165, 1717, 851, 3619, 13623, 24295, 48253, 13143, 0 };
            const std::uint32_t dim8455JoeKuoD6Init[]   =   { 1, 1, 7, 9, 13, 59, 69, 97, 113, 163, 871, 1795, 2719, 13675, 11767, 23687, 65841, 0 };
            const std::uint32_t dim8456JoeKuoD6Init[]   =   { 1, 1, 5, 3, 21, 31, 41, 115, 469, 177, 137, 2129, 1385, 10835, 16471, 59411, 30795, 0 };
            const std::uint32_t dim8457JoeKuoD6Init[]   =   { 1, 1, 7, 7, 13, 45, 73, 119, 457, 673, 1481, 3735, 2675, 11413, 9069, 34741, 8757, 0 };
            const std::uint32_t dim8458JoeKuoD6Init[]   =   { 1, 3, 5, 3, 15, 9, 11, 191, 499, 51, 1963, 3957, 1341, 7129, 13491, 65369, 4339, 0 };
            const std::uint32_t dim8459JoeKuoD6Init[]   =   { 1, 3, 7, 1, 5, 45, 103, 209, 183, 205, 525, 2417, 847, 10801, 10699, 16723, 36421, 0 };
            const std::uint32_t dim8460JoeKuoD6Init[]   =   { 1, 3, 7, 13, 3, 57, 37, 75, 299, 359, 2017, 125, 6737, 4859, 18443, 20765, 40319, 0 };
            const std::uint32_t dim8461JoeKuoD6Init[]   =   { 1, 1, 3, 5, 5, 17, 43, 141, 31, 141, 1019, 1685, 6831, 9433, 31245, 29227, 64083, 0 };
            const std::uint32_t dim8462JoeKuoD6Init[]   =   { 1, 3, 1, 13, 25, 47, 107, 69, 459, 595, 1759, 3391, 1531, 15197, 25975, 16971, 70861, 0 };
            const std::uint32_t dim8463JoeKuoD6Init[]   =   { 1, 1, 3, 11, 3, 53, 63, 211, 69, 469, 1407, 1435, 2763, 917, 19943, 16591, 97101, 0 };
            const std::uint32_t dim8464JoeKuoD6Init[]   =   { 1, 3, 5, 13, 25, 41, 39, 61, 319, 809, 1109, 169, 3101, 8801, 21697, 50759, 130985, 0 };
            const std::uint32_t dim8465JoeKuoD6Init[]   =   { 1, 3, 1, 9, 23, 1, 11, 249, 243, 605, 1419, 269, 1601, 2063, 5365, 38077, 106161, 0 };
            const std::uint32_t dim8466JoeKuoD6Init[]   =   { 1, 1, 7, 7, 19, 55, 97, 155, 477, 845, 61, 263, 1337, 8857, 31611, 44417, 43111, 0 };
            const std::uint32_t dim8467JoeKuoD6Init[]   =   { 1, 3, 3, 15, 7, 63, 45, 239, 291, 279, 1875, 3769, 1571, 15857, 13335, 17209, 34399, 0 };
            const std::uint32_t dim8468JoeKuoD6Init[]   =   { 1, 1, 7, 11, 19, 19, 69, 111, 217, 927, 1643, 1077, 4763, 15893, 17491, 39737, 10705, 0 };
            const std::uint32_t dim8469JoeKuoD6Init[]   =   { 1, 1, 5, 11, 3, 3, 31, 199, 109, 403, 973, 3833, 2729, 7285, 26743, 53915, 96203, 0 };
            const std::uint32_t dim8470JoeKuoD6Init[]   =   { 1, 3, 3, 11, 9, 7, 19, 145, 495, 805, 381, 919, 1323, 4343, 15887, 5163, 68267, 0 };
            const std::uint32_t dim8471JoeKuoD6Init[]   =   { 1, 1, 3, 11, 15, 31, 27, 201, 251, 279, 1377, 1313, 7143, 9731, 10451, 63431, 31307, 0 };
            const std::uint32_t dim8472JoeKuoD6Init[]   =   { 1, 1, 7, 1, 1, 55, 35, 249, 133, 645, 425, 279, 6401, 11687, 751, 947, 21791, 0 };
            const std::uint32_t dim8473JoeKuoD6Init[]   =   { 1, 3, 5, 9, 5, 43, 89, 31, 419, 573, 1087, 2197, 3451, 2393, 6569, 4859, 36607, 0 };
            const std::uint32_t dim8474JoeKuoD6Init[]   =   { 1, 3, 5, 15, 25, 51, 11, 149, 483, 789, 661, 967, 3537, 15511, 26587, 29861, 120337, 0 };
            const std::uint32_t dim8475JoeKuoD6Init[]   =   { 1, 3, 5, 13, 21, 39, 75, 111, 57, 321, 1591, 381, 7399, 10807, 26651, 62489, 78341, 0 };
            const std::uint32_t dim8476JoeKuoD6Init[]   =   { 1, 3, 1, 13, 1, 1, 49, 137, 193, 967, 805, 221, 803, 11381, 27803, 51013, 10475, 0 };
            const std::uint32_t dim8477JoeKuoD6Init[]   =   { 1, 3, 7, 5, 3, 13, 47, 195, 123, 753, 397, 1203, 981, 12863, 20845, 36155, 19055, 0 };
            const std::uint32_t dim8478JoeKuoD6Init[]   =   { 1, 1, 1, 9, 9, 11, 53, 203, 3, 163, 1537, 2061, 941, 12629, 16053, 34881, 31489, 0 };
            const std::uint32_t dim8479JoeKuoD6Init[]   =   { 1, 1, 1, 15, 5, 23, 51, 197, 459, 21, 1989, 2529, 4267, 1505, 8951, 15777, 20493, 0 };
            const std::uint32_t dim8480JoeKuoD6Init[]   =   { 1, 1, 7, 3, 31, 55, 9, 55, 217, 695, 1563, 4077, 3207, 7029, 10881, 39581, 82511, 0 };
            const std::uint32_t dim8481JoeKuoD6Init[]   =   { 1, 3, 1, 5, 1, 11, 81, 1, 505, 631, 1093, 3655, 2085, 7349, 5009, 49381, 30527, 0 };
            const std::uint32_t dim8482JoeKuoD6Init[]   =   { 1, 1, 7, 1, 27, 51, 25, 235, 213, 59, 611, 3883, 2909, 6411, 19605, 49001, 114529, 0 };
            const std::uint32_t dim8483JoeKuoD6Init[]   =   { 1, 3, 5, 3, 25, 29, 19, 137, 199, 681, 1625, 2711, 4873, 14677, 9767, 30441, 54673, 0 };
            const std::uint32_t dim8484JoeKuoD6Init[]   =   { 1, 1, 1, 9, 27, 43, 109, 161, 139, 675, 741, 2839, 1425, 5701, 19897, 12787, 33069, 0 };
            const std::uint32_t dim8485JoeKuoD6Init[]   =   { 1, 3, 5, 11, 21, 19, 77, 107, 197, 591, 1899, 1311, 3347, 6369, 26891, 3771, 32455, 0 };
            const std::uint32_t dim8486JoeKuoD6Init[]   =   { 1, 1, 7, 15, 31, 13, 109, 69, 207, 349, 249, 971, 7891, 10919, 31579, 38453, 124601, 0 };
            const std::uint32_t dim8487JoeKuoD6Init[]   =   { 1, 3, 5, 5, 27, 61, 67, 193, 53, 259, 1729, 4033, 2637, 8217, 22351, 4001, 118527, 0 };
            const std::uint32_t dim8488JoeKuoD6Init[]   =   { 1, 1, 3, 5, 9, 45, 55, 73, 189, 131, 1947, 1889, 837, 4085, 10393, 64359, 1037, 0 };
            const std::uint32_t dim8489JoeKuoD6Init[]   =   { 1, 3, 7, 3, 13, 51, 55, 37, 335, 939, 35, 461, 5057, 2595, 3305, 58823, 3941, 0 };
            const std::uint32_t dim8490JoeKuoD6Init[]   =   { 1, 1, 7, 11, 7, 3, 121, 139, 241, 477, 615, 2707, 5391, 7611, 11563, 41083, 16719, 0 };
            const std::uint32_t dim8491JoeKuoD6Init[]   =   { 1, 3, 3, 15, 27, 55, 13, 221, 195, 543, 215, 4035, 1647, 8111, 26425, 43571, 79893, 0 };
            const std::uint32_t dim8492JoeKuoD6Init[]   =   { 1, 1, 1, 5, 31, 5, 35, 145, 481, 339, 1951, 2155, 1309, 9851, 31505, 37371, 21247, 0 };
            const std::uint32_t dim8493JoeKuoD6Init[]   =   { 1, 1, 7, 9, 7, 5, 73, 119, 3, 741, 1351, 2855, 2207, 1465, 12047, 13507, 129173, 0 };
            const std::uint32_t dim8494JoeKuoD6Init[]   =   { 1, 1, 7, 13, 5, 57, 119, 63, 367, 327, 1257, 3191, 6929, 9593, 16565, 54397, 100305, 0 };
            const std::uint32_t dim8495JoeKuoD6Init[]   =   { 1, 3, 1, 11, 9, 1, 85, 53, 65, 945, 17, 1963, 4819, 16173, 11669, 53579, 33701, 0 };
            const std::uint32_t dim8496JoeKuoD6Init[]   =   { 1, 1, 3, 15, 25, 27, 3, 25, 23, 429, 197, 2717, 6107, 6719, 12457, 31793, 78647, 0 };
            const std::uint32_t dim8497JoeKuoD6Init[]   =   { 1, 1, 3, 1, 7, 63, 111, 235, 299, 91, 369, 1423, 7083, 4229, 18535, 33793, 19943, 0 };
            const std::uint32_t dim8498JoeKuoD6Init[]   =   { 1, 1, 7, 13, 9, 11, 123, 9, 169, 895, 1989, 1047, 6139, 11773, 19381, 9593, 14809, 0 };
            const std::uint32_t dim8499JoeKuoD6Init[]   =   { 1, 3, 1, 3, 29, 31, 63, 91, 59, 391, 1695, 2459, 3301, 5615, 3425, 8029, 16069, 0 };
            const std::uint32_t dim8500JoeKuoD6Init[]   =   { 1, 1, 7, 1, 25, 25, 79, 49, 131, 695, 987, 2911, 1109, 8237, 18227, 37287, 22443, 0 };
            const std::uint32_t dim8501JoeKuoD6Init[]   =   { 1, 3, 3, 3, 25, 21, 33, 207, 187, 381, 129, 445, 2967, 5119, 18777, 14849, 97115, 0 };
            const std::uint32_t dim8502JoeKuoD6Init[]   =   { 1, 1, 7, 13, 19, 9, 93, 185, 391, 579, 1509, 3245, 3921, 9473, 4795, 6685, 49549, 0 };
            const std::uint32_t dim8503JoeKuoD6Init[]   =   { 1, 1, 5, 11, 1, 49, 57, 127, 363, 811, 1383, 2869, 7625, 15177, 2581, 64253, 53677, 0 };
            const std::uint32_t dim8504JoeKuoD6Init[]   =   { 1, 1, 7, 3, 7, 27, 73, 187, 31, 1011, 1013, 3269, 6625, 5001, 20805, 13331, 93725, 0 };
            const std::uint32_t dim8505JoeKuoD6Init[]   =   { 1, 3, 7, 1, 23, 61, 123, 9, 141, 113, 1009, 3713, 4947, 9929, 24125, 1101, 104249, 0 };
            const std::uint32_t dim8506JoeKuoD6Init[]   =   { 1, 3, 7, 3, 23, 17, 25, 187, 189, 875, 1435, 163, 4197, 6619, 29031, 23117, 45347, 0 };
            const std::uint32_t dim8507JoeKuoD6Init[]   =   { 1, 1, 5, 7, 11, 17, 9, 55, 117, 223, 417, 3993, 1843, 5817, 20435, 56705, 98337, 0 };
            const std::uint32_t dim8508JoeKuoD6Init[]   =   { 1, 1, 7, 3, 21, 59, 3, 77, 297, 61, 407, 1603, 3209, 1611, 30185, 50275, 56139, 0 };
            const std::uint32_t dim8509JoeKuoD6Init[]   =   { 1, 1, 1, 5, 31, 3, 101, 167, 367, 543, 339, 1885, 7855, 9989, 30969, 6735, 108123, 0 };
            const std::uint32_t dim8510JoeKuoD6Init[]   =   { 1, 1, 3, 9, 27, 63, 9, 79, 335, 351, 673, 3107, 3955, 1799, 16879, 57631, 109073, 0 };
            const std::uint32_t dim8511JoeKuoD6Init[]   =   { 1, 1, 1, 3, 27, 17, 107, 115, 155, 371, 379, 2837, 6213, 2663, 1101, 451, 69517, 0 };
            const std::uint32_t dim8512JoeKuoD6Init[]   =   { 1, 1, 3, 9, 13, 3, 55, 9, 449, 43, 1011, 3281, 5311, 223, 10715, 6639, 79949, 0 };
            const std::uint32_t dim8513JoeKuoD6Init[]   =   { 1, 3, 3, 11, 23, 9, 43, 185, 271, 1005, 1041, 2633, 377, 4247, 10417, 51903, 19239, 0 };
            const std::uint32_t dim8514JoeKuoD6Init[]   =   { 1, 3, 1, 9, 15, 39, 115, 233, 33, 425, 1979, 583, 1901, 8943, 1527, 56065, 50159, 0 };
            const std::uint32_t dim8515JoeKuoD6Init[]   =   { 1, 1, 3, 1, 13, 1, 105, 149, 13, 625, 671, 1811, 3701, 241, 27357, 25835, 127265, 0 };
            const std::uint32_t dim8516JoeKuoD6Init[]   =   { 1, 3, 1, 9, 11, 23, 107, 197, 21, 589, 1065, 2591, 1163, 15013, 8931, 6355, 87079, 0 };
            const std::uint32_t dim8517JoeKuoD6Init[]   =   { 1, 3, 5, 3, 17, 5, 121, 61, 99, 987, 2033, 2237, 2299, 14689, 19785, 9599, 101035, 0 };
            const std::uint32_t dim8518JoeKuoD6Init[]   =   { 1, 1, 1, 1, 17, 25, 5, 97, 55, 75, 1419, 2793, 7215, 3185, 7029, 23023, 89089, 0 };
            const std::uint32_t dim8519JoeKuoD6Init[]   =   { 1, 3, 3, 3, 11, 57, 103, 191, 405, 463, 1421, 253, 6069, 10905, 18193, 719, 17337, 0 };
            const std::uint32_t dim8520JoeKuoD6Init[]   =   { 1, 3, 5, 11, 23, 37, 39, 169, 295, 527, 1671, 3913, 6057, 689, 27719, 47245, 95895, 0 };
            const std::uint32_t dim8521JoeKuoD6Init[]   =   { 1, 3, 7, 5, 13, 9, 43, 189, 411, 155, 559, 3701, 1623, 2401, 10359, 22675, 41897, 0 };
            const std::uint32_t dim8522JoeKuoD6Init[]   =   { 1, 1, 1, 11, 17, 55, 47, 101, 357, 669, 857, 2745, 6425, 11839, 13095, 10757, 52383, 0 };
            const std::uint32_t dim8523JoeKuoD6Init[]   =   { 1, 1, 7, 5, 11, 13, 53, 151, 93, 455, 133, 3353, 1417, 7917, 12913, 2615, 34281, 0 };
            const std::uint32_t dim8524JoeKuoD6Init[]   =   { 1, 1, 3, 5, 29, 57, 43, 35, 203, 423, 311, 3133, 1757, 1291, 2019, 3115, 126939, 0 };
            const std::uint32_t dim8525JoeKuoD6Init[]   =   { 1, 1, 3, 11, 9, 43, 119, 95, 135, 351, 1865, 2821, 717, 6275, 19713, 42315, 97935, 0 };
            const std::uint32_t dim8526JoeKuoD6Init[]   =   { 1, 3, 7, 7, 31, 51, 7, 29, 405, 31, 1765, 3231, 1315, 1307, 26469, 62033, 35619, 0 };
            const std::uint32_t dim8527JoeKuoD6Init[]   =   { 1, 1, 5, 7, 5, 17, 49, 137, 501, 631, 1401, 2851, 6971, 14721, 4329, 26483, 120007, 0 };
            const std::uint32_t dim8528JoeKuoD6Init[]   =   { 1, 1, 5, 13, 21, 19, 95, 93, 125, 331, 1797, 1653, 1891, 11081, 30989, 24671, 95421, 0 };
            const std::uint32_t dim8529JoeKuoD6Init[]   =   { 1, 3, 3, 11, 13, 29, 61, 157, 165, 39, 661, 89, 637, 1397, 12561, 62399, 129107, 0 };
            const std::uint32_t dim8530JoeKuoD6Init[]   =   { 1, 3, 1, 15, 13, 19, 5, 115, 345, 903, 531, 4069, 6775, 7433, 569, 21779, 13271, 0 };
            const std::uint32_t dim8531JoeKuoD6Init[]   =   { 1, 3, 3, 9, 5, 53, 17, 115, 67, 939, 1907, 3979, 4311, 3573, 857, 34931, 112397, 0 };
            const std::uint32_t dim8532JoeKuoD6Init[]   =   { 1, 3, 7, 11, 9, 47, 83, 85, 277, 219, 1701, 3013, 3037, 3473, 3797, 40713, 118573, 0 };
            const std::uint32_t dim8533JoeKuoD6Init[]   =   { 1, 1, 3, 13, 25, 33, 117, 115, 179, 119, 487, 3213, 2873, 17, 20865, 20043, 64381, 0 };
            const std::uint32_t dim8534JoeKuoD6Init[]   =   { 1, 1, 1, 3, 1, 45, 73, 103, 75, 579, 981, 2449, 2141, 8697, 22995, 59693, 104461, 0 };
            const std::uint32_t dim8535JoeKuoD6Init[]   =   { 1, 3, 1, 1, 29, 9, 9, 201, 55, 389, 1069, 2057, 4149, 9217, 10753, 7889, 95849, 0 };
            const std::uint32_t dim8536JoeKuoD6Init[]   =   { 1, 3, 7, 9, 27, 39, 19, 223, 7, 253, 55, 503, 3339, 6049, 32603, 34807, 115403, 0 };
            const std::uint32_t dim8537JoeKuoD6Init[]   =   { 1, 1, 5, 3, 13, 21, 67, 87, 205, 309, 1371, 1579, 281, 16135, 28403, 25951, 24109, 0 };
            const std::uint32_t dim8538JoeKuoD6Init[]   =   { 1, 3, 1, 3, 17, 21, 49, 77, 393, 943, 1701, 2661, 5173, 12875, 2731, 40531, 19301, 0 };
            const std::uint32_t dim8539JoeKuoD6Init[]   =   { 1, 3, 1, 5, 23, 29, 61, 161, 373, 389, 1699, 359, 2513, 4717, 30397, 24395, 20881, 0 };
            const std::uint32_t dim8540JoeKuoD6Init[]   =   { 1, 3, 5, 5, 29, 3, 115, 251, 277, 487, 7, 3301, 7945, 14233, 20497, 62035, 21537, 0 };
            const std::uint32_t dim8541JoeKuoD6Init[]   =   { 1, 1, 1, 9, 7, 59, 23, 85, 367, 109, 1761, 4011, 6535, 8263, 2081, 63647, 69807, 0 };
            const std::uint32_t dim8542JoeKuoD6Init[]   =   { 1, 1, 7, 11, 21, 41, 29, 219, 271, 617, 929, 407, 2899, 14299, 7645, 44815, 58817, 0 };
            const std::uint32_t dim8543JoeKuoD6Init[]   =   { 1, 3, 5, 7, 11, 29, 119, 33, 261, 571, 2013, 3327, 2181, 12767, 93, 2437, 76533, 0 };
            const std::uint32_t dim8544JoeKuoD6Init[]   =   { 1, 1, 7, 13, 17, 39, 55, 203, 261, 917, 967, 3651, 7235, 13751, 14439, 7591, 96553, 0 };
            const std::uint32_t dim8545JoeKuoD6Init[]   =   { 1, 1, 1, 1, 11, 39, 19, 21, 125, 93, 1773, 1155, 6213, 7173, 9057, 6219, 4643, 0 };
            const std::uint32_t dim8546JoeKuoD6Init[]   =   { 1, 3, 1, 5, 1, 31, 55, 143, 425, 539, 61, 3377, 7647, 257, 15007, 24511, 8707, 0 };
            const std::uint32_t dim8547JoeKuoD6Init[]   =   { 1, 3, 3, 11, 27, 51, 103, 197, 427, 139, 181, 1169, 3123, 11803, 5285, 1321, 62267, 0 };
            const std::uint32_t dim8548JoeKuoD6Init[]   =   { 1, 3, 5, 9, 11, 3, 13, 149, 197, 37, 31, 927, 3313, 16149, 14209, 60177, 46525, 0 };
            const std::uint32_t dim8549JoeKuoD6Init[]   =   { 1, 1, 5, 13, 15, 29, 103, 49, 355, 797, 1253, 1833, 621, 3877, 9981, 49207, 91035, 0 };
            const std::uint32_t dim8550JoeKuoD6Init[]   =   { 1, 1, 3, 3, 13, 19, 27, 51, 151, 275, 35, 3755, 7511, 14197, 26141, 43765, 104327, 0 };
            const std::uint32_t dim8551JoeKuoD6Init[]   =   { 1, 3, 5, 15, 23, 47, 101, 213, 97, 957, 831, 1533, 7913, 15763, 29717, 60425, 38559, 0 };
            const std::uint32_t dim8552JoeKuoD6Init[]   =   { 1, 1, 7, 9, 29, 31, 49, 245, 361, 299, 151, 2969, 1487, 1761, 11697, 4043, 100909, 0 };
            const std::uint32_t dim8553JoeKuoD6Init[]   =   { 1, 1, 1, 3, 17, 49, 99, 159, 3, 525, 1527, 3435, 5113, 459, 13341, 54103, 85813, 0 };
            const std::uint32_t dim8554JoeKuoD6Init[]   =   { 1, 3, 1, 1, 5, 59, 35, 75, 107, 91, 1621, 3261, 619, 3271, 10813, 29857, 1547, 0 };
            const std::uint32_t dim8555JoeKuoD6Init[]   =   { 1, 1, 5, 9, 9, 33, 85, 245, 39, 879, 1621, 2587, 3825, 12939, 30113, 24611, 68491, 0 };
            const std::uint32_t dim8556JoeKuoD6Init[]   =   { 1, 3, 1, 3, 9, 39, 93, 241, 307, 237, 3, 1763, 7729, 9257, 31911, 32591, 77333, 0 };
            const std::uint32_t dim8557JoeKuoD6Init[]   =   { 1, 3, 1, 3, 27, 7, 51, 121, 317, 361, 1027, 95, 7035, 3097, 21007, 38311, 88287, 0 };
            const std::uint32_t dim8558JoeKuoD6Init[]   =   { 1, 3, 7, 3, 19, 3, 111, 115, 339, 793, 1571, 3101, 1911, 14929, 12841, 45871, 119905, 0 };
            const std::uint32_t dim8559JoeKuoD6Init[]   =   { 1, 1, 5, 7, 31, 61, 37, 143, 279, 941, 1215, 2411, 7617, 1657, 10189, 19139, 6307, 0 };
            const std::uint32_t dim8560JoeKuoD6Init[]   =   { 1, 1, 3, 9, 21, 35, 13, 157, 187, 79, 689, 1085, 37, 4549, 5901, 15321, 61627, 0 };
            const std::uint32_t dim8561JoeKuoD6Init[]   =   { 1, 3, 1, 13, 15, 39, 21, 231, 39, 327, 801, 2321, 587, 1877, 3489, 54467, 95773, 0 };
            const std::uint32_t dim8562JoeKuoD6Init[]   =   { 1, 1, 5, 7, 1, 9, 53, 1, 243, 365, 789, 3833, 317, 10697, 26567, 65187, 22507, 0 };
            const std::uint32_t dim8563JoeKuoD6Init[]   =   { 1, 3, 3, 7, 9, 41, 31, 135, 425, 939, 15, 2043, 6593, 7651, 25467, 62549, 35847, 0 };
            const std::uint32_t dim8564JoeKuoD6Init[]   =   { 1, 1, 1, 7, 15, 23, 19, 57, 421, 25, 1037, 3055, 6173, 12451, 485, 54567, 109561, 0 };
            const std::uint32_t dim8565JoeKuoD6Init[]   =   { 1, 3, 5, 1, 3, 29, 67, 233, 157, 677, 1711, 513, 4673, 2895, 1983, 31075, 1861, 0 };
            const std::uint32_t dim8566JoeKuoD6Init[]   =   { 1, 1, 1, 1, 7, 39, 115, 251, 275, 791, 15, 1685, 6835, 14685, 12607, 28213, 121475, 0 };
            const std::uint32_t dim8567JoeKuoD6Init[]   =   { 1, 1, 5, 5, 13, 11, 103, 93, 489, 709, 1339, 2407, 1663, 10195, 3135, 15531, 88427, 0 };
            const std::uint32_t dim8568JoeKuoD6Init[]   =   { 1, 1, 7, 7, 17, 1, 123, 143, 31, 721, 1739, 2273, 3785, 10261, 14741, 52573, 113677, 0 };
            const std::uint32_t dim8569JoeKuoD6Init[]   =   { 1, 3, 7, 3, 9, 21, 77, 13, 241, 429, 165, 3399, 7543, 2633, 21129, 13537, 84473, 0 };
            const std::uint32_t dim8570JoeKuoD6Init[]   =   { 1, 1, 1, 11, 21, 33, 125, 123, 189, 337, 163, 3727, 2101, 14113, 1719, 46017, 68601, 0 };
            const std::uint32_t dim8571JoeKuoD6Init[]   =   { 1, 1, 7, 9, 9, 53, 101, 111, 125, 605, 1419, 3901, 1769, 4585, 20063, 20857, 21901, 0 };
            const std::uint32_t dim8572JoeKuoD6Init[]   =   { 1, 3, 7, 11, 1, 19, 51, 7, 457, 119, 871, 3847, 57, 11437, 28763, 58831, 675, 0 };
            const std::uint32_t dim8573JoeKuoD6Init[]   =   { 1, 3, 1, 15, 25, 63, 69, 25, 405, 823, 1701, 2441, 7561, 8679, 31643, 29325, 25563, 0 };
            const std::uint32_t dim8574JoeKuoD6Init[]   =   { 1, 1, 3, 9, 15, 5, 89, 13, 73, 951, 959, 2693, 4565, 13095, 991, 12419, 8267, 0 };
            const std::uint32_t dim8575JoeKuoD6Init[]   =   { 1, 1, 7, 1, 15, 1, 119, 223, 213, 585, 1047, 2623, 4141, 2043, 1583, 59155, 5133, 0 };
            const std::uint32_t dim8576JoeKuoD6Init[]   =   { 1, 3, 3, 3, 17, 37, 81, 233, 87, 843, 1597, 1251, 4713, 10813, 24357, 48499, 84465, 0 };
            const std::uint32_t dim8577JoeKuoD6Init[]   =   { 1, 1, 1, 1, 11, 55, 125, 5, 255, 809, 543, 2351, 7079, 7801, 29247, 23937, 97405, 0 };
            const std::uint32_t dim8578JoeKuoD6Init[]   =   { 1, 3, 3, 5, 17, 55, 87, 245, 371, 679, 943, 655, 5857, 261, 28229, 22519, 35191, 0 };
            const std::uint32_t dim8579JoeKuoD6Init[]   =   { 1, 1, 7, 15, 9, 49, 25, 155, 13, 893, 1303, 2317, 2903, 15601, 1433, 20397, 70125, 0 };
            const std::uint32_t dim8580JoeKuoD6Init[]   =   { 1, 3, 5, 3, 11, 47, 99, 63, 253, 95, 1023, 397, 4307, 4771, 17027, 19833, 18269, 0 };
            const std::uint32_t dim8581JoeKuoD6Init[]   =   { 1, 3, 3, 7, 25, 17, 69, 119, 475, 575, 1637, 3785, 649, 11557, 22457, 38633, 96153, 0 };
            const std::uint32_t dim8582JoeKuoD6Init[]   =   { 1, 1, 1, 5, 31, 55, 85, 83, 307, 201, 1543, 727, 977, 15779, 21907, 31025, 38969, 0 };
            const std::uint32_t dim8583JoeKuoD6Init[]   =   { 1, 3, 5, 1, 7, 53, 107, 239, 341, 237, 1567, 2717, 3197, 12419, 23733, 42119, 86619, 0 };
            const std::uint32_t dim8584JoeKuoD6Init[]   =   { 1, 1, 5, 13, 3, 7, 105, 95, 201, 953, 781, 2043, 5263, 13427, 10303, 60027, 19297, 0 };
            const std::uint32_t dim8585JoeKuoD6Init[]   =   { 1, 1, 5, 15, 25, 51, 5, 77, 165, 297, 1281, 1635, 4139, 11569, 32325, 23135, 27013, 0 };
            const std::uint32_t dim8586JoeKuoD6Init[]   =   { 1, 1, 3, 9, 3, 59, 107, 137, 251, 715, 1477, 511, 5629, 12205, 7541, 62559, 4253, 0 };
            const std::uint32_t dim8587JoeKuoD6Init[]   =   { 1, 1, 7, 11, 31, 29, 7, 251, 119, 547, 1179, 3063, 1625, 8941, 30515, 13601, 72741, 0 };
            const std::uint32_t dim8588JoeKuoD6Init[]   =   { 1, 3, 7, 13, 27, 43, 31, 43, 465, 355, 1063, 2305, 1425, 11963, 27327, 53335, 127517, 0 };
            const std::uint32_t dim8589JoeKuoD6Init[]   =   { 1, 3, 1, 3, 21, 17, 53, 171, 269, 783, 349, 1879, 575, 13537, 16931, 61171, 23499, 0 };
            const std::uint32_t dim8590JoeKuoD6Init[]   =   { 1, 3, 5, 3, 11, 5, 121, 227, 237, 841, 431, 3209, 3241, 6071, 23465, 39533, 102391, 0 };
            const std::uint32_t dim8591JoeKuoD6Init[]   =   { 1, 3, 5, 11, 9, 1, 59, 143, 181, 869, 1859, 1543, 6419, 13305, 29075, 28051, 105799, 0 };
            const std::uint32_t dim8592JoeKuoD6Init[]   =   { 1, 1, 7, 13, 31, 1, 105, 169, 67, 693, 1667, 2181, 4127, 4605, 3701, 36467, 19631, 0 };
            const std::uint32_t dim8593JoeKuoD6Init[]   =   { 1, 1, 7, 5, 31, 15, 119, 161, 55, 549, 1195, 4051, 1923, 2497, 8289, 60393, 96181, 0 };
            const std::uint32_t dim8594JoeKuoD6Init[]   =   { 1, 1, 3, 3, 5, 43, 13, 123, 469, 603, 2047, 2347, 815, 3457, 7503, 25261, 71951, 0 };
            const std::uint32_t dim8595JoeKuoD6Init[]   =   { 1, 1, 7, 3, 13, 25, 85, 141, 497, 405, 957, 1407, 2075, 12445, 6675, 9993, 40429, 0 };
            const std::uint32_t dim8596JoeKuoD6Init[]   =   { 1, 1, 5, 13, 29, 43, 99, 113, 307, 1003, 859, 723, 7513, 12249, 12653, 57685, 89551, 0 };
            const std::uint32_t dim8597JoeKuoD6Init[]   =   { 1, 3, 7, 3, 11, 3, 9, 141, 501, 113, 69, 2285, 4525, 9049, 24765, 11585, 53787, 0 };
            const std::uint32_t dim8598JoeKuoD6Init[]   =   { 1, 1, 3, 1, 25, 41, 103, 159, 215, 871, 77, 1849, 609, 15877, 32515, 22931, 11933, 0 };
            const std::uint32_t dim8599JoeKuoD6Init[]   =   { 1, 1, 5, 11, 3, 27, 27, 111, 479, 861, 1041, 3777, 4443, 3095, 30379, 6293, 30823, 0 };
            const std::uint32_t dim8600JoeKuoD6Init[]   =   { 1, 3, 5, 5, 27, 45, 9, 25, 451, 845, 1153, 897, 325, 15679, 30151, 37695, 54593, 0 };
            const std::uint32_t dim8601JoeKuoD6Init[]   =   { 1, 3, 7, 1, 15, 47, 87, 135, 87, 567, 221, 3173, 769, 8173, 2957, 51287, 20961, 0 };
            const std::uint32_t dim8602JoeKuoD6Init[]   =   { 1, 3, 1, 9, 3, 33, 1, 71, 147, 983, 1485, 3531, 213, 2353, 28269, 49353, 88343, 0 };
            const std::uint32_t dim8603JoeKuoD6Init[]   =   { 1, 1, 3, 11, 11, 63, 109, 255, 35, 127, 1777, 791, 1379, 9539, 4915, 21593, 98901, 0 };
            const std::uint32_t dim8604JoeKuoD6Init[]   =   { 1, 1, 7, 5, 3, 47, 93, 219, 381, 963, 359, 2461, 7629, 2803, 17345, 54311, 79057, 0 };
            const std::uint32_t dim8605JoeKuoD6Init[]   =   { 1, 3, 5, 13, 13, 21, 1, 65, 455, 203, 29, 3717, 4495, 1285, 25289, 38597, 42431, 0 };
            const std::uint32_t dim8606JoeKuoD6Init[]   =   { 1, 1, 3, 3, 27, 57, 7, 171, 65, 469, 1921, 3855, 1637, 5517, 14907, 48239, 117573, 0 };
            const std::uint32_t dim8607JoeKuoD6Init[]   =   { 1, 3, 5, 1, 11, 35, 105, 251, 19, 219, 1191, 2177, 7885, 8399, 30527, 61415, 122215, 0 };
            const std::uint32_t dim8608JoeKuoD6Init[]   =   { 1, 3, 5, 5, 21, 25, 59, 193, 509, 147, 1805, 561, 3505, 9639, 14221, 31, 99261, 0 };
            const std::uint32_t dim8609JoeKuoD6Init[]   =   { 1, 1, 5, 13, 31, 23, 35, 143, 367, 385, 1335, 2497, 3573, 8113, 16661, 16147, 8763, 0 };
            const std::uint32_t dim8610JoeKuoD6Init[]   =   { 1, 1, 7, 13, 15, 27, 35, 15, 7, 539, 633, 1145, 2267, 11527, 20975, 16689, 58227, 0 };
            const std::uint32_t dim8611JoeKuoD6Init[]   =   { 1, 1, 1, 15, 9, 11, 51, 121, 381, 331, 1445, 187, 519, 15827, 27611, 32891, 113671, 0 };
            const std::uint32_t dim8612JoeKuoD6Init[]   =   { 1, 3, 1, 5, 19, 3, 77, 67, 107, 105, 1025, 3229, 6869, 5717, 4227, 28489, 59759, 0 };
            const std::uint32_t dim8613JoeKuoD6Init[]   =   { 1, 1, 5, 15, 25, 23, 7, 25, 103, 733, 525, 453, 6467, 2901, 7197, 33267, 68177, 0 };
            const std::uint32_t dim8614JoeKuoD6Init[]   =   { 1, 1, 5, 7, 27, 27, 41, 93, 449, 733, 571, 411, 1709, 9557, 549, 5925, 24123, 0 };
            const std::uint32_t dim8615JoeKuoD6Init[]   =   { 1, 1, 7, 5, 31, 57, 119, 227, 105, 533, 717, 3357, 2495, 6467, 7211, 38169, 44603, 0 };
            const std::uint32_t dim8616JoeKuoD6Init[]   =   { 1, 1, 5, 7, 29, 9, 125, 241, 471, 571, 1271, 2911, 8087, 5067, 31139, 39681, 28579, 0 };
            const std::uint32_t dim8617JoeKuoD6Init[]   =   { 1, 3, 5, 11, 25, 53, 109, 35, 183, 109, 1961, 1681, 7773, 6935, 28049, 37279, 96829, 0 };
            const std::uint32_t dim8618JoeKuoD6Init[]   =   { 1, 1, 1, 11, 1, 17, 47, 245, 231, 747, 1395, 1635, 5129, 3165, 627, 34463, 38967, 0 };
            const std::uint32_t dim8619JoeKuoD6Init[]   =   { 1, 3, 5, 1, 9, 41, 25, 215, 251, 525, 1399, 3405, 7399, 11041, 5599, 51167, 38697, 0 };
            const std::uint32_t dim8620JoeKuoD6Init[]   =   { 1, 3, 3, 13, 11, 15, 121, 95, 139, 611, 633, 3941, 2619, 15123, 28535, 64823, 17527, 0 };
            const std::uint32_t dim8621JoeKuoD6Init[]   =   { 1, 3, 7, 13, 21, 53, 65, 175, 81, 5, 699, 1525, 7397, 2465, 4479, 58225, 26387, 0 };
            const std::uint32_t dim8622JoeKuoD6Init[]   =   { 1, 1, 5, 7, 9, 31, 31, 149, 359, 613, 397, 153, 4861, 8195, 22969, 26003, 124423, 0 };
            const std::uint32_t dim8623JoeKuoD6Init[]   =   { 1, 3, 1, 13, 27, 17, 107, 27, 19, 13, 1481, 573, 7701, 6273, 30255, 16125, 11809, 0 };
            const std::uint32_t dim8624JoeKuoD6Init[]   =   { 1, 3, 1, 9, 15, 1, 45, 105, 287, 901, 667, 3197, 3493, 12259, 1511, 63361, 94257, 0 };
            const std::uint32_t dim8625JoeKuoD6Init[]   =   { 1, 3, 1, 3, 25, 53, 19, 87, 365, 585, 1569, 1731, 3747, 11985, 22673, 17767, 113779, 0 };
            const std::uint32_t dim8626JoeKuoD6Init[]   =   { 1, 3, 3, 9, 7, 21, 103, 201, 501, 149, 1939, 3111, 4739, 8389, 27127, 55889, 54487, 0 };
            const std::uint32_t dim8627JoeKuoD6Init[]   =   { 1, 3, 5, 7, 25, 53, 75, 57, 19, 505, 849, 2631, 6999, 11269, 24541, 17695, 97671, 0 };
            const std::uint32_t dim8628JoeKuoD6Init[]   =   { 1, 1, 7, 15, 5, 51, 123, 93, 445, 379, 1729, 2747, 5821, 10779, 29335, 57419, 109339, 0 };
            const std::uint32_t dim8629JoeKuoD6Init[]   =   { 1, 1, 7, 3, 7, 57, 117, 65, 297, 891, 487, 1535, 2361, 10457, 30759, 34571, 129949, 0 };
            const std::uint32_t dim8630JoeKuoD6Init[]   =   { 1, 3, 5, 5, 17, 51, 27, 103, 55, 925, 947, 1237, 1629, 12687, 14775, 49627, 100939, 0 };
            const std::uint32_t dim8631JoeKuoD6Init[]   =   { 1, 3, 3, 15, 1, 11, 75, 177, 399, 55, 1705, 1165, 7525, 8909, 13071, 60703, 11561, 0 };
            const std::uint32_t dim8632JoeKuoD6Init[]   =   { 1, 1, 1, 7, 13, 29, 23, 65, 279, 853, 637, 3947, 4099, 6465, 7061, 50417, 35015, 0 };
            const std::uint32_t dim8633JoeKuoD6Init[]   =   { 1, 1, 3, 3, 15, 11, 111, 169, 135, 279, 1941, 3035, 3027, 6813, 13363, 20387, 3257, 0 };
            const std::uint32_t dim8634JoeKuoD6Init[]   =   { 1, 3, 3, 11, 3, 5, 95, 181, 405, 313, 39, 1503, 2443, 3221, 17021, 23485, 43909, 0 };
            const std::uint32_t dim8635JoeKuoD6Init[]   =   { 1, 1, 1, 3, 17, 63, 27, 247, 441, 533, 449, 3845, 4021, 14269, 31477, 7013, 37473, 0 };
            const std::uint32_t dim8636JoeKuoD6Init[]   =   { 1, 1, 5, 13, 29, 39, 41, 95, 417, 21, 685, 609, 5787, 13145, 32677, 6121, 50919, 0 };
            const std::uint32_t dim8637JoeKuoD6Init[]   =   { 1, 1, 5, 3, 17, 5, 93, 143, 171, 681, 1143, 2875, 805, 15823, 29649, 63327, 12041, 0 };
            const std::uint32_t dim8638JoeKuoD6Init[]   =   { 1, 1, 1, 11, 3, 53, 123, 105, 59, 485, 1799, 2939, 657, 2485, 29563, 36221, 89095, 0 };
            const std::uint32_t dim8639JoeKuoD6Init[]   =   { 1, 1, 5, 5, 15, 13, 127, 87, 211, 579, 175, 793, 6895, 9051, 17681, 28831, 31783, 0 };
            const std::uint32_t dim8640JoeKuoD6Init[]   =   { 1, 3, 7, 5, 11, 37, 9, 219, 453, 697, 139, 335, 6411, 8495, 4203, 29065, 114837, 0 };
            const std::uint32_t dim8641JoeKuoD6Init[]   =   { 1, 1, 3, 5, 31, 25, 89, 215, 249, 271, 1731, 3133, 3947, 10227, 9679, 51303, 82833, 0 };
            const std::uint32_t dim8642JoeKuoD6Init[]   =   { 1, 3, 5, 1, 31, 15, 7, 131, 369, 757, 1963, 3223, 35, 13967, 31807, 5093, 113743, 0 };
            const std::uint32_t dim8643JoeKuoD6Init[]   =   { 1, 1, 7, 3, 15, 23, 21, 173, 295, 929, 1137, 3943, 1985, 13015, 8523, 59117, 127, 0 };
            const std::uint32_t dim8644JoeKuoD6Init[]   =   { 1, 3, 7, 1, 31, 1, 115, 229, 345, 859, 1757, 1835, 7491, 4545, 1483, 40149, 122321, 0 };
            const std::uint32_t dim8645JoeKuoD6Init[]   =   { 1, 1, 1, 3, 13, 5, 3, 133, 177, 47, 1515, 17, 5663, 3185, 2775, 31389, 37409, 0 };
            const std::uint32_t dim8646JoeKuoD6Init[]   =   { 1, 1, 3, 3, 31, 3, 43, 137, 185, 803, 709, 391, 3513, 8117, 32593, 46593, 61037, 0 };
            const std::uint32_t dim8647JoeKuoD6Init[]   =   { 1, 1, 1, 7, 29, 27, 13, 35, 61, 961, 777, 2725, 7379, 7053, 21781, 60285, 49221, 0 };
            const std::uint32_t dim8648JoeKuoD6Init[]   =   { 1, 3, 7, 15, 7, 7, 15, 123, 109, 97, 361, 791, 4773, 8111, 4319, 13981, 92505, 0 };
            const std::uint32_t dim8649JoeKuoD6Init[]   =   { 1, 1, 3, 11, 21, 33, 113, 221, 453, 981, 341, 4041, 5129, 5981, 11051, 17243, 19023, 0 };
            const std::uint32_t dim8650JoeKuoD6Init[]   =   { 1, 3, 1, 1, 19, 7, 75, 213, 467, 221, 1829, 1275, 5729, 6843, 23855, 44805, 89269, 0 };
            const std::uint32_t dim8651JoeKuoD6Init[]   =   { 1, 1, 3, 7, 5, 29, 39, 125, 147, 329, 1485, 2793, 2329, 14979, 18395, 37951, 58699, 0 };
            const std::uint32_t dim8652JoeKuoD6Init[]   =   { 1, 3, 1, 3, 11, 37, 117, 189, 103, 381, 39, 31, 5205, 5601, 17127, 49073, 121417, 0 };
            const std::uint32_t dim8653JoeKuoD6Init[]   =   { 1, 3, 3, 13, 23, 49, 57, 187, 441, 189, 349, 2559, 3313, 1321, 7731, 57309, 80195, 0 };
            const std::uint32_t dim8654JoeKuoD6Init[]   =   { 1, 3, 7, 1, 17, 9, 21, 15, 447, 333, 959, 3471, 5301, 8573, 9761, 23183, 57997, 0 };
            const std::uint32_t dim8655JoeKuoD6Init[]   =   { 1, 3, 1, 9, 19, 1, 101, 71, 325, 309, 85, 2097, 8003, 12249, 1887, 2097, 68375, 0 };
            const std::uint32_t dim8656JoeKuoD6Init[]   =   { 1, 1, 7, 7, 11, 39, 85, 241, 293, 205, 387, 1539, 6583, 1395, 8869, 48843, 49983, 0 };
            const std::uint32_t dim8657JoeKuoD6Init[]   =   { 1, 3, 7, 13, 11, 23, 83, 125, 55, 429, 169, 1893, 4657, 643, 3405, 9943, 128753, 0 };
            const std::uint32_t dim8658JoeKuoD6Init[]   =   { 1, 1, 3, 11, 19, 43, 13, 171, 495, 117, 437, 3697, 6723, 6199, 1859, 39637, 111499, 0 };
            const std::uint32_t dim8659JoeKuoD6Init[]   =   { 1, 1, 1, 5, 1, 31, 83, 199, 129, 941, 1637, 1997, 5011, 14957, 32427, 60797, 4989, 0 };
            const std::uint32_t dim8660JoeKuoD6Init[]   =   { 1, 3, 3, 3, 5, 61, 33, 225, 315, 157, 1709, 807, 7809, 11063, 319, 20901, 73599, 0 };
            const std::uint32_t dim8661JoeKuoD6Init[]   =   { 1, 1, 7, 3, 27, 3, 1, 173, 125, 769, 1203, 3357, 4899, 13115, 7081, 42459, 18525, 0 };
            const std::uint32_t dim8662JoeKuoD6Init[]   =   { 1, 1, 7, 9, 9, 27, 43, 115, 229, 867, 661, 1825, 2883, 4285, 22393, 65141, 24699, 0 };
            const std::uint32_t dim8663JoeKuoD6Init[]   =   { 1, 1, 3, 7, 5, 9, 93, 47, 33, 823, 309, 2977, 5791, 9177, 27645, 35683, 57455, 0 };
            const std::uint32_t dim8664JoeKuoD6Init[]   =   { 1, 1, 5, 7, 9, 53, 9, 77, 499, 1023, 917, 209, 7311, 249, 773, 18303, 41447, 0 };
            const std::uint32_t dim8665JoeKuoD6Init[]   =   { 1, 1, 3, 5, 7, 9, 33, 73, 325, 369, 1657, 2257, 2893, 13911, 10797, 21055, 103511, 0 };
            const std::uint32_t dim8666JoeKuoD6Init[]   =   { 1, 3, 1, 3, 21, 31, 125, 29, 149, 513, 979, 2271, 989, 9541, 4179, 13215, 71369, 0 };
            const std::uint32_t dim8667JoeKuoD6Init[]   =   { 1, 1, 7, 7, 19, 41, 39, 165, 59, 79, 137, 3479, 3389, 6635, 21467, 51073, 20765, 0 };
            const std::uint32_t dim8668JoeKuoD6Init[]   =   { 1, 3, 3, 5, 7, 13, 109, 53, 335, 627, 339, 3825, 287, 6077, 11319, 2377, 112693, 0 };
            const std::uint32_t dim8669JoeKuoD6Init[]   =   { 1, 3, 3, 1, 3, 57, 9, 47, 437, 717, 563, 1219, 6191, 9081, 21533, 2651, 17275, 0 };
            const std::uint32_t dim8670JoeKuoD6Init[]   =   { 1, 1, 1, 5, 21, 9, 109, 109, 339, 947, 1699, 1487, 6477, 12601, 12327, 39427, 80937, 0 };
            const std::uint32_t dim8671JoeKuoD6Init[]   =   { 1, 1, 7, 9, 1, 5, 55, 43, 95, 733, 1151, 3657, 2119, 11947, 21279, 21581, 22053, 0 };
            const std::uint32_t dim8672JoeKuoD6Init[]   =   { 1, 3, 5, 11, 7, 9, 97, 149, 55, 523, 1911, 1389, 5343, 5533, 15439, 65313, 73421, 0 };
            const std::uint32_t dim8673JoeKuoD6Init[]   =   { 1, 1, 3, 7, 19, 15, 119, 141, 57, 243, 423, 981, 1407, 12633, 20455, 53069, 98593, 0 };
            const std::uint32_t dim8674JoeKuoD6Init[]   =   { 1, 1, 3, 3, 15, 57, 71, 203, 15, 133, 601, 805, 2821, 11623, 147, 4333, 97681, 0 };
            const std::uint32_t dim8675JoeKuoD6Init[]   =   { 1, 1, 5, 7, 17, 61, 15, 251, 53, 699, 105, 1195, 3979, 41, 9077, 5145, 80057, 0 };
            const std::uint32_t dim8676JoeKuoD6Init[]   =   { 1, 1, 5, 15, 29, 33, 53, 19, 41, 471, 1143, 65, 5833, 8417, 17263, 35859, 45035, 0 };
            const std::uint32_t dim8677JoeKuoD6Init[]   =   { 1, 1, 1, 1, 15, 51, 73, 131, 181, 147, 1863, 3777, 1749, 10135, 11591, 12395, 85163, 0 };
            const std::uint32_t dim8678JoeKuoD6Init[]   =   { 1, 3, 1, 9, 23, 63, 83, 199, 87, 499, 2025, 863, 4665, 3941, 17647, 52463, 108615, 0 };
            const std::uint32_t dim8679JoeKuoD6Init[]   =   { 1, 3, 5, 7, 11, 39, 65, 161, 367, 593, 699, 1807, 7217, 5221, 22093, 44933, 6201, 0 };
            const std::uint32_t dim8680JoeKuoD6Init[]   =   { 1, 1, 7, 13, 9, 41, 35, 77, 353, 291, 1267, 3923, 5397, 15401, 30317, 14945, 8715, 0 };
            const std::uint32_t dim8681JoeKuoD6Init[]   =   { 1, 3, 1, 15, 11, 3, 29, 25, 505, 945, 1425, 2297, 1133, 4675, 8069, 55115, 114177, 0 };
            const std::uint32_t dim8682JoeKuoD6Init[]   =   { 1, 3, 1, 5, 27, 63, 25, 7, 5, 399, 473, 1325, 7391, 5953, 27755, 65407, 89435, 0 };
            const std::uint32_t dim8683JoeKuoD6Init[]   =   { 1, 3, 3, 13, 21, 61, 5, 119, 23, 999, 849, 1225, 3077, 821, 12059, 43223, 45427, 0 };
            const std::uint32_t dim8684JoeKuoD6Init[]   =   { 1, 3, 7, 13, 1, 5, 93, 173, 181, 453, 1449, 3823, 1713, 14737, 8891, 43643, 1983, 0 };
            const std::uint32_t dim8685JoeKuoD6Init[]   =   { 1, 1, 3, 3, 29, 53, 31, 163, 321, 539, 1283, 429, 3449, 15617, 4761, 21187, 120725, 0 };
            const std::uint32_t dim8686JoeKuoD6Init[]   =   { 1, 1, 1, 1, 13, 27, 49, 37, 33, 631, 375, 425, 2465, 8773, 2777, 2115, 35633, 0 };
            const std::uint32_t dim8687JoeKuoD6Init[]   =   { 1, 3, 5, 3, 25, 25, 27, 201, 63, 259, 1571, 1143, 2325, 6773, 11941, 28897, 19719, 0 };
            const std::uint32_t dim8688JoeKuoD6Init[]   =   { 1, 1, 3, 5, 11, 39, 59, 203, 37, 899, 559, 2599, 4397, 12159, 29579, 51251, 83213, 0 };
            const std::uint32_t dim8689JoeKuoD6Init[]   =   { 1, 1, 1, 7, 9, 19, 63, 169, 257, 921, 381, 3605, 3479, 1739, 26599, 20599, 29617, 0 };
            const std::uint32_t dim8690JoeKuoD6Init[]   =   { 1, 1, 1, 9, 7, 29, 123, 35, 419, 963, 855, 1903, 6199, 2727, 29811, 49279, 101673, 0 };
            const std::uint32_t dim8691JoeKuoD6Init[]   =   { 1, 3, 5, 11, 29, 23, 73, 13, 467, 935, 181, 3837, 8117, 11501, 18361, 26803, 99471, 0 };
            const std::uint32_t dim8692JoeKuoD6Init[]   =   { 1, 1, 1, 5, 31, 41, 109, 45, 115, 113, 1893, 727, 2453, 13463, 22339, 13495, 11473, 0 };
            const std::uint32_t dim8693JoeKuoD6Init[]   =   { 1, 1, 5, 9, 5, 31, 109, 145, 511, 243, 57, 2219, 1601, 1821, 12787, 48239, 89645, 0 };
            const std::uint32_t dim8694JoeKuoD6Init[]   =   { 1, 3, 1, 7, 19, 41, 25, 57, 45, 489, 1531, 3959, 2007, 14247, 13445, 1991, 114977, 0 };
            const std::uint32_t dim8695JoeKuoD6Init[]   =   { 1, 3, 7, 15, 7, 17, 107, 27, 249, 207, 183, 2483, 5817, 8927, 10715, 63631, 51947, 0 };
            const std::uint32_t dim8696JoeKuoD6Init[]   =   { 1, 3, 1, 3, 13, 21, 57, 113, 171, 885, 1335, 783, 7575, 4443, 19497, 13827, 130727, 0 };
            const std::uint32_t dim8697JoeKuoD6Init[]   =   { 1, 1, 5, 7, 19, 33, 95, 13, 387, 297, 1597, 767, 7543, 16063, 10367, 51683, 119811, 0 };
            const std::uint32_t dim8698JoeKuoD6Init[]   =   { 1, 3, 7, 9, 27, 57, 111, 209, 305, 139, 179, 25, 2295, 2593, 31361, 23677, 74501, 0 };
            const std::uint32_t dim8699JoeKuoD6Init[]   =   { 1, 3, 7, 3, 21, 63, 97, 189, 3, 693, 209, 2227, 7169, 9, 32575, 61521, 115155, 0 };
            const std::uint32_t dim8700JoeKuoD6Init[]   =   { 1, 1, 1, 11, 13, 21, 125, 249, 193, 895, 139, 1207, 5941, 5821, 6623, 7753, 80939, 0 };
            const std::uint32_t dim8701JoeKuoD6Init[]   =   { 1, 3, 5, 5, 11, 49, 17, 21, 423, 497, 835, 539, 6195, 12783, 1271, 20069, 2657, 0 };
            const std::uint32_t dim8702JoeKuoD6Init[]   =   { 1, 1, 7, 15, 13, 39, 83, 191, 77, 95, 661, 3627, 1853, 1349, 23109, 43583, 104121, 0 };
            const std::uint32_t dim8703JoeKuoD6Init[]   =   { 1, 3, 1, 15, 31, 15, 71, 255, 489, 91, 351, 367, 309, 6275, 18325, 51231, 52159, 0 };
            const std::uint32_t dim8704JoeKuoD6Init[]   =   { 1, 1, 7, 13, 21, 49, 37, 135, 355, 421, 507, 2563, 4955, 4095, 1933, 29517, 119699, 0 };
            const std::uint32_t dim8705JoeKuoD6Init[]   =   { 1, 1, 1, 1, 27, 41, 15, 161, 475, 635, 863, 3773, 6015, 6197, 24261, 26271, 42375, 0 };
            const std::uint32_t dim8706JoeKuoD6Init[]   =   { 1, 1, 7, 13, 25, 7, 23, 185, 129, 597, 1561, 3003, 2879, 15187, 4913, 24589, 12927, 0 };
            const std::uint32_t dim8707JoeKuoD6Init[]   =   { 1, 1, 3, 3, 9, 23, 49, 233, 345, 83, 823, 2627, 5019, 2365, 23755, 9855, 48515, 0 };
            const std::uint32_t dim8708JoeKuoD6Init[]   =   { 1, 3, 1, 1, 11, 7, 117, 213, 27, 923, 375, 2597, 8173, 8935, 16487, 49283, 104569, 0 };
            const std::uint32_t dim8709JoeKuoD6Init[]   =   { 1, 1, 7, 7, 23, 13, 61, 131, 313, 883, 495, 1105, 6207, 1473, 21655, 51883, 403, 0 };
            const std::uint32_t dim8710JoeKuoD6Init[]   =   { 1, 3, 3, 1, 25, 5, 5, 159, 243, 929, 1429, 1151, 5043, 11551, 21231, 38767, 105299, 0 };
            const std::uint32_t dim8711JoeKuoD6Init[]   =   { 1, 3, 7, 7, 15, 37, 49, 219, 67, 147, 873, 2391, 455, 9565, 8977, 64759, 40347, 0 };
            const std::uint32_t dim8712JoeKuoD6Init[]   =   { 1, 1, 1, 13, 21, 13, 13, 243, 303, 333, 187, 3591, 871, 2501, 30853, 5247, 48855, 0 };
            const std::uint32_t dim8713JoeKuoD6Init[]   =   { 1, 1, 1, 5, 1, 5, 127, 249, 23, 79, 789, 3507, 8119, 5025, 26545, 54009, 100633, 0 };
            const std::uint32_t dim8714JoeKuoD6Init[]   =   { 1, 3, 3, 11, 3, 31, 27, 115, 423, 309, 1805, 169, 789, 4081, 28139, 35355, 47991, 0 };
            const std::uint32_t dim8715JoeKuoD6Init[]   =   { 1, 3, 1, 5, 19, 13, 43, 165, 165, 241, 309, 1703, 7631, 5899, 12041, 21235, 97045, 0 };
            const std::uint32_t dim8716JoeKuoD6Init[]   =   { 1, 3, 1, 13, 15, 49, 29, 199, 93, 611, 77, 2681, 191, 10215, 8115, 11895, 108687, 0 };
            const std::uint32_t dim8717JoeKuoD6Init[]   =   { 1, 1, 3, 3, 13, 45, 15, 151, 345, 111, 1829, 1357, 6317, 5239, 26193, 46763, 73101, 0 };
            const std::uint32_t dim8718JoeKuoD6Init[]   =   { 1, 3, 7, 3, 1, 19, 119, 63, 23, 759, 173, 307, 967, 2731, 9353, 14479, 119, 0 };
            const std::uint32_t dim8719JoeKuoD6Init[]   =   { 1, 3, 5, 15, 5, 21, 127, 21, 419, 575, 991, 3465, 7365, 5711, 30657, 43513, 22447, 0 };
            const std::uint32_t dim8720JoeKuoD6Init[]   =   { 1, 3, 7, 1, 19, 5, 49, 7, 45, 963, 1755, 3745, 4061, 4619, 9089, 59953, 100265, 0 };
            const std::uint32_t dim8721JoeKuoD6Init[]   =   { 1, 1, 1, 3, 25, 53, 97, 97, 347, 749, 823, 1499, 8151, 9957, 731, 22317, 121623, 0 };
            const std::uint32_t dim8722JoeKuoD6Init[]   =   { 1, 3, 5, 5, 19, 3, 121, 127, 313, 457, 1737, 4065, 5295, 7957, 16373, 62085, 5711, 0 };
            const std::uint32_t dim8723JoeKuoD6Init[]   =   { 1, 1, 7, 13, 7, 37, 97, 43, 179, 837, 161, 477, 5095, 4985, 111, 58743, 24049, 0 };
            const std::uint32_t dim8724JoeKuoD6Init[]   =   { 1, 3, 1, 13, 27, 13, 91, 241, 339, 235, 111, 369, 3361, 15105, 11097, 23955, 53561, 0 };
            const std::uint32_t dim8725JoeKuoD6Init[]   =   { 1, 3, 5, 3, 9, 17, 103, 133, 309, 683, 71, 3329, 7229, 8763, 4165, 9649, 8529, 0 };
            const std::uint32_t dim8726JoeKuoD6Init[]   =   { 1, 3, 5, 13, 29, 55, 29, 205, 433, 1007, 1173, 731, 5653, 89, 18447, 37911, 65603, 0 };
            const std::uint32_t dim8727JoeKuoD6Init[]   =   { 1, 3, 5, 1, 15, 1, 7, 195, 397, 877, 1433, 3487, 1581, 1539, 3361, 7453, 46451, 0 };
            const std::uint32_t dim8728JoeKuoD6Init[]   =   { 1, 1, 5, 13, 23, 1, 47, 245, 19, 859, 681, 2971, 2531, 11393, 32765, 4595, 45213, 0 };
            const std::uint32_t dim8729JoeKuoD6Init[]   =   { 1, 3, 1, 3, 1, 11, 85, 185, 467, 413, 25, 3677, 881, 1791, 14655, 44811, 50819, 0 };
            const std::uint32_t dim8730JoeKuoD6Init[]   =   { 1, 3, 5, 9, 9, 21, 65, 99, 441, 215, 1453, 2873, 5883, 485, 20883, 1303, 11837, 0 };
            const std::uint32_t dim8731JoeKuoD6Init[]   =   { 1, 3, 3, 5, 9, 37, 87, 211, 247, 535, 1163, 1785, 4219, 12559, 17419, 48201, 21725, 0 };
            const std::uint32_t dim8732JoeKuoD6Init[]   =   { 1, 1, 1, 11, 29, 11, 9, 215, 375, 601, 627, 2641, 6961, 6175, 10995, 49299, 102891, 0 };
            const std::uint32_t dim8733JoeKuoD6Init[]   =   { 1, 3, 1, 3, 7, 7, 23, 139, 89, 1005, 1815, 947, 1507, 10349, 35, 43595, 104697, 0 };
            const std::uint32_t dim8734JoeKuoD6Init[]   =   { 1, 1, 5, 13, 29, 47, 77, 255, 341, 333, 1211, 3473, 1303, 11237, 28371, 43283, 77617, 0 };
            const std::uint32_t dim8735JoeKuoD6Init[]   =   { 1, 3, 3, 13, 27, 17, 73, 95, 227, 241, 1369, 833, 6683, 2193, 309, 64249, 6731, 0 };
            const std::uint32_t dim8736JoeKuoD6Init[]   =   { 1, 3, 3, 3, 15, 29, 45, 209, 401, 725, 1123, 1659, 6099, 15941, 5797, 30563, 119385, 0 };
            const std::uint32_t dim8737JoeKuoD6Init[]   =   { 1, 1, 1, 1, 7, 55, 95, 151, 351, 373, 1131, 2357, 7535, 3899, 19047, 17879, 34623, 0 };
            const std::uint32_t dim8738JoeKuoD6Init[]   =   { 1, 3, 1, 5, 31, 5, 33, 97, 477, 399, 1255, 1073, 1513, 11651, 2951, 31351, 102635, 0 };
            const std::uint32_t dim8739JoeKuoD6Init[]   =   { 1, 1, 3, 13, 17, 63, 51, 209, 57, 87, 977, 3663, 6717, 15441, 10709, 607, 48297, 0 };
            const std::uint32_t dim8740JoeKuoD6Init[]   =   { 1, 1, 5, 1, 9, 29, 1, 105, 343, 19, 977, 3401, 3873, 4259, 23057, 13071, 105771, 0 };
            const std::uint32_t dim8741JoeKuoD6Init[]   =   { 1, 1, 1, 5, 1, 33, 59, 17, 115, 225, 853, 3295, 965, 12547, 26971, 50097, 54999, 0 };
            const std::uint32_t dim8742JoeKuoD6Init[]   =   { 1, 3, 3, 13, 1, 51, 29, 19, 245, 781, 493, 1121, 2937, 4177, 3267, 47463, 101195, 0 };
            const std::uint32_t dim8743JoeKuoD6Init[]   =   { 1, 3, 7, 5, 3, 51, 25, 131, 451, 997, 1809, 1583, 355, 15383, 28159, 39141, 109379, 0 };
            const std::uint32_t dim8744JoeKuoD6Init[]   =   { 1, 1, 5, 7, 3, 19, 75, 103, 401, 115, 1627, 423, 2485, 7281, 6177, 54677, 31499, 0 };
            const std::uint32_t dim8745JoeKuoD6Init[]   =   { 1, 1, 1, 11, 23, 7, 57, 121, 5, 921, 1191, 1779, 1979, 3427, 25617, 19423, 73835, 0 };
            const std::uint32_t dim8746JoeKuoD6Init[]   =   { 1, 3, 3, 11, 17, 51, 15, 163, 265, 665, 1399, 1977, 3097, 7109, 14741, 24291, 79239, 0 };
            const std::uint32_t dim8747JoeKuoD6Init[]   =   { 1, 1, 7, 3, 25, 61, 69, 77, 341, 23, 713, 2879, 8075, 14855, 9691, 58241, 113277, 0 };
            const std::uint32_t dim8748JoeKuoD6Init[]   =   { 1, 3, 7, 9, 27, 43, 95, 11, 239, 445, 951, 3869, 1049, 6493, 9569, 9285, 29183, 0 };
            const std::uint32_t dim8749JoeKuoD6Init[]   =   { 1, 1, 3, 1, 1, 23, 27, 101, 337, 171, 1977, 3181, 2693, 8591, 32309, 24909, 106535, 0 };
            const std::uint32_t dim8750JoeKuoD6Init[]   =   { 1, 1, 1, 7, 23, 59, 79, 115, 49, 351, 871, 1209, 1045, 5985, 28427, 23047, 113571, 0 };
            const std::uint32_t dim8751JoeKuoD6Init[]   =   { 1, 1, 7, 13, 27, 3, 35, 7, 319, 503, 977, 3747, 4859, 16315, 30375, 25999, 24341, 0 };
            const std::uint32_t dim8752JoeKuoD6Init[]   =   { 1, 3, 3, 7, 23, 43, 67, 21, 399, 349, 1541, 2991, 5781, 14501, 5609, 65093, 12789, 0 };
            const std::uint32_t dim8753JoeKuoD6Init[]   =   { 1, 3, 1, 11, 5, 21, 17, 157, 311, 663, 469, 4033, 1557, 7569, 31163, 14079, 127771, 0 };
            const std::uint32_t dim8754JoeKuoD6Init[]   =   { 1, 1, 7, 15, 15, 31, 15, 183, 365, 35, 1433, 2793, 6685, 10565, 30409, 46815, 14173, 0 };
            const std::uint32_t dim8755JoeKuoD6Init[]   =   { 1, 1, 7, 7, 7, 45, 61, 163, 99, 353, 1535, 3185, 4023, 7999, 26173, 12675, 98073, 0 };
            const std::uint32_t dim8756JoeKuoD6Init[]   =   { 1, 1, 5, 13, 1, 11, 107, 41, 171, 773, 1513, 883, 2117, 14449, 32323, 58271, 97173, 0 };
            const std::uint32_t dim8757JoeKuoD6Init[]   =   { 1, 1, 3, 13, 27, 15, 123, 247, 281, 851, 233, 1173, 6863, 14805, 12401, 30729, 104127, 0 };
            const std::uint32_t dim8758JoeKuoD6Init[]   =   { 1, 1, 7, 11, 25, 9, 97, 215, 217, 51, 1865, 3897, 725, 4779, 21661, 11853, 72225, 0 };
            const std::uint32_t dim8759JoeKuoD6Init[]   =   { 1, 1, 5, 3, 5, 31, 125, 81, 367, 705, 325, 519, 3879, 5607, 3247, 7149, 33177, 0 };
            const std::uint32_t dim8760JoeKuoD6Init[]   =   { 1, 3, 3, 7, 17, 17, 19, 113, 331, 277, 317, 1893, 1287, 8965, 27523, 61355, 45331, 0 };
            const std::uint32_t dim8761JoeKuoD6Init[]   =   { 1, 3, 7, 9, 27, 15, 87, 21, 343, 479, 11, 2945, 1235, 1591, 28195, 40559, 42773, 0 };
            const std::uint32_t dim8762JoeKuoD6Init[]   =   { 1, 3, 3, 13, 1, 45, 115, 41, 263, 569, 71, 4051, 739, 1031, 19213, 23961, 110767, 0 };
            const std::uint32_t dim8763JoeKuoD6Init[]   =   { 1, 3, 7, 1, 9, 41, 21, 131, 3, 617, 191, 4051, 2445, 13451, 11889, 25075, 82631, 0 };
            const std::uint32_t dim8764JoeKuoD6Init[]   =   { 1, 3, 3, 15, 7, 55, 65, 67, 443, 1023, 1445, 1467, 3907, 11449, 2247, 65085, 102161, 0 };
            const std::uint32_t dim8765JoeKuoD6Init[]   =   { 1, 3, 5, 15, 19, 27, 97, 181, 51, 591, 99, 1443, 4927, 9809, 29693, 44293, 29369, 0 };
            const std::uint32_t dim8766JoeKuoD6Init[]   =   { 1, 1, 7, 7, 17, 59, 69, 163, 37, 171, 107, 2581, 3567, 9455, 19707, 6329, 27755, 0 };
            const std::uint32_t dim8767JoeKuoD6Init[]   =   { 1, 1, 1, 11, 15, 17, 83, 223, 183, 861, 1047, 3739, 3509, 5571, 28259, 42781, 130657, 0 };
            const std::uint32_t dim8768JoeKuoD6Init[]   =   { 1, 3, 3, 7, 15, 11, 33, 115, 297, 841, 1629, 1559, 2261, 11763, 22255, 63819, 55831, 0 };
            const std::uint32_t dim8769JoeKuoD6Init[]   =   { 1, 3, 3, 5, 19, 49, 17, 251, 507, 251, 805, 1041, 3947, 2219, 19977, 65449, 25031, 0 };
            const std::uint32_t dim8770JoeKuoD6Init[]   =   { 1, 1, 1, 11, 3, 7, 81, 17, 219, 729, 949, 3257, 6495, 4701, 2181, 7009, 106465, 0 };
            const std::uint32_t dim8771JoeKuoD6Init[]   =   { 1, 3, 7, 5, 27, 35, 15, 83, 43, 1013, 1427, 1943, 7555, 6613, 26879, 42685, 22071, 0 };
            const std::uint32_t dim8772JoeKuoD6Init[]   =   { 1, 1, 3, 13, 23, 55, 15, 87, 15, 579, 717, 777, 149, 11431, 26197, 17711, 7337, 0 };
            const std::uint32_t dim8773JoeKuoD6Init[]   =   { 1, 1, 5, 1, 31, 45, 113, 253, 211, 915, 1855, 4043, 2159, 1803, 5061, 40473, 3657, 0 };
            const std::uint32_t dim8774JoeKuoD6Init[]   =   { 1, 1, 3, 7, 25, 15, 37, 73, 467, 969, 1123, 4053, 4837, 10091, 25461, 40803, 91157, 0 };
            const std::uint32_t dim8775JoeKuoD6Init[]   =   { 1, 1, 5, 1, 7, 31, 77, 207, 21, 623, 577, 1195, 5839, 13013, 11189, 61691, 33327, 0 };
            const std::uint32_t dim8776JoeKuoD6Init[]   =   { 1, 3, 7, 7, 13, 3, 9, 55, 47, 779, 599, 3747, 1533, 14705, 23185, 4011, 36003, 0 };
            const std::uint32_t dim8777JoeKuoD6Init[]   =   { 1, 1, 5, 5, 31, 17, 99, 253, 103, 957, 241, 1893, 7435, 14907, 9089, 23205, 70639, 0 };
            const std::uint32_t dim8778JoeKuoD6Init[]   =   { 1, 3, 7, 15, 7, 55, 53, 101, 227, 541, 2017, 275, 577, 15621, 1799, 50373, 43197, 0 };
            const std::uint32_t dim8779JoeKuoD6Init[]   =   { 1, 3, 1, 15, 29, 23, 69, 193, 429, 359, 1045, 4091, 6551, 1673, 29113, 43247, 80993, 0 };
            const std::uint32_t dim8780JoeKuoD6Init[]   =   { 1, 3, 7, 11, 5, 37, 13, 27, 277, 65, 565, 2631, 6919, 5593, 8481, 14703, 9719, 0 };
            const std::uint32_t dim8781JoeKuoD6Init[]   =   { 1, 3, 1, 15, 5, 7, 83, 51, 77, 307, 1299, 1373, 5281, 15359, 15569, 50093, 59661, 0 };
            const std::uint32_t dim8782JoeKuoD6Init[]   =   { 1, 3, 5, 11, 13, 31, 99, 123, 263, 319, 2033, 4055, 2427, 103, 2009, 27517, 112467, 0 };
            const std::uint32_t dim8783JoeKuoD6Init[]   =   { 1, 1, 7, 3, 13, 1, 51, 131, 17, 861, 459, 3925, 5511, 5255, 28553, 36437, 54591, 0 };
            const std::uint32_t dim8784JoeKuoD6Init[]   =   { 1, 3, 7, 5, 9, 57, 49, 119, 291, 727, 1611, 4035, 4517, 10979, 28445, 26905, 57517, 0 };
            const std::uint32_t dim8785JoeKuoD6Init[]   =   { 1, 1, 5, 9, 9, 55, 43, 209, 411, 137, 1619, 3965, 5253, 8217, 7569, 42043, 104163, 0 };
            const std::uint32_t dim8786JoeKuoD6Init[]   =   { 1, 3, 3, 7, 21, 3, 107, 255, 353, 735, 71, 1789, 3351, 755, 22805, 53537, 126859, 0 };
            const std::uint32_t dim8787JoeKuoD6Init[]   =   { 1, 1, 7, 5, 15, 55, 13, 167, 165, 289, 1231, 2547, 8135, 5475, 2361, 49019, 110579, 0 };
            const std::uint32_t dim8788JoeKuoD6Init[]   =   { 1, 3, 1, 11, 17, 21, 59, 37, 177, 517, 499, 4035, 749, 14297, 22415, 54975, 29769, 0 };
            const std::uint32_t dim8789JoeKuoD6Init[]   =   { 1, 3, 7, 3, 3, 59, 55, 17, 483, 625, 875, 1465, 7583, 2969, 2741, 36965, 80367, 0 };
            const std::uint32_t dim8790JoeKuoD6Init[]   =   { 1, 1, 3, 13, 31, 5, 11, 149, 7, 297, 1485, 735, 4095, 10089, 5757, 64997, 56629, 0 };
            const std::uint32_t dim8791JoeKuoD6Init[]   =   { 1, 3, 1, 13, 19, 43, 77, 209, 309, 739, 1765, 3297, 8167, 6523, 27987, 25235, 80555, 0 };
            const std::uint32_t dim8792JoeKuoD6Init[]   =   { 1, 1, 3, 9, 31, 57, 125, 75, 3, 633, 85, 3339, 1691, 9721, 17465, 36801, 106147, 0 };
            const std::uint32_t dim8793JoeKuoD6Init[]   =   { 1, 3, 5, 15, 27, 7, 111, 7, 475, 523, 1825, 1367, 1549, 15533, 13827, 14471, 100271, 0 };
            const std::uint32_t dim8794JoeKuoD6Init[]   =   { 1, 1, 5, 3, 5, 61, 1, 221, 163, 183, 1701, 3549, 349, 10057, 26169, 20725, 55305, 0 };
            const std::uint32_t dim8795JoeKuoD6Init[]   =   { 1, 1, 3, 1, 15, 41, 13, 71, 269, 909, 1253, 2553, 83, 10055, 1057, 39841, 20437, 0 };
            const std::uint32_t dim8796JoeKuoD6Init[]   =   { 1, 3, 3, 5, 29, 39, 113, 23, 137, 601, 361, 1779, 279, 15803, 8993, 2633, 114847, 0 };
            const std::uint32_t dim8797JoeKuoD6Init[]   =   { 1, 1, 3, 7, 29, 45, 35, 27, 71, 253, 231, 3449, 1955, 9109, 9043, 50593, 15023, 0 };
            const std::uint32_t dim8798JoeKuoD6Init[]   =   { 1, 3, 1, 11, 17, 45, 85, 255, 341, 957, 769, 3009, 3997, 6435, 1161, 34219, 97077, 0 };
            const std::uint32_t dim8799JoeKuoD6Init[]   =   { 1, 1, 5, 1, 1, 19, 9, 51, 477, 129, 1411, 3223, 5069, 3237, 15947, 27215, 70401, 0 };
            const std::uint32_t dim8800JoeKuoD6Init[]   =   { 1, 1, 3, 1, 1, 1, 73, 31, 301, 227, 119, 607, 3379, 3907, 1263, 2651, 43769, 0 };
            const std::uint32_t dim8801JoeKuoD6Init[]   =   { 1, 1, 1, 15, 21, 59, 109, 155, 473, 361, 1871, 3085, 513, 12607, 12747, 41067, 44977, 0 };
            const std::uint32_t dim8802JoeKuoD6Init[]   =   { 1, 1, 7, 3, 27, 21, 89, 71, 437, 671, 1469, 2191, 4225, 6343, 1131, 29141, 25221, 0 };
            const std::uint32_t dim8803JoeKuoD6Init[]   =   { 1, 1, 7, 9, 7, 45, 95, 197, 391, 11, 1913, 3107, 5247, 959, 30395, 32809, 20893, 0 };
            const std::uint32_t dim8804JoeKuoD6Init[]   =   { 1, 3, 7, 15, 13, 49, 77, 245, 463, 769, 1807, 1311, 2715, 14819, 27595, 57521, 105221, 0 };
            const std::uint32_t dim8805JoeKuoD6Init[]   =   { 1, 1, 1, 5, 23, 45, 119, 77, 325, 405, 1631, 461, 6357, 7037, 31699, 46295, 118577, 0 };
            const std::uint32_t dim8806JoeKuoD6Init[]   =   { 1, 3, 5, 1, 21, 3, 31, 13, 7, 571, 633, 425, 6547, 3423, 19355, 49481, 76289, 0 };
            const std::uint32_t dim8807JoeKuoD6Init[]   =   { 1, 1, 3, 9, 7, 51, 113, 173, 169, 97, 1821, 979, 2553, 11505, 20047, 39277, 122905, 0 };
            const std::uint32_t dim8808JoeKuoD6Init[]   =   { 1, 1, 5, 13, 17, 9, 111, 205, 261, 671, 657, 507, 3903, 10767, 4387, 3045, 102617, 0 };
            const std::uint32_t dim8809JoeKuoD6Init[]   =   { 1, 1, 3, 3, 5, 11, 19, 61, 401, 605, 455, 2457, 4471, 7255, 18435, 49673, 97289, 0 };
            const std::uint32_t dim8810JoeKuoD6Init[]   =   { 1, 3, 1, 1, 31, 25, 77, 35, 65, 127, 929, 2325, 2315, 13819, 5509, 12515, 36991, 0 };
            const std::uint32_t dim8811JoeKuoD6Init[]   =   { 1, 1, 7, 5, 21, 49, 33, 119, 181, 645, 1425, 2411, 245, 13755, 18775, 50061, 47119, 0 };
            const std::uint32_t dim8812JoeKuoD6Init[]   =   { 1, 3, 7, 5, 27, 43, 81, 191, 233, 435, 829, 3881, 713, 11153, 4637, 37721, 115567, 0 };
            const std::uint32_t dim8813JoeKuoD6Init[]   =   { 1, 3, 7, 1, 27, 59, 51, 165, 59, 931, 1921, 3059, 6843, 813, 22063, 29445, 114765, 0 };
            const std::uint32_t dim8814JoeKuoD6Init[]   =   { 1, 1, 5, 11, 31, 53, 89, 69, 29, 893, 1241, 7, 1707, 16167, 8371, 14021, 103281, 0 };
            const std::uint32_t dim8815JoeKuoD6Init[]   =   { 1, 3, 1, 1, 23, 21, 3, 35, 73, 769, 1417, 4051, 3223, 813, 1141, 18823, 31951, 0 };
            const std::uint32_t dim8816JoeKuoD6Init[]   =   { 1, 3, 7, 11, 9, 17, 89, 85, 407, 137, 1865, 2881, 1495, 3757, 3711, 36651, 1797, 0 };
            const std::uint32_t dim8817JoeKuoD6Init[]   =   { 1, 3, 5, 1, 25, 29, 29, 217, 15, 173, 479, 2363, 2341, 6193, 16403, 64097, 1173, 0 };
            const std::uint32_t dim8818JoeKuoD6Init[]   =   { 1, 3, 3, 3, 11, 29, 113, 167, 333, 573, 1467, 2223, 5693, 1063, 20299, 40993, 69055, 0 };
            const std::uint32_t dim8819JoeKuoD6Init[]   =   { 1, 1, 3, 7, 3, 51, 45, 139, 79, 393, 1251, 1087, 1423, 1827, 23445, 41635, 78511, 0 };
            const std::uint32_t dim8820JoeKuoD6Init[]   =   { 1, 3, 3, 13, 29, 45, 85, 229, 33, 373, 113, 1205, 997, 11777, 7663, 18513, 5797, 0 };
            const std::uint32_t dim8821JoeKuoD6Init[]   =   { 1, 1, 5, 5, 15, 5, 127, 85, 49, 345, 901, 3215, 2347, 2329, 19597, 39555, 25031, 0 };
            const std::uint32_t dim8822JoeKuoD6Init[]   =   { 1, 1, 7, 11, 9, 25, 71, 183, 341, 1011, 439, 3649, 2859, 10183, 7635, 45297, 38581, 0 };
            const std::uint32_t dim8823JoeKuoD6Init[]   =   { 1, 1, 1, 11, 23, 13, 1, 69, 461, 77, 1641, 2851, 1889, 2413, 1131, 39009, 33773, 0 };
            const std::uint32_t dim8824JoeKuoD6Init[]   =   { 1, 3, 7, 7, 25, 19, 67, 233, 141, 207, 1501, 453, 4773, 7411, 22839, 25365, 53189, 0 };
            const std::uint32_t dim8825JoeKuoD6Init[]   =   { 1, 1, 7, 3, 3, 17, 13, 167, 73, 1005, 887, 2595, 4351, 3249, 5653, 36025, 33733, 0 };
            const std::uint32_t dim8826JoeKuoD6Init[]   =   { 1, 1, 7, 15, 11, 1, 105, 215, 329, 601, 1477, 723, 4597, 3525, 26235, 63957, 26677, 0 };
            const std::uint32_t dim8827JoeKuoD6Init[]   =   { 1, 1, 1, 11, 27, 15, 111, 133, 327, 567, 845, 2135, 7905, 7297, 29255, 14947, 104885, 0 };
            const std::uint32_t dim8828JoeKuoD6Init[]   =   { 1, 1, 7, 9, 21, 11, 67, 179, 459, 423, 295, 3445, 1681, 12907, 29281, 7445, 35539, 0 };
            const std::uint32_t dim8829JoeKuoD6Init[]   =   { 1, 1, 3, 11, 23, 61, 111, 123, 81, 439, 299, 3557, 2821, 705, 15393, 37175, 11533, 0 };
            const std::uint32_t dim8830JoeKuoD6Init[]   =   { 1, 1, 3, 1, 13, 15, 113, 227, 285, 313, 687, 2085, 6363, 8003, 32661, 36461, 68759, 0 };
            const std::uint32_t dim8831JoeKuoD6Init[]   =   { 1, 3, 3, 1, 27, 7, 101, 177, 363, 461, 1519, 2339, 473, 7469, 4335, 30951, 130987, 0 };
            const std::uint32_t dim8832JoeKuoD6Init[]   =   { 1, 1, 1, 3, 31, 39, 59, 159, 207, 93, 581, 1973, 945, 11343, 15901, 22001, 3515, 0 };
            const std::uint32_t dim8833JoeKuoD6Init[]   =   { 1, 3, 7, 5, 11, 53, 125, 57, 389, 985, 1055, 3803, 3879, 5537, 28221, 36805, 16025, 0 };
            const std::uint32_t dim8834JoeKuoD6Init[]   =   { 1, 1, 1, 9, 1, 63, 81, 57, 59, 813, 865, 3491, 3771, 6121, 6847, 14765, 68567, 0 };
            const std::uint32_t dim8835JoeKuoD6Init[]   =   { 1, 1, 7, 7, 13, 17, 23, 211, 435, 167, 933, 357, 3567, 3019, 28439, 17701, 119937, 0 };
            const std::uint32_t dim8836JoeKuoD6Init[]   =   { 1, 1, 1, 9, 7, 53, 103, 155, 211, 719, 413, 3673, 2795, 15687, 1737, 50855, 129133, 0 };
            const std::uint32_t dim8837JoeKuoD6Init[]   =   { 1, 1, 3, 13, 11, 23, 53, 121, 497, 383, 1655, 937, 5563, 2549, 23183, 46149, 78875, 0 };
            const std::uint32_t dim8838JoeKuoD6Init[]   =   { 1, 3, 5, 11, 25, 1, 45, 139, 437, 729, 2009, 3245, 4091, 551, 25993, 31655, 33641, 0 };
            const std::uint32_t dim8839JoeKuoD6Init[]   =   { 1, 3, 1, 13, 7, 23, 87, 111, 471, 501, 1767, 1051, 7037, 3199, 19609, 43227, 53667, 0 };
            const std::uint32_t dim8840JoeKuoD6Init[]   =   { 1, 3, 7, 1, 25, 1, 49, 189, 55, 375, 601, 2065, 2991, 7697, 25739, 14951, 43705, 0 };
            const std::uint32_t dim8841JoeKuoD6Init[]   =   { 1, 1, 7, 5, 29, 21, 51, 111, 81, 809, 1963, 2143, 5529, 15701, 4719, 11857, 88207, 0 };
            const std::uint32_t dim8842JoeKuoD6Init[]   =   { 1, 1, 5, 11, 27, 27, 7, 145, 281, 939, 537, 1255, 1475, 11383, 15081, 9105, 102775, 0 };
            const std::uint32_t dim8843JoeKuoD6Init[]   =   { 1, 1, 5, 7, 9, 45, 67, 23, 65, 139, 1871, 3975, 6357, 6515, 25423, 23915, 76289, 0 };
            const std::uint32_t dim8844JoeKuoD6Init[]   =   { 1, 1, 5, 11, 31, 31, 89, 65, 451, 341, 819, 2439, 6753, 15113, 9085, 32687, 5055, 0 };
            const std::uint32_t dim8845JoeKuoD6Init[]   =   { 1, 1, 5, 1, 15, 29, 123, 83, 495, 185, 303, 315, 6015, 5257, 2467, 4903, 78269, 0 };
            const std::uint32_t dim8846JoeKuoD6Init[]   =   { 1, 1, 3, 5, 31, 51, 49, 199, 501, 407, 733, 1181, 8023, 7321, 14765, 17535, 19893, 0 };
            const std::uint32_t dim8847JoeKuoD6Init[]   =   { 1, 1, 5, 5, 19, 15, 103, 183, 13, 969, 1537, 3053, 3173, 12983, 21761, 33733, 67799, 0 };
            const std::uint32_t dim8848JoeKuoD6Init[]   =   { 1, 3, 1, 1, 27, 55, 37, 149, 379, 11, 1655, 2317, 3135, 6459, 25941, 12679, 60245, 0 };
            const std::uint32_t dim8849JoeKuoD6Init[]   =   { 1, 1, 3, 9, 9, 13, 33, 243, 337, 741, 1685, 1147, 5465, 4865, 559, 23993, 47273, 0 };
            const std::uint32_t dim8850JoeKuoD6Init[]   =   { 1, 3, 5, 13, 21, 11, 39, 169, 135, 209, 1909, 3655, 3117, 1075, 8165, 54633, 28189, 0 };
            const std::uint32_t dim8851JoeKuoD6Init[]   =   { 1, 3, 1, 15, 9, 23, 11, 123, 63, 133, 947, 907, 3853, 10291, 22905, 4561, 92497, 0 };
            const std::uint32_t dim8852JoeKuoD6Init[]   =   { 1, 1, 3, 13, 17, 9, 5, 209, 429, 3, 2035, 1497, 6765, 5991, 24991, 8155, 103417, 0 };
            const std::uint32_t dim8853JoeKuoD6Init[]   =   { 1, 1, 5, 13, 27, 47, 79, 11, 41, 791, 1939, 3099, 4069, 4665, 20801, 18659, 72163, 0 };
            const std::uint32_t dim8854JoeKuoD6Init[]   =   { 1, 3, 1, 13, 25, 37, 79, 131, 233, 647, 291, 1419, 5157, 4261, 27715, 611, 83157, 0 };
            const std::uint32_t dim8855JoeKuoD6Init[]   =   { 1, 1, 5, 1, 17, 61, 45, 163, 137, 937, 91, 1695, 1553, 543, 28615, 6855, 75201, 0 };
            const std::uint32_t dim8856JoeKuoD6Init[]   =   { 1, 1, 3, 13, 7, 63, 109, 13, 351, 159, 1111, 2791, 4701, 5805, 9707, 18361, 98091, 0 };
            const std::uint32_t dim8857JoeKuoD6Init[]   =   { 1, 1, 3, 11, 11, 21, 55, 247, 111, 801, 93, 3091, 1043, 9761, 23679, 5555, 195, 0 };
            const std::uint32_t dim8858JoeKuoD6Init[]   =   { 1, 1, 1, 1, 13, 43, 123, 113, 265, 561, 659, 3755, 6605, 10949, 30511, 29495, 9075, 0 };
            const std::uint32_t dim8859JoeKuoD6Init[]   =   { 1, 3, 1, 7, 23, 63, 19, 73, 233, 1017, 851, 1971, 3999, 7407, 25309, 63991, 92867, 0 };
            const std::uint32_t dim8860JoeKuoD6Init[]   =   { 1, 3, 3, 3, 19, 63, 127, 107, 465, 463, 1507, 1323, 4729, 14717, 9129, 24859, 117565, 0 };
            const std::uint32_t dim8861JoeKuoD6Init[]   =   { 1, 1, 7, 1, 19, 11, 13, 85, 339, 939, 895, 887, 765, 15501, 8783, 65087, 77899, 0 };
            const std::uint32_t dim8862JoeKuoD6Init[]   =   { 1, 3, 7, 3, 7, 15, 43, 153, 365, 223, 1947, 2295, 787, 5549, 20089, 29203, 4807, 0 };
            const std::uint32_t dim8863JoeKuoD6Init[]   =   { 1, 3, 7, 3, 31, 27, 51, 217, 483, 623, 633, 2123, 1211, 9173, 17949, 54251, 89161, 0 };
            const std::uint32_t dim8864JoeKuoD6Init[]   =   { 1, 3, 3, 11, 3, 11, 111, 73, 283, 23, 1925, 253, 5141, 12545, 24913, 16847, 13067, 0 };
            const std::uint32_t dim8865JoeKuoD6Init[]   =   { 1, 3, 5, 5, 31, 39, 35, 235, 135, 85, 191, 999, 6633, 12527, 21401, 61339, 81239, 0 };
            const std::uint32_t dim8866JoeKuoD6Init[]   =   { 1, 1, 3, 15, 9, 13, 39, 125, 137, 639, 555, 813, 2821, 1199, 32075, 15079, 104609, 0 };
            const std::uint32_t dim8867JoeKuoD6Init[]   =   { 1, 3, 7, 7, 15, 43, 99, 51, 245, 25, 147, 89, 6841, 5523, 28493, 13967, 113109, 0 };
            const std::uint32_t dim8868JoeKuoD6Init[]   =   { 1, 1, 3, 13, 7, 5, 27, 121, 269, 231, 1011, 1365, 5055, 11619, 27393, 48033, 65725, 0 };
            const std::uint32_t dim8869JoeKuoD6Init[]   =   { 1, 1, 7, 5, 9, 23, 41, 71, 327, 339, 1681, 3303, 4143, 421, 15213, 48405, 98067, 0 };
            const std::uint32_t dim8870JoeKuoD6Init[]   =   { 1, 3, 7, 15, 15, 33, 73, 33, 351, 131, 1051, 3909, 7535, 7659, 9443, 35015, 329, 0 };
            const std::uint32_t dim8871JoeKuoD6Init[]   =   { 1, 1, 3, 9, 19, 55, 97, 223, 265, 877, 235, 867, 4961, 3137, 19885, 10955, 7655, 0 };
            const std::uint32_t dim8872JoeKuoD6Init[]   =   { 1, 3, 5, 13, 1, 11, 75, 215, 271, 793, 1691, 1437, 1317, 10977, 1311, 64865, 92361, 0 };
            const std::uint32_t dim8873JoeKuoD6Init[]   =   { 1, 1, 1, 5, 23, 23, 35, 53, 187, 345, 115, 929, 3919, 4523, 31709, 16771, 33399, 0 };
            const std::uint32_t dim8874JoeKuoD6Init[]   =   { 1, 3, 5, 11, 17, 7, 75, 57, 351, 359, 1737, 2665, 4259, 13905, 6999, 45359, 117891, 0 };
            const std::uint32_t dim8875JoeKuoD6Init[]   =   { 1, 1, 5, 3, 23, 29, 49, 209, 417, 843, 531, 1649, 7829, 6271, 3759, 39727, 47415, 0 };
            const std::uint32_t dim8876JoeKuoD6Init[]   =   { 1, 1, 7, 1, 21, 45, 101, 105, 385, 797, 985, 1447, 3757, 3287, 583, 29283, 96821, 0 };
            const std::uint32_t dim8877JoeKuoD6Init[]   =   { 1, 1, 7, 9, 1, 29, 15, 207, 289, 465, 815, 2289, 449, 9403, 19197, 13797, 102651, 0 };
            const std::uint32_t dim8878JoeKuoD6Init[]   =   { 1, 3, 7, 15, 5, 45, 81, 187, 21, 433, 679, 2759, 3375, 6935, 22595, 50149, 13557, 0 };
            const std::uint32_t dim8879JoeKuoD6Init[]   =   { 1, 3, 3, 5, 11, 55, 69, 219, 95, 21, 645, 1955, 7527, 6037, 29427, 36297, 62013, 0 };
            const std::uint32_t dim8880JoeKuoD6Init[]   =   { 1, 1, 7, 15, 13, 35, 25, 67, 383, 13, 539, 2399, 4611, 8065, 3815, 27771, 50411, 0 };
            const std::uint32_t dim8881JoeKuoD6Init[]   =   { 1, 3, 1, 3, 27, 47, 65, 33, 393, 895, 1663, 1289, 1057, 11887, 1259, 53611, 36811, 0 };
            const std::uint32_t dim8882JoeKuoD6Init[]   =   { 1, 3, 5, 3, 5, 1, 27, 65, 379, 15, 1643, 1461, 3009, 8177, 15589, 5889, 1103, 0 };
            const std::uint32_t dim8883JoeKuoD6Init[]   =   { 1, 1, 5, 15, 27, 53, 43, 173, 377, 665, 581, 1061, 1363, 15015, 26709, 29507, 28075, 0 };
            const std::uint32_t dim8884JoeKuoD6Init[]   =   { 1, 1, 7, 3, 9, 11, 45, 71, 23, 995, 1277, 855, 1001, 12927, 19753, 46639, 16949, 0 };
            const std::uint32_t dim8885JoeKuoD6Init[]   =   { 1, 1, 7, 5, 15, 33, 27, 27, 437, 415, 1785, 2091, 279, 8041, 2209, 15821, 122363, 0 };
            const std::uint32_t dim8886JoeKuoD6Init[]   =   { 1, 1, 7, 1, 21, 1, 47, 215, 463, 959, 849, 1703, 5175, 10043, 16991, 11023, 52201, 0 };
            const std::uint32_t dim8887JoeKuoD6Init[]   =   { 1, 1, 1, 11, 21, 7, 121, 31, 95, 631, 1717, 3017, 2083, 2047, 12051, 63117, 25949, 0 };
            const std::uint32_t dim8888JoeKuoD6Init[]   =   { 1, 1, 5, 5, 9, 5, 105, 121, 205, 643, 1721, 2601, 2991, 2381, 4873, 12049, 20043, 0 };
            const std::uint32_t dim8889JoeKuoD6Init[]   =   { 1, 3, 5, 11, 7, 11, 97, 187, 253, 571, 101, 3077, 1479, 9513, 15451, 37105, 34445, 0 };
            const std::uint32_t dim8890JoeKuoD6Init[]   =   { 1, 1, 7, 11, 19, 19, 39, 115, 221, 13, 217, 369, 6855, 14529, 143, 13461, 62927, 0 };
            const std::uint32_t dim8891JoeKuoD6Init[]   =   { 1, 3, 3, 7, 29, 27, 9, 171, 419, 571, 837, 3829, 1871, 12691, 30693, 4195, 38905, 0 };
            const std::uint32_t dim8892JoeKuoD6Init[]   =   { 1, 1, 1, 11, 5, 55, 17, 41, 241, 419, 337, 897, 4663, 14469, 18701, 18009, 44605, 0 };
            const std::uint32_t dim8893JoeKuoD6Init[]   =   { 1, 1, 7, 7, 1, 33, 63, 197, 257, 655, 1287, 2571, 57, 13275, 29669, 8501, 61389, 0 };
            const std::uint32_t dim8894JoeKuoD6Init[]   =   { 1, 3, 5, 3, 29, 39, 101, 215, 101, 271, 1373, 2171, 841, 9865, 28951, 20369, 42413, 0 };
            const std::uint32_t dim8895JoeKuoD6Init[]   =   { 1, 3, 5, 1, 31, 23, 119, 137, 263, 633, 1239, 281, 4965, 14913, 30229, 14147, 37183, 0 };
            const std::uint32_t dim8896JoeKuoD6Init[]   =   { 1, 3, 1, 3, 11, 55, 33, 45, 69, 913, 269, 1021, 4005, 15191, 11187, 45917, 76905, 0 };
            const std::uint32_t dim8897JoeKuoD6Init[]   =   { 1, 1, 1, 13, 27, 11, 75, 139, 243, 221, 1289, 2195, 7041, 10053, 5731, 35245, 41317, 0 };
            const std::uint32_t dim8898JoeKuoD6Init[]   =   { 1, 1, 7, 9, 25, 11, 81, 243, 233, 137, 831, 2825, 6007, 7305, 31733, 64343, 7047, 0 };
            const std::uint32_t dim8899JoeKuoD6Init[]   =   { 1, 3, 5, 9, 17, 61, 25, 245, 285, 969, 1397, 1331, 5393, 3653, 15533, 9121, 111115, 0 };
            const std::uint32_t dim8900JoeKuoD6Init[]   =   { 1, 1, 5, 9, 1, 9, 61, 205, 285, 849, 1071, 1013, 2655, 10121, 15165, 25189, 56207, 0 };
            const std::uint32_t dim8901JoeKuoD6Init[]   =   { 1, 3, 5, 7, 19, 45, 121, 19, 237, 711, 1523, 3251, 693, 13567, 31993, 11239, 64127, 0 };
            const std::uint32_t dim8902JoeKuoD6Init[]   =   { 1, 1, 1, 11, 23, 25, 33, 211, 321, 1021, 1855, 291, 2911, 11841, 21929, 64147, 63201, 0 };
            const std::uint32_t dim8903JoeKuoD6Init[]   =   { 1, 1, 7, 3, 27, 21, 119, 219, 431, 819, 83, 2487, 7533, 10697, 3129, 53301, 104999, 0 };
            const std::uint32_t dim8904JoeKuoD6Init[]   =   { 1, 3, 5, 15, 9, 25, 89, 65, 293, 411, 989, 3103, 5563, 15703, 8757, 32595, 43409, 0 };
            const std::uint32_t dim8905JoeKuoD6Init[]   =   { 1, 3, 3, 1, 31, 31, 45, 173, 231, 171, 1185, 1499, 1713, 9945, 11575, 37113, 103989, 0 };
            const std::uint32_t dim8906JoeKuoD6Init[]   =   { 1, 1, 5, 13, 27, 3, 93, 253, 23, 71, 1963, 2571, 6259, 15757, 9709, 42835, 42047, 0 };
            const std::uint32_t dim8907JoeKuoD6Init[]   =   { 1, 1, 7, 11, 5, 11, 123, 117, 39, 559, 111, 527, 6253, 781, 9177, 47189, 94031, 0 };
            const std::uint32_t dim8908JoeKuoD6Init[]   =   { 1, 1, 5, 15, 5, 49, 93, 185, 167, 787, 1553, 3291, 3723, 1651, 23225, 5643, 42967, 0 };
            const std::uint32_t dim8909JoeKuoD6Init[]   =   { 1, 3, 1, 13, 15, 35, 19, 193, 505, 127, 661, 1943, 1249, 5103, 8233, 64319, 76955, 0 };
            const std::uint32_t dim8910JoeKuoD6Init[]   =   { 1, 3, 7, 7, 17, 13, 97, 185, 415, 331, 283, 3341, 2903, 2927, 7729, 4095, 103083, 0 };
            const std::uint32_t dim8911JoeKuoD6Init[]   =   { 1, 1, 3, 15, 15, 25, 65, 45, 413, 521, 747, 2605, 5845, 12909, 7651, 45937, 99043, 0 };
            const std::uint32_t dim8912JoeKuoD6Init[]   =   { 1, 1, 5, 9, 9, 21, 3, 75, 335, 745, 1493, 1721, 1977, 11105, 22621, 49281, 107113, 0 };
            const std::uint32_t dim8913JoeKuoD6Init[]   =   { 1, 3, 1, 11, 25, 11, 99, 53, 239, 831, 655, 615, 7565, 14039, 29115, 26165, 127159, 0 };
            const std::uint32_t dim8914JoeKuoD6Init[]   =   { 1, 1, 7, 5, 31, 35, 75, 157, 441, 815, 119, 565, 2703, 14059, 7867, 42487, 93647, 0 };
            const std::uint32_t dim8915JoeKuoD6Init[]   =   { 1, 3, 7, 3, 3, 59, 101, 223, 257, 989, 363, 1059, 5157, 11129, 1481, 19287, 117623, 0 };
            const std::uint32_t dim8916JoeKuoD6Init[]   =   { 1, 1, 1, 1, 29, 27, 1, 129, 253, 673, 103, 1881, 7053, 1261, 32003, 23345, 102503, 0 };
            const std::uint32_t dim8917JoeKuoD6Init[]   =   { 1, 3, 1, 9, 11, 37, 3, 99, 303, 519, 1175, 3021, 2275, 9919, 25011, 45865, 71351, 0 };
            const std::uint32_t dim8918JoeKuoD6Init[]   =   { 1, 1, 7, 15, 27, 9, 107, 61, 385, 21, 861, 2119, 4643, 8379, 25455, 22425, 113387, 0 };
            const std::uint32_t dim8919JoeKuoD6Init[]   =   { 1, 1, 1, 7, 27, 15, 73, 211, 497, 527, 873, 329, 2213, 415, 13987, 56581, 27829, 0 };
            const std::uint32_t dim8920JoeKuoD6Init[]   =   { 1, 3, 5, 1, 31, 43, 107, 149, 209, 211, 2029, 2793, 2213, 12389, 27177, 51375, 51983, 0 };
            const std::uint32_t dim8921JoeKuoD6Init[]   =   { 1, 3, 3, 7, 25, 57, 67, 101, 127, 43, 1775, 801, 3343, 12203, 8667, 58387, 10735, 0 };
            const std::uint32_t dim8922JoeKuoD6Init[]   =   { 1, 1, 7, 5, 13, 47, 101, 123, 133, 593, 1409, 3525, 2545, 13009, 11873, 38463, 1075, 0 };
            const std::uint32_t dim8923JoeKuoD6Init[]   =   { 1, 3, 3, 1, 3, 19, 75, 221, 157, 67, 397, 1141, 5073, 10795, 9857, 35459, 62701, 0 };
            const std::uint32_t dim8924JoeKuoD6Init[]   =   { 1, 1, 7, 7, 23, 17, 41, 179, 83, 543, 1839, 3709, 131, 15681, 9147, 18685, 90389, 0 };
            const std::uint32_t dim8925JoeKuoD6Init[]   =   { 1, 1, 5, 7, 17, 15, 31, 217, 79, 687, 1927, 2889, 6127, 15095, 28437, 16403, 123275, 0 };
            const std::uint32_t dim8926JoeKuoD6Init[]   =   { 1, 3, 7, 15, 13, 17, 123, 75, 45, 635, 525, 3897, 6769, 13855, 16695, 18039, 37479, 0 };
            const std::uint32_t dim8927JoeKuoD6Init[]   =   { 1, 1, 5, 1, 23, 15, 69, 161, 503, 339, 1061, 839, 9, 10013, 24493, 32711, 50147, 0 };
            const std::uint32_t dim8928JoeKuoD6Init[]   =   { 1, 3, 3, 11, 5, 45, 9, 233, 131, 629, 1111, 3311, 2211, 9079, 19763, 23793, 85389, 0 };
            const std::uint32_t dim8929JoeKuoD6Init[]   =   { 1, 1, 7, 7, 7, 27, 15, 85, 291, 925, 1545, 3061, 4867, 1613, 13467, 53731, 92811, 0 };
            const std::uint32_t dim8930JoeKuoD6Init[]   =   { 1, 3, 5, 1, 21, 21, 71, 33, 141, 675, 1519, 3275, 1491, 10717, 28199, 14983, 18961, 0 };
            const std::uint32_t dim8931JoeKuoD6Init[]   =   { 1, 3, 5, 5, 31, 13, 109, 239, 369, 373, 257, 3765, 2531, 13281, 11877, 29439, 106939, 0 };
            const std::uint32_t dim8932JoeKuoD6Init[]   =   { 1, 3, 7, 15, 13, 39, 111, 203, 109, 179, 789, 3849, 433, 5745, 2343, 15795, 92603, 0 };
            const std::uint32_t dim8933JoeKuoD6Init[]   =   { 1, 3, 5, 5, 11, 57, 3, 245, 289, 249, 713, 315, 2261, 1249, 6963, 44507, 100829, 0 };
            const std::uint32_t dim8934JoeKuoD6Init[]   =   { 1, 3, 5, 11, 5, 49, 97, 245, 363, 315, 509, 17, 4485, 15393, 28491, 17945, 65663, 0 };
            const std::uint32_t dim8935JoeKuoD6Init[]   =   { 1, 3, 5, 1, 5, 13, 15, 17, 141, 119, 1393, 581, 2439, 2015, 11527, 8537, 103005, 0 };
            const std::uint32_t dim8936JoeKuoD6Init[]   =   { 1, 3, 5, 1, 25, 9, 117, 25, 99, 777, 985, 1159, 99, 3013, 21429, 19027, 61833, 0 };
            const std::uint32_t dim8937JoeKuoD6Init[]   =   { 1, 1, 1, 5, 1, 47, 37, 83, 159, 29, 281, 3789, 2525, 15999, 8965, 11145, 14453, 0 };
            const std::uint32_t dim8938JoeKuoD6Init[]   =   { 1, 1, 3, 1, 11, 63, 77, 207, 267, 473, 241, 629, 6969, 9093, 839, 3875, 18873, 0 };
            const std::uint32_t dim8939JoeKuoD6Init[]   =   { 1, 3, 5, 7, 31, 57, 103, 65, 349, 321, 717, 2403, 105, 643, 27999, 2509, 123061, 0 };
            const std::uint32_t dim8940JoeKuoD6Init[]   =   { 1, 1, 5, 7, 3, 31, 7, 113, 17, 995, 1211, 1749, 6757, 3391, 8011, 47715, 24301, 0 };
            const std::uint32_t dim8941JoeKuoD6Init[]   =   { 1, 3, 7, 11, 7, 55, 29, 155, 373, 81, 1255, 2205, 3233, 9537, 22129, 24505, 79021, 0 };
            const std::uint32_t dim8942JoeKuoD6Init[]   =   { 1, 1, 7, 5, 3, 49, 5, 51, 89, 107, 585, 3933, 745, 11685, 20663, 12521, 24357, 0 };
            const std::uint32_t dim8943JoeKuoD6Init[]   =   { 1, 1, 7, 1, 17, 17, 83, 215, 357, 581, 2025, 3411, 7287, 11925, 2253, 43513, 98655, 0 };
            const std::uint32_t dim8944JoeKuoD6Init[]   =   { 1, 3, 5, 3, 27, 27, 51, 147, 471, 509, 423, 3807, 677, 8429, 581, 47999, 35913, 0 };
            const std::uint32_t dim8945JoeKuoD6Init[]   =   { 1, 3, 3, 9, 15, 31, 1, 93, 207, 759, 1991, 473, 2273, 43, 12547, 58085, 20953, 0 };
            const std::uint32_t dim8946JoeKuoD6Init[]   =   { 1, 1, 3, 3, 1, 27, 39, 219, 381, 187, 159, 2333, 6141, 3775, 5693, 14853, 38765, 0 };
            const std::uint32_t dim8947JoeKuoD6Init[]   =   { 1, 3, 1, 5, 19, 1, 19, 237, 231, 975, 1609, 723, 241, 10105, 18817, 58373, 118889, 0 };
            const std::uint32_t dim8948JoeKuoD6Init[]   =   { 1, 1, 5, 7, 7, 43, 99, 181, 109, 529, 421, 1493, 1075, 12219, 24287, 33479, 29987, 0 };
            const std::uint32_t dim8949JoeKuoD6Init[]   =   { 1, 1, 7, 1, 17, 11, 79, 85, 157, 851, 1429, 3355, 139, 14327, 30025, 60303, 109015, 0 };
            const std::uint32_t dim8950JoeKuoD6Init[]   =   { 1, 3, 5, 9, 11, 15, 37, 79, 5, 169, 999, 815, 6255, 11763, 16299, 49891, 101917, 0 };
            const std::uint32_t dim8951JoeKuoD6Init[]   =   { 1, 3, 5, 9, 29, 45, 51, 211, 159, 771, 1631, 2871, 4877, 4941, 18127, 15669, 57515, 0 };
            const std::uint32_t dim8952JoeKuoD6Init[]   =   { 1, 1, 3, 3, 19, 29, 9, 205, 253, 399, 303, 2441, 3187, 641, 23341, 52951, 57559, 0 };
            const std::uint32_t dim8953JoeKuoD6Init[]   =   { 1, 3, 3, 15, 11, 29, 121, 227, 69, 935, 365, 217, 4617, 13193, 27663, 46903, 107843, 0 };
            const std::uint32_t dim8954JoeKuoD6Init[]   =   { 1, 1, 5, 11, 13, 31, 13, 243, 275, 685, 1613, 1915, 2775, 11225, 4729, 45549, 103875, 0 };
            const std::uint32_t dim8955JoeKuoD6Init[]   =   { 1, 1, 5, 1, 9, 61, 35, 143, 165, 441, 517, 1735, 5281, 10139, 21107, 11713, 130483, 0 };
            const std::uint32_t dim8956JoeKuoD6Init[]   =   { 1, 3, 5, 5, 13, 21, 7, 219, 97, 887, 1845, 469, 2523, 1569, 9959, 4397, 15823, 0 };
            const std::uint32_t dim8957JoeKuoD6Init[]   =   { 1, 3, 7, 11, 15, 27, 73, 223, 365, 939, 331, 145, 683, 6441, 23421, 59177, 31763, 0 };
            const std::uint32_t dim8958JoeKuoD6Init[]   =   { 1, 3, 1, 5, 9, 59, 85, 113, 343, 831, 121, 3157, 6059, 14923, 27401, 19759, 14223, 0 };
            const std::uint32_t dim8959JoeKuoD6Init[]   =   { 1, 3, 1, 7, 17, 25, 3, 39, 471, 759, 2041, 609, 4293, 7491, 8041, 50857, 25601, 0 };
            const std::uint32_t dim8960JoeKuoD6Init[]   =   { 1, 1, 5, 15, 19, 45, 21, 5, 269, 197, 527, 1839, 1719, 15105, 18671, 42167, 9617, 0 };
            const std::uint32_t dim8961JoeKuoD6Init[]   =   { 1, 3, 1, 3, 5, 35, 3, 105, 395, 113, 1945, 3945, 3951, 12207, 32135, 34121, 10237, 0 };
            const std::uint32_t dim8962JoeKuoD6Init[]   =   { 1, 1, 5, 13, 21, 43, 51, 255, 57, 399, 1937, 1573, 363, 11589, 26989, 54345, 94341, 0 };
            const std::uint32_t dim8963JoeKuoD6Init[]   =   { 1, 3, 3, 3, 5, 45, 83, 125, 179, 923, 39, 3617, 7683, 8191, 31469, 23633, 79179, 0 };
            const std::uint32_t dim8964JoeKuoD6Init[]   =   { 1, 3, 7, 9, 9, 37, 107, 65, 423, 77, 1779, 1375, 2085, 11779, 6535, 2973, 29425, 0 };
            const std::uint32_t dim8965JoeKuoD6Init[]   =   { 1, 1, 7, 3, 11, 39, 101, 137, 407, 855, 1767, 1717, 2821, 10447, 31187, 6329, 124111, 0 };
            const std::uint32_t dim8966JoeKuoD6Init[]   =   { 1, 1, 5, 11, 27, 27, 45, 103, 225, 681, 725, 1791, 2881, 2923, 14473, 12269, 58743, 0 };
            const std::uint32_t dim8967JoeKuoD6Init[]   =   { 1, 1, 3, 11, 15, 39, 113, 167, 143, 677, 1189, 1571, 5339, 6065, 30187, 19639, 42227, 0 };
            const std::uint32_t dim8968JoeKuoD6Init[]   =   { 1, 1, 1, 3, 13, 7, 113, 75, 129, 619, 1741, 1495, 4751, 11085, 22391, 199, 105463, 0 };
            const std::uint32_t dim8969JoeKuoD6Init[]   =   { 1, 1, 3, 3, 19, 47, 77, 195, 209, 453, 495, 1605, 5255, 15327, 8941, 18239, 54511, 0 };
            const std::uint32_t dim8970JoeKuoD6Init[]   =   { 1, 1, 7, 7, 21, 29, 95, 175, 3, 689, 611, 2467, 6919, 12399, 18869, 16171, 102753, 0 };
            const std::uint32_t dim8971JoeKuoD6Init[]   =   { 1, 1, 5, 1, 27, 43, 61, 133, 37, 603, 315, 1915, 813, 15769, 27447, 29589, 122281, 0 };
            const std::uint32_t dim8972JoeKuoD6Init[]   =   { 1, 1, 7, 3, 11, 1, 119, 235, 93, 481, 1811, 1643, 4853, 11313, 8991, 6153, 68985, 0 };
            const std::uint32_t dim8973JoeKuoD6Init[]   =   { 1, 1, 1, 7, 1, 13, 99, 83, 221, 775, 1345, 219, 4445, 11837, 10405, 43563, 122111, 0 };
            const std::uint32_t dim8974JoeKuoD6Init[]   =   { 1, 1, 5, 13, 21, 33, 105, 19, 343, 571, 703, 429, 2485, 15531, 9801, 24101, 88275, 0 };
            const std::uint32_t dim8975JoeKuoD6Init[]   =   { 1, 3, 5, 1, 27, 55, 73, 49, 33, 773, 1411, 1227, 6827, 1271, 28897, 24265, 32383, 0 };
            const std::uint32_t dim8976JoeKuoD6Init[]   =   { 1, 3, 7, 3, 9, 45, 59, 5, 157, 669, 261, 2077, 1425, 8221, 5849, 40857, 121029, 0 };
            const std::uint32_t dim8977JoeKuoD6Init[]   =   { 1, 3, 7, 11, 23, 5, 87, 113, 279, 611, 1195, 1775, 5813, 6737, 18051, 41341, 93331, 0 };
            const std::uint32_t dim8978JoeKuoD6Init[]   =   { 1, 1, 7, 7, 9, 55, 113, 3, 167, 295, 1579, 2833, 4003, 7583, 22833, 44427, 34781, 0 };
            const std::uint32_t dim8979JoeKuoD6Init[]   =   { 1, 1, 5, 13, 21, 33, 127, 175, 153, 961, 819, 143, 3969, 6159, 29437, 14123, 65317, 0 };
            const std::uint32_t dim8980JoeKuoD6Init[]   =   { 1, 1, 1, 15, 31, 27, 1, 17, 329, 963, 1907, 421, 535, 2323, 22749, 44375, 115531, 0 };
            const std::uint32_t dim8981JoeKuoD6Init[]   =   { 1, 1, 5, 15, 15, 23, 57, 171, 253, 401, 1577, 3855, 197, 7979, 17577, 25275, 88831, 0 };
            const std::uint32_t dim8982JoeKuoD6Init[]   =   { 1, 1, 7, 9, 27, 9, 7, 13, 381, 847, 533, 357, 6551, 13441, 5717, 20209, 64347, 0 };
            const std::uint32_t dim8983JoeKuoD6Init[]   =   { 1, 1, 7, 9, 1, 1, 31, 245, 315, 901, 1857, 497, 4285, 13227, 3937, 45025, 59627, 0 };
            const std::uint32_t dim8984JoeKuoD6Init[]   =   { 1, 1, 7, 3, 5, 23, 119, 147, 479, 71, 113, 3379, 863, 8285, 31259, 15863, 47267, 0 };
            const std::uint32_t dim8985JoeKuoD6Init[]   =   { 1, 3, 5, 1, 5, 7, 77, 163, 421, 353, 1757, 1335, 4975, 3011, 11703, 56075, 12045, 0 };
            const std::uint32_t dim8986JoeKuoD6Init[]   =   { 1, 1, 5, 3, 31, 25, 81, 59, 211, 463, 1693, 609, 3307, 3641, 19643, 29361, 8399, 0 };
            const std::uint32_t dim8987JoeKuoD6Init[]   =   { 1, 1, 7, 13, 19, 47, 43, 43, 275, 735, 535, 3689, 3987, 10695, 17243, 60565, 72299, 0 };
            const std::uint32_t dim8988JoeKuoD6Init[]   =   { 1, 3, 3, 5, 25, 35, 75, 63, 305, 127, 189, 1785, 731, 12089, 27811, 43259, 28191, 0 };
            const std::uint32_t dim8989JoeKuoD6Init[]   =   { 1, 3, 7, 11, 17, 17, 59, 107, 139, 355, 1055, 3181, 4743, 14785, 26323, 441, 35613, 0 };
            const std::uint32_t dim8990JoeKuoD6Init[]   =   { 1, 3, 1, 1, 17, 17, 39, 203, 373, 601, 449, 1837, 835, 7061, 14655, 61765, 80735, 0 };
            const std::uint32_t dim8991JoeKuoD6Init[]   =   { 1, 3, 5, 7, 27, 17, 25, 41, 125, 895, 1843, 3167, 1527, 4707, 6477, 33575, 97247, 0 };
            const std::uint32_t dim8992JoeKuoD6Init[]   =   { 1, 3, 3, 3, 13, 39, 25, 15, 279, 347, 1121, 3603, 3019, 9577, 16863, 61483, 15995, 0 };
            const std::uint32_t dim8993JoeKuoD6Init[]   =   { 1, 3, 5, 11, 15, 33, 15, 81, 185, 289, 909, 1237, 3623, 3983, 24211, 62719, 79685, 0 };
            const std::uint32_t dim8994JoeKuoD6Init[]   =   { 1, 1, 1, 7, 29, 1, 53, 17, 137, 269, 1209, 3937, 4167, 14057, 8061, 38863, 101477, 0 };
            const std::uint32_t dim8995JoeKuoD6Init[]   =   { 1, 1, 1, 9, 5, 45, 95, 127, 507, 159, 1763, 1527, 5689, 11007, 549, 22837, 99207, 0 };
            const std::uint32_t dim8996JoeKuoD6Init[]   =   { 1, 3, 3, 1, 15, 57, 127, 39, 73, 397, 67, 3159, 119, 8929, 29425, 57687, 68063, 0 };
            const std::uint32_t dim8997JoeKuoD6Init[]   =   { 1, 3, 1, 3, 27, 7, 111, 209, 291, 17, 1381, 1597, 5389, 4577, 20463, 28325, 23743, 0 };
            const std::uint32_t dim8998JoeKuoD6Init[]   =   { 1, 3, 3, 7, 23, 41, 83, 81, 213, 537, 1037, 2371, 1485, 8391, 12471, 58541, 27559, 0 };
            const std::uint32_t dim8999JoeKuoD6Init[]   =   { 1, 3, 1, 15, 21, 43, 87, 75, 451, 851, 1917, 2739, 2167, 12531, 29931, 8017, 15163, 0 };
            const std::uint32_t dim9000JoeKuoD6Init[]   =   { 1, 1, 3, 9, 27, 19, 41, 145, 401, 759, 527, 3085, 187, 10615, 4995, 22421, 69867, 0 };
            const std::uint32_t dim9001JoeKuoD6Init[]   =   { 1, 3, 3, 13, 29, 51, 65, 47, 157, 609, 1061, 1913, 6195, 12503, 10375, 55819, 122091, 0 };
            const std::uint32_t dim9002JoeKuoD6Init[]   =   { 1, 1, 3, 7, 1, 19, 3, 149, 453, 279, 569, 3429, 331, 711, 26773, 21163, 129339, 0 };
            const std::uint32_t dim9003JoeKuoD6Init[]   =   { 1, 1, 5, 3, 7, 47, 39, 181, 115, 771, 2037, 411, 2697, 7501, 6393, 19461, 74967, 0 };
            const std::uint32_t dim9004JoeKuoD6Init[]   =   { 1, 3, 3, 5, 5, 17, 89, 161, 409, 49, 1447, 3977, 4777, 15553, 3521, 32553, 126385, 0 };
            const std::uint32_t dim9005JoeKuoD6Init[]   =   { 1, 3, 1, 3, 25, 59, 73, 105, 505, 1009, 1147, 317, 3457, 13743, 8337, 38077, 7709, 0 };
            const std::uint32_t dim9006JoeKuoD6Init[]   =   { 1, 3, 3, 15, 23, 37, 25, 123, 413, 911, 637, 2345, 691, 15199, 22927, 52467, 126715, 0 };
            const std::uint32_t dim9007JoeKuoD6Init[]   =   { 1, 1, 5, 1, 9, 51, 93, 123, 269, 45, 1947, 179, 5091, 3743, 31491, 39771, 119175, 0 };
            const std::uint32_t dim9008JoeKuoD6Init[]   =   { 1, 3, 1, 5, 29, 23, 107, 183, 25, 115, 187, 857, 7337, 469, 8755, 17281, 45941, 0 };
            const std::uint32_t dim9009JoeKuoD6Init[]   =   { 1, 3, 1, 13, 25, 61, 85, 115, 181, 955, 1365, 837, 5941, 13209, 27009, 58865, 115149, 0 };
            const std::uint32_t dim9010JoeKuoD6Init[]   =   { 1, 1, 1, 11, 31, 63, 101, 29, 37, 185, 465, 2651, 6249, 6887, 25021, 60539, 50037, 0 };
            const std::uint32_t dim9011JoeKuoD6Init[]   =   { 1, 3, 1, 7, 7, 61, 57, 243, 143, 223, 1759, 4085, 6765, 13293, 31929, 29579, 35053, 0 };
            const std::uint32_t dim9012JoeKuoD6Init[]   =   { 1, 3, 1, 3, 29, 9, 121, 3, 285, 199, 1439, 3151, 5059, 8535, 17049, 38917, 46347, 0 };
            const std::uint32_t dim9013JoeKuoD6Init[]   =   { 1, 3, 1, 3, 17, 43, 63, 87, 427, 341, 1251, 3775, 7729, 3183, 10579, 917, 49035, 0 };
            const std::uint32_t dim9014JoeKuoD6Init[]   =   { 1, 1, 7, 3, 5, 59, 119, 227, 495, 345, 841, 2021, 2483, 15987, 24663, 9819, 33009, 0 };
            const std::uint32_t dim9015JoeKuoD6Init[]   =   { 1, 1, 5, 11, 19, 57, 23, 181, 63, 991, 1, 2927, 4785, 9645, 17435, 55627, 1069, 0 };
            const std::uint32_t dim9016JoeKuoD6Init[]   =   { 1, 1, 7, 1, 31, 11, 57, 123, 279, 815, 1407, 3509, 3963, 8503, 20345, 7777, 103701, 0 };
            const std::uint32_t dim9017JoeKuoD6Init[]   =   { 1, 1, 5, 5, 19, 51, 37, 15, 363, 939, 1863, 3485, 7073, 3035, 31279, 7289, 39811, 0 };
            const std::uint32_t dim9018JoeKuoD6Init[]   =   { 1, 1, 3, 3, 3, 41, 29, 37, 311, 535, 1993, 3937, 309, 13055, 22595, 59641, 95317, 0 };
            const std::uint32_t dim9019JoeKuoD6Init[]   =   { 1, 3, 7, 9, 19, 29, 23, 181, 503, 223, 1655, 997, 7861, 5867, 16979, 4559, 7447, 0 };
            const std::uint32_t dim9020JoeKuoD6Init[]   =   { 1, 3, 5, 3, 13, 13, 3, 137, 361, 101, 1005, 2339, 609, 11891, 15245, 9653, 63579, 0 };
            const std::uint32_t dim9021JoeKuoD6Init[]   =   { 1, 1, 1, 15, 31, 15, 117, 151, 51, 805, 1403, 3243, 4007, 11979, 3945, 61935, 43225, 0 };
            const std::uint32_t dim9022JoeKuoD6Init[]   =   { 1, 1, 7, 3, 1, 43, 93, 105, 9, 555, 731, 655, 2097, 8015, 27557, 27985, 11323, 0 };
            const std::uint32_t dim9023JoeKuoD6Init[]   =   { 1, 3, 3, 9, 23, 35, 59, 217, 437, 755, 685, 1431, 2965, 5269, 25621, 21735, 1397, 0 };
            const std::uint32_t dim9024JoeKuoD6Init[]   =   { 1, 1, 5, 1, 9, 61, 41, 53, 101, 111, 531, 3385, 4771, 9535, 15995, 29687, 99035, 0 };
            const std::uint32_t dim9025JoeKuoD6Init[]   =   { 1, 1, 7, 7, 1, 3, 25, 251, 463, 99, 677, 1889, 3697, 5579, 11429, 38301, 57917, 0 };
            const std::uint32_t dim9026JoeKuoD6Init[]   =   { 1, 1, 5, 9, 11, 15, 65, 31, 369, 825, 1229, 1595, 3891, 5235, 16973, 25307, 7805, 0 };
            const std::uint32_t dim9027JoeKuoD6Init[]   =   { 1, 3, 7, 15, 27, 37, 35, 103, 393, 781, 1713, 2009, 1973, 15461, 6801, 17557, 105139, 0 };
            const std::uint32_t dim9028JoeKuoD6Init[]   =   { 1, 3, 7, 7, 17, 51, 83, 29, 113, 173, 1733, 2137, 3041, 11361, 15999, 25779, 112493, 0 };
            const std::uint32_t dim9029JoeKuoD6Init[]   =   { 1, 3, 5, 11, 19, 3, 89, 103, 449, 375, 437, 4077, 889, 12163, 29323, 48845, 7783, 0 };
            const std::uint32_t dim9030JoeKuoD6Init[]   =   { 1, 3, 7, 1, 19, 25, 83, 35, 203, 27, 507, 25, 6629, 13941, 6187, 17533, 83349, 0 };
            const std::uint32_t dim9031JoeKuoD6Init[]   =   { 1, 3, 5, 9, 15, 59, 3, 87, 473, 733, 1263, 1733, 4275, 9283, 32535, 20807, 59487, 0 };
            const std::uint32_t dim9032JoeKuoD6Init[]   =   { 1, 3, 3, 9, 19, 11, 27, 83, 355, 949, 1339, 171, 921, 14171, 16271, 41485, 20405, 0 };
            const std::uint32_t dim9033JoeKuoD6Init[]   =   { 1, 1, 3, 11, 25, 51, 9, 241, 367, 519, 1895, 429, 7689, 9469, 32709, 46363, 75767, 0 };
            const std::uint32_t dim9034JoeKuoD6Init[]   =   { 1, 1, 7, 7, 27, 59, 85, 87, 467, 273, 1763, 391, 451, 16165, 7501, 44779, 68281, 0 };
            const std::uint32_t dim9035JoeKuoD6Init[]   =   { 1, 1, 7, 5, 1, 35, 5, 217, 31, 145, 1151, 2255, 3543, 401, 17141, 5981, 25183, 0 };
            const std::uint32_t dim9036JoeKuoD6Init[]   =   { 1, 1, 1, 13, 11, 11, 19, 93, 95, 751, 31, 1091, 2733, 10517, 2553, 5247, 42651, 0 };
            const std::uint32_t dim9037JoeKuoD6Init[]   =   { 1, 3, 7, 5, 15, 1, 67, 21, 303, 137, 355, 1989, 5211, 4985, 645, 6867, 126931, 0 };
            const std::uint32_t dim9038JoeKuoD6Init[]   =   { 1, 1, 3, 15, 21, 23, 59, 209, 121, 623, 575, 2447, 6149, 10481, 4959, 22913, 64963, 0 };
            const std::uint32_t dim9039JoeKuoD6Init[]   =   { 1, 3, 1, 1, 25, 55, 47, 95, 215, 609, 639, 1023, 1579, 5953, 3063, 13721, 17607, 0 };
            const std::uint32_t dim9040JoeKuoD6Init[]   =   { 1, 1, 1, 11, 7, 61, 127, 173, 307, 623, 453, 3827, 4847, 16085, 4407, 4043, 14881, 0 };
            const std::uint32_t dim9041JoeKuoD6Init[]   =   { 1, 1, 7, 11, 5, 15, 51, 125, 439, 795, 203, 91, 3543, 6925, 32055, 52277, 26841, 0 };
            const std::uint32_t dim9042JoeKuoD6Init[]   =   { 1, 1, 1, 13, 15, 9, 107, 183, 391, 751, 243, 1105, 8031, 7443, 137, 45695, 80163, 0 };
            const std::uint32_t dim9043JoeKuoD6Init[]   =   { 1, 3, 5, 9, 5, 61, 117, 113, 121, 291, 225, 1705, 4017, 13113, 11035, 28613, 25927, 0 };
            const std::uint32_t dim9044JoeKuoD6Init[]   =   { 1, 1, 3, 11, 27, 9, 45, 85, 309, 991, 1639, 1183, 8013, 14587, 7563, 21111, 48497, 0 };
            const std::uint32_t dim9045JoeKuoD6Init[]   =   { 1, 3, 1, 9, 21, 61, 123, 189, 265, 593, 163, 3681, 2271, 2795, 753, 48019, 129507, 0 };
            const std::uint32_t dim9046JoeKuoD6Init[]   =   { 1, 1, 1, 5, 31, 51, 127, 79, 333, 177, 1723, 1365, 2055, 3063, 10693, 61223, 60659, 0 };
            const std::uint32_t dim9047JoeKuoD6Init[]   =   { 1, 3, 7, 15, 9, 11, 11, 223, 31, 397, 319, 3283, 3765, 4729, 4711, 58323, 114063, 0 };
            const std::uint32_t dim9048JoeKuoD6Init[]   =   { 1, 1, 7, 11, 7, 63, 107, 215, 19, 491, 131, 2491, 6373, 11081, 2159, 1311, 109547, 0 };
            const std::uint32_t dim9049JoeKuoD6Init[]   =   { 1, 3, 5, 5, 21, 13, 105, 21, 193, 447, 1331, 2439, 4165, 15689, 21273, 4007, 55161, 0 };
            const std::uint32_t dim9050JoeKuoD6Init[]   =   { 1, 3, 5, 11, 19, 47, 25, 211, 335, 437, 1041, 2093, 7239, 2869, 18273, 40505, 13681, 0 };
            const std::uint32_t dim9051JoeKuoD6Init[]   =   { 1, 3, 3, 15, 7, 13, 127, 59, 439, 163, 1841, 1945, 4915, 16269, 18315, 15057, 43197, 0 };
            const std::uint32_t dim9052JoeKuoD6Init[]   =   { 1, 1, 3, 3, 15, 33, 101, 241, 131, 353, 1749, 3965, 1231, 8167, 9309, 40337, 4419, 0 };
            const std::uint32_t dim9053JoeKuoD6Init[]   =   { 1, 3, 1, 1, 1, 43, 33, 129, 137, 889, 799, 2937, 3633, 4769, 2411, 56059, 585, 0 };
            const std::uint32_t dim9054JoeKuoD6Init[]   =   { 1, 1, 3, 9, 25, 31, 45, 199, 229, 175, 1099, 1143, 1721, 11811, 22757, 59843, 117813, 0 };
            const std::uint32_t dim9055JoeKuoD6Init[]   =   { 1, 1, 7, 7, 19, 45, 43, 101, 219, 209, 1169, 599, 5523, 2463, 15161, 16675, 85111, 0 };
            const std::uint32_t dim9056JoeKuoD6Init[]   =   { 1, 1, 3, 15, 23, 27, 91, 51, 397, 705, 651, 2345, 3875, 10005, 29523, 42805, 76891, 0 };
            const std::uint32_t dim9057JoeKuoD6Init[]   =   { 1, 3, 3, 5, 29, 49, 17, 233, 149, 821, 1953, 1931, 7127, 957, 6477, 21259, 126657, 0 };
            const std::uint32_t dim9058JoeKuoD6Init[]   =   { 1, 3, 3, 3, 27, 49, 57, 145, 143, 1, 583, 3987, 651, 12285, 20139, 51063, 21449, 0 };
            const std::uint32_t dim9059JoeKuoD6Init[]   =   { 1, 1, 3, 5, 29, 61, 41, 93, 277, 111, 395, 2929, 5325, 15183, 3981, 23799, 72781, 0 };
            const std::uint32_t dim9060JoeKuoD6Init[]   =   { 1, 1, 7, 5, 25, 43, 85, 137, 401, 261, 1183, 3959, 1983, 16209, 30523, 429, 109181, 0 };
            const std::uint32_t dim9061JoeKuoD6Init[]   =   { 1, 1, 1, 5, 7, 19, 79, 237, 373, 929, 907, 1771, 6991, 211, 5269, 2135, 32051, 0 };
            const std::uint32_t dim9062JoeKuoD6Init[]   =   { 1, 1, 7, 5, 17, 15, 41, 49, 363, 15, 1483, 1017, 2439, 11713, 19983, 26275, 11945, 0 };
            const std::uint32_t dim9063JoeKuoD6Init[]   =   { 1, 1, 7, 7, 19, 5, 55, 15, 15, 573, 1075, 3225, 6815, 11893, 18417, 50833, 71903, 0 };
            const std::uint32_t dim9064JoeKuoD6Init[]   =   { 1, 1, 7, 9, 23, 37, 75, 3, 477, 291, 37, 1861, 2697, 13369, 24573, 27285, 96757, 0 };
            const std::uint32_t dim9065JoeKuoD6Init[]   =   { 1, 1, 1, 13, 5, 29, 65, 195, 365, 465, 865, 2705, 5249, 7051, 3795, 56611, 72317, 0 };
            const std::uint32_t dim9066JoeKuoD6Init[]   =   { 1, 1, 3, 9, 19, 9, 85, 239, 509, 313, 1137, 2221, 5475, 71, 11901, 1877, 68701, 0 };
            const std::uint32_t dim9067JoeKuoD6Init[]   =   { 1, 3, 3, 7, 3, 53, 55, 223, 441, 159, 933, 2573, 3441, 3295, 25005, 29021, 97145, 0 };
            const std::uint32_t dim9068JoeKuoD6Init[]   =   { 1, 3, 5, 5, 3, 11, 101, 181, 293, 319, 47, 2971, 387, 4697, 26613, 8531, 20461, 0 };
            const std::uint32_t dim9069JoeKuoD6Init[]   =   { 1, 3, 3, 13, 17, 11, 41, 233, 455, 353, 1817, 3065, 4657, 1717, 3039, 10937, 107085, 0 };
            const std::uint32_t dim9070JoeKuoD6Init[]   =   { 1, 1, 7, 1, 17, 23, 85, 5, 291, 725, 1791, 3525, 7705, 6561, 25311, 44679, 21419, 0 };
            const std::uint32_t dim9071JoeKuoD6Init[]   =   { 1, 1, 7, 1, 23, 41, 97, 117, 435, 261, 2007, 965, 6913, 12245, 25723, 8445, 30871, 0 };
            const std::uint32_t dim9072JoeKuoD6Init[]   =   { 1, 1, 1, 15, 29, 39, 101, 33, 55, 1019, 1431, 2601, 3837, 14873, 11785, 12449, 30815, 0 };
            const std::uint32_t dim9073JoeKuoD6Init[]   =   { 1, 1, 5, 3, 15, 35, 101, 7, 479, 535, 1875, 2435, 1461, 13967, 2755, 45879, 93561, 0 };
            const std::uint32_t dim9074JoeKuoD6Init[]   =   { 1, 3, 1, 5, 29, 57, 89, 209, 473, 289, 1843, 2051, 3997, 1753, 18179, 41355, 89301, 0 };
            const std::uint32_t dim9075JoeKuoD6Init[]   =   { 1, 3, 1, 11, 17, 45, 47, 57, 109, 309, 1009, 653, 5175, 15599, 21617, 35353, 55253, 0 };
            const std::uint32_t dim9076JoeKuoD6Init[]   =   { 1, 3, 5, 3, 1, 11, 57, 83, 385, 765, 1887, 785, 2115, 8689, 14783, 14841, 122221, 0 };
            const std::uint32_t dim9077JoeKuoD6Init[]   =   { 1, 3, 5, 11, 11, 5, 77, 115, 189, 371, 887, 3653, 8159, 15737, 6763, 52807, 128841, 0 };
            const std::uint32_t dim9078JoeKuoD6Init[]   =   { 1, 1, 1, 11, 11, 33, 9, 145, 439, 565, 171, 3867, 7149, 4369, 15073, 3277, 25873, 0 };
            const std::uint32_t dim9079JoeKuoD6Init[]   =   { 1, 1, 3, 1, 11, 9, 17, 255, 129, 835, 1705, 1551, 877, 4831, 12717, 2549, 62723, 0 };
            const std::uint32_t dim9080JoeKuoD6Init[]   =   { 1, 1, 7, 11, 17, 33, 21, 195, 143, 153, 1855, 1323, 1225, 16359, 16479, 8883, 76449, 0 };
            const std::uint32_t dim9081JoeKuoD6Init[]   =   { 1, 1, 1, 5, 31, 23, 61, 53, 77, 465, 1983, 4019, 4865, 14721, 18601, 48179, 100453, 0 };
            const std::uint32_t dim9082JoeKuoD6Init[]   =   { 1, 3, 1, 13, 19, 53, 83, 63, 165, 393, 469, 1465, 2669, 10155, 7029, 26185, 121223, 0 };
            const std::uint32_t dim9083JoeKuoD6Init[]   =   { 1, 1, 1, 3, 3, 3, 123, 23, 45, 359, 1063, 847, 3943, 6113, 23749, 30323, 10583, 0 };
            const std::uint32_t dim9084JoeKuoD6Init[]   =   { 1, 3, 5, 15, 1, 55, 65, 149, 139, 217, 141, 2425, 7019, 14127, 11725, 50821, 52643, 0 };
            const std::uint32_t dim9085JoeKuoD6Init[]   =   { 1, 3, 5, 15, 13, 13, 15, 93, 457, 869, 117, 585, 7159, 5957, 15073, 21861, 118119, 0 };
            const std::uint32_t dim9086JoeKuoD6Init[]   =   { 1, 3, 1, 15, 3, 31, 29, 245, 47, 895, 197, 1169, 945, 11503, 26615, 14079, 27175, 0 };
            const std::uint32_t dim9087JoeKuoD6Init[]   =   { 1, 3, 5, 5, 31, 1, 107, 109, 253, 999, 1451, 2243, 6675, 10779, 26181, 64597, 16443, 0 };
            const std::uint32_t dim9088JoeKuoD6Init[]   =   { 1, 3, 7, 15, 9, 53, 25, 41, 151, 197, 1955, 2365, 5305, 2901, 24825, 9595, 57377, 0 };
            const std::uint32_t dim9089JoeKuoD6Init[]   =   { 1, 3, 1, 3, 25, 37, 37, 193, 417, 373, 1127, 3239, 4583, 2861, 14501, 64163, 30055, 0 };
            const std::uint32_t dim9090JoeKuoD6Init[]   =   { 1, 3, 7, 9, 7, 21, 49, 231, 241, 95, 1757, 2281, 2679, 1611, 11115, 31743, 26851, 0 };
            const std::uint32_t dim9091JoeKuoD6Init[]   =   { 1, 3, 5, 5, 1, 1, 23, 173, 195, 593, 1639, 1449, 4733, 2451, 12677, 31959, 128217, 0 };
            const std::uint32_t dim9092JoeKuoD6Init[]   =   { 1, 1, 1, 7, 17, 49, 117, 253, 167, 721, 889, 3027, 7781, 13521, 15477, 17981, 95487, 0 };
            const std::uint32_t dim9093JoeKuoD6Init[]   =   { 1, 1, 1, 15, 13, 47, 125, 9, 33, 567, 1733, 1263, 307, 10285, 6325, 55827, 39823, 0 };
            const std::uint32_t dim9094JoeKuoD6Init[]   =   { 1, 1, 1, 15, 23, 3, 11, 169, 369, 667, 313, 2287, 6655, 16067, 5915, 8605, 92177, 0 };
            const std::uint32_t dim9095JoeKuoD6Init[]   =   { 1, 3, 3, 15, 13, 21, 125, 111, 171, 785, 79, 2281, 1247, 11321, 30397, 28555, 84863, 0 };
            const std::uint32_t dim9096JoeKuoD6Init[]   =   { 1, 1, 5, 13, 1, 31, 123, 97, 127, 245, 1213, 2381, 3545, 13545, 28657, 54087, 79039, 0 };
            const std::uint32_t dim9097JoeKuoD6Init[]   =   { 1, 1, 7, 9, 9, 21, 87, 111, 27, 33, 843, 199, 1465, 6555, 8019, 39521, 98883, 0 };
            const std::uint32_t dim9098JoeKuoD6Init[]   =   { 1, 3, 3, 5, 5, 55, 61, 219, 279, 207, 1811, 667, 2989, 3133, 25213, 51979, 87695, 0 };
            const std::uint32_t dim9099JoeKuoD6Init[]   =   { 1, 1, 7, 3, 17, 11, 31, 97, 277, 385, 229, 3045, 557, 13521, 32733, 36831, 43003, 0 };
            const std::uint32_t dim9100JoeKuoD6Init[]   =   { 1, 3, 5, 13, 27, 57, 31, 207, 147, 405, 1495, 2471, 4889, 14861, 4861, 28185, 62363, 0 };
            const std::uint32_t dim9101JoeKuoD6Init[]   =   { 1, 1, 5, 13, 23, 19, 5, 21, 509, 299, 1077, 1747, 6229, 2375, 17903, 58473, 72637, 0 };
            const std::uint32_t dim9102JoeKuoD6Init[]   =   { 1, 3, 7, 11, 15, 61, 63, 165, 27, 461, 1359, 3375, 3029, 9907, 17393, 11097, 43593, 0 };
            const std::uint32_t dim9103JoeKuoD6Init[]   =   { 1, 3, 5, 1, 17, 29, 15, 5, 419, 19, 1981, 3169, 2389, 9169, 31697, 26201, 6997, 0 };
            const std::uint32_t dim9104JoeKuoD6Init[]   =   { 1, 3, 3, 1, 29, 31, 89, 79, 347, 707, 505, 2087, 2163, 5465, 8677, 11421, 93217, 0 };
            const std::uint32_t dim9105JoeKuoD6Init[]   =   { 1, 3, 7, 9, 3, 23, 75, 215, 7, 971, 925, 3223, 7825, 12347, 19763, 10927, 41245, 0 };
            const std::uint32_t dim9106JoeKuoD6Init[]   =   { 1, 3, 5, 5, 3, 43, 119, 79, 373, 761, 709, 1897, 3953, 13895, 13421, 16939, 112449, 0 };
            const std::uint32_t dim9107JoeKuoD6Init[]   =   { 1, 1, 3, 15, 11, 25, 65, 101, 315, 1005, 1319, 1163, 161, 15331, 4845, 40375, 121361, 0 };
            const std::uint32_t dim9108JoeKuoD6Init[]   =   { 1, 1, 3, 7, 1, 57, 63, 131, 145, 1007, 549, 2327, 1513, 3591, 10839, 56297, 80613, 0 };
            const std::uint32_t dim9109JoeKuoD6Init[]   =   { 1, 1, 3, 5, 1, 19, 79, 81, 505, 945, 65, 319, 6105, 5491, 13257, 4651, 48247, 0 };
            const std::uint32_t dim9110JoeKuoD6Init[]   =   { 1, 3, 1, 9, 27, 41, 61, 41, 421, 707, 1279, 3699, 2403, 4075, 16947, 53435, 2917, 0 };
            const std::uint32_t dim9111JoeKuoD6Init[]   =   { 1, 1, 5, 13, 11, 29, 35, 141, 313, 769, 749, 4025, 2597, 12197, 32265, 32159, 37003, 0 };
            const std::uint32_t dim9112JoeKuoD6Init[]   =   { 1, 3, 7, 11, 25, 63, 121, 15, 273, 877, 637, 409, 5001, 4723, 27985, 55501, 43495, 0 };
            const std::uint32_t dim9113JoeKuoD6Init[]   =   { 1, 3, 1, 13, 27, 29, 127, 65, 275, 967, 1723, 4007, 6147, 13277, 8361, 12305, 95433, 0 };
            const std::uint32_t dim9114JoeKuoD6Init[]   =   { 1, 3, 3, 13, 11, 45, 7, 101, 169, 361, 517, 2897, 4283, 7587, 7495, 31549, 29113, 0 };
            const std::uint32_t dim9115JoeKuoD6Init[]   =   { 1, 3, 3, 1, 9, 27, 65, 15, 279, 127, 1039, 829, 5739, 1949, 24789, 30433, 54503, 0 };
            const std::uint32_t dim9116JoeKuoD6Init[]   =   { 1, 3, 7, 5, 13, 19, 95, 133, 25, 271, 1527, 3571, 101, 15987, 10985, 55761, 39833, 0 };
            const std::uint32_t dim9117JoeKuoD6Init[]   =   { 1, 3, 5, 9, 27, 5, 37, 219, 249, 947, 1063, 4081, 1763, 15003, 23753, 3975, 109803, 0 };
            const std::uint32_t dim9118JoeKuoD6Init[]   =   { 1, 3, 3, 5, 21, 37, 35, 145, 323, 573, 1939, 885, 4645, 4515, 16815, 28783, 76017, 0 };
            const std::uint32_t dim9119JoeKuoD6Init[]   =   { 1, 3, 7, 13, 27, 41, 39, 123, 423, 949, 1487, 2207, 8069, 15337, 20671, 20163, 70667, 0 };
            const std::uint32_t dim9120JoeKuoD6Init[]   =   { 1, 1, 3, 3, 15, 29, 69, 15, 151, 729, 35, 2067, 6715, 12759, 27611, 54133, 16561, 0 };
            const std::uint32_t dim9121JoeKuoD6Init[]   =   { 1, 3, 7, 13, 21, 13, 7, 161, 327, 339, 535, 2059, 413, 11161, 18415, 12415, 63713, 0 };
            const std::uint32_t dim9122JoeKuoD6Init[]   =   { 1, 3, 5, 5, 23, 49, 9, 181, 417, 339, 1013, 1707, 5097, 13319, 18951, 56415, 14397, 0 };
            const std::uint32_t dim9123JoeKuoD6Init[]   =   { 1, 1, 5, 7, 29, 23, 117, 159, 287, 695, 71, 2393, 2655, 6417, 24349, 20441, 77987, 0 };
            const std::uint32_t dim9124JoeKuoD6Init[]   =   { 1, 1, 5, 7, 31, 23, 81, 125, 145, 141, 1459, 4095, 713, 1817, 9263, 21025, 91983, 0 };
            const std::uint32_t dim9125JoeKuoD6Init[]   =   { 1, 1, 1, 9, 17, 23, 91, 39, 459, 299, 1951, 3229, 6229, 3267, 15883, 31719, 96573, 0 };
            const std::uint32_t dim9126JoeKuoD6Init[]   =   { 1, 1, 1, 15, 3, 51, 9, 7, 455, 653, 1447, 153, 8117, 723, 2177, 9107, 7757, 0 };
            const std::uint32_t dim9127JoeKuoD6Init[]   =   { 1, 3, 1, 15, 27, 47, 49, 245, 499, 807, 175, 1653, 1693, 3931, 27479, 30095, 62353, 0 };
            const std::uint32_t dim9128JoeKuoD6Init[]   =   { 1, 1, 5, 5, 23, 7, 15, 193, 499, 193, 201, 2771, 4153, 11533, 25883, 23337, 126685, 0 };
            const std::uint32_t dim9129JoeKuoD6Init[]   =   { 1, 1, 1, 7, 9, 43, 125, 181, 425, 557, 1401, 2593, 1933, 6803, 20021, 32687, 126465, 0 };
            const std::uint32_t dim9130JoeKuoD6Init[]   =   { 1, 3, 3, 13, 27, 19, 99, 29, 395, 765, 1137, 2963, 7397, 9695, 19259, 27965, 83157, 0 };
            const std::uint32_t dim9131JoeKuoD6Init[]   =   { 1, 3, 7, 7, 17, 29, 7, 241, 5, 281, 1489, 1599, 5567, 4579, 7739, 41413, 110571, 0 };
            const std::uint32_t dim9132JoeKuoD6Init[]   =   { 1, 3, 3, 9, 7, 5, 83, 1, 231, 1003, 631, 2557, 831, 6495, 30409, 53519, 79331, 0 };
            const std::uint32_t dim9133JoeKuoD6Init[]   =   { 1, 1, 5, 1, 7, 49, 45, 241, 201, 551, 1645, 2003, 1455, 3317, 23639, 7841, 100765, 0 };
            const std::uint32_t dim9134JoeKuoD6Init[]   =   { 1, 3, 5, 13, 25, 47, 103, 37, 81, 263, 1143, 801, 5863, 6871, 8615, 57363, 90161, 0 };
            const std::uint32_t dim9135JoeKuoD6Init[]   =   { 1, 3, 7, 11, 27, 23, 119, 211, 473, 207, 605, 637, 3369, 7287, 27827, 25003, 65925, 0 };
            const std::uint32_t dim9136JoeKuoD6Init[]   =   { 1, 3, 1, 15, 27, 31, 97, 247, 75, 893, 1099, 3609, 6807, 4393, 10253, 62759, 89971, 0 };
            const std::uint32_t dim9137JoeKuoD6Init[]   =   { 1, 1, 7, 15, 27, 19, 43, 59, 419, 263, 387, 3193, 5589, 4197, 19143, 64749, 103093, 0 };
            const std::uint32_t dim9138JoeKuoD6Init[]   =   { 1, 1, 7, 11, 21, 51, 97, 227, 251, 869, 1927, 2331, 7741, 8207, 12885, 13267, 17945, 0 };
            const std::uint32_t dim9139JoeKuoD6Init[]   =   { 1, 1, 7, 7, 5, 53, 41, 147, 75, 709, 607, 1073, 2853, 8081, 12797, 5279, 86083, 0 };
            const std::uint32_t dim9140JoeKuoD6Init[]   =   { 1, 1, 5, 5, 15, 21, 77, 189, 269, 595, 197, 3117, 5073, 14277, 26867, 49505, 75755, 0 };
            const std::uint32_t dim9141JoeKuoD6Init[]   =   { 1, 3, 5, 15, 13, 55, 1, 223, 135, 367, 735, 3139, 4851, 9773, 11699, 19081, 26011, 0 };
            const std::uint32_t dim9142JoeKuoD6Init[]   =   { 1, 3, 5, 7, 9, 3, 89, 103, 321, 727, 1809, 3527, 6881, 2399, 13593, 27867, 16219, 0 };
            const std::uint32_t dim9143JoeKuoD6Init[]   =   { 1, 3, 3, 1, 23, 5, 53, 51, 403, 753, 2037, 1261, 7575, 2725, 11341, 18533, 98767, 0 };
            const std::uint32_t dim9144JoeKuoD6Init[]   =   { 1, 1, 1, 11, 1, 13, 37, 141, 477, 689, 1789, 1913, 5753, 6069, 6965, 55209, 77329, 0 };
            const std::uint32_t dim9145JoeKuoD6Init[]   =   { 1, 3, 7, 3, 17, 59, 79, 249, 381, 163, 1773, 1645, 7295, 2359, 21889, 28429, 117073, 0 };
            const std::uint32_t dim9146JoeKuoD6Init[]   =   { 1, 3, 5, 15, 7, 45, 59, 3, 93, 259, 1257, 2967, 1175, 10171, 873, 51423, 67437, 0 };
            const std::uint32_t dim9147JoeKuoD6Init[]   =   { 1, 1, 7, 13, 17, 33, 53, 217, 159, 683, 1169, 3363, 4591, 3959, 10089, 35443, 99677, 0 };
            const std::uint32_t dim9148JoeKuoD6Init[]   =   { 1, 3, 7, 9, 3, 1, 5, 171, 17, 635, 369, 1529, 4861, 4977, 29303, 42357, 69309, 0 };
            const std::uint32_t dim9149JoeKuoD6Init[]   =   { 1, 3, 7, 9, 21, 17, 77, 127, 105, 427, 525, 1123, 2365, 7487, 6315, 64773, 122747, 0 };
            const std::uint32_t dim9150JoeKuoD6Init[]   =   { 1, 1, 1, 15, 19, 63, 65, 83, 219, 987, 169, 2589, 3809, 8807, 22473, 6479, 44617, 0 };
            const std::uint32_t dim9151JoeKuoD6Init[]   =   { 1, 3, 1, 7, 11, 51, 107, 19, 379, 191, 1013, 3145, 1501, 11871, 14111, 18269, 98247, 0 };
            const std::uint32_t dim9152JoeKuoD6Init[]   =   { 1, 1, 7, 5, 17, 63, 23, 231, 423, 855, 1955, 907, 4553, 16173, 7701, 40329, 42047, 0 };
            const std::uint32_t dim9153JoeKuoD6Init[]   =   { 1, 3, 7, 1, 7, 45, 103, 127, 185, 721, 1035, 839, 691, 6823, 23819, 50781, 92767, 0 };
            const std::uint32_t dim9154JoeKuoD6Init[]   =   { 1, 1, 1, 3, 9, 21, 57, 253, 285, 85, 1227, 365, 2347, 7491, 15183, 8619, 108819, 0 };
            const std::uint32_t dim9155JoeKuoD6Init[]   =   { 1, 1, 3, 15, 27, 13, 5, 85, 45, 1009, 1315, 1749, 2797, 3941, 19367, 50855, 60693, 0 };
            const std::uint32_t dim9156JoeKuoD6Init[]   =   { 1, 3, 5, 15, 29, 63, 115, 197, 317, 601, 711, 377, 7489, 4247, 4843, 56549, 108447, 0 };
            const std::uint32_t dim9157JoeKuoD6Init[]   =   { 1, 3, 7, 15, 11, 25, 7, 145, 371, 395, 1743, 267, 2609, 15707, 13909, 55031, 71115, 0 };
            const std::uint32_t dim9158JoeKuoD6Init[]   =   { 1, 3, 1, 1, 1, 53, 111, 245, 433, 309, 245, 15, 2091, 9051, 11095, 31821, 104535, 0 };
            const std::uint32_t dim9159JoeKuoD6Init[]   =   { 1, 3, 1, 15, 25, 31, 99, 89, 259, 595, 1095, 3681, 5105, 8671, 23663, 29717, 126429, 0 };
            const std::uint32_t dim9160JoeKuoD6Init[]   =   { 1, 3, 7, 7, 5, 31, 15, 59, 109, 527, 257, 1785, 6799, 1283, 11741, 34589, 102397, 0 };
            const std::uint32_t dim9161JoeKuoD6Init[]   =   { 1, 3, 3, 15, 9, 27, 55, 35, 291, 587, 1281, 779, 4615, 373, 24037, 64671, 124019, 0 };
            const std::uint32_t dim9162JoeKuoD6Init[]   =   { 1, 1, 5, 5, 13, 51, 49, 19, 37, 857, 539, 1291, 6021, 8645, 30351, 33839, 111515, 0 };
            const std::uint32_t dim9163JoeKuoD6Init[]   =   { 1, 1, 5, 13, 3, 47, 9, 197, 19, 337, 2025, 3003, 7179, 5755, 31187, 59317, 69753, 0 };
            const std::uint32_t dim9164JoeKuoD6Init[]   =   { 1, 1, 7, 3, 3, 43, 11, 3, 123, 29, 857, 3349, 791, 11157, 23967, 33729, 28445, 0 };
            const std::uint32_t dim9165JoeKuoD6Init[]   =   { 1, 1, 5, 1, 1, 11, 73, 231, 173, 925, 331, 161, 3303, 11015, 17507, 21271, 56865, 0 };
            const std::uint32_t dim9166JoeKuoD6Init[]   =   { 1, 1, 3, 9, 21, 21, 115, 145, 421, 981, 1789, 3343, 7591, 12043, 5795, 17737, 106501, 0 };
            const std::uint32_t dim9167JoeKuoD6Init[]   =   { 1, 1, 7, 13, 7, 15, 51, 75, 497, 637, 1073, 1505, 5613, 1415, 30861, 26159, 79573, 0 };
            const std::uint32_t dim9168JoeKuoD6Init[]   =   { 1, 1, 3, 15, 17, 35, 17, 129, 169, 283, 1383, 149, 211, 1381, 22205, 28367, 831, 0 };
            const std::uint32_t dim9169JoeKuoD6Init[]   =   { 1, 3, 5, 5, 17, 11, 127, 183, 503, 499, 2011, 2721, 2717, 3105, 4731, 60319, 9361, 0 };
            const std::uint32_t dim9170JoeKuoD6Init[]   =   { 1, 1, 1, 7, 27, 55, 77, 203, 255, 761, 1159, 2915, 4479, 13671, 19757, 65497, 4461, 0 };
            const std::uint32_t dim9171JoeKuoD6Init[]   =   { 1, 3, 1, 9, 9, 51, 67, 205, 445, 35, 371, 1837, 3623, 10365, 19463, 59005, 3185, 0 };
            const std::uint32_t dim9172JoeKuoD6Init[]   =   { 1, 3, 7, 3, 23, 5, 51, 141, 293, 489, 263, 2187, 1259, 2729, 1779, 61027, 53931, 0 };
            const std::uint32_t dim9173JoeKuoD6Init[]   =   { 1, 1, 1, 15, 27, 7, 15, 109, 475, 839, 175, 953, 4531, 437, 22475, 24167, 19051, 0 };
            const std::uint32_t dim9174JoeKuoD6Init[]   =   { 1, 1, 7, 9, 25, 23, 41, 107, 299, 115, 1713, 1559, 5701, 5427, 28813, 39913, 15941, 0 };
            const std::uint32_t dim9175JoeKuoD6Init[]   =   { 1, 3, 5, 7, 5, 25, 99, 9, 307, 591, 1303, 3501, 1589, 12095, 26629, 52127, 60635, 0 };
            const std::uint32_t dim9176JoeKuoD6Init[]   =   { 1, 3, 7, 3, 9, 23, 3, 29, 113, 49, 1601, 541, 1415, 11601, 19165, 46595, 111623, 0 };
            const std::uint32_t dim9177JoeKuoD6Init[]   =   { 1, 1, 3, 11, 5, 53, 37, 153, 51, 41, 1267, 545, 2055, 13137, 7749, 30721, 119591, 0 };
            const std::uint32_t dim9178JoeKuoD6Init[]   =   { 1, 3, 5, 11, 1, 15, 65, 17, 155, 65, 745, 2547, 6351, 2347, 13553, 5785, 129857, 0 };
            const std::uint32_t dim9179JoeKuoD6Init[]   =   { 1, 3, 7, 13, 5, 53, 11, 59, 453, 467, 1275, 3669, 4481, 5229, 2953, 23369, 100161, 0 };
            const std::uint32_t dim9180JoeKuoD6Init[]   =   { 1, 3, 1, 1, 13, 41, 91, 179, 331, 547, 1571, 1787, 6467, 12375, 4579, 45023, 119149, 0 };
            const std::uint32_t dim9181JoeKuoD6Init[]   =   { 1, 3, 3, 5, 17, 55, 105, 57, 227, 323, 1517, 1215, 3149, 13919, 18595, 5525, 82445, 0 };
            const std::uint32_t dim9182JoeKuoD6Init[]   =   { 1, 3, 1, 13, 19, 23, 17, 239, 81, 481, 1625, 2003, 7295, 2185, 7021, 19357, 37867, 0 };
            const std::uint32_t dim9183JoeKuoD6Init[]   =   { 1, 3, 5, 9, 11, 15, 61, 223, 153, 139, 2023, 2579, 495, 14319, 2835, 26541, 113115, 0 };
            const std::uint32_t dim9184JoeKuoD6Init[]   =   { 1, 1, 3, 13, 29, 9, 13, 149, 325, 87, 697, 2345, 2205, 5069, 9939, 61351, 127313, 0 };
            const std::uint32_t dim9185JoeKuoD6Init[]   =   { 1, 1, 7, 11, 13, 53, 45, 197, 167, 551, 439, 3715, 4587, 8549, 28193, 35827, 96721, 0 };
            const std::uint32_t dim9186JoeKuoD6Init[]   =   { 1, 3, 1, 1, 17, 7, 31, 205, 219, 739, 1165, 243, 3877, 15943, 15207, 43857, 120565, 0 };
            const std::uint32_t dim9187JoeKuoD6Init[]   =   { 1, 3, 7, 9, 7, 43, 81, 203, 295, 553, 279, 2717, 9, 751, 24715, 21591, 11485, 0 };
            const std::uint32_t dim9188JoeKuoD6Init[]   =   { 1, 1, 1, 11, 15, 17, 41, 121, 355, 157, 955, 3875, 7595, 235, 4937, 20607, 11401, 0 };
            const std::uint32_t dim9189JoeKuoD6Init[]   =   { 1, 1, 7, 7, 13, 49, 33, 161, 65, 251, 1895, 2665, 3017, 9725, 10797, 46313, 43407, 0 };
            const std::uint32_t dim9190JoeKuoD6Init[]   =   { 1, 1, 3, 9, 23, 17, 127, 69, 385, 875, 461, 3305, 3001, 5875, 13547, 61239, 113571, 0 };
            const std::uint32_t dim9191JoeKuoD6Init[]   =   { 1, 3, 7, 5, 15, 47, 113, 131, 465, 89, 733, 433, 799, 5689, 723, 63479, 106945, 0 };
            const std::uint32_t dim9192JoeKuoD6Init[]   =   { 1, 3, 3, 15, 29, 1, 51, 115, 317, 1021, 1219, 1797, 4005, 10435, 28935, 49467, 66833, 0 };
            const std::uint32_t dim9193JoeKuoD6Init[]   =   { 1, 1, 3, 11, 15, 9, 51, 209, 477, 479, 1099, 2781, 5525, 12715, 9067, 18317, 121671, 0 };
            const std::uint32_t dim9194JoeKuoD6Init[]   =   { 1, 3, 1, 7, 19, 35, 61, 27, 479, 815, 1639, 2825, 7449, 13697, 3079, 49833, 35119, 0 };
            const std::uint32_t dim9195JoeKuoD6Init[]   =   { 1, 3, 7, 3, 17, 53, 95, 155, 505, 185, 717, 3419, 3857, 2369, 14525, 22797, 38553, 0 };
            const std::uint32_t dim9196JoeKuoD6Init[]   =   { 1, 3, 1, 13, 27, 5, 11, 21, 507, 65, 39, 2841, 7887, 2783, 18767, 34171, 40527, 0 };
            const std::uint32_t dim9197JoeKuoD6Init[]   =   { 1, 3, 1, 7, 9, 47, 69, 217, 251, 775, 631, 1967, 5541, 10679, 16439, 33533, 57817, 0 };
            const std::uint32_t dim9198JoeKuoD6Init[]   =   { 1, 1, 5, 11, 27, 57, 103, 255, 359, 745, 63, 3725, 4113, 10943, 7833, 46857, 99239, 0 };
            const std::uint32_t dim9199JoeKuoD6Init[]   =   { 1, 3, 1, 5, 31, 41, 69, 245, 401, 451, 959, 351, 6999, 6187, 21437, 55067, 53547, 0 };
            const std::uint32_t dim9200JoeKuoD6Init[]   =   { 1, 1, 1, 13, 25, 49, 85, 181, 457, 731, 743, 1901, 7013, 12027, 14729, 24193, 89685, 0 };
            const std::uint32_t dim9201JoeKuoD6Init[]   =   { 1, 3, 3, 1, 31, 29, 101, 137, 117, 135, 345, 1419, 7133, 2695, 3631, 53049, 45875, 0 };
            const std::uint32_t dim9202JoeKuoD6Init[]   =   { 1, 1, 1, 13, 11, 51, 95, 221, 339, 655, 201, 3007, 8179, 8093, 22399, 59123, 127319, 0 };
            const std::uint32_t dim9203JoeKuoD6Init[]   =   { 1, 3, 7, 3, 31, 37, 23, 199, 191, 649, 817, 1959, 893, 2333, 21477, 29087, 115667, 0 };
            const std::uint32_t dim9204JoeKuoD6Init[]   =   { 1, 3, 3, 5, 9, 55, 123, 67, 39, 533, 797, 2575, 3955, 14585, 28587, 13079, 60053, 0 };
            const std::uint32_t dim9205JoeKuoD6Init[]   =   { 1, 3, 1, 1, 17, 19, 15, 219, 185, 21, 967, 667, 3361, 3883, 8059, 26199, 80913, 0 };
            const std::uint32_t dim9206JoeKuoD6Init[]   =   { 1, 3, 3, 11, 23, 5, 99, 57, 379, 151, 271, 3735, 7087, 12731, 2949, 54831, 37835, 0 };
            const std::uint32_t dim9207JoeKuoD6Init[]   =   { 1, 3, 1, 7, 21, 25, 9, 195, 497, 585, 901, 19, 7675, 13611, 31155, 14567, 20545, 0 };
            const std::uint32_t dim9208JoeKuoD6Init[]   =   { 1, 1, 3, 3, 27, 45, 51, 169, 397, 531, 673, 2935, 3779, 7169, 23479, 16157, 100237, 0 };
            const std::uint32_t dim9209JoeKuoD6Init[]   =   { 1, 1, 1, 1, 19, 49, 3, 75, 455, 805, 591, 1929, 2883, 2797, 31379, 12025, 120929, 0 };
            const std::uint32_t dim9210JoeKuoD6Init[]   =   { 1, 3, 5, 3, 17, 39, 115, 93, 341, 329, 1857, 2753, 4923, 12539, 25589, 19437, 29027, 0 };
            const std::uint32_t dim9211JoeKuoD6Init[]   =   { 1, 3, 5, 9, 27, 37, 21, 235, 499, 369, 1341, 3719, 6819, 3153, 30619, 50901, 52999, 0 };
            const std::uint32_t dim9212JoeKuoD6Init[]   =   { 1, 3, 1, 11, 3, 55, 43, 219, 83, 771, 783, 3569, 7879, 2363, 30605, 5965, 126855, 0 };
            const std::uint32_t dim9213JoeKuoD6Init[]   =   { 1, 3, 7, 13, 7, 25, 111, 63, 355, 317, 1579, 1523, 2733, 11963, 25205, 20545, 67389, 0 };
            const std::uint32_t dim9214JoeKuoD6Init[]   =   { 1, 3, 5, 7, 3, 17, 55, 99, 321, 633, 2013, 1991, 1019, 9223, 21117, 23337, 90589, 0 };
            const std::uint32_t dim9215JoeKuoD6Init[]   =   { 1, 3, 1, 1, 17, 25, 79, 171, 303, 403, 2037, 2595, 3951, 8021, 8669, 9363, 20345, 0 };
            const std::uint32_t dim9216JoeKuoD6Init[]   =   { 1, 1, 1, 7, 13, 7, 11, 7, 347, 53, 1763, 3097, 3353, 3769, 22947, 20919, 92247, 0 };
            const std::uint32_t dim9217JoeKuoD6Init[]   =   { 1, 3, 5, 11, 19, 29, 91, 191, 511, 705, 1317, 3367, 7, 4999, 30251, 18299, 66983, 0 };
            const std::uint32_t dim9218JoeKuoD6Init[]   =   { 1, 1, 3, 7, 19, 17, 71, 77, 285, 189, 853, 2305, 4205, 15603, 15501, 48073, 11411, 0 };
            const std::uint32_t dim9219JoeKuoD6Init[]   =   { 1, 3, 7, 5, 21, 15, 47, 13, 277, 969, 1861, 3493, 6723, 11521, 22145, 43779, 44713, 0 };
            const std::uint32_t dim9220JoeKuoD6Init[]   =   { 1, 1, 3, 5, 19, 47, 51, 207, 229, 957, 709, 267, 8081, 611, 26403, 14871, 111841, 0 };
            const std::uint32_t dim9221JoeKuoD6Init[]   =   { 1, 3, 7, 1, 19, 43, 71, 73, 405, 351, 1131, 3527, 5949, 14363, 20041, 48123, 68123, 0 };
            const std::uint32_t dim9222JoeKuoD6Init[]   =   { 1, 3, 3, 7, 23, 51, 81, 13, 161, 453, 365, 1089, 3505, 12359, 14277, 56113, 19717, 0 };
            const std::uint32_t dim9223JoeKuoD6Init[]   =   { 1, 1, 1, 7, 29, 35, 103, 137, 317, 417, 1465, 2787, 6935, 9885, 12943, 43937, 28353, 0 };
            const std::uint32_t dim9224JoeKuoD6Init[]   =   { 1, 1, 3, 13, 19, 37, 97, 5, 115, 89, 1005, 3033, 2011, 2633, 10615, 6641, 73385, 0 };
            const std::uint32_t dim9225JoeKuoD6Init[]   =   { 1, 3, 7, 7, 31, 39, 107, 165, 61, 1009, 1159, 865, 3469, 11093, 10425, 43959, 37395, 0 };
            const std::uint32_t dim9226JoeKuoD6Init[]   =   { 1, 3, 5, 9, 7, 51, 99, 91, 37, 457, 39, 2455, 7481, 4929, 29755, 50603, 48943, 0 };
            const std::uint32_t dim9227JoeKuoD6Init[]   =   { 1, 1, 5, 13, 5, 39, 47, 149, 341, 303, 843, 3619, 7527, 8739, 5893, 42623, 99899, 0 };
            const std::uint32_t dim9228JoeKuoD6Init[]   =   { 1, 1, 1, 1, 1, 41, 73, 71, 409, 351, 131, 515, 6657, 337, 23913, 583, 21665, 0 };
            const std::uint32_t dim9229JoeKuoD6Init[]   =   { 1, 1, 3, 3, 11, 45, 39, 113, 315, 965, 1605, 2779, 501, 7429, 2567, 7011, 71445, 0 };
            const std::uint32_t dim9230JoeKuoD6Init[]   =   { 1, 3, 7, 13, 21, 13, 45, 105, 385, 281, 1683, 3997, 6391, 10943, 22349, 37261, 57555, 0 };
            const std::uint32_t dim9231JoeKuoD6Init[]   =   { 1, 1, 3, 5, 17, 55, 109, 71, 393, 561, 433, 1091, 1923, 13861, 12981, 5523, 15467, 0 };
            const std::uint32_t dim9232JoeKuoD6Init[]   =   { 1, 3, 7, 5, 17, 11, 113, 119, 37, 989, 1609, 2191, 1511, 11835, 25423, 793, 15227, 0 };
            const std::uint32_t dim9233JoeKuoD6Init[]   =   { 1, 3, 1, 5, 5, 55, 105, 225, 349, 351, 1259, 1309, 821, 2733, 1357, 3665, 38863, 0 };
            const std::uint32_t dim9234JoeKuoD6Init[]   =   { 1, 3, 5, 1, 23, 61, 49, 113, 169, 319, 85, 1581, 97, 5271, 30625, 37693, 7297, 0 };
            const std::uint32_t dim9235JoeKuoD6Init[]   =   { 1, 3, 5, 1, 1, 25, 31, 125, 307, 731, 1815, 1047, 7251, 12481, 20781, 63275, 51985, 0 };
            const std::uint32_t dim9236JoeKuoD6Init[]   =   { 1, 3, 5, 9, 11, 9, 121, 111, 45, 751, 793, 2593, 6409, 4355, 30183, 36959, 105161, 0 };
            const std::uint32_t dim9237JoeKuoD6Init[]   =   { 1, 1, 3, 9, 25, 37, 95, 253, 401, 481, 1521, 3555, 231, 15459, 1581, 36661, 121727, 0 };
            const std::uint32_t dim9238JoeKuoD6Init[]   =   { 1, 3, 5, 3, 27, 11, 107, 115, 213, 813, 27, 1789, 603, 383, 1129, 63365, 51147, 0 };
            const std::uint32_t dim9239JoeKuoD6Init[]   =   { 1, 1, 3, 13, 25, 7, 33, 1, 97, 907, 35, 4069, 5001, 507, 911, 62037, 22019, 0 };
            const std::uint32_t dim9240JoeKuoD6Init[]   =   { 1, 1, 3, 5, 7, 55, 35, 95, 261, 217, 1565, 3473, 3475, 12181, 569, 27389, 81771, 0 };
            const std::uint32_t dim9241JoeKuoD6Init[]   =   { 1, 1, 3, 5, 11, 33, 95, 121, 453, 711, 361, 3927, 5231, 15685, 31143, 56915, 23707, 0 };
            const std::uint32_t dim9242JoeKuoD6Init[]   =   { 1, 1, 3, 11, 25, 15, 53, 155, 469, 647, 1547, 335, 3753, 12873, 13639, 25129, 79287, 0 };
            const std::uint32_t dim9243JoeKuoD6Init[]   =   { 1, 3, 3, 3, 1, 21, 21, 121, 105, 903, 83, 2287, 4295, 14369, 29183, 26841, 38115, 0 };
            const std::uint32_t dim9244JoeKuoD6Init[]   =   { 1, 1, 7, 11, 5, 29, 65, 191, 389, 419, 1315, 739, 3485, 10587, 2399, 36377, 28789, 0 };
            const std::uint32_t dim9245JoeKuoD6Init[]   =   { 1, 3, 3, 11, 3, 29, 71, 169, 265, 747, 395, 1211, 3487, 15705, 25611, 18183, 85771, 0 };
            const std::uint32_t dim9246JoeKuoD6Init[]   =   { 1, 1, 7, 3, 23, 5, 45, 47, 337, 571, 33, 1221, 5671, 1233, 28361, 36945, 911, 0 };
            const std::uint32_t dim9247JoeKuoD6Init[]   =   { 1, 1, 5, 11, 17, 15, 57, 97, 185, 999, 1277, 3371, 2785, 3341, 13395, 11925, 86777, 0 };
            const std::uint32_t dim9248JoeKuoD6Init[]   =   { 1, 1, 3, 1, 31, 37, 23, 105, 503, 869, 1309, 3733, 4629, 8263, 11763, 30669, 26179, 0 };
            const std::uint32_t dim9249JoeKuoD6Init[]   =   { 1, 1, 3, 15, 25, 61, 37, 27, 325, 413, 809, 2959, 8137, 3397, 21185, 27995, 84297, 0 };
            const std::uint32_t dim9250JoeKuoD6Init[]   =   { 1, 3, 5, 5, 1, 55, 95, 41, 493, 469, 331, 1789, 7037, 7947, 14239, 16109, 51795, 0 };
            const std::uint32_t dim9251JoeKuoD6Init[]   =   { 1, 1, 1, 1, 19, 33, 111, 237, 261, 331, 871, 3539, 1731, 6953, 11345, 37901, 5623, 0 };
            const std::uint32_t dim9252JoeKuoD6Init[]   =   { 1, 1, 5, 7, 21, 41, 49, 179, 49, 797, 231, 1299, 145, 7743, 725, 60595, 19581, 0 };
            const std::uint32_t dim9253JoeKuoD6Init[]   =   { 1, 3, 7, 15, 7, 43, 67, 219, 133, 641, 1657, 2301, 1591, 12309, 6395, 3999, 92961, 0 };
            const std::uint32_t dim9254JoeKuoD6Init[]   =   { 1, 1, 1, 5, 1, 49, 37, 81, 219, 323, 461, 1379, 1797, 14825, 21811, 7347, 35643, 0 };
            const std::uint32_t dim9255JoeKuoD6Init[]   =   { 1, 1, 1, 11, 1, 3, 83, 31, 307, 83, 1169, 3277, 1875, 13397, 20265, 46707, 15205, 0 };
            const std::uint32_t dim9256JoeKuoD6Init[]   =   { 1, 3, 7, 11, 29, 41, 69, 33, 405, 991, 1937, 1217, 2137, 8657, 4319, 41119, 43371, 0 };
            const std::uint32_t dim9257JoeKuoD6Init[]   =   { 1, 3, 3, 3, 25, 49, 107, 197, 347, 923, 1585, 3023, 4087, 13875, 22015, 35733, 33755, 0 };
            const std::uint32_t dim9258JoeKuoD6Init[]   =   { 1, 3, 3, 5, 15, 61, 89, 249, 141, 853, 1469, 999, 7425, 10015, 12341, 51535, 61619, 0 };
            const std::uint32_t dim9259JoeKuoD6Init[]   =   { 1, 1, 7, 13, 31, 61, 89, 113, 117, 429, 1011, 1589, 1419, 5083, 4843, 26759, 47401, 0 };
            const std::uint32_t dim9260JoeKuoD6Init[]   =   { 1, 1, 7, 9, 17, 37, 119, 39, 499, 93, 1155, 3069, 2033, 12483, 29849, 40077, 11103, 0 };
            const std::uint32_t dim9261JoeKuoD6Init[]   =   { 1, 3, 1, 15, 11, 5, 23, 121, 283, 717, 1573, 3911, 2031, 2617, 20387, 33157, 301, 0 };
            const std::uint32_t dim9262JoeKuoD6Init[]   =   { 1, 3, 5, 7, 17, 61, 109, 3, 205, 617, 1171, 223, 6609, 15027, 2629, 15801, 73749, 0 };
            const std::uint32_t dim9263JoeKuoD6Init[]   =   { 1, 1, 3, 7, 5, 49, 9, 73, 333, 401, 675, 2765, 993, 77, 19237, 60929, 88703, 0 };
            const std::uint32_t dim9264JoeKuoD6Init[]   =   { 1, 1, 1, 9, 21, 25, 53, 249, 241, 43, 1959, 545, 3729, 11395, 3027, 12661, 87729, 0 };
            const std::uint32_t dim9265JoeKuoD6Init[]   =   { 1, 3, 3, 15, 15, 61, 33, 59, 155, 773, 1043, 3111, 6549, 5397, 29099, 57851, 107671, 0 };
            const std::uint32_t dim9266JoeKuoD6Init[]   =   { 1, 3, 7, 1, 29, 29, 1, 161, 273, 883, 1913, 2389, 401, 9425, 17613, 50443, 84601, 0 };
            const std::uint32_t dim9267JoeKuoD6Init[]   =   { 1, 3, 7, 11, 15, 63, 41, 53, 371, 153, 1491, 3013, 6635, 4955, 30145, 20175, 16541, 0 };
            const std::uint32_t dim9268JoeKuoD6Init[]   =   { 1, 3, 3, 11, 31, 27, 127, 207, 11, 313, 1067, 3445, 3075, 4071, 28305, 58911, 85273, 0 };
            const std::uint32_t dim9269JoeKuoD6Init[]   =   { 1, 1, 7, 11, 17, 47, 77, 119, 209, 657, 1181, 459, 5821, 4267, 5757, 53703, 35621, 0 };
            const std::uint32_t dim9270JoeKuoD6Init[]   =   { 1, 3, 1, 15, 27, 41, 3, 217, 457, 531, 1749, 2847, 4715, 11451, 25071, 53999, 93503, 0 };
            const std::uint32_t dim9271JoeKuoD6Init[]   =   { 1, 3, 5, 3, 19, 29, 9, 177, 355, 265, 883, 1113, 2397, 1819, 20757, 50389, 95551, 0 };
            const std::uint32_t dim9272JoeKuoD6Init[]   =   { 1, 1, 3, 15, 3, 45, 85, 211, 377, 293, 1791, 1193, 1117, 9383, 28039, 27155, 129513, 0 };
            const std::uint32_t dim9273JoeKuoD6Init[]   =   { 1, 1, 7, 5, 1, 17, 59, 215, 161, 933, 1653, 2407, 2693, 3655, 7515, 2239, 88985, 0 };
            const std::uint32_t dim9274JoeKuoD6Init[]   =   { 1, 1, 3, 11, 31, 3, 1, 77, 459, 817, 651, 603, 1711, 9391, 20607, 48195, 127153, 0 };
            const std::uint32_t dim9275JoeKuoD6Init[]   =   { 1, 1, 5, 13, 11, 49, 25, 13, 51, 443, 1877, 1257, 163, 4673, 30313, 18841, 24547, 0 };
            const std::uint32_t dim9276JoeKuoD6Init[]   =   { 1, 1, 7, 7, 15, 33, 43, 79, 127, 625, 1991, 1311, 2095, 14659, 3477, 56023, 57955, 0 };
            const std::uint32_t dim9277JoeKuoD6Init[]   =   { 1, 3, 7, 15, 29, 7, 119, 183, 123, 323, 1723, 959, 2733, 2097, 2927, 57595, 86067, 0 };
            const std::uint32_t dim9278JoeKuoD6Init[]   =   { 1, 3, 5, 5, 29, 57, 93, 139, 495, 739, 1715, 713, 243, 2027, 11223, 44143, 119155, 0 };
            const std::uint32_t dim9279JoeKuoD6Init[]   =   { 1, 3, 1, 9, 3, 63, 113, 29, 19, 439, 869, 1101, 4947, 2191, 14737, 57049, 93505, 0 };
            const std::uint32_t dim9280JoeKuoD6Init[]   =   { 1, 1, 7, 1, 11, 39, 27, 29, 281, 829, 1979, 2185, 2207, 14969, 7447, 55541, 59593, 0 };
            const std::uint32_t dim9281JoeKuoD6Init[]   =   { 1, 1, 7, 13, 11, 15, 15, 143, 383, 469, 1439, 2823, 7489, 7675, 15433, 26203, 80433, 0 };
            const std::uint32_t dim9282JoeKuoD6Init[]   =   { 1, 1, 1, 7, 15, 45, 23, 93, 477, 1, 1431, 3173, 7879, 12211, 13051, 56971, 114289, 0 };
            const std::uint32_t dim9283JoeKuoD6Init[]   =   { 1, 3, 1, 1, 27, 55, 61, 185, 323, 569, 1063, 1357, 7373, 14947, 15967, 64517, 104625, 0 };
            const std::uint32_t dim9284JoeKuoD6Init[]   =   { 1, 1, 5, 11, 25, 1, 127, 163, 419, 657, 911, 361, 3675, 10765, 24565, 2661, 61979, 0 };
            const std::uint32_t dim9285JoeKuoD6Init[]   =   { 1, 3, 7, 15, 29, 53, 29, 149, 465, 535, 1865, 2243, 4783, 9327, 24843, 52313, 15683, 0 };
            const std::uint32_t dim9286JoeKuoD6Init[]   =   { 1, 1, 7, 7, 17, 7, 85, 187, 91, 1013, 1917, 2959, 3571, 12047, 25267, 34095, 9877, 0 };
            const std::uint32_t dim9287JoeKuoD6Init[]   =   { 1, 1, 1, 7, 5, 27, 111, 107, 313, 571, 1081, 3193, 1025, 2589, 1523, 40453, 77065, 0 };
            const std::uint32_t dim9288JoeKuoD6Init[]   =   { 1, 3, 7, 1, 19, 27, 1, 103, 479, 405, 583, 1737, 3495, 9093, 20397, 16429, 45609, 0 };
            const std::uint32_t dim9289JoeKuoD6Init[]   =   { 1, 1, 3, 11, 17, 1, 125, 97, 261, 651, 901, 1245, 1181, 14469, 16229, 31935, 100227, 0 };
            const std::uint32_t dim9290JoeKuoD6Init[]   =   { 1, 1, 7, 11, 15, 1, 19, 151, 453, 833, 1371, 1109, 5373, 25, 5619, 58351, 26349, 0 };
            const std::uint32_t dim9291JoeKuoD6Init[]   =   { 1, 1, 7, 15, 17, 55, 51, 67, 123, 13, 1873, 1035, 5871, 11943, 11543, 43261, 62587, 0 };
            const std::uint32_t dim9292JoeKuoD6Init[]   =   { 1, 3, 1, 13, 21, 15, 83, 205, 333, 379, 2021, 1389, 861, 10395, 20587, 38207, 49109, 0 };
            const std::uint32_t dim9293JoeKuoD6Init[]   =   { 1, 1, 5, 3, 13, 49, 89, 85, 463, 1005, 1367, 3487, 581, 12145, 22445, 35343, 65745, 0 };
            const std::uint32_t dim9294JoeKuoD6Init[]   =   { 1, 3, 3, 3, 29, 27, 99, 195, 89, 793, 1677, 3989, 4811, 8303, 9165, 50349, 96947, 0 };
            const std::uint32_t dim9295JoeKuoD6Init[]   =   { 1, 1, 3, 5, 29, 11, 91, 107, 13, 659, 213, 1613, 2245, 11567, 28157, 2937, 53275, 0 };
            const std::uint32_t dim9296JoeKuoD6Init[]   =   { 1, 3, 7, 5, 3, 41, 65, 27, 93, 747, 1143, 505, 3881, 2123, 2903, 54137, 96185, 0 };
            const std::uint32_t dim9297JoeKuoD6Init[]   =   { 1, 1, 3, 15, 9, 49, 3, 25, 77, 681, 1709, 915, 2243, 2127, 18243, 13915, 67399, 0 };
            const std::uint32_t dim9298JoeKuoD6Init[]   =   { 1, 3, 5, 7, 13, 49, 89, 67, 63, 271, 1651, 897, 4035, 1067, 13743, 56791, 44371, 0 };
            const std::uint32_t dim9299JoeKuoD6Init[]   =   { 1, 1, 7, 9, 25, 19, 125, 15, 125, 705, 1359, 817, 1241, 12447, 19097, 33209, 89091, 0 };
            const std::uint32_t dim9300JoeKuoD6Init[]   =   { 1, 3, 7, 3, 19, 43, 127, 197, 39, 709, 257, 3547, 3069, 1187, 21255, 6453, 40763, 0 };
            const std::uint32_t dim9301JoeKuoD6Init[]   =   { 1, 3, 3, 5, 3, 53, 37, 65, 415, 183, 991, 533, 7805, 9905, 18925, 52665, 100987, 0 };
            const std::uint32_t dim9302JoeKuoD6Init[]   =   { 1, 3, 3, 11, 17, 41, 17, 137, 143, 277, 945, 1531, 7427, 7287, 30869, 27651, 116507, 0 };
            const std::uint32_t dim9303JoeKuoD6Init[]   =   { 1, 1, 1, 3, 13, 3, 9, 163, 113, 373, 1909, 1051, 97, 10729, 28615, 40081, 129297, 0 };
            const std::uint32_t dim9304JoeKuoD6Init[]   =   { 1, 3, 3, 9, 11, 47, 113, 27, 307, 339, 1319, 3083, 7383, 1551, 26691, 28769, 114313, 0 };
            const std::uint32_t dim9305JoeKuoD6Init[]   =   { 1, 3, 7, 7, 25, 49, 31, 231, 485, 629, 59, 283, 7463, 6603, 23055, 63643, 10121, 0 };
            const std::uint32_t dim9306JoeKuoD6Init[]   =   { 1, 3, 7, 9, 5, 55, 53, 127, 147, 103, 1697, 485, 7051, 14153, 21631, 35561, 10393, 0 };
            const std::uint32_t dim9307JoeKuoD6Init[]   =   { 1, 3, 3, 7, 23, 7, 83, 17, 135, 487, 315, 719, 7003, 3919, 13255, 24031, 110493, 0 };
            const std::uint32_t dim9308JoeKuoD6Init[]   =   { 1, 3, 1, 15, 27, 55, 121, 177, 205, 733, 933, 1535, 2925, 4259, 22203, 59059, 89209, 0 };
            const std::uint32_t dim9309JoeKuoD6Init[]   =   { 1, 1, 1, 11, 9, 11, 127, 47, 493, 349, 1415, 3089, 4739, 14347, 31579, 20739, 72997, 0 };
            const std::uint32_t dim9310JoeKuoD6Init[]   =   { 1, 3, 1, 7, 9, 31, 121, 111, 163, 733, 1699, 1507, 5467, 13499, 25269, 6303, 70201, 0 };
            const std::uint32_t dim9311JoeKuoD6Init[]   =   { 1, 3, 1, 5, 7, 23, 123, 203, 329, 387, 577, 2331, 2283, 14029, 19409, 103, 2477, 0 };
            const std::uint32_t dim9312JoeKuoD6Init[]   =   { 1, 1, 7, 15, 11, 29, 29, 153, 289, 333, 1669, 2065, 5465, 8835, 28753, 21209, 34283, 0 };
            const std::uint32_t dim9313JoeKuoD6Init[]   =   { 1, 3, 5, 11, 15, 33, 45, 81, 241, 461, 1167, 1073, 5511, 795, 30955, 49121, 42805, 0 };
            const std::uint32_t dim9314JoeKuoD6Init[]   =   { 1, 1, 1, 13, 7, 33, 11, 201, 161, 475, 1359, 2329, 177, 9883, 8967, 21399, 73045, 0 };
            const std::uint32_t dim9315JoeKuoD6Init[]   =   { 1, 3, 3, 1, 25, 59, 85, 51, 481, 751, 1213, 3019, 421, 9903, 30071, 50661, 94715, 0 };
            const std::uint32_t dim9316JoeKuoD6Init[]   =   { 1, 3, 3, 1, 5, 61, 3, 179, 131, 233, 1627, 3577, 6323, 14161, 21595, 44963, 20215, 0 };
            const std::uint32_t dim9317JoeKuoD6Init[]   =   { 1, 1, 1, 5, 9, 53, 45, 105, 275, 769, 105, 2757, 6769, 14987, 19955, 18291, 81707, 0 };
            const std::uint32_t dim9318JoeKuoD6Init[]   =   { 1, 1, 7, 1, 1, 59, 33, 19, 385, 775, 423, 1799, 1325, 13545, 16027, 58347, 102397, 0 };
            const std::uint32_t dim9319JoeKuoD6Init[]   =   { 1, 1, 3, 11, 15, 61, 63, 59, 355, 659, 1483, 3781, 7383, 5563, 32537, 34175, 40303, 0 };
            const std::uint32_t dim9320JoeKuoD6Init[]   =   { 1, 3, 5, 7, 5, 37, 19, 223, 323, 129, 287, 2655, 3767, 16201, 4147, 315, 54885, 0 };
            const std::uint32_t dim9321JoeKuoD6Init[]   =   { 1, 1, 7, 13, 13, 23, 43, 129, 405, 205, 1691, 2189, 3313, 11789, 10263, 16367, 65547, 0 };
            const std::uint32_t dim9322JoeKuoD6Init[]   =   { 1, 3, 5, 1, 15, 21, 85, 233, 427, 71, 475, 3731, 3335, 11483, 28613, 4335, 35669, 0 };
            const std::uint32_t dim9323JoeKuoD6Init[]   =   { 1, 1, 3, 3, 31, 47, 27, 109, 373, 451, 1459, 3103, 1941, 10405, 20233, 30517, 122787, 0 };
            const std::uint32_t dim9324JoeKuoD6Init[]   =   { 1, 3, 1, 7, 3, 11, 113, 49, 355, 465, 1959, 1355, 6521, 10863, 11481, 13385, 31787, 0 };
            const std::uint32_t dim9325JoeKuoD6Init[]   =   { 1, 3, 1, 1, 9, 45, 125, 69, 267, 413, 717, 2767, 833, 317, 23019, 37753, 3081, 0 };
            const std::uint32_t dim9326JoeKuoD6Init[]   =   { 1, 1, 7, 7, 13, 55, 75, 105, 71, 505, 239, 3739, 4873, 4257, 18841, 41711, 24045, 0 };
            const std::uint32_t dim9327JoeKuoD6Init[]   =   { 1, 1, 5, 13, 21, 59, 107, 229, 421, 441, 1079, 3727, 7941, 8443, 30433, 56419, 105751, 0 };
            const std::uint32_t dim9328JoeKuoD6Init[]   =   { 1, 1, 1, 9, 15, 59, 29, 49, 117, 1009, 1971, 115, 2899, 1069, 29145, 11855, 35277, 0 };
            const std::uint32_t dim9329JoeKuoD6Init[]   =   { 1, 3, 7, 15, 19, 55, 111, 77, 169, 537, 1695, 2687, 3871, 14017, 15119, 27313, 112807, 0 };
            const std::uint32_t dim9330JoeKuoD6Init[]   =   { 1, 1, 3, 7, 29, 5, 41, 201, 211, 127, 1877, 643, 2441, 8743, 29393, 6077, 52597, 0 };
            const std::uint32_t dim9331JoeKuoD6Init[]   =   { 1, 3, 1, 11, 7, 1, 95, 15, 229, 339, 475, 3463, 7827, 9943, 30903, 65013, 1145, 0 };
            const std::uint32_t dim9332JoeKuoD6Init[]   =   { 1, 1, 1, 5, 23, 19, 81, 23, 475, 169, 373, 1147, 1805, 12779, 13173, 8945, 28175, 0 };
            const std::uint32_t dim9333JoeKuoD6Init[]   =   { 1, 3, 5, 9, 3, 53, 127, 33, 237, 803, 121, 307, 4981, 8765, 12761, 23601, 92921, 0 };
            const std::uint32_t dim9334JoeKuoD6Init[]   =   { 1, 1, 3, 7, 17, 63, 11, 37, 213, 619, 1095, 1693, 6747, 7373, 17355, 5987, 97923, 0 };
            const std::uint32_t dim9335JoeKuoD6Init[]   =   { 1, 1, 3, 15, 11, 37, 109, 175, 503, 339, 591, 2745, 2387, 7419, 13915, 4769, 48229, 0 };
            const std::uint32_t dim9336JoeKuoD6Init[]   =   { 1, 3, 5, 7, 19, 17, 5, 81, 471, 989, 249, 437, 7309, 5747, 25277, 31911, 87907, 0 };
            const std::uint32_t dim9337JoeKuoD6Init[]   =   { 1, 3, 1, 7, 15, 25, 49, 243, 423, 911, 1957, 911, 6331, 9831, 26021, 58877, 99257, 0 };
            const std::uint32_t dim9338JoeKuoD6Init[]   =   { 1, 3, 5, 11, 3, 55, 39, 129, 271, 145, 1973, 3391, 2905, 9229, 7989, 15641, 67933, 0 };
            const std::uint32_t dim9339JoeKuoD6Init[]   =   { 1, 3, 5, 9, 13, 13, 43, 135, 183, 319, 1391, 2953, 2207, 14205, 31203, 6329, 98907, 0 };
            const std::uint32_t dim9340JoeKuoD6Init[]   =   { 1, 3, 1, 9, 27, 41, 27, 155, 11, 191, 1747, 975, 7043, 13139, 30387, 47099, 120321, 0 };
            const std::uint32_t dim9341JoeKuoD6Init[]   =   { 1, 1, 5, 9, 25, 27, 53, 235, 437, 77, 371, 2413, 4867, 14245, 27199, 37387, 88217, 0 };
            const std::uint32_t dim9342JoeKuoD6Init[]   =   { 1, 1, 7, 7, 11, 59, 103, 15, 109, 65, 1987, 3695, 7737, 7341, 26963, 16075, 6301, 0 };
            const std::uint32_t dim9343JoeKuoD6Init[]   =   { 1, 3, 7, 5, 7, 59, 109, 159, 121, 377, 1851, 3983, 5421, 7633, 7321, 14869, 54633, 0 };
            const std::uint32_t dim9344JoeKuoD6Init[]   =   { 1, 1, 3, 15, 21, 51, 35, 243, 397, 411, 1107, 3689, 7913, 14715, 26349, 23361, 90665, 0 };
            const std::uint32_t dim9345JoeKuoD6Init[]   =   { 1, 1, 1, 3, 5, 11, 77, 205, 187, 981, 1969, 1749, 6295, 8267, 16073, 54451, 103603, 0 };
            const std::uint32_t dim9346JoeKuoD6Init[]   =   { 1, 3, 3, 9, 11, 13, 113, 83, 243, 1021, 2003, 2277, 6457, 10535, 13461, 52741, 9385, 0 };
            const std::uint32_t dim9347JoeKuoD6Init[]   =   { 1, 3, 3, 11, 19, 9, 103, 13, 219, 269, 1805, 2689, 5219, 11497, 4909, 57985, 40141, 0 };
            const std::uint32_t dim9348JoeKuoD6Init[]   =   { 1, 1, 1, 1, 29, 25, 15, 217, 69, 567, 839, 1515, 3627, 9837, 21433, 37177, 10487, 0 };
            const std::uint32_t dim9349JoeKuoD6Init[]   =   { 1, 1, 7, 15, 15, 23, 119, 217, 277, 447, 551, 825, 7571, 3083, 16573, 1189, 64959, 0 };
            const std::uint32_t dim9350JoeKuoD6Init[]   =   { 1, 1, 3, 11, 9, 13, 63, 77, 313, 195, 941, 1621, 165, 8905, 20265, 53761, 25091, 0 };
            const std::uint32_t dim9351JoeKuoD6Init[]   =   { 1, 3, 3, 9, 17, 5, 9, 183, 175, 1015, 253, 233, 2883, 15587, 27175, 38517, 22707, 0 };
            const std::uint32_t dim9352JoeKuoD6Init[]   =   { 1, 3, 3, 11, 23, 63, 83, 17, 49, 671, 749, 3249, 7821, 7189, 26735, 28995, 101737, 0 };
            const std::uint32_t dim9353JoeKuoD6Init[]   =   { 1, 1, 7, 5, 25, 15, 97, 247, 161, 585, 1307, 3803, 1105, 9093, 23523, 1383, 65671, 0 };
            const std::uint32_t dim9354JoeKuoD6Init[]   =   { 1, 1, 3, 15, 29, 51, 65, 237, 349, 709, 799, 1425, 6267, 6283, 4773, 18123, 74833, 0 };
            const std::uint32_t dim9355JoeKuoD6Init[]   =   { 1, 1, 5, 5, 11, 13, 9, 251, 373, 189, 467, 945, 7279, 11349, 10917, 6581, 83967, 0 };
            const std::uint32_t dim9356JoeKuoD6Init[]   =   { 1, 1, 7, 15, 23, 27, 1, 197, 41, 325, 757, 1229, 6295, 345, 26147, 40135, 123063, 0 };
            const std::uint32_t dim9357JoeKuoD6Init[]   =   { 1, 1, 7, 9, 23, 9, 93, 225, 191, 837, 103, 3367, 5411, 8289, 7057, 55391, 10669, 0 };
            const std::uint32_t dim9358JoeKuoD6Init[]   =   { 1, 1, 5, 15, 21, 17, 49, 221, 487, 23, 1943, 1563, 6157, 4035, 27769, 14933, 56913, 0 };
            const std::uint32_t dim9359JoeKuoD6Init[]   =   { 1, 1, 5, 13, 13, 43, 67, 245, 457, 365, 1115, 2205, 6229, 4173, 25167, 56333, 55605, 0 };
            const std::uint32_t dim9360JoeKuoD6Init[]   =   { 1, 1, 5, 11, 15, 59, 109, 83, 17, 913, 497, 1299, 5221, 321, 32139, 13717, 94311, 0 };
            const std::uint32_t dim9361JoeKuoD6Init[]   =   { 1, 3, 3, 3, 31, 11, 5, 203, 3, 843, 2039, 25, 6211, 14927, 6015, 46269, 90369, 0 };
            const std::uint32_t dim9362JoeKuoD6Init[]   =   { 1, 1, 3, 9, 21, 51, 91, 203, 149, 147, 197, 1771, 2921, 6609, 2343, 35249, 12963, 0 };
            const std::uint32_t dim9363JoeKuoD6Init[]   =   { 1, 3, 1, 7, 17, 43, 91, 229, 107, 521, 737, 2355, 5855, 6707, 21217, 47041, 81833, 0 };
            const std::uint32_t dim9364JoeKuoD6Init[]   =   { 1, 3, 3, 7, 7, 31, 97, 135, 503, 665, 1799, 2937, 6867, 4125, 7375, 34401, 18111, 0 };
            const std::uint32_t dim9365JoeKuoD6Init[]   =   { 1, 1, 7, 1, 11, 29, 89, 185, 495, 633, 507, 3727, 5999, 5871, 5911, 24877, 10259, 0 };
            const std::uint32_t dim9366JoeKuoD6Init[]   =   { 1, 1, 1, 13, 25, 3, 25, 65, 91, 411, 147, 3699, 7003, 3017, 25635, 56619, 101491, 0 };
            const std::uint32_t dim9367JoeKuoD6Init[]   =   { 1, 3, 5, 7, 31, 1, 63, 255, 115, 179, 87, 735, 1649, 4767, 31093, 60149, 49829, 0 };
            const std::uint32_t dim9368JoeKuoD6Init[]   =   { 1, 1, 3, 1, 21, 63, 67, 85, 399, 279, 1963, 1759, 4679, 15423, 11533, 54387, 36563, 0 };
            const std::uint32_t dim9369JoeKuoD6Init[]   =   { 1, 3, 5, 3, 31, 53, 73, 73, 481, 443, 1393, 2763, 1199, 5375, 8977, 5369, 114603, 0 };
            const std::uint32_t dim9370JoeKuoD6Init[]   =   { 1, 1, 1, 3, 29, 47, 73, 205, 469, 187, 815, 2787, 1431, 4705, 11455, 53643, 89269, 0 };
            const std::uint32_t dim9371JoeKuoD6Init[]   =   { 1, 3, 3, 9, 27, 57, 93, 55, 287, 539, 1259, 3279, 1563, 11399, 22975, 27077, 41031, 0 };
            const std::uint32_t dim9372JoeKuoD6Init[]   =   { 1, 1, 3, 15, 7, 27, 67, 25, 169, 263, 621, 1921, 509, 11715, 15363, 27447, 75535, 0 };
            const std::uint32_t dim9373JoeKuoD6Init[]   =   { 1, 1, 1, 9, 29, 63, 31, 99, 321, 361, 1693, 763, 5593, 10815, 741, 31257, 70843, 0 };
            const std::uint32_t dim9374JoeKuoD6Init[]   =   { 1, 1, 1, 9, 1, 17, 73, 141, 401, 549, 415, 1289, 1697, 1903, 8919, 59563, 60017, 0 };
            const std::uint32_t dim9375JoeKuoD6Init[]   =   { 1, 3, 7, 3, 5, 51, 127, 221, 9, 929, 153, 1045, 6587, 13653, 5343, 14043, 116125, 0 };
            const std::uint32_t dim9376JoeKuoD6Init[]   =   { 1, 3, 3, 13, 13, 17, 29, 93, 465, 59, 1207, 3121, 6331, 8647, 5047, 41869, 51969, 0 };
            const std::uint32_t dim9377JoeKuoD6Init[]   =   { 1, 1, 1, 15, 23, 29, 47, 149, 119, 855, 367, 1419, 7739, 1141, 19787, 38185, 84403, 0 };
            const std::uint32_t dim9378JoeKuoD6Init[]   =   { 1, 3, 1, 9, 29, 63, 5, 63, 435, 401, 1023, 1981, 6819, 7547, 30065, 33833, 7471, 0 };
            const std::uint32_t dim9379JoeKuoD6Init[]   =   { 1, 3, 1, 15, 1, 47, 35, 161, 243, 225, 935, 2179, 7737, 7841, 28523, 11505, 103741, 0 };
            const std::uint32_t dim9380JoeKuoD6Init[]   =   { 1, 1, 7, 3, 7, 57, 73, 55, 101, 905, 1705, 4057, 3781, 8213, 18997, 17185, 33265, 0 };
            const std::uint32_t dim9381JoeKuoD6Init[]   =   { 1, 1, 5, 1, 7, 57, 31, 77, 323, 395, 927, 1969, 6973, 9013, 30789, 757, 84075, 0 };
            const std::uint32_t dim9382JoeKuoD6Init[]   =   { 1, 1, 3, 7, 15, 53, 51, 205, 401, 679, 1295, 1955, 7739, 11423, 23207, 55449, 60419, 0 };
            const std::uint32_t dim9383JoeKuoD6Init[]   =   { 1, 3, 5, 11, 23, 21, 67, 141, 157, 767, 219, 3607, 1847, 11051, 31499, 8461, 106353, 0 };
            const std::uint32_t dim9384JoeKuoD6Init[]   =   { 1, 1, 3, 9, 17, 19, 123, 169, 1, 31, 1019, 1823, 6043, 1895, 17293, 62079, 16945, 0 };
            const std::uint32_t dim9385JoeKuoD6Init[]   =   { 1, 3, 5, 9, 3, 15, 49, 27, 183, 293, 989, 2161, 1845, 1103, 20149, 11121, 31935, 0 };
            const std::uint32_t dim9386JoeKuoD6Init[]   =   { 1, 3, 1, 3, 17, 39, 103, 45, 491, 91, 413, 487, 1381, 5457, 22503, 40477, 94297, 0 };
            const std::uint32_t dim9387JoeKuoD6Init[]   =   { 1, 1, 3, 7, 29, 11, 87, 79, 349, 437, 945, 3753, 6691, 4373, 24875, 54397, 33697, 0 };
            const std::uint32_t dim9388JoeKuoD6Init[]   =   { 1, 1, 7, 1, 9, 31, 105, 121, 97, 947, 129, 1909, 2371, 5493, 29523, 52685, 24325, 0 };
            const std::uint32_t dim9389JoeKuoD6Init[]   =   { 1, 1, 5, 9, 19, 21, 63, 115, 511, 525, 49, 1879, 6075, 8181, 10135, 56785, 53309, 0 };
            const std::uint32_t dim9390JoeKuoD6Init[]   =   { 1, 1, 5, 15, 3, 55, 75, 135, 451, 697, 1407, 2765, 2443, 11589, 24863, 47187, 98477, 0 };
            const std::uint32_t dim9391JoeKuoD6Init[]   =   { 1, 1, 1, 13, 27, 37, 77, 157, 121, 603, 491, 2201, 619, 9157, 32511, 19843, 49919, 0 };
            const std::uint32_t dim9392JoeKuoD6Init[]   =   { 1, 1, 3, 1, 23, 17, 23, 115, 119, 349, 987, 2587, 1847, 12099, 31955, 31685, 1989, 0 };
            const std::uint32_t dim9393JoeKuoD6Init[]   =   { 1, 3, 7, 7, 5, 47, 63, 209, 69, 921, 1041, 1391, 7485, 11121, 30993, 5691, 74551, 0 };
            const std::uint32_t dim9394JoeKuoD6Init[]   =   { 1, 3, 1, 3, 23, 61, 55, 253, 355, 299, 971, 279, 3543, 10073, 5199, 50539, 88303, 0 };
            const std::uint32_t dim9395JoeKuoD6Init[]   =   { 1, 1, 1, 11, 13, 19, 7, 255, 189, 267, 2021, 93, 219, 10537, 28627, 58141, 53675, 0 };
            const std::uint32_t dim9396JoeKuoD6Init[]   =   { 1, 3, 3, 7, 27, 61, 83, 95, 163, 777, 1533, 2485, 7211, 6979, 4013, 20797, 91411, 0 };
            const std::uint32_t dim9397JoeKuoD6Init[]   =   { 1, 1, 7, 13, 15, 37, 5, 109, 133, 225, 59, 3855, 3351, 659, 24321, 63531, 15573, 0 };
            const std::uint32_t dim9398JoeKuoD6Init[]   =   { 1, 1, 5, 1, 7, 55, 59, 213, 45, 77, 2003, 2921, 1105, 11089, 17197, 45459, 67681, 0 };
            const std::uint32_t dim9399JoeKuoD6Init[]   =   { 1, 1, 1, 5, 13, 21, 107, 245, 505, 409, 1453, 1201, 6945, 2103, 7377, 59413, 8785, 0 };
            const std::uint32_t dim9400JoeKuoD6Init[]   =   { 1, 1, 1, 13, 5, 37, 73, 55, 39, 219, 225, 3877, 6583, 3105, 25355, 14839, 23435, 0 };
            const std::uint32_t dim9401JoeKuoD6Init[]   =   { 1, 1, 7, 1, 21, 35, 87, 227, 487, 767, 609, 1685, 2731, 10135, 381, 24021, 122137, 0 };
            const std::uint32_t dim9402JoeKuoD6Init[]   =   { 1, 1, 1, 3, 29, 13, 19, 255, 355, 505, 1757, 3537, 3029, 11403, 22685, 61169, 397, 0 };
            const std::uint32_t dim9403JoeKuoD6Init[]   =   { 1, 1, 7, 1, 29, 43, 11, 207, 83, 97, 435, 1453, 4709, 4193, 18517, 47203, 3255, 0 };
            const std::uint32_t dim9404JoeKuoD6Init[]   =   { 1, 1, 1, 1, 21, 49, 39, 163, 459, 849, 561, 1207, 4109, 1435, 17519, 14839, 1331, 0 };
            const std::uint32_t dim9405JoeKuoD6Init[]   =   { 1, 1, 3, 11, 27, 35, 65, 219, 135, 559, 1111, 2959, 7835, 5165, 26641, 22765, 121829, 0 };
            const std::uint32_t dim9406JoeKuoD6Init[]   =   { 1, 3, 5, 3, 23, 31, 57, 149, 431, 451, 189, 1771, 5877, 3503, 7531, 46485, 129031, 0 };
            const std::uint32_t dim9407JoeKuoD6Init[]   =   { 1, 1, 3, 11, 1, 13, 47, 17, 331, 1003, 215, 2797, 689, 6289, 12719, 37139, 35827, 0 };
            const std::uint32_t dim9408JoeKuoD6Init[]   =   { 1, 3, 5, 9, 19, 13, 11, 29, 275, 165, 783, 313, 2153, 6009, 2247, 5699, 128753, 0 };
            const std::uint32_t dim9409JoeKuoD6Init[]   =   { 1, 1, 7, 13, 5, 43, 51, 75, 411, 743, 335, 217, 559, 15389, 6567, 41193, 127443, 0 };
            const std::uint32_t dim9410JoeKuoD6Init[]   =   { 1, 3, 5, 15, 5, 63, 7, 145, 445, 835, 825, 35, 5951, 5121, 16365, 36789, 2941, 0 };
            const std::uint32_t dim9411JoeKuoD6Init[]   =   { 1, 3, 5, 5, 29, 1, 61, 19, 427, 245, 445, 3505, 3647, 8817, 8031, 64577, 60745, 0 };
            const std::uint32_t dim9412JoeKuoD6Init[]   =   { 1, 1, 3, 9, 29, 9, 35, 225, 55, 535, 1537, 831, 6483, 16123, 26079, 32809, 62227, 0 };
            const std::uint32_t dim9413JoeKuoD6Init[]   =   { 1, 3, 7, 7, 25, 33, 15, 61, 343, 749, 1963, 2763, 3171, 6755, 6529, 49449, 88903, 0 };
            const std::uint32_t dim9414JoeKuoD6Init[]   =   { 1, 1, 7, 13, 17, 35, 91, 119, 87, 1023, 1101, 1785, 2005, 15947, 21679, 63179, 3389, 0 };
            const std::uint32_t dim9415JoeKuoD6Init[]   =   { 1, 3, 1, 1, 1, 1, 123, 195, 315, 681, 153, 1621, 5097, 3669, 20505, 39305, 127065, 0 };
            const std::uint32_t dim9416JoeKuoD6Init[]   =   { 1, 1, 5, 11, 1, 17, 73, 251, 185, 59, 1723, 2321, 2103, 6331, 29571, 63811, 66651, 0 };
            const std::uint32_t dim9417JoeKuoD6Init[]   =   { 1, 1, 7, 13, 15, 19, 111, 91, 211, 85, 711, 2197, 3107, 2717, 16725, 52995, 65791, 0 };
            const std::uint32_t dim9418JoeKuoD6Init[]   =   { 1, 3, 3, 9, 21, 41, 53, 145, 459, 155, 93, 2833, 6747, 737, 30625, 40581, 65825, 0 };
            const std::uint32_t dim9419JoeKuoD6Init[]   =   { 1, 3, 3, 3, 1, 45, 119, 81, 185, 431, 1221, 3043, 7277, 10537, 12355, 42261, 126117, 0 };
            const std::uint32_t dim9420JoeKuoD6Init[]   =   { 1, 3, 7, 7, 11, 47, 37, 41, 123, 643, 707, 2963, 6183, 15527, 10951, 24031, 38187, 0 };
            const std::uint32_t dim9421JoeKuoD6Init[]   =   { 1, 3, 1, 7, 13, 57, 1, 149, 117, 627, 1999, 2805, 4857, 12805, 31453, 25699, 109447, 0 };
            const std::uint32_t dim9422JoeKuoD6Init[]   =   { 1, 3, 5, 3, 9, 37, 83, 221, 77, 573, 661, 465, 1279, 7355, 24061, 36151, 96595, 0 };
            const std::uint32_t dim9423JoeKuoD6Init[]   =   { 1, 1, 7, 15, 29, 31, 125, 205, 449, 563, 1263, 3427, 8013, 14025, 15235, 11833, 25601, 0 };
            const std::uint32_t dim9424JoeKuoD6Init[]   =   { 1, 3, 7, 11, 31, 35, 99, 193, 163, 527, 1455, 395, 4853, 2561, 11909, 57311, 101007, 0 };
            const std::uint32_t dim9425JoeKuoD6Init[]   =   { 1, 1, 5, 3, 17, 39, 99, 173, 497, 245, 1671, 3457, 83, 11959, 2963, 3401, 102259, 0 };
            const std::uint32_t dim9426JoeKuoD6Init[]   =   { 1, 1, 1, 5, 25, 41, 119, 81, 301, 797, 661, 2543, 1195, 2111, 1785, 41533, 51947, 0 };
            const std::uint32_t dim9427JoeKuoD6Init[]   =   { 1, 3, 3, 13, 5, 59, 61, 153, 213, 541, 1849, 249, 3897, 3877, 17095, 6857, 76781, 0 };
            const std::uint32_t dim9428JoeKuoD6Init[]   =   { 1, 3, 7, 1, 19, 13, 57, 47, 359, 165, 1085, 2263, 3261, 12825, 17405, 25853, 20731, 0 };
            const std::uint32_t dim9429JoeKuoD6Init[]   =   { 1, 1, 1, 7, 7, 43, 7, 65, 51, 503, 173, 1023, 283, 14809, 1183, 33497, 110683, 0 };
            const std::uint32_t dim9430JoeKuoD6Init[]   =   { 1, 3, 5, 11, 19, 51, 29, 157, 159, 191, 1293, 2951, 6569, 12433, 14587, 30631, 30485, 0 };
            const std::uint32_t dim9431JoeKuoD6Init[]   =   { 1, 3, 7, 5, 1, 27, 25, 221, 255, 471, 779, 3991, 6985, 1803, 28451, 33403, 5567, 0 };
            const std::uint32_t dim9432JoeKuoD6Init[]   =   { 1, 1, 5, 5, 7, 29, 55, 241, 457, 863, 1715, 3393, 4127, 13985, 6313, 13683, 114837, 0 };
            const std::uint32_t dim9433JoeKuoD6Init[]   =   { 1, 3, 5, 5, 11, 27, 55, 109, 247, 199, 1593, 2881, 307, 97, 24751, 35921, 121931, 0 };
            const std::uint32_t dim9434JoeKuoD6Init[]   =   { 1, 3, 1, 13, 3, 59, 17, 161, 47, 467, 1019, 3629, 3017, 15645, 3983, 32393, 79213, 0 };
            const std::uint32_t dim9435JoeKuoD6Init[]   =   { 1, 1, 3, 11, 19, 57, 67, 199, 319, 107, 2043, 2045, 4025, 5733, 29979, 37721, 117031, 0 };
            const std::uint32_t dim9436JoeKuoD6Init[]   =   { 1, 3, 7, 11, 9, 23, 31, 81, 177, 801, 1177, 3451, 7777, 15351, 7579, 39033, 23847, 0 };
            const std::uint32_t dim9437JoeKuoD6Init[]   =   { 1, 1, 3, 5, 17, 61, 63, 7, 371, 905, 1147, 1383, 4075, 6721, 17503, 32015, 112547, 0 };
            const std::uint32_t dim9438JoeKuoD6Init[]   =   { 1, 1, 3, 13, 13, 25, 69, 159, 49, 133, 227, 2155, 1603, 10077, 3429, 39131, 18949, 0 };
            const std::uint32_t dim9439JoeKuoD6Init[]   =   { 1, 3, 5, 3, 29, 5, 115, 93, 243, 791, 1113, 2841, 4733, 3041, 31733, 28539, 84567, 0 };
            const std::uint32_t dim9440JoeKuoD6Init[]   =   { 1, 3, 3, 7, 21, 9, 5, 95, 489, 517, 1453, 2697, 7951, 12369, 19571, 29811, 51805, 0 };
            const std::uint32_t dim9441JoeKuoD6Init[]   =   { 1, 1, 5, 9, 1, 29, 97, 191, 73, 357, 745, 2787, 7815, 4565, 19761, 33729, 86849, 0 };
            const std::uint32_t dim9442JoeKuoD6Init[]   =   { 1, 3, 5, 13, 3, 5, 35, 79, 387, 813, 1673, 3187, 337, 5539, 6761, 46903, 122967, 0 };
            const std::uint32_t dim9443JoeKuoD6Init[]   =   { 1, 1, 7, 11, 1, 15, 125, 175, 255, 35, 145, 2391, 887, 10505, 11587, 53941, 5089, 0 };
            const std::uint32_t dim9444JoeKuoD6Init[]   =   { 1, 1, 7, 13, 9, 13, 15, 215, 361, 227, 1665, 3345, 3615, 14031, 16281, 4457, 52037, 0 };
            const std::uint32_t dim9445JoeKuoD6Init[]   =   { 1, 3, 5, 9, 31, 21, 3, 189, 211, 855, 1781, 2097, 1345, 6763, 27651, 54137, 52689, 0 };
            const std::uint32_t dim9446JoeKuoD6Init[]   =   { 1, 3, 1, 5, 29, 9, 99, 183, 183, 205, 149, 53, 7179, 3387, 9603, 4281, 47145, 0 };
            const std::uint32_t dim9447JoeKuoD6Init[]   =   { 1, 3, 1, 11, 13, 35, 97, 21, 29, 877, 191, 1621, 2501, 4283, 1707, 48957, 129029, 0 };
            const std::uint32_t dim9448JoeKuoD6Init[]   =   { 1, 3, 1, 9, 5, 19, 57, 219, 105, 467, 1179, 3155, 7743, 4835, 14845, 35671, 47655, 0 };
            const std::uint32_t dim9449JoeKuoD6Init[]   =   { 1, 3, 1, 7, 27, 41, 27, 185, 271, 611, 1173, 2875, 529, 11619, 20231, 18741, 41799, 0 };
            const std::uint32_t dim9450JoeKuoD6Init[]   =   { 1, 3, 7, 13, 9, 3, 35, 71, 467, 689, 1797, 319, 6657, 13193, 15861, 7567, 12891, 0 };
            const std::uint32_t dim9451JoeKuoD6Init[]   =   { 1, 1, 7, 13, 19, 57, 25, 141, 195, 995, 859, 811, 4685, 6711, 8963, 49657, 54751, 0 };
            const std::uint32_t dim9452JoeKuoD6Init[]   =   { 1, 1, 1, 11, 27, 25, 9, 91, 97, 251, 757, 2783, 5447, 3617, 26801, 32501, 55245, 0 };
            const std::uint32_t dim9453JoeKuoD6Init[]   =   { 1, 3, 7, 1, 5, 1, 103, 129, 127, 593, 857, 3957, 3665, 10279, 26211, 2095, 15869, 0 };
            const std::uint32_t dim9454JoeKuoD6Init[]   =   { 1, 1, 7, 1, 25, 49, 3, 139, 25, 545, 615, 1353, 4103, 1099, 21729, 45383, 110611, 0 };
            const std::uint32_t dim9455JoeKuoD6Init[]   =   { 1, 3, 5, 3, 7, 49, 83, 41, 209, 357, 939, 849, 5851, 3945, 831, 8131, 105897, 0 };
            const std::uint32_t dim9456JoeKuoD6Init[]   =   { 1, 1, 1, 3, 27, 19, 123, 71, 195, 1019, 1021, 1287, 5665, 5277, 8647, 27033, 89539, 0 };
            const std::uint32_t dim9457JoeKuoD6Init[]   =   { 1, 1, 1, 9, 27, 51, 49, 159, 401, 1013, 763, 653, 1449, 12441, 21191, 28871, 106181, 0 };
            const std::uint32_t dim9458JoeKuoD6Init[]   =   { 1, 1, 5, 7, 31, 7, 105, 137, 331, 367, 1305, 2761, 863, 3915, 12633, 32251, 82867, 0 };
            const std::uint32_t dim9459JoeKuoD6Init[]   =   { 1, 3, 7, 11, 9, 47, 35, 57, 137, 269, 443, 79, 11, 11817, 28995, 46681, 104263, 0 };
            const std::uint32_t dim9460JoeKuoD6Init[]   =   { 1, 3, 1, 5, 3, 25, 89, 179, 183, 835, 367, 2215, 295, 5365, 1899, 10785, 88979, 0 };
            const std::uint32_t dim9461JoeKuoD6Init[]   =   { 1, 3, 7, 13, 3, 5, 93, 43, 409, 363, 267, 2077, 3745, 445, 25957, 34103, 29475, 0 };
            const std::uint32_t dim9462JoeKuoD6Init[]   =   { 1, 1, 1, 7, 27, 21, 121, 29, 171, 783, 553, 265, 6835, 3929, 18127, 33463, 70999, 0 };
            const std::uint32_t dim9463JoeKuoD6Init[]   =   { 1, 3, 3, 15, 15, 55, 13, 1, 297, 935, 1307, 1779, 2239, 15471, 32453, 30649, 45973, 0 };
            const std::uint32_t dim9464JoeKuoD6Init[]   =   { 1, 3, 7, 5, 25, 41, 3, 171, 347, 607, 1873, 1087, 2433, 8377, 7959, 19941, 117319, 0 };
            const std::uint32_t dim9465JoeKuoD6Init[]   =   { 1, 1, 1, 3, 5, 47, 107, 69, 431, 63, 325, 1241, 3487, 11249, 28559, 30001, 93789, 0 };
            const std::uint32_t dim9466JoeKuoD6Init[]   =   { 1, 1, 1, 5, 15, 17, 9, 145, 335, 169, 1099, 3637, 5397, 6711, 16095, 27053, 124247, 0 };
            const std::uint32_t dim9467JoeKuoD6Init[]   =   { 1, 3, 3, 5, 3, 9, 65, 97, 421, 951, 2003, 2837, 7095, 15685, 5147, 56801, 98679, 0 };
            const std::uint32_t dim9468JoeKuoD6Init[]   =   { 1, 3, 7, 15, 1, 33, 115, 45, 215, 253, 361, 555, 787, 15483, 25531, 53273, 8933, 0 };
            const std::uint32_t dim9469JoeKuoD6Init[]   =   { 1, 3, 1, 9, 3, 63, 47, 205, 457, 977, 991, 3189, 1369, 14899, 10937, 56999, 11525, 0 };
            const std::uint32_t dim9470JoeKuoD6Init[]   =   { 1, 1, 7, 5, 11, 61, 53, 55, 231, 357, 1695, 2489, 2355, 7583, 14097, 50039, 96595, 0 };
            const std::uint32_t dim9471JoeKuoD6Init[]   =   { 1, 3, 7, 7, 3, 57, 115, 245, 259, 573, 1275, 2971, 1793, 13683, 8683, 51815, 26807, 0 };
            const std::uint32_t dim9472JoeKuoD6Init[]   =   { 1, 1, 5, 3, 17, 59, 55, 237, 491, 757, 1447, 2941, 2641, 14175, 4401, 4367, 36853, 0 };
            const std::uint32_t dim9473JoeKuoD6Init[]   =   { 1, 3, 1, 15, 3, 63, 67, 1, 403, 79, 1161, 2379, 3337, 14447, 5877, 40759, 12573, 0 };
            const std::uint32_t dim9474JoeKuoD6Init[]   =   { 1, 1, 7, 15, 17, 1, 91, 5, 173, 215, 1567, 1851, 3309, 9813, 21215, 19151, 96785, 0 };
            const std::uint32_t dim9475JoeKuoD6Init[]   =   { 1, 1, 1, 9, 31, 45, 123, 221, 397, 51, 1489, 3247, 923, 10423, 10461, 51231, 92909, 0 };
            const std::uint32_t dim9476JoeKuoD6Init[]   =   { 1, 1, 1, 13, 27, 17, 105, 163, 403, 193, 1487, 2421, 4415, 14303, 6419, 24105, 29997, 0 };
            const std::uint32_t dim9477JoeKuoD6Init[]   =   { 1, 1, 5, 13, 31, 55, 17, 125, 341, 219, 401, 1611, 891, 12909, 13949, 46245, 26769, 0 };
            const std::uint32_t dim9478JoeKuoD6Init[]   =   { 1, 3, 7, 3, 31, 41, 65, 207, 311, 643, 1617, 271, 3749, 14635, 26385, 55251, 50719, 0 };
            const std::uint32_t dim9479JoeKuoD6Init[]   =   { 1, 3, 3, 13, 7, 55, 69, 241, 413, 399, 137, 2255, 5395, 12625, 26583, 64603, 22571, 0 };
            const std::uint32_t dim9480JoeKuoD6Init[]   =   { 1, 3, 5, 3, 31, 15, 15, 161, 153, 445, 595, 273, 6631, 12845, 23331, 16963, 52099, 0 };
            const std::uint32_t dim9481JoeKuoD6Init[]   =   { 1, 3, 3, 1, 27, 39, 71, 41, 455, 841, 831, 1719, 3531, 5113, 29183, 1933, 42227, 0 };
            const std::uint32_t dim9482JoeKuoD6Init[]   =   { 1, 3, 7, 3, 1, 15, 31, 183, 429, 557, 1747, 1059, 2079, 16361, 29103, 43207, 921, 0 };
            const std::uint32_t dim9483JoeKuoD6Init[]   =   { 1, 3, 1, 1, 31, 39, 97, 73, 339, 405, 1423, 2215, 5435, 9205, 1889, 58249, 61517, 0 };
            const std::uint32_t dim9484JoeKuoD6Init[]   =   { 1, 3, 7, 1, 23, 59, 127, 245, 11, 627, 1555, 2497, 6427, 7205, 22675, 62847, 69691, 0 };
            const std::uint32_t dim9485JoeKuoD6Init[]   =   { 1, 1, 3, 5, 1, 13, 95, 9, 167, 481, 947, 3181, 8057, 5559, 7537, 33757, 72419, 0 };
            const std::uint32_t dim9486JoeKuoD6Init[]   =   { 1, 1, 7, 3, 15, 9, 105, 205, 287, 375, 115, 1731, 1063, 11551, 12077, 41013, 88853, 0 };
            const std::uint32_t dim9487JoeKuoD6Init[]   =   { 1, 3, 3, 9, 5, 63, 127, 33, 409, 279, 1379, 4069, 4091, 14703, 27435, 19525, 71261, 0 };
            const std::uint32_t dim9488JoeKuoD6Init[]   =   { 1, 3, 1, 13, 31, 31, 59, 205, 167, 131, 891, 1259, 6909, 211, 31517, 8085, 112065, 0 };
            const std::uint32_t dim9489JoeKuoD6Init[]   =   { 1, 1, 5, 11, 17, 25, 119, 77, 449, 569, 381, 825, 2459, 983, 2959, 51611, 90721, 0 };
            const std::uint32_t dim9490JoeKuoD6Init[]   =   { 1, 3, 1, 7, 17, 55, 91, 231, 133, 541, 499, 3609, 4237, 11627, 30007, 58911, 43443, 0 };
            const std::uint32_t dim9491JoeKuoD6Init[]   =   { 1, 3, 7, 7, 29, 5, 47, 187, 71, 695, 1389, 2855, 5815, 11605, 3643, 24961, 25793, 0 };
            const std::uint32_t dim9492JoeKuoD6Init[]   =   { 1, 3, 3, 5, 11, 31, 43, 31, 185, 1021, 795, 3585, 3981, 8627, 18117, 42351, 19513, 0 };
            const std::uint32_t dim9493JoeKuoD6Init[]   =   { 1, 1, 5, 13, 9, 3, 115, 45, 39, 577, 1847, 653, 2625, 9367, 27923, 35661, 113613, 0 };
            const std::uint32_t dim9494JoeKuoD6Init[]   =   { 1, 3, 7, 7, 17, 9, 69, 233, 367, 673, 11, 2215, 1177, 4501, 9693, 62013, 45647, 0 };
            const std::uint32_t dim9495JoeKuoD6Init[]   =   { 1, 3, 5, 7, 7, 53, 11, 227, 465, 843, 2017, 689, 6767, 10321, 25163, 56561, 6865, 0 };
            const std::uint32_t dim9496JoeKuoD6Init[]   =   { 1, 3, 3, 5, 13, 43, 119, 9, 185, 893, 133, 863, 7137, 6653, 7875, 23167, 13893, 0 };
            const std::uint32_t dim9497JoeKuoD6Init[]   =   { 1, 3, 5, 9, 1, 47, 17, 85, 273, 901, 493, 2411, 983, 15717, 25151, 21323, 57939, 0 };
            const std::uint32_t dim9498JoeKuoD6Init[]   =   { 1, 1, 7, 5, 19, 17, 49, 37, 425, 443, 781, 2593, 4929, 12313, 12727, 42285, 88451, 0 };
            const std::uint32_t dim9499JoeKuoD6Init[]   =   { 1, 3, 3, 11, 9, 53, 17, 67, 237, 463, 1509, 2153, 3715, 7909, 21151, 64517, 87695, 0 };
            const std::uint32_t dim9500JoeKuoD6Init[]   =   { 1, 3, 7, 1, 29, 39, 25, 83, 413, 1005, 2011, 3933, 2911, 7041, 10537, 23135, 22671, 0 };
            const std::uint32_t dim9501JoeKuoD6Init[]   =   { 1, 1, 3, 9, 23, 61, 117, 33, 431, 181, 1819, 683, 1809, 1723, 27041, 29113, 99347, 0 };
            const std::uint32_t dim9502JoeKuoD6Init[]   =   { 1, 1, 5, 11, 11, 7, 101, 181, 51, 857, 923, 3495, 7123, 7775, 30081, 48513, 116137, 0 };
            const std::uint32_t dim9503JoeKuoD6Init[]   =   { 1, 1, 3, 11, 15, 31, 97, 127, 365, 799, 715, 2101, 6081, 11607, 1055, 35027, 62967, 0 };
            const std::uint32_t dim9504JoeKuoD6Init[]   =   { 1, 3, 5, 7, 3, 31, 109, 247, 225, 221, 1093, 2633, 1847, 7427, 8767, 16581, 32145, 0 };
            const std::uint32_t dim9505JoeKuoD6Init[]   =   { 1, 3, 1, 7, 15, 23, 43, 109, 327, 417, 1895, 2333, 6265, 6599, 6623, 47375, 92731, 0 };
            const std::uint32_t dim9506JoeKuoD6Init[]   =   { 1, 3, 7, 1, 29, 29, 45, 217, 163, 941, 1327, 3685, 5481, 15783, 26281, 60339, 34277, 0 };
            const std::uint32_t dim9507JoeKuoD6Init[]   =   { 1, 1, 7, 11, 1, 7, 119, 201, 29, 193, 1805, 1395, 267, 2011, 637, 26765, 48883, 0 };
            const std::uint32_t dim9508JoeKuoD6Init[]   =   { 1, 1, 3, 7, 11, 63, 41, 89, 365, 729, 25, 3185, 2143, 1737, 29693, 7443, 78079, 0 };
            const std::uint32_t dim9509JoeKuoD6Init[]   =   { 1, 3, 1, 13, 25, 27, 63, 233, 79, 1007, 1357, 679, 7581, 8333, 2469, 31787, 128531, 0 };
            const std::uint32_t dim9510JoeKuoD6Init[]   =   { 1, 3, 1, 3, 23, 39, 53, 99, 219, 475, 931, 507, 3615, 10613, 14663, 1151, 123459, 0 };
            const std::uint32_t dim9511JoeKuoD6Init[]   =   { 1, 1, 1, 1, 13, 15, 67, 45, 393, 791, 415, 2731, 1151, 8935, 28983, 7239, 106247, 0 };
            const std::uint32_t dim9512JoeKuoD6Init[]   =   { 1, 3, 7, 7, 11, 35, 95, 153, 421, 193, 1997, 2587, 3183, 9229, 17663, 28221, 6759, 0 };
            const std::uint32_t dim9513JoeKuoD6Init[]   =   { 1, 3, 1, 7, 5, 5, 123, 55, 509, 973, 261, 463, 2723, 15225, 1925, 62283, 86329, 0 };
            const std::uint32_t dim9514JoeKuoD6Init[]   =   { 1, 1, 3, 13, 5, 47, 123, 239, 273, 407, 1725, 717, 1229, 1387, 11743, 13739, 104503, 0 };
            const std::uint32_t dim9515JoeKuoD6Init[]   =   { 1, 3, 3, 13, 23, 35, 43, 113, 299, 847, 1903, 3445, 3395, 641, 11271, 61517, 40747, 0 };
            const std::uint32_t dim9516JoeKuoD6Init[]   =   { 1, 3, 1, 15, 17, 49, 97, 9, 335, 731, 151, 167, 8129, 11845, 18285, 20113, 122397, 0 };
            const std::uint32_t dim9517JoeKuoD6Init[]   =   { 1, 1, 5, 11, 11, 63, 3, 153, 345, 511, 1939, 1815, 7231, 10555, 14293, 50753, 14681, 0 };
            const std::uint32_t dim9518JoeKuoD6Init[]   =   { 1, 3, 7, 5, 21, 31, 127, 223, 241, 783, 887, 3519, 4743, 3541, 4143, 57461, 27791, 0 };
            const std::uint32_t dim9519JoeKuoD6Init[]   =   { 1, 1, 5, 7, 13, 15, 83, 225, 201, 979, 145, 769, 1491, 12155, 21307, 64877, 113277, 0 };
            const std::uint32_t dim9520JoeKuoD6Init[]   =   { 1, 1, 7, 1, 27, 25, 105, 69, 239, 323, 1059, 573, 4913, 14215, 27007, 42351, 66315, 0 };
            const std::uint32_t dim9521JoeKuoD6Init[]   =   { 1, 1, 3, 11, 21, 33, 93, 23, 363, 633, 935, 637, 6171, 12695, 14077, 17505, 69681, 0 };
            const std::uint32_t dim9522JoeKuoD6Init[]   =   { 1, 3, 1, 5, 15, 11, 93, 211, 175, 377, 33, 1403, 5097, 1503, 8483, 2881, 85877, 0 };
            const std::uint32_t dim9523JoeKuoD6Init[]   =   { 1, 1, 5, 3, 5, 51, 5, 255, 429, 661, 625, 3015, 4813, 3573, 22917, 45967, 70559, 0 };
            const std::uint32_t dim9524JoeKuoD6Init[]   =   { 1, 1, 7, 3, 11, 41, 3, 197, 181, 897, 767, 1385, 7395, 15543, 4655, 40309, 73169, 0 };
            const std::uint32_t dim9525JoeKuoD6Init[]   =   { 1, 1, 5, 9, 15, 35, 71, 119, 509, 817, 1169, 75, 1337, 2959, 611, 38243, 46987, 0 };
            const std::uint32_t dim9526JoeKuoD6Init[]   =   { 1, 1, 1, 9, 1, 7, 43, 65, 479, 625, 1685, 1309, 5619, 14163, 13633, 18169, 8311, 0 };
            const std::uint32_t dim9527JoeKuoD6Init[]   =   { 1, 3, 5, 9, 19, 39, 95, 105, 273, 1023, 79, 229, 6895, 2931, 5717, 27911, 22139, 0 };
            const std::uint32_t dim9528JoeKuoD6Init[]   =   { 1, 3, 5, 7, 1, 55, 15, 15, 297, 731, 2029, 2789, 11, 1333, 26571, 62595, 15131, 0 };
            const std::uint32_t dim9529JoeKuoD6Init[]   =   { 1, 1, 5, 7, 29, 35, 3, 125, 381, 709, 2047, 2395, 6315, 2301, 7175, 19857, 75085, 0 };
            const std::uint32_t dim9530JoeKuoD6Init[]   =   { 1, 1, 5, 15, 23, 45, 95, 117, 49, 635, 1525, 1105, 7335, 4653, 18159, 29729, 62627, 0 };
            const std::uint32_t dim9531JoeKuoD6Init[]   =   { 1, 3, 3, 11, 29, 19, 29, 169, 141, 243, 1765, 1829, 4555, 16299, 3053, 58933, 44605, 0 };
            const std::uint32_t dim9532JoeKuoD6Init[]   =   { 1, 1, 3, 15, 5, 45, 35, 213, 385, 993, 1521, 9, 3561, 10497, 12601, 38163, 86501, 0 };
            const std::uint32_t dim9533JoeKuoD6Init[]   =   { 1, 3, 3, 13, 9, 23, 109, 95, 491, 1003, 473, 3325, 6577, 14617, 17765, 33391, 82927, 0 };
            const std::uint32_t dim9534JoeKuoD6Init[]   =   { 1, 3, 3, 11, 25, 31, 93, 111, 231, 71, 1233, 3581, 6789, 4569, 16741, 61967, 32249, 0 };
            const std::uint32_t dim9535JoeKuoD6Init[]   =   { 1, 3, 3, 15, 15, 63, 39, 247, 79, 923, 327, 2639, 2013, 12325, 18133, 60623, 2215, 0 };
            const std::uint32_t dim9536JoeKuoD6Init[]   =   { 1, 3, 5, 1, 5, 49, 121, 53, 283, 529, 37, 3233, 6285, 12447, 4355, 9343, 45631, 0 };
            const std::uint32_t dim9537JoeKuoD6Init[]   =   { 1, 1, 7, 11, 11, 11, 111, 139, 429, 279, 1019, 2139, 2033, 6809, 8847, 22535, 107005, 0 };
            const std::uint32_t dim9538JoeKuoD6Init[]   =   { 1, 3, 5, 1, 1, 21, 35, 97, 167, 57, 491, 511, 4065, 11699, 16851, 6847, 40929, 0 };
            const std::uint32_t dim9539JoeKuoD6Init[]   =   { 1, 3, 1, 15, 3, 55, 113, 33, 255, 537, 835, 1867, 3927, 839, 955, 29079, 93727, 0 };
            const std::uint32_t dim9540JoeKuoD6Init[]   =   { 1, 1, 7, 3, 5, 7, 35, 111, 165, 885, 115, 3051, 4541, 1701, 22827, 361, 91843, 0 };
            const std::uint32_t dim9541JoeKuoD6Init[]   =   { 1, 1, 7, 11, 7, 55, 81, 43, 237, 725, 1761, 1599, 639, 14189, 31241, 52827, 107943, 0 };
            const std::uint32_t dim9542JoeKuoD6Init[]   =   { 1, 3, 1, 3, 29, 35, 67, 119, 369, 877, 1861, 123, 8121, 13861, 31155, 60245, 79799, 0 };
            const std::uint32_t dim9543JoeKuoD6Init[]   =   { 1, 1, 3, 13, 7, 49, 63, 19, 253, 723, 639, 1677, 291, 13697, 22231, 46893, 90069, 0 };
            const std::uint32_t dim9544JoeKuoD6Init[]   =   { 1, 3, 5, 1, 7, 57, 29, 233, 35, 715, 515, 3221, 2715, 13839, 18321, 4445, 103843, 0 };
            const std::uint32_t dim9545JoeKuoD6Init[]   =   { 1, 3, 1, 7, 1, 63, 33, 7, 481, 461, 1923, 2679, 2441, 5449, 13233, 2245, 48667, 0 };
            const std::uint32_t dim9546JoeKuoD6Init[]   =   { 1, 1, 7, 11, 11, 9, 95, 151, 441, 333, 1871, 1181, 3027, 12887, 11923, 63847, 6953, 0 };
            const std::uint32_t dim9547JoeKuoD6Init[]   =   { 1, 3, 5, 5, 15, 33, 53, 47, 351, 387, 55, 393, 5475, 3027, 18565, 37997, 120877, 0 };
            const std::uint32_t dim9548JoeKuoD6Init[]   =   { 1, 3, 5, 9, 23, 43, 67, 97, 445, 783, 1499, 1977, 1441, 10159, 13479, 149, 4939, 0 };
            const std::uint32_t dim9549JoeKuoD6Init[]   =   { 1, 3, 7, 3, 15, 41, 119, 55, 139, 25, 849, 857, 53, 10421, 2683, 24839, 107797, 0 };
            const std::uint32_t dim9550JoeKuoD6Init[]   =   { 1, 1, 7, 13, 25, 51, 51, 13, 333, 93, 95, 1755, 3055, 12585, 3519, 44857, 11257, 0 };
            const std::uint32_t dim9551JoeKuoD6Init[]   =   { 1, 1, 5, 11, 29, 55, 13, 235, 419, 327, 823, 2675, 8031, 9303, 8749, 20215, 12111, 0 };
            const std::uint32_t dim9552JoeKuoD6Init[]   =   { 1, 1, 3, 5, 7, 31, 103, 19, 467, 255, 583, 419, 2845, 12179, 63, 51693, 9755, 0 };
            const std::uint32_t dim9553JoeKuoD6Init[]   =   { 1, 1, 1, 13, 15, 29, 109, 81, 381, 659, 601, 3867, 7663, 7307, 16445, 56327, 48559, 0 };
            const std::uint32_t dim9554JoeKuoD6Init[]   =   { 1, 3, 3, 15, 31, 35, 29, 153, 423, 247, 55, 3259, 6199, 4199, 13931, 14433, 52645, 0 };
            const std::uint32_t dim9555JoeKuoD6Init[]   =   { 1, 1, 5, 11, 9, 17, 17, 191, 231, 977, 721, 2817, 2485, 4965, 32341, 55131, 4547, 0 };
            const std::uint32_t dim9556JoeKuoD6Init[]   =   { 1, 1, 7, 7, 7, 7, 89, 69, 299, 503, 597, 311, 1321, 2335, 30193, 45347, 126631, 0 };
            const std::uint32_t dim9557JoeKuoD6Init[]   =   { 1, 1, 7, 11, 13, 43, 105, 153, 89, 229, 1573, 1549, 3699, 15981, 28911, 45011, 83759, 0 };
            const std::uint32_t dim9558JoeKuoD6Init[]   =   { 1, 3, 7, 3, 1, 3, 121, 137, 263, 325, 1449, 3793, 5795, 7715, 7449, 26453, 85081, 0 };
            const std::uint32_t dim9559JoeKuoD6Init[]   =   { 1, 3, 1, 7, 23, 15, 39, 217, 99, 873, 1641, 1411, 4627, 283, 20707, 41795, 62239, 0 };
            const std::uint32_t dim9560JoeKuoD6Init[]   =   { 1, 3, 5, 9, 15, 15, 35, 255, 501, 945, 79, 799, 2361, 4495, 27825, 27699, 129335, 0 };
            const std::uint32_t dim9561JoeKuoD6Init[]   =   { 1, 3, 1, 7, 9, 19, 89, 31, 65, 905, 1475, 1353, 7253, 12825, 20723, 47757, 12007, 0 };
            const std::uint32_t dim9562JoeKuoD6Init[]   =   { 1, 1, 3, 3, 15, 35, 83, 239, 463, 835, 1249, 2521, 3429, 14073, 13569, 6161, 71309, 0 };
            const std::uint32_t dim9563JoeKuoD6Init[]   =   { 1, 1, 7, 11, 31, 43, 15, 57, 461, 917, 339, 3787, 2925, 1879, 7217, 17091, 108819, 0 };
            const std::uint32_t dim9564JoeKuoD6Init[]   =   { 1, 3, 7, 3, 17, 51, 29, 105, 221, 941, 1291, 835, 1563, 15623, 2953, 62985, 63037, 0 };
            const std::uint32_t dim9565JoeKuoD6Init[]   =   { 1, 1, 7, 3, 1, 39, 83, 41, 399, 465, 587, 2011, 137, 6017, 5067, 52389, 71053, 0 };
            const std::uint32_t dim9566JoeKuoD6Init[]   =   { 1, 1, 7, 11, 17, 55, 103, 239, 173, 181, 1219, 2671, 5183, 3799, 19589, 31247, 68889, 0 };
            const std::uint32_t dim9567JoeKuoD6Init[]   =   { 1, 1, 3, 3, 21, 43, 123, 253, 281, 627, 353, 3077, 1685, 12143, 19723, 57775, 70761, 0 };
            const std::uint32_t dim9568JoeKuoD6Init[]   =   { 1, 1, 7, 15, 31, 13, 101, 159, 311, 305, 1783, 3523, 149, 9269, 7103, 40315, 30569, 0 };
            const std::uint32_t dim9569JoeKuoD6Init[]   =   { 1, 1, 5, 3, 29, 47, 11, 219, 301, 207, 1361, 563, 7831, 14469, 18983, 54535, 64647, 0 };
            const std::uint32_t dim9570JoeKuoD6Init[]   =   { 1, 1, 3, 15, 11, 37, 85, 237, 225, 1009, 1065, 985, 6849, 5395, 22853, 43965, 51363, 0 };
            const std::uint32_t dim9571JoeKuoD6Init[]   =   { 1, 3, 3, 1, 11, 61, 45, 131, 201, 609, 757, 2539, 3817, 9309, 24759, 26789, 41437, 0 };
            const std::uint32_t dim9572JoeKuoD6Init[]   =   { 1, 1, 7, 3, 21, 5, 19, 137, 75, 573, 583, 2499, 41, 3429, 24273, 36711, 110015, 0 };
            const std::uint32_t dim9573JoeKuoD6Init[]   =   { 1, 3, 7, 9, 1, 51, 39, 75, 115, 269, 1983, 2709, 6989, 6521, 5551, 43675, 1019, 0 };
            const std::uint32_t dim9574JoeKuoD6Init[]   =   { 1, 1, 3, 9, 27, 1, 125, 7, 67, 821, 275, 1253, 4635, 3557, 4155, 13831, 1523, 0 };
            const std::uint32_t dim9575JoeKuoD6Init[]   =   { 1, 1, 5, 15, 23, 15, 79, 43, 275, 791, 1867, 2495, 2933, 2167, 22819, 52913, 88871, 0 };
            const std::uint32_t dim9576JoeKuoD6Init[]   =   { 1, 1, 1, 5, 31, 59, 27, 153, 159, 919, 219, 3373, 3227, 6321, 27559, 33905, 126145, 0 };
            const std::uint32_t dim9577JoeKuoD6Init[]   =   { 1, 3, 3, 13, 23, 21, 119, 175, 119, 741, 1745, 3985, 3847, 5163, 13699, 32373, 75201, 0 };
            const std::uint32_t dim9578JoeKuoD6Init[]   =   { 1, 3, 7, 15, 1, 47, 101, 89, 425, 269, 713, 3587, 3373, 13315, 16481, 40031, 50353, 0 };
            const std::uint32_t dim9579JoeKuoD6Init[]   =   { 1, 3, 7, 3, 19, 29, 5, 69, 385, 979, 1893, 1849, 8007, 14415, 18343, 60555, 109117, 0 };
            const std::uint32_t dim9580JoeKuoD6Init[]   =   { 1, 1, 3, 13, 5, 35, 111, 239, 489, 395, 1565, 1607, 543, 89, 8971, 22311, 899, 0 };
            const std::uint32_t dim9581JoeKuoD6Init[]   =   { 1, 1, 7, 7, 11, 51, 105, 211, 341, 85, 991, 1275, 3995, 12611, 2363, 29501, 44217, 0 };
            const std::uint32_t dim9582JoeKuoD6Init[]   =   { 1, 1, 5, 13, 9, 17, 93, 69, 145, 917, 469, 1109, 7405, 12903, 8341, 50383, 20133, 0 };
            const std::uint32_t dim9583JoeKuoD6Init[]   =   { 1, 3, 1, 7, 27, 45, 45, 85, 101, 161, 1117, 2757, 7847, 359, 17155, 27073, 123535, 0 };
            const std::uint32_t dim9584JoeKuoD6Init[]   =   { 1, 3, 1, 3, 9, 11, 67, 205, 109, 257, 1635, 141, 3969, 11571, 211, 48683, 108671, 0 };
            const std::uint32_t dim9585JoeKuoD6Init[]   =   { 1, 1, 3, 7, 13, 9, 29, 251, 113, 851, 1549, 981, 5553, 6095, 28885, 32953, 112563, 0 };
            const std::uint32_t dim9586JoeKuoD6Init[]   =   { 1, 1, 5, 7, 11, 5, 13, 83, 343, 499, 587, 3887, 3859, 11459, 7361, 25665, 86151, 0 };
            const std::uint32_t dim9587JoeKuoD6Init[]   =   { 1, 1, 5, 1, 13, 43, 3, 37, 273, 749, 1707, 2069, 3083, 1095, 3081, 23919, 21939, 0 };
            const std::uint32_t dim9588JoeKuoD6Init[]   =   { 1, 3, 5, 13, 13, 49, 115, 99, 357, 95, 699, 2615, 1911, 12675, 8607, 12535, 118651, 0 };
            const std::uint32_t dim9589JoeKuoD6Init[]   =   { 1, 1, 7, 7, 29, 43, 17, 131, 271, 895, 1427, 3659, 1843, 8247, 1175, 48239, 54435, 0 };
            const std::uint32_t dim9590JoeKuoD6Init[]   =   { 1, 1, 1, 9, 1, 27, 85, 163, 353, 669, 745, 317, 2505, 7685, 14831, 31131, 106687, 0 };
            const std::uint32_t dim9591JoeKuoD6Init[]   =   { 1, 1, 7, 9, 1, 23, 121, 53, 289, 651, 303, 3049, 6819, 6733, 17485, 20023, 110009, 0 };
            const std::uint32_t dim9592JoeKuoD6Init[]   =   { 1, 3, 7, 3, 5, 47, 93, 75, 363, 479, 825, 1801, 6807, 3341, 6419, 9889, 5557, 0 };
            const std::uint32_t dim9593JoeKuoD6Init[]   =   { 1, 1, 3, 15, 23, 5, 7, 25, 73, 811, 1597, 2041, 6707, 6817, 20427, 50749, 46255, 0 };
            const std::uint32_t dim9594JoeKuoD6Init[]   =   { 1, 3, 7, 9, 1, 11, 61, 63, 435, 977, 1937, 93, 2685, 643, 20113, 25873, 63829, 0 };
            const std::uint32_t dim9595JoeKuoD6Init[]   =   { 1, 1, 3, 15, 5, 41, 31, 53, 143, 271, 27, 3899, 5045, 1063, 17229, 52715, 67689, 0 };
            const std::uint32_t dim9596JoeKuoD6Init[]   =   { 1, 1, 3, 11, 1, 57, 121, 13, 291, 861, 1547, 3899, 7949, 15401, 29807, 52307, 104359, 0 };
            const std::uint32_t dim9597JoeKuoD6Init[]   =   { 1, 3, 5, 15, 23, 3, 95, 43, 377, 437, 1687, 3075, 5131, 11791, 3637, 12621, 105575, 0 };
            const std::uint32_t dim9598JoeKuoD6Init[]   =   { 1, 3, 1, 3, 27, 1, 117, 11, 153, 401, 1971, 2097, 3227, 14603, 4757, 56281, 112263, 0 };
            const std::uint32_t dim9599JoeKuoD6Init[]   =   { 1, 3, 3, 5, 13, 25, 51, 209, 367, 327, 1941, 1943, 1347, 14393, 31997, 16001, 129047, 0 };
            const std::uint32_t dim9600JoeKuoD6Init[]   =   { 1, 1, 5, 11, 19, 51, 109, 229, 71, 923, 1741, 1193, 4657, 6043, 26703, 17757, 75009, 0 };
            const std::uint32_t dim9601JoeKuoD6Init[]   =   { 1, 1, 7, 3, 23, 3, 125, 165, 137, 999, 1583, 3493, 859, 15603, 7143, 28791, 28201, 0 };
            const std::uint32_t dim9602JoeKuoD6Init[]   =   { 1, 1, 5, 11, 29, 57, 65, 41, 295, 729, 635, 1871, 6347, 3509, 59, 40765, 42673, 0 };
            const std::uint32_t dim9603JoeKuoD6Init[]   =   { 1, 3, 3, 3, 15, 59, 53, 97, 15, 131, 891, 1105, 841, 6065, 14427, 4721, 106433, 0 };
            const std::uint32_t dim9604JoeKuoD6Init[]   =   { 1, 1, 1, 7, 19, 37, 101, 121, 141, 613, 1363, 691, 1731, 12477, 8339, 55669, 99379, 0 };
            const std::uint32_t dim9605JoeKuoD6Init[]   =   { 1, 3, 5, 13, 17, 49, 75, 25, 447, 113, 1853, 3465, 5225, 4531, 14287, 1039, 17399, 0 };
            const std::uint32_t dim9606JoeKuoD6Init[]   =   { 1, 3, 5, 3, 3, 49, 101, 79, 117, 939, 1161, 1991, 2343, 7183, 12599, 52877, 94337, 0 };
            const std::uint32_t dim9607JoeKuoD6Init[]   =   { 1, 3, 1, 1, 19, 47, 73, 195, 475, 435, 1807, 2723, 7885, 15469, 26057, 37325, 57005, 0 };
            const std::uint32_t dim9608JoeKuoD6Init[]   =   { 1, 1, 1, 11, 17, 7, 111, 143, 357, 977, 719, 553, 4559, 7225, 10405, 26895, 8385, 0 };
            const std::uint32_t dim9609JoeKuoD6Init[]   =   { 1, 3, 3, 9, 17, 5, 1, 73, 125, 913, 1275, 2387, 5153, 13611, 20585, 8465, 27545, 0 };
            const std::uint32_t dim9610JoeKuoD6Init[]   =   { 1, 1, 7, 5, 27, 51, 107, 147, 503, 699, 851, 1729, 2875, 16331, 28025, 26451, 92705, 0 };
            const std::uint32_t dim9611JoeKuoD6Init[]   =   { 1, 1, 5, 9, 3, 37, 21, 139, 13, 427, 225, 1345, 2491, 15495, 25847, 3095, 128879, 0 };
            const std::uint32_t dim9612JoeKuoD6Init[]   =   { 1, 1, 3, 11, 7, 47, 113, 133, 99, 871, 1151, 1953, 7931, 6389, 28715, 36861, 60017, 0 };
            const std::uint32_t dim9613JoeKuoD6Init[]   =   { 1, 1, 7, 1, 21, 47, 35, 83, 137, 945, 2047, 3491, 3719, 3001, 20563, 51243, 14491, 0 };
            const std::uint32_t dim9614JoeKuoD6Init[]   =   { 1, 1, 5, 15, 1, 13, 85, 61, 479, 853, 813, 805, 4931, 12651, 22757, 29531, 92861, 0 };
            const std::uint32_t dim9615JoeKuoD6Init[]   =   { 1, 3, 7, 7, 27, 63, 31, 169, 43, 185, 637, 729, 7231, 2381, 23539, 53885, 90215, 0 };
            const std::uint32_t dim9616JoeKuoD6Init[]   =   { 1, 1, 3, 13, 5, 51, 69, 111, 357, 277, 1889, 3809, 8031, 13341, 14261, 34001, 63317, 0 };
            const std::uint32_t dim9617JoeKuoD6Init[]   =   { 1, 1, 7, 3, 11, 59, 1, 43, 227, 503, 1407, 3917, 7077, 847, 4513, 53007, 66721, 0 };
            const std::uint32_t dim9618JoeKuoD6Init[]   =   { 1, 1, 5, 11, 15, 25, 109, 169, 25, 391, 597, 2997, 2377, 9045, 15239, 25291, 5451, 0 };
            const std::uint32_t dim9619JoeKuoD6Init[]   =   { 1, 3, 3, 11, 15, 11, 1, 59, 347, 707, 239, 2473, 8057, 4787, 32247, 17955, 79151, 0 };
            const std::uint32_t dim9620JoeKuoD6Init[]   =   { 1, 3, 7, 11, 9, 59, 9, 117, 137, 713, 451, 1105, 4485, 14979, 26271, 46017, 89211, 0 };
            const std::uint32_t dim9621JoeKuoD6Init[]   =   { 1, 3, 3, 3, 3, 19, 95, 131, 413, 291, 1179, 3265, 7107, 10419, 13527, 19905, 8059, 0 };
            const std::uint32_t dim9622JoeKuoD6Init[]   =   { 1, 3, 7, 9, 29, 43, 19, 243, 443, 27, 1401, 3469, 6925, 2833, 19715, 39667, 11983, 0 };
            const std::uint32_t dim9623JoeKuoD6Init[]   =   { 1, 3, 3, 7, 23, 33, 115, 59, 29, 61, 1085, 1115, 4007, 12673, 26479, 22397, 95609, 0 };
            const std::uint32_t dim9624JoeKuoD6Init[]   =   { 1, 3, 3, 5, 1, 47, 43, 83, 21, 621, 59, 1, 891, 12285, 31855, 48641, 52479, 0 };
            const std::uint32_t dim9625JoeKuoD6Init[]   =   { 1, 3, 3, 5, 3, 9, 17, 181, 15, 315, 1705, 2461, 1853, 14007, 17665, 40593, 126179, 0 };
            const std::uint32_t dim9626JoeKuoD6Init[]   =   { 1, 3, 5, 3, 3, 23, 83, 163, 29, 293, 1891, 2631, 2989, 7295, 2441, 21689, 8187, 0 };
            const std::uint32_t dim9627JoeKuoD6Init[]   =   { 1, 3, 1, 1, 1, 23, 53, 215, 185, 843, 1083, 2603, 3857, 4981, 25079, 20249, 93717, 0 };
            const std::uint32_t dim9628JoeKuoD6Init[]   =   { 1, 3, 5, 11, 7, 61, 127, 13, 449, 395, 1909, 3967, 2441, 3073, 8159, 33979, 26345, 0 };
            const std::uint32_t dim9629JoeKuoD6Init[]   =   { 1, 1, 5, 1, 15, 5, 93, 87, 319, 173, 1729, 1395, 1019, 5139, 10819, 29877, 81025, 0 };
            const std::uint32_t dim9630JoeKuoD6Init[]   =   { 1, 3, 3, 7, 17, 55, 61, 227, 299, 245, 849, 211, 895, 2999, 18215, 37069, 32821, 0 };
            const std::uint32_t dim9631JoeKuoD6Init[]   =   { 1, 1, 5, 3, 17, 49, 115, 55, 447, 533, 1463, 2983, 3245, 9345, 11955, 49145, 128035, 0 };
            const std::uint32_t dim9632JoeKuoD6Init[]   =   { 1, 3, 1, 7, 5, 17, 61, 71, 101, 529, 1761, 827, 7887, 5713, 31039, 18087, 82277, 0 };
            const std::uint32_t dim9633JoeKuoD6Init[]   =   { 1, 3, 1, 11, 27, 59, 1, 231, 303, 431, 1279, 3647, 1333, 3675, 29401, 55533, 65997, 0 };
            const std::uint32_t dim9634JoeKuoD6Init[]   =   { 1, 1, 5, 9, 7, 9, 111, 245, 269, 919, 1147, 1601, 6219, 4931, 3035, 12231, 4011, 0 };
            const std::uint32_t dim9635JoeKuoD6Init[]   =   { 1, 3, 5, 15, 3, 19, 83, 25, 129, 979, 79, 3027, 3983, 7703, 16859, 12085, 83115, 0 };
            const std::uint32_t dim9636JoeKuoD6Init[]   =   { 1, 1, 5, 11, 31, 41, 99, 3, 383, 943, 1579, 2435, 1209, 161, 31733, 11755, 95697, 0 };
            const std::uint32_t dim9637JoeKuoD6Init[]   =   { 1, 1, 1, 9, 9, 55, 115, 187, 499, 165, 1081, 813, 2545, 8065, 10501, 15475, 85107, 0 };
            const std::uint32_t dim9638JoeKuoD6Init[]   =   { 1, 1, 1, 3, 1, 31, 81, 213, 301, 575, 605, 543, 3347, 12759, 21645, 37173, 36127, 0 };
            const std::uint32_t dim9639JoeKuoD6Init[]   =   { 1, 3, 3, 9, 21, 29, 51, 91, 307, 617, 1839, 443, 1013, 4473, 3885, 57669, 123271, 0 };
            const std::uint32_t dim9640JoeKuoD6Init[]   =   { 1, 3, 1, 15, 31, 43, 83, 187, 51, 513, 1505, 3895, 3557, 9527, 27537, 6173, 99595, 0 };
            const std::uint32_t dim9641JoeKuoD6Init[]   =   { 1, 3, 3, 1, 3, 53, 113, 27, 431, 505, 219, 2143, 6691, 3219, 9589, 9885, 24037, 0 };
            const std::uint32_t dim9642JoeKuoD6Init[]   =   { 1, 1, 5, 9, 13, 3, 53, 145, 49, 411, 691, 289, 6443, 4963, 13815, 23663, 95497, 0 };
            const std::uint32_t dim9643JoeKuoD6Init[]   =   { 1, 3, 5, 9, 19, 7, 53, 101, 199, 69, 1821, 3233, 3267, 5947, 4869, 30095, 21255, 0 };
            const std::uint32_t dim9644JoeKuoD6Init[]   =   { 1, 1, 5, 11, 29, 7, 79, 11, 451, 585, 987, 2333, 1891, 1853, 14739, 34399, 62895, 0 };
            const std::uint32_t dim9645JoeKuoD6Init[]   =   { 1, 3, 1, 7, 29, 43, 103, 219, 139, 359, 1663, 3453, 7469, 1943, 11457, 19227, 62211, 0 };
            const std::uint32_t dim9646JoeKuoD6Init[]   =   { 1, 3, 3, 11, 9, 47, 17, 237, 87, 881, 583, 3473, 2579, 975, 1531, 50997, 76219, 0 };
            const std::uint32_t dim9647JoeKuoD6Init[]   =   { 1, 1, 7, 15, 31, 37, 79, 115, 95, 515, 2003, 2595, 4077, 4537, 9171, 31183, 41219, 0 };
            const std::uint32_t dim9648JoeKuoD6Init[]   =   { 1, 1, 1, 9, 21, 41, 93, 33, 211, 341, 233, 2217, 6657, 12913, 8329, 3881, 42563, 0 };
            const std::uint32_t dim9649JoeKuoD6Init[]   =   { 1, 3, 3, 11, 25, 3, 23, 197, 49, 339, 877, 1117, 7817, 14143, 1575, 50301, 92367, 0 };
            const std::uint32_t dim9650JoeKuoD6Init[]   =   { 1, 3, 5, 5, 19, 45, 69, 179, 447, 861, 1633, 1941, 5821, 1843, 4085, 23501, 109047, 0 };
            const std::uint32_t dim9651JoeKuoD6Init[]   =   { 1, 3, 1, 3, 31, 29, 49, 183, 311, 133, 345, 1541, 111, 5571, 1943, 11039, 127673, 0 };
            const std::uint32_t dim9652JoeKuoD6Init[]   =   { 1, 3, 1, 5, 3, 13, 63, 5, 59, 789, 71, 3271, 3871, 9105, 22525, 31, 117803, 0 };
            const std::uint32_t dim9653JoeKuoD6Init[]   =   { 1, 3, 1, 13, 31, 43, 97, 133, 313, 729, 287, 2971, 5623, 13183, 15179, 47271, 28853, 0 };
            const std::uint32_t dim9654JoeKuoD6Init[]   =   { 1, 1, 3, 13, 27, 15, 35, 37, 507, 139, 1933, 2847, 361, 10261, 21031, 3889, 56875, 0 };
            const std::uint32_t dim9655JoeKuoD6Init[]   =   { 1, 3, 1, 15, 31, 13, 45, 73, 279, 331, 471, 3881, 3295, 12035, 28329, 899, 47397, 0 };
            const std::uint32_t dim9656JoeKuoD6Init[]   =   { 1, 1, 3, 13, 1, 7, 81, 255, 315, 595, 43, 3919, 5229, 7953, 25711, 19509, 107181, 0 };
            const std::uint32_t dim9657JoeKuoD6Init[]   =   { 1, 1, 3, 15, 7, 33, 117, 169, 71, 577, 629, 3665, 7761, 13529, 26375, 17181, 22125, 0 };
            const std::uint32_t dim9658JoeKuoD6Init[]   =   { 1, 3, 5, 7, 5, 7, 1, 93, 489, 289, 329, 2273, 685, 14835, 11433, 26041, 112735, 0 };
            const std::uint32_t dim9659JoeKuoD6Init[]   =   { 1, 3, 3, 3, 9, 39, 45, 23, 171, 35, 571, 551, 7815, 6169, 24283, 61477, 71877, 0 };
            const std::uint32_t dim9660JoeKuoD6Init[]   =   { 1, 1, 5, 7, 23, 15, 81, 215, 297, 269, 655, 2059, 3643, 12741, 11955, 41085, 46047, 0 };
            const std::uint32_t dim9661JoeKuoD6Init[]   =   { 1, 1, 7, 5, 3, 35, 125, 141, 419, 137, 1031, 2053, 7925, 7267, 6267, 34323, 77495, 0 };
            const std::uint32_t dim9662JoeKuoD6Init[]   =   { 1, 1, 7, 11, 3, 57, 91, 43, 139, 691, 1569, 1825, 7855, 1093, 19263, 31601, 16019, 0 };
            const std::uint32_t dim9663JoeKuoD6Init[]   =   { 1, 3, 1, 5, 21, 7, 11, 225, 105, 757, 1493, 455, 4757, 12007, 5139, 3545, 79717, 0 };
            const std::uint32_t dim9664JoeKuoD6Init[]   =   { 1, 3, 1, 13, 17, 29, 125, 249, 475, 79, 1271, 341, 863, 853, 2105, 32897, 121261, 0 };
            const std::uint32_t dim9665JoeKuoD6Init[]   =   { 1, 3, 1, 11, 17, 59, 3, 29, 61, 399, 1465, 4029, 2103, 12481, 28495, 34363, 63781, 0 };
            const std::uint32_t dim9666JoeKuoD6Init[]   =   { 1, 3, 3, 15, 29, 13, 101, 191, 435, 215, 1355, 2263, 6059, 4545, 7535, 15041, 84091, 0 };
            const std::uint32_t dim9667JoeKuoD6Init[]   =   { 1, 1, 3, 9, 29, 23, 99, 55, 91, 145, 235, 2847, 725, 209, 24565, 16545, 103669, 0 };
            const std::uint32_t dim9668JoeKuoD6Init[]   =   { 1, 1, 1, 1, 31, 15, 93, 197, 207, 357, 667, 3511, 3865, 5329, 6491, 9027, 125979, 0 };
            const std::uint32_t dim9669JoeKuoD6Init[]   =   { 1, 3, 3, 13, 17, 35, 99, 187, 153, 589, 1633, 4053, 1023, 9541, 9841, 39585, 24885, 0 };
            const std::uint32_t dim9670JoeKuoD6Init[]   =   { 1, 3, 7, 11, 23, 5, 71, 89, 455, 665, 1221, 1821, 591, 11459, 503, 56777, 65691, 0 };
            const std::uint32_t dim9671JoeKuoD6Init[]   =   { 1, 3, 1, 1, 9, 33, 51, 203, 223, 709, 1263, 3535, 7753, 8279, 8673, 60259, 2671, 0 };
            const std::uint32_t dim9672JoeKuoD6Init[]   =   { 1, 1, 7, 9, 17, 63, 5, 229, 495, 435, 1711, 3359, 399, 15901, 28519, 56627, 8079, 0 };
            const std::uint32_t dim9673JoeKuoD6Init[]   =   { 1, 3, 5, 11, 9, 25, 49, 143, 275, 989, 461, 447, 1917, 9253, 28421, 1803, 119725, 0 };
            const std::uint32_t dim9674JoeKuoD6Init[]   =   { 1, 3, 3, 7, 25, 3, 39, 171, 303, 905, 1353, 2561, 7347, 7339, 15271, 61945, 26343, 0 };
            const std::uint32_t dim9675JoeKuoD6Init[]   =   { 1, 1, 1, 3, 5, 63, 9, 229, 107, 815, 1705, 3621, 2345, 3065, 16315, 17017, 33667, 0 };
            const std::uint32_t dim9676JoeKuoD6Init[]   =   { 1, 3, 5, 13, 29, 13, 91, 111, 475, 561, 443, 3825, 5331, 11211, 27639, 28305, 101831, 0 };
            const std::uint32_t dim9677JoeKuoD6Init[]   =   { 1, 3, 1, 9, 15, 33, 17, 47, 249, 89, 429, 3819, 1959, 14317, 10737, 28151, 40395, 0 };
            const std::uint32_t dim9678JoeKuoD6Init[]   =   { 1, 3, 7, 13, 19, 29, 83, 81, 511, 783, 823, 2865, 5823, 9459, 27413, 63297, 44181, 0 };
            const std::uint32_t dim9679JoeKuoD6Init[]   =   { 1, 3, 1, 1, 19, 53, 45, 227, 193, 631, 289, 1227, 6241, 6915, 16051, 31237, 50201, 0 };
            const std::uint32_t dim9680JoeKuoD6Init[]   =   { 1, 3, 7, 7, 15, 49, 77, 147, 421, 515, 927, 1561, 4391, 12943, 6807, 36889, 70249, 0 };
            const std::uint32_t dim9681JoeKuoD6Init[]   =   { 1, 3, 7, 7, 17, 15, 63, 123, 101, 283, 59, 977, 5185, 16161, 5007, 36255, 11537, 0 };
            const std::uint32_t dim9682JoeKuoD6Init[]   =   { 1, 1, 7, 1, 13, 17, 79, 35, 193, 947, 767, 1365, 2145, 13267, 30561, 51949, 37591, 0 };
            const std::uint32_t dim9683JoeKuoD6Init[]   =   { 1, 1, 1, 13, 11, 13, 91, 129, 355, 549, 295, 673, 209, 15953, 14703, 30857, 47967, 0 };
            const std::uint32_t dim9684JoeKuoD6Init[]   =   { 1, 3, 5, 9, 17, 17, 83, 161, 189, 585, 21, 1019, 4879, 15943, 17281, 46013, 94839, 0 };
            const std::uint32_t dim9685JoeKuoD6Init[]   =   { 1, 3, 5, 9, 23, 39, 65, 25, 181, 3, 2005, 635, 201, 9391, 8755, 38535, 88697, 0 };
            const std::uint32_t dim9686JoeKuoD6Init[]   =   { 1, 3, 1, 15, 13, 35, 47, 125, 429, 901, 895, 3495, 327, 397, 7847, 62157, 3489, 0 };
            const std::uint32_t dim9687JoeKuoD6Init[]   =   { 1, 3, 5, 3, 19, 21, 81, 39, 85, 169, 1981, 3323, 113, 2057, 16617, 58051, 55059, 0 };
            const std::uint32_t dim9688JoeKuoD6Init[]   =   { 1, 3, 1, 13, 9, 1, 101, 81, 129, 717, 1495, 4077, 5555, 93, 12957, 14805, 110219, 0 };
            const std::uint32_t dim9689JoeKuoD6Init[]   =   { 1, 3, 5, 5, 5, 47, 107, 111, 387, 987, 2009, 179, 1111, 3443, 25579, 12293, 123035, 0 };
            const std::uint32_t dim9690JoeKuoD6Init[]   =   { 1, 1, 7, 13, 21, 25, 33, 211, 9, 783, 1785, 2691, 6835, 2867, 22469, 17853, 90685, 0 };
            const std::uint32_t dim9691JoeKuoD6Init[]   =   { 1, 1, 3, 3, 19, 57, 59, 203, 197, 347, 553, 1361, 7593, 91, 15303, 30045, 86605, 0 };
            const std::uint32_t dim9692JoeKuoD6Init[]   =   { 1, 3, 5, 7, 29, 23, 1, 235, 159, 277, 1227, 1727, 1853, 9717, 2377, 13597, 18119, 0 };
            const std::uint32_t dim9693JoeKuoD6Init[]   =   { 1, 1, 1, 11, 15, 29, 5, 15, 349, 685, 197, 3127, 1075, 8847, 27873, 539, 57149, 0 };
            const std::uint32_t dim9694JoeKuoD6Init[]   =   { 1, 1, 7, 9, 23, 25, 121, 239, 219, 747, 1981, 2683, 5319, 75, 22569, 29697, 27627, 0 };
            const std::uint32_t dim9695JoeKuoD6Init[]   =   { 1, 3, 7, 5, 31, 43, 95, 131, 423, 547, 1437, 127, 1953, 861, 839, 54503, 20465, 0 };
            const std::uint32_t dim9696JoeKuoD6Init[]   =   { 1, 1, 5, 3, 29, 29, 71, 237, 275, 493, 513, 4067, 393, 9415, 20511, 29257, 86267, 0 };
            const std::uint32_t dim9697JoeKuoD6Init[]   =   { 1, 1, 1, 1, 25, 11, 59, 185, 211, 175, 37, 2999, 4919, 10225, 16727, 60447, 59985, 0 };
            const std::uint32_t dim9698JoeKuoD6Init[]   =   { 1, 1, 3, 3, 1, 9, 69, 195, 197, 677, 229, 599, 5613, 4537, 5495, 58801, 14297, 0 };
            const std::uint32_t dim9699JoeKuoD6Init[]   =   { 1, 3, 1, 15, 17, 23, 5, 101, 331, 943, 1433, 2199, 313, 469, 3651, 3281, 100119, 0 };
            const std::uint32_t dim9700JoeKuoD6Init[]   =   { 1, 1, 5, 15, 13, 25, 87, 45, 229, 821, 59, 761, 6259, 15159, 3197, 39763, 87301, 0 };
            const std::uint32_t dim9701JoeKuoD6Init[]   =   { 1, 3, 5, 7, 19, 21, 89, 15, 19, 623, 603, 4069, 3531, 13353, 21267, 6355, 53821, 0 };
            const std::uint32_t dim9702JoeKuoD6Init[]   =   { 1, 1, 5, 9, 13, 13, 111, 77, 439, 599, 1577, 959, 4567, 3117, 7127, 49265, 35667, 0 };
            const std::uint32_t dim9703JoeKuoD6Init[]   =   { 1, 3, 7, 9, 27, 61, 1, 19, 43, 475, 221, 655, 4351, 15827, 30489, 22245, 41077, 0 };
            const std::uint32_t dim9704JoeKuoD6Init[]   =   { 1, 1, 3, 13, 17, 17, 111, 85, 253, 11, 367, 2349, 4103, 12517, 27037, 42481, 84451, 0 };
            const std::uint32_t dim9705JoeKuoD6Init[]   =   { 1, 3, 5, 7, 7, 25, 53, 27, 429, 503, 893, 2923, 2539, 15849, 30157, 12111, 108893, 0 };
            const std::uint32_t dim9706JoeKuoD6Init[]   =   { 1, 1, 7, 9, 13, 29, 51, 113, 273, 745, 759, 263, 3031, 705, 23203, 64245, 127183, 0 };
            const std::uint32_t dim9707JoeKuoD6Init[]   =   { 1, 1, 1, 9, 29, 5, 25, 165, 261, 319, 645, 2199, 3135, 10263, 10711, 18713, 63337, 0 };
            const std::uint32_t dim9708JoeKuoD6Init[]   =   { 1, 1, 5, 1, 23, 41, 43, 71, 365, 683, 1107, 1671, 7079, 8933, 12815, 8095, 97955, 0 };
            const std::uint32_t dim9709JoeKuoD6Init[]   =   { 1, 3, 1, 15, 9, 43, 105, 217, 131, 299, 1459, 1087, 3493, 15297, 11741, 43383, 35021, 0 };
            const std::uint32_t dim9710JoeKuoD6Init[]   =   { 1, 3, 1, 3, 3, 57, 69, 7, 73, 977, 1163, 3591, 243, 13129, 23247, 20609, 22489, 0 };
            const std::uint32_t dim9711JoeKuoD6Init[]   =   { 1, 3, 7, 5, 1, 57, 65, 27, 121, 575, 903, 3527, 5601, 5597, 1941, 60079, 88121, 0 };
            const std::uint32_t dim9712JoeKuoD6Init[]   =   { 1, 3, 1, 3, 15, 3, 23, 87, 233, 389, 1671, 1557, 4825, 1017, 17697, 26735, 53421, 0 };
            const std::uint32_t dim9713JoeKuoD6Init[]   =   { 1, 3, 5, 3, 5, 43, 61, 249, 273, 251, 1383, 2415, 1061, 12363, 3071, 23785, 127909, 0 };
            const std::uint32_t dim9714JoeKuoD6Init[]   =   { 1, 3, 3, 13, 5, 63, 15, 165, 353, 603, 1627, 2037, 487, 11603, 719, 54693, 52645, 0 };
            const std::uint32_t dim9715JoeKuoD6Init[]   =   { 1, 3, 5, 11, 31, 41, 41, 83, 481, 251, 1903, 2655, 5237, 6073, 20201, 14069, 91649, 0 };
            const std::uint32_t dim9716JoeKuoD6Init[]   =   { 1, 3, 1, 15, 21, 41, 99, 61, 55, 63, 1595, 1805, 7625, 12261, 23275, 43471, 5147, 0 };
            const std::uint32_t dim9717JoeKuoD6Init[]   =   { 1, 3, 1, 5, 23, 21, 71, 169, 197, 51, 1653, 3053, 4663, 293, 12751, 15641, 83993, 0 };
            const std::uint32_t dim9718JoeKuoD6Init[]   =   { 1, 3, 5, 15, 29, 45, 55, 199, 275, 103, 1093, 3569, 5997, 9445, 2291, 30973, 68589, 0 };
            const std::uint32_t dim9719JoeKuoD6Init[]   =   { 1, 3, 5, 7, 15, 3, 15, 3, 287, 961, 1759, 1153, 7613, 9885, 8981, 5109, 112865, 0 };
            const std::uint32_t dim9720JoeKuoD6Init[]   =   { 1, 1, 1, 9, 1, 37, 111, 61, 309, 581, 875, 2121, 1035, 4345, 1351, 59743, 34955, 0 };
            const std::uint32_t dim9721JoeKuoD6Init[]   =   { 1, 3, 7, 7, 11, 23, 51, 235, 23, 697, 991, 1995, 3615, 6665, 15885, 18555, 11711, 0 };
            const std::uint32_t dim9722JoeKuoD6Init[]   =   { 1, 3, 7, 13, 3, 59, 87, 129, 405, 689, 1189, 2071, 877, 12347, 18381, 28367, 27247, 0 };
            const std::uint32_t dim9723JoeKuoD6Init[]   =   { 1, 1, 1, 9, 23, 29, 113, 71, 479, 421, 215, 1029, 6125, 13575, 10823, 45303, 3153, 0 };
            const std::uint32_t dim9724JoeKuoD6Init[]   =   { 1, 1, 3, 11, 13, 5, 31, 29, 279, 597, 791, 319, 1391, 14487, 3811, 36913, 11513, 0 };
            const std::uint32_t dim9725JoeKuoD6Init[]   =   { 1, 3, 7, 11, 9, 11, 55, 167, 69, 519, 1887, 145, 6133, 1307, 14465, 17419, 18319, 0 };
            const std::uint32_t dim9726JoeKuoD6Init[]   =   { 1, 1, 3, 1, 29, 25, 57, 75, 19, 187, 1591, 421, 959, 7499, 8377, 42811, 53423, 0 };
            const std::uint32_t dim9727JoeKuoD6Init[]   =   { 1, 3, 1, 3, 7, 9, 73, 217, 383, 755, 1561, 3923, 3891, 16129, 13195, 62097, 67493, 0 };
            const std::uint32_t dim9728JoeKuoD6Init[]   =   { 1, 3, 7, 9, 5, 7, 47, 29, 319, 243, 405, 2867, 5803, 2273, 4913, 54777, 88301, 0 };
            const std::uint32_t dim9729JoeKuoD6Init[]   =   { 1, 3, 7, 1, 25, 11, 51, 183, 387, 863, 39, 2119, 2395, 10175, 20833, 3235, 108197, 0 };
            const std::uint32_t dim9730JoeKuoD6Init[]   =   { 1, 1, 7, 13, 25, 43, 21, 67, 103, 709, 603, 1045, 7079, 8867, 29039, 61499, 39533, 0 };
            const std::uint32_t dim9731JoeKuoD6Init[]   =   { 1, 1, 7, 5, 7, 55, 77, 115, 409, 287, 1149, 1535, 7459, 5525, 27129, 43659, 86953, 0 };
            const std::uint32_t dim9732JoeKuoD6Init[]   =   { 1, 3, 5, 3, 21, 41, 47, 147, 267, 473, 1501, 2663, 5381, 41, 18265, 53845, 16039, 0 };
            const std::uint32_t dim9733JoeKuoD6Init[]   =   { 1, 1, 7, 15, 27, 63, 95, 103, 169, 1, 133, 3103, 7539, 5765, 11453, 4133, 95133, 0 };
            const std::uint32_t dim9734JoeKuoD6Init[]   =   { 1, 3, 3, 15, 3, 53, 121, 135, 385, 475, 889, 2557, 4937, 11129, 18461, 16757, 30339, 0 };
            const std::uint32_t dim9735JoeKuoD6Init[]   =   { 1, 3, 1, 13, 11, 39, 111, 13, 475, 201, 1973, 2151, 6973, 4083, 12593, 44093, 108037, 0 };
            const std::uint32_t dim9736JoeKuoD6Init[]   =   { 1, 3, 7, 9, 31, 31, 97, 235, 179, 689, 403, 1995, 7697, 7511, 29333, 11005, 50723, 0 };
            const std::uint32_t dim9737JoeKuoD6Init[]   =   { 1, 1, 7, 13, 23, 5, 7, 171, 441, 921, 1455, 3865, 7089, 5469, 10423, 53013, 80559, 0 };
            const std::uint32_t dim9738JoeKuoD6Init[]   =   { 1, 3, 5, 3, 25, 43, 105, 157, 507, 143, 297, 1111, 2761, 14103, 4965, 36733, 11741, 0 };
            const std::uint32_t dim9739JoeKuoD6Init[]   =   { 1, 3, 7, 9, 29, 61, 49, 239, 271, 697, 211, 1633, 2991, 14933, 12347, 44291, 12219, 0 };
            const std::uint32_t dim9740JoeKuoD6Init[]   =   { 1, 1, 7, 7, 17, 61, 29, 43, 87, 633, 937, 1931, 3541, 12259, 23045, 5923, 48479, 0 };
            const std::uint32_t dim9741JoeKuoD6Init[]   =   { 1, 3, 3, 3, 15, 25, 105, 17, 159, 863, 1377, 331, 1475, 10573, 28947, 8141, 26671, 0 };
            const std::uint32_t dim9742JoeKuoD6Init[]   =   { 1, 1, 7, 7, 31, 59, 81, 23, 467, 241, 1257, 1337, 7731, 9071, 3417, 51191, 78369, 0 };
            const std::uint32_t dim9743JoeKuoD6Init[]   =   { 1, 1, 5, 9, 11, 45, 49, 227, 319, 63, 1339, 885, 4571, 11649, 5607, 10509, 55055, 0 };
            const std::uint32_t dim9744JoeKuoD6Init[]   =   { 1, 3, 3, 9, 29, 17, 7, 235, 191, 927, 575, 1115, 4111, 14179, 2041, 13331, 29825, 0 };
            const std::uint32_t dim9745JoeKuoD6Init[]   =   { 1, 1, 5, 9, 27, 61, 71, 201, 341, 577, 221, 1371, 1135, 4347, 24211, 36171, 23435, 0 };
            const std::uint32_t dim9746JoeKuoD6Init[]   =   { 1, 3, 3, 1, 1, 29, 75, 121, 193, 647, 1429, 275, 5243, 783, 28533, 13941, 68035, 0 };
            const std::uint32_t dim9747JoeKuoD6Init[]   =   { 1, 3, 5, 15, 21, 27, 117, 183, 251, 991, 935, 3119, 5133, 2765, 7423, 28867, 120565, 0 };
            const std::uint32_t dim9748JoeKuoD6Init[]   =   { 1, 3, 5, 5, 13, 23, 29, 101, 299, 699, 1249, 1225, 1335, 6079, 17825, 60467, 87787, 0 };
            const std::uint32_t dim9749JoeKuoD6Init[]   =   { 1, 1, 1, 9, 15, 19, 11, 163, 433, 553, 1487, 813, 3293, 1195, 895, 28431, 62905, 0 };
            const std::uint32_t dim9750JoeKuoD6Init[]   =   { 1, 1, 1, 13, 25, 37, 111, 129, 391, 813, 1061, 4065, 7339, 10731, 23799, 41463, 99673, 0 };
            const std::uint32_t dim9751JoeKuoD6Init[]   =   { 1, 1, 7, 15, 3, 21, 45, 77, 471, 155, 967, 711, 4947, 13983, 27827, 28653, 117839, 0 };
            const std::uint32_t dim9752JoeKuoD6Init[]   =   { 1, 1, 5, 9, 13, 39, 107, 237, 233, 881, 297, 2189, 8085, 1221, 18659, 299, 90951, 0 };
            const std::uint32_t dim9753JoeKuoD6Init[]   =   { 1, 1, 1, 13, 21, 53, 83, 17, 487, 215, 1203, 3017, 7887, 3759, 10521, 31223, 87917, 0 };
            const std::uint32_t dim9754JoeKuoD6Init[]   =   { 1, 1, 7, 1, 13, 31, 123, 219, 127, 743, 1325, 3907, 129, 8901, 4855, 22509, 47331, 0 };
            const std::uint32_t dim9755JoeKuoD6Init[]   =   { 1, 1, 7, 11, 29, 37, 11, 157, 401, 35, 2037, 2873, 7409, 7837, 1247, 33911, 3979, 0 };
            const std::uint32_t dim9756JoeKuoD6Init[]   =   { 1, 1, 5, 15, 1, 13, 35, 253, 287, 1007, 1417, 1613, 6019, 11617, 6323, 56263, 45073, 0 };
            const std::uint32_t dim9757JoeKuoD6Init[]   =   { 1, 3, 1, 15, 1, 59, 41, 239, 373, 443, 897, 275, 5783, 8619, 18559, 16279, 92063, 0 };
            const std::uint32_t dim9758JoeKuoD6Init[]   =   { 1, 3, 1, 9, 23, 33, 83, 43, 231, 819, 1657, 1031, 5507, 12621, 8961, 23059, 63453, 0 };
            const std::uint32_t dim9759JoeKuoD6Init[]   =   { 1, 1, 7, 5, 29, 49, 21, 251, 267, 43, 729, 4013, 1497, 15489, 16761, 49689, 122755, 0 };
            const std::uint32_t dim9760JoeKuoD6Init[]   =   { 1, 3, 7, 1, 31, 21, 11, 149, 127, 711, 1249, 49, 5503, 677, 12313, 61301, 16279, 0 };
            const std::uint32_t dim9761JoeKuoD6Init[]   =   { 1, 1, 5, 11, 9, 15, 41, 61, 81, 991, 1387, 3567, 221, 15835, 8609, 28265, 98199, 0 };
            const std::uint32_t dim9762JoeKuoD6Init[]   =   { 1, 3, 1, 7, 21, 35, 13, 59, 173, 637, 107, 393, 4551, 6523, 27389, 33129, 45579, 0 };
            const std::uint32_t dim9763JoeKuoD6Init[]   =   { 1, 1, 1, 9, 29, 51, 65, 199, 417, 553, 1321, 2513, 4749, 8477, 19721, 24301, 16301, 0 };
            const std::uint32_t dim9764JoeKuoD6Init[]   =   { 1, 3, 5, 1, 25, 13, 7, 55, 163, 581, 1677, 2313, 6843, 15697, 3055, 53171, 59899, 0 };
            const std::uint32_t dim9765JoeKuoD6Init[]   =   { 1, 3, 1, 5, 31, 13, 101, 195, 235, 359, 911, 1017, 2575, 12801, 997, 7819, 73243, 0 };
            const std::uint32_t dim9766JoeKuoD6Init[]   =   { 1, 1, 7, 1, 9, 39, 59, 83, 57, 885, 317, 2689, 5741, 11833, 25563, 62581, 62239, 0 };
            const std::uint32_t dim9767JoeKuoD6Init[]   =   { 1, 1, 5, 15, 25, 25, 55, 207, 223, 907, 913, 387, 5599, 15567, 8859, 13703, 66071, 0 };
            const std::uint32_t dim9768JoeKuoD6Init[]   =   { 1, 1, 5, 15, 19, 39, 83, 177, 333, 531, 1257, 2687, 7793, 15967, 19175, 1381, 106629, 0 };
            const std::uint32_t dim9769JoeKuoD6Init[]   =   { 1, 3, 5, 13, 29, 29, 77, 1, 273, 483, 725, 3825, 5115, 4043, 11571, 8693, 49761, 0 };
            const std::uint32_t dim9770JoeKuoD6Init[]   =   { 1, 1, 7, 3, 5, 45, 37, 65, 267, 191, 301, 2863, 167, 9303, 14563, 41553, 119561, 0 };
            const std::uint32_t dim9771JoeKuoD6Init[]   =   { 1, 1, 7, 5, 21, 41, 107, 213, 267, 427, 699, 1485, 2125, 16011, 29243, 4691, 50545, 0 };
            const std::uint32_t dim9772JoeKuoD6Init[]   =   { 1, 3, 3, 9, 15, 29, 81, 53, 289, 689, 933, 2667, 5175, 10409, 28221, 56375, 49109, 0 };
            const std::uint32_t dim9773JoeKuoD6Init[]   =   { 1, 1, 1, 15, 3, 11, 77, 107, 353, 349, 219, 1961, 7559, 10081, 25119, 46041, 103827, 0 };
            const std::uint32_t dim9774JoeKuoD6Init[]   =   { 1, 3, 3, 1, 5, 27, 109, 17, 271, 543, 565, 397, 2649, 12037, 4525, 37835, 107071, 0 };
            const std::uint32_t dim9775JoeKuoD6Init[]   =   { 1, 1, 5, 15, 3, 37, 123, 157, 389, 619, 1379, 4093, 6107, 4419, 21011, 36189, 21269, 0 };
            const std::uint32_t dim9776JoeKuoD6Init[]   =   { 1, 3, 1, 7, 25, 17, 37, 133, 247, 113, 985, 815, 441, 7869, 25121, 49459, 429, 0 };
            const std::uint32_t dim9777JoeKuoD6Init[]   =   { 1, 3, 3, 11, 7, 23, 59, 51, 403, 685, 2019, 1167, 7973, 6915, 10819, 43807, 127793, 0 };
            const std::uint32_t dim9778JoeKuoD6Init[]   =   { 1, 1, 3, 1, 29, 3, 125, 107, 305, 101, 391, 2733, 6883, 5867, 5139, 16025, 112439, 0 };
            const std::uint32_t dim9779JoeKuoD6Init[]   =   { 1, 1, 5, 5, 23, 23, 89, 33, 275, 451, 1033, 649, 3761, 4735, 26021, 9627, 102747, 0 };
            const std::uint32_t dim9780JoeKuoD6Init[]   =   { 1, 1, 5, 13, 3, 17, 117, 251, 425, 917, 759, 3047, 8171, 14421, 27765, 11085, 64889, 0 };
            const std::uint32_t dim9781JoeKuoD6Init[]   =   { 1, 3, 1, 9, 7, 23, 107, 143, 123, 413, 2045, 655, 6283, 8783, 20263, 55463, 33271, 0 };
            const std::uint32_t dim9782JoeKuoD6Init[]   =   { 1, 3, 7, 11, 5, 49, 73, 55, 465, 43, 587, 3943, 521, 12357, 16273, 26603, 23219, 0 };
            const std::uint32_t dim9783JoeKuoD6Init[]   =   { 1, 3, 5, 13, 9, 3, 127, 171, 271, 227, 993, 1427, 2235, 6325, 13501, 1411, 44393, 0 };
            const std::uint32_t dim9784JoeKuoD6Init[]   =   { 1, 1, 1, 3, 13, 27, 19, 37, 175, 423, 5, 3403, 5427, 16345, 30297, 11909, 104647, 0 };
            const std::uint32_t dim9785JoeKuoD6Init[]   =   { 1, 3, 1, 3, 3, 39, 111, 179, 487, 923, 1945, 1609, 4689, 11807, 13725, 3081, 48163, 0 };
            const std::uint32_t dim9786JoeKuoD6Init[]   =   { 1, 3, 1, 1, 9, 35, 7, 151, 109, 925, 1249, 3171, 1207, 2053, 5135, 34821, 57291, 0 };
            const std::uint32_t dim9787JoeKuoD6Init[]   =   { 1, 1, 5, 13, 31, 35, 101, 199, 499, 725, 1229, 2857, 6437, 503, 14437, 35721, 24971, 0 };
            const std::uint32_t dim9788JoeKuoD6Init[]   =   { 1, 1, 1, 15, 3, 49, 75, 101, 373, 119, 875, 245, 15, 12937, 4731, 13037, 1555, 0 };
            const std::uint32_t dim9789JoeKuoD6Init[]   =   { 1, 1, 1, 7, 15, 5, 53, 5, 423, 69, 73, 2139, 383, 4035, 6723, 59941, 124503, 0 };
            const std::uint32_t dim9790JoeKuoD6Init[]   =   { 1, 1, 3, 13, 1, 23, 29, 47, 145, 785, 1013, 1579, 4579, 107, 17571, 46311, 27777, 0 };
            const std::uint32_t dim9791JoeKuoD6Init[]   =   { 1, 1, 1, 5, 23, 25, 97, 75, 105, 183, 827, 3871, 2005, 6453, 28729, 42583, 62979, 0 };
            const std::uint32_t dim9792JoeKuoD6Init[]   =   { 1, 3, 5, 9, 11, 49, 29, 201, 333, 441, 429, 1955, 5301, 11775, 22915, 58693, 111917, 0 };
            const std::uint32_t dim9793JoeKuoD6Init[]   =   { 1, 3, 3, 1, 15, 37, 117, 223, 319, 181, 61, 177, 507, 14871, 16419, 34261, 106937, 0 };
            const std::uint32_t dim9794JoeKuoD6Init[]   =   { 1, 3, 3, 9, 25, 27, 81, 253, 459, 5, 693, 1271, 485, 16171, 427, 17917, 4393, 0 };
            const std::uint32_t dim9795JoeKuoD6Init[]   =   { 1, 3, 3, 1, 27, 47, 11, 57, 269, 95, 569, 2733, 3275, 1599, 15073, 58071, 86805, 0 };
            const std::uint32_t dim9796JoeKuoD6Init[]   =   { 1, 3, 7, 13, 21, 57, 75, 63, 53, 487, 251, 3193, 4279, 2311, 6613, 38319, 93557, 0 };
            const std::uint32_t dim9797JoeKuoD6Init[]   =   { 1, 3, 5, 5, 31, 35, 39, 255, 11, 81, 605, 1457, 6367, 14121, 8069, 46653, 79945, 0 };
            const std::uint32_t dim9798JoeKuoD6Init[]   =   { 1, 1, 1, 7, 17, 19, 19, 247, 13, 757, 1069, 2811, 4969, 10943, 29399, 4153, 120817, 0 };
            const std::uint32_t dim9799JoeKuoD6Init[]   =   { 1, 1, 1, 15, 31, 13, 1, 247, 157, 785, 1565, 897, 4825, 8375, 4933, 60671, 88403, 0 };
            const std::uint32_t dim9800JoeKuoD6Init[]   =   { 1, 3, 3, 7, 31, 53, 117, 207, 243, 603, 625, 1039, 5725, 5021, 20227, 28613, 123759, 0 };
            const std::uint32_t dim9801JoeKuoD6Init[]   =   { 1, 1, 5, 1, 7, 29, 65, 153, 393, 821, 295, 2705, 5999, 15801, 31301, 15545, 52917, 0 };
            const std::uint32_t dim9802JoeKuoD6Init[]   =   { 1, 1, 1, 1, 11, 51, 97, 143, 27, 279, 1005, 1235, 5539, 1523, 26293, 35015, 47835, 0 };
            const std::uint32_t dim9803JoeKuoD6Init[]   =   { 1, 3, 3, 13, 27, 17, 123, 147, 39, 35, 567, 961, 5431, 5557, 17849, 46675, 102181, 0 };
            const std::uint32_t dim9804JoeKuoD6Init[]   =   { 1, 1, 7, 11, 7, 25, 73, 223, 459, 207, 1637, 647, 2057, 685, 24539, 48809, 26877, 0 };
            const std::uint32_t dim9805JoeKuoD6Init[]   =   { 1, 3, 1, 3, 21, 43, 121, 11, 431, 383, 1703, 1451, 2349, 11845, 13801, 20589, 43125, 0 };
            const std::uint32_t dim9806JoeKuoD6Init[]   =   { 1, 1, 5, 1, 27, 29, 89, 233, 437, 303, 853, 3425, 263, 2073, 14111, 39129, 59547, 0 };
            const std::uint32_t dim9807JoeKuoD6Init[]   =   { 1, 1, 1, 3, 3, 47, 99, 207, 261, 179, 1761, 2657, 4339, 6567, 25455, 18729, 51431, 0 };
            const std::uint32_t dim9808JoeKuoD6Init[]   =   { 1, 3, 3, 13, 5, 5, 109, 125, 123, 233, 1713, 1539, 4375, 12187, 18355, 49597, 109959, 0 };
            const std::uint32_t dim9809JoeKuoD6Init[]   =   { 1, 3, 7, 7, 9, 23, 45, 193, 363, 837, 855, 1413, 7587, 9091, 27907, 17809, 63249, 0 };
            const std::uint32_t dim9810JoeKuoD6Init[]   =   { 1, 3, 3, 9, 19, 23, 63, 85, 419, 1007, 1753, 539, 1471, 2171, 9239, 36289, 105503, 0 };
            const std::uint32_t dim9811JoeKuoD6Init[]   =   { 1, 3, 1, 11, 23, 5, 105, 79, 473, 879, 1623, 3155, 5157, 4699, 697, 41919, 15441, 0 };
            const std::uint32_t dim9812JoeKuoD6Init[]   =   { 1, 1, 7, 11, 5, 21, 43, 207, 491, 355, 857, 2325, 819, 15849, 24529, 5789, 110661, 0 };
            const std::uint32_t dim9813JoeKuoD6Init[]   =   { 1, 1, 5, 15, 19, 33, 81, 137, 473, 853, 1681, 3841, 5617, 13715, 1987, 52983, 66327, 0 };
            const std::uint32_t dim9814JoeKuoD6Init[]   =   { 1, 3, 5, 7, 11, 31, 69, 85, 33, 197, 1771, 1957, 1311, 169, 14159, 7327, 8577, 0 };
            const std::uint32_t dim9815JoeKuoD6Init[]   =   { 1, 1, 3, 9, 11, 23, 19, 143, 9, 579, 111, 2973, 3567, 8561, 10447, 55875, 64305, 0 };
            const std::uint32_t dim9816JoeKuoD6Init[]   =   { 1, 1, 5, 7, 1, 17, 93, 11, 423, 1007, 839, 719, 3965, 14531, 17301, 29577, 4083, 0 };
            const std::uint32_t dim9817JoeKuoD6Init[]   =   { 1, 3, 5, 13, 19, 17, 123, 61, 59, 115, 1165, 579, 2545, 633, 5597, 21865, 109167, 0 };
            const std::uint32_t dim9818JoeKuoD6Init[]   =   { 1, 1, 5, 3, 29, 29, 99, 163, 321, 367, 1523, 3719, 665, 15843, 28831, 63823, 113533, 0 };
            const std::uint32_t dim9819JoeKuoD6Init[]   =   { 1, 1, 1, 3, 15, 7, 85, 1, 181, 759, 537, 3315, 7159, 4363, 4183, 53775, 8801, 0 };
            const std::uint32_t dim9820JoeKuoD6Init[]   =   { 1, 3, 1, 1, 15, 53, 9, 35, 459, 417, 1169, 2055, 1175, 10923, 335, 24269, 93001, 0 };
            const std::uint32_t dim9821JoeKuoD6Init[]   =   { 1, 3, 1, 5, 31, 43, 51, 149, 175, 541, 629, 1147, 7585, 9725, 18623, 13345, 65391, 0 };
            const std::uint32_t dim9822JoeKuoD6Init[]   =   { 1, 3, 7, 1, 13, 39, 13, 217, 507, 765, 721, 1491, 5037, 6267, 2871, 19181, 123751, 0 };
            const std::uint32_t dim9823JoeKuoD6Init[]   =   { 1, 1, 3, 5, 21, 9, 123, 195, 63, 347, 7, 531, 3015, 9457, 29543, 51479, 26607, 0 };
            const std::uint32_t dim9824JoeKuoD6Init[]   =   { 1, 1, 1, 1, 21, 15, 81, 127, 429, 15, 901, 1503, 1919, 6515, 2477, 53571, 113447, 0 };
            const std::uint32_t dim9825JoeKuoD6Init[]   =   { 1, 3, 1, 13, 9, 33, 79, 169, 499, 767, 441, 2085, 2429, 10213, 4125, 2611, 26137, 0 };
            const std::uint32_t dim9826JoeKuoD6Init[]   =   { 1, 1, 3, 1, 19, 23, 83, 179, 447, 513, 913, 1201, 1861, 11595, 29037, 7775, 116417, 0 };
            const std::uint32_t dim9827JoeKuoD6Init[]   =   { 1, 3, 3, 7, 3, 57, 47, 183, 413, 319, 1375, 1401, 2231, 14331, 28625, 43839, 102717, 0 };
            const std::uint32_t dim9828JoeKuoD6Init[]   =   { 1, 1, 5, 11, 31, 27, 111, 85, 191, 155, 2025, 1501, 4991, 4655, 3451, 10219, 60391, 0 };
            const std::uint32_t dim9829JoeKuoD6Init[]   =   { 1, 3, 3, 7, 17, 19, 113, 37, 423, 479, 709, 3659, 6567, 1709, 13483, 61821, 77101, 0 };
            const std::uint32_t dim9830JoeKuoD6Init[]   =   { 1, 3, 1, 13, 3, 17, 73, 61, 275, 359, 1341, 449, 1373, 12047, 11207, 52651, 83305, 0 };
            const std::uint32_t dim9831JoeKuoD6Init[]   =   { 1, 1, 7, 9, 9, 45, 15, 121, 15, 51, 509, 2189, 5057, 6119, 11669, 14559, 108323, 0 };
            const std::uint32_t dim9832JoeKuoD6Init[]   =   { 1, 1, 7, 7, 25, 13, 13, 141, 157, 249, 823, 821, 1909, 5925, 3505, 13187, 19237, 0 };
            const std::uint32_t dim9833JoeKuoD6Init[]   =   { 1, 3, 3, 1, 9, 51, 79, 91, 5, 709, 787, 2427, 4613, 7307, 20141, 1675, 49779, 0 };
            const std::uint32_t dim9834JoeKuoD6Init[]   =   { 1, 1, 1, 11, 11, 13, 33, 81, 413, 981, 907, 2709, 4113, 10607, 2587, 12845, 11103, 0 };
            const std::uint32_t dim9835JoeKuoD6Init[]   =   { 1, 1, 7, 9, 13, 25, 37, 81, 375, 1013, 2027, 321, 3947, 2269, 10687, 7537, 67495, 0 };
            const std::uint32_t dim9836JoeKuoD6Init[]   =   { 1, 3, 5, 11, 9, 43, 53, 111, 339, 841, 503, 3209, 6437, 10893, 13627, 51809, 57229, 0 };
            const std::uint32_t dim9837JoeKuoD6Init[]   =   { 1, 3, 1, 1, 21, 15, 71, 93, 453, 405, 1099, 2979, 7471, 10173, 17875, 13179, 48615, 0 };
            const std::uint32_t dim9838JoeKuoD6Init[]   =   { 1, 3, 5, 9, 9, 1, 121, 117, 275, 157, 57, 3459, 4787, 15005, 24591, 23963, 45077, 0 };
            const std::uint32_t dim9839JoeKuoD6Init[]   =   { 1, 1, 5, 3, 21, 57, 113, 207, 169, 603, 637, 1455, 6281, 6527, 17219, 32307, 18617, 0 };
            const std::uint32_t dim9840JoeKuoD6Init[]   =   { 1, 3, 7, 5, 25, 15, 99, 91, 253, 267, 537, 713, 3929, 895, 7999, 47989, 118731, 0 };
            const std::uint32_t dim9841JoeKuoD6Init[]   =   { 1, 3, 7, 15, 23, 17, 5, 129, 121, 251, 219, 2547, 7291, 1079, 14577, 56229, 35253, 0 };
            const std::uint32_t dim9842JoeKuoD6Init[]   =   { 1, 3, 1, 15, 5, 61, 35, 135, 497, 681, 751, 2303, 6697, 11225, 30389, 61673, 87313, 0 };
            const std::uint32_t dim9843JoeKuoD6Init[]   =   { 1, 3, 1, 7, 7, 37, 9, 85, 257, 805, 1325, 3597, 6065, 727, 18203, 57077, 437, 0 };
            const std::uint32_t dim9844JoeKuoD6Init[]   =   { 1, 3, 5, 7, 5, 43, 29, 179, 73, 173, 1441, 1233, 1779, 7893, 10629, 27547, 7775, 0 };
            const std::uint32_t dim9845JoeKuoD6Init[]   =   { 1, 1, 7, 5, 31, 29, 21, 35, 289, 423, 449, 3331, 2929, 6827, 15569, 9873, 76889, 0 };
            const std::uint32_t dim9846JoeKuoD6Init[]   =   { 1, 1, 7, 13, 13, 37, 55, 99, 135, 797, 1263, 2539, 893, 4225, 16689, 38259, 50857, 0 };
            const std::uint32_t dim9847JoeKuoD6Init[]   =   { 1, 1, 3, 1, 5, 3, 95, 29, 15, 539, 825, 3931, 4809, 8299, 29891, 61357, 97523, 0 };
            const std::uint32_t dim9848JoeKuoD6Init[]   =   { 1, 3, 1, 9, 27, 25, 115, 239, 387, 163, 1153, 31, 2375, 7943, 31929, 1121, 33085, 0 };
            const std::uint32_t dim9849JoeKuoD6Init[]   =   { 1, 3, 5, 9, 3, 53, 121, 159, 165, 81, 317, 3051, 1991, 493, 2029, 43305, 130209, 0 };
            const std::uint32_t dim9850JoeKuoD6Init[]   =   { 1, 1, 1, 5, 9, 57, 39, 247, 73, 613, 1047, 3289, 2569, 5363, 18475, 32749, 39415, 0 };
            const std::uint32_t dim9851JoeKuoD6Init[]   =   { 1, 3, 1, 5, 19, 23, 39, 33, 151, 463, 153, 737, 2501, 7531, 2769, 35595, 71799, 0 };
            const std::uint32_t dim9852JoeKuoD6Init[]   =   { 1, 3, 5, 5, 29, 49, 105, 81, 67, 441, 1101, 2241, 6243, 6177, 7157, 51635, 81241, 0 };
            const std::uint32_t dim9853JoeKuoD6Init[]   =   { 1, 3, 3, 3, 29, 53, 13, 239, 487, 503, 97, 1323, 1817, 13021, 12881, 26943, 21011, 0 };
            const std::uint32_t dim9854JoeKuoD6Init[]   =   { 1, 1, 1, 15, 25, 9, 5, 205, 85, 635, 789, 2495, 5069, 4987, 847, 26857, 84225, 0 };
            const std::uint32_t dim9855JoeKuoD6Init[]   =   { 1, 1, 3, 15, 9, 51, 79, 13, 377, 637, 159, 3407, 2057, 13967, 31781, 40869, 52987, 0 };
            const std::uint32_t dim9856JoeKuoD6Init[]   =   { 1, 3, 1, 13, 11, 27, 103, 207, 383, 887, 749, 1119, 285, 4269, 31745, 57539, 5671, 0 };
            const std::uint32_t dim9857JoeKuoD6Init[]   =   { 1, 3, 1, 13, 23, 19, 41, 43, 455, 425, 1653, 4091, 4855, 16321, 169, 59289, 82397, 0 };
            const std::uint32_t dim9858JoeKuoD6Init[]   =   { 1, 3, 3, 15, 31, 39, 51, 127, 391, 989, 1831, 3327, 6487, 6077, 17277, 52093, 20389, 0 };
            const std::uint32_t dim9859JoeKuoD6Init[]   =   { 1, 3, 5, 15, 19, 1, 21, 241, 15, 543, 1529, 2355, 1503, 12795, 17321, 41219, 61115, 0 };
            const std::uint32_t dim9860JoeKuoD6Init[]   =   { 1, 1, 3, 11, 9, 33, 21, 197, 307, 141, 1663, 371, 1663, 8307, 3617, 56941, 62477, 0 };
            const std::uint32_t dim9861JoeKuoD6Init[]   =   { 1, 3, 7, 9, 19, 53, 123, 3, 29, 635, 1795, 2471, 2491, 15847, 9169, 2561, 101515, 0 };
            const std::uint32_t dim9862JoeKuoD6Init[]   =   { 1, 1, 5, 3, 19, 11, 117, 231, 475, 837, 1833, 3499, 4415, 9961, 28285, 37821, 81497, 0 };
            const std::uint32_t dim9863JoeKuoD6Init[]   =   { 1, 1, 3, 5, 7, 11, 57, 89, 345, 157, 1519, 3021, 7157, 2159, 32557, 31559, 128907, 0 };
            const std::uint32_t dim9864JoeKuoD6Init[]   =   { 1, 1, 7, 3, 27, 1, 15, 177, 489, 405, 811, 3597, 4939, 15595, 7279, 58097, 84703, 0 };
            const std::uint32_t dim9865JoeKuoD6Init[]   =   { 1, 3, 1, 9, 25, 61, 119, 219, 111, 339, 1091, 759, 6087, 16001, 6757, 15627, 1691, 0 };
            const std::uint32_t dim9866JoeKuoD6Init[]   =   { 1, 3, 7, 9, 1, 39, 107, 139, 143, 917, 421, 1623, 7135, 4851, 6687, 6177, 102425, 0 };
            const std::uint32_t dim9867JoeKuoD6Init[]   =   { 1, 1, 7, 13, 23, 17, 19, 167, 317, 331, 743, 3737, 2195, 545, 2185, 9125, 30503, 0 };
            const std::uint32_t dim9868JoeKuoD6Init[]   =   { 1, 1, 5, 13, 27, 33, 117, 141, 493, 129, 1553, 2335, 4161, 14205, 24177, 35163, 84869, 0 };
            const std::uint32_t dim9869JoeKuoD6Init[]   =   { 1, 3, 7, 1, 11, 9, 75, 133, 113, 507, 2007, 2473, 4769, 14655, 17967, 17709, 90653, 0 };
            const std::uint32_t dim9870JoeKuoD6Init[]   =   { 1, 1, 7, 11, 17, 11, 83, 23, 387, 61, 29, 3905, 4351, 15173, 28375, 9129, 111939, 0 };
            const std::uint32_t dim9871JoeKuoD6Init[]   =   { 1, 1, 5, 15, 15, 53, 81, 125, 189, 937, 1607, 2595, 2847, 7229, 22241, 26269, 64781, 0 };
            const std::uint32_t dim9872JoeKuoD6Init[]   =   { 1, 3, 1, 7, 5, 11, 61, 111, 13, 423, 885, 2329, 6003, 16331, 11207, 25743, 54619, 0 };
            const std::uint32_t dim9873JoeKuoD6Init[]   =   { 1, 3, 5, 9, 1, 13, 95, 241, 237, 629, 263, 1629, 1063, 12695, 14501, 5455, 121483, 0 };
            const std::uint32_t dim9874JoeKuoD6Init[]   =   { 1, 1, 7, 15, 5, 17, 45, 255, 143, 79, 87, 1755, 6215, 5095, 32411, 8695, 85511, 0 };
            const std::uint32_t dim9875JoeKuoD6Init[]   =   { 1, 3, 7, 7, 21, 11, 117, 135, 333, 73, 1471, 2749, 5801, 4209, 9353, 46171, 90645, 0 };
            const std::uint32_t dim9876JoeKuoD6Init[]   =   { 1, 1, 7, 13, 11, 35, 77, 149, 159, 783, 1527, 2881, 1409, 3455, 26991, 3225, 30693, 0 };
            const std::uint32_t dim9877JoeKuoD6Init[]   =   { 1, 1, 3, 15, 19, 55, 21, 245, 207, 103, 775, 2041, 4637, 7333, 11267, 60509, 43099, 0 };
            const std::uint32_t dim9878JoeKuoD6Init[]   =   { 1, 3, 3, 15, 17, 63, 23, 81, 183, 923, 75, 391, 615, 13343, 20839, 56529, 115747, 0 };
            const std::uint32_t dim9879JoeKuoD6Init[]   =   { 1, 3, 1, 13, 5, 5, 15, 27, 263, 497, 1365, 2733, 5395, 7461, 2725, 24735, 89251, 0 };
            const std::uint32_t dim9880JoeKuoD6Init[]   =   { 1, 1, 7, 7, 29, 17, 39, 117, 363, 915, 123, 283, 4575, 3497, 20995, 37883, 16645, 0 };
            const std::uint32_t dim9881JoeKuoD6Init[]   =   { 1, 3, 3, 9, 1, 25, 79, 181, 331, 617, 393, 1807, 5145, 8007, 9173, 45189, 37945, 0 };
            const std::uint32_t dim9882JoeKuoD6Init[]   =   { 1, 3, 1, 5, 1, 9, 127, 137, 379, 371, 367, 3237, 581, 15295, 18191, 37689, 103495, 0 };
            const std::uint32_t dim9883JoeKuoD6Init[]   =   { 1, 1, 7, 1, 29, 53, 103, 173, 171, 973, 933, 3847, 3185, 10107, 31701, 45021, 106251, 0 };
            const std::uint32_t dim9884JoeKuoD6Init[]   =   { 1, 1, 1, 7, 23, 9, 61, 25, 343, 471, 2041, 2179, 7647, 1885, 15353, 50379, 67681, 0 };
            const std::uint32_t dim9885JoeKuoD6Init[]   =   { 1, 1, 5, 11, 31, 13, 51, 185, 83, 917, 85, 1317, 8185, 14949, 32455, 57939, 1217, 0 };
            const std::uint32_t dim9886JoeKuoD6Init[]   =   { 1, 1, 7, 5, 23, 45, 101, 227, 497, 941, 985, 167, 6847, 9611, 20011, 40069, 83285, 0 };
            const std::uint32_t dim9887JoeKuoD6Init[]   =   { 1, 1, 5, 13, 17, 33, 61, 197, 433, 255, 67, 1479, 5663, 6501, 30695, 27235, 80141, 0 };
            const std::uint32_t dim9888JoeKuoD6Init[]   =   { 1, 1, 3, 5, 11, 45, 123, 49, 327, 893, 1963, 2225, 2611, 8925, 22811, 2313, 8411, 0 };
            const std::uint32_t dim9889JoeKuoD6Init[]   =   { 1, 3, 7, 7, 15, 39, 75, 235, 13, 847, 575, 3947, 6947, 2061, 13467, 103, 86285, 0 };
            const std::uint32_t dim9890JoeKuoD6Init[]   =   { 1, 1, 7, 3, 21, 43, 113, 197, 141, 873, 1139, 2707, 7235, 10683, 10831, 33695, 57063, 0 };
            const std::uint32_t dim9891JoeKuoD6Init[]   =   { 1, 3, 5, 1, 3, 27, 45, 43, 119, 979, 1933, 1851, 6497, 14937, 4965, 41285, 120221, 0 };
            const std::uint32_t dim9892JoeKuoD6Init[]   =   { 1, 1, 3, 1, 23, 59, 67, 7, 49, 351, 1053, 1837, 501, 7671, 26239, 51951, 95119, 0 };
            const std::uint32_t dim9893JoeKuoD6Init[]   =   { 1, 3, 5, 11, 3, 19, 33, 33, 219, 175, 1439, 197, 1841, 159, 11229, 20463, 81797, 0 };
            const std::uint32_t dim9894JoeKuoD6Init[]   =   { 1, 1, 7, 1, 13, 11, 79, 75, 53, 525, 91, 233, 5999, 2921, 21295, 56831, 116049, 0 };
            const std::uint32_t dim9895JoeKuoD6Init[]   =   { 1, 3, 3, 13, 29, 7, 71, 207, 193, 635, 1393, 3093, 3775, 12445, 23281, 29401, 103225, 0 };
            const std::uint32_t dim9896JoeKuoD6Init[]   =   { 1, 1, 7, 3, 29, 57, 111, 163, 63, 593, 881, 1587, 3027, 12599, 30977, 38891, 95495, 0 };
            const std::uint32_t dim9897JoeKuoD6Init[]   =   { 1, 1, 5, 15, 17, 57, 111, 169, 149, 767, 377, 765, 7533, 1539, 22979, 55489, 29799, 0 };
            const std::uint32_t dim9898JoeKuoD6Init[]   =   { 1, 3, 5, 15, 25, 7, 127, 71, 319, 389, 497, 1513, 1287, 7359, 12311, 45457, 45897, 0 };
            const std::uint32_t dim9899JoeKuoD6Init[]   =   { 1, 1, 5, 3, 3, 35, 45, 17, 49, 483, 197, 727, 5355, 7201, 3035, 14313, 40933, 0 };
            const std::uint32_t dim9900JoeKuoD6Init[]   =   { 1, 1, 7, 15, 1, 9, 27, 59, 455, 653, 1907, 281, 1435, 14593, 18909, 37655, 87603, 0 };
            const std::uint32_t dim9901JoeKuoD6Init[]   =   { 1, 1, 7, 11, 29, 9, 67, 17, 353, 709, 859, 3687, 7741, 4251, 12263, 41717, 79393, 0 };
            const std::uint32_t dim9902JoeKuoD6Init[]   =   { 1, 3, 3, 3, 1, 15, 113, 187, 255, 851, 503, 4089, 7923, 1701, 305, 8353, 16357, 0 };
            const std::uint32_t dim9903JoeKuoD6Init[]   =   { 1, 1, 5, 3, 17, 31, 29, 233, 377, 215, 1889, 3459, 2443, 3907, 4193, 16519, 49089, 0 };
            const std::uint32_t dim9904JoeKuoD6Init[]   =   { 1, 1, 3, 1, 17, 39, 11, 255, 247, 305, 669, 1769, 1355, 12055, 2275, 51681, 112337, 0 };
            const std::uint32_t dim9905JoeKuoD6Init[]   =   { 1, 3, 1, 1, 17, 17, 75, 95, 409, 21, 1513, 1443, 4931, 6491, 1587, 62979, 90395, 0 };
            const std::uint32_t dim9906JoeKuoD6Init[]   =   { 1, 1, 3, 5, 3, 19, 125, 175, 279, 911, 301, 407, 7773, 949, 32107, 13571, 58717, 0 };
            const std::uint32_t dim9907JoeKuoD6Init[]   =   { 1, 3, 3, 15, 31, 35, 11, 223, 125, 209, 1719, 1725, 3387, 14879, 32243, 7219, 126791, 0 };
            const std::uint32_t dim9908JoeKuoD6Init[]   =   { 1, 1, 3, 1, 31, 29, 67, 79, 93, 193, 1573, 2285, 3209, 8397, 17717, 5657, 61545, 0 };
            const std::uint32_t dim9909JoeKuoD6Init[]   =   { 1, 3, 1, 9, 11, 33, 85, 121, 193, 63, 461, 1835, 889, 10687, 19831, 49551, 59087, 0 };
            const std::uint32_t dim9910JoeKuoD6Init[]   =   { 1, 3, 3, 7, 11, 3, 9, 87, 91, 487, 289, 1113, 8135, 7971, 16693, 31009, 81197, 0 };
            const std::uint32_t dim9911JoeKuoD6Init[]   =   { 1, 3, 3, 1, 23, 23, 61, 209, 409, 845, 547, 1493, 465, 6399, 17633, 53647, 52425, 0 };
            const std::uint32_t dim9912JoeKuoD6Init[]   =   { 1, 1, 7, 7, 21, 31, 71, 249, 63, 895, 653, 93, 4429, 8951, 16873, 48089, 33947, 0 };
            const std::uint32_t dim9913JoeKuoD6Init[]   =   { 1, 3, 5, 11, 3, 35, 49, 15, 379, 645, 855, 3657, 8019, 2141, 11233, 60731, 80455, 0 };
            const std::uint32_t dim9914JoeKuoD6Init[]   =   { 1, 3, 1, 3, 1, 53, 101, 157, 255, 765, 1575, 1615, 7677, 9699, 13351, 2207, 90939, 0 };
            const std::uint32_t dim9915JoeKuoD6Init[]   =   { 1, 3, 7, 7, 5, 43, 123, 109, 119, 391, 1889, 1991, 3151, 1457, 16321, 65245, 75891, 0 };
            const std::uint32_t dim9916JoeKuoD6Init[]   =   { 1, 3, 1, 15, 9, 1, 113, 249, 1, 675, 501, 487, 2209, 4411, 6609, 29243, 100177, 0 };
            const std::uint32_t dim9917JoeKuoD6Init[]   =   { 1, 1, 1, 7, 9, 23, 9, 197, 341, 191, 453, 3733, 5475, 15515, 28979, 36077, 17801, 0 };
            const std::uint32_t dim9918JoeKuoD6Init[]   =   { 1, 1, 3, 13, 5, 35, 85, 121, 59, 429, 1251, 3437, 3121, 12411, 14713, 28125, 31921, 0 };
            const std::uint32_t dim9919JoeKuoD6Init[]   =   { 1, 3, 5, 3, 27, 17, 61, 255, 485, 709, 83, 3201, 2191, 3371, 2941, 10931, 22141, 0 };
            const std::uint32_t dim9920JoeKuoD6Init[]   =   { 1, 1, 1, 1, 19, 19, 25, 177, 397, 579, 529, 1619, 3887, 4537, 8123, 52481, 8305, 0 };
            const std::uint32_t dim9921JoeKuoD6Init[]   =   { 1, 1, 3, 15, 3, 15, 77, 51, 31, 881, 203, 2359, 4947, 6321, 14705, 16471, 84395, 0 };
            const std::uint32_t dim9922JoeKuoD6Init[]   =   { 1, 3, 7, 9, 13, 53, 67, 41, 289, 721, 1743, 2725, 435, 1327, 14953, 14283, 113211, 0 };
            const std::uint32_t dim9923JoeKuoD6Init[]   =   { 1, 3, 1, 5, 19, 23, 73, 181, 187, 675, 125, 1877, 6167, 7919, 3955, 25007, 28299, 0 };
            const std::uint32_t dim9924JoeKuoD6Init[]   =   { 1, 1, 3, 1, 5, 11, 123, 189, 173, 123, 499, 2175, 483, 13017, 14709, 5797, 36327, 0 };
            const std::uint32_t dim9925JoeKuoD6Init[]   =   { 1, 3, 7, 5, 21, 39, 79, 229, 19, 203, 375, 3901, 1053, 14209, 13535, 63155, 99727, 0 };
            const std::uint32_t dim9926JoeKuoD6Init[]   =   { 1, 1, 1, 13, 11, 29, 29, 173, 441, 271, 1147, 2891, 965, 10777, 16325, 37135, 101601, 0 };
            const std::uint32_t dim9927JoeKuoD6Init[]   =   { 1, 1, 3, 3, 25, 13, 79, 233, 75, 191, 987, 3231, 3667, 1525, 14193, 62027, 77441, 0 };
            const std::uint32_t dim9928JoeKuoD6Init[]   =   { 1, 3, 1, 1, 15, 53, 17, 45, 367, 263, 425, 1565, 6139, 13833, 12547, 61103, 75361, 0 };
            const std::uint32_t dim9929JoeKuoD6Init[]   =   { 1, 1, 5, 15, 5, 57, 123, 47, 407, 887, 375, 1181, 5367, 10283, 24799, 33121, 76373, 0 };
            const std::uint32_t dim9930JoeKuoD6Init[]   =   { 1, 1, 7, 3, 11, 17, 65, 133, 3, 609, 601, 3391, 7801, 4137, 32095, 55983, 23037, 0 };
            const std::uint32_t dim9931JoeKuoD6Init[]   =   { 1, 3, 1, 3, 25, 5, 125, 5, 297, 571, 145, 3601, 1929, 13457, 16977, 21049, 92169, 0 };
            const std::uint32_t dim9932JoeKuoD6Init[]   =   { 1, 3, 5, 13, 23, 29, 13, 143, 507, 187, 857, 427, 5125, 1377, 10947, 58473, 110541, 0 };
            const std::uint32_t dim9933JoeKuoD6Init[]   =   { 1, 3, 3, 15, 15, 49, 39, 103, 193, 507, 639, 2399, 3829, 12105, 15993, 52975, 115935, 0 };
            const std::uint32_t dim9934JoeKuoD6Init[]   =   { 1, 3, 7, 3, 7, 41, 95, 127, 193, 923, 1729, 3039, 7959, 3345, 7725, 35293, 34361, 0 };
            const std::uint32_t dim9935JoeKuoD6Init[]   =   { 1, 3, 5, 13, 17, 53, 111, 141, 151, 389, 1955, 3333, 4523, 6331, 21239, 57447, 113325, 0 };
            const std::uint32_t dim9936JoeKuoD6Init[]   =   { 1, 3, 7, 15, 31, 7, 11, 35, 105, 607, 1665, 3281, 487, 9417, 26205, 26963, 81537, 0 };
            const std::uint32_t dim9937JoeKuoD6Init[]   =   { 1, 3, 1, 1, 17, 15, 3, 55, 451, 691, 1525, 2009, 6443, 4629, 15091, 46961, 83361, 0 };
            const std::uint32_t dim9938JoeKuoD6Init[]   =   { 1, 3, 1, 15, 1, 29, 99, 79, 225, 665, 623, 2389, 3303, 7221, 20567, 15917, 24677, 0 };
            const std::uint32_t dim9939JoeKuoD6Init[]   =   { 1, 1, 3, 15, 3, 17, 125, 239, 485, 849, 327, 1459, 3911, 2145, 14475, 24337, 19695, 0 };
            const std::uint32_t dim9940JoeKuoD6Init[]   =   { 1, 3, 5, 7, 7, 37, 19, 51, 373, 587, 147, 563, 7623, 7781, 18289, 37239, 6803, 0 };
            const std::uint32_t dim9941JoeKuoD6Init[]   =   { 1, 3, 5, 1, 9, 63, 5, 87, 171, 5, 1553, 429, 5001, 7881, 1493, 20425, 57727, 0 };
            const std::uint32_t dim9942JoeKuoD6Init[]   =   { 1, 3, 5, 9, 25, 43, 17, 71, 87, 869, 1219, 2661, 4571, 9689, 18799, 62467, 128531, 0 };
            const std::uint32_t dim9943JoeKuoD6Init[]   =   { 1, 1, 3, 3, 19, 53, 61, 9, 55, 433, 1555, 2369, 1423, 9081, 19185, 8513, 111079, 0 };
            const std::uint32_t dim9944JoeKuoD6Init[]   =   { 1, 3, 5, 15, 11, 61, 1, 147, 17, 71, 1563, 1113, 4809, 16229, 23743, 59757, 64699, 0 };
            const std::uint32_t dim9945JoeKuoD6Init[]   =   { 1, 1, 5, 11, 29, 23, 61, 43, 203, 97, 1119, 237, 6445, 14507, 9799, 18447, 14745, 0 };
            const std::uint32_t dim9946JoeKuoD6Init[]   =   { 1, 3, 5, 15, 11, 17, 117, 139, 117, 537, 251, 149, 2731, 15863, 1381, 25435, 25501, 0 };
            const std::uint32_t dim9947JoeKuoD6Init[]   =   { 1, 3, 3, 15, 31, 57, 53, 43, 95, 445, 1423, 3833, 2485, 11789, 16011, 8101, 39165, 0 };
            const std::uint32_t dim9948JoeKuoD6Init[]   =   { 1, 1, 3, 11, 15, 37, 117, 3, 245, 57, 593, 2771, 7181, 11397, 5691, 3217, 44139, 0 };
            const std::uint32_t dim9949JoeKuoD6Init[]   =   { 1, 3, 5, 1, 11, 13, 121, 85, 85, 511, 1837, 611, 237, 4893, 24025, 28903, 102025, 0 };
            const std::uint32_t dim9950JoeKuoD6Init[]   =   { 1, 3, 1, 11, 5, 45, 43, 45, 393, 741, 1157, 1511, 1665, 2359, 19071, 24537, 122879, 0 };
            const std::uint32_t dim9951JoeKuoD6Init[]   =   { 1, 3, 3, 3, 9, 59, 27, 11, 257, 203, 1535, 2729, 2313, 3539, 1689, 31901, 42949, 0 };
            const std::uint32_t dim9952JoeKuoD6Init[]   =   { 1, 1, 1, 11, 17, 7, 21, 35, 479, 697, 107, 1317, 6585, 705, 3789, 20439, 33375, 0 };
            const std::uint32_t dim9953JoeKuoD6Init[]   =   { 1, 1, 3, 11, 19, 37, 123, 233, 253, 733, 901, 3047, 3595, 2357, 24533, 40519, 109171, 0 };
            const std::uint32_t dim9954JoeKuoD6Init[]   =   { 1, 3, 3, 13, 29, 51, 25, 149, 57, 253, 2001, 351, 7367, 15361, 4955, 60951, 19449, 0 };
            const std::uint32_t dim9955JoeKuoD6Init[]   =   { 1, 1, 3, 15, 21, 53, 25, 239, 257, 437, 711, 3599, 5441, 7405, 15039, 19207, 63841, 0 };
            const std::uint32_t dim9956JoeKuoD6Init[]   =   { 1, 3, 1, 9, 17, 41, 43, 231, 413, 747, 1447, 1407, 2615, 14529, 10781, 20001, 82713, 0 };
            const std::uint32_t dim9957JoeKuoD6Init[]   =   { 1, 3, 7, 7, 9, 29, 25, 55, 53, 423, 1711, 2871, 2675, 421, 31703, 57099, 2955, 0 };
            const std::uint32_t dim9958JoeKuoD6Init[]   =   { 1, 3, 1, 7, 31, 17, 113, 83, 387, 611, 1815, 2137, 3453, 4409, 20377, 60263, 81205, 0 };
            const std::uint32_t dim9959JoeKuoD6Init[]   =   { 1, 1, 5, 3, 11, 1, 7, 225, 367, 267, 95, 939, 3801, 2619, 1207, 62695, 116407, 0 };
            const std::uint32_t dim9960JoeKuoD6Init[]   =   { 1, 3, 3, 9, 5, 39, 85, 45, 247, 483, 491, 865, 3493, 8243, 8411, 26449, 50473, 0 };
            const std::uint32_t dim9961JoeKuoD6Init[]   =   { 1, 3, 3, 9, 1, 53, 23, 127, 13, 529, 1925, 2629, 3451, 15073, 16075, 29909, 34101, 0 };
            const std::uint32_t dim9962JoeKuoD6Init[]   =   { 1, 3, 1, 11, 1, 9, 125, 57, 79, 633, 979, 3843, 325, 883, 7769, 40155, 104057, 0 };
            const std::uint32_t dim9963JoeKuoD6Init[]   =   { 1, 1, 7, 13, 23, 53, 27, 157, 493, 901, 1077, 1079, 1327, 15903, 20603, 64377, 103335, 0 };
            const std::uint32_t dim9964JoeKuoD6Init[]   =   { 1, 3, 3, 3, 3, 35, 37, 167, 73, 301, 385, 1045, 6913, 2269, 22491, 19735, 70125, 0 };
            const std::uint32_t dim9965JoeKuoD6Init[]   =   { 1, 1, 1, 11, 5, 23, 23, 85, 267, 845, 207, 77, 1245, 16209, 25579, 12417, 48723, 0 };
            const std::uint32_t dim9966JoeKuoD6Init[]   =   { 1, 1, 5, 15, 11, 17, 43, 83, 373, 1005, 541, 115, 163, 2165, 8181, 35839, 44471, 0 };
            const std::uint32_t dim9967JoeKuoD6Init[]   =   { 1, 3, 5, 7, 27, 41, 101, 13, 213, 235, 2037, 2179, 2121, 4481, 8127, 20011, 3981, 0 };
            const std::uint32_t dim9968JoeKuoD6Init[]   =   { 1, 1, 5, 11, 7, 43, 59, 129, 127, 387, 489, 1985, 623, 13307, 19765, 62155, 93271, 0 };
            const std::uint32_t dim9969JoeKuoD6Init[]   =   { 1, 1, 7, 5, 23, 63, 23, 177, 211, 233, 101, 1809, 7411, 8003, 25101, 32601, 75071, 0 };
            const std::uint32_t dim9970JoeKuoD6Init[]   =   { 1, 1, 1, 11, 3, 25, 9, 91, 459, 611, 867, 3639, 5457, 9101, 15333, 40069, 67723, 0 };
            const std::uint32_t dim9971JoeKuoD6Init[]   =   { 1, 3, 7, 5, 3, 29, 111, 75, 459, 195, 1405, 2281, 6085, 4425, 29061, 57335, 87449, 0 };
            const std::uint32_t dim9972JoeKuoD6Init[]   =   { 1, 3, 7, 11, 21, 45, 53, 81, 77, 863, 1901, 3355, 5253, 10897, 26289, 48399, 26877, 0 };
            const std::uint32_t dim9973JoeKuoD6Init[]   =   { 1, 3, 3, 13, 21, 37, 69, 87, 259, 101, 1203, 167, 6229, 145, 9355, 15347, 68047, 0 };
            const std::uint32_t dim9974JoeKuoD6Init[]   =   { 1, 1, 3, 1, 31, 1, 15, 229, 429, 915, 929, 381, 1857, 8441, 22207, 47071, 127853, 0 };
            const std::uint32_t dim9975JoeKuoD6Init[]   =   { 1, 3, 7, 3, 15, 9, 13, 161, 173, 573, 405, 3253, 7331, 13965, 3061, 40687, 130185, 0 };
            const std::uint32_t dim9976JoeKuoD6Init[]   =   { 1, 3, 5, 5, 29, 29, 9, 115, 393, 377, 909, 321, 2861, 9881, 17863, 52033, 55133, 0 };
            const std::uint32_t dim9977JoeKuoD6Init[]   =   { 1, 1, 7, 7, 27, 53, 101, 213, 199, 301, 1995, 2549, 5037, 13639, 18423, 23547, 79359, 0 };
            const std::uint32_t dim9978JoeKuoD6Init[]   =   { 1, 3, 1, 7, 21, 51, 29, 151, 301, 665, 571, 53, 2637, 7229, 12517, 33647, 49413, 0 };
            const std::uint32_t dim9979JoeKuoD6Init[]   =   { 1, 3, 3, 13, 13, 49, 49, 131, 325, 273, 1127, 2981, 2365, 14287, 23185, 26915, 81755, 0 };
            const std::uint32_t dim9980JoeKuoD6Init[]   =   { 1, 1, 5, 3, 17, 45, 25, 79, 37, 265, 1205, 1805, 6707, 11525, 16473, 39525, 9571, 0 };
            const std::uint32_t dim9981JoeKuoD6Init[]   =   { 1, 3, 3, 15, 9, 43, 55, 101, 469, 939, 365, 3443, 5759, 4751, 28893, 46727, 74569, 0 };
            const std::uint32_t dim9982JoeKuoD6Init[]   =   { 1, 3, 7, 9, 5, 33, 11, 201, 263, 227, 1475, 2795, 1489, 11129, 18053, 31009, 73105, 0 };
            const std::uint32_t dim9983JoeKuoD6Init[]   =   { 1, 3, 5, 5, 5, 25, 41, 151, 393, 237, 2017, 3811, 953, 13835, 28761, 22439, 76355, 0 };
            const std::uint32_t dim9984JoeKuoD6Init[]   =   { 1, 1, 5, 13, 21, 37, 29, 11, 289, 67, 1317, 511, 685, 15227, 8731, 15039, 79491, 0 };
            const std::uint32_t dim9985JoeKuoD6Init[]   =   { 1, 3, 1, 9, 31, 59, 123, 169, 473, 139, 575, 1057, 3213, 8213, 21845, 28123, 105335, 0 };
            const std::uint32_t dim9986JoeKuoD6Init[]   =   { 1, 1, 1, 5, 21, 47, 23, 121, 403, 5, 1457, 2137, 569, 9267, 6367, 6991, 3113, 0 };
            const std::uint32_t dim9987JoeKuoD6Init[]   =   { 1, 3, 3, 7, 13, 7, 25, 215, 81, 1003, 2041, 1317, 3913, 14705, 30551, 50889, 83441, 0 };
            const std::uint32_t dim9988JoeKuoD6Init[]   =   { 1, 3, 3, 3, 13, 17, 63, 229, 83, 901, 953, 2603, 4685, 6961, 7519, 52441, 33223, 0 };
            const std::uint32_t dim9989JoeKuoD6Init[]   =   { 1, 3, 7, 5, 7, 57, 65, 73, 243, 531, 261, 2517, 4083, 5889, 22913, 49603, 67135, 0 };
            const std::uint32_t dim9990JoeKuoD6Init[]   =   { 1, 3, 5, 11, 15, 47, 81, 83, 35, 1021, 1313, 1109, 5103, 5469, 18149, 15307, 34939, 0 };
            const std::uint32_t dim9991JoeKuoD6Init[]   =   { 1, 3, 7, 5, 21, 13, 105, 157, 435, 23, 931, 3565, 1, 4987, 8829, 7327, 51049, 0 };
            const std::uint32_t dim9992JoeKuoD6Init[]   =   { 1, 1, 3, 11, 29, 9, 59, 49, 261, 1009, 1953, 2683, 8125, 10937, 16683, 36013, 5967, 0 };
            const std::uint32_t dim9993JoeKuoD6Init[]   =   { 1, 1, 1, 1, 19, 29, 57, 9, 307, 457, 675, 3023, 495, 15257, 7945, 10449, 30155, 0 };
            const std::uint32_t dim9994JoeKuoD6Init[]   =   { 1, 1, 7, 13, 25, 9, 51, 135, 491, 205, 1715, 3253, 1031, 4137, 14885, 39925, 6061, 0 };
            const std::uint32_t dim9995JoeKuoD6Init[]   =   { 1, 1, 7, 7, 3, 13, 111, 91, 469, 133, 1221, 1035, 919, 3697, 26387, 41675, 487, 0 };
            const std::uint32_t dim9996JoeKuoD6Init[]   =   { 1, 1, 3, 1, 19, 53, 11, 113, 245, 747, 189, 4051, 87, 1767, 3595, 10259, 100097, 0 };
            const std::uint32_t dim9997JoeKuoD6Init[]   =   { 1, 1, 5, 3, 23, 49, 31, 47, 341, 1019, 723, 2353, 6191, 3809, 3297, 39443, 73529, 0 };
            const std::uint32_t dim9998JoeKuoD6Init[]   =   { 1, 3, 3, 9, 25, 27, 123, 49, 51, 85, 1063, 2633, 6549, 14493, 7367, 3557, 60651, 0 };
            const std::uint32_t dim9999JoeKuoD6Init[]   =   { 1, 3, 7, 5, 13, 27, 127, 65, 115, 731, 1147, 283, 91, 14205, 2457, 57083, 35815, 0 };
            const std::uint32_t dim10000JoeKuoD6Init[]   =   { 1, 3, 3, 3, 25, 63, 99, 249, 25, 951, 733, 3621, 7139, 14223, 23641, 20287, 30743, 0 };
            const std::uint32_t dim10001JoeKuoD6Init[]   =   { 1, 3, 3, 7, 21, 23, 83, 207, 235, 467, 1857, 2661, 1391, 10097, 12297, 54825, 5035, 0 };
            const std::uint32_t dim10002JoeKuoD6Init[]   =   { 1, 1, 5, 3, 31, 17, 77, 9, 215, 553, 989, 3643, 729, 2057, 32053, 50305, 5499, 0 };
            const std::uint32_t dim10003JoeKuoD6Init[]   =   { 1, 1, 7, 1, 23, 5, 111, 195, 431, 947, 403, 1781, 943, 15073, 67, 52225, 98987, 0 };
            const std::uint32_t dim10004JoeKuoD6Init[]   =   { 1, 1, 5, 11, 23, 1, 41, 33, 457, 767, 275, 801, 5119, 3781, 14805, 52789, 41775, 0 };
            const std::uint32_t dim10005JoeKuoD6Init[]   =   { 1, 1, 5, 3, 9, 53, 15, 183, 281, 691, 165, 3277, 7673, 1509, 16605, 53799, 100185, 0 };
            const std::uint32_t dim10006JoeKuoD6Init[]   =   { 1, 3, 5, 11, 19, 45, 29, 159, 167, 67, 1259, 879, 7787, 8855, 24153, 42667, 102855, 0 };
            const std::uint32_t dim10007JoeKuoD6Init[]   =   { 1, 1, 7, 13, 31, 19, 43, 133, 295, 287, 1985, 2451, 2297, 3853, 22401, 27659, 11149, 0 };
            const std::uint32_t dim10008JoeKuoD6Init[]   =   { 1, 1, 7, 13, 31, 39, 125, 21, 173, 103, 1119, 3739, 6467, 2113, 4465, 26537, 129949, 0 };
            const std::uint32_t dim10009JoeKuoD6Init[]   =   { 1, 1, 5, 15, 21, 47, 35, 125, 199, 335, 421, 31, 185, 12769, 30659, 33427, 106981, 0 };
            const std::uint32_t dim10010JoeKuoD6Init[]   =   { 1, 3, 5, 13, 25, 35, 53, 253, 325, 921, 1705, 2735, 6437, 2287, 20479, 61107, 91453, 0 };
            const std::uint32_t dim10011JoeKuoD6Init[]   =   { 1, 3, 7, 13, 25, 63, 83, 183, 5, 401, 329, 525, 3141, 393, 30469, 16529, 9605, 0 };
            const std::uint32_t dim10012JoeKuoD6Init[]   =   { 1, 3, 3, 13, 19, 23, 15, 85, 323, 545, 149, 3645, 6269, 15595, 18453, 39, 128169, 0 };
            const std::uint32_t dim10013JoeKuoD6Init[]   =   { 1, 3, 7, 15, 17, 5, 61, 61, 91, 353, 1039, 2959, 4147, 13205, 12599, 53281, 39509, 0 };
            const std::uint32_t dim10014JoeKuoD6Init[]   =   { 1, 1, 3, 7, 21, 9, 97, 111, 249, 775, 845, 1789, 667, 489, 6689, 29217, 56527, 0 };
            const std::uint32_t dim10015JoeKuoD6Init[]   =   { 1, 3, 5, 7, 11, 5, 59, 219, 29, 803, 923, 3861, 7953, 8969, 1819, 43501, 20513, 0 };
            const std::uint32_t dim10016JoeKuoD6Init[]   =   { 1, 1, 5, 11, 7, 53, 63, 231, 193, 293, 1467, 1409, 6397, 13237, 15903, 19271, 66257, 0 };
            const std::uint32_t dim10017JoeKuoD6Init[]   =   { 1, 3, 1, 15, 23, 15, 37, 123, 189, 63, 1121, 751, 6711, 10095, 6493, 40709, 47641, 0 };
            const std::uint32_t dim10018JoeKuoD6Init[]   =   { 1, 3, 7, 3, 23, 59, 99, 183, 249, 479, 771, 1087, 7979, 409, 4819, 4337, 33345, 0 };
            const std::uint32_t dim10019JoeKuoD6Init[]   =   { 1, 1, 5, 1, 17, 7, 15, 167, 305, 411, 1429, 3127, 23, 9123, 7185, 44405, 114841, 0 };
            const std::uint32_t dim10020JoeKuoD6Init[]   =   { 1, 1, 5, 11, 3, 29, 29, 31, 399, 777, 251, 1841, 3607, 211, 23543, 29111, 54565, 0 };
            const std::uint32_t dim10021JoeKuoD6Init[]   =   { 1, 3, 3, 9, 27, 33, 79, 27, 469, 67, 1327, 183, 5783, 10039, 13165, 20443, 4913, 0 };
            const std::uint32_t dim10022JoeKuoD6Init[]   =   { 1, 3, 7, 15, 21, 23, 5, 227, 141, 1021, 69, 3347, 7221, 13837, 20921, 20525, 32567, 0 };
            const std::uint32_t dim10023JoeKuoD6Init[]   =   { 1, 1, 5, 5, 25, 53, 73, 111, 319, 311, 1597, 1809, 5343, 13963, 6613, 14471, 53871, 0 };
            const std::uint32_t dim10024JoeKuoD6Init[]   =   { 1, 3, 3, 1, 15, 57, 47, 205, 53, 471, 185, 273, 8077, 5031, 31195, 30859, 15979, 0 };
            const std::uint32_t dim10025JoeKuoD6Init[]   =   { 1, 1, 3, 5, 23, 15, 87, 211, 83, 265, 1629, 2979, 69, 12559, 30455, 36363, 61461, 0 };
            const std::uint32_t dim10026JoeKuoD6Init[]   =   { 1, 1, 7, 7, 1, 47, 5, 199, 95, 17, 57, 1887, 6847, 9501, 21361, 57763, 77069, 0 };
            const std::uint32_t dim10027JoeKuoD6Init[]   =   { 1, 1, 3, 5, 9, 15, 15, 149, 141, 605, 639, 2197, 7237, 5753, 9415, 4677, 129947, 0 };
            const std::uint32_t dim10028JoeKuoD6Init[]   =   { 1, 3, 7, 1, 7, 9, 29, 249, 275, 461, 1667, 4093, 5763, 3205, 24079, 11883, 86455, 0 };
            const std::uint32_t dim10029JoeKuoD6Init[]   =   { 1, 1, 3, 5, 15, 39, 117, 145, 153, 671, 1819, 111, 3607, 12279, 4927, 63759, 42905, 0 };
            const std::uint32_t dim10030JoeKuoD6Init[]   =   { 1, 1, 1, 5, 31, 5, 35, 183, 189, 839, 1811, 1877, 6545, 11373, 27947, 27183, 29857, 0 };
            const std::uint32_t dim10031JoeKuoD6Init[]   =   { 1, 3, 5, 7, 29, 47, 3, 183, 511, 145, 1953, 3419, 6385, 7745, 12823, 59783, 69399, 0 };
            const std::uint32_t dim10032JoeKuoD6Init[]   =   { 1, 3, 5, 9, 5, 39, 85, 145, 33, 899, 1009, 2035, 6145, 3855, 20583, 4329, 95231, 0 };
            const std::uint32_t dim10033JoeKuoD6Init[]   =   { 1, 1, 3, 3, 15, 61, 85, 181, 247, 705, 413, 1633, 7489, 1785, 30397, 42851, 80197, 0 };
            const std::uint32_t dim10034JoeKuoD6Init[]   =   { 1, 3, 3, 13, 23, 11, 3, 97, 307, 183, 113, 3881, 7455, 8327, 6749, 23977, 101629, 0 };
            const std::uint32_t dim10035JoeKuoD6Init[]   =   { 1, 1, 7, 13, 1, 23, 59, 219, 125, 789, 1401, 707, 6915, 6275, 25813, 46595, 54119, 0 };
            const std::uint32_t dim10036JoeKuoD6Init[]   =   { 1, 3, 7, 9, 5, 7, 37, 33, 165, 181, 833, 1993, 4541, 5799, 23323, 39825, 44575, 0 };
            const std::uint32_t dim10037JoeKuoD6Init[]   =   { 1, 3, 1, 13, 13, 43, 69, 219, 437, 521, 503, 2293, 3607, 6845, 22583, 291, 65645, 0 };
            const std::uint32_t dim10038JoeKuoD6Init[]   =   { 1, 1, 7, 9, 29, 13, 123, 67, 191, 933, 1875, 1223, 5525, 13797, 29771, 58191, 84469, 0 };
            const std::uint32_t dim10039JoeKuoD6Init[]   =   { 1, 1, 7, 7, 3, 57, 101, 69, 23, 239, 1023, 3289, 1541, 6245, 23379, 161, 61155, 0 };
            const std::uint32_t dim10040JoeKuoD6Init[]   =   { 1, 3, 7, 13, 25, 33, 49, 145, 487, 681, 451, 1719, 109, 16273, 20009, 3003, 115815, 0 };
            const std::uint32_t dim10041JoeKuoD6Init[]   =   { 1, 1, 5, 11, 11, 59, 41, 133, 303, 469, 1975, 847, 5291, 13947, 8759, 8533, 25099, 0 };
            const std::uint32_t dim10042JoeKuoD6Init[]   =   { 1, 1, 1, 1, 29, 31, 53, 11, 239, 57, 1627, 1247, 1577, 3269, 20751, 4627, 40499, 0 };
            const std::uint32_t dim10043JoeKuoD6Init[]   =   { 1, 3, 7, 15, 1, 1, 51, 39, 383, 203, 1841, 3867, 4975, 9937, 1863, 52611, 83189, 0 };
            const std::uint32_t dim10044JoeKuoD6Init[]   =   { 1, 3, 7, 7, 13, 59, 15, 217, 355, 945, 1317, 815, 2413, 10985, 30647, 37745, 126553, 0 };
            const std::uint32_t dim10045JoeKuoD6Init[]   =   { 1, 1, 3, 11, 7, 29, 101, 137, 97, 119, 927, 3269, 6977, 4253, 10741, 61907, 122815, 0 };
            const std::uint32_t dim10046JoeKuoD6Init[]   =   { 1, 3, 3, 1, 29, 5, 49, 137, 411, 349, 905, 2481, 4961, 4513, 29409, 19503, 77915, 0 };
            const std::uint32_t dim10047JoeKuoD6Init[]   =   { 1, 1, 7, 13, 29, 59, 93, 61, 393, 29, 257, 3601, 6281, 5105, 17339, 53827, 83137, 0 };
            const std::uint32_t dim10048JoeKuoD6Init[]   =   { 1, 1, 1, 13, 5, 23, 61, 7, 51, 161, 737, 1549, 6021, 3385, 5539, 21261, 69995, 0 };
            const std::uint32_t dim10049JoeKuoD6Init[]   =   { 1, 1, 1, 15, 31, 1, 21, 113, 481, 7, 175, 717, 1593, 5937, 12347, 51835, 66649, 0 };
            const std::uint32_t dim10050JoeKuoD6Init[]   =   { 1, 1, 3, 7, 9, 51, 9, 199, 39, 607, 1157, 3913, 7767, 14195, 28721, 27655, 34709, 0 };
            const std::uint32_t dim10051JoeKuoD6Init[]   =   { 1, 3, 5, 5, 1, 15, 49, 33, 441, 721, 1749, 1497, 2023, 8351, 12641, 11861, 78545, 0 };
            const std::uint32_t dim10052JoeKuoD6Init[]   =   { 1, 3, 1, 7, 7, 17, 103, 113, 243, 25, 889, 1419, 3163, 12401, 22459, 39037, 101719, 0 };
            const std::uint32_t dim10053JoeKuoD6Init[]   =   { 1, 1, 7, 11, 17, 45, 121, 215, 3, 409, 1871, 2149, 4249, 5071, 14277, 55869, 91233, 0 };
            const std::uint32_t dim10054JoeKuoD6Init[]   =   { 1, 1, 3, 7, 19, 31, 47, 241, 175, 749, 1709, 355, 6037, 10555, 24107, 64683, 42673, 0 };
            const std::uint32_t dim10055JoeKuoD6Init[]   =   { 1, 3, 7, 11, 5, 21, 105, 137, 307, 101, 417, 1903, 1027, 10257, 27767, 9755, 92105, 0 };
            const std::uint32_t dim10056JoeKuoD6Init[]   =   { 1, 1, 3, 13, 9, 59, 11, 63, 295, 923, 401, 1471, 3517, 7761, 28855, 11525, 72455, 0 };
            const std::uint32_t dim10057JoeKuoD6Init[]   =   { 1, 1, 7, 15, 31, 51, 77, 29, 323, 579, 1313, 3441, 2903, 1683, 20605, 8185, 29753, 0 };
            const std::uint32_t dim10058JoeKuoD6Init[]   =   { 1, 1, 5, 15, 11, 59, 119, 109, 233, 1001, 1527, 2709, 73, 5311, 18313, 27155, 85999, 0 };
            const std::uint32_t dim10059JoeKuoD6Init[]   =   { 1, 3, 1, 5, 9, 59, 105, 93, 213, 401, 839, 3225, 3263, 13501, 2413, 60367, 121281, 0 };
            const std::uint32_t dim10060JoeKuoD6Init[]   =   { 1, 1, 7, 3, 19, 25, 75, 27, 325, 435, 527, 1465, 3601, 5785, 6135, 32841, 60129, 0 };
            const std::uint32_t dim10061JoeKuoD6Init[]   =   { 1, 1, 3, 7, 31, 19, 37, 157, 189, 51, 869, 2963, 5269, 9151, 14845, 30441, 89685, 0 };
            const std::uint32_t dim10062JoeKuoD6Init[]   =   { 1, 3, 3, 9, 17, 51, 23, 177, 417, 255, 1739, 3085, 7811, 15177, 25433, 38487, 51021, 0 };
            const std::uint32_t dim10063JoeKuoD6Init[]   =   { 1, 1, 3, 7, 27, 1, 45, 235, 59, 491, 1327, 3967, 7585, 4313, 29669, 47193, 89427, 0 };
            const std::uint32_t dim10064JoeKuoD6Init[]   =   { 1, 1, 3, 9, 19, 5, 27, 63, 263, 593, 1599, 1311, 1029, 603, 25291, 51391, 98915, 0 };
            const std::uint32_t dim10065JoeKuoD6Init[]   =   { 1, 3, 3, 15, 11, 7, 97, 99, 263, 155, 437, 3849, 2665, 3371, 8179, 51883, 3601, 0 };
            const std::uint32_t dim10066JoeKuoD6Init[]   =   { 1, 1, 3, 15, 7, 35, 37, 149, 251, 619, 1423, 553, 4453, 16365, 22543, 6951, 34655, 0 };
            const std::uint32_t dim10067JoeKuoD6Init[]   =   { 1, 3, 3, 11, 15, 21, 95, 143, 31, 425, 179, 2383, 4799, 7655, 26945, 9273, 103469, 0 };
            const std::uint32_t dim10068JoeKuoD6Init[]   =   { 1, 3, 1, 9, 13, 49, 3, 117, 361, 459, 227, 2067, 4909, 13461, 22505, 10259, 59697, 0 };
            const std::uint32_t dim10069JoeKuoD6Init[]   =   { 1, 1, 7, 7, 7, 23, 67, 217, 313, 965, 1747, 995, 579, 6217, 8915, 49329, 851, 0 };
            const std::uint32_t dim10070JoeKuoD6Init[]   =   { 1, 1, 3, 1, 17, 19, 7, 99, 281, 207, 1685, 2401, 967, 9399, 28741, 28839, 6003, 0 };
            const std::uint32_t dim10071JoeKuoD6Init[]   =   { 1, 3, 3, 5, 31, 61, 105, 251, 499, 319, 1167, 2203, 1195, 2663, 11797, 12981, 125523, 0 };
            const std::uint32_t dim10072JoeKuoD6Init[]   =   { 1, 3, 1, 5, 23, 19, 99, 101, 85, 837, 501, 2737, 4051, 2413, 9275, 38995, 21633, 0 };
            const std::uint32_t dim10073JoeKuoD6Init[]   =   { 1, 3, 7, 13, 17, 17, 119, 75, 281, 527, 1477, 1515, 7765, 5573, 10143, 6219, 57817, 0 };
            const std::uint32_t dim10074JoeKuoD6Init[]   =   { 1, 1, 5, 11, 19, 35, 85, 171, 107, 905, 1395, 1199, 7345, 15719, 14021, 47425, 36081, 0 };
            const std::uint32_t dim10075JoeKuoD6Init[]   =   { 1, 1, 3, 9, 9, 63, 109, 15, 323, 73, 1541, 2227, 5197, 12617, 23379, 53415, 105291, 0 };
            const std::uint32_t dim10076JoeKuoD6Init[]   =   { 1, 3, 3, 5, 5, 41, 85, 99, 3, 895, 1383, 3627, 3897, 1893, 23673, 56501, 78411, 0 };
            const std::uint32_t dim10077JoeKuoD6Init[]   =   { 1, 1, 7, 1, 25, 27, 45, 185, 475, 577, 1619, 727, 1407, 2383, 9215, 55295, 27349, 0 };
            const std::uint32_t dim10078JoeKuoD6Init[]   =   { 1, 3, 7, 11, 3, 51, 53, 53, 399, 711, 1075, 511, 5369, 10777, 14419, 63217, 130181, 0 };
            const std::uint32_t dim10079JoeKuoD6Init[]   =   { 1, 1, 7, 13, 25, 19, 107, 71, 151, 73, 735, 3837, 5307, 10229, 10529, 9989, 111925, 0 };
            const std::uint32_t dim10080JoeKuoD6Init[]   =   { 1, 1, 1, 15, 19, 59, 65, 77, 465, 957, 1085, 1359, 3959, 15823, 6273, 12565, 126167, 0 };
            const std::uint32_t dim10081JoeKuoD6Init[]   =   { 1, 1, 5, 5, 31, 53, 23, 173, 407, 795, 41, 3275, 1953, 13673, 26625, 33477, 14149, 0 };
            const std::uint32_t dim10082JoeKuoD6Init[]   =   { 1, 1, 7, 7, 1, 11, 121, 139, 77, 321, 1939, 2597, 621, 9579, 11629, 13119, 30505, 0 };
            const std::uint32_t dim10083JoeKuoD6Init[]   =   { 1, 1, 1, 5, 3, 33, 45, 127, 169, 581, 1521, 1019, 6489, 1069, 2469, 40255, 66619, 0 };
            const std::uint32_t dim10084JoeKuoD6Init[]   =   { 1, 3, 7, 5, 29, 47, 7, 245, 459, 417, 1027, 857, 4905, 11255, 3267, 9491, 78013, 0 };
            const std::uint32_t dim10085JoeKuoD6Init[]   =   { 1, 3, 5, 9, 25, 49, 61, 215, 19, 731, 303, 1001, 6031, 3705, 7797, 31957, 119383, 0 };
            const std::uint32_t dim10086JoeKuoD6Init[]   =   { 1, 3, 5, 5, 1, 9, 37, 187, 235, 453, 963, 2833, 3501, 605, 2763, 41215, 93547, 0 };
            const std::uint32_t dim10087JoeKuoD6Init[]   =   { 1, 3, 1, 1, 21, 3, 41, 53, 425, 687, 1051, 2365, 7835, 3981, 5557, 61993, 127417, 0 };
            const std::uint32_t dim10088JoeKuoD6Init[]   =   { 1, 3, 3, 7, 13, 61, 41, 189, 261, 163, 1931, 1803, 2379, 16379, 25453, 17911, 123431, 0 };
            const std::uint32_t dim10089JoeKuoD6Init[]   =   { 1, 1, 7, 15, 23, 21, 95, 7, 27, 897, 721, 3917, 7971, 4643, 5223, 46583, 32453, 0 };
            const std::uint32_t dim10090JoeKuoD6Init[]   =   { 1, 1, 7, 7, 1, 25, 83, 109, 223, 573, 533, 449, 6477, 10719, 28705, 8283, 94963, 0 };
            const std::uint32_t dim10091JoeKuoD6Init[]   =   { 1, 1, 5, 13, 21, 45, 63, 31, 21, 223, 31, 1249, 425, 7199, 11539, 7731, 44333, 0 };
            const std::uint32_t dim10092JoeKuoD6Init[]   =   { 1, 1, 5, 15, 29, 5, 87, 215, 287, 567, 297, 451, 5867, 15511, 1005, 57469, 87257, 0 };
            const std::uint32_t dim10093JoeKuoD6Init[]   =   { 1, 3, 5, 11, 13, 51, 117, 139, 377, 1015, 1237, 2053, 7625, 1003, 22673, 64345, 16203, 0 };
            const std::uint32_t dim10094JoeKuoD6Init[]   =   { 1, 1, 3, 15, 19, 39, 73, 205, 185, 331, 869, 857, 5043, 7247, 25253, 5799, 64857, 0 };
            const std::uint32_t dim10095JoeKuoD6Init[]   =   { 1, 3, 7, 1, 25, 63, 125, 47, 161, 289, 373, 1603, 1663, 1123, 28907, 37855, 47935, 0 };
            const std::uint32_t dim10096JoeKuoD6Init[]   =   { 1, 1, 7, 15, 9, 17, 97, 63, 79, 123, 1357, 3055, 2323, 16083, 21861, 38743, 81291, 0 };
            const std::uint32_t dim10097JoeKuoD6Init[]   =   { 1, 1, 3, 15, 5, 23, 7, 159, 127, 511, 55, 2691, 6823, 16151, 8059, 43021, 18911, 0 };
            const std::uint32_t dim10098JoeKuoD6Init[]   =   { 1, 1, 3, 9, 27, 19, 41, 75, 375, 921, 1745, 35, 1189, 5857, 29869, 43827, 16899, 0 };
            const std::uint32_t dim10099JoeKuoD6Init[]   =   { 1, 1, 1, 5, 3, 21, 13, 235, 51, 529, 291, 2619, 5419, 12573, 10907, 8865, 54987, 0 };
            const std::uint32_t dim10100JoeKuoD6Init[]   =   { 1, 3, 1, 13, 7, 9, 85, 131, 159, 743, 1671, 3001, 4559, 12343, 27563, 49941, 68447, 0 };
            const std::uint32_t dim10101JoeKuoD6Init[]   =   { 1, 1, 7, 5, 17, 61, 99, 63, 199, 383, 485, 2569, 5329, 645, 18805, 20421, 101229, 0 };
            const std::uint32_t dim10102JoeKuoD6Init[]   =   { 1, 1, 1, 15, 3, 59, 41, 247, 213, 843, 2003, 125, 7755, 4203, 20277, 47195, 48249, 0 };
            const std::uint32_t dim10103JoeKuoD6Init[]   =   { 1, 1, 5, 15, 15, 17, 113, 101, 27, 811, 1791, 1777, 749, 14317, 17267, 54467, 118369, 0 };
            const std::uint32_t dim10104JoeKuoD6Init[]   =   { 1, 3, 3, 3, 19, 37, 23, 117, 275, 733, 1259, 567, 1769, 12071, 5413, 49411, 99259, 0 };
            const std::uint32_t dim10105JoeKuoD6Init[]   =   { 1, 3, 1, 11, 3, 27, 103, 113, 251, 731, 481, 2771, 3205, 14151, 19403, 30307, 114691, 0 };
            const std::uint32_t dim10106JoeKuoD6Init[]   =   { 1, 1, 5, 15, 19, 15, 103, 25, 357, 197, 1437, 3621, 4747, 773, 5769, 33465, 28307, 0 };
            const std::uint32_t dim10107JoeKuoD6Init[]   =   { 1, 1, 5, 15, 5, 17, 89, 87, 423, 611, 549, 2549, 1275, 14545, 2931, 3853, 24577, 0 };
            const std::uint32_t dim10108JoeKuoD6Init[]   =   { 1, 3, 5, 1, 15, 13, 29, 49, 279, 495, 697, 1015, 4899, 15977, 10765, 47979, 40237, 0 };
            const std::uint32_t dim10109JoeKuoD6Init[]   =   { 1, 3, 3, 9, 31, 51, 21, 5, 279, 947, 1871, 3075, 5433, 1631, 30075, 30517, 99609, 0 };
            const std::uint32_t dim10110JoeKuoD6Init[]   =   { 1, 1, 1, 15, 19, 63, 79, 81, 19, 629, 617, 1887, 4015, 15501, 10551, 56419, 108739, 0 };
            const std::uint32_t dim10111JoeKuoD6Init[]   =   { 1, 1, 3, 9, 31, 15, 45, 37, 43, 349, 1357, 189, 4551, 9363, 15683, 48445, 89279, 0 };
            const std::uint32_t dim10112JoeKuoD6Init[]   =   { 1, 1, 1, 1, 17, 19, 121, 119, 397, 947, 1797, 613, 1627, 9591, 15779, 62295, 118843, 0 };
            const std::uint32_t dim10113JoeKuoD6Init[]   =   { 1, 1, 1, 7, 25, 55, 71, 227, 507, 497, 1209, 2919, 5733, 15785, 21437, 40043, 2325, 0 };
            const std::uint32_t dim10114JoeKuoD6Init[]   =   { 1, 1, 1, 15, 11, 1, 59, 93, 69, 859, 67, 1831, 6345, 5643, 29515, 20337, 77281, 0 };
            const std::uint32_t dim10115JoeKuoD6Init[]   =   { 1, 3, 5, 9, 19, 53, 59, 63, 161, 853, 697, 1441, 3457, 951, 29659, 15337, 38443, 0 };
            const std::uint32_t dim10116JoeKuoD6Init[]   =   { 1, 3, 1, 9, 7, 21, 73, 81, 89, 291, 411, 3793, 4639, 2829, 6855, 38113, 32875, 0 };
            const std::uint32_t dim10117JoeKuoD6Init[]   =   { 1, 1, 7, 1, 15, 3, 79, 35, 363, 459, 907, 1157, 5165, 8021, 10135, 36367, 111991, 0 };
            const std::uint32_t dim10118JoeKuoD6Init[]   =   { 1, 3, 5, 13, 21, 23, 63, 155, 393, 869, 1553, 3345, 2711, 8249, 24907, 28111, 36667, 0 };
            const std::uint32_t dim10119JoeKuoD6Init[]   =   { 1, 1, 7, 11, 15, 25, 29, 93, 45, 637, 1473, 2053, 313, 8047, 23411, 8643, 2925, 0 };
            const std::uint32_t dim10120JoeKuoD6Init[]   =   { 1, 3, 7, 9, 11, 5, 73, 69, 311, 949, 2017, 259, 2861, 10547, 12017, 34125, 74101, 0 };
            const std::uint32_t dim10121JoeKuoD6Init[]   =   { 1, 3, 1, 13, 19, 61, 115, 59, 447, 787, 1621, 2221, 7841, 5329, 18137, 13857, 51889, 0 };
            const std::uint32_t dim10122JoeKuoD6Init[]   =   { 1, 3, 7, 13, 1, 23, 117, 49, 449, 541, 7, 3269, 1725, 6677, 15979, 4319, 40919, 0 };
            const std::uint32_t dim10123JoeKuoD6Init[]   =   { 1, 3, 5, 5, 17, 29, 35, 123, 3, 481, 305, 1589, 4319, 5183, 31907, 53019, 49375, 0 };
            const std::uint32_t dim10124JoeKuoD6Init[]   =   { 1, 3, 1, 7, 11, 59, 79, 89, 479, 821, 763, 3597, 7457, 13775, 11213, 22777, 80379, 0 };
            const std::uint32_t dim10125JoeKuoD6Init[]   =   { 1, 1, 3, 7, 13, 17, 65, 155, 335, 671, 331, 895, 7459, 1719, 10675, 60109, 63143, 0 };
            const std::uint32_t dim10126JoeKuoD6Init[]   =   { 1, 3, 5, 1, 29, 33, 105, 249, 61, 469, 1629, 3777, 4393, 14457, 11701, 6065, 2635, 0 };
            const std::uint32_t dim10127JoeKuoD6Init[]   =   { 1, 3, 7, 3, 13, 13, 21, 15, 363, 63, 1263, 1479, 1459, 6577, 7481, 30393, 19831, 0 };
            const std::uint32_t dim10128JoeKuoD6Init[]   =   { 1, 1, 3, 7, 29, 25, 71, 247, 501, 815, 1697, 2457, 4975, 3821, 25759, 24901, 120603, 0 };
            const std::uint32_t dim10129JoeKuoD6Init[]   =   { 1, 1, 1, 5, 19, 3, 59, 163, 367, 779, 47, 905, 897, 3293, 13951, 25497, 99151, 0 };
            const std::uint32_t dim10130JoeKuoD6Init[]   =   { 1, 3, 1, 5, 11, 47, 21, 171, 123, 215, 1797, 3741, 4921, 7213, 4847, 3239, 114839, 0 };
            const std::uint32_t dim10131JoeKuoD6Init[]   =   { 1, 3, 3, 5, 23, 63, 57, 31, 409, 431, 1337, 3301, 4695, 7401, 9383, 12639, 34347, 0 };
            const std::uint32_t dim10132JoeKuoD6Init[]   =   { 1, 3, 3, 5, 27, 57, 29, 147, 111, 1015, 815, 1509, 3967, 7255, 15109, 26001, 90775, 0 };
            const std::uint32_t dim10133JoeKuoD6Init[]   =   { 1, 1, 7, 13, 31, 45, 21, 99, 377, 399, 255, 459, 6043, 11055, 5675, 3333, 32813, 0 };
            const std::uint32_t dim10134JoeKuoD6Init[]   =   { 1, 3, 1, 7, 1, 55, 121, 77, 429, 433, 297, 3181, 3029, 6777, 22795, 61515, 58553, 0 };
            const std::uint32_t dim10135JoeKuoD6Init[]   =   { 1, 3, 5, 9, 1, 19, 121, 1, 499, 589, 1597, 2219, 1029, 4223, 31613, 45685, 53517, 0 };
            const std::uint32_t dim10136JoeKuoD6Init[]   =   { 1, 3, 1, 9, 29, 39, 83, 193, 43, 41, 467, 1711, 2761, 10635, 15503, 38043, 120615, 0 };
            const std::uint32_t dim10137JoeKuoD6Init[]   =   { 1, 1, 7, 13, 27, 61, 1, 181, 163, 613, 221, 63, 6147, 8215, 15093, 2417, 71489, 0 };
            const std::uint32_t dim10138JoeKuoD6Init[]   =   { 1, 1, 7, 15, 31, 63, 47, 139, 427, 847, 53, 1275, 1019, 9455, 12537, 22467, 129947, 0 };
            const std::uint32_t dim10139JoeKuoD6Init[]   =   { 1, 1, 5, 3, 7, 1, 67, 189, 501, 319, 37, 2849, 2535, 10917, 11115, 48083, 67255, 0 };
            const std::uint32_t dim10140JoeKuoD6Init[]   =   { 1, 1, 3, 13, 7, 31, 69, 137, 19, 73, 1553, 3945, 2381, 8761, 3977, 24291, 128189, 0 };
            const std::uint32_t dim10141JoeKuoD6Init[]   =   { 1, 3, 5, 11, 1, 59, 43, 229, 301, 771, 559, 195, 1675, 12605, 22211, 2915, 90351, 0 };
            const std::uint32_t dim10142JoeKuoD6Init[]   =   { 1, 3, 3, 9, 13, 27, 97, 33, 273, 229, 1537, 1179, 6985, 11679, 17889, 44673, 126641, 0 };
            const std::uint32_t dim10143JoeKuoD6Init[]   =   { 1, 1, 7, 3, 31, 29, 41, 123, 491, 639, 269, 45, 2155, 14103, 6725, 50781, 42785, 0 };
            const std::uint32_t dim10144JoeKuoD6Init[]   =   { 1, 3, 5, 9, 9, 11, 89, 249, 475, 701, 1029, 985, 8167, 439, 31897, 24529, 45759, 0 };
            const std::uint32_t dim10145JoeKuoD6Init[]   =   { 1, 1, 5, 11, 9, 39, 127, 179, 15, 135, 1437, 3331, 5553, 939, 15319, 64937, 110783, 0 };
            const std::uint32_t dim10146JoeKuoD6Init[]   =   { 1, 3, 1, 5, 7, 61, 1, 219, 111, 801, 85, 3427, 2533, 12861, 5395, 28969, 48091, 0 };
            const std::uint32_t dim10147JoeKuoD6Init[]   =   { 1, 1, 1, 9, 23, 57, 77, 41, 61, 635, 457, 231, 8121, 5349, 27021, 64807, 87563, 0 };
            const std::uint32_t dim10148JoeKuoD6Init[]   =   { 1, 3, 5, 7, 31, 31, 101, 155, 255, 199, 1973, 903, 7681, 15379, 12845, 47943, 60663, 0 };
            const std::uint32_t dim10149JoeKuoD6Init[]   =   { 1, 1, 5, 7, 1, 7, 71, 121, 323, 669, 193, 1209, 267, 9, 21223, 22037, 121567, 0 };
            const std::uint32_t dim10150JoeKuoD6Init[]   =   { 1, 3, 1, 5, 17, 29, 97, 189, 219, 813, 187, 1763, 5817, 13185, 467, 40159, 18037, 0 };
            const std::uint32_t dim10151JoeKuoD6Init[]   =   { 1, 1, 7, 9, 7, 59, 3, 189, 379, 843, 631, 3945, 2909, 4191, 30343, 11223, 105629, 0 };
            const std::uint32_t dim10152JoeKuoD6Init[]   =   { 1, 3, 1, 3, 15, 17, 23, 73, 439, 699, 657, 451, 6139, 15869, 4101, 32327, 55485, 0 };
            const std::uint32_t dim10153JoeKuoD6Init[]   =   { 1, 3, 3, 5, 21, 37, 87, 157, 205, 493, 705, 1539, 2193, 13539, 2797, 49063, 55595, 0 };
            const std::uint32_t dim10154JoeKuoD6Init[]   =   { 1, 1, 5, 11, 11, 41, 5, 131, 445, 781, 1153, 1371, 6763, 3101, 32449, 16065, 86579, 0 };
            const std::uint32_t dim10155JoeKuoD6Init[]   =   { 1, 3, 5, 1, 23, 51, 97, 87, 161, 261, 269, 2035, 2139, 3049, 32217, 25189, 93571, 0 };
            const std::uint32_t dim10156JoeKuoD6Init[]   =   { 1, 3, 1, 11, 23, 1, 111, 45, 19, 19, 1767, 3571, 6027, 3593, 17453, 53821, 28121, 0 };
            const std::uint32_t dim10157JoeKuoD6Init[]   =   { 1, 3, 3, 5, 17, 5, 17, 247, 5, 73, 29, 443, 7713, 15803, 22311, 56755, 100119, 0 };
            const std::uint32_t dim10158JoeKuoD6Init[]   =   { 1, 3, 1, 13, 7, 1, 41, 139, 317, 977, 1529, 1217, 529, 3231, 21491, 28461, 96699, 0 };
            const std::uint32_t dim10159JoeKuoD6Init[]   =   { 1, 3, 1, 13, 11, 41, 103, 99, 81, 849, 231, 1729, 761, 711, 11499, 25581, 59433, 0 };
            const std::uint32_t dim10160JoeKuoD6Init[]   =   { 1, 1, 5, 5, 13, 33, 79, 175, 89, 29, 295, 2867, 1197, 6137, 32063, 23471, 21721, 0 };
            const std::uint32_t dim10161JoeKuoD6Init[]   =   { 1, 1, 5, 15, 17, 29, 123, 249, 273, 437, 443, 2601, 3957, 11955, 261, 54863, 85727, 0 };
            const std::uint32_t dim10162JoeKuoD6Init[]   =   { 1, 1, 5, 13, 3, 31, 57, 205, 3, 903, 905, 3851, 757, 13761, 28615, 48185, 33227, 0 };
            const std::uint32_t dim10163JoeKuoD6Init[]   =   { 1, 3, 7, 1, 1, 1, 107, 15, 307, 405, 45, 297, 4365, 1569, 9263, 13685, 36027, 0 };
            const std::uint32_t dim10164JoeKuoD6Init[]   =   { 1, 3, 1, 9, 17, 61, 113, 121, 249, 743, 191, 2523, 6621, 5395, 23797, 57975, 51675, 0 };
            const std::uint32_t dim10165JoeKuoD6Init[]   =   { 1, 3, 5, 3, 27, 21, 49, 113, 59, 989, 501, 2651, 3827, 5121, 29667, 32903, 84199, 0 };
            const std::uint32_t dim10166JoeKuoD6Init[]   =   { 1, 1, 7, 7, 19, 43, 11, 191, 143, 93, 1167, 2521, 2569, 12187, 28575, 13073, 113545, 0 };
            const std::uint32_t dim10167JoeKuoD6Init[]   =   { 1, 1, 7, 3, 27, 39, 11, 85, 61, 979, 49, 2191, 2607, 13967, 28123, 48903, 16327, 0 };
            const std::uint32_t dim10168JoeKuoD6Init[]   =   { 1, 1, 5, 3, 17, 17, 1, 149, 189, 1017, 705, 3119, 6441, 1595, 30533, 18795, 34265, 0 };
            const std::uint32_t dim10169JoeKuoD6Init[]   =   { 1, 1, 3, 11, 31, 11, 125, 109, 39, 41, 191, 2615, 1377, 16089, 8793, 31425, 90507, 0 };
            const std::uint32_t dim10170JoeKuoD6Init[]   =   { 1, 1, 1, 1, 23, 15, 21, 245, 337, 649, 585, 2893, 927, 883, 15119, 2595, 127963, 0 };
            const std::uint32_t dim10171JoeKuoD6Init[]   =   { 1, 3, 5, 3, 13, 17, 123, 167, 471, 5, 1671, 2787, 5081, 12903, 4257, 19213, 2503, 0 };
            const std::uint32_t dim10172JoeKuoD6Init[]   =   { 1, 1, 5, 7, 21, 57, 75, 171, 509, 591, 85, 407, 1747, 6375, 19641, 55683, 111289, 0 };
            const std::uint32_t dim10173JoeKuoD6Init[]   =   { 1, 1, 7, 7, 3, 31, 121, 111, 19, 361, 1033, 4033, 2359, 13451, 15095, 61817, 69683, 0 };
            const std::uint32_t dim10174JoeKuoD6Init[]   =   { 1, 1, 5, 9, 21, 33, 83, 179, 387, 69, 1085, 2147, 2751, 10899, 16971, 40623, 110891, 0 };
            const std::uint32_t dim10175JoeKuoD6Init[]   =   { 1, 1, 7, 9, 11, 45, 81, 71, 73, 551, 145, 159, 7519, 3459, 5197, 48913, 59045, 0 };
            const std::uint32_t dim10176JoeKuoD6Init[]   =   { 1, 3, 1, 3, 7, 35, 17, 249, 207, 767, 1189, 1451, 4351, 3673, 28807, 671, 69271, 0 };
            const std::uint32_t dim10177JoeKuoD6Init[]   =   { 1, 3, 1, 15, 21, 27, 81, 243, 55, 191, 1497, 3205, 1601, 705, 14891, 14403, 130729, 0 };
            const std::uint32_t dim10178JoeKuoD6Init[]   =   { 1, 3, 1, 7, 17, 43, 41, 123, 507, 201, 1873, 3547, 5681, 1819, 4251, 39661, 57923, 0 };
            const std::uint32_t dim10179JoeKuoD6Init[]   =   { 1, 3, 1, 9, 3, 59, 57, 235, 445, 479, 961, 1937, 2229, 2511, 15235, 59707, 72261, 0 };
            const std::uint32_t dim10180JoeKuoD6Init[]   =   { 1, 1, 5, 13, 9, 63, 67, 217, 63, 259, 175, 2469, 3075, 12365, 7727, 42215, 12635, 0 };
            const std::uint32_t dim10181JoeKuoD6Init[]   =   { 1, 1, 3, 13, 11, 9, 125, 131, 17, 399, 675, 767, 7349, 10433, 21615, 46823, 3955, 0 };
            const std::uint32_t dim10182JoeKuoD6Init[]   =   { 1, 1, 3, 15, 19, 53, 73, 171, 125, 531, 1093, 1449, 2931, 10897, 12263, 9799, 98251, 0 };
            const std::uint32_t dim10183JoeKuoD6Init[]   =   { 1, 1, 5, 5, 11, 27, 33, 9, 503, 545, 339, 1099, 1973, 13261, 26871, 14569, 22755, 0 };
            const std::uint32_t dim10184JoeKuoD6Init[]   =   { 1, 3, 7, 1, 19, 5, 79, 133, 247, 1021, 1431, 3707, 4603, 3285, 5469, 46963, 98203, 0 };
            const std::uint32_t dim10185JoeKuoD6Init[]   =   { 1, 3, 5, 7, 15, 11, 87, 169, 495, 763, 1295, 2533, 4213, 8671, 21683, 12521, 90071, 0 };
            const std::uint32_t dim10186JoeKuoD6Init[]   =   { 1, 1, 3, 1, 17, 55, 7, 165, 313, 659, 49, 377, 6675, 15255, 9881, 11751, 87789, 0 };
            const std::uint32_t dim10187JoeKuoD6Init[]   =   { 1, 3, 1, 15, 3, 49, 27, 109, 145, 1011, 1939, 3201, 6141, 7229, 20741, 59285, 129365, 0 };
            const std::uint32_t dim10188JoeKuoD6Init[]   =   { 1, 1, 5, 5, 5, 51, 117, 17, 363, 795, 1343, 2637, 6209, 1045, 22515, 10687, 48487, 0 };
            const std::uint32_t dim10189JoeKuoD6Init[]   =   { 1, 1, 5, 15, 1, 37, 91, 241, 245, 703, 505, 3369, 6163, 10265, 12497, 46301, 109523, 0 };
            const std::uint32_t dim10190JoeKuoD6Init[]   =   { 1, 1, 7, 11, 3, 37, 67, 35, 229, 823, 193, 913, 3331, 4475, 9271, 11859, 52709, 0 };
            const std::uint32_t dim10191JoeKuoD6Init[]   =   { 1, 1, 3, 3, 7, 25, 61, 159, 81, 1011, 1491, 1439, 1031, 765, 9839, 61891, 20969, 0 };
            const std::uint32_t dim10192JoeKuoD6Init[]   =   { 1, 3, 3, 7, 25, 39, 73, 59, 101, 101, 225, 1105, 5943, 5223, 12585, 16411, 62699, 0 };
            const std::uint32_t dim10193JoeKuoD6Init[]   =   { 1, 1, 7, 5, 25, 19, 27, 113, 465, 319, 2035, 2127, 1319, 11793, 26821, 44805, 28217, 0 };
            const std::uint32_t dim10194JoeKuoD6Init[]   =   { 1, 3, 5, 11, 7, 9, 81, 107, 67, 31, 1503, 3303, 4451, 11417, 32681, 26861, 54845, 0 };
            const std::uint32_t dim10195JoeKuoD6Init[]   =   { 1, 3, 1, 1, 3, 51, 93, 235, 93, 247, 2027, 1517, 6797, 1703, 10233, 45313, 60771, 0 };
            const std::uint32_t dim10196JoeKuoD6Init[]   =   { 1, 3, 3, 15, 25, 11, 83, 77, 413, 189, 119, 597, 2199, 12347, 7935, 40191, 125569, 0 };
            const std::uint32_t dim10197JoeKuoD6Init[]   =   { 1, 3, 7, 9, 11, 3, 77, 31, 89, 163, 1993, 3017, 3973, 10943, 22247, 45565, 7261, 0 };
            const std::uint32_t dim10198JoeKuoD6Init[]   =   { 1, 3, 7, 7, 15, 13, 7, 155, 373, 893, 607, 3521, 7455, 13809, 6145, 31743, 86329, 0 };
            const std::uint32_t dim10199JoeKuoD6Init[]   =   { 1, 1, 1, 15, 25, 41, 111, 65, 11, 627, 59, 2725, 995, 3761, 25361, 45189, 48355, 0 };
            const std::uint32_t dim10200JoeKuoD6Init[]   =   { 1, 1, 7, 5, 29, 43, 91, 139, 323, 503, 679, 4079, 403, 1899, 1425, 26989, 117057, 0 };
            const std::uint32_t dim10201JoeKuoD6Init[]   =   { 1, 3, 5, 13, 1, 17, 19, 61, 205, 833, 345, 1031, 7995, 999, 27469, 15943, 88011, 0 };
            const std::uint32_t dim10202JoeKuoD6Init[]   =   { 1, 3, 1, 7, 23, 49, 123, 9, 11, 761, 1163, 669, 3837, 15225, 23393, 19513, 9457, 0 };
            const std::uint32_t dim10203JoeKuoD6Init[]   =   { 1, 1, 5, 9, 9, 33, 29, 123, 277, 433, 1799, 1583, 3133, 13461, 26443, 15807, 80173, 0 };
            const std::uint32_t dim10204JoeKuoD6Init[]   =   { 1, 3, 7, 3, 31, 29, 77, 105, 297, 617, 491, 647, 6541, 5033, 31841, 48405, 126985, 0 };
            const std::uint32_t dim10205JoeKuoD6Init[]   =   { 1, 1, 5, 5, 31, 39, 17, 25, 3, 279, 89, 3985, 3333, 5681, 3701, 36319, 12585, 0 };
            const std::uint32_t dim10206JoeKuoD6Init[]   =   { 1, 1, 7, 13, 13, 19, 93, 129, 51, 875, 1083, 1739, 5193, 6217, 10033, 51839, 66071, 0 };
            const std::uint32_t dim10207JoeKuoD6Init[]   =   { 1, 1, 7, 9, 15, 23, 93, 121, 507, 115, 707, 3181, 1521, 9609, 4577, 54389, 19167, 0 };
            const std::uint32_t dim10208JoeKuoD6Init[]   =   { 1, 3, 3, 7, 17, 51, 19, 29, 387, 711, 1105, 1627, 4421, 15183, 14149, 26485, 106425, 0 };
            const std::uint32_t dim10209JoeKuoD6Init[]   =   { 1, 3, 3, 15, 25, 59, 11, 45, 259, 1019, 1997, 3373, 5083, 5701, 30217, 44845, 67559, 0 };
            const std::uint32_t dim10210JoeKuoD6Init[]   =   { 1, 3, 3, 9, 17, 47, 5, 103, 477, 785, 235, 1523, 1505, 8811, 15255, 53493, 4383, 0 };
            const std::uint32_t dim10211JoeKuoD6Init[]   =   { 1, 3, 7, 3, 7, 37, 73, 247, 397, 409, 1065, 525, 5665, 8533, 30627, 19035, 22937, 0 };
            const std::uint32_t dim10212JoeKuoD6Init[]   =   { 1, 3, 3, 15, 15, 47, 123, 215, 413, 249, 55, 2563, 8033, 8743, 18659, 7947, 56057, 0 };
            const std::uint32_t dim10213JoeKuoD6Init[]   =   { 1, 1, 7, 3, 11, 61, 103, 109, 313, 293, 149, 999, 901, 13387, 15351, 52973, 68385, 0 };
            const std::uint32_t dim10214JoeKuoD6Init[]   =   { 1, 1, 1, 5, 31, 13, 57, 43, 263, 141, 335, 2777, 3435, 4231, 20623, 2597, 33481, 0 };
            const std::uint32_t dim10215JoeKuoD6Init[]   =   { 1, 1, 7, 13, 21, 53, 101, 75, 237, 275, 1903, 3501, 8023, 3651, 19609, 44417, 60287, 0 };
            const std::uint32_t dim10216JoeKuoD6Init[]   =   { 1, 1, 1, 1, 13, 43, 83, 255, 355, 567, 1781, 2943, 1061, 2701, 24861, 58381, 60255, 0 };
            const std::uint32_t dim10217JoeKuoD6Init[]   =   { 1, 1, 3, 9, 25, 5, 81, 85, 445, 857, 517, 3687, 2641, 6699, 19273, 4481, 8715, 0 };
            const std::uint32_t dim10218JoeKuoD6Init[]   =   { 1, 1, 3, 7, 17, 39, 33, 31, 29, 269, 379, 3149, 4731, 10387, 7941, 49199, 18423, 0 };
            const std::uint32_t dim10219JoeKuoD6Init[]   =   { 1, 1, 7, 15, 19, 37, 105, 157, 185, 1023, 1865, 53, 6765, 3, 22897, 17019, 109521, 0 };
            const std::uint32_t dim10220JoeKuoD6Init[]   =   { 1, 3, 7, 5, 5, 7, 117, 211, 19, 149, 1091, 3721, 201, 4455, 18965, 51401, 67225, 0 };
            const std::uint32_t dim10221JoeKuoD6Init[]   =   { 1, 3, 5, 11, 1, 55, 101, 41, 469, 271, 1251, 949, 861, 11903, 14773, 25675, 114161, 0 };
            const std::uint32_t dim10222JoeKuoD6Init[]   =   { 1, 1, 7, 7, 23, 13, 103, 185, 137, 575, 797, 1195, 5301, 13307, 12043, 26003, 31719, 0 };
            const std::uint32_t dim10223JoeKuoD6Init[]   =   { 1, 1, 5, 7, 11, 51, 17, 71, 321, 559, 1461, 3571, 1033, 15575, 7097, 14703, 52359, 0 };
            const std::uint32_t dim10224JoeKuoD6Init[]   =   { 1, 1, 1, 5, 21, 9, 123, 211, 233, 81, 111, 1433, 7825, 11771, 30743, 23993, 48717, 0 };
            const std::uint32_t dim10225JoeKuoD6Init[]   =   { 1, 3, 5, 15, 7, 3, 109, 33, 99, 135, 393, 3463, 7271, 14387, 30723, 19079, 83073, 0 };
            const std::uint32_t dim10226JoeKuoD6Init[]   =   { 1, 3, 3, 15, 3, 51, 77, 219, 409, 11, 67, 3787, 5155, 9259, 7185, 21611, 32577, 0 };
            const std::uint32_t dim10227JoeKuoD6Init[]   =   { 1, 3, 7, 1, 5, 49, 125, 85, 151, 301, 887, 1765, 5, 12849, 11775, 11319, 29547, 0 };
            const std::uint32_t dim10228JoeKuoD6Init[]   =   { 1, 1, 7, 11, 17, 15, 105, 29, 327, 637, 1493, 3361, 1823, 14709, 18355, 741, 57807, 0 };
            const std::uint32_t dim10229JoeKuoD6Init[]   =   { 1, 1, 7, 7, 3, 27, 15, 113, 227, 617, 1543, 1719, 8065, 13627, 23525, 20511, 64759, 0 };
            const std::uint32_t dim10230JoeKuoD6Init[]   =   { 1, 1, 3, 3, 21, 47, 89, 177, 381, 711, 1367, 2405, 887, 2351, 22957, 49679, 5963, 0 };
            const std::uint32_t dim10231JoeKuoD6Init[]   =   { 1, 3, 7, 9, 7, 1, 39, 71, 9, 275, 875, 1385, 6215, 10419, 25921, 63427, 18031, 0 };
            const std::uint32_t dim10232JoeKuoD6Init[]   =   { 1, 1, 7, 5, 23, 57, 27, 7, 445, 111, 953, 37, 2769, 1967, 8165, 35417, 36471, 0 };
            const std::uint32_t dim10233JoeKuoD6Init[]   =   { 1, 3, 3, 11, 23, 17, 119, 113, 275, 625, 1957, 2795, 3815, 7937, 11049, 31939, 128053, 0 };
            const std::uint32_t dim10234JoeKuoD6Init[]   =   { 1, 3, 3, 5, 7, 35, 45, 41, 251, 491, 1953, 3201, 751, 5705, 595, 27003, 77917, 0 };
            const std::uint32_t dim10235JoeKuoD6Init[]   =   { 1, 3, 5, 3, 25, 17, 55, 137, 299, 541, 289, 2225, 4667, 3569, 13687, 36193, 75705, 0 };
            const std::uint32_t dim10236JoeKuoD6Init[]   =   { 1, 1, 7, 15, 21, 9, 27, 157, 469, 441, 193, 2097, 4863, 2147, 31197, 24283, 102039, 0 };
            const std::uint32_t dim10237JoeKuoD6Init[]   =   { 1, 1, 1, 11, 17, 39, 73, 37, 91, 121, 1283, 367, 1875, 14365, 28349, 60993, 10791, 0 };
            const std::uint32_t dim10238JoeKuoD6Init[]   =   { 1, 3, 5, 9, 13, 63, 89, 53, 459, 347, 343, 2321, 5237, 2497, 279, 63833, 10709, 0 };
            const std::uint32_t dim10239JoeKuoD6Init[]   =   { 1, 1, 1, 15, 11, 23, 41, 79, 45, 567, 1217, 1669, 1679, 2561, 16191, 49041, 4081, 0 };
            const std::uint32_t dim10240JoeKuoD6Init[]   =   { 1, 3, 1, 5, 3, 9, 103, 245, 47, 561, 229, 2945, 6563, 797, 21571, 25769, 12995, 0 };
            const std::uint32_t dim10241JoeKuoD6Init[]   =   { 1, 3, 5, 7, 5, 47, 99, 55, 49, 951, 765, 2095, 8021, 4389, 20501, 26047, 119967, 0 };
            const std::uint32_t dim10242JoeKuoD6Init[]   =   { 1, 1, 5, 3, 15, 47, 81, 121, 379, 527, 419, 1093, 367, 10939, 17181, 13905, 49859, 0 };
            const std::uint32_t dim10243JoeKuoD6Init[]   =   { 1, 3, 3, 5, 7, 59, 53, 255, 131, 685, 1677, 3757, 3601, 89, 6225, 32705, 28287, 0 };
            const std::uint32_t dim10244JoeKuoD6Init[]   =   { 1, 3, 7, 1, 7, 55, 85, 47, 425, 793, 605, 2313, 791, 4247, 9693, 10633, 82915, 0 };
            const std::uint32_t dim10245JoeKuoD6Init[]   =   { 1, 3, 5, 13, 13, 49, 127, 213, 27, 657, 419, 55, 6289, 295, 4211, 8899, 120237, 0 };
            const std::uint32_t dim10246JoeKuoD6Init[]   =   { 1, 1, 7, 11, 11, 7, 75, 35, 315, 125, 517, 3677, 2323, 6897, 11535, 36789, 20179, 0 };
            const std::uint32_t dim10247JoeKuoD6Init[]   =   { 1, 1, 5, 9, 11, 3, 77, 43, 323, 647, 383, 485, 3937, 9081, 27745, 59149, 103433, 0 };
            const std::uint32_t dim10248JoeKuoD6Init[]   =   { 1, 3, 3, 13, 3, 47, 91, 81, 115, 625, 2003, 3601, 531, 113, 20719, 47391, 111039, 0 };
            const std::uint32_t dim10249JoeKuoD6Init[]   =   { 1, 1, 3, 13, 5, 49, 123, 189, 109, 325, 497, 923, 3861, 14029, 22651, 19857, 104801, 0 };
            const std::uint32_t dim10250JoeKuoD6Init[]   =   { 1, 1, 5, 3, 29, 23, 25, 23, 501, 371, 1983, 1303, 2261, 11865, 13281, 2587, 75741, 0 };
            const std::uint32_t dim10251JoeKuoD6Init[]   =   { 1, 3, 5, 13, 27, 61, 45, 11, 157, 615, 897, 1529, 2213, 757, 30105, 2011, 27267, 0 };
            const std::uint32_t dim10252JoeKuoD6Init[]   =   { 1, 3, 5, 13, 29, 31, 95, 159, 449, 307, 1575, 1897, 2301, 14023, 6921, 30543, 31843, 0 };
            const std::uint32_t dim10253JoeKuoD6Init[]   =   { 1, 3, 3, 5, 1, 1, 79, 147, 437, 623, 1161, 3407, 3073, 15425, 4329, 19651, 90597, 0 };
            const std::uint32_t dim10254JoeKuoD6Init[]   =   { 1, 1, 1, 11, 17, 7, 43, 171, 447, 841, 573, 3775, 5517, 3629, 18241, 31907, 51423, 0 };
            const std::uint32_t dim10255JoeKuoD6Init[]   =   { 1, 1, 3, 7, 15, 53, 111, 203, 171, 963, 1983, 2017, 6067, 12281, 3417, 7431, 33803, 0 };
            const std::uint32_t dim10256JoeKuoD6Init[]   =   { 1, 3, 1, 1, 31, 49, 125, 65, 7, 579, 1709, 1815, 2643, 11537, 30093, 11813, 65157, 0 };
            const std::uint32_t dim10257JoeKuoD6Init[]   =   { 1, 3, 7, 15, 1, 3, 61, 21, 163, 809, 1263, 2577, 7811, 12611, 6921, 18529, 25709, 0 };
            const std::uint32_t dim10258JoeKuoD6Init[]   =   { 1, 1, 3, 5, 17, 43, 13, 81, 29, 905, 1975, 589, 5875, 15683, 29447, 46453, 127911, 0 };
            const std::uint32_t dim10259JoeKuoD6Init[]   =   { 1, 1, 5, 3, 19, 29, 11, 67, 375, 771, 755, 3939, 1465, 3275, 1119, 24695, 105105, 0 };
            const std::uint32_t dim10260JoeKuoD6Init[]   =   { 1, 1, 3, 11, 23, 37, 33, 135, 329, 733, 245, 2353, 2547, 7823, 16265, 5975, 37877, 0 };
            const std::uint32_t dim10261JoeKuoD6Init[]   =   { 1, 3, 7, 13, 15, 9, 47, 181, 239, 723, 1219, 409, 1685, 5493, 14189, 18107, 26231, 0 };
            const std::uint32_t dim10262JoeKuoD6Init[]   =   { 1, 1, 5, 1, 9, 1, 65, 125, 439, 591, 1499, 3797, 5879, 4231, 18655, 9643, 42265, 0 };
            const std::uint32_t dim10263JoeKuoD6Init[]   =   { 1, 1, 7, 7, 11, 51, 111, 47, 169, 39, 45, 2211, 6729, 10987, 22367, 27257, 112711, 0 };
            const std::uint32_t dim10264JoeKuoD6Init[]   =   { 1, 3, 5, 3, 19, 61, 89, 185, 23, 793, 1457, 1743, 3743, 15063, 14053, 50201, 109175, 0 };
            const std::uint32_t dim10265JoeKuoD6Init[]   =   { 1, 1, 5, 13, 31, 51, 69, 135, 427, 527, 1673, 2393, 5829, 683, 1509, 56617, 105735, 0 };
            const std::uint32_t dim10266JoeKuoD6Init[]   =   { 1, 1, 1, 15, 31, 51, 3, 105, 125, 593, 1589, 3217, 7449, 525, 30599, 11689, 14781, 0 };
            const std::uint32_t dim10267JoeKuoD6Init[]   =   { 1, 1, 1, 11, 9, 37, 113, 45, 487, 961, 87, 1461, 3521, 8645, 19771, 43817, 43277, 0 };
            const std::uint32_t dim10268JoeKuoD6Init[]   =   { 1, 1, 7, 3, 7, 11, 45, 97, 11, 593, 319, 2597, 37, 4157, 6669, 29929, 17213, 0 };
            const std::uint32_t dim10269JoeKuoD6Init[]   =   { 1, 3, 7, 3, 29, 21, 101, 93, 289, 975, 1937, 3423, 757, 7075, 12575, 26801, 90989, 0 };
            const std::uint32_t dim10270JoeKuoD6Init[]   =   { 1, 1, 7, 15, 25, 49, 49, 149, 503, 365, 1359, 2155, 7977, 14955, 18439, 44269, 88995, 0 };
            const std::uint32_t dim10271JoeKuoD6Init[]   =   { 1, 3, 7, 13, 25, 27, 15, 67, 157, 873, 339, 2143, 1405, 12209, 30939, 36109, 107699, 0 };
            const std::uint32_t dim10272JoeKuoD6Init[]   =   { 1, 3, 5, 5, 21, 33, 121, 95, 61, 159, 1423, 2899, 3811, 263, 9139, 54481, 107375, 0 };
            const std::uint32_t dim10273JoeKuoD6Init[]   =   { 1, 1, 7, 7, 13, 49, 83, 53, 267, 131, 673, 3945, 5255, 2009, 21017, 41749, 44817, 0 };
            const std::uint32_t dim10274JoeKuoD6Init[]   =   { 1, 3, 1, 13, 25, 57, 125, 5, 323, 653, 221, 2013, 7225, 8719, 28049, 41953, 14725, 0 };
            const std::uint32_t dim10275JoeKuoD6Init[]   =   { 1, 3, 7, 7, 5, 13, 35, 161, 221, 951, 769, 717, 267, 2233, 23387, 47411, 95739, 0 };
            const std::uint32_t dim10276JoeKuoD6Init[]   =   { 1, 3, 7, 11, 23, 47, 37, 67, 501, 159, 763, 4045, 5125, 5667, 9895, 33041, 101171, 0 };
            const std::uint32_t dim10277JoeKuoD6Init[]   =   { 1, 1, 7, 1, 31, 31, 111, 183, 33, 895, 1819, 3593, 1285, 10145, 3679, 36615, 82863, 0 };
            const std::uint32_t dim10278JoeKuoD6Init[]   =   { 1, 3, 5, 7, 21, 59, 55, 163, 139, 855, 1903, 3229, 3745, 10289, 28831, 46895, 12647, 0 };
            const std::uint32_t dim10279JoeKuoD6Init[]   =   { 1, 3, 7, 9, 25, 31, 113, 177, 459, 201, 565, 2089, 725, 9273, 26249, 5987, 49573, 0 };
            const std::uint32_t dim10280JoeKuoD6Init[]   =   { 1, 1, 7, 15, 3, 37, 49, 145, 121, 803, 1197, 2797, 21, 833, 2277, 28189, 93171, 0 };
            const std::uint32_t dim10281JoeKuoD6Init[]   =   { 1, 1, 7, 7, 13, 31, 93, 153, 345, 363, 1825, 1481, 3347, 13277, 26119, 63153, 118231, 0 };
            const std::uint32_t dim10282JoeKuoD6Init[]   =   { 1, 3, 1, 11, 31, 9, 33, 95, 433, 595, 1131, 465, 1797, 15453, 32527, 40789, 37799, 0 };
            const std::uint32_t dim10283JoeKuoD6Init[]   =   { 1, 1, 5, 11, 31, 29, 83, 33, 243, 633, 1325, 3843, 7717, 851, 29789, 48827, 89209, 0 };
            const std::uint32_t dim10284JoeKuoD6Init[]   =   { 1, 1, 3, 7, 25, 31, 127, 219, 281, 51, 1843, 3363, 5985, 1697, 3083, 18967, 117421, 0 };
            const std::uint32_t dim10285JoeKuoD6Init[]   =   { 1, 3, 7, 9, 1, 19, 125, 199, 41, 117, 903, 1131, 7731, 14431, 24753, 62841, 50251, 0 };
            const std::uint32_t dim10286JoeKuoD6Init[]   =   { 1, 3, 5, 5, 11, 37, 19, 249, 97, 59, 1849, 1151, 2171, 1217, 31277, 26547, 86601, 0 };
            const std::uint32_t dim10287JoeKuoD6Init[]   =   { 1, 3, 3, 7, 29, 35, 21, 7, 93, 971, 1155, 1847, 89, 6759, 29611, 40793, 88327, 0 };
            const std::uint32_t dim10288JoeKuoD6Init[]   =   { 1, 3, 5, 5, 29, 23, 91, 71, 479, 943, 1839, 3699, 2491, 9603, 15061, 43221, 20435, 0 };
            const std::uint32_t dim10289JoeKuoD6Init[]   =   { 1, 3, 3, 7, 29, 11, 15, 83, 21, 585, 501, 161, 4797, 11243, 14879, 12519, 19069, 0 };
            const std::uint32_t dim10290JoeKuoD6Init[]   =   { 1, 1, 5, 15, 13, 37, 9, 215, 433, 925, 987, 3253, 8027, 7013, 20801, 12891, 36497, 0 };
            const std::uint32_t dim10291JoeKuoD6Init[]   =   { 1, 3, 7, 1, 15, 31, 95, 85, 355, 1013, 1963, 2943, 1925, 13691, 15237, 28943, 63873, 0 };
            const std::uint32_t dim10292JoeKuoD6Init[]   =   { 1, 3, 3, 1, 17, 21, 99, 201, 465, 819, 665, 901, 2671, 2457, 29603, 35275, 28339, 0 };
            const std::uint32_t dim10293JoeKuoD6Init[]   =   { 1, 1, 1, 9, 5, 23, 111, 107, 27, 433, 1341, 91, 6879, 1933, 25433, 37435, 99061, 0 };
            const std::uint32_t dim10294JoeKuoD6Init[]   =   { 1, 3, 5, 13, 11, 55, 27, 151, 397, 591, 89, 1221, 5581, 2701, 15033, 41879, 71415, 0 };
            const std::uint32_t dim10295JoeKuoD6Init[]   =   { 1, 3, 3, 5, 17, 35, 15, 119, 487, 903, 875, 3391, 7731, 12181, 27823, 32561, 59133, 0 };
            const std::uint32_t dim10296JoeKuoD6Init[]   =   { 1, 1, 5, 7, 15, 33, 67, 53, 307, 947, 857, 2713, 803, 765, 4175, 15513, 23985, 0 };
            const std::uint32_t dim10297JoeKuoD6Init[]   =   { 1, 3, 1, 15, 23, 11, 15, 101, 467, 429, 153, 3205, 5627, 7555, 22515, 12721, 7905, 0 };
            const std::uint32_t dim10298JoeKuoD6Init[]   =   { 1, 1, 3, 7, 19, 61, 55, 187, 413, 49, 1031, 3415, 3903, 6933, 20017, 50429, 116407, 0 };
            const std::uint32_t dim10299JoeKuoD6Init[]   =   { 1, 3, 1, 13, 13, 15, 33, 1, 403, 441, 1969, 775, 2209, 15061, 15657, 28819, 62705, 0 };
            const std::uint32_t dim10300JoeKuoD6Init[]   =   { 1, 1, 5, 13, 13, 47, 67, 97, 87, 677, 1639, 3281, 1395, 8499, 18449, 49935, 25775, 0 };
            const std::uint32_t dim10301JoeKuoD6Init[]   =   { 1, 3, 3, 13, 7, 13, 77, 45, 405, 881, 293, 2263, 6517, 15415, 25809, 5681, 31327, 0 };
            const std::uint32_t dim10302JoeKuoD6Init[]   =   { 1, 3, 7, 5, 5, 51, 63, 171, 401, 671, 1631, 1735, 7361, 8741, 31933, 44761, 12209, 0 };
            const std::uint32_t dim10303JoeKuoD6Init[]   =   { 1, 1, 7, 3, 13, 3, 39, 223, 105, 781, 241, 2895, 5165, 12135, 5683, 63009, 58399, 0 };
            const std::uint32_t dim10304JoeKuoD6Init[]   =   { 1, 1, 5, 11, 29, 11, 37, 1, 445, 157, 219, 2269, 3025, 5721, 24539, 41879, 128445, 0 };
            const std::uint32_t dim10305JoeKuoD6Init[]   =   { 1, 3, 7, 15, 23, 21, 125, 105, 141, 101, 1981, 3765, 5349, 13781, 10055, 7069, 77721, 0 };
            const std::uint32_t dim10306JoeKuoD6Init[]   =   { 1, 1, 7, 9, 3, 37, 111, 95, 33, 53, 1021, 1629, 6945, 4657, 19977, 36715, 101401, 0 };
            const std::uint32_t dim10307JoeKuoD6Init[]   =   { 1, 3, 3, 1, 9, 5, 65, 77, 459, 471, 1045, 2351, 2787, 13001, 16211, 22585, 116205, 0 };
            const std::uint32_t dim10308JoeKuoD6Init[]   =   { 1, 1, 7, 9, 25, 41, 21, 187, 471, 997, 583, 2243, 6537, 11837, 21089, 51051, 98517, 0 };
            const std::uint32_t dim10309JoeKuoD6Init[]   =   { 1, 1, 7, 5, 13, 15, 81, 39, 223, 935, 951, 5, 4315, 11789, 18365, 49647, 92461, 0 };
            const std::uint32_t dim10310JoeKuoD6Init[]   =   { 1, 3, 3, 5, 11, 15, 97, 245, 43, 819, 1415, 3287, 2051, 15879, 21727, 54467, 53875, 0 };
            const std::uint32_t dim10311JoeKuoD6Init[]   =   { 1, 3, 1, 11, 7, 47, 125, 155, 301, 469, 805, 3789, 6967, 12117, 30369, 55183, 12671, 0 };
            const std::uint32_t dim10312JoeKuoD6Init[]   =   { 1, 1, 3, 13, 17, 25, 45, 199, 69, 1015, 581, 3891, 7743, 9273, 7639, 59055, 93923, 0 };
            const std::uint32_t dim10313JoeKuoD6Init[]   =   { 1, 1, 5, 11, 9, 47, 39, 251, 489, 47, 83, 2147, 943, 1959, 21361, 5325, 106079, 0 };
            const std::uint32_t dim10314JoeKuoD6Init[]   =   { 1, 3, 5, 13, 27, 59, 35, 1, 155, 367, 165, 2665, 3021, 1127, 28585, 45347, 66763, 0 };
            const std::uint32_t dim10315JoeKuoD6Init[]   =   { 1, 3, 1, 5, 31, 31, 15, 125, 485, 581, 1987, 2293, 4573, 11431, 20773, 58661, 79869, 0 };
            const std::uint32_t dim10316JoeKuoD6Init[]   =   { 1, 3, 5, 15, 31, 11, 109, 229, 11, 831, 1545, 919, 6125, 9337, 4169, 58041, 67577, 0 };
            const std::uint32_t dim10317JoeKuoD6Init[]   =   { 1, 1, 1, 3, 1, 43, 13, 89, 89, 863, 1607, 1897, 4831, 5239, 24503, 51853, 126983, 0 };
            const std::uint32_t dim10318JoeKuoD6Init[]   =   { 1, 1, 5, 11, 11, 37, 11, 253, 495, 83, 941, 3665, 5187, 13679, 11811, 29563, 80571, 0 };
            const std::uint32_t dim10319JoeKuoD6Init[]   =   { 1, 3, 7, 15, 3, 45, 45, 157, 477, 321, 1401, 1133, 271, 12455, 31543, 18223, 116701, 0 };
            const std::uint32_t dim10320JoeKuoD6Init[]   =   { 1, 1, 5, 3, 7, 5, 17, 127, 195, 583, 715, 3975, 6865, 7617, 6749, 15687, 42375, 0 };
            const std::uint32_t dim10321JoeKuoD6Init[]   =   { 1, 1, 1, 7, 5, 7, 21, 163, 303, 45, 1435, 1345, 2489, 15333, 18459, 60837, 104339, 0 };
            const std::uint32_t dim10322JoeKuoD6Init[]   =   { 1, 3, 1, 1, 7, 23, 39, 93, 347, 947, 345, 1713, 6383, 15411, 10849, 32559, 126431, 0 };
            const std::uint32_t dim10323JoeKuoD6Init[]   =   { 1, 3, 1, 5, 19, 41, 119, 213, 3, 991, 1745, 3989, 155, 7761, 28179, 59805, 106759, 0 };
            const std::uint32_t dim10324JoeKuoD6Init[]   =   { 1, 1, 7, 5, 25, 11, 105, 89, 505, 711, 1213, 2831, 8087, 8855, 31171, 49749, 921, 0 };
            const std::uint32_t dim10325JoeKuoD6Init[]   =   { 1, 1, 5, 5, 23, 61, 49, 101, 209, 805, 123, 17, 805, 9033, 25753, 33261, 33753, 0 };
            const std::uint32_t dim10326JoeKuoD6Init[]   =   { 1, 1, 3, 5, 5, 17, 93, 223, 179, 307, 869, 1851, 4313, 477, 12925, 21365, 103999, 0 };
            const std::uint32_t dim10327JoeKuoD6Init[]   =   { 1, 1, 7, 13, 21, 23, 105, 53, 393, 939, 291, 2407, 4815, 4961, 30305, 8613, 62599, 0 };
            const std::uint32_t dim10328JoeKuoD6Init[]   =   { 1, 1, 1, 11, 9, 55, 55, 135, 411, 225, 205, 3357, 4553, 10139, 17649, 51209, 94037, 0 };
            const std::uint32_t dim10329JoeKuoD6Init[]   =   { 1, 3, 5, 15, 17, 17, 119, 15, 121, 581, 169, 2495, 3673, 7173, 13099, 7683, 53397, 0 };
            const std::uint32_t dim10330JoeKuoD6Init[]   =   { 1, 3, 1, 11, 29, 29, 119, 255, 447, 85, 845, 1015, 2793, 2471, 12639, 32155, 99193, 0 };
            const std::uint32_t dim10331JoeKuoD6Init[]   =   { 1, 3, 3, 3, 9, 33, 77, 251, 425, 1007, 1003, 2697, 4989, 7799, 26581, 15963, 50443, 0 };
            const std::uint32_t dim10332JoeKuoD6Init[]   =   { 1, 3, 1, 5, 13, 47, 13, 203, 473, 529, 147, 2061, 343, 4029, 14615, 51355, 27863, 0 };
            const std::uint32_t dim10333JoeKuoD6Init[]   =   { 1, 1, 3, 15, 19, 63, 39, 25, 241, 487, 461, 3021, 3545, 4537, 8991, 17689, 77131, 0 };
            const std::uint32_t dim10334JoeKuoD6Init[]   =   { 1, 3, 5, 5, 7, 1, 61, 89, 495, 943, 1061, 405, 449, 12785, 25151, 24497, 65709, 0 };
            const std::uint32_t dim10335JoeKuoD6Init[]   =   { 1, 1, 5, 3, 7, 43, 51, 55, 193, 615, 37, 1377, 2541, 3861, 29447, 32269, 106335, 0 };
            const std::uint32_t dim10336JoeKuoD6Init[]   =   { 1, 1, 5, 11, 21, 55, 103, 43, 421, 673, 175, 979, 5175, 1301, 8617, 55875, 111095, 0 };
            const std::uint32_t dim10337JoeKuoD6Init[]   =   { 1, 3, 5, 13, 29, 31, 33, 241, 129, 473, 201, 2015, 447, 99, 23781, 33517, 107851, 0 };
            const std::uint32_t dim10338JoeKuoD6Init[]   =   { 1, 3, 5, 3, 13, 27, 125, 205, 287, 957, 1609, 2907, 5481, 14239, 19719, 22459, 75365, 0 };
            const std::uint32_t dim10339JoeKuoD6Init[]   =   { 1, 3, 3, 5, 27, 23, 53, 39, 329, 381, 745, 517, 7853, 5333, 2773, 29119, 7049, 0 };
            const std::uint32_t dim10340JoeKuoD6Init[]   =   { 1, 3, 5, 15, 29, 11, 89, 3, 503, 755, 485, 2669, 6737, 16241, 7345, 50991, 107291, 0 };
            const std::uint32_t dim10341JoeKuoD6Init[]   =   { 1, 1, 7, 3, 17, 45, 11, 3, 157, 715, 577, 1309, 3323, 9401, 10573, 55135, 100067, 0 };
            const std::uint32_t dim10342JoeKuoD6Init[]   =   { 1, 1, 5, 9, 19, 21, 49, 103, 349, 503, 1447, 675, 4273, 7673, 27507, 57697, 80875, 0 };
            const std::uint32_t dim10343JoeKuoD6Init[]   =   { 1, 1, 5, 1, 9, 53, 19, 99, 225, 915, 431, 781, 3291, 4383, 26505, 50339, 99799, 0 };
            const std::uint32_t dim10344JoeKuoD6Init[]   =   { 1, 3, 1, 5, 7, 37, 87, 201, 481, 991, 1553, 1867, 7893, 13147, 18647, 10373, 51951, 0 };
            const std::uint32_t dim10345JoeKuoD6Init[]   =   { 1, 1, 3, 13, 17, 37, 19, 199, 253, 901, 759, 3545, 3565, 10461, 11867, 57605, 75555, 0 };
            const std::uint32_t dim10346JoeKuoD6Init[]   =   { 1, 1, 1, 5, 15, 23, 115, 69, 363, 673, 201, 2451, 3197, 10059, 1667, 47145, 89, 0 };
            const std::uint32_t dim10347JoeKuoD6Init[]   =   { 1, 1, 7, 13, 19, 31, 63, 35, 93, 939, 1057, 3221, 951, 3575, 9659, 7005, 2087, 0 };
            const std::uint32_t dim10348JoeKuoD6Init[]   =   { 1, 1, 7, 15, 15, 21, 79, 7, 23, 595, 1123, 1909, 6863, 7383, 28067, 30113, 107497, 0 };
            const std::uint32_t dim10349JoeKuoD6Init[]   =   { 1, 3, 5, 7, 11, 47, 41, 177, 163, 855, 1853, 3837, 6995, 9727, 27285, 62667, 77531, 0 };
            const std::uint32_t dim10350JoeKuoD6Init[]   =   { 1, 3, 7, 3, 3, 29, 99, 163, 95, 893, 1049, 2001, 2961, 601, 4613, 59745, 61203, 0 };
            const std::uint32_t dim10351JoeKuoD6Init[]   =   { 1, 3, 5, 1, 27, 5, 5, 47, 119, 631, 1171, 3467, 2115, 8581, 24863, 64193, 52093, 0 };
            const std::uint32_t dim10352JoeKuoD6Init[]   =   { 1, 1, 1, 5, 9, 51, 49, 251, 97, 177, 311, 993, 1103, 7875, 25273, 51587, 9081, 0 };
            const std::uint32_t dim10353JoeKuoD6Init[]   =   { 1, 3, 7, 5, 31, 21, 43, 137, 143, 779, 691, 2331, 5073, 5409, 13335, 999, 127765, 0 };
            const std::uint32_t dim10354JoeKuoD6Init[]   =   { 1, 1, 7, 1, 31, 33, 27, 193, 175, 755, 1559, 659, 5663, 10491, 29209, 50979, 116683, 0 };
            const std::uint32_t dim10355JoeKuoD6Init[]   =   { 1, 3, 1, 7, 23, 49, 1, 39, 117, 45, 1767, 3503, 4901, 5699, 23613, 44195, 17867, 0 };
            const std::uint32_t dim10356JoeKuoD6Init[]   =   { 1, 3, 7, 13, 3, 5, 105, 89, 343, 627, 1117, 3419, 2081, 5747, 7919, 44329, 125133, 0 };
            const std::uint32_t dim10357JoeKuoD6Init[]   =   { 1, 3, 1, 9, 13, 33, 53, 203, 17, 927, 127, 2195, 415, 11301, 15115, 54467, 128777, 0 };
            const std::uint32_t dim10358JoeKuoD6Init[]   =   { 1, 3, 7, 1, 9, 41, 15, 89, 403, 333, 57, 1159, 1325, 2335, 10609, 20485, 110317, 0 };
            const std::uint32_t dim10359JoeKuoD6Init[]   =   { 1, 3, 3, 5, 3, 61, 25, 155, 477, 907, 359, 359, 5119, 8157, 29945, 38955, 106485, 0 };
            const std::uint32_t dim10360JoeKuoD6Init[]   =   { 1, 1, 7, 5, 19, 47, 91, 89, 367, 703, 761, 431, 6813, 2983, 29739, 52453, 125935, 0 };
            const std::uint32_t dim10361JoeKuoD6Init[]   =   { 1, 1, 1, 7, 7, 61, 127, 239, 277, 649, 1111, 2319, 1737, 5071, 13469, 52119, 48899, 0 };
            const std::uint32_t dim10362JoeKuoD6Init[]   =   { 1, 3, 5, 15, 7, 17, 21, 209, 265, 895, 719, 263, 6871, 5835, 28483, 49859, 67619, 0 };
            const std::uint32_t dim10363JoeKuoD6Init[]   =   { 1, 3, 3, 15, 3, 7, 113, 109, 333, 545, 597, 1193, 7593, 3961, 25169, 64673, 47839, 0 };
            const std::uint32_t dim10364JoeKuoD6Init[]   =   { 1, 1, 1, 3, 15, 45, 55, 41, 317, 719, 1587, 2953, 2441, 1127, 9183, 21637, 69075, 0 };
            const std::uint32_t dim10365JoeKuoD6Init[]   =   { 1, 3, 1, 9, 25, 57, 59, 29, 89, 833, 379, 1085, 763, 14747, 30797, 24089, 83367, 0 };
            const std::uint32_t dim10366JoeKuoD6Init[]   =   { 1, 1, 5, 13, 29, 3, 117, 239, 453, 595, 243, 3103, 6047, 631, 22739, 41669, 11683, 0 };
            const std::uint32_t dim10367JoeKuoD6Init[]   =   { 1, 1, 3, 1, 9, 53, 81, 21, 67, 735, 827, 3519, 7991, 16249, 4183, 61295, 4531, 0 };
            const std::uint32_t dim10368JoeKuoD6Init[]   =   { 1, 3, 5, 3, 1, 57, 47, 99, 91, 71, 1421, 2949, 5951, 15439, 25239, 26453, 50199, 0 };
            const std::uint32_t dim10369JoeKuoD6Init[]   =   { 1, 1, 3, 15, 21, 3, 93, 21, 41, 809, 855, 727, 7797, 6957, 15835, 27175, 60617, 0 };
            const std::uint32_t dim10370JoeKuoD6Init[]   =   { 1, 1, 1, 13, 1, 3, 83, 135, 197, 171, 1459, 2841, 5021, 6961, 30675, 38295, 39555, 0 };
            const std::uint32_t dim10371JoeKuoD6Init[]   =   { 1, 1, 7, 5, 7, 49, 83, 83, 117, 73, 639, 2717, 651, 3253, 31635, 14427, 116509, 0 };
            const std::uint32_t dim10372JoeKuoD6Init[]   =   { 1, 3, 1, 3, 23, 63, 15, 23, 433, 539, 903, 2655, 1787, 12901, 12013, 41315, 128217, 0 };
            const std::uint32_t dim10373JoeKuoD6Init[]   =   { 1, 3, 1, 7, 5, 19, 3, 137, 493, 681, 775, 3725, 4855, 10817, 25277, 3631, 60779, 0 };
            const std::uint32_t dim10374JoeKuoD6Init[]   =   { 1, 3, 3, 5, 1, 7, 67, 39, 309, 77, 1679, 2853, 3803, 2065, 7461, 1555, 88219, 0 };
            const std::uint32_t dim10375JoeKuoD6Init[]   =   { 1, 1, 3, 5, 3, 47, 17, 193, 429, 789, 1525, 969, 7905, 6523, 10149, 64689, 40037, 0 };
            const std::uint32_t dim10376JoeKuoD6Init[]   =   { 1, 3, 5, 7, 21, 17, 65, 61, 255, 517, 1765, 2603, 4929, 11073, 7871, 29313, 84739, 0 };
            const std::uint32_t dim10377JoeKuoD6Init[]   =   { 1, 1, 5, 7, 13, 55, 111, 63, 499, 9, 1715, 957, 6951, 15839, 13531, 45483, 17923, 0 };
            const std::uint32_t dim10378JoeKuoD6Init[]   =   { 1, 1, 1, 1, 27, 7, 13, 135, 27, 259, 1735, 3847, 7931, 14777, 15249, 62367, 45773, 0 };
            const std::uint32_t dim10379JoeKuoD6Init[]   =   { 1, 1, 5, 3, 5, 7, 99, 171, 491, 1007, 195, 2223, 2657, 13557, 6549, 47125, 25117, 0 };
            const std::uint32_t dim10380JoeKuoD6Init[]   =   { 1, 1, 1, 9, 13, 21, 59, 205, 205, 951, 1707, 3387, 2901, 5463, 13403, 1917, 90591, 0 };
            const std::uint32_t dim10381JoeKuoD6Init[]   =   { 1, 3, 3, 5, 21, 37, 71, 91, 297, 885, 1415, 355, 2877, 9261, 6485, 45855, 90081, 0 };
            const std::uint32_t dim10382JoeKuoD6Init[]   =   { 1, 1, 5, 9, 23, 51, 107, 75, 93, 1015, 439, 3589, 3307, 337, 17247, 42285, 85417, 0 };
            const std::uint32_t dim10383JoeKuoD6Init[]   =   { 1, 1, 7, 15, 29, 33, 51, 23, 269, 35, 1241, 1137, 729, 14531, 14603, 47547, 17151, 0 };
            const std::uint32_t dim10384JoeKuoD6Init[]   =   { 1, 3, 3, 1, 25, 21, 51, 229, 55, 561, 653, 3289, 7629, 15445, 21115, 35941, 113669, 0 };
            const std::uint32_t dim10385JoeKuoD6Init[]   =   { 1, 1, 5, 15, 1, 33, 119, 171, 75, 621, 2025, 3235, 1895, 8279, 13205, 61085, 105401, 0 };
            const std::uint32_t dim10386JoeKuoD6Init[]   =   { 1, 3, 1, 7, 25, 33, 73, 25, 1, 531, 603, 77, 4939, 5957, 28065, 59467, 66659, 0 };
            const std::uint32_t dim10387JoeKuoD6Init[]   =   { 1, 1, 7, 3, 17, 61, 103, 47, 289, 39, 917, 2515, 6607, 1129, 23361, 46321, 81929, 0 };
            const std::uint32_t dim10388JoeKuoD6Init[]   =   { 1, 1, 7, 5, 29, 53, 5, 191, 151, 19, 895, 1215, 5401, 9861, 24751, 15481, 34179, 0 };
            const std::uint32_t dim10389JoeKuoD6Init[]   =   { 1, 3, 7, 9, 5, 3, 29, 205, 173, 547, 727, 947, 5619, 4181, 30621, 5553, 37587, 0 };
            const std::uint32_t dim10390JoeKuoD6Init[]   =   { 1, 1, 3, 9, 13, 59, 95, 145, 287, 849, 1483, 3375, 3531, 6585, 29565, 4243, 88333, 0 };
            const std::uint32_t dim10391JoeKuoD6Init[]   =   { 1, 1, 7, 11, 21, 23, 59, 223, 71, 743, 443, 697, 7789, 10371, 28565, 45127, 37967, 0 };
            const std::uint32_t dim10392JoeKuoD6Init[]   =   { 1, 3, 5, 11, 15, 25, 79, 71, 21, 817, 751, 189, 1769, 3835, 21465, 17991, 102043, 0 };
            const std::uint32_t dim10393JoeKuoD6Init[]   =   { 1, 1, 7, 11, 3, 19, 25, 5, 261, 181, 49, 261, 7715, 2195, 19771, 43463, 36533, 0 };
            const std::uint32_t dim10394JoeKuoD6Init[]   =   { 1, 1, 7, 13, 21, 21, 15, 235, 191, 197, 1305, 1351, 4511, 625, 6613, 37053, 59491, 0 };
            const std::uint32_t dim10395JoeKuoD6Init[]   =   { 1, 1, 1, 13, 15, 13, 93, 239, 251, 1009, 527, 1347, 4173, 14753, 27389, 20397, 13101, 0 };
            const std::uint32_t dim10396JoeKuoD6Init[]   =   { 1, 1, 3, 1, 15, 11, 127, 141, 277, 775, 1419, 2353, 6929, 2265, 7253, 19807, 74853, 0 };
            const std::uint32_t dim10397JoeKuoD6Init[]   =   { 1, 3, 3, 15, 15, 49, 9, 183, 407, 377, 675, 871, 347, 3417, 4409, 7805, 40507, 0 };
            const std::uint32_t dim10398JoeKuoD6Init[]   =   { 1, 3, 5, 3, 23, 11, 81, 53, 343, 681, 1777, 3411, 757, 10875, 3581, 56105, 79907, 0 };
            const std::uint32_t dim10399JoeKuoD6Init[]   =   { 1, 3, 5, 1, 25, 9, 109, 55, 283, 311, 1607, 2479, 5675, 8819, 10853, 38719, 44471, 0 };
            const std::uint32_t dim10400JoeKuoD6Init[]   =   { 1, 1, 7, 7, 9, 53, 33, 195, 503, 167, 993, 3203, 3885, 1921, 1039, 25785, 47411, 0 };
            const std::uint32_t dim10401JoeKuoD6Init[]   =   { 1, 3, 3, 3, 31, 3, 11, 85, 475, 743, 1825, 2649, 2373, 12177, 21481, 35579, 85803, 0 };
            const std::uint32_t dim10402JoeKuoD6Init[]   =   { 1, 3, 7, 3, 23, 45, 45, 207, 369, 773, 1579, 783, 2491, 7441, 21203, 57091, 107413, 0 };
            const std::uint32_t dim10403JoeKuoD6Init[]   =   { 1, 1, 1, 5, 19, 7, 97, 213, 431, 533, 637, 1767, 4945, 4693, 977, 64781, 111811, 0 };
            const std::uint32_t dim10404JoeKuoD6Init[]   =   { 1, 3, 7, 7, 1, 55, 101, 251, 153, 95, 1043, 3219, 3499, 6297, 11571, 9131, 61899, 0 };
            const std::uint32_t dim10405JoeKuoD6Init[]   =   { 1, 3, 5, 5, 25, 53, 121, 255, 69, 661, 799, 3559, 2029, 11701, 14151, 37897, 18333, 0 };
            const std::uint32_t dim10406JoeKuoD6Init[]   =   { 1, 1, 1, 9, 21, 19, 97, 21, 321, 957, 1115, 251, 5131, 8465, 24215, 34423, 12747, 0 };
            const std::uint32_t dim10407JoeKuoD6Init[]   =   { 1, 3, 5, 7, 17, 19, 99, 135, 429, 625, 1401, 1025, 4193, 2911, 7349, 34135, 9341, 0 };
            const std::uint32_t dim10408JoeKuoD6Init[]   =   { 1, 3, 5, 1, 5, 63, 97, 121, 307, 547, 1967, 641, 487, 4627, 30899, 62049, 94343, 0 };
            const std::uint32_t dim10409JoeKuoD6Init[]   =   { 1, 3, 5, 13, 1, 1, 109, 23, 267, 843, 271, 2277, 855, 4245, 2177, 33633, 113835, 0 };
            const std::uint32_t dim10410JoeKuoD6Init[]   =   { 1, 1, 3, 7, 3, 27, 91, 79, 27, 855, 2025, 443, 4797, 9005, 27533, 20497, 100431, 0 };
            const std::uint32_t dim10411JoeKuoD6Init[]   =   { 1, 3, 3, 5, 23, 7, 73, 35, 395, 649, 881, 2923, 4065, 853, 10829, 19461, 82383, 0 };
            const std::uint32_t dim10412JoeKuoD6Init[]   =   { 1, 3, 1, 5, 25, 13, 85, 93, 369, 259, 393, 3233, 799, 12409, 26631, 64291, 110133, 0 };
            const std::uint32_t dim10413JoeKuoD6Init[]   =   { 1, 3, 5, 5, 31, 35, 25, 239, 455, 893, 573, 1449, 3359, 12077, 17149, 12921, 66931, 0 };
            const std::uint32_t dim10414JoeKuoD6Init[]   =   { 1, 1, 7, 3, 25, 39, 67, 87, 215, 325, 627, 3609, 4417, 10021, 12047, 64593, 116525, 0 };
            const std::uint32_t dim10415JoeKuoD6Init[]   =   { 1, 1, 5, 5, 23, 51, 125, 247, 83, 419, 655, 635, 7053, 4907, 12887, 18083, 49481, 0 };
            const std::uint32_t dim10416JoeKuoD6Init[]   =   { 1, 1, 7, 11, 5, 25, 65, 139, 235, 331, 1885, 1851, 1061, 13265, 14371, 23067, 56757, 0 };
            const std::uint32_t dim10417JoeKuoD6Init[]   =   { 1, 1, 7, 9, 11, 15, 29, 255, 509, 869, 561, 2201, 487, 2989, 14943, 65373, 35789, 0 };
            const std::uint32_t dim10418JoeKuoD6Init[]   =   { 1, 1, 1, 3, 3, 33, 23, 121, 129, 351, 1481, 65, 321, 15927, 23849, 2813, 98547, 0 };
            const std::uint32_t dim10419JoeKuoD6Init[]   =   { 1, 1, 1, 3, 23, 55, 121, 35, 339, 87, 1147, 401, 1477, 10617, 15943, 20535, 89321, 0 };
            const std::uint32_t dim10420JoeKuoD6Init[]   =   { 1, 3, 5, 15, 25, 59, 111, 185, 305, 47, 523, 2801, 5485, 625, 30191, 58153, 9019, 0 };
            const std::uint32_t dim10421JoeKuoD6Init[]   =   { 1, 1, 7, 13, 15, 51, 105, 55, 77, 419, 1011, 1117, 2705, 15093, 15629, 51429, 58487, 0 };
            const std::uint32_t dim10422JoeKuoD6Init[]   =   { 1, 3, 7, 5, 15, 27, 19, 7, 401, 295, 1841, 1167, 2133, 1967, 6941, 13571, 29467, 0 };
            const std::uint32_t dim10423JoeKuoD6Init[]   =   { 1, 1, 5, 15, 25, 43, 23, 253, 173, 927, 1299, 2779, 5489, 16135, 1503, 51097, 105751, 0 };
            const std::uint32_t dim10424JoeKuoD6Init[]   =   { 1, 3, 3, 5, 9, 13, 5, 13, 411, 639, 1323, 1495, 2539, 15087, 21489, 49653, 76229, 0 };
            const std::uint32_t dim10425JoeKuoD6Init[]   =   { 1, 1, 1, 11, 7, 51, 47, 99, 247, 541, 1355, 2373, 4121, 13621, 7715, 16763, 127985, 0 };
            const std::uint32_t dim10426JoeKuoD6Init[]   =   { 1, 1, 3, 9, 7, 1, 85, 45, 269, 769, 581, 2229, 7143, 5203, 22483, 18511, 30997, 0 };
            const std::uint32_t dim10427JoeKuoD6Init[]   =   { 1, 3, 5, 7, 21, 41, 97, 225, 109, 195, 1197, 3417, 7613, 13225, 29157, 18969, 82045, 0 };
            const std::uint32_t dim10428JoeKuoD6Init[]   =   { 1, 3, 3, 3, 17, 41, 13, 77, 129, 679, 1659, 1299, 4809, 8537, 19081, 1281, 70793, 0 };
            const std::uint32_t dim10429JoeKuoD6Init[]   =   { 1, 1, 5, 5, 5, 49, 5, 15, 313, 941, 775, 259, 6579, 7745, 20531, 51669, 35257, 0 };
            const std::uint32_t dim10430JoeKuoD6Init[]   =   { 1, 1, 5, 5, 17, 35, 13, 235, 169, 699, 1365, 3907, 4231, 10965, 7737, 6735, 4253, 0 };
            const std::uint32_t dim10431JoeKuoD6Init[]   =   { 1, 1, 5, 3, 29, 3, 1, 197, 133, 935, 571, 3977, 2467, 2029, 12803, 64559, 6427, 0 };
            const std::uint32_t dim10432JoeKuoD6Init[]   =   { 1, 3, 5, 5, 27, 5, 69, 57, 439, 925, 1695, 827, 4685, 10971, 3011, 56821, 92187, 0 };
            const std::uint32_t dim10433JoeKuoD6Init[]   =   { 1, 1, 1, 3, 9, 45, 77, 179, 173, 1023, 907, 1999, 3913, 6973, 26987, 30237, 62987, 0 };
            const std::uint32_t dim10434JoeKuoD6Init[]   =   { 1, 3, 7, 3, 5, 21, 17, 97, 433, 277, 1515, 2923, 8025, 14119, 11243, 3983, 33943, 0 };
            const std::uint32_t dim10435JoeKuoD6Init[]   =   { 1, 1, 5, 7, 15, 13, 119, 169, 21, 927, 439, 361, 2655, 2237, 19775, 4157, 84245, 0 };
            const std::uint32_t dim10436JoeKuoD6Init[]   =   { 1, 3, 5, 5, 31, 41, 117, 159, 421, 505, 1617, 3855, 7835, 8105, 29525, 56735, 82335, 0 };
            const std::uint32_t dim10437JoeKuoD6Init[]   =   { 1, 1, 5, 5, 1, 33, 51, 3, 79, 933, 389, 493, 5969, 12493, 26723, 61159, 116951, 0 };
            const std::uint32_t dim10438JoeKuoD6Init[]   =   { 1, 3, 7, 13, 17, 23, 75, 13, 355, 111, 675, 3191, 3931, 5651, 17495, 4595, 49869, 0 };
            const std::uint32_t dim10439JoeKuoD6Init[]   =   { 1, 1, 7, 7, 15, 21, 35, 125, 89, 903, 697, 3493, 4043, 6631, 4793, 45655, 86969, 0 };
            const std::uint32_t dim10440JoeKuoD6Init[]   =   { 1, 3, 1, 15, 13, 43, 113, 213, 451, 473, 191, 2913, 6391, 1321, 29615, 24791, 26979, 0 };
            const std::uint32_t dim10441JoeKuoD6Init[]   =   { 1, 3, 3, 13, 17, 25, 9, 163, 163, 161, 1647, 3949, 1343, 12881, 10931, 31365, 70013, 0 };
            const std::uint32_t dim10442JoeKuoD6Init[]   =   { 1, 3, 7, 3, 3, 19, 1, 121, 387, 543, 1655, 1797, 6727, 2951, 21925, 21595, 73207, 0 };
            const std::uint32_t dim10443JoeKuoD6Init[]   =   { 1, 1, 5, 9, 7, 19, 91, 9, 83, 893, 1393, 163, 2219, 7763, 32395, 29569, 98645, 0 };
            const std::uint32_t dim10444JoeKuoD6Init[]   =   { 1, 1, 5, 7, 13, 63, 91, 115, 247, 387, 87, 3239, 7561, 297, 32615, 48817, 41761, 0 };
            const std::uint32_t dim10445JoeKuoD6Init[]   =   { 1, 3, 5, 3, 21, 23, 27, 141, 257, 377, 1745, 443, 897, 9033, 1715, 9225, 110181, 0 };
            const std::uint32_t dim10446JoeKuoD6Init[]   =   { 1, 1, 7, 9, 23, 49, 125, 131, 225, 253, 139, 2057, 3273, 4049, 6861, 4463, 11659, 0 };
            const std::uint32_t dim10447JoeKuoD6Init[]   =   { 1, 1, 5, 11, 5, 41, 97, 213, 133, 481, 2009, 2039, 1533, 10765, 22427, 23297, 80661, 0 };
            const std::uint32_t dim10448JoeKuoD6Init[]   =   { 1, 1, 5, 15, 9, 11, 77, 129, 421, 219, 1623, 703, 1611, 13377, 9859, 42869, 101943, 0 };
            const std::uint32_t dim10449JoeKuoD6Init[]   =   { 1, 3, 3, 3, 17, 63, 55, 29, 317, 973, 1159, 11, 1733, 14551, 25911, 39151, 45861, 0 };
            const std::uint32_t dim10450JoeKuoD6Init[]   =   { 1, 3, 7, 11, 29, 63, 107, 193, 263, 799, 1171, 543, 553, 12591, 21965, 8165, 64347, 0 };
            const std::uint32_t dim10451JoeKuoD6Init[]   =   { 1, 1, 7, 15, 23, 49, 65, 65, 401, 897, 681, 1113, 6737, 9157, 1557, 55891, 129175, 0 };
            const std::uint32_t dim10452JoeKuoD6Init[]   =   { 1, 3, 3, 1, 15, 23, 107, 123, 313, 633, 1009, 2615, 1155, 11701, 21945, 7939, 28111, 0 };
            const std::uint32_t dim10453JoeKuoD6Init[]   =   { 1, 3, 1, 11, 15, 11, 47, 137, 299, 393, 877, 1989, 5903, 6505, 9599, 4129, 23073, 0 };
            const std::uint32_t dim10454JoeKuoD6Init[]   =   { 1, 1, 7, 15, 9, 49, 67, 15, 79, 125, 505, 17, 8071, 12957, 13855, 23611, 66465, 0 };
            const std::uint32_t dim10455JoeKuoD6Init[]   =   { 1, 1, 5, 13, 31, 49, 1, 161, 121, 145, 711, 1347, 5297, 11309, 9871, 43075, 95541, 0 };
            const std::uint32_t dim10456JoeKuoD6Init[]   =   { 1, 3, 3, 13, 19, 7, 55, 199, 469, 471, 1269, 3779, 6251, 3513, 1775, 19501, 94055, 0 };
            const std::uint32_t dim10457JoeKuoD6Init[]   =   { 1, 3, 3, 13, 9, 41, 109, 211, 197, 227, 1211, 3327, 1247, 12253, 4493, 31507, 38677, 0 };
            const std::uint32_t dim10458JoeKuoD6Init[]   =   { 1, 1, 7, 3, 11, 45, 11, 103, 325, 849, 1817, 3971, 1059, 9047, 27237, 32211, 121165, 0 };
            const std::uint32_t dim10459JoeKuoD6Init[]   =   { 1, 3, 3, 3, 13, 43, 7, 35, 293, 3, 679, 1441, 5189, 7585, 32009, 6151, 89803, 0 };
            const std::uint32_t dim10460JoeKuoD6Init[]   =   { 1, 1, 7, 9, 29, 41, 127, 255, 363, 913, 2027, 3891, 5187, 10233, 8871, 48085, 125609, 0 };
            const std::uint32_t dim10461JoeKuoD6Init[]   =   { 1, 3, 1, 5, 21, 23, 59, 145, 171, 775, 535, 3803, 6981, 15901, 20255, 63199, 92905, 0 };
            const std::uint32_t dim10462JoeKuoD6Init[]   =   { 1, 3, 5, 9, 7, 63, 53, 7, 145, 547, 1753, 3351, 1273, 8175, 24103, 42133, 87459, 0 };
            const std::uint32_t dim10463JoeKuoD6Init[]   =   { 1, 3, 7, 7, 25, 33, 5, 217, 469, 473, 1573, 2525, 7345, 5261, 7023, 50893, 124129, 0 };
            const std::uint32_t dim10464JoeKuoD6Init[]   =   { 1, 3, 5, 13, 5, 51, 23, 61, 429, 775, 519, 2671, 1979, 9005, 21617, 33611, 120487, 0 };
            const std::uint32_t dim10465JoeKuoD6Init[]   =   { 1, 3, 3, 15, 23, 1, 73, 187, 47, 369, 943, 99, 2529, 5569, 13649, 51481, 128949, 0 };
            const std::uint32_t dim10466JoeKuoD6Init[]   =   { 1, 3, 1, 5, 25, 55, 35, 191, 327, 845, 1353, 261, 6297, 6067, 22241, 32381, 17749, 0 };
            const std::uint32_t dim10467JoeKuoD6Init[]   =   { 1, 1, 5, 15, 31, 5, 29, 129, 15, 47, 739, 755, 7595, 14743, 14705, 34347, 11805, 0 };
            const std::uint32_t dim10468JoeKuoD6Init[]   =   { 1, 3, 1, 3, 15, 49, 119, 47, 185, 63, 2003, 2847, 5393, 855, 7699, 29521, 67011, 0 };
            const std::uint32_t dim10469JoeKuoD6Init[]   =   { 1, 3, 7, 15, 11, 41, 37, 149, 173, 1015, 29, 1805, 1269, 16199, 32337, 11023, 60065, 0 };
            const std::uint32_t dim10470JoeKuoD6Init[]   =   { 1, 1, 1, 7, 31, 19, 65, 81, 255, 875, 1379, 2347, 1873, 14427, 29523, 38413, 65583, 0 };
            const std::uint32_t dim10471JoeKuoD6Init[]   =   { 1, 1, 1, 15, 13, 59, 3, 219, 127, 479, 1029, 3385, 563, 11825, 10081, 17423, 26431, 0 };
            const std::uint32_t dim10472JoeKuoD6Init[]   =   { 1, 1, 1, 1, 25, 27, 79, 87, 489, 281, 457, 3527, 5117, 4705, 21167, 46211, 90383, 0 };
            const std::uint32_t dim10473JoeKuoD6Init[]   =   { 1, 3, 7, 13, 7, 5, 67, 111, 53, 439, 1483, 3639, 7781, 9471, 10957, 60711, 64957, 0 };
            const std::uint32_t dim10474JoeKuoD6Init[]   =   { 1, 3, 7, 9, 7, 7, 41, 137, 159, 245, 551, 4007, 1277, 4743, 4863, 48689, 123289, 0 };
            const std::uint32_t dim10475JoeKuoD6Init[]   =   { 1, 3, 7, 9, 15, 49, 55, 77, 41, 475, 1563, 3569, 5993, 301, 14831, 44095, 22641, 0 };
            const std::uint32_t dim10476JoeKuoD6Init[]   =   { 1, 1, 1, 1, 15, 33, 39, 135, 81, 533, 869, 305, 1125, 6399, 14321, 37217, 121081, 0 };
            const std::uint32_t dim10477JoeKuoD6Init[]   =   { 1, 1, 7, 15, 21, 59, 43, 7, 225, 1, 115, 1531, 2931, 2593, 15935, 61973, 106899, 0 };
            const std::uint32_t dim10478JoeKuoD6Init[]   =   { 1, 1, 1, 1, 13, 13, 99, 191, 437, 367, 641, 1933, 5807, 11677, 13557, 46475, 34875, 0 };
            const std::uint32_t dim10479JoeKuoD6Init[]   =   { 1, 3, 7, 9, 21, 7, 119, 209, 31, 919, 901, 1229, 5823, 11439, 18151, 18991, 114743, 0 };
            const std::uint32_t dim10480JoeKuoD6Init[]   =   { 1, 3, 3, 3, 19, 37, 109, 53, 411, 617, 1841, 2769, 1271, 5719, 22359, 1199, 72405, 0 };
            const std::uint32_t dim10481JoeKuoD6Init[]   =   { 1, 1, 1, 5, 29, 3, 51, 59, 141, 897, 1907, 3799, 1463, 5661, 181, 50565, 95085, 0 };
            const std::uint32_t dim10482JoeKuoD6Init[]   =   { 1, 1, 1, 7, 1, 35, 77, 225, 341, 587, 137, 35, 2177, 15177, 12869, 35013, 39471, 0 };
            const std::uint32_t dim10483JoeKuoD6Init[]   =   { 1, 1, 3, 13, 15, 63, 45, 33, 337, 1, 1133, 263, 4985, 11591, 1085, 31197, 67897, 0 };
            const std::uint32_t dim10484JoeKuoD6Init[]   =   { 1, 1, 5, 13, 23, 11, 123, 21, 185, 639, 145, 3865, 2999, 6261, 23247, 23055, 32755, 0 };
            const std::uint32_t dim10485JoeKuoD6Init[]   =   { 1, 1, 5, 9, 19, 21, 47, 133, 281, 431, 1661, 3719, 3637, 973, 9727, 52627, 60035, 0 };
            const std::uint32_t dim10486JoeKuoD6Init[]   =   { 1, 1, 3, 5, 3, 19, 19, 89, 63, 549, 551, 3357, 5665, 4781, 22437, 1149, 10825, 0 };
            const std::uint32_t dim10487JoeKuoD6Init[]   =   { 1, 3, 5, 15, 3, 25, 81, 193, 11, 711, 1481, 1767, 1159, 4967, 16915, 3387, 26245, 0 };
            const std::uint32_t dim10488JoeKuoD6Init[]   =   { 1, 1, 1, 3, 29, 39, 23, 131, 473, 107, 765, 2249, 6087, 9145, 20751, 21085, 42989, 0 };
            const std::uint32_t dim10489JoeKuoD6Init[]   =   { 1, 3, 1, 9, 7, 39, 13, 199, 475, 333, 269, 1041, 5927, 14039, 19081, 9045, 119645, 0 };
            const std::uint32_t dim10490JoeKuoD6Init[]   =   { 1, 1, 5, 13, 11, 61, 99, 71, 151, 175, 1327, 3397, 5063, 10683, 7895, 62255, 85749, 0 };
            const std::uint32_t dim10491JoeKuoD6Init[]   =   { 1, 3, 7, 9, 1, 57, 21, 217, 423, 467, 1435, 2887, 1567, 8819, 19961, 36507, 110309, 0 };
            const std::uint32_t dim10492JoeKuoD6Init[]   =   { 1, 3, 3, 11, 11, 35, 77, 127, 153, 357, 865, 1943, 1947, 10995, 13617, 44347, 26851, 0 };
            const std::uint32_t dim10493JoeKuoD6Init[]   =   { 1, 3, 1, 11, 9, 43, 31, 81, 123, 813, 995, 169, 6593, 13621, 32195, 51125, 53509, 0 };
            const std::uint32_t dim10494JoeKuoD6Init[]   =   { 1, 1, 5, 5, 27, 29, 77, 35, 93, 545, 377, 2345, 6475, 15729, 15103, 49591, 101121, 0 };
            const std::uint32_t dim10495JoeKuoD6Init[]   =   { 1, 1, 5, 13, 1, 17, 97, 187, 129, 173, 641, 2937, 3277, 15087, 28111, 46905, 112367, 0 };
            const std::uint32_t dim10496JoeKuoD6Init[]   =   { 1, 3, 7, 7, 1, 27, 75, 43, 305, 431, 571, 1327, 7419, 3093, 2691, 23417, 11975, 0 };
            const std::uint32_t dim10497JoeKuoD6Init[]   =   { 1, 1, 5, 15, 17, 3, 91, 57, 417, 87, 1891, 1973, 5765, 5521, 21931, 60011, 20883, 0 };
            const std::uint32_t dim10498JoeKuoD6Init[]   =   { 1, 3, 1, 3, 27, 13, 105, 153, 495, 371, 453, 1295, 5675, 6377, 8971, 40505, 41149, 0 };
            const std::uint32_t dim10499JoeKuoD6Init[]   =   { 1, 1, 1, 15, 1, 17, 105, 177, 41, 455, 611, 3585, 2307, 2603, 20985, 5581, 14033, 0 };
            const std::uint32_t dim10500JoeKuoD6Init[]   =   { 1, 3, 3, 9, 7, 41, 33, 145, 307, 293, 1321, 2151, 3265, 14845, 15687, 38715, 8041, 0 };
            const std::uint32_t dim10501JoeKuoD6Init[]   =   { 1, 3, 3, 3, 5, 47, 127, 253, 129, 337, 1467, 5, 2743, 1921, 26979, 11737, 41479, 0 };
            const std::uint32_t dim10502JoeKuoD6Init[]   =   { 1, 1, 1, 5, 15, 35, 37, 9, 5, 405, 1041, 1903, 3655, 14315, 9441, 20577, 50715, 0 };
            const std::uint32_t dim10503JoeKuoD6Init[]   =   { 1, 1, 5, 15, 7, 5, 53, 61, 409, 353, 87, 1805, 4523, 11417, 24105, 21451, 56387, 0 };
            const std::uint32_t dim10504JoeKuoD6Init[]   =   { 1, 3, 3, 5, 5, 9, 25, 249, 511, 795, 559, 2695, 3071, 3971, 29421, 46593, 96563, 0 };
            const std::uint32_t dim10505JoeKuoD6Init[]   =   { 1, 1, 3, 1, 3, 39, 61, 85, 399, 105, 1253, 3787, 3065, 10553, 8195, 5637, 129579, 0 };
            const std::uint32_t dim10506JoeKuoD6Init[]   =   { 1, 3, 3, 7, 23, 23, 23, 197, 263, 687, 943, 1977, 5767, 15373, 17995, 24509, 81293, 0 };
            const std::uint32_t dim10507JoeKuoD6Init[]   =   { 1, 3, 1, 11, 15, 37, 15, 67, 207, 985, 895, 509, 3435, 11563, 2055, 19253, 42649, 0 };
            const std::uint32_t dim10508JoeKuoD6Init[]   =   { 1, 1, 7, 3, 1, 51, 59, 133, 241, 569, 1575, 3633, 2243, 11939, 5501, 11249, 86013, 0 };
            const std::uint32_t dim10509JoeKuoD6Init[]   =   { 1, 1, 7, 13, 25, 59, 97, 191, 385, 179, 1195, 1537, 1837, 11953, 14231, 37025, 49803, 0 };
            const std::uint32_t dim10510JoeKuoD6Init[]   =   { 1, 3, 5, 5, 13, 49, 19, 171, 503, 433, 1633, 553, 2759, 4379, 18313, 62437, 37453, 0 };
            const std::uint32_t dim10511JoeKuoD6Init[]   =   { 1, 3, 3, 15, 29, 49, 107, 239, 21, 913, 1095, 989, 4749, 10657, 27169, 15913, 1573, 0 };
            const std::uint32_t dim10512JoeKuoD6Init[]   =   { 1, 1, 1, 1, 3, 3, 53, 241, 287, 149, 557, 2665, 2027, 449, 29231, 23025, 102521, 0 };
            const std::uint32_t dim10513JoeKuoD6Init[]   =   { 1, 3, 5, 7, 23, 21, 9, 1, 11, 837, 1337, 2815, 7883, 16053, 10031, 43405, 5037, 0 };
            const std::uint32_t dim10514JoeKuoD6Init[]   =   { 1, 3, 7, 1, 23, 53, 113, 125, 337, 491, 1125, 3083, 4941, 951, 15805, 1571, 79779, 0 };
            const std::uint32_t dim10515JoeKuoD6Init[]   =   { 1, 3, 7, 13, 1, 3, 95, 105, 431, 723, 1771, 3773, 177, 2045, 24719, 57727, 79005, 0 };
            const std::uint32_t dim10516JoeKuoD6Init[]   =   { 1, 3, 1, 1, 7, 17, 107, 171, 213, 437, 409, 2015, 7543, 12693, 23597, 44477, 72543, 0 };
            const std::uint32_t dim10517JoeKuoD6Init[]   =   { 1, 3, 5, 9, 7, 21, 27, 167, 473, 901, 1245, 3737, 3485, 14593, 7619, 18753, 14209, 0 };
            const std::uint32_t dim10518JoeKuoD6Init[]   =   { 1, 1, 1, 3, 25, 37, 51, 21, 363, 73, 711, 3749, 5147, 8495, 30151, 14275, 128217, 0 };
            const std::uint32_t dim10519JoeKuoD6Init[]   =   { 1, 3, 1, 13, 17, 35, 69, 15, 293, 331, 301, 691, 7315, 6495, 315, 62909, 105047, 0 };
            const std::uint32_t dim10520JoeKuoD6Init[]   =   { 1, 3, 5, 3, 25, 23, 105, 111, 213, 887, 1701, 2085, 5931, 9217, 4009, 2321, 103631, 0 };
            const std::uint32_t dim10521JoeKuoD6Init[]   =   { 1, 1, 7, 15, 17, 57, 59, 249, 267, 941, 777, 2509, 6587, 12033, 24969, 31563, 129049, 0 };
            const std::uint32_t dim10522JoeKuoD6Init[]   =   { 1, 1, 1, 5, 31, 23, 31, 217, 509, 973, 659, 673, 7759, 3865, 21221, 4319, 117411, 0 };
            const std::uint32_t dim10523JoeKuoD6Init[]   =   { 1, 1, 3, 7, 13, 13, 103, 179, 107, 233, 753, 3121, 835, 13595, 9271, 31421, 45275, 0 };
            const std::uint32_t dim10524JoeKuoD6Init[]   =   { 1, 3, 5, 13, 23, 61, 125, 189, 283, 83, 1087, 755, 3697, 14845, 27901, 16389, 82993, 0 };
            const std::uint32_t dim10525JoeKuoD6Init[]   =   { 1, 3, 1, 3, 1, 55, 25, 139, 435, 681, 1913, 975, 3109, 6699, 12943, 50865, 71811, 0 };
            const std::uint32_t dim10526JoeKuoD6Init[]   =   { 1, 3, 1, 5, 15, 61, 17, 219, 29, 805, 1881, 3761, 3535, 473, 15629, 26301, 51085, 0 };
            const std::uint32_t dim10527JoeKuoD6Init[]   =   { 1, 3, 1, 1, 7, 43, 87, 93, 355, 247, 641, 2851, 4565, 9293, 6025, 1945, 112549, 0 };
            const std::uint32_t dim10528JoeKuoD6Init[]   =   { 1, 3, 7, 5, 19, 55, 69, 227, 107, 443, 1587, 2457, 2873, 953, 27529, 57527, 54145, 0 };
            const std::uint32_t dim10529JoeKuoD6Init[]   =   { 1, 1, 5, 9, 1, 33, 31, 241, 339, 791, 399, 3435, 1711, 10815, 32657, 59875, 31291, 0 };
            const std::uint32_t dim10530JoeKuoD6Init[]   =   { 1, 1, 1, 7, 25, 59, 87, 115, 435, 47, 1907, 193, 6069, 10933, 9877, 46443, 3451, 0 };
            const std::uint32_t dim10531JoeKuoD6Init[]   =   { 1, 3, 3, 15, 25, 33, 19, 121, 133, 253, 1227, 75, 2839, 3341, 30727, 52451, 44883, 0 };
            const std::uint32_t dim10532JoeKuoD6Init[]   =   { 1, 1, 7, 11, 5, 47, 97, 255, 235, 565, 1701, 529, 839, 15473, 24471, 5749, 73135, 0 };
            const std::uint32_t dim10533JoeKuoD6Init[]   =   { 1, 1, 3, 7, 21, 15, 31, 81, 389, 957, 603, 3879, 2875, 11987, 24625, 53667, 77775, 0 };
            const std::uint32_t dim10534JoeKuoD6Init[]   =   { 1, 1, 5, 11, 29, 29, 31, 233, 107, 541, 561, 2533, 1421, 13587, 6943, 45635, 71315, 0 };
            const std::uint32_t dim10535JoeKuoD6Init[]   =   { 1, 3, 1, 9, 25, 19, 33, 53, 509, 485, 1637, 2877, 5927, 16059, 195, 17279, 127025, 0 };
            const std::uint32_t dim10536JoeKuoD6Init[]   =   { 1, 1, 1, 3, 9, 23, 97, 101, 337, 43, 1979, 1139, 3693, 2601, 8225, 53037, 63709, 0 };
            const std::uint32_t dim10537JoeKuoD6Init[]   =   { 1, 1, 7, 7, 17, 25, 121, 253, 63, 105, 527, 1397, 121, 9665, 29151, 10795, 79077, 0 };
            const std::uint32_t dim10538JoeKuoD6Init[]   =   { 1, 3, 3, 1, 27, 33, 123, 69, 209, 25, 1677, 1569, 4441, 7817, 5165, 29517, 117165, 0 };
            const std::uint32_t dim10539JoeKuoD6Init[]   =   { 1, 1, 5, 15, 3, 59, 13, 25, 359, 71, 179, 3925, 6899, 6007, 9121, 36297, 88541, 0 };
            const std::uint32_t dim10540JoeKuoD6Init[]   =   { 1, 1, 3, 11, 23, 17, 55, 133, 27, 277, 1055, 1057, 807, 1221, 1665, 64129, 102395, 0 };
            const std::uint32_t dim10541JoeKuoD6Init[]   =   { 1, 3, 1, 15, 13, 15, 105, 141, 329, 73, 609, 1663, 3277, 1767, 6371, 34325, 109563, 0 };
            const std::uint32_t dim10542JoeKuoD6Init[]   =   { 1, 1, 5, 1, 17, 21, 37, 81, 187, 403, 291, 1495, 5071, 14289, 29075, 44089, 95001, 0 };
            const std::uint32_t dim10543JoeKuoD6Init[]   =   { 1, 3, 3, 3, 15, 33, 49, 155, 41, 853, 15, 3571, 1433, 8469, 18711, 59007, 98703, 0 };
            const std::uint32_t dim10544JoeKuoD6Init[]   =   { 1, 3, 1, 13, 17, 47, 61, 151, 127, 87, 207, 3157, 5141, 14745, 32567, 18401, 7497, 0 };
            const std::uint32_t dim10545JoeKuoD6Init[]   =   { 1, 3, 5, 1, 19, 25, 49, 147, 137, 603, 1223, 3195, 5965, 11335, 20343, 10109, 63975, 0 };
            const std::uint32_t dim10546JoeKuoD6Init[]   =   { 1, 1, 7, 13, 29, 59, 1, 33, 157, 765, 961, 641, 7303, 3279, 20287, 37553, 114573, 0 };
            const std::uint32_t dim10547JoeKuoD6Init[]   =   { 1, 3, 5, 1, 11, 63, 63, 41, 15, 717, 1037, 227, 7875, 8681, 26943, 11761, 28005, 0 };
            const std::uint32_t dim10548JoeKuoD6Init[]   =   { 1, 3, 1, 3, 19, 5, 67, 169, 209, 293, 343, 2033, 7669, 1077, 15513, 54475, 15459, 0 };
            const std::uint32_t dim10549JoeKuoD6Init[]   =   { 1, 1, 3, 3, 17, 47, 49, 187, 341, 767, 1463, 301, 2083, 9265, 12313, 14763, 126627, 0 };
            const std::uint32_t dim10550JoeKuoD6Init[]   =   { 1, 3, 5, 13, 11, 15, 45, 237, 445, 55, 319, 2989, 5043, 1053, 22809, 23111, 7617, 0 };
            const std::uint32_t dim10551JoeKuoD6Init[]   =   { 1, 1, 7, 9, 7, 15, 41, 185, 511, 701, 1279, 1995, 7829, 2947, 3431, 45799, 1709, 0 };
            const std::uint32_t dim10552JoeKuoD6Init[]   =   { 1, 3, 7, 15, 5, 15, 85, 29, 487, 811, 1653, 483, 1193, 11331, 21815, 57215, 8373, 0 };
            const std::uint32_t dim10553JoeKuoD6Init[]   =   { 1, 3, 1, 15, 27, 19, 111, 161, 19, 373, 419, 1547, 2415, 10705, 17283, 56663, 73625, 0 };
            const std::uint32_t dim10554JoeKuoD6Init[]   =   { 1, 1, 3, 11, 27, 7, 75, 57, 411, 35, 685, 1249, 5227, 7313, 3167, 30537, 40655, 0 };
            const std::uint32_t dim10555JoeKuoD6Init[]   =   { 1, 3, 1, 9, 7, 37, 9, 209, 353, 319, 843, 657, 2069, 6523, 611, 16291, 107121, 0 };
            const std::uint32_t dim10556JoeKuoD6Init[]   =   { 1, 1, 5, 11, 11, 51, 25, 171, 315, 63, 207, 2279, 2379, 3583, 31927, 62451, 109911, 0 };
            const std::uint32_t dim10557JoeKuoD6Init[]   =   { 1, 1, 7, 11, 15, 41, 19, 175, 103, 605, 1889, 3161, 1217, 3259, 29655, 11715, 35551, 0 };
            const std::uint32_t dim10558JoeKuoD6Init[]   =   { 1, 3, 5, 13, 23, 11, 121, 147, 179, 397, 659, 3753, 2355, 1093, 25863, 39751, 112381, 0 };
            const std::uint32_t dim10559JoeKuoD6Init[]   =   { 1, 3, 5, 7, 1, 23, 37, 117, 7, 361, 991, 661, 4427, 15333, 5307, 55171, 96959, 0 };
            const std::uint32_t dim10560JoeKuoD6Init[]   =   { 1, 3, 1, 5, 17, 9, 77, 147, 289, 79, 295, 1271, 7809, 6387, 31785, 26489, 9335, 0 };
            const std::uint32_t dim10561JoeKuoD6Init[]   =   { 1, 1, 1, 7, 17, 33, 63, 147, 17, 515, 1349, 1907, 7703, 5511, 27773, 54025, 30019, 0 };
            const std::uint32_t dim10562JoeKuoD6Init[]   =   { 1, 3, 5, 3, 27, 57, 75, 129, 219, 533, 207, 3569, 5799, 6943, 12271, 53115, 120389, 0 };
            const std::uint32_t dim10563JoeKuoD6Init[]   =   { 1, 1, 1, 13, 11, 25, 101, 251, 289, 215, 1875, 1821, 703, 15395, 27167, 43187, 63401, 0 };
            const std::uint32_t dim10564JoeKuoD6Init[]   =   { 1, 1, 7, 15, 7, 39, 125, 41, 57, 513, 17, 965, 3225, 12833, 21131, 53243, 60377, 0 };
            const std::uint32_t dim10565JoeKuoD6Init[]   =   { 1, 3, 5, 3, 21, 19, 43, 195, 259, 523, 587, 3393, 6621, 43, 10951, 51877, 79967, 0 };
            const std::uint32_t dim10566JoeKuoD6Init[]   =   { 1, 3, 3, 7, 7, 19, 11, 89, 321, 821, 99, 2201, 1297, 949, 11539, 6295, 19721, 0 };
            const std::uint32_t dim10567JoeKuoD6Init[]   =   { 1, 1, 5, 3, 29, 27, 123, 111, 441, 441, 337, 3849, 1677, 14403, 17203, 50661, 92177, 0 };
            const std::uint32_t dim10568JoeKuoD6Init[]   =   { 1, 3, 5, 9, 23, 23, 73, 153, 241, 841, 371, 1503, 5815, 14117, 4679, 17997, 112269, 0 };
            const std::uint32_t dim10569JoeKuoD6Init[]   =   { 1, 1, 1, 1, 7, 37, 105, 185, 453, 905, 15, 57, 6963, 9665, 3371, 2391, 96023, 0 };
            const std::uint32_t dim10570JoeKuoD6Init[]   =   { 1, 3, 7, 1, 1, 21, 35, 43, 449, 111, 191, 2163, 3249, 15049, 30215, 43569, 127973, 0 };
            const std::uint32_t dim10571JoeKuoD6Init[]   =   { 1, 3, 3, 3, 17, 13, 77, 123, 471, 929, 1797, 2061, 355, 4441, 1101, 24631, 128711, 0 };
            const std::uint32_t dim10572JoeKuoD6Init[]   =   { 1, 3, 7, 7, 17, 51, 1, 69, 23, 1003, 535, 3751, 765, 5253, 21027, 52901, 61951, 0 };
            const std::uint32_t dim10573JoeKuoD6Init[]   =   { 1, 1, 7, 9, 25, 13, 33, 13, 423, 787, 223, 729, 4443, 227, 11487, 14259, 52951, 0 };
            const std::uint32_t dim10574JoeKuoD6Init[]   =   { 1, 3, 5, 5, 25, 27, 113, 93, 13, 679, 1295, 3773, 7253, 14629, 8907, 45885, 85387, 0 };
            const std::uint32_t dim10575JoeKuoD6Init[]   =   { 1, 3, 3, 13, 15, 55, 99, 31, 119, 955, 1477, 3745, 6777, 973, 4723, 62133, 65093, 0 };
            const std::uint32_t dim10576JoeKuoD6Init[]   =   { 1, 3, 3, 9, 13, 51, 105, 37, 477, 579, 765, 2573, 6869, 3891, 30969, 63413, 56603, 0 };
            const std::uint32_t dim10577JoeKuoD6Init[]   =   { 1, 3, 1, 3, 15, 23, 67, 109, 75, 721, 523, 1433, 3455, 6377, 23795, 13711, 121349, 0 };
            const std::uint32_t dim10578JoeKuoD6Init[]   =   { 1, 1, 3, 11, 5, 5, 99, 117, 233, 621, 509, 3235, 7483, 12325, 13203, 20075, 27537, 0 };
            const std::uint32_t dim10579JoeKuoD6Init[]   =   { 1, 3, 3, 9, 23, 51, 93, 245, 307, 689, 1993, 3607, 1985, 11839, 25553, 54941, 68741, 0 };
            const std::uint32_t dim10580JoeKuoD6Init[]   =   { 1, 1, 3, 5, 19, 21, 33, 71, 447, 539, 351, 2549, 87, 4317, 1287, 62289, 121065, 0 };
            const std::uint32_t dim10581JoeKuoD6Init[]   =   { 1, 3, 5, 5, 9, 23, 37, 189, 449, 263, 37, 3127, 1709, 10793, 7379, 38565, 8267, 0 };
            const std::uint32_t dim10582JoeKuoD6Init[]   =   { 1, 1, 7, 7, 7, 33, 23, 79, 457, 947, 1275, 2755, 3747, 9225, 31385, 8785, 76945, 0 };
            const std::uint32_t dim10583JoeKuoD6Init[]   =   { 1, 3, 1, 9, 17, 33, 29, 59, 505, 649, 1679, 3609, 1361, 5987, 26455, 17295, 98697, 0 };
            const std::uint32_t dim10584JoeKuoD6Init[]   =   { 1, 1, 3, 11, 7, 47, 127, 79, 419, 143, 349, 985, 6397, 10271, 29427, 19661, 32629, 0 };
            const std::uint32_t dim10585JoeKuoD6Init[]   =   { 1, 1, 5, 13, 15, 5, 79, 171, 491, 223, 1601, 705, 623, 4405, 10065, 28057, 105737, 0 };
            const std::uint32_t dim10586JoeKuoD6Init[]   =   { 1, 1, 7, 3, 29, 7, 81, 69, 265, 669, 1763, 2109, 6275, 7683, 19561, 26737, 54449, 0 };
            const std::uint32_t dim10587JoeKuoD6Init[]   =   { 1, 1, 1, 7, 1, 1, 5, 9, 65, 487, 1663, 1021, 1819, 9971, 22065, 40407, 4187, 0 };
            const std::uint32_t dim10588JoeKuoD6Init[]   =   { 1, 3, 5, 5, 21, 33, 11, 213, 309, 575, 427, 1421, 6435, 981, 31533, 16751, 47813, 0 };
            const std::uint32_t dim10589JoeKuoD6Init[]   =   { 1, 3, 3, 13, 7, 59, 65, 65, 401, 195, 211, 421, 1139, 11729, 19717, 20699, 111863, 0 };
            const std::uint32_t dim10590JoeKuoD6Init[]   =   { 1, 3, 7, 5, 17, 51, 25, 217, 223, 935, 431, 1703, 4869, 5635, 199, 5485, 37311, 0 };
            const std::uint32_t dim10591JoeKuoD6Init[]   =   { 1, 1, 3, 11, 23, 25, 15, 37, 187, 1007, 857, 3327, 5471, 10089, 13745, 1741, 37769, 0 };
            const std::uint32_t dim10592JoeKuoD6Init[]   =   { 1, 3, 5, 15, 31, 17, 75, 125, 1, 449, 1293, 3427, 709, 8285, 31143, 50655, 130793, 0 };
            const std::uint32_t dim10593JoeKuoD6Init[]   =   { 1, 1, 7, 3, 25, 55, 105, 255, 319, 183, 1571, 2425, 5429, 7151, 8569, 37447, 23055, 0 };
            const std::uint32_t dim10594JoeKuoD6Init[]   =   { 1, 3, 1, 1, 23, 37, 17, 61, 161, 559, 1025, 2651, 5861, 5231, 1365, 4853, 127301, 0 };
            const std::uint32_t dim10595JoeKuoD6Init[]   =   { 1, 3, 1, 9, 17, 37, 87, 241, 411, 53, 1555, 3805, 6867, 125, 9829, 53581, 117413, 0 };
            const std::uint32_t dim10596JoeKuoD6Init[]   =   { 1, 3, 3, 3, 23, 55, 121, 109, 441, 623, 1345, 3055, 2591, 11329, 16891, 61347, 125643, 0 };
            const std::uint32_t dim10597JoeKuoD6Init[]   =   { 1, 3, 1, 1, 5, 29, 53, 97, 15, 275, 1587, 1245, 379, 16117, 24369, 26873, 39547, 0 };
            const std::uint32_t dim10598JoeKuoD6Init[]   =   { 1, 3, 1, 5, 3, 63, 85, 167, 301, 45, 1357, 1185, 3939, 945, 24961, 59427, 128129, 0 };
            const std::uint32_t dim10599JoeKuoD6Init[]   =   { 1, 3, 1, 7, 23, 25, 109, 253, 37, 151, 17, 1241, 787, 15895, 7947, 65071, 14765, 0 };
            const std::uint32_t dim10600JoeKuoD6Init[]   =   { 1, 3, 3, 1, 7, 3, 103, 35, 73, 533, 1055, 823, 7403, 8117, 28813, 42457, 56037, 0 };
            const std::uint32_t dim10601JoeKuoD6Init[]   =   { 1, 3, 5, 15, 1, 15, 97, 109, 293, 259, 935, 2977, 5257, 14563, 28871, 17647, 34185, 0 };
            const std::uint32_t dim10602JoeKuoD6Init[]   =   { 1, 1, 1, 3, 29, 21, 101, 163, 173, 1019, 1025, 553, 945, 3781, 1097, 58025, 124819, 0 };
            const std::uint32_t dim10603JoeKuoD6Init[]   =   { 1, 1, 3, 9, 7, 35, 65, 61, 31, 547, 75, 3515, 6719, 12809, 23287, 14609, 30341, 0 };
            const std::uint32_t dim10604JoeKuoD6Init[]   =   { 1, 3, 7, 9, 3, 53, 21, 207, 383, 917, 1383, 2873, 1663, 15665, 1787, 50741, 35145, 0 };
            const std::uint32_t dim10605JoeKuoD6Init[]   =   { 1, 3, 7, 5, 3, 35, 113, 191, 171, 635, 1597, 2943, 2421, 5555, 6457, 22087, 104221, 0 };
            const std::uint32_t dim10606JoeKuoD6Init[]   =   { 1, 1, 1, 1, 29, 25, 3, 225, 175, 807, 1325, 215, 6475, 10729, 18619, 45401, 20627, 0 };
            const std::uint32_t dim10607JoeKuoD6Init[]   =   { 1, 1, 5, 11, 23, 25, 39, 207, 81, 633, 403, 3369, 1295, 1289, 20853, 48899, 16613, 0 };
            const std::uint32_t dim10608JoeKuoD6Init[]   =   { 1, 1, 7, 15, 5, 23, 17, 77, 169, 969, 1459, 3795, 3121, 5501, 32323, 46743, 124175, 0 };
            const std::uint32_t dim10609JoeKuoD6Init[]   =   { 1, 1, 7, 13, 3, 25, 77, 153, 105, 1017, 1599, 237, 4691, 1993, 6707, 50265, 13529, 0 };
            const std::uint32_t dim10610JoeKuoD6Init[]   =   { 1, 3, 3, 15, 7, 11, 81, 223, 61, 589, 1263, 3999, 7643, 12101, 19853, 49279, 29999, 0 };
            const std::uint32_t dim10611JoeKuoD6Init[]   =   { 1, 3, 1, 13, 3, 31, 61, 59, 41, 313, 115, 561, 3973, 13513, 6359, 29395, 34565, 0 };
            const std::uint32_t dim10612JoeKuoD6Init[]   =   { 1, 1, 7, 7, 7, 61, 91, 181, 307, 875, 2045, 1367, 3743, 6497, 2443, 12153, 96431, 0 };
            const std::uint32_t dim10613JoeKuoD6Init[]   =   { 1, 1, 3, 7, 19, 63, 97, 211, 157, 945, 891, 3747, 5483, 3081, 28939, 11179, 15935, 0 };
            const std::uint32_t dim10614JoeKuoD6Init[]   =   { 1, 3, 7, 3, 23, 39, 51, 137, 91, 179, 1515, 1397, 2783, 9343, 11483, 52407, 111725, 0 };
            const std::uint32_t dim10615JoeKuoD6Init[]   =   { 1, 3, 3, 11, 11, 25, 111, 61, 115, 329, 485, 1713, 565, 8607, 18869, 6595, 18605, 0 };
            const std::uint32_t dim10616JoeKuoD6Init[]   =   { 1, 1, 5, 1, 13, 59, 67, 231, 443, 695, 1185, 393, 6393, 12957, 15817, 37219, 113127, 0 };
            const std::uint32_t dim10617JoeKuoD6Init[]   =   { 1, 3, 5, 3, 15, 57, 25, 97, 321, 627, 15, 2005, 3813, 10399, 26779, 24243, 66463, 0 };
            const std::uint32_t dim10618JoeKuoD6Init[]   =   { 1, 3, 7, 7, 17, 43, 117, 179, 447, 1005, 2007, 1753, 7685, 13331, 5187, 49341, 111927, 0 };
            const std::uint32_t dim10619JoeKuoD6Init[]   =   { 1, 1, 3, 3, 5, 53, 35, 185, 93, 847, 1523, 3039, 25, 3351, 23195, 41133, 38547, 0 };
            const std::uint32_t dim10620JoeKuoD6Init[]   =   { 1, 1, 7, 5, 27, 59, 95, 137, 55, 129, 331, 127, 7421, 5633, 557, 18137, 89055, 0 };
            const std::uint32_t dim10621JoeKuoD6Init[]   =   { 1, 3, 3, 11, 5, 53, 93, 137, 175, 191, 1645, 2047, 2569, 8177, 22691, 4037, 31823, 0 };
            const std::uint32_t dim10622JoeKuoD6Init[]   =   { 1, 3, 3, 11, 11, 45, 77, 7, 21, 541, 49, 1689, 171, 829, 28917, 45095, 1807, 0 };
            const std::uint32_t dim10623JoeKuoD6Init[]   =   { 1, 3, 7, 5, 21, 5, 113, 81, 33, 681, 361, 1107, 1597, 115, 11503, 27413, 9199, 0 };
            const std::uint32_t dim10624JoeKuoD6Init[]   =   { 1, 1, 3, 11, 29, 57, 15, 249, 105, 683, 833, 2579, 3517, 16153, 17373, 32587, 124333, 0 };
            const std::uint32_t dim10625JoeKuoD6Init[]   =   { 1, 3, 7, 13, 3, 35, 55, 23, 293, 5, 2003, 2741, 4237, 8117, 20569, 63967, 106041, 0 };
            const std::uint32_t dim10626JoeKuoD6Init[]   =   { 1, 3, 3, 1, 1, 15, 57, 119, 135, 967, 1495, 801, 4959, 5037, 10051, 53915, 116891, 0 };
            const std::uint32_t dim10627JoeKuoD6Init[]   =   { 1, 1, 7, 9, 15, 29, 53, 139, 505, 473, 1179, 3289, 369, 13147, 15739, 16739, 54949, 0 };
            const std::uint32_t dim10628JoeKuoD6Init[]   =   { 1, 1, 5, 7, 7, 45, 17, 213, 381, 63, 437, 3099, 3765, 175, 13521, 11689, 58675, 0 };
            const std::uint32_t dim10629JoeKuoD6Init[]   =   { 1, 1, 7, 1, 15, 35, 55, 43, 147, 873, 1193, 3801, 2301, 14569, 31789, 50443, 62577, 0 };
            const std::uint32_t dim10630JoeKuoD6Init[]   =   { 1, 1, 5, 7, 21, 41, 3, 45, 43, 303, 1465, 1461, 5295, 13397, 30439, 7103, 87505, 0 };
            const std::uint32_t dim10631JoeKuoD6Init[]   =   { 1, 1, 1, 15, 19, 27, 81, 141, 307, 259, 521, 1785, 6917, 15635, 27781, 64809, 53297, 0 };
            const std::uint32_t dim10632JoeKuoD6Init[]   =   { 1, 1, 1, 7, 27, 15, 53, 99, 377, 935, 1869, 3835, 741, 8447, 18947, 10727, 72179, 0 };
            const std::uint32_t dim10633JoeKuoD6Init[]   =   { 1, 1, 3, 5, 15, 51, 91, 207, 7, 997, 935, 591, 7325, 3025, 11335, 32087, 109535, 0 };
            const std::uint32_t dim10634JoeKuoD6Init[]   =   { 1, 3, 1, 5, 11, 13, 1, 57, 45, 307, 1839, 1735, 2247, 13117, 17471, 16599, 103063, 0 };
            const std::uint32_t dim10635JoeKuoD6Init[]   =   { 1, 3, 5, 11, 19, 7, 121, 3, 325, 731, 1945, 4025, 7649, 8939, 11147, 59065, 49971, 0 };
            const std::uint32_t dim10636JoeKuoD6Init[]   =   { 1, 3, 1, 5, 29, 63, 95, 121, 467, 7, 1857, 2389, 5213, 3931, 21187, 43529, 6767, 0 };
            const std::uint32_t dim10637JoeKuoD6Init[]   =   { 1, 1, 7, 7, 9, 53, 31, 227, 95, 827, 927, 3501, 2003, 12853, 2595, 33223, 125799, 0 };
            const std::uint32_t dim10638JoeKuoD6Init[]   =   { 1, 3, 3, 3, 27, 25, 105, 143, 233, 887, 1135, 3449, 5767, 11447, 10251, 34621, 102113, 0 };
            const std::uint32_t dim10639JoeKuoD6Init[]   =   { 1, 3, 3, 15, 3, 63, 85, 119, 103, 835, 443, 3861, 4957, 5389, 6137, 48851, 51887, 0 };
            const std::uint32_t dim10640JoeKuoD6Init[]   =   { 1, 3, 7, 9, 23, 23, 45, 129, 463, 653, 1309, 3533, 1303, 2955, 18023, 37457, 114765, 0 };
            const std::uint32_t dim10641JoeKuoD6Init[]   =   { 1, 3, 7, 1, 23, 17, 31, 151, 71, 515, 781, 1793, 3507, 6051, 30279, 29461, 48271, 0 };
            const std::uint32_t dim10642JoeKuoD6Init[]   =   { 1, 3, 5, 15, 1, 31, 9, 187, 131, 571, 1309, 965, 7561, 16113, 23209, 54615, 16969, 0 };
            const std::uint32_t dim10643JoeKuoD6Init[]   =   { 1, 3, 5, 11, 11, 9, 109, 161, 9, 697, 1683, 1245, 2223, 3571, 18117, 13085, 99315, 0 };
            const std::uint32_t dim10644JoeKuoD6Init[]   =   { 1, 3, 3, 1, 13, 21, 27, 17, 11, 11, 1095, 1447, 6941, 3399, 21245, 36661, 54283, 0 };
            const std::uint32_t dim10645JoeKuoD6Init[]   =   { 1, 3, 1, 3, 21, 51, 21, 197, 161, 689, 1219, 1337, 6623, 5765, 11579, 2679, 23889, 0 };
            const std::uint32_t dim10646JoeKuoD6Init[]   =   { 1, 1, 5, 11, 7, 31, 101, 25, 231, 719, 1677, 1545, 459, 14735, 25153, 65079, 15141, 0 };
            const std::uint32_t dim10647JoeKuoD6Init[]   =   { 1, 1, 7, 9, 17, 7, 49, 1, 83, 829, 815, 307, 3405, 15189, 23699, 50889, 70391, 0 };
            const std::uint32_t dim10648JoeKuoD6Init[]   =   { 1, 1, 3, 15, 21, 57, 97, 191, 415, 899, 197, 2635, 7507, 14009, 8633, 48997, 93925, 0 };
            const std::uint32_t dim10649JoeKuoD6Init[]   =   { 1, 3, 5, 15, 23, 13, 67, 127, 33, 551, 911, 3933, 2027, 10665, 19509, 18485, 76111, 0 };
            const std::uint32_t dim10650JoeKuoD6Init[]   =   { 1, 1, 5, 7, 23, 63, 19, 149, 139, 155, 1621, 3391, 2337, 2809, 21161, 38565, 401, 0 };
            const std::uint32_t dim10651JoeKuoD6Init[]   =   { 1, 1, 1, 7, 19, 23, 81, 49, 339, 879, 1903, 657, 2677, 2273, 10853, 3225, 57933, 0 };
            const std::uint32_t dim10652JoeKuoD6Init[]   =   { 1, 3, 5, 5, 13, 31, 19, 203, 269, 1015, 997, 2151, 4471, 11331, 5363, 46519, 51709, 0 };
            const std::uint32_t dim10653JoeKuoD6Init[]   =   { 1, 1, 5, 11, 29, 19, 17, 169, 511, 389, 1429, 2707, 1341, 10511, 6779, 43345, 68693, 0 };
            const std::uint32_t dim10654JoeKuoD6Init[]   =   { 1, 1, 5, 11, 19, 25, 29, 37, 423, 345, 953, 2525, 5937, 6595, 31389, 39347, 36343, 0 };
            const std::uint32_t dim10655JoeKuoD6Init[]   =   { 1, 3, 1, 3, 15, 25, 45, 95, 111, 207, 19, 1723, 4113, 421, 3297, 46771, 8639, 0 };
            const std::uint32_t dim10656JoeKuoD6Init[]   =   { 1, 1, 3, 9, 9, 47, 27, 99, 327, 393, 1547, 1587, 4463, 719, 14609, 24347, 68107, 0 };
            const std::uint32_t dim10657JoeKuoD6Init[]   =   { 1, 3, 7, 7, 29, 19, 57, 229, 131, 497, 109, 251, 6599, 8947, 10255, 12875, 83831, 0 };
            const std::uint32_t dim10658JoeKuoD6Init[]   =   { 1, 3, 3, 7, 17, 5, 17, 45, 423, 393, 1793, 3, 603, 15221, 13141, 40585, 37489, 0 };
            const std::uint32_t dim10659JoeKuoD6Init[]   =   { 1, 1, 1, 11, 5, 1, 53, 147, 129, 135, 1473, 17, 7539, 13513, 16045, 17375, 41261, 0 };
            const std::uint32_t dim10660JoeKuoD6Init[]   =   { 1, 3, 1, 5, 3, 15, 75, 57, 47, 581, 739, 3529, 4323, 10225, 27861, 14431, 106811, 0 };
            const std::uint32_t dim10661JoeKuoD6Init[]   =   { 1, 3, 3, 13, 23, 57, 41, 39, 217, 67, 595, 1381, 6281, 10125, 30605, 7935, 124219, 0 };
            const std::uint32_t dim10662JoeKuoD6Init[]   =   { 1, 1, 7, 15, 15, 45, 1, 135, 495, 271, 2023, 3267, 39, 15025, 32763, 39023, 20041, 0 };
            const std::uint32_t dim10663JoeKuoD6Init[]   =   { 1, 3, 7, 13, 23, 53, 75, 147, 187, 633, 1989, 1885, 6581, 12169, 13639, 19707, 96429, 0 };
            const std::uint32_t dim10664JoeKuoD6Init[]   =   { 1, 1, 5, 9, 13, 55, 13, 41, 305, 105, 1983, 273, 35, 5185, 22569, 54203, 31641, 0 };
            const std::uint32_t dim10665JoeKuoD6Init[]   =   { 1, 1, 3, 15, 21, 19, 59, 35, 165, 575, 1961, 1443, 4803, 2339, 28329, 47695, 21505, 0 };
            const std::uint32_t dim10666JoeKuoD6Init[]   =   { 1, 3, 1, 3, 23, 45, 95, 85, 55, 457, 1957, 1243, 4091, 14669, 13213, 53901, 122605, 0 };
            const std::uint32_t dim10667JoeKuoD6Init[]   =   { 1, 3, 7, 1, 13, 1, 61, 253, 195, 839, 181, 1153, 1391, 205, 6725, 1757, 86817, 0 };
            const std::uint32_t dim10668JoeKuoD6Init[]   =   { 1, 1, 3, 9, 7, 13, 115, 137, 169, 851, 299, 509, 6709, 6331, 51, 31833, 25217, 0 };
            const std::uint32_t dim10669JoeKuoD6Init[]   =   { 1, 1, 5, 15, 29, 23, 119, 15, 41, 585, 1713, 1203, 1653, 3287, 25333, 58873, 71853, 0 };
            const std::uint32_t dim10670JoeKuoD6Init[]   =   { 1, 3, 5, 15, 1, 45, 35, 79, 97, 381, 2027, 3795, 2127, 4775, 4579, 63267, 24719, 0 };
            const std::uint32_t dim10671JoeKuoD6Init[]   =   { 1, 1, 5, 7, 17, 21, 123, 75, 3, 887, 1537, 2017, 1623, 16315, 12535, 64281, 54925, 0 };
            const std::uint32_t dim10672JoeKuoD6Init[]   =   { 1, 1, 3, 13, 5, 23, 117, 43, 305, 365, 775, 1599, 5917, 13995, 6353, 3113, 106317, 0 };
            const std::uint32_t dim10673JoeKuoD6Init[]   =   { 1, 1, 3, 11, 21, 19, 9, 11, 129, 349, 579, 3523, 5259, 8083, 24513, 15077, 115377, 0 };
            const std::uint32_t dim10674JoeKuoD6Init[]   =   { 1, 1, 7, 9, 19, 31, 107, 3, 185, 821, 907, 2389, 7015, 3161, 13603, 35063, 60641, 0 };
            const std::uint32_t dim10675JoeKuoD6Init[]   =   { 1, 1, 3, 1, 19, 35, 105, 245, 363, 745, 1287, 4051, 5201, 7787, 20919, 26567, 37357, 0 };
            const std::uint32_t dim10676JoeKuoD6Init[]   =   { 1, 3, 1, 1, 23, 31, 1, 149, 61, 489, 371, 987, 3689, 14275, 8581, 48221, 44183, 0 };
            const std::uint32_t dim10677JoeKuoD6Init[]   =   { 1, 1, 5, 3, 9, 35, 51, 17, 439, 355, 461, 2129, 1567, 13261, 22347, 17013, 53857, 0 };
            const std::uint32_t dim10678JoeKuoD6Init[]   =   { 1, 3, 3, 15, 3, 33, 59, 185, 157, 933, 1489, 647, 4839, 12139, 3145, 57819, 11731, 0 };
            const std::uint32_t dim10679JoeKuoD6Init[]   =   { 1, 3, 5, 15, 17, 31, 59, 51, 117, 1001, 1585, 2861, 2785, 9579, 28013, 4481, 126723, 0 };
            const std::uint32_t dim10680JoeKuoD6Init[]   =   { 1, 3, 7, 13, 27, 1, 41, 119, 179, 879, 1617, 4053, 3537, 15389, 16381, 40153, 68019, 0 };
            const std::uint32_t dim10681JoeKuoD6Init[]   =   { 1, 1, 3, 13, 13, 35, 45, 203, 333, 337, 1415, 1889, 2361, 4207, 10411, 21013, 44009, 0 };
            const std::uint32_t dim10682JoeKuoD6Init[]   =   { 1, 3, 3, 5, 27, 9, 17, 85, 331, 369, 1219, 247, 1977, 12267, 1181, 18811, 54017, 0 };
            const std::uint32_t dim10683JoeKuoD6Init[]   =   { 1, 3, 5, 9, 21, 57, 57, 175, 283, 639, 1155, 1595, 8187, 9981, 21451, 7525, 52751, 0 };
            const std::uint32_t dim10684JoeKuoD6Init[]   =   { 1, 3, 1, 5, 27, 61, 95, 25, 271, 81, 1335, 2821, 7805, 10167, 13197, 58341, 62325, 0 };
            const std::uint32_t dim10685JoeKuoD6Init[]   =   { 1, 1, 7, 3, 15, 31, 75, 5, 211, 663, 551, 963, 6015, 11907, 17045, 22863, 32389, 0 };
            const std::uint32_t dim10686JoeKuoD6Init[]   =   { 1, 1, 7, 5, 21, 53, 67, 71, 251, 135, 1153, 2247, 2499, 15431, 21419, 46737, 2827, 0 };
            const std::uint32_t dim10687JoeKuoD6Init[]   =   { 1, 1, 5, 3, 31, 25, 39, 209, 437, 791, 1595, 637, 1581, 6575, 26407, 24043, 11277, 0 };
            const std::uint32_t dim10688JoeKuoD6Init[]   =   { 1, 3, 3, 5, 21, 15, 13, 19, 259, 949, 1237, 239, 5739, 4661, 3405, 55775, 58781, 0 };
            const std::uint32_t dim10689JoeKuoD6Init[]   =   { 1, 1, 3, 5, 1, 63, 5, 197, 329, 625, 981, 913, 3957, 2765, 8801, 56675, 129511, 0 };
            const std::uint32_t dim10690JoeKuoD6Init[]   =   { 1, 3, 3, 3, 29, 53, 65, 145, 435, 937, 787, 2043, 4945, 14585, 2789, 15771, 112335, 0 };
            const std::uint32_t dim10691JoeKuoD6Init[]   =   { 1, 3, 7, 13, 3, 23, 33, 141, 131, 375, 739, 711, 897, 469, 3635, 43335, 3069, 0 };
            const std::uint32_t dim10692JoeKuoD6Init[]   =   { 1, 1, 7, 11, 29, 13, 111, 149, 197, 793, 1541, 1879, 7683, 9397, 6873, 43733, 118507, 0 };
            const std::uint32_t dim10693JoeKuoD6Init[]   =   { 1, 3, 7, 7, 29, 21, 97, 113, 139, 573, 1099, 2615, 5123, 13021, 9533, 57673, 79283, 0 };
            const std::uint32_t dim10694JoeKuoD6Init[]   =   { 1, 3, 1, 5, 11, 9, 59, 89, 469, 797, 1119, 1037, 1667, 5947, 6051, 65045, 98275, 0 };
            const std::uint32_t dim10695JoeKuoD6Init[]   =   { 1, 3, 3, 9, 11, 7, 51, 191, 321, 677, 1601, 681, 3579, 14441, 26579, 18019, 43065, 0 };
            const std::uint32_t dim10696JoeKuoD6Init[]   =   { 1, 3, 5, 11, 7, 11, 79, 21, 335, 537, 801, 3553, 4311, 375, 7333, 64839, 88841, 0 };
            const std::uint32_t dim10697JoeKuoD6Init[]   =   { 1, 3, 1, 7, 5, 11, 15, 163, 69, 645, 57, 3685, 5143, 8275, 12763, 25035, 68949, 0 };
            const std::uint32_t dim10698JoeKuoD6Init[]   =   { 1, 1, 3, 13, 29, 33, 125, 179, 431, 129, 1367, 951, 5843, 13419, 13897, 17315, 58083, 0 };
            const std::uint32_t dim10699JoeKuoD6Init[]   =   { 1, 1, 3, 11, 31, 33, 3, 7, 185, 821, 231, 869, 6147, 15243, 32029, 20295, 60871, 0 };
            const std::uint32_t dim10700JoeKuoD6Init[]   =   { 1, 1, 1, 1, 31, 43, 21, 103, 275, 573, 805, 225, 2049, 8375, 32595, 53201, 126487, 0 };
            const std::uint32_t dim10701JoeKuoD6Init[]   =   { 1, 1, 1, 9, 31, 29, 7, 91, 277, 937, 1223, 2435, 4335, 7861, 9647, 13577, 30059, 0 };
            const std::uint32_t dim10702JoeKuoD6Init[]   =   { 1, 1, 1, 1, 23, 25, 69, 175, 293, 905, 765, 1527, 6655, 15431, 2511, 3147, 75431, 0 };
            const std::uint32_t dim10703JoeKuoD6Init[]   =   { 1, 3, 3, 3, 15, 53, 109, 195, 87, 557, 1277, 1471, 7401, 14127, 11479, 41505, 769, 0 };
            const std::uint32_t dim10704JoeKuoD6Init[]   =   { 1, 1, 5, 11, 23, 37, 121, 181, 199, 359, 1521, 2561, 3641, 7621, 14219, 6959, 77529, 0 };
            const std::uint32_t dim10705JoeKuoD6Init[]   =   { 1, 3, 1, 11, 5, 7, 69, 199, 501, 251, 707, 1485, 8125, 3209, 30883, 40259, 85087, 0 };
            const std::uint32_t dim10706JoeKuoD6Init[]   =   { 1, 3, 5, 13, 9, 35, 5, 133, 505, 39, 581, 1605, 6303, 1211, 27211, 55591, 31689, 0 };
            const std::uint32_t dim10707JoeKuoD6Init[]   =   { 1, 1, 5, 3, 17, 7, 11, 61, 483, 59, 1569, 2583, 759, 5759, 3575, 44547, 89783, 0 };
            const std::uint32_t dim10708JoeKuoD6Init[]   =   { 1, 1, 7, 15, 5, 27, 107, 5, 471, 421, 383, 3591, 3609, 13817, 633, 22043, 83119, 0 };
            const std::uint32_t dim10709JoeKuoD6Init[]   =   { 1, 1, 3, 7, 27, 55, 61, 249, 37, 241, 1483, 2839, 1231, 4765, 1551, 55801, 129679, 0 };
            const std::uint32_t dim10710JoeKuoD6Init[]   =   { 1, 1, 1, 3, 11, 1, 19, 207, 143, 351, 409, 721, 4597, 13389, 30297, 43253, 129923, 0 };
            const std::uint32_t dim10711JoeKuoD6Init[]   =   { 1, 3, 3, 7, 7, 53, 83, 27, 167, 163, 537, 3871, 2459, 12813, 30019, 41131, 56109, 0 };
            const std::uint32_t dim10712JoeKuoD6Init[]   =   { 1, 1, 5, 1, 23, 37, 11, 67, 161, 751, 123, 307, 3341, 12983, 21565, 58529, 94503, 0 };
            const std::uint32_t dim10713JoeKuoD6Init[]   =   { 1, 3, 3, 15, 11, 33, 39, 195, 467, 647, 1479, 1197, 7949, 6501, 18375, 15263, 21121, 0 };
            const std::uint32_t dim10714JoeKuoD6Init[]   =   { 1, 3, 5, 13, 3, 35, 9, 253, 299, 679, 69, 165, 2735, 14725, 4217, 16391, 107017, 0 };
            const std::uint32_t dim10715JoeKuoD6Init[]   =   { 1, 1, 1, 15, 3, 11, 87, 87, 391, 515, 843, 3957, 1365, 13201, 15983, 53647, 35643, 0 };
            const std::uint32_t dim10716JoeKuoD6Init[]   =   { 1, 1, 3, 7, 9, 53, 45, 221, 209, 855, 169, 2729, 1219, 5229, 14111, 28877, 114653, 0 };
            const std::uint32_t dim10717JoeKuoD6Init[]   =   { 1, 1, 5, 3, 11, 17, 5, 93, 303, 785, 1895, 2483, 7399, 14031, 1007, 2743, 47307, 0 };
            const std::uint32_t dim10718JoeKuoD6Init[]   =   { 1, 1, 7, 11, 9, 13, 115, 31, 223, 1011, 723, 1291, 5183, 559, 15881, 43045, 28131, 0 };
            const std::uint32_t dim10719JoeKuoD6Init[]   =   { 1, 3, 7, 11, 7, 59, 85, 111, 79, 227, 691, 1597, 2453, 10023, 19255, 47781, 88351, 0 };
            const std::uint32_t dim10720JoeKuoD6Init[]   =   { 1, 3, 3, 7, 21, 33, 39, 35, 253, 743, 563, 2455, 8015, 13403, 24883, 47881, 115559, 0 };
            const std::uint32_t dim10721JoeKuoD6Init[]   =   { 1, 3, 1, 1, 5, 33, 69, 37, 225, 157, 1347, 3241, 4981, 15985, 9949, 49189, 21267, 0 };
            const std::uint32_t dim10722JoeKuoD6Init[]   =   { 1, 1, 3, 11, 9, 33, 123, 133, 215, 297, 961, 1571, 1133, 1, 31871, 25253, 100097, 0 };
            const std::uint32_t dim10723JoeKuoD6Init[]   =   { 1, 1, 1, 7, 13, 29, 101, 127, 113, 785, 1257, 525, 7397, 13143, 30315, 5969, 37829, 0 };
            const std::uint32_t dim10724JoeKuoD6Init[]   =   { 1, 1, 1, 7, 29, 33, 17, 95, 439, 577, 1857, 423, 63, 15365, 4777, 59073, 7773, 0 };
            const std::uint32_t dim10725JoeKuoD6Init[]   =   { 1, 1, 5, 15, 3, 17, 89, 133, 217, 601, 1979, 391, 105, 13709, 10081, 37725, 40957, 0 };
            const std::uint32_t dim10726JoeKuoD6Init[]   =   { 1, 1, 1, 15, 25, 7, 85, 197, 155, 367, 1927, 2007, 2563, 13147, 2345, 28735, 88243, 0 };
            const std::uint32_t dim10727JoeKuoD6Init[]   =   { 1, 3, 5, 3, 5, 33, 87, 153, 153, 779, 825, 2163, 385, 11663, 2005, 51261, 25893, 0 };
            const std::uint32_t dim10728JoeKuoD6Init[]   =   { 1, 3, 5, 5, 23, 15, 19, 99, 71, 723, 523, 3683, 7773, 191, 17423, 30497, 129889, 0 };
            const std::uint32_t dim10729JoeKuoD6Init[]   =   { 1, 1, 7, 11, 1, 3, 49, 119, 39, 661, 297, 27, 1575, 12145, 18519, 57285, 50059, 0 };
            const std::uint32_t dim10730JoeKuoD6Init[]   =   { 1, 3, 7, 5, 7, 37, 75, 235, 403, 743, 603, 1689, 5031, 8871, 28241, 16917, 16947, 0 };
            const std::uint32_t dim10731JoeKuoD6Init[]   =   { 1, 1, 5, 13, 17, 41, 67, 219, 237, 365, 833, 3521, 3211, 1037, 5657, 34789, 119739, 0 };
            const std::uint32_t dim10732JoeKuoD6Init[]   =   { 1, 1, 5, 7, 3, 61, 89, 107, 335, 825, 803, 2445, 6861, 5421, 14585, 44037, 92711, 0 };
            const std::uint32_t dim10733JoeKuoD6Init[]   =   { 1, 3, 7, 3, 19, 25, 81, 51, 101, 477, 1653, 2841, 6597, 9261, 30609, 15681, 48897, 0 };
            const std::uint32_t dim10734JoeKuoD6Init[]   =   { 1, 1, 7, 11, 17, 1, 43, 39, 133, 513, 1839, 553, 6379, 4865, 28161, 7249, 80073, 0 };
            const std::uint32_t dim10735JoeKuoD6Init[]   =   { 1, 1, 5, 5, 13, 45, 19, 225, 399, 679, 195, 3613, 413, 2901, 26749, 39971, 31435, 0 };
            const std::uint32_t dim10736JoeKuoD6Init[]   =   { 1, 3, 7, 3, 23, 55, 57, 77, 447, 721, 677, 271, 6211, 12631, 5843, 35991, 82653, 0 };
            const std::uint32_t dim10737JoeKuoD6Init[]   =   { 1, 1, 1, 1, 3, 63, 23, 195, 1, 1019, 723, 3865, 5913, 5491, 5495, 27483, 73637, 0 };
            const std::uint32_t dim10738JoeKuoD6Init[]   =   { 1, 3, 1, 11, 17, 31, 27, 211, 411, 789, 1049, 2487, 2203, 6457, 7275, 4833, 14131, 0 };
            const std::uint32_t dim10739JoeKuoD6Init[]   =   { 1, 1, 5, 15, 15, 13, 65, 155, 127, 753, 1605, 1859, 2873, 9197, 1763, 11969, 82971, 0 };
            const std::uint32_t dim10740JoeKuoD6Init[]   =   { 1, 1, 3, 11, 11, 63, 13, 29, 31, 851, 251, 3231, 1227, 5513, 9785, 34659, 123811, 0 };
            const std::uint32_t dim10741JoeKuoD6Init[]   =   { 1, 3, 5, 1, 19, 57, 41, 205, 91, 39, 989, 1897, 4789, 16071, 6507, 29363, 75773, 0 };
            const std::uint32_t dim10742JoeKuoD6Init[]   =   { 1, 1, 1, 1, 5, 29, 113, 203, 53, 599, 1529, 1417, 7017, 9609, 4867, 17659, 80719, 0 };
            const std::uint32_t dim10743JoeKuoD6Init[]   =   { 1, 3, 7, 9, 27, 17, 77, 25, 461, 511, 781, 2977, 7601, 3551, 23615, 57669, 119723, 0 };
            const std::uint32_t dim10744JoeKuoD6Init[]   =   { 1, 3, 3, 9, 23, 43, 115, 21, 125, 237, 893, 1431, 7423, 3717, 4371, 36193, 30481, 0 };
            const std::uint32_t dim10745JoeKuoD6Init[]   =   { 1, 1, 5, 13, 3, 37, 13, 239, 267, 665, 205, 2745, 3865, 12167, 26689, 999, 9355, 0 };
            const std::uint32_t dim10746JoeKuoD6Init[]   =   { 1, 1, 1, 1, 31, 35, 55, 115, 387, 217, 657, 2827, 2963, 3687, 24271, 41701, 5911, 0 };
            const std::uint32_t dim10747JoeKuoD6Init[]   =   { 1, 1, 3, 3, 27, 57, 41, 183, 351, 841, 1327, 719, 7043, 12503, 17953, 60719, 98223, 0 };
            const std::uint32_t dim10748JoeKuoD6Init[]   =   { 1, 3, 1, 1, 27, 1, 119, 85, 197, 673, 1951, 2949, 4783, 561, 12807, 43355, 63397, 0 };
            const std::uint32_t dim10749JoeKuoD6Init[]   =   { 1, 1, 7, 7, 17, 63, 109, 87, 303, 439, 529, 685, 111, 8405, 21249, 33803, 77927, 0 };
            const std::uint32_t dim10750JoeKuoD6Init[]   =   { 1, 1, 7, 9, 11, 63, 27, 185, 445, 25, 1313, 3979, 4229, 8797, 10671, 33995, 84463, 0 };
            const std::uint32_t dim10751JoeKuoD6Init[]   =   { 1, 1, 1, 15, 27, 63, 67, 237, 39, 993, 851, 4075, 3417, 1077, 11939, 31737, 93897, 0 };
            const std::uint32_t dim10752JoeKuoD6Init[]   =   { 1, 1, 3, 5, 25, 9, 51, 241, 213, 661, 1135, 213, 7027, 5933, 24485, 65029, 8583, 0 };
            const std::uint32_t dim10753JoeKuoD6Init[]   =   { 1, 3, 5, 11, 31, 1, 17, 237, 107, 1021, 279, 181, 1741, 11099, 7871, 63231, 64445, 0 };
            const std::uint32_t dim10754JoeKuoD6Init[]   =   { 1, 3, 5, 9, 17, 21, 11, 45, 23, 409, 519, 1703, 5467, 9591, 13555, 23739, 73837, 0 };
            const std::uint32_t dim10755JoeKuoD6Init[]   =   { 1, 3, 3, 15, 3, 39, 11, 157, 273, 241, 413, 1723, 3179, 2125, 16859, 5231, 122969, 0 };
            const std::uint32_t dim10756JoeKuoD6Init[]   =   { 1, 3, 5, 11, 21, 27, 29, 243, 255, 1011, 1179, 3545, 3557, 8091, 31569, 10217, 108361, 0 };
            const std::uint32_t dim10757JoeKuoD6Init[]   =   { 1, 1, 5, 9, 25, 33, 29, 67, 395, 123, 1405, 3855, 7481, 5601, 21231, 17099, 13399, 0 };
            const std::uint32_t dim10758JoeKuoD6Init[]   =   { 1, 1, 5, 5, 13, 17, 111, 47, 77, 827, 577, 1767, 3367, 11719, 8801, 22431, 85451, 0 };
            const std::uint32_t dim10759JoeKuoD6Init[]   =   { 1, 3, 7, 11, 11, 31, 17, 141, 149, 293, 55, 3459, 19, 13709, 29135, 62765, 66455, 0 };
            const std::uint32_t dim10760JoeKuoD6Init[]   =   { 1, 1, 7, 15, 13, 19, 59, 211, 189, 773, 1791, 2089, 2857, 1635, 17777, 46585, 70115, 0 };
            const std::uint32_t dim10761JoeKuoD6Init[]   =   { 1, 1, 5, 11, 29, 29, 15, 7, 93, 733, 1605, 3731, 2381, 1063, 15565, 25081, 46651, 0 };
            const std::uint32_t dim10762JoeKuoD6Init[]   =   { 1, 3, 1, 9, 25, 5, 87, 113, 25, 93, 881, 1137, 3237, 10983, 14317, 25945, 121493, 0 };
            const std::uint32_t dim10763JoeKuoD6Init[]   =   { 1, 1, 5, 11, 29, 47, 99, 111, 165, 453, 259, 2001, 7715, 2609, 15633, 40273, 2065, 0 };
            const std::uint32_t dim10764JoeKuoD6Init[]   =   { 1, 1, 7, 13, 11, 29, 33, 255, 149, 361, 89, 2837, 49, 3033, 1917, 9029, 38123, 0 };
            const std::uint32_t dim10765JoeKuoD6Init[]   =   { 1, 1, 1, 7, 27, 31, 105, 61, 469, 497, 1919, 3005, 3651, 2143, 24359, 8053, 103647, 0 };
            const std::uint32_t dim10766JoeKuoD6Init[]   =   { 1, 1, 3, 13, 31, 63, 101, 47, 397, 89, 1915, 2385, 5399, 8897, 21001, 42997, 110333, 0 };
            const std::uint32_t dim10767JoeKuoD6Init[]   =   { 1, 3, 7, 5, 29, 1, 5, 119, 493, 349, 153, 1839, 283, 14343, 12975, 55597, 89467, 0 };
            const std::uint32_t dim10768JoeKuoD6Init[]   =   { 1, 3, 5, 3, 5, 51, 71, 227, 63, 799, 745, 1387, 2435, 1003, 27937, 43421, 12279, 0 };
            const std::uint32_t dim10769JoeKuoD6Init[]   =   { 1, 3, 3, 7, 7, 31, 37, 61, 11, 175, 581, 1583, 4737, 3087, 10335, 60683, 57085, 0 };
            const std::uint32_t dim10770JoeKuoD6Init[]   =   { 1, 3, 1, 1, 1, 63, 59, 47, 417, 35, 1673, 3277, 1873, 14981, 22463, 26835, 91115, 0 };
            const std::uint32_t dim10771JoeKuoD6Init[]   =   { 1, 1, 7, 5, 15, 23, 115, 13, 253, 583, 219, 1307, 1189, 9891, 641, 20841, 87133, 0 };
            const std::uint32_t dim10772JoeKuoD6Init[]   =   { 1, 1, 5, 11, 1, 3, 71, 235, 429, 335, 1649, 1775, 3077, 13723, 3209, 19807, 7283, 0 };
            const std::uint32_t dim10773JoeKuoD6Init[]   =   { 1, 1, 7, 1, 31, 49, 39, 141, 127, 63, 1561, 2559, 7661, 4825, 9419, 15327, 87145, 0 };
            const std::uint32_t dim10774JoeKuoD6Init[]   =   { 1, 1, 5, 3, 17, 33, 51, 219, 467, 151, 161, 3301, 7509, 2235, 30371, 64031, 62741, 0 };
            const std::uint32_t dim10775JoeKuoD6Init[]   =   { 1, 3, 1, 3, 23, 63, 43, 29, 399, 279, 271, 3537, 1863, 1811, 14917, 28247, 34807, 0 };
            const std::uint32_t dim10776JoeKuoD6Init[]   =   { 1, 1, 3, 5, 13, 29, 37, 151, 129, 19, 149, 2145, 5363, 6835, 19655, 1207, 74527, 0 };
            const std::uint32_t dim10777JoeKuoD6Init[]   =   { 1, 3, 5, 7, 27, 35, 63, 53, 247, 987, 1767, 483, 3489, 1711, 10763, 6981, 78251, 0 };
            const std::uint32_t dim10778JoeKuoD6Init[]   =   { 1, 1, 3, 1, 15, 47, 83, 147, 375, 539, 1623, 29, 4599, 7981, 23533, 64659, 48753, 0 };
            const std::uint32_t dim10779JoeKuoD6Init[]   =   { 1, 1, 1, 9, 21, 17, 85, 45, 167, 469, 1319, 2969, 1605, 1405, 9961, 28829, 125757, 0 };
            const std::uint32_t dim10780JoeKuoD6Init[]   =   { 1, 3, 1, 11, 3, 45, 43, 159, 301, 579, 1821, 701, 1149, 457, 16601, 49377, 99845, 0 };
            const std::uint32_t dim10781JoeKuoD6Init[]   =   { 1, 1, 7, 13, 11, 7, 37, 227, 345, 973, 1167, 1247, 5109, 10917, 3029, 60065, 127347, 0 };
            const std::uint32_t dim10782JoeKuoD6Init[]   =   { 1, 1, 3, 5, 3, 63, 95, 233, 495, 225, 1225, 3451, 7731, 14677, 10437, 1417, 33293, 0 };
            const std::uint32_t dim10783JoeKuoD6Init[]   =   { 1, 1, 7, 15, 1, 3, 3, 171, 201, 1009, 1481, 587, 7661, 10085, 4961, 46415, 28573, 0 };
            const std::uint32_t dim10784JoeKuoD6Init[]   =   { 1, 1, 5, 1, 3, 45, 67, 79, 463, 733, 2007, 2811, 2943, 14857, 23469, 14479, 97875, 0 };
            const std::uint32_t dim10785JoeKuoD6Init[]   =   { 1, 1, 1, 5, 19, 1, 29, 29, 447, 173, 1081, 153, 5343, 5707, 1357, 30169, 122527, 0 };
            const std::uint32_t dim10786JoeKuoD6Init[]   =   { 1, 1, 1, 5, 15, 57, 33, 129, 71, 717, 173, 3271, 4741, 13211, 28321, 56793, 119833, 0 };
            const std::uint32_t dim10787JoeKuoD6Init[]   =   { 1, 3, 3, 9, 9, 41, 47, 71, 103, 713, 725, 1335, 5261, 13835, 17619, 47429, 69815, 0 };
            const std::uint32_t dim10788JoeKuoD6Init[]   =   { 1, 3, 3, 15, 7, 3, 71, 25, 75, 967, 1037, 3585, 3407, 9979, 2195, 51087, 126535, 0 };
            const std::uint32_t dim10789JoeKuoD6Init[]   =   { 1, 3, 3, 11, 25, 7, 25, 249, 473, 339, 1211, 3503, 4343, 9707, 26127, 62061, 52479, 0 };
            const std::uint32_t dim10790JoeKuoD6Init[]   =   { 1, 1, 3, 3, 27, 9, 79, 197, 207, 845, 377, 3231, 5177, 899, 19497, 41187, 105897, 0 };
            const std::uint32_t dim10791JoeKuoD6Init[]   =   { 1, 3, 5, 15, 5, 27, 65, 151, 207, 677, 713, 2495, 681, 15341, 5389, 51965, 43761, 0 };
            const std::uint32_t dim10792JoeKuoD6Init[]   =   { 1, 3, 3, 11, 19, 11, 55, 189, 291, 183, 1345, 2677, 791, 2391, 25771, 55147, 24223, 0 };
            const std::uint32_t dim10793JoeKuoD6Init[]   =   { 1, 1, 3, 11, 31, 59, 29, 5, 275, 483, 1361, 1527, 3019, 245, 17667, 57905, 41329, 0 };
            const std::uint32_t dim10794JoeKuoD6Init[]   =   { 1, 3, 3, 9, 7, 19, 83, 71, 147, 999, 793, 3535, 1931, 12817, 2707, 45735, 31311, 0 };
            const std::uint32_t dim10795JoeKuoD6Init[]   =   { 1, 1, 5, 7, 5, 1, 117, 247, 127, 1011, 1441, 2449, 4095, 12239, 4743, 64781, 32621, 0 };
            const std::uint32_t dim10796JoeKuoD6Init[]   =   { 1, 3, 1, 11, 19, 57, 43, 39, 97, 485, 951, 989, 5975, 5219, 14421, 43681, 37305, 0 };
            const std::uint32_t dim10797JoeKuoD6Init[]   =   { 1, 1, 5, 15, 7, 49, 113, 161, 199, 545, 1113, 3821, 2019, 8747, 4085, 50823, 31955, 0 };
            const std::uint32_t dim10798JoeKuoD6Init[]   =   { 1, 3, 3, 3, 19, 41, 47, 191, 403, 25, 2043, 3489, 6263, 4843, 12961, 63791, 5027, 0 };
            const std::uint32_t dim10799JoeKuoD6Init[]   =   { 1, 1, 7, 1, 25, 55, 5, 51, 121, 273, 973, 3893, 1771, 9373, 21927, 29353, 95935, 0 };
            const std::uint32_t dim10800JoeKuoD6Init[]   =   { 1, 3, 3, 3, 27, 1, 97, 63, 445, 179, 481, 2995, 3123, 4687, 24359, 35973, 74535, 0 };
            const std::uint32_t dim10801JoeKuoD6Init[]   =   { 1, 1, 5, 1, 29, 23, 117, 183, 197, 819, 695, 641, 4155, 13593, 30965, 41407, 42433, 0 };
            const std::uint32_t dim10802JoeKuoD6Init[]   =   { 1, 3, 5, 1, 23, 53, 61, 253, 87, 487, 1995, 1281, 3367, 15047, 3493, 41711, 53407, 0 };
            const std::uint32_t dim10803JoeKuoD6Init[]   =   { 1, 1, 1, 9, 27, 49, 83, 21, 63, 181, 1661, 1649, 281, 12141, 25771, 35563, 42643, 0 };
            const std::uint32_t dim10804JoeKuoD6Init[]   =   { 1, 3, 5, 13, 15, 59, 121, 113, 379, 487, 1929, 3725, 2477, 6527, 8619, 64869, 57103, 0 };
            const std::uint32_t dim10805JoeKuoD6Init[]   =   { 1, 3, 1, 7, 27, 39, 69, 93, 193, 395, 433, 2091, 151, 6921, 11599, 36143, 41179, 0 };
            const std::uint32_t dim10806JoeKuoD6Init[]   =   { 1, 1, 7, 1, 31, 33, 73, 199, 57, 37, 1387, 3505, 7919, 3507, 2855, 8239, 84527, 0 };
            const std::uint32_t dim10807JoeKuoD6Init[]   =   { 1, 1, 7, 5, 15, 5, 119, 253, 263, 785, 1409, 1485, 3675, 5515, 13057, 30323, 98015, 0 };
            const std::uint32_t dim10808JoeKuoD6Init[]   =   { 1, 3, 1, 1, 11, 5, 57, 83, 365, 703, 1923, 1397, 1103, 4015, 13123, 47093, 113793, 0 };
            const std::uint32_t dim10809JoeKuoD6Init[]   =   { 1, 3, 3, 1, 5, 61, 29, 173, 189, 999, 897, 3389, 6745, 1487, 2349, 59105, 107407, 0 };
            const std::uint32_t dim10810JoeKuoD6Init[]   =   { 1, 1, 1, 1, 17, 51, 65, 1, 249, 863, 399, 3819, 2485, 12215, 12365, 58909, 25559, 0 };
            const std::uint32_t dim10811JoeKuoD6Init[]   =   { 1, 3, 7, 1, 31, 39, 43, 219, 51, 13, 779, 505, 2259, 14571, 9049, 21555, 11869, 0 };
            const std::uint32_t dim10812JoeKuoD6Init[]   =   { 1, 1, 7, 7, 13, 5, 97, 85, 111, 511, 587, 63, 2395, 8099, 26223, 757, 119821, 0 };
            const std::uint32_t dim10813JoeKuoD6Init[]   =   { 1, 3, 3, 5, 5, 19, 113, 35, 101, 41, 499, 1313, 6489, 6793, 31435, 45007, 95691, 0 };
            const std::uint32_t dim10814JoeKuoD6Init[]   =   { 1, 3, 5, 15, 19, 37, 103, 187, 347, 667, 1957, 1825, 7447, 12359, 21779, 52749, 18679, 0 };
            const std::uint32_t dim10815JoeKuoD6Init[]   =   { 1, 3, 5, 5, 17, 19, 19, 193, 435, 379, 439, 2093, 725, 2133, 15659, 54645, 59567, 0 };
            const std::uint32_t dim10816JoeKuoD6Init[]   =   { 1, 3, 7, 3, 23, 35, 33, 13, 23, 349, 231, 1635, 1625, 5039, 21299, 36413, 104681, 0 };
            const std::uint32_t dim10817JoeKuoD6Init[]   =   { 1, 1, 3, 13, 23, 49, 15, 253, 509, 9, 411, 2157, 3737, 11227, 6021, 42919, 100375, 0 };
            const std::uint32_t dim10818JoeKuoD6Init[]   =   { 1, 1, 7, 1, 17, 11, 33, 167, 219, 63, 137, 741, 4193, 16149, 9657, 50223, 85213, 0 };
            const std::uint32_t dim10819JoeKuoD6Init[]   =   { 1, 3, 7, 11, 23, 59, 113, 149, 427, 697, 1723, 255, 201, 10081, 1079, 323, 109091, 0 };
            const std::uint32_t dim10820JoeKuoD6Init[]   =   { 1, 3, 3, 15, 11, 9, 89, 39, 67, 249, 1939, 1737, 3719, 10515, 16517, 22345, 83959, 0 };
            const std::uint32_t dim10821JoeKuoD6Init[]   =   { 1, 3, 3, 13, 5, 33, 127, 9, 329, 429, 563, 1579, 4427, 8343, 22083, 5035, 124915, 0 };
            const std::uint32_t dim10822JoeKuoD6Init[]   =   { 1, 1, 1, 5, 15, 57, 121, 171, 315, 983, 743, 2015, 2421, 12431, 2561, 13331, 73163, 0 };
            const std::uint32_t dim10823JoeKuoD6Init[]   =   { 1, 1, 3, 9, 1, 39, 85, 159, 23, 979, 1467, 231, 4231, 3669, 16747, 24195, 46745, 0 };
            const std::uint32_t dim10824JoeKuoD6Init[]   =   { 1, 1, 3, 7, 3, 11, 65, 67, 85, 455, 365, 2279, 3471, 12771, 14443, 42773, 28723, 0 };
            const std::uint32_t dim10825JoeKuoD6Init[]   =   { 1, 3, 5, 1, 13, 9, 105, 237, 103, 59, 1301, 3125, 509, 12669, 3893, 9775, 81303, 0 };
            const std::uint32_t dim10826JoeKuoD6Init[]   =   { 1, 1, 3, 11, 19, 9, 125, 23, 191, 979, 533, 429, 3239, 15013, 13833, 40689, 102827, 0 };
            const std::uint32_t dim10827JoeKuoD6Init[]   =   { 1, 3, 3, 7, 15, 5, 83, 243, 467, 913, 1279, 3889, 8049, 8357, 5957, 39073, 93521, 0 };
            const std::uint32_t dim10828JoeKuoD6Init[]   =   { 1, 3, 3, 3, 19, 5, 123, 77, 289, 57, 2001, 807, 5257, 1671, 20273, 10183, 128439, 0 };
            const std::uint32_t dim10829JoeKuoD6Init[]   =   { 1, 1, 7, 13, 19, 45, 25, 47, 135, 929, 1353, 2731, 3351, 7637, 27037, 58835, 50285, 0 };
            const std::uint32_t dim10830JoeKuoD6Init[]   =   { 1, 3, 1, 1, 13, 55, 55, 197, 409, 93, 1351, 161, 1885, 5913, 27937, 49793, 84541, 0 };
            const std::uint32_t dim10831JoeKuoD6Init[]   =   { 1, 1, 3, 7, 29, 21, 113, 179, 203, 533, 1471, 2035, 447, 6781, 28729, 31099, 23027, 0 };
            const std::uint32_t dim10832JoeKuoD6Init[]   =   { 1, 1, 3, 11, 27, 3, 5, 209, 367, 945, 749, 3637, 2881, 8139, 27875, 34223, 97263, 0 };
            const std::uint32_t dim10833JoeKuoD6Init[]   =   { 1, 3, 5, 13, 25, 27, 35, 3, 13, 707, 303, 3663, 6617, 13501, 25537, 33077, 71485, 0 };
            const std::uint32_t dim10834JoeKuoD6Init[]   =   { 1, 1, 7, 15, 11, 29, 65, 47, 235, 635, 133, 153, 6175, 2961, 8171, 28641, 122589, 0 };
            const std::uint32_t dim10835JoeKuoD6Init[]   =   { 1, 1, 5, 15, 17, 41, 85, 147, 323, 673, 1629, 3477, 3341, 16373, 13901, 60961, 39451, 0 };
            const std::uint32_t dim10836JoeKuoD6Init[]   =   { 1, 3, 1, 15, 29, 15, 37, 109, 293, 863, 1835, 1173, 2263, 13815, 24995, 6989, 103417, 0 };
            const std::uint32_t dim10837JoeKuoD6Init[]   =   { 1, 3, 3, 15, 3, 31, 23, 47, 15, 717, 1457, 1067, 6229, 7051, 21771, 54815, 115827, 0 };
            const std::uint32_t dim10838JoeKuoD6Init[]   =   { 1, 1, 1, 13, 21, 3, 45, 239, 89, 603, 407, 781, 8095, 7389, 18035, 32229, 39867, 0 };
            const std::uint32_t dim10839JoeKuoD6Init[]   =   { 1, 1, 3, 7, 7, 59, 79, 51, 411, 917, 803, 2455, 2623, 12413, 23957, 44199, 67903, 0 };
            const std::uint32_t dim10840JoeKuoD6Init[]   =   { 1, 3, 1, 9, 17, 37, 117, 47, 101, 733, 1861, 1111, 6785, 13743, 24371, 49427, 54711, 0 };
            const std::uint32_t dim10841JoeKuoD6Init[]   =   { 1, 3, 1, 15, 27, 63, 107, 33, 351, 287, 1765, 1947, 6209, 8127, 30007, 18757, 31453, 0 };
            const std::uint32_t dim10842JoeKuoD6Init[]   =   { 1, 3, 5, 13, 11, 13, 29, 247, 7, 609, 1235, 1767, 5365, 12673, 10151, 51579, 106407, 0 };
            const std::uint32_t dim10843JoeKuoD6Init[]   =   { 1, 3, 7, 15, 5, 25, 81, 197, 51, 615, 1695, 259, 7983, 1403, 7903, 21441, 73263, 0 };
            const std::uint32_t dim10844JoeKuoD6Init[]   =   { 1, 1, 5, 1, 13, 61, 55, 175, 445, 3, 1957, 1171, 6823, 4285, 11847, 12789, 79787, 0 };
            const std::uint32_t dim10845JoeKuoD6Init[]   =   { 1, 1, 5, 15, 17, 51, 111, 201, 45, 97, 45, 2533, 1125, 3663, 13685, 45719, 51497, 0 };
            const std::uint32_t dim10846JoeKuoD6Init[]   =   { 1, 3, 3, 13, 29, 59, 111, 97, 381, 477, 1229, 3709, 5185, 7055, 32729, 32881, 25539, 0 };
            const std::uint32_t dim10847JoeKuoD6Init[]   =   { 1, 3, 1, 9, 1, 39, 57, 143, 189, 625, 1717, 1755, 3129, 807, 27975, 15511, 66123, 0 };
            const std::uint32_t dim10848JoeKuoD6Init[]   =   { 1, 3, 3, 1, 5, 41, 25, 27, 163, 397, 1595, 2325, 1803, 12439, 25743, 24509, 72613, 0 };
            const std::uint32_t dim10849JoeKuoD6Init[]   =   { 1, 1, 5, 13, 29, 41, 125, 113, 367, 709, 1911, 669, 831, 5375, 31145, 26197, 33543, 0 };
            const std::uint32_t dim10850JoeKuoD6Init[]   =   { 1, 1, 5, 1, 1, 5, 91, 199, 133, 273, 393, 1179, 717, 12791, 17693, 6905, 20433, 0 };
            const std::uint32_t dim10851JoeKuoD6Init[]   =   { 1, 1, 3, 15, 29, 35, 9, 127, 383, 673, 1821, 2765, 2425, 11789, 19741, 43189, 99557, 0 };
            const std::uint32_t dim10852JoeKuoD6Init[]   =   { 1, 1, 7, 13, 9, 19, 119, 103, 11, 983, 623, 391, 1609, 2333, 19843, 28269, 41237, 0 };
            const std::uint32_t dim10853JoeKuoD6Init[]   =   { 1, 3, 7, 5, 29, 3, 13, 213, 387, 361, 749, 669, 1625, 5687, 11369, 38119, 38389, 0 };
            const std::uint32_t dim10854JoeKuoD6Init[]   =   { 1, 3, 5, 13, 13, 51, 47, 33, 1, 979, 1817, 2633, 7181, 47, 3603, 49211, 4377, 0 };
            const std::uint32_t dim10855JoeKuoD6Init[]   =   { 1, 3, 1, 1, 11, 63, 5, 249, 13, 805, 1097, 1449, 5235, 16299, 25855, 30949, 3013, 0 };
            const std::uint32_t dim10856JoeKuoD6Init[]   =   { 1, 3, 7, 9, 29, 35, 89, 135, 475, 945, 999, 771, 6023, 13317, 32611, 43971, 10393, 0 };
            const std::uint32_t dim10857JoeKuoD6Init[]   =   { 1, 1, 1, 5, 23, 3, 37, 117, 95, 985, 1599, 2191, 3617, 5831, 31113, 10873, 112219, 0 };
            const std::uint32_t dim10858JoeKuoD6Init[]   =   { 1, 3, 5, 7, 11, 15, 55, 65, 239, 365, 1209, 3509, 8101, 8619, 24775, 65291, 50589, 0 };
            const std::uint32_t dim10859JoeKuoD6Init[]   =   { 1, 1, 7, 9, 21, 19, 123, 83, 317, 717, 433, 31, 2597, 14723, 28839, 7817, 126123, 0 };
            const std::uint32_t dim10860JoeKuoD6Init[]   =   { 1, 1, 7, 11, 3, 33, 99, 39, 227, 279, 353, 1921, 7883, 16187, 5157, 41121, 89425, 0 };
            const std::uint32_t dim10861JoeKuoD6Init[]   =   { 1, 3, 5, 9, 25, 7, 29, 165, 129, 77, 159, 923, 1357, 1159, 23537, 58087, 56443, 0 };
            const std::uint32_t dim10862JoeKuoD6Init[]   =   { 1, 1, 7, 3, 13, 51, 45, 161, 27, 41, 1295, 2937, 7223, 5271, 17927, 23311, 2543, 0 };
            const std::uint32_t dim10863JoeKuoD6Init[]   =   { 1, 1, 1, 1, 11, 53, 119, 165, 409, 785, 1649, 3587, 259, 10997, 3171, 31271, 104631, 0 };
            const std::uint32_t dim10864JoeKuoD6Init[]   =   { 1, 1, 5, 7, 5, 7, 49, 201, 373, 825, 1755, 3751, 8041, 8133, 21347, 12039, 3049, 0 };
            const std::uint32_t dim10865JoeKuoD6Init[]   =   { 1, 1, 1, 3, 7, 29, 103, 1, 473, 65, 761, 1611, 5121, 14345, 32535, 16679, 11321, 0 };
            const std::uint32_t dim10866JoeKuoD6Init[]   =   { 1, 3, 3, 11, 21, 57, 35, 63, 237, 415, 1943, 483, 5377, 14647, 23433, 45459, 32535, 0 };
            const std::uint32_t dim10867JoeKuoD6Init[]   =   { 1, 1, 1, 15, 21, 57, 7, 103, 493, 279, 665, 3699, 169, 7619, 3571, 11539, 31983, 0 };
            const std::uint32_t dim10868JoeKuoD6Init[]   =   { 1, 1, 1, 1, 9, 5, 81, 159, 105, 927, 379, 1133, 1805, 14341, 9833, 63151, 70877, 0 };
            const std::uint32_t dim10869JoeKuoD6Init[]   =   { 1, 1, 7, 5, 19, 5, 63, 127, 129, 43, 757, 2215, 3899, 643, 19731, 17345, 102611, 0 };
            const std::uint32_t dim10870JoeKuoD6Init[]   =   { 1, 3, 7, 7, 27, 21, 3, 69, 475, 283, 319, 833, 3683, 11275, 18191, 44027, 24901, 0 };
            const std::uint32_t dim10871JoeKuoD6Init[]   =   { 1, 1, 5, 5, 31, 25, 63, 33, 505, 765, 257, 1147, 779, 12505, 19971, 24695, 65935, 0 };
            const std::uint32_t dim10872JoeKuoD6Init[]   =   { 1, 1, 1, 15, 23, 33, 31, 107, 59, 639, 1307, 3211, 6171, 15665, 16775, 61671, 25569, 0 };
            const std::uint32_t dim10873JoeKuoD6Init[]   =   { 1, 3, 3, 9, 31, 3, 113, 199, 425, 895, 1051, 2125, 1525, 15199, 14845, 4213, 18449, 0 };
            const std::uint32_t dim10874JoeKuoD6Init[]   =   { 1, 3, 5, 3, 3, 11, 75, 121, 33, 265, 459, 3879, 909, 6533, 18451, 32421, 117427, 0 };
            const std::uint32_t dim10875JoeKuoD6Init[]   =   { 1, 1, 1, 9, 11, 9, 125, 175, 309, 847, 959, 2013, 1557, 9291, 2963, 43275, 9917, 0 };
            const std::uint32_t dim10876JoeKuoD6Init[]   =   { 1, 1, 5, 3, 15, 39, 67, 35, 373, 601, 463, 1263, 1615, 15059, 31011, 36059, 114493, 0 };
            const std::uint32_t dim10877JoeKuoD6Init[]   =   { 1, 1, 5, 15, 5, 43, 49, 239, 461, 171, 1863, 2249, 2923, 15897, 22941, 29925, 21429, 0 };
            const std::uint32_t dim10878JoeKuoD6Init[]   =   { 1, 1, 1, 15, 13, 31, 127, 205, 361, 149, 1641, 1443, 5959, 13183, 13861, 9533, 1011, 0 };
            const std::uint32_t dim10879JoeKuoD6Init[]   =   { 1, 1, 3, 13, 9, 49, 39, 67, 165, 695, 611, 2261, 3425, 6247, 23575, 51833, 106167, 0 };
            const std::uint32_t dim10880JoeKuoD6Init[]   =   { 1, 1, 7, 9, 29, 21, 75, 251, 87, 263, 2035, 1007, 3821, 12719, 8889, 47901, 39037, 0 };
            const std::uint32_t dim10881JoeKuoD6Init[]   =   { 1, 3, 1, 3, 15, 51, 79, 127, 201, 497, 1881, 3841, 1821, 14435, 4933, 6853, 104305, 0 };
            const std::uint32_t dim10882JoeKuoD6Init[]   =   { 1, 1, 5, 11, 23, 47, 33, 109, 481, 585, 333, 2525, 593, 1625, 5787, 23839, 30647, 0 };
            const std::uint32_t dim10883JoeKuoD6Init[]   =   { 1, 1, 5, 1, 17, 3, 7, 43, 113, 873, 1433, 3377, 45, 831, 17015, 21479, 7257, 0 };
            const std::uint32_t dim10884JoeKuoD6Init[]   =   { 1, 1, 1, 1, 13, 21, 59, 159, 279, 871, 53, 3647, 2599, 12417, 25807, 6867, 18251, 0 };
            const std::uint32_t dim10885JoeKuoD6Init[]   =   { 1, 1, 5, 9, 29, 61, 7, 81, 353, 761, 269, 4047, 3051, 8385, 2919, 18875, 15239, 0 };
            const std::uint32_t dim10886JoeKuoD6Init[]   =   { 1, 1, 7, 13, 31, 17, 71, 103, 107, 655, 1263, 849, 1809, 349, 3239, 45381, 117451, 0 };
            const std::uint32_t dim10887JoeKuoD6Init[]   =   { 1, 1, 5, 9, 27, 45, 83, 207, 117, 77, 437, 523, 851, 13595, 12381, 27271, 59951, 0 };
            const std::uint32_t dim10888JoeKuoD6Init[]   =   { 1, 3, 3, 15, 3, 33, 103, 217, 61, 443, 1077, 2887, 1751, 11111, 465, 37051, 89687, 0 };
            const std::uint32_t dim10889JoeKuoD6Init[]   =   { 1, 1, 1, 5, 15, 15, 13, 115, 275, 565, 1257, 1067, 6561, 8143, 2149, 53169, 123637, 0 };
            const std::uint32_t dim10890JoeKuoD6Init[]   =   { 1, 3, 3, 15, 27, 63, 25, 191, 143, 103, 1247, 1053, 2469, 9823, 4437, 18195, 91751, 0 };
            const std::uint32_t dim10891JoeKuoD6Init[]   =   { 1, 1, 7, 11, 1, 63, 31, 103, 249, 861, 983, 335, 35, 4291, 16307, 43669, 68065, 0 };
            const std::uint32_t dim10892JoeKuoD6Init[]   =   { 1, 3, 1, 15, 13, 29, 51, 145, 177, 851, 39, 3531, 4477, 4243, 3301, 64293, 15741, 0 };
            const std::uint32_t dim10893JoeKuoD6Init[]   =   { 1, 1, 7, 3, 29, 45, 5, 85, 185, 191, 1007, 3085, 2177, 14911, 18319, 265, 25435, 0 };
            const std::uint32_t dim10894JoeKuoD6Init[]   =   { 1, 1, 5, 9, 9, 57, 47, 143, 217, 947, 2021, 1835, 4773, 15145, 26519, 46407, 103667, 0 };
            const std::uint32_t dim10895JoeKuoD6Init[]   =   { 1, 3, 1, 11, 1, 7, 51, 75, 207, 757, 89, 1289, 39, 15641, 9477, 28503, 47113, 0 };
            const std::uint32_t dim10896JoeKuoD6Init[]   =   { 1, 3, 1, 11, 9, 19, 21, 197, 429, 121, 813, 3447, 6091, 3167, 5401, 27791, 26499, 0 };
            const std::uint32_t dim10897JoeKuoD6Init[]   =   { 1, 1, 7, 15, 1, 15, 85, 247, 3, 111, 433, 3103, 5049, 7929, 22645, 53247, 53417, 0 };
            const std::uint32_t dim10898JoeKuoD6Init[]   =   { 1, 1, 7, 7, 27, 19, 125, 101, 269, 7, 777, 1289, 1429, 11561, 18043, 3601, 125857, 0 };
            const std::uint32_t dim10899JoeKuoD6Init[]   =   { 1, 1, 1, 13, 11, 9, 127, 231, 239, 435, 1291, 4025, 1049, 15549, 7577, 51147, 38121, 0 };
            const std::uint32_t dim10900JoeKuoD6Init[]   =   { 1, 1, 7, 3, 9, 55, 57, 137, 387, 565, 873, 1417, 5993, 4849, 1731, 51653, 105697, 0 };
            const std::uint32_t dim10901JoeKuoD6Init[]   =   { 1, 1, 7, 9, 7, 47, 115, 119, 325, 881, 1687, 1009, 7007, 12541, 6737, 28471, 7369, 0 };
            const std::uint32_t dim10902JoeKuoD6Init[]   =   { 1, 3, 1, 1, 11, 47, 25, 163, 399, 977, 1777, 727, 5575, 1311, 23843, 2199, 93229, 0 };
            const std::uint32_t dim10903JoeKuoD6Init[]   =   { 1, 1, 7, 5, 13, 19, 53, 123, 439, 585, 1977, 3387, 5305, 1463, 14307, 9519, 537, 0 };
            const std::uint32_t dim10904JoeKuoD6Init[]   =   { 1, 1, 7, 15, 1, 53, 13, 213, 323, 699, 1585, 3499, 2441, 3055, 31263, 63923, 9779, 0 };
            const std::uint32_t dim10905JoeKuoD6Init[]   =   { 1, 1, 5, 5, 21, 43, 123, 43, 475, 521, 1301, 3185, 5627, 7443, 1195, 39485, 113125, 0 };
            const std::uint32_t dim10906JoeKuoD6Init[]   =   { 1, 1, 5, 7, 9, 3, 39, 5, 237, 719, 1743, 1153, 6401, 14701, 5503, 38491, 24123, 0 };
            const std::uint32_t dim10907JoeKuoD6Init[]   =   { 1, 3, 5, 9, 17, 33, 117, 23, 409, 63, 1829, 2587, 3489, 3209, 4775, 40069, 4721, 0 };
            const std::uint32_t dim10908JoeKuoD6Init[]   =   { 1, 3, 3, 5, 21, 63, 95, 231, 25, 167, 1181, 813, 4591, 5227, 21999, 19633, 37547, 0 };
            const std::uint32_t dim10909JoeKuoD6Init[]   =   { 1, 1, 7, 11, 13, 9, 13, 147, 239, 951, 1247, 1199, 7907, 12493, 25371, 1917, 107499, 0 };
            const std::uint32_t dim10910JoeKuoD6Init[]   =   { 1, 1, 5, 15, 3, 49, 31, 103, 189, 561, 1763, 3941, 3525, 3165, 7789, 57729, 92635, 0 };
            const std::uint32_t dim10911JoeKuoD6Init[]   =   { 1, 1, 1, 5, 3, 61, 107, 163, 465, 631, 1519, 169, 4469, 8153, 11039, 247, 37657, 0 };
            const std::uint32_t dim10912JoeKuoD6Init[]   =   { 1, 3, 1, 5, 9, 37, 51, 195, 465, 975, 169, 1077, 995, 2669, 7663, 28997, 25779, 0 };
            const std::uint32_t dim10913JoeKuoD6Init[]   =   { 1, 1, 7, 13, 7, 37, 3, 117, 147, 335, 629, 4077, 5855, 2893, 5629, 55075, 83359, 0 };
            const std::uint32_t dim10914JoeKuoD6Init[]   =   { 1, 1, 5, 9, 9, 25, 53, 63, 315, 287, 1833, 1397, 2395, 5719, 6719, 18003, 101073, 0 };
            const std::uint32_t dim10915JoeKuoD6Init[]   =   { 1, 1, 7, 1, 13, 19, 13, 81, 497, 399, 413, 2411, 3915, 14037, 19735, 4587, 69655, 0 };
            const std::uint32_t dim10916JoeKuoD6Init[]   =   { 1, 3, 1, 7, 5, 61, 101, 209, 299, 729, 1359, 4013, 2057, 8439, 8113, 57417, 8951, 0 };
            const std::uint32_t dim10917JoeKuoD6Init[]   =   { 1, 3, 5, 7, 29, 21, 67, 73, 107, 359, 1655, 3729, 4403, 10467, 28103, 10261, 74651, 0 };
            const std::uint32_t dim10918JoeKuoD6Init[]   =   { 1, 1, 1, 9, 3, 39, 25, 91, 287, 497, 1743, 339, 4739, 1709, 16351, 45385, 64693, 0 };
            const std::uint32_t dim10919JoeKuoD6Init[]   =   { 1, 3, 1, 1, 7, 13, 41, 93, 49, 285, 997, 891, 4353, 4249, 11269, 36935, 71249, 0 };
            const std::uint32_t dim10920JoeKuoD6Init[]   =   { 1, 3, 3, 13, 13, 23, 97, 231, 101, 93, 1183, 201, 6795, 16287, 30707, 20845, 105873, 0 };
            const std::uint32_t dim10921JoeKuoD6Init[]   =   { 1, 1, 1, 9, 7, 57, 123, 167, 451, 245, 1887, 1839, 2967, 2387, 15075, 11877, 629, 0 };
            const std::uint32_t dim10922JoeKuoD6Init[]   =   { 1, 3, 3, 1, 13, 13, 83, 41, 219, 313, 1743, 1265, 4435, 11731, 17625, 64235, 24865, 0 };
            const std::uint32_t dim10923JoeKuoD6Init[]   =   { 1, 3, 1, 9, 13, 17, 109, 235, 387, 581, 887, 1071, 603, 10955, 5001, 8419, 20997, 0 };
            const std::uint32_t dim10924JoeKuoD6Init[]   =   { 1, 3, 1, 5, 31, 55, 1, 219, 27, 623, 1425, 1309, 5409, 9633, 3231, 15029, 22989, 0 };
            const std::uint32_t dim10925JoeKuoD6Init[]   =   { 1, 3, 3, 13, 25, 47, 23, 223, 283, 189, 1665, 3743, 387, 1807, 16919, 8511, 15933, 0 };
            const std::uint32_t dim10926JoeKuoD6Init[]   =   { 1, 1, 1, 1, 13, 11, 81, 59, 423, 1007, 317, 2761, 2617, 9715, 24853, 63585, 77083, 0 };
            const std::uint32_t dim10927JoeKuoD6Init[]   =   { 1, 3, 1, 3, 3, 11, 103, 123, 401, 467, 1159, 2725, 3275, 15513, 2281, 21617, 87211, 0 };
            const std::uint32_t dim10928JoeKuoD6Init[]   =   { 1, 1, 5, 7, 23, 17, 25, 83, 11, 901, 809, 3233, 3929, 8685, 7609, 50949, 104841, 0 };
            const std::uint32_t dim10929JoeKuoD6Init[]   =   { 1, 3, 7, 1, 15, 33, 37, 245, 275, 453, 729, 721, 1589, 5417, 29839, 57315, 67227, 0 };
            const std::uint32_t dim10930JoeKuoD6Init[]   =   { 1, 3, 7, 3, 21, 17, 51, 213, 225, 471, 1201, 931, 1229, 9503, 5507, 4057, 7737, 0 };
            const std::uint32_t dim10931JoeKuoD6Init[]   =   { 1, 3, 1, 11, 29, 55, 19, 193, 9, 151, 597, 1377, 827, 8549, 1293, 10963, 86183, 0 };
            const std::uint32_t dim10932JoeKuoD6Init[]   =   { 1, 3, 3, 15, 17, 23, 89, 47, 195, 333, 2001, 1001, 6715, 9797, 21631, 5723, 88847, 0 };
            const std::uint32_t dim10933JoeKuoD6Init[]   =   { 1, 3, 5, 9, 21, 33, 111, 101, 503, 513, 785, 1947, 1139, 7921, 13189, 34831, 80963, 0 };
            const std::uint32_t dim10934JoeKuoD6Init[]   =   { 1, 3, 3, 13, 9, 61, 35, 39, 451, 485, 661, 1993, 4705, 9477, 32541, 16553, 33167, 0 };
            const std::uint32_t dim10935JoeKuoD6Init[]   =   { 1, 3, 3, 9, 29, 37, 115, 87, 367, 325, 539, 1975, 6769, 1453, 31099, 3335, 16939, 0 };
            const std::uint32_t dim10936JoeKuoD6Init[]   =   { 1, 1, 1, 7, 15, 21, 113, 203, 97, 847, 625, 847, 1819, 1109, 14503, 25319, 100259, 0 };
            const std::uint32_t dim10937JoeKuoD6Init[]   =   { 1, 1, 5, 11, 9, 13, 65, 21, 429, 865, 513, 2183, 3785, 11817, 6283, 23041, 7969, 0 };
            const std::uint32_t dim10938JoeKuoD6Init[]   =   { 1, 1, 5, 13, 1, 41, 109, 43, 91, 211, 1477, 3543, 5217, 3133, 12503, 15523, 12917, 0 };
            const std::uint32_t dim10939JoeKuoD6Init[]   =   { 1, 3, 7, 9, 23, 53, 109, 89, 229, 939, 1211, 2771, 541, 15915, 5411, 47273, 54453, 0 };
            const std::uint32_t dim10940JoeKuoD6Init[]   =   { 1, 1, 1, 3, 3, 45, 31, 63, 99, 347, 17, 523, 441, 12325, 15673, 1887, 15289, 0 };
            const std::uint32_t dim10941JoeKuoD6Init[]   =   { 1, 1, 1, 7, 29, 61, 35, 115, 345, 1011, 5, 595, 465, 3897, 28147, 791, 98757, 0 };
            const std::uint32_t dim10942JoeKuoD6Init[]   =   { 1, 1, 5, 9, 27, 1, 21, 155, 467, 469, 1565, 1439, 5809, 851, 32503, 3025, 97231, 0 };
            const std::uint32_t dim10943JoeKuoD6Init[]   =   { 1, 1, 1, 9, 3, 17, 15, 73, 487, 1011, 63, 2605, 6647, 9385, 4527, 21993, 19783, 0 };
            const std::uint32_t dim10944JoeKuoD6Init[]   =   { 1, 1, 3, 9, 17, 17, 65, 75, 175, 897, 1317, 2593, 1495, 15835, 12025, 57457, 29577, 0 };
            const std::uint32_t dim10945JoeKuoD6Init[]   =   { 1, 1, 1, 13, 7, 1, 13, 145, 491, 427, 375, 1235, 3045, 2991, 26607, 30581, 43377, 0 };
            const std::uint32_t dim10946JoeKuoD6Init[]   =   { 1, 1, 1, 1, 31, 1, 75, 235, 345, 75, 1505, 1401, 6921, 6207, 13729, 21545, 34703, 0 };
            const std::uint32_t dim10947JoeKuoD6Init[]   =   { 1, 3, 7, 9, 31, 35, 53, 233, 85, 385, 2045, 1401, 5365, 827, 13093, 41097, 97381, 0 };
            const std::uint32_t dim10948JoeKuoD6Init[]   =   { 1, 3, 7, 15, 5, 9, 19, 125, 49, 29, 1553, 675, 3947, 4775, 8161, 12321, 55191, 0 };
            const std::uint32_t dim10949JoeKuoD6Init[]   =   { 1, 3, 3, 7, 17, 17, 27, 237, 87, 927, 275, 1965, 4993, 1429, 31613, 38403, 119319, 0 };
            const std::uint32_t dim10950JoeKuoD6Init[]   =   { 1, 3, 7, 13, 25, 61, 87, 133, 37, 725, 697, 371, 7607, 13861, 8015, 63997, 25745, 0 };
            const std::uint32_t dim10951JoeKuoD6Init[]   =   { 1, 1, 5, 3, 1, 29, 115, 53, 355, 533, 1711, 3863, 6983, 4849, 15787, 38933, 100299, 0 };
            const std::uint32_t dim10952JoeKuoD6Init[]   =   { 1, 1, 3, 5, 7, 11, 95, 21, 363, 1005, 425, 3497, 841, 8251, 11933, 47783, 122699, 0 };
            const std::uint32_t dim10953JoeKuoD6Init[]   =   { 1, 1, 1, 11, 15, 41, 23, 159, 191, 433, 919, 3151, 5311, 2061, 11277, 4947, 10549, 0 };
            const std::uint32_t dim10954JoeKuoD6Init[]   =   { 1, 1, 5, 1, 29, 57, 23, 239, 179, 821, 1825, 1745, 4357, 4041, 27517, 8557, 86969, 0 };
            const std::uint32_t dim10955JoeKuoD6Init[]   =   { 1, 3, 1, 13, 3, 45, 91, 21, 221, 203, 683, 1787, 375, 4101, 13555, 43269, 8063, 0 };
            const std::uint32_t dim10956JoeKuoD6Init[]   =   { 1, 1, 5, 15, 17, 61, 95, 95, 285, 597, 1967, 4061, 389, 3813, 6061, 50261, 56035, 0 };
            const std::uint32_t dim10957JoeKuoD6Init[]   =   { 1, 1, 7, 9, 9, 35, 103, 255, 239, 77, 145, 4089, 757, 16151, 29963, 1229, 31895, 0 };
            const std::uint32_t dim10958JoeKuoD6Init[]   =   { 1, 1, 7, 7, 29, 51, 63, 105, 55, 609, 665, 2101, 4605, 7085, 18543, 64221, 102503, 0 };
            const std::uint32_t dim10959JoeKuoD6Init[]   =   { 1, 1, 3, 9, 23, 49, 83, 71, 191, 917, 39, 1013, 4689, 2407, 1733, 31113, 31263, 0 };
            const std::uint32_t dim10960JoeKuoD6Init[]   =   { 1, 1, 5, 11, 31, 51, 17, 223, 325, 829, 541, 3561, 5319, 15397, 12479, 57199, 38611, 0 };
            const std::uint32_t dim10961JoeKuoD6Init[]   =   { 1, 3, 1, 3, 19, 57, 19, 191, 427, 905, 1111, 695, 5447, 4061, 25543, 45699, 113283, 0 };
            const std::uint32_t dim10962JoeKuoD6Init[]   =   { 1, 1, 3, 7, 5, 11, 59, 249, 375, 889, 563, 2757, 5857, 3595, 23183, 1785, 105017, 0 };
            const std::uint32_t dim10963JoeKuoD6Init[]   =   { 1, 3, 5, 7, 11, 55, 95, 167, 27, 823, 903, 2403, 1137, 3209, 6313, 61871, 129865, 0 };
            const std::uint32_t dim10964JoeKuoD6Init[]   =   { 1, 1, 3, 11, 25, 3, 89, 171, 209, 409, 1357, 3825, 5261, 10805, 13493, 3303, 129987, 0 };
            const std::uint32_t dim10965JoeKuoD6Init[]   =   { 1, 1, 5, 1, 23, 21, 3, 207, 471, 375, 1785, 2555, 1613, 16235, 1585, 48221, 10197, 0 };
            const std::uint32_t dim10966JoeKuoD6Init[]   =   { 1, 1, 1, 15, 13, 33, 89, 185, 331, 239, 1401, 789, 2687, 15193, 20911, 18935, 28751, 0 };
            const std::uint32_t dim10967JoeKuoD6Init[]   =   { 1, 1, 1, 13, 27, 19, 111, 139, 385, 531, 1069, 2343, 7405, 10305, 7049, 48215, 77591, 0 };
            const std::uint32_t dim10968JoeKuoD6Init[]   =   { 1, 3, 7, 13, 23, 9, 113, 107, 441, 265, 1617, 63, 7629, 5505, 7059, 47307, 82527, 0 };
            const std::uint32_t dim10969JoeKuoD6Init[]   =   { 1, 3, 1, 9, 27, 27, 35, 233, 189, 517, 1285, 1843, 1569, 14921, 6617, 44337, 46917, 0 };
            const std::uint32_t dim10970JoeKuoD6Init[]   =   { 1, 1, 3, 15, 7, 15, 9, 255, 109, 629, 437, 3601, 6591, 10873, 1765, 46459, 110991, 0 };
            const std::uint32_t dim10971JoeKuoD6Init[]   =   { 1, 1, 5, 15, 17, 13, 115, 97, 401, 979, 1139, 2607, 6537, 5369, 17775, 7657, 57175, 0 };
            const std::uint32_t dim10972JoeKuoD6Init[]   =   { 1, 1, 5, 15, 27, 15, 43, 95, 271, 945, 1205, 3505, 7403, 13203, 27259, 24821, 62921, 0 };
            const std::uint32_t dim10973JoeKuoD6Init[]   =   { 1, 1, 7, 15, 9, 13, 53, 177, 93, 169, 1933, 1101, 4847, 15477, 22107, 13009, 93675, 0 };
            const std::uint32_t dim10974JoeKuoD6Init[]   =   { 1, 3, 1, 3, 13, 57, 121, 229, 353, 449, 769, 1207, 557, 5673, 13129, 29383, 35925, 0 };
            const std::uint32_t dim10975JoeKuoD6Init[]   =   { 1, 3, 3, 1, 31, 33, 5, 87, 461, 873, 795, 2715, 1421, 14723, 17917, 20681, 46103, 0 };
            const std::uint32_t dim10976JoeKuoD6Init[]   =   { 1, 1, 7, 3, 29, 5, 49, 215, 341, 25, 1473, 177, 1443, 14181, 26723, 49143, 73461, 0 };
            const std::uint32_t dim10977JoeKuoD6Init[]   =   { 1, 3, 1, 5, 17, 53, 5, 27, 1, 325, 1335, 2941, 7195, 8179, 26971, 63469, 49357, 0 };
            const std::uint32_t dim10978JoeKuoD6Init[]   =   { 1, 3, 5, 3, 3, 5, 29, 241, 119, 415, 1371, 3201, 2815, 15567, 32521, 18635, 2101, 0 };
            const std::uint32_t dim10979JoeKuoD6Init[]   =   { 1, 3, 1, 3, 7, 13, 127, 157, 271, 403, 187, 3663, 4073, 12613, 1305, 31061, 48361, 0 };
            const std::uint32_t dim10980JoeKuoD6Init[]   =   { 1, 1, 3, 5, 1, 39, 41, 201, 113, 923, 621, 497, 3823, 12543, 27273, 58509, 21613, 0 };
            const std::uint32_t dim10981JoeKuoD6Init[]   =   { 1, 1, 1, 11, 5, 51, 93, 39, 345, 175, 679, 617, 3445, 8591, 4017, 5147, 88847, 0 };
            const std::uint32_t dim10982JoeKuoD6Init[]   =   { 1, 1, 7, 7, 7, 9, 63, 7, 89, 711, 487, 69, 447, 3355, 31929, 34719, 93629, 0 };
            const std::uint32_t dim10983JoeKuoD6Init[]   =   { 1, 3, 1, 3, 27, 11, 51, 11, 471, 889, 1935, 2185, 1277, 3127, 8853, 17839, 40279, 0 };
            const std::uint32_t dim10984JoeKuoD6Init[]   =   { 1, 3, 3, 15, 25, 35, 71, 213, 121, 935, 1601, 537, 5753, 8743, 15243, 59545, 60399, 0 };
            const std::uint32_t dim10985JoeKuoD6Init[]   =   { 1, 1, 3, 15, 31, 41, 51, 205, 123, 215, 305, 3777, 4103, 7275, 21603, 56853, 54575, 0 };
            const std::uint32_t dim10986JoeKuoD6Init[]   =   { 1, 3, 7, 9, 17, 19, 37, 59, 193, 303, 1079, 3627, 6503, 14649, 10283, 64469, 83677, 0 };
            const std::uint32_t dim10987JoeKuoD6Init[]   =   { 1, 3, 1, 5, 11, 3, 115, 139, 213, 307, 721, 1611, 5093, 11817, 32503, 38559, 38449, 0 };
            const std::uint32_t dim10988JoeKuoD6Init[]   =   { 1, 3, 1, 1, 17, 31, 41, 113, 135, 733, 723, 2021, 7397, 15917, 15741, 7295, 69885, 0 };
            const std::uint32_t dim10989JoeKuoD6Init[]   =   { 1, 1, 7, 11, 31, 3, 125, 77, 89, 793, 1441, 1527, 457, 9457, 13581, 62979, 125279, 0 };
            const std::uint32_t dim10990JoeKuoD6Init[]   =   { 1, 1, 1, 5, 9, 17, 19, 115, 43, 395, 183, 2091, 7021, 7555, 20165, 45165, 58925, 0 };
            const std::uint32_t dim10991JoeKuoD6Init[]   =   { 1, 1, 1, 15, 23, 37, 97, 45, 357, 201, 425, 3605, 5305, 10079, 16397, 40635, 15355, 0 };
            const std::uint32_t dim10992JoeKuoD6Init[]   =   { 1, 1, 3, 7, 3, 43, 65, 89, 51, 801, 917, 2835, 5675, 2347, 16587, 19701, 68655, 0 };
            const std::uint32_t dim10993JoeKuoD6Init[]   =   { 1, 3, 7, 13, 11, 59, 93, 155, 53, 435, 165, 3231, 429, 12757, 27033, 14081, 12625, 0 };
            const std::uint32_t dim10994JoeKuoD6Init[]   =   { 1, 3, 1, 15, 15, 33, 121, 157, 271, 295, 901, 1689, 709, 13395, 17773, 14397, 37743, 0 };
            const std::uint32_t dim10995JoeKuoD6Init[]   =   { 1, 1, 1, 3, 7, 17, 125, 113, 223, 603, 425, 3213, 2781, 2921, 15181, 18649, 93493, 0 };
            const std::uint32_t dim10996JoeKuoD6Init[]   =   { 1, 3, 3, 5, 1, 25, 3, 101, 151, 435, 1339, 1207, 7687, 12579, 29331, 4653, 67353, 0 };
            const std::uint32_t dim10997JoeKuoD6Init[]   =   { 1, 1, 7, 1, 29, 53, 101, 61, 31, 633, 1899, 3919, 1879, 3143, 25319, 45809, 77425, 0 };
            const std::uint32_t dim10998JoeKuoD6Init[]   =   { 1, 1, 5, 1, 17, 31, 79, 247, 77, 197, 1693, 313, 2183, 14343, 4511, 26009, 44943, 0 };
            const std::uint32_t dim10999JoeKuoD6Init[]   =   { 1, 1, 7, 5, 31, 29, 119, 251, 345, 867, 271, 165, 6425, 8343, 11251, 28125, 34849, 0 };
            const std::uint32_t dim11000JoeKuoD6Init[]   =   { 1, 3, 1, 1, 13, 35, 9, 103, 365, 675, 1653, 4095, 3123, 8245, 4679, 18951, 88543, 0 };
            const std::uint32_t dim11001JoeKuoD6Init[]   =   { 1, 1, 1, 1, 23, 29, 109, 157, 253, 751, 145, 2077, 4555, 7523, 30099, 37709, 97369, 0 };
            const std::uint32_t dim11002JoeKuoD6Init[]   =   { 1, 3, 3, 11, 5, 1, 51, 11, 203, 963, 1961, 351, 6697, 8137, 25933, 53505, 28531, 0 };
            const std::uint32_t dim11003JoeKuoD6Init[]   =   { 1, 1, 7, 15, 27, 1, 31, 159, 447, 501, 1873, 2845, 875, 1671, 5049, 38901, 32559, 0 };
            const std::uint32_t dim11004JoeKuoD6Init[]   =   { 1, 1, 3, 3, 29, 19, 33, 83, 71, 703, 1861, 3683, 3589, 15339, 21075, 40399, 47853, 0 };
            const std::uint32_t dim11005JoeKuoD6Init[]   =   { 1, 3, 3, 7, 5, 41, 61, 181, 319, 77, 777, 2537, 3887, 2687, 29227, 55217, 55813, 0 };
            const std::uint32_t dim11006JoeKuoD6Init[]   =   { 1, 3, 3, 1, 25, 41, 23, 31, 31, 775, 693, 891, 861, 7613, 9557, 43275, 36311, 0 };
            const std::uint32_t dim11007JoeKuoD6Init[]   =   { 1, 1, 7, 13, 11, 5, 99, 217, 81, 441, 765, 3981, 2921, 9657, 6905, 30657, 18395, 0 };
            const std::uint32_t dim11008JoeKuoD6Init[]   =   { 1, 3, 1, 11, 21, 55, 25, 209, 13, 1021, 1373, 785, 3243, 1541, 12033, 17309, 116517, 0 };
            const std::uint32_t dim11009JoeKuoD6Init[]   =   { 1, 1, 1, 7, 3, 3, 61, 113, 453, 405, 1321, 2327, 3529, 12779, 11707, 55795, 105137, 0 };
            const std::uint32_t dim11010JoeKuoD6Init[]   =   { 1, 3, 1, 13, 15, 53, 17, 189, 197, 459, 1999, 935, 7835, 9563, 31231, 47757, 80807, 0 };
            const std::uint32_t dim11011JoeKuoD6Init[]   =   { 1, 3, 5, 13, 11, 15, 91, 115, 427, 723, 1815, 3527, 5917, 4931, 28297, 12257, 5587, 0 };
            const std::uint32_t dim11012JoeKuoD6Init[]   =   { 1, 1, 5, 9, 31, 5, 77, 201, 373, 143, 581, 1199, 6807, 6059, 3133, 57069, 4895, 0 };
            const std::uint32_t dim11013JoeKuoD6Init[]   =   { 1, 3, 1, 9, 17, 13, 127, 61, 235, 991, 279, 1545, 2875, 8453, 13329, 39763, 66897, 0 };
            const std::uint32_t dim11014JoeKuoD6Init[]   =   { 1, 1, 3, 15, 31, 51, 3, 95, 221, 685, 635, 1747, 177, 9781, 4859, 45345, 37607, 0 };
            const std::uint32_t dim11015JoeKuoD6Init[]   =   { 1, 3, 5, 1, 3, 55, 63, 51, 63, 707, 883, 2985, 3699, 3881, 8159, 41775, 41411, 0 };
            const std::uint32_t dim11016JoeKuoD6Init[]   =   { 1, 1, 1, 11, 3, 41, 69, 181, 413, 33, 525, 1883, 6063, 13787, 1259, 19497, 8119, 0 };
            const std::uint32_t dim11017JoeKuoD6Init[]   =   { 1, 1, 5, 15, 13, 27, 65, 63, 117, 831, 855, 369, 1005, 9069, 16179, 32027, 6527, 0 };
            const std::uint32_t dim11018JoeKuoD6Init[]   =   { 1, 3, 7, 5, 25, 51, 63, 163, 101, 299, 1637, 641, 2077, 9195, 11181, 59783, 109481, 0 };
            const std::uint32_t dim11019JoeKuoD6Init[]   =   { 1, 3, 5, 13, 27, 13, 117, 253, 257, 919, 709, 411, 5525, 1247, 19951, 51423, 34605, 0 };
            const std::uint32_t dim11020JoeKuoD6Init[]   =   { 1, 1, 5, 5, 1, 37, 49, 125, 87, 291, 339, 3235, 1477, 9787, 19637, 22855, 103013, 0 };
            const std::uint32_t dim11021JoeKuoD6Init[]   =   { 1, 3, 7, 15, 25, 17, 77, 23, 303, 739, 1921, 1425, 6451, 9521, 6311, 38551, 123683, 0 };
            const std::uint32_t dim11022JoeKuoD6Init[]   =   { 1, 3, 1, 7, 13, 19, 33, 73, 347, 85, 1693, 3671, 713, 1191, 3285, 6815, 61833, 0 };
            const std::uint32_t dim11023JoeKuoD6Init[]   =   { 1, 1, 3, 3, 13, 53, 81, 177, 305, 967, 551, 1177, 2315, 4899, 5733, 11147, 128895, 0 };
            const std::uint32_t dim11024JoeKuoD6Init[]   =   { 1, 3, 5, 3, 17, 17, 93, 173, 417, 645, 1631, 1817, 6127, 3545, 6127, 22331, 59751, 0 };
            const std::uint32_t dim11025JoeKuoD6Init[]   =   { 1, 1, 5, 11, 7, 53, 61, 117, 133, 141, 283, 3351, 6745, 599, 7221, 50583, 9067, 0 };
            const std::uint32_t dim11026JoeKuoD6Init[]   =   { 1, 3, 7, 3, 29, 45, 71, 177, 97, 897, 589, 3319, 1821, 7207, 25715, 13043, 96695, 0 };
            const std::uint32_t dim11027JoeKuoD6Init[]   =   { 1, 3, 3, 1, 13, 39, 19, 49, 419, 905, 1063, 4023, 145, 1479, 22197, 43883, 45503, 0 };
            const std::uint32_t dim11028JoeKuoD6Init[]   =   { 1, 3, 3, 15, 9, 45, 45, 201, 61, 193, 375, 2439, 2339, 15981, 5197, 6285, 109389, 0 };
            const std::uint32_t dim11029JoeKuoD6Init[]   =   { 1, 1, 7, 13, 29, 51, 93, 223, 509, 1003, 1861, 3715, 2511, 13843, 25297, 1241, 12157, 0 };
            const std::uint32_t dim11030JoeKuoD6Init[]   =   { 1, 3, 5, 15, 19, 17, 95, 243, 251, 485, 1837, 1829, 2081, 15117, 29635, 63861, 100397, 0 };
            const std::uint32_t dim11031JoeKuoD6Init[]   =   { 1, 1, 7, 3, 1, 37, 31, 53, 483, 849, 1197, 3069, 2539, 2529, 12749, 64331, 45757, 0 };
            const std::uint32_t dim11032JoeKuoD6Init[]   =   { 1, 3, 7, 7, 1, 19, 25, 243, 335, 99, 1507, 2155, 6085, 2253, 32439, 16141, 6781, 0 };
            const std::uint32_t dim11033JoeKuoD6Init[]   =   { 1, 3, 7, 15, 9, 13, 35, 63, 371, 373, 1891, 3913, 4577, 15553, 13079, 60251, 71193, 0 };
            const std::uint32_t dim11034JoeKuoD6Init[]   =   { 1, 3, 1, 7, 15, 13, 105, 113, 409, 289, 57, 1095, 791, 15675, 21471, 42851, 29203, 0 };
            const std::uint32_t dim11035JoeKuoD6Init[]   =   { 1, 1, 1, 13, 1, 57, 65, 7, 153, 929, 1325, 229, 3841, 8967, 29889, 49427, 46853, 0 };
            const std::uint32_t dim11036JoeKuoD6Init[]   =   { 1, 1, 3, 11, 29, 1, 79, 111, 479, 931, 1619, 505, 4503, 4055, 18849, 3979, 46091, 0 };
            const std::uint32_t dim11037JoeKuoD6Init[]   =   { 1, 1, 7, 3, 31, 27, 127, 63, 219, 43, 883, 1265, 5733, 9051, 17059, 61625, 93843, 0 };
            const std::uint32_t dim11038JoeKuoD6Init[]   =   { 1, 1, 7, 7, 23, 21, 35, 211, 243, 399, 1225, 1415, 5923, 2143, 25303, 36171, 126349, 0 };
            const std::uint32_t dim11039JoeKuoD6Init[]   =   { 1, 3, 1, 3, 3, 13, 77, 205, 271, 393, 769, 2101, 4045, 6159, 3409, 44065, 102799, 0 };
            const std::uint32_t dim11040JoeKuoD6Init[]   =   { 1, 1, 5, 15, 19, 1, 67, 199, 367, 51, 495, 2051, 3195, 15239, 10525, 45319, 50489, 0 };
            const std::uint32_t dim11041JoeKuoD6Init[]   =   { 1, 1, 1, 9, 3, 19, 105, 147, 417, 399, 373, 1025, 2727, 13779, 30079, 22723, 41551, 0 };
            const std::uint32_t dim11042JoeKuoD6Init[]   =   { 1, 1, 3, 1, 9, 15, 105, 95, 267, 995, 275, 2627, 3883, 10785, 8075, 40591, 54647, 0 };
            const std::uint32_t dim11043JoeKuoD6Init[]   =   { 1, 1, 1, 5, 31, 37, 117, 185, 55, 273, 525, 445, 4221, 2081, 16017, 19859, 3297, 0 };
            const std::uint32_t dim11044JoeKuoD6Init[]   =   { 1, 3, 5, 13, 21, 13, 105, 231, 461, 831, 393, 3253, 1213, 2625, 3393, 36715, 104889, 0 };
            const std::uint32_t dim11045JoeKuoD6Init[]   =   { 1, 3, 5, 15, 1, 17, 103, 129, 257, 1003, 285, 2927, 3967, 53, 5197, 39665, 50751, 0 };
            const std::uint32_t dim11046JoeKuoD6Init[]   =   { 1, 1, 1, 13, 1, 61, 47, 255, 137, 849, 213, 301, 681, 9547, 28209, 32941, 72109, 0 };
            const std::uint32_t dim11047JoeKuoD6Init[]   =   { 1, 1, 7, 11, 31, 15, 81, 117, 327, 289, 1861, 861, 6189, 13425, 18279, 7635, 116969, 0 };
            const std::uint32_t dim11048JoeKuoD6Init[]   =   { 1, 3, 3, 3, 9, 11, 13, 181, 183, 621, 329, 2751, 3989, 6345, 20319, 52267, 79695, 0 };
            const std::uint32_t dim11049JoeKuoD6Init[]   =   { 1, 1, 7, 13, 9, 1, 5, 125, 1, 735, 691, 13, 3961, 2273, 18299, 65221, 20115, 0 };
            const std::uint32_t dim11050JoeKuoD6Init[]   =   { 1, 3, 7, 1, 7, 3, 87, 115, 241, 101, 523, 3019, 7571, 7721, 27409, 49751, 97859, 0 };
            const std::uint32_t dim11051JoeKuoD6Init[]   =   { 1, 3, 5, 11, 9, 5, 33, 59, 299, 191, 307, 2115, 2823, 10187, 10437, 34137, 93217, 0 };
            const std::uint32_t dim11052JoeKuoD6Init[]   =   { 1, 3, 3, 7, 21, 31, 5, 113, 77, 215, 177, 2029, 7241, 4465, 31489, 10165, 19035, 0 };
            const std::uint32_t dim11053JoeKuoD6Init[]   =   { 1, 3, 5, 1, 27, 63, 11, 161, 435, 941, 1593, 1765, 1519, 9111, 12787, 35961, 105263, 0 };
            const std::uint32_t dim11054JoeKuoD6Init[]   =   { 1, 1, 1, 9, 11, 57, 41, 229, 387, 617, 1991, 221, 2857, 4337, 13851, 23185, 111031, 0 };
            const std::uint32_t dim11055JoeKuoD6Init[]   =   { 1, 1, 3, 5, 21, 27, 125, 83, 129, 919, 65, 403, 2981, 10111, 17017, 24829, 12205, 0 };
            const std::uint32_t dim11056JoeKuoD6Init[]   =   { 1, 3, 3, 9, 25, 19, 109, 47, 199, 395, 1909, 2819, 5361, 6629, 7067, 18755, 17921, 0 };
            const std::uint32_t dim11057JoeKuoD6Init[]   =   { 1, 1, 3, 15, 25, 37, 111, 129, 409, 291, 1403, 2785, 3819, 10245, 24647, 64799, 64951, 0 };
            const std::uint32_t dim11058JoeKuoD6Init[]   =   { 1, 3, 5, 11, 1, 7, 105, 223, 427, 661, 1817, 1023, 145, 927, 6507, 13235, 30147, 0 };
            const std::uint32_t dim11059JoeKuoD6Init[]   =   { 1, 3, 5, 13, 7, 15, 65, 125, 121, 113, 923, 2729, 1397, 14247, 8487, 54907, 41921, 0 };
            const std::uint32_t dim11060JoeKuoD6Init[]   =   { 1, 1, 5, 1, 13, 15, 47, 111, 453, 375, 1705, 1539, 4103, 601, 7499, 33287, 123689, 0 };
            const std::uint32_t dim11061JoeKuoD6Init[]   =   { 1, 1, 5, 3, 21, 11, 87, 115, 483, 617, 1593, 2817, 6519, 16203, 361, 34415, 100829, 0 };
            const std::uint32_t dim11062JoeKuoD6Init[]   =   { 1, 3, 7, 15, 23, 25, 41, 193, 473, 517, 1195, 3627, 1089, 13391, 3653, 25637, 5643, 0 };
            const std::uint32_t dim11063JoeKuoD6Init[]   =   { 1, 3, 1, 1, 13, 57, 29, 175, 35, 107, 5, 3641, 1843, 1507, 7591, 39967, 66859, 0 };
            const std::uint32_t dim11064JoeKuoD6Init[]   =   { 1, 1, 3, 13, 1, 39, 31, 11, 493, 123, 523, 843, 133, 7971, 14131, 51927, 97943, 0 };
            const std::uint32_t dim11065JoeKuoD6Init[]   =   { 1, 1, 3, 7, 23, 45, 5, 195, 195, 683, 497, 1215, 5855, 14569, 20441, 29541, 30431, 0 };
            const std::uint32_t dim11066JoeKuoD6Init[]   =   { 1, 3, 1, 11, 31, 39, 127, 187, 187, 17, 817, 907, 4657, 8223, 13305, 36489, 28909, 0 };
            const std::uint32_t dim11067JoeKuoD6Init[]   =   { 1, 1, 7, 13, 9, 1, 59, 27, 449, 887, 39, 191, 803, 2339, 5213, 2611, 93175, 0 };
            const std::uint32_t dim11068JoeKuoD6Init[]   =   { 1, 1, 1, 1, 29, 17, 105, 13, 175, 401, 1145, 297, 6873, 889, 10301, 48993, 49959, 0 };
            const std::uint32_t dim11069JoeKuoD6Init[]   =   { 1, 3, 5, 5, 1, 57, 81, 81, 403, 719, 1887, 2597, 1069, 5219, 29767, 46905, 8025, 0 };
            const std::uint32_t dim11070JoeKuoD6Init[]   =   { 1, 1, 5, 11, 13, 37, 41, 3, 487, 895, 343, 1729, 3777, 8681, 24737, 34179, 15015, 0 };
            const std::uint32_t dim11071JoeKuoD6Init[]   =   { 1, 1, 1, 15, 9, 43, 67, 203, 71, 399, 23, 529, 2375, 15373, 21013, 17389, 93809, 0 };
            const std::uint32_t dim11072JoeKuoD6Init[]   =   { 1, 3, 7, 7, 9, 23, 81, 27, 39, 529, 631, 199, 3555, 953, 4249, 39297, 88107, 0 };
            const std::uint32_t dim11073JoeKuoD6Init[]   =   { 1, 3, 1, 3, 31, 45, 33, 63, 319, 245, 1567, 3359, 2051, 11523, 30177, 20293, 13245, 0 };
            const std::uint32_t dim11074JoeKuoD6Init[]   =   { 1, 1, 1, 13, 9, 61, 39, 127, 453, 1019, 2037, 3541, 6983, 10717, 19587, 8981, 99637, 0 };
            const std::uint32_t dim11075JoeKuoD6Init[]   =   { 1, 3, 5, 9, 15, 7, 55, 79, 93, 303, 1423, 499, 5499, 795, 14553, 16945, 46161, 0 };
            const std::uint32_t dim11076JoeKuoD6Init[]   =   { 1, 1, 7, 5, 21, 21, 27, 201, 147, 461, 363, 267, 2963, 3409, 17835, 40777, 71879, 0 };
            const std::uint32_t dim11077JoeKuoD6Init[]   =   { 1, 1, 7, 9, 23, 63, 115, 243, 103, 119, 2023, 2223, 7989, 1365, 26181, 4631, 88001, 0 };
            const std::uint32_t dim11078JoeKuoD6Init[]   =   { 1, 3, 5, 5, 27, 57, 101, 199, 461, 853, 449, 2733, 2225, 8609, 19461, 15265, 54079, 0 };
            const std::uint32_t dim11079JoeKuoD6Init[]   =   { 1, 3, 3, 15, 29, 59, 115, 105, 145, 391, 303, 901, 5481, 1491, 30441, 22331, 3841, 0 };
            const std::uint32_t dim11080JoeKuoD6Init[]   =   { 1, 1, 3, 1, 27, 45, 11, 167, 73, 181, 253, 1947, 1731, 15269, 16971, 12299, 46439, 0 };
            const std::uint32_t dim11081JoeKuoD6Init[]   =   { 1, 1, 7, 13, 11, 21, 83, 157, 75, 705, 1709, 487, 5029, 9879, 27589, 21601, 50575, 0 };
            const std::uint32_t dim11082JoeKuoD6Init[]   =   { 1, 1, 5, 3, 27, 37, 101, 163, 115, 903, 1137, 3807, 2899, 3407, 27935, 14203, 31009, 0 };
            const std::uint32_t dim11083JoeKuoD6Init[]   =   { 1, 3, 5, 9, 31, 33, 63, 69, 159, 737, 1973, 3661, 6159, 1781, 9239, 12989, 82947, 0 };
            const std::uint32_t dim11084JoeKuoD6Init[]   =   { 1, 3, 5, 9, 15, 33, 41, 89, 183, 933, 1305, 1013, 7245, 16225, 10891, 6641, 61699, 0 };
            const std::uint32_t dim11085JoeKuoD6Init[]   =   { 1, 1, 5, 3, 25, 41, 91, 183, 45, 553, 1817, 3305, 5169, 9051, 24917, 52431, 52505, 0 };
            const std::uint32_t dim11086JoeKuoD6Init[]   =   { 1, 3, 3, 9, 3, 9, 127, 59, 117, 1001, 1255, 3435, 3797, 8507, 28593, 24119, 75569, 0 };
            const std::uint32_t dim11087JoeKuoD6Init[]   =   { 1, 3, 1, 5, 17, 43, 45, 21, 461, 339, 1127, 2213, 7351, 14585, 2001, 32619, 33825, 0 };
            const std::uint32_t dim11088JoeKuoD6Init[]   =   { 1, 1, 5, 11, 3, 37, 61, 83, 101, 707, 861, 3037, 1867, 7747, 16313, 58745, 14387, 0 };
            const std::uint32_t dim11089JoeKuoD6Init[]   =   { 1, 1, 5, 3, 27, 25, 99, 17, 293, 867, 1655, 2301, 2007, 7379, 14487, 18233, 3625, 0 };
            const std::uint32_t dim11090JoeKuoD6Init[]   =   { 1, 1, 7, 13, 25, 29, 21, 133, 207, 119, 423, 1561, 6587, 1221, 27295, 48141, 125473, 0 };
            const std::uint32_t dim11091JoeKuoD6Init[]   =   { 1, 3, 3, 1, 19, 45, 39, 85, 127, 249, 157, 1307, 7343, 6309, 31073, 16909, 93223, 0 };
            const std::uint32_t dim11092JoeKuoD6Init[]   =   { 1, 1, 5, 13, 19, 43, 111, 109, 385, 847, 1071, 1009, 2783, 8471, 5719, 50459, 110507, 0 };
            const std::uint32_t dim11093JoeKuoD6Init[]   =   { 1, 1, 5, 15, 1, 45, 39, 197, 209, 839, 485, 3943, 5939, 11835, 18297, 61217, 85015, 0 };
            const std::uint32_t dim11094JoeKuoD6Init[]   =   { 1, 1, 1, 15, 5, 61, 1, 195, 415, 355, 1593, 151, 8143, 3527, 11633, 44337, 99749, 0 };
            const std::uint32_t dim11095JoeKuoD6Init[]   =   { 1, 1, 5, 13, 11, 11, 117, 109, 91, 663, 1351, 2361, 1409, 9317, 31133, 17577, 123919, 0 };
            const std::uint32_t dim11096JoeKuoD6Init[]   =   { 1, 3, 3, 9, 3, 5, 115, 173, 459, 937, 1581, 781, 1069, 573, 24025, 30721, 116837, 0 };
            const std::uint32_t dim11097JoeKuoD6Init[]   =   { 1, 1, 1, 5, 21, 37, 47, 51, 21, 169, 119, 3285, 2543, 14023, 29179, 13407, 130491, 0 };
            const std::uint32_t dim11098JoeKuoD6Init[]   =   { 1, 3, 5, 5, 25, 27, 41, 147, 485, 79, 737, 699, 6763, 16347, 9265, 52129, 41431, 0 };
            const std::uint32_t dim11099JoeKuoD6Init[]   =   { 1, 1, 1, 3, 5, 33, 115, 187, 311, 717, 1897, 2215, 2639, 4167, 1429, 26359, 52703, 0 };
            const std::uint32_t dim11100JoeKuoD6Init[]   =   { 1, 3, 5, 5, 13, 51, 103, 5, 47, 683, 319, 2969, 7701, 11031, 9257, 16725, 80825, 0 };
            const std::uint32_t dim11101JoeKuoD6Init[]   =   { 1, 3, 1, 11, 31, 47, 17, 205, 11, 411, 523, 4053, 6743, 3095, 3219, 63163, 84547, 0 };
            const std::uint32_t dim11102JoeKuoD6Init[]   =   { 1, 1, 7, 15, 9, 55, 109, 225, 273, 595, 1697, 2059, 21, 11319, 23277, 60613, 4539, 0 };
            const std::uint32_t dim11103JoeKuoD6Init[]   =   { 1, 1, 5, 13, 3, 59, 49, 239, 509, 847, 975, 3361, 5443, 1941, 29277, 56379, 38997, 0 };
            const std::uint32_t dim11104JoeKuoD6Init[]   =   { 1, 3, 1, 7, 15, 5, 49, 19, 235, 437, 1309, 827, 4123, 5839, 22409, 42535, 98041, 0 };
            const std::uint32_t dim11105JoeKuoD6Init[]   =   { 1, 1, 5, 15, 9, 33, 57, 153, 165, 215, 177, 1271, 1861, 15489, 4183, 43701, 114169, 0 };
            const std::uint32_t dim11106JoeKuoD6Init[]   =   { 1, 3, 5, 5, 13, 3, 119, 89, 17, 421, 1205, 835, 4917, 6113, 28991, 26839, 114871, 0 };
            const std::uint32_t dim11107JoeKuoD6Init[]   =   { 1, 3, 5, 1, 7, 49, 49, 159, 205, 601, 1939, 4063, 5975, 11747, 10329, 21103, 16779, 0 };
            const std::uint32_t dim11108JoeKuoD6Init[]   =   { 1, 1, 5, 15, 13, 33, 89, 21, 113, 639, 891, 989, 829, 1435, 11475, 42711, 67049, 0 };
            const std::uint32_t dim11109JoeKuoD6Init[]   =   { 1, 1, 5, 5, 9, 59, 57, 105, 385, 733, 1175, 329, 6809, 7175, 27267, 9941, 14203, 0 };
            const std::uint32_t dim11110JoeKuoD6Init[]   =   { 1, 3, 1, 13, 21, 53, 83, 139, 287, 659, 1991, 3225, 4153, 4325, 16803, 27719, 86263, 0 };
            const std::uint32_t dim11111JoeKuoD6Init[]   =   { 1, 3, 5, 13, 27, 21, 111, 105, 29, 573, 405, 2781, 1737, 12057, 25263, 16903, 45389, 0 };
            const std::uint32_t dim11112JoeKuoD6Init[]   =   { 1, 1, 5, 5, 23, 23, 61, 27, 335, 279, 937, 2509, 4751, 2993, 28069, 30187, 3595, 0 };
            const std::uint32_t dim11113JoeKuoD6Init[]   =   { 1, 1, 5, 7, 29, 37, 117, 71, 221, 875, 1987, 2329, 5953, 15901, 29813, 17419, 4745, 0 };
            const std::uint32_t dim11114JoeKuoD6Init[]   =   { 1, 3, 3, 13, 21, 51, 77, 85, 53, 573, 1129, 3415, 2283, 5221, 29991, 46091, 65843, 0 };
            const std::uint32_t dim11115JoeKuoD6Init[]   =   { 1, 1, 1, 3, 17, 51, 89, 211, 463, 743, 1189, 4083, 1437, 5219, 8373, 15559, 18557, 0 };
            const std::uint32_t dim11116JoeKuoD6Init[]   =   { 1, 1, 5, 3, 29, 27, 1, 207, 285, 739, 505, 1587, 6565, 14195, 4995, 39453, 61023, 0 };
            const std::uint32_t dim11117JoeKuoD6Init[]   =   { 1, 3, 3, 15, 7, 57, 19, 45, 39, 881, 1207, 2829, 3265, 2637, 7843, 62889, 53289, 0 };
            const std::uint32_t dim11118JoeKuoD6Init[]   =   { 1, 1, 1, 11, 31, 21, 73, 245, 87, 457, 1523, 2397, 1157, 8237, 26195, 23149, 106523, 0 };
            const std::uint32_t dim11119JoeKuoD6Init[]   =   { 1, 3, 5, 13, 3, 55, 3, 179, 107, 85, 639, 2711, 6359, 1599, 2325, 59573, 111941, 0 };
            const std::uint32_t dim11120JoeKuoD6Init[]   =   { 1, 1, 1, 13, 17, 61, 45, 253, 45, 149, 1251, 139, 7113, 6503, 27675, 37301, 21713, 0 };
            const std::uint32_t dim11121JoeKuoD6Init[]   =   { 1, 3, 5, 9, 31, 31, 67, 79, 355, 225, 1187, 761, 4927, 5481, 9139, 13399, 35653, 0 };
            const std::uint32_t dim11122JoeKuoD6Init[]   =   { 1, 1, 5, 3, 7, 3, 95, 119, 161, 529, 1443, 1099, 609, 3919, 10935, 37779, 92993, 0 };
            const std::uint32_t dim11123JoeKuoD6Init[]   =   { 1, 1, 7, 9, 13, 21, 13, 7, 165, 173, 989, 2315, 2305, 13115, 6933, 56233, 112113, 0 };
            const std::uint32_t dim11124JoeKuoD6Init[]   =   { 1, 1, 7, 3, 9, 11, 25, 45, 493, 119, 839, 3907, 2273, 14113, 29453, 55181, 667, 0 };
            const std::uint32_t dim11125JoeKuoD6Init[]   =   { 1, 3, 5, 15, 25, 33, 15, 23, 245, 517, 1883, 2865, 1483, 7043, 32615, 12261, 49297, 0 };
            const std::uint32_t dim11126JoeKuoD6Init[]   =   { 1, 3, 7, 9, 31, 35, 89, 103, 245, 441, 1709, 1321, 3743, 3767, 23885, 43587, 18017, 0 };
            const std::uint32_t dim11127JoeKuoD6Init[]   =   { 1, 3, 7, 5, 23, 43, 103, 7, 47, 187, 1257, 3517, 591, 16263, 12047, 16699, 81633, 0 };
            const std::uint32_t dim11128JoeKuoD6Init[]   =   { 1, 1, 5, 15, 5, 5, 79, 11, 327, 719, 37, 2913, 6107, 3463, 25901, 6125, 100647, 0 };
            const std::uint32_t dim11129JoeKuoD6Init[]   =   { 1, 1, 1, 11, 13, 29, 83, 251, 41, 125, 1137, 2627, 4643, 29, 24631, 51435, 98643, 0 };
            const std::uint32_t dim11130JoeKuoD6Init[]   =   { 1, 1, 7, 3, 27, 3, 69, 245, 365, 599, 1575, 2969, 3441, 12327, 18951, 56167, 13861, 0 };
            const std::uint32_t dim11131JoeKuoD6Init[]   =   { 1, 3, 3, 11, 5, 47, 103, 233, 351, 821, 867, 3199, 6133, 4627, 22663, 14775, 83205, 0 };
            const std::uint32_t dim11132JoeKuoD6Init[]   =   { 1, 3, 1, 13, 9, 35, 27, 251, 281, 727, 873, 3713, 5247, 8407, 17739, 57207, 126201, 0 };
            const std::uint32_t dim11133JoeKuoD6Init[]   =   { 1, 1, 7, 11, 11, 35, 53, 115, 93, 663, 625, 565, 3137, 7869, 18845, 49155, 83395, 0 };
            const std::uint32_t dim11134JoeKuoD6Init[]   =   { 1, 3, 3, 5, 21, 13, 99, 151, 319, 9, 1363, 1489, 2545, 1963, 1271, 24815, 43355, 0 };
            const std::uint32_t dim11135JoeKuoD6Init[]   =   { 1, 3, 5, 9, 15, 51, 109, 85, 67, 131, 1947, 181, 7331, 15163, 2255, 33449, 78107, 0 };
            const std::uint32_t dim11136JoeKuoD6Init[]   =   { 1, 1, 7, 9, 27, 61, 1, 163, 309, 739, 453, 1837, 2093, 16021, 8485, 19755, 61335, 0 };
            const std::uint32_t dim11137JoeKuoD6Init[]   =   { 1, 3, 5, 7, 3, 13, 11, 195, 91, 143, 203, 2785, 7319, 7153, 19265, 11597, 63365, 0 };
            const std::uint32_t dim11138JoeKuoD6Init[]   =   { 1, 3, 1, 9, 29, 1, 123, 247, 253, 757, 191, 1699, 6625, 1785, 29199, 29409, 32577, 0 };
            const std::uint32_t dim11139JoeKuoD6Init[]   =   { 1, 3, 5, 11, 23, 21, 31, 35, 383, 587, 65, 1695, 4045, 12305, 12437, 5919, 51465, 0 };
            const std::uint32_t dim11140JoeKuoD6Init[]   =   { 1, 1, 5, 9, 11, 13, 123, 171, 499, 877, 1785, 561, 2547, 1797, 27679, 56305, 93223, 0 };
            const std::uint32_t dim11141JoeKuoD6Init[]   =   { 1, 3, 1, 3, 25, 41, 63, 243, 219, 533, 753, 1903, 3257, 11901, 4777, 28629, 111141, 0 };
            const std::uint32_t dim11142JoeKuoD6Init[]   =   { 1, 3, 3, 5, 31, 47, 1, 253, 283, 995, 1787, 1767, 6599, 11913, 21515, 39259, 117727, 0 };
            const std::uint32_t dim11143JoeKuoD6Init[]   =   { 1, 1, 7, 7, 31, 35, 39, 255, 463, 763, 881, 2583, 347, 14343, 22761, 45821, 119155, 0 };
            const std::uint32_t dim11144JoeKuoD6Init[]   =   { 1, 3, 5, 9, 5, 37, 43, 55, 423, 525, 157, 3593, 2831, 11539, 15675, 11695, 100609, 0 };
            const std::uint32_t dim11145JoeKuoD6Init[]   =   { 1, 3, 3, 5, 11, 9, 27, 57, 409, 201, 1029, 2461, 5823, 2593, 32031, 4203, 55327, 0 };
            const std::uint32_t dim11146JoeKuoD6Init[]   =   { 1, 1, 7, 15, 15, 25, 69, 83, 309, 687, 1607, 819, 7381, 3697, 5289, 33153, 48157, 0 };
            const std::uint32_t dim11147JoeKuoD6Init[]   =   { 1, 1, 5, 5, 31, 57, 41, 195, 201, 59, 2045, 2213, 6695, 3839, 17331, 4981, 26803, 0 };
            const std::uint32_t dim11148JoeKuoD6Init[]   =   { 1, 1, 1, 11, 7, 53, 109, 169, 387, 181, 391, 19, 4159, 299, 29059, 27781, 110193, 0 };
            const std::uint32_t dim11149JoeKuoD6Init[]   =   { 1, 3, 7, 15, 5, 31, 95, 155, 47, 601, 1463, 1799, 8027, 3003, 18067, 24589, 108171, 0 };
            const std::uint32_t dim11150JoeKuoD6Init[]   =   { 1, 3, 3, 7, 11, 61, 21, 121, 117, 149, 1037, 3829, 3581, 15223, 17051, 34539, 37263, 0 };
            const std::uint32_t dim11151JoeKuoD6Init[]   =   { 1, 3, 3, 3, 15, 15, 115, 91, 443, 309, 1073, 2053, 789, 7415, 26253, 62657, 49729, 0 };
            const std::uint32_t dim11152JoeKuoD6Init[]   =   { 1, 3, 5, 5, 31, 19, 23, 221, 19, 105, 1105, 2025, 4209, 7531, 30191, 40777, 46069, 0 };
            const std::uint32_t dim11153JoeKuoD6Init[]   =   { 1, 1, 1, 7, 29, 45, 29, 215, 33, 21, 1147, 1725, 3711, 2759, 12731, 57031, 42361, 0 };
            const std::uint32_t dim11154JoeKuoD6Init[]   =   { 1, 1, 5, 15, 13, 59, 111, 169, 317, 841, 1387, 3513, 3137, 8265, 31789, 26963, 126219, 0 };
            const std::uint32_t dim11155JoeKuoD6Init[]   =   { 1, 1, 3, 1, 23, 21, 13, 113, 71, 177, 345, 3149, 1461, 12945, 3971, 59759, 61839, 0 };
            const std::uint32_t dim11156JoeKuoD6Init[]   =   { 1, 3, 5, 13, 9, 19, 103, 17, 95, 617, 1477, 263, 4259, 12899, 24351, 47431, 11583, 0 };
            const std::uint32_t dim11157JoeKuoD6Init[]   =   { 1, 3, 5, 11, 13, 11, 7, 61, 13, 63, 1687, 631, 381, 5899, 10225, 19657, 37087, 0 };
            const std::uint32_t dim11158JoeKuoD6Init[]   =   { 1, 3, 5, 3, 7, 53, 11, 193, 103, 427, 1097, 299, 2905, 5019, 31803, 28931, 47495, 0 };
            const std::uint32_t dim11159JoeKuoD6Init[]   =   { 1, 3, 3, 11, 21, 31, 125, 249, 233, 941, 975, 2287, 7837, 6481, 11021, 52829, 63023, 0 };
            const std::uint32_t dim11160JoeKuoD6Init[]   =   { 1, 1, 7, 15, 13, 17, 33, 85, 503, 11, 689, 637, 4063, 12223, 1835, 17161, 35213, 0 };
            const std::uint32_t dim11161JoeKuoD6Init[]   =   { 1, 3, 5, 13, 25, 37, 21, 135, 377, 623, 895, 2547, 2757, 9055, 17337, 65457, 24737, 0 };
            const std::uint32_t dim11162JoeKuoD6Init[]   =   { 1, 1, 1, 15, 25, 11, 17, 95, 65, 271, 1791, 841, 1441, 11177, 10087, 63963, 71481, 0 };
            const std::uint32_t dim11163JoeKuoD6Init[]   =   { 1, 3, 5, 11, 31, 1, 37, 107, 109, 459, 1185, 2155, 271, 11775, 23243, 53517, 103669, 0 };
            const std::uint32_t dim11164JoeKuoD6Init[]   =   { 1, 3, 1, 9, 1, 49, 23, 141, 169, 475, 469, 2271, 1379, 13139, 1765, 63625, 14143, 0 };
            const std::uint32_t dim11165JoeKuoD6Init[]   =   { 1, 1, 1, 9, 13, 7, 23, 219, 381, 105, 743, 1745, 2999, 661, 7245, 39653, 99913, 0 };
            const std::uint32_t dim11166JoeKuoD6Init[]   =   { 1, 3, 1, 11, 7, 35, 9, 215, 41, 537, 1569, 1803, 3613, 667, 15089, 39485, 85457, 0 };
            const std::uint32_t dim11167JoeKuoD6Init[]   =   { 1, 1, 1, 15, 9, 49, 75, 235, 119, 97, 273, 209, 2707, 2071, 21943, 60249, 57737, 0 };
            const std::uint32_t dim11168JoeKuoD6Init[]   =   { 1, 1, 5, 15, 31, 19, 33, 49, 279, 461, 143, 3001, 3539, 1015, 27597, 35389, 36483, 0 };
            const std::uint32_t dim11169JoeKuoD6Init[]   =   { 1, 3, 7, 1, 23, 51, 123, 247, 485, 343, 1365, 593, 6465, 12305, 29375, 30641, 43165, 0 };
            const std::uint32_t dim11170JoeKuoD6Init[]   =   { 1, 1, 7, 13, 15, 11, 125, 51, 235, 717, 1427, 3203, 1711, 12607, 8805, 5773, 27467, 0 };
            const std::uint32_t dim11171JoeKuoD6Init[]   =   { 1, 3, 5, 5, 5, 13, 51, 181, 133, 977, 469, 2513, 6819, 12985, 8917, 47317, 47557, 0 };
            const std::uint32_t dim11172JoeKuoD6Init[]   =   { 1, 1, 5, 7, 3, 7, 71, 17, 345, 921, 1621, 2801, 5825, 827, 17711, 33701, 113503, 0 };
            const std::uint32_t dim11173JoeKuoD6Init[]   =   { 1, 3, 1, 1, 17, 7, 99, 83, 73, 349, 567, 713, 5639, 4969, 11549, 35317, 28995, 0 };
            const std::uint32_t dim11174JoeKuoD6Init[]   =   { 1, 3, 3, 9, 11, 53, 123, 227, 391, 775, 1013, 3971, 6183, 14453, 6403, 57063, 7123, 0 };
            const std::uint32_t dim11175JoeKuoD6Init[]   =   { 1, 1, 1, 15, 27, 13, 51, 147, 151, 535, 2017, 3019, 6791, 3931, 12529, 30855, 33243, 0 };
            const std::uint32_t dim11176JoeKuoD6Init[]   =   { 1, 3, 1, 1, 27, 43, 103, 85, 135, 207, 621, 251, 3723, 10893, 29533, 31023, 11043, 0 };
            const std::uint32_t dim11177JoeKuoD6Init[]   =   { 1, 3, 7, 5, 7, 39, 55, 133, 141, 63, 237, 3299, 861, 15123, 11859, 13271, 32893, 0 };
            const std::uint32_t dim11178JoeKuoD6Init[]   =   { 1, 3, 7, 9, 23, 17, 73, 197, 113, 725, 137, 2835, 2877, 6913, 22949, 56071, 67597, 0 };
            const std::uint32_t dim11179JoeKuoD6Init[]   =   { 1, 3, 7, 7, 15, 3, 15, 253, 51, 443, 15, 2549, 7833, 4713, 29211, 22339, 6009, 0 };
            const std::uint32_t dim11180JoeKuoD6Init[]   =   { 1, 3, 5, 15, 19, 55, 35, 59, 281, 995, 1113, 605, 2345, 10009, 14629, 11757, 53241, 0 };
            const std::uint32_t dim11181JoeKuoD6Init[]   =   { 1, 1, 1, 11, 3, 31, 11, 193, 437, 1003, 873, 909, 6513, 2045, 10495, 17387, 25461, 0 };
            const std::uint32_t dim11182JoeKuoD6Init[]   =   { 1, 1, 3, 5, 21, 61, 47, 177, 379, 773, 951, 419, 4455, 10171, 17403, 19045, 87327, 0 };
            const std::uint32_t dim11183JoeKuoD6Init[]   =   { 1, 3, 3, 11, 31, 41, 69, 229, 207, 299, 1743, 1417, 4785, 1327, 26967, 43077, 124319, 0 };
            const std::uint32_t dim11184JoeKuoD6Init[]   =   { 1, 3, 7, 15, 19, 37, 65, 219, 33, 691, 205, 1577, 4775, 8427, 28315, 53559, 100789, 0 };
            const std::uint32_t dim11185JoeKuoD6Init[]   =   { 1, 3, 5, 11, 5, 39, 55, 147, 139, 871, 1563, 3661, 4791, 423, 30007, 1589, 20255, 0 };
            const std::uint32_t dim11186JoeKuoD6Init[]   =   { 1, 1, 3, 15, 5, 61, 89, 83, 261, 519, 1367, 2019, 3799, 8237, 9011, 28995, 1587, 0 };
            const std::uint32_t dim11187JoeKuoD6Init[]   =   { 1, 1, 7, 15, 17, 55, 49, 41, 353, 507, 1565, 3365, 7947, 10391, 1323, 61591, 126305, 0 };
            const std::uint32_t dim11188JoeKuoD6Init[]   =   { 1, 3, 3, 5, 13, 19, 49, 195, 355, 915, 1867, 3513, 1239, 4809, 16925, 22947, 92641, 0 };
            const std::uint32_t dim11189JoeKuoD6Init[]   =   { 1, 1, 7, 3, 31, 51, 45, 241, 55, 195, 1233, 3675, 8077, 4981, 17679, 53025, 77927, 0 };
            const std::uint32_t dim11190JoeKuoD6Init[]   =   { 1, 3, 5, 11, 23, 5, 93, 49, 277, 979, 1093, 3031, 6131, 8085, 19121, 45305, 6705, 0 };
            const std::uint32_t dim11191JoeKuoD6Init[]   =   { 1, 1, 7, 13, 29, 25, 83, 105, 469, 729, 1495, 2607, 2681, 13959, 101, 1913, 2671, 0 };
            const std::uint32_t dim11192JoeKuoD6Init[]   =   { 1, 1, 1, 15, 7, 19, 63, 105, 253, 807, 1889, 2433, 1591, 16267, 11997, 18939, 113313, 0 };
            const std::uint32_t dim11193JoeKuoD6Init[]   =   { 1, 1, 5, 3, 13, 23, 29, 227, 337, 115, 783, 475, 6949, 9485, 1797, 18713, 123981, 0 };
            const std::uint32_t dim11194JoeKuoD6Init[]   =   { 1, 3, 3, 9, 21, 43, 115, 225, 147, 753, 919, 1157, 2901, 14813, 30035, 52553, 30225, 0 };
            const std::uint32_t dim11195JoeKuoD6Init[]   =   { 1, 1, 3, 15, 23, 19, 65, 83, 457, 965, 579, 2133, 291, 2033, 7533, 52995, 92243, 0 };
            const std::uint32_t dim11196JoeKuoD6Init[]   =   { 1, 1, 1, 5, 11, 3, 23, 245, 255, 373, 1119, 3695, 6449, 13497, 817, 32215, 103599, 0 };
            const std::uint32_t dim11197JoeKuoD6Init[]   =   { 1, 3, 1, 5, 5, 19, 57, 53, 145, 441, 1253, 929, 1299, 11491, 29457, 11245, 55717, 0 };
            const std::uint32_t dim11198JoeKuoD6Init[]   =   { 1, 1, 7, 13, 9, 13, 73, 85, 127, 29, 629, 409, 2487, 13079, 3767, 27985, 110139, 0 };
            const std::uint32_t dim11199JoeKuoD6Init[]   =   { 1, 1, 5, 11, 29, 39, 27, 9, 487, 623, 757, 2879, 669, 12521, 23471, 47933, 41721, 0 };
            const std::uint32_t dim11200JoeKuoD6Init[]   =   { 1, 1, 7, 15, 21, 9, 59, 39, 325, 787, 1347, 3039, 7333, 9793, 19337, 41285, 48339, 0 };
            const std::uint32_t dim11201JoeKuoD6Init[]   =   { 1, 3, 3, 11, 11, 21, 127, 45, 173, 981, 483, 3707, 3651, 10545, 16865, 62105, 114847, 0 };
            const std::uint32_t dim11202JoeKuoD6Init[]   =   { 1, 3, 5, 11, 11, 49, 89, 179, 393, 455, 1775, 1903, 8173, 12589, 17281, 57687, 56153, 0 };
            const std::uint32_t dim11203JoeKuoD6Init[]   =   { 1, 3, 1, 3, 7, 7, 59, 223, 255, 559, 375, 2427, 6921, 3709, 24767, 16213, 60373, 0 };
            const std::uint32_t dim11204JoeKuoD6Init[]   =   { 1, 1, 7, 15, 3, 31, 37, 129, 307, 1023, 1807, 519, 6779, 8997, 15383, 4391, 61161, 0 };
            const std::uint32_t dim11205JoeKuoD6Init[]   =   { 1, 1, 1, 1, 9, 25, 53, 27, 263, 459, 1015, 417, 4195, 10931, 20507, 19299, 82371, 0 };
            const std::uint32_t dim11206JoeKuoD6Init[]   =   { 1, 1, 3, 1, 7, 7, 49, 221, 47, 7, 1747, 1533, 3089, 14369, 32609, 64157, 78139, 0 };
            const std::uint32_t dim11207JoeKuoD6Init[]   =   { 1, 3, 7, 5, 5, 13, 101, 231, 227, 19, 1359, 3017, 1405, 3715, 3541, 933, 1117, 0 };
            const std::uint32_t dim11208JoeKuoD6Init[]   =   { 1, 1, 7, 15, 5, 63, 59, 253, 269, 781, 1639, 2247, 1041, 667, 7055, 21221, 84447, 0 };
            const std::uint32_t dim11209JoeKuoD6Init[]   =   { 1, 1, 7, 3, 9, 13, 115, 247, 215, 173, 457, 1125, 5613, 13171, 17847, 26323, 68461, 0 };
            const std::uint32_t dim11210JoeKuoD6Init[]   =   { 1, 3, 5, 9, 15, 19, 95, 213, 425, 567, 1625, 1659, 6961, 10569, 20985, 17255, 89919, 0 };
            const std::uint32_t dim11211JoeKuoD6Init[]   =   { 1, 3, 5, 5, 3, 11, 107, 123, 265, 743, 499, 1885, 6079, 7791, 24953, 30925, 112517, 0 };
            const std::uint32_t dim11212JoeKuoD6Init[]   =   { 1, 1, 5, 15, 29, 27, 103, 195, 119, 873, 1751, 2091, 6623, 7583, 20413, 52367, 16831, 0 };
            const std::uint32_t dim11213JoeKuoD6Init[]   =   { 1, 1, 7, 7, 21, 15, 111, 197, 89, 107, 1317, 2107, 1951, 189, 31663, 63007, 21405, 0 };
            const std::uint32_t dim11214JoeKuoD6Init[]   =   { 1, 3, 1, 13, 27, 15, 93, 251, 209, 93, 1419, 3785, 1899, 3143, 3205, 16309, 121455, 0 };
            const std::uint32_t dim11215JoeKuoD6Init[]   =   { 1, 1, 7, 7, 17, 43, 23, 251, 425, 591, 1101, 1317, 6369, 14209, 10257, 33813, 59557, 0 };
            const std::uint32_t dim11216JoeKuoD6Init[]   =   { 1, 1, 7, 3, 5, 41, 65, 59, 327, 369, 1867, 1045, 4953, 3155, 25679, 8545, 22753, 0 };
            const std::uint32_t dim11217JoeKuoD6Init[]   =   { 1, 1, 5, 3, 5, 25, 117, 97, 369, 721, 1459, 2501, 4899, 5299, 3859, 2509, 127723, 0 };
            const std::uint32_t dim11218JoeKuoD6Init[]   =   { 1, 3, 3, 1, 27, 13, 65, 185, 255, 543, 2013, 2027, 1131, 4067, 1327, 44639, 53275, 0 };
            const std::uint32_t dim11219JoeKuoD6Init[]   =   { 1, 1, 7, 3, 11, 15, 53, 67, 265, 477, 971, 3201, 51, 10599, 23691, 10493, 130347, 0 };
            const std::uint32_t dim11220JoeKuoD6Init[]   =   { 1, 3, 7, 7, 19, 35, 47, 61, 375, 547, 1867, 1147, 7775, 12757, 15101, 63243, 89817, 0 };
            const std::uint32_t dim11221JoeKuoD6Init[]   =   { 1, 1, 5, 3, 5, 21, 57, 59, 145, 901, 835, 1093, 6487, 12727, 20585, 6309, 67803, 0 };
            const std::uint32_t dim11222JoeKuoD6Init[]   =   { 1, 1, 1, 11, 13, 31, 75, 171, 189, 741, 1923, 3503, 4887, 15423, 2499, 39125, 4125, 0 };
            const std::uint32_t dim11223JoeKuoD6Init[]   =   { 1, 3, 7, 1, 29, 31, 103, 207, 383, 631, 1017, 1693, 6251, 9429, 17491, 60959, 68131, 0 };
            const std::uint32_t dim11224JoeKuoD6Init[]   =   { 1, 1, 1, 1, 19, 45, 127, 105, 451, 287, 657, 3521, 2021, 15793, 8993, 34837, 65441, 0 };
            const std::uint32_t dim11225JoeKuoD6Init[]   =   { 1, 1, 7, 9, 17, 15, 13, 189, 255, 753, 1779, 3047, 1179, 13201, 28249, 5909, 35775, 0 };
            const std::uint32_t dim11226JoeKuoD6Init[]   =   { 1, 3, 3, 3, 5, 11, 125, 207, 375, 375, 135, 2939, 1141, 12211, 727, 16137, 52253, 0 };
            const std::uint32_t dim11227JoeKuoD6Init[]   =   { 1, 3, 7, 9, 29, 3, 83, 221, 281, 299, 667, 3435, 589, 8039, 7991, 24289, 13079, 0 };
            const std::uint32_t dim11228JoeKuoD6Init[]   =   { 1, 3, 5, 13, 9, 11, 11, 99, 337, 155, 233, 2497, 3385, 15045, 5783, 40915, 19201, 0 };
            const std::uint32_t dim11229JoeKuoD6Init[]   =   { 1, 1, 7, 5, 5, 23, 25, 223, 341, 149, 505, 893, 4933, 14899, 29899, 207, 125359, 0 };
            const std::uint32_t dim11230JoeKuoD6Init[]   =   { 1, 3, 3, 15, 3, 5, 43, 165, 21, 993, 1091, 3849, 6005, 1905, 7199, 13495, 76915, 0 };
            const std::uint32_t dim11231JoeKuoD6Init[]   =   { 1, 1, 1, 15, 1, 19, 55, 217, 179, 431, 935, 2219, 8135, 15071, 17437, 43271, 115963, 0 };
            const std::uint32_t dim11232JoeKuoD6Init[]   =   { 1, 1, 7, 15, 7, 61, 45, 157, 441, 107, 1955, 2877, 5285, 12157, 21783, 60999, 102949, 0 };
            const std::uint32_t dim11233JoeKuoD6Init[]   =   { 1, 1, 1, 3, 9, 29, 41, 75, 81, 73, 1859, 2923, 3009, 10847, 30257, 44527, 21933, 0 };
            const std::uint32_t dim11234JoeKuoD6Init[]   =   { 1, 1, 3, 3, 29, 29, 103, 3, 401, 197, 237, 3727, 7919, 13669, 26869, 64987, 1581, 0 };
            const std::uint32_t dim11235JoeKuoD6Init[]   =   { 1, 1, 5, 13, 13, 47, 99, 209, 45, 745, 1239, 663, 5535, 3777, 10479, 15327, 1441, 0 };
            const std::uint32_t dim11236JoeKuoD6Init[]   =   { 1, 3, 1, 9, 1, 49, 31, 231, 15, 1001, 773, 2113, 1957, 15271, 25355, 7461, 33089, 0 };
            const std::uint32_t dim11237JoeKuoD6Init[]   =   { 1, 1, 1, 5, 13, 31, 123, 123, 439, 373, 1817, 2555, 7905, 3151, 2311, 62083, 45535, 0 };
            const std::uint32_t dim11238JoeKuoD6Init[]   =   { 1, 3, 1, 3, 31, 37, 83, 117, 177, 483, 1285, 1725, 821, 2115, 12893, 54301, 36491, 0 };
            const std::uint32_t dim11239JoeKuoD6Init[]   =   { 1, 3, 3, 3, 9, 13, 87, 7, 467, 287, 1173, 2739, 3293, 883, 9123, 30799, 110221, 0 };
            const std::uint32_t dim11240JoeKuoD6Init[]   =   { 1, 3, 1, 15, 3, 5, 119, 235, 393, 789, 67, 1193, 1613, 8607, 17371, 16723, 103747, 0 };
            const std::uint32_t dim11241JoeKuoD6Init[]   =   { 1, 3, 1, 13, 13, 47, 61, 51, 447, 1, 1221, 1619, 3785, 5851, 10557, 51181, 6535, 0 };
            const std::uint32_t dim11242JoeKuoD6Init[]   =   { 1, 3, 5, 11, 1, 1, 85, 119, 195, 177, 805, 1161, 4851, 15765, 24405, 41757, 110081, 0 };
            const std::uint32_t dim11243JoeKuoD6Init[]   =   { 1, 1, 7, 1, 17, 21, 89, 13, 59, 169, 1847, 2401, 6243, 2841, 6153, 16039, 47407, 0 };
            const std::uint32_t dim11244JoeKuoD6Init[]   =   { 1, 1, 3, 15, 21, 53, 103, 187, 143, 897, 65, 3677, 213, 4027, 22365, 53703, 82951, 0 };
            const std::uint32_t dim11245JoeKuoD6Init[]   =   { 1, 3, 5, 5, 25, 5, 39, 49, 55, 71, 825, 2123, 2345, 5683, 18027, 29897, 53023, 0 };
            const std::uint32_t dim11246JoeKuoD6Init[]   =   { 1, 1, 3, 5, 13, 55, 27, 77, 327, 429, 1219, 2103, 7095, 13461, 31027, 15383, 98485, 0 };
            const std::uint32_t dim11247JoeKuoD6Init[]   =   { 1, 3, 1, 3, 9, 41, 33, 241, 487, 229, 1743, 951, 2319, 15595, 3213, 5959, 90721, 0 };
            const std::uint32_t dim11248JoeKuoD6Init[]   =   { 1, 1, 7, 1, 29, 45, 45, 163, 123, 227, 305, 1577, 5465, 5639, 14507, 65155, 71425, 0 };
            const std::uint32_t dim11249JoeKuoD6Init[]   =   { 1, 1, 5, 1, 3, 5, 33, 15, 203, 141, 465, 3509, 6653, 14193, 7073, 22525, 22951, 0 };
            const std::uint32_t dim11250JoeKuoD6Init[]   =   { 1, 1, 7, 3, 27, 39, 3, 27, 75, 821, 1329, 3655, 4715, 7659, 31957, 60219, 79123, 0 };
            const std::uint32_t dim11251JoeKuoD6Init[]   =   { 1, 3, 5, 13, 29, 45, 111, 19, 207, 387, 87, 3731, 7427, 13351, 9497, 34285, 25623, 0 };
            const std::uint32_t dim11252JoeKuoD6Init[]   =   { 1, 1, 3, 11, 19, 39, 79, 219, 97, 125, 947, 1397, 3645, 1021, 9403, 38695, 54985, 0 };
            const std::uint32_t dim11253JoeKuoD6Init[]   =   { 1, 3, 3, 7, 3, 3, 45, 93, 65, 289, 1843, 1599, 897, 16159, 23485, 24699, 43123, 0 };
            const std::uint32_t dim11254JoeKuoD6Init[]   =   { 1, 3, 5, 3, 15, 1, 81, 219, 299, 429, 1115, 1763, 6381, 869, 7817, 143, 23583, 0 };
            const std::uint32_t dim11255JoeKuoD6Init[]   =   { 1, 1, 3, 5, 1, 35, 95, 147, 425, 1011, 1039, 2875, 3089, 3685, 9995, 13279, 60923, 0 };
            const std::uint32_t dim11256JoeKuoD6Init[]   =   { 1, 1, 5, 7, 5, 59, 105, 241, 151, 307, 735, 1541, 3115, 12331, 19535, 56965, 127015, 0 };
            const std::uint32_t dim11257JoeKuoD6Init[]   =   { 1, 3, 5, 7, 5, 33, 83, 179, 65, 397, 787, 3425, 1305, 10713, 6973, 9007, 112081, 0 };
            const std::uint32_t dim11258JoeKuoD6Init[]   =   { 1, 3, 7, 13, 29, 11, 37, 31, 271, 501, 897, 1383, 5333, 13627, 22091, 38421, 94575, 0 };
            const std::uint32_t dim11259JoeKuoD6Init[]   =   { 1, 3, 1, 1, 9, 61, 87, 115, 13, 79, 391, 2385, 7157, 3369, 26035, 883, 34705, 0 };
            const std::uint32_t dim11260JoeKuoD6Init[]   =   { 1, 1, 3, 9, 21, 29, 15, 165, 53, 719, 1509, 1295, 4437, 8229, 17961, 55297, 62635, 0 };
            const std::uint32_t dim11261JoeKuoD6Init[]   =   { 1, 1, 7, 5, 27, 21, 23, 141, 341, 423, 9, 2693, 5555, 5797, 13179, 1107, 33489, 0 };
            const std::uint32_t dim11262JoeKuoD6Init[]   =   { 1, 3, 1, 13, 27, 33, 101, 29, 379, 119, 1259, 861, 6843, 69, 3253, 61977, 80061, 0 };
            const std::uint32_t dim11263JoeKuoD6Init[]   =   { 1, 1, 3, 11, 1, 37, 35, 43, 105, 655, 221, 873, 91, 9095, 8999, 44033, 24807, 0 };
            const std::uint32_t dim11264JoeKuoD6Init[]   =   { 1, 3, 3, 7, 29, 15, 23, 227, 399, 305, 2007, 747, 2717, 14767, 6515, 40617, 7873, 0 };
            const std::uint32_t dim11265JoeKuoD6Init[]   =   { 1, 1, 5, 15, 21, 43, 39, 7, 261, 421, 505, 1433, 1155, 5621, 2337, 54027, 54039, 0 };
            const std::uint32_t dim11266JoeKuoD6Init[]   =   { 1, 1, 1, 9, 15, 39, 49, 185, 503, 895, 1321, 375, 4245, 4929, 9637, 50561, 65733, 0 };
            const std::uint32_t dim11267JoeKuoD6Init[]   =   { 1, 1, 5, 15, 7, 29, 27, 155, 423, 631, 1295, 973, 4227, 2637, 8479, 29527, 70505, 0 };
            const std::uint32_t dim11268JoeKuoD6Init[]   =   { 1, 3, 1, 3, 31, 33, 13, 67, 195, 335, 1577, 3715, 559, 7251, 7215, 46443, 125359, 0 };
            const std::uint32_t dim11269JoeKuoD6Init[]   =   { 1, 3, 1, 9, 17, 37, 15, 119, 79, 851, 911, 3549, 99, 9221, 29897, 63489, 34937, 0 };
            const std::uint32_t dim11270JoeKuoD6Init[]   =   { 1, 3, 5, 9, 31, 11, 125, 1, 265, 467, 835, 2997, 2401, 9615, 19397, 50947, 29963, 0 };
            const std::uint32_t dim11271JoeKuoD6Init[]   =   { 1, 1, 5, 3, 11, 21, 63, 15, 471, 763, 1963, 2815, 4419, 11457, 7151, 27009, 124847, 0 };
            const std::uint32_t dim11272JoeKuoD6Init[]   =   { 1, 1, 7, 3, 19, 9, 97, 59, 375, 109, 519, 305, 2787, 3001, 14199, 27415, 35403, 0 };
            const std::uint32_t dim11273JoeKuoD6Init[]   =   { 1, 1, 1, 3, 13, 47, 3, 93, 307, 979, 419, 2817, 3741, 305, 1813, 34549, 116959, 0 };
            const std::uint32_t dim11274JoeKuoD6Init[]   =   { 1, 3, 5, 13, 13, 19, 35, 231, 493, 973, 895, 1583, 1843, 9057, 27705, 32333, 130347, 0 };
            const std::uint32_t dim11275JoeKuoD6Init[]   =   { 1, 1, 1, 13, 31, 35, 81, 11, 363, 229, 1865, 2849, 7805, 877, 3965, 45337, 33239, 0 };
            const std::uint32_t dim11276JoeKuoD6Init[]   =   { 1, 3, 5, 1, 15, 3, 125, 93, 191, 405, 1359, 929, 3085, 7907, 7777, 7815, 103717, 0 };
            const std::uint32_t dim11277JoeKuoD6Init[]   =   { 1, 1, 3, 7, 15, 33, 61, 235, 283, 141, 817, 1611, 665, 13113, 4197, 45831, 44505, 0 };
            const std::uint32_t dim11278JoeKuoD6Init[]   =   { 1, 1, 5, 5, 25, 3, 63, 159, 223, 531, 1147, 2323, 2715, 10319, 32203, 23943, 95407, 0 };
            const std::uint32_t dim11279JoeKuoD6Init[]   =   { 1, 3, 3, 3, 3, 33, 37, 99, 317, 811, 515, 339, 6527, 11149, 13071, 7177, 1549, 0 };
            const std::uint32_t dim11280JoeKuoD6Init[]   =   { 1, 3, 1, 11, 31, 53, 9, 17, 297, 259, 1235, 53, 7065, 1721, 8191, 21663, 13393, 0 };
            const std::uint32_t dim11281JoeKuoD6Init[]   =   { 1, 3, 7, 7, 29, 41, 127, 179, 113, 191, 783, 861, 6509, 5199, 3369, 18327, 30647, 0 };
            const std::uint32_t dim11282JoeKuoD6Init[]   =   { 1, 3, 1, 7, 23, 41, 49, 155, 135, 513, 1127, 1443, 8081, 2553, 10389, 35459, 122513, 0 };
            const std::uint32_t dim11283JoeKuoD6Init[]   =   { 1, 1, 7, 3, 25, 3, 117, 125, 283, 165, 1409, 1587, 7915, 12899, 12239, 48161, 7385, 0 };
            const std::uint32_t dim11284JoeKuoD6Init[]   =   { 1, 3, 7, 3, 23, 19, 29, 47, 7, 723, 455, 4013, 2739, 12303, 29883, 51485, 1571, 0 };
            const std::uint32_t dim11285JoeKuoD6Init[]   =   { 1, 1, 1, 11, 1, 31, 111, 199, 207, 209, 1163, 2865, 5335, 2647, 9125, 6737, 99881, 0 };
            const std::uint32_t dim11286JoeKuoD6Init[]   =   { 1, 3, 1, 11, 31, 19, 59, 153, 65, 133, 1399, 2709, 905, 3257, 13603, 46299, 15139, 0 };
            const std::uint32_t dim11287JoeKuoD6Init[]   =   { 1, 3, 1, 1, 23, 19, 123, 115, 59, 667, 333, 2461, 1843, 16049, 12353, 17297, 107779, 0 };
            const std::uint32_t dim11288JoeKuoD6Init[]   =   { 1, 1, 5, 1, 5, 29, 91, 241, 97, 557, 1701, 2441, 2995, 13103, 9261, 55833, 843, 0 };
            const std::uint32_t dim11289JoeKuoD6Init[]   =   { 1, 1, 1, 5, 15, 19, 23, 189, 69, 91, 427, 3149, 5199, 13073, 32273, 41503, 98749, 0 };
            const std::uint32_t dim11290JoeKuoD6Init[]   =   { 1, 3, 5, 11, 19, 3, 71, 125, 307, 241, 861, 681, 5657, 5189, 7555, 2037, 72921, 0 };
            const std::uint32_t dim11291JoeKuoD6Init[]   =   { 1, 1, 5, 5, 29, 61, 93, 61, 421, 685, 883, 1559, 5875, 10561, 11761, 18879, 31577, 0 };
            const std::uint32_t dim11292JoeKuoD6Init[]   =   { 1, 3, 7, 15, 9, 29, 41, 241, 365, 941, 1087, 3743, 6781, 9467, 1409, 20605, 2361, 0 };
            const std::uint32_t dim11293JoeKuoD6Init[]   =   { 1, 1, 5, 13, 25, 29, 7, 21, 41, 621, 1751, 3731, 2667, 8613, 20999, 3851, 39677, 0 };
            const std::uint32_t dim11294JoeKuoD6Init[]   =   { 1, 1, 7, 5, 17, 23, 25, 43, 401, 749, 975, 91, 5277, 2711, 19847, 41419, 11851, 0 };
            const std::uint32_t dim11295JoeKuoD6Init[]   =   { 1, 1, 7, 9, 13, 37, 113, 89, 435, 749, 1553, 1853, 7709, 5449, 25055, 45207, 2269, 0 };
            const std::uint32_t dim11296JoeKuoD6Init[]   =   { 1, 3, 1, 11, 3, 59, 79, 13, 35, 901, 165, 907, 7579, 12739, 24679, 54163, 61059, 0 };
            const std::uint32_t dim11297JoeKuoD6Init[]   =   { 1, 1, 5, 7, 9, 47, 101, 61, 25, 461, 1737, 2825, 4439, 5363, 28433, 61979, 120401, 0 };
            const std::uint32_t dim11298JoeKuoD6Init[]   =   { 1, 3, 3, 3, 1, 55, 103, 1, 449, 473, 375, 2609, 4933, 3411, 19663, 6067, 61129, 0 };
            const std::uint32_t dim11299JoeKuoD6Init[]   =   { 1, 1, 3, 9, 27, 29, 53, 151, 391, 507, 425, 3469, 6605, 5783, 31747, 37677, 116037, 0 };
            const std::uint32_t dim11300JoeKuoD6Init[]   =   { 1, 1, 1, 5, 5, 43, 61, 67, 319, 553, 1163, 3095, 4447, 7505, 15617, 26167, 11145, 0 };
            const std::uint32_t dim11301JoeKuoD6Init[]   =   { 1, 1, 5, 7, 3, 3, 9, 161, 155, 869, 337, 3693, 6847, 8449, 15077, 54769, 123335, 0 };
            const std::uint32_t dim11302JoeKuoD6Init[]   =   { 1, 3, 3, 7, 11, 19, 17, 71, 105, 649, 323, 3033, 1695, 15973, 6361, 3163, 17669, 0 };
            const std::uint32_t dim11303JoeKuoD6Init[]   =   { 1, 3, 7, 13, 13, 9, 3, 251, 149, 513, 637, 2211, 6397, 1741, 8547, 3165, 38241, 0 };
            const std::uint32_t dim11304JoeKuoD6Init[]   =   { 1, 1, 5, 5, 1, 57, 73, 35, 287, 347, 221, 3261, 7693, 5443, 6175, 18181, 23733, 0 };
            const std::uint32_t dim11305JoeKuoD6Init[]   =   { 1, 3, 7, 5, 5, 19, 1, 167, 5, 825, 815, 1369, 7657, 6169, 9583, 34761, 81003, 0 };
            const std::uint32_t dim11306JoeKuoD6Init[]   =   { 1, 3, 3, 5, 15, 17, 23, 157, 475, 297, 1495, 811, 8135, 11453, 9683, 55505, 84361, 0 };
            const std::uint32_t dim11307JoeKuoD6Init[]   =   { 1, 1, 1, 11, 1, 63, 59, 189, 205, 1023, 1065, 1095, 2293, 14629, 29399, 2925, 28327, 0 };
            const std::uint32_t dim11308JoeKuoD6Init[]   =   { 1, 3, 1, 3, 31, 33, 85, 183, 383, 731, 1223, 3353, 3703, 5655, 31265, 12249, 22127, 0 };
            const std::uint32_t dim11309JoeKuoD6Init[]   =   { 1, 3, 5, 7, 7, 29, 61, 3, 375, 95, 1815, 4065, 6287, 3797, 32397, 50581, 123371, 0 };
            const std::uint32_t dim11310JoeKuoD6Init[]   =   { 1, 3, 1, 9, 13, 37, 57, 139, 43, 561, 425, 3603, 1167, 10281, 31825, 32673, 106169, 0 };
            const std::uint32_t dim11311JoeKuoD6Init[]   =   { 1, 3, 5, 3, 15, 41, 29, 223, 79, 851, 1741, 2241, 5659, 9773, 18369, 37239, 14831, 0 };
            const std::uint32_t dim11312JoeKuoD6Init[]   =   { 1, 3, 1, 1, 7, 11, 83, 63, 51, 521, 1911, 475, 5207, 3219, 10257, 40461, 9087, 0 };
            const std::uint32_t dim11313JoeKuoD6Init[]   =   { 1, 3, 5, 7, 23, 17, 97, 195, 5, 451, 1971, 1881, 921, 8729, 3443, 64529, 67747, 0 };
            const std::uint32_t dim11314JoeKuoD6Init[]   =   { 1, 1, 3, 9, 21, 63, 45, 181, 429, 605, 169, 3493, 2381, 2887, 19515, 53151, 60147, 0 };
            const std::uint32_t dim11315JoeKuoD6Init[]   =   { 1, 3, 3, 7, 15, 11, 117, 161, 333, 139, 587, 2331, 3175, 12093, 12649, 52381, 107117, 0 };
            const std::uint32_t dim11316JoeKuoD6Init[]   =   { 1, 1, 5, 15, 23, 57, 19, 57, 507, 461, 799, 611, 1589, 10909, 7649, 17817, 24677, 0 };
            const std::uint32_t dim11317JoeKuoD6Init[]   =   { 1, 1, 3, 15, 1, 61, 9, 201, 401, 387, 527, 2855, 2339, 3813, 11825, 14273, 73745, 0 };
            const std::uint32_t dim11318JoeKuoD6Init[]   =   { 1, 3, 1, 5, 1, 37, 27, 105, 475, 335, 1169, 3233, 3225, 12861, 10133, 36673, 55025, 0 };
            const std::uint32_t dim11319JoeKuoD6Init[]   =   { 1, 1, 1, 9, 27, 53, 55, 197, 229, 5, 93, 1157, 7929, 9745, 5295, 15359, 75567, 0 };
            const std::uint32_t dim11320JoeKuoD6Init[]   =   { 1, 1, 7, 5, 11, 3, 109, 81, 457, 159, 1899, 557, 1067, 295, 2661, 1145, 8745, 0 };
            const std::uint32_t dim11321JoeKuoD6Init[]   =   { 1, 1, 1, 15, 31, 29, 77, 171, 411, 425, 1041, 2791, 2567, 5357, 21871, 27689, 103485, 0 };
            const std::uint32_t dim11322JoeKuoD6Init[]   =   { 1, 3, 5, 11, 19, 47, 23, 97, 405, 667, 2045, 2951, 2063, 7775, 20629, 34283, 26925, 0 };
            const std::uint32_t dim11323JoeKuoD6Init[]   =   { 1, 3, 5, 7, 5, 51, 125, 67, 165, 145, 733, 1649, 5787, 4333, 24355, 33397, 101001, 0 };
            const std::uint32_t dim11324JoeKuoD6Init[]   =   { 1, 3, 7, 11, 13, 7, 117, 147, 449, 201, 953, 553, 1839, 6903, 10417, 42751, 36823, 0 };
            const std::uint32_t dim11325JoeKuoD6Init[]   =   { 1, 1, 3, 5, 3, 21, 109, 35, 95, 953, 211, 2849, 5681, 16287, 16553, 30345, 69729, 0 };
            const std::uint32_t dim11326JoeKuoD6Init[]   =   { 1, 3, 7, 5, 25, 37, 21, 143, 317, 621, 1417, 283, 3801, 15375, 3799, 13345, 59727, 0 };
            const std::uint32_t dim11327JoeKuoD6Init[]   =   { 1, 3, 3, 9, 3, 37, 113, 127, 123, 979, 1225, 2585, 2055, 2571, 16727, 38863, 74347, 0 };
            const std::uint32_t dim11328JoeKuoD6Init[]   =   { 1, 3, 3, 3, 23, 13, 49, 111, 277, 143, 1171, 605, 91, 13693, 1971, 18209, 114203, 0 };
            const std::uint32_t dim11329JoeKuoD6Init[]   =   { 1, 1, 1, 9, 27, 33, 73, 9, 93, 343, 55, 3045, 2029, 3665, 28483, 6601, 72085, 0 };
            const std::uint32_t dim11330JoeKuoD6Init[]   =   { 1, 1, 1, 15, 17, 55, 87, 231, 103, 1005, 1451, 3617, 7477, 2045, 10683, 39053, 1289, 0 };
            const std::uint32_t dim11331JoeKuoD6Init[]   =   { 1, 3, 7, 7, 25, 55, 39, 89, 489, 609, 1969, 159, 7485, 10713, 28371, 14935, 95347, 0 };
            const std::uint32_t dim11332JoeKuoD6Init[]   =   { 1, 3, 3, 13, 25, 9, 83, 167, 25, 135, 2017, 3313, 1493, 7799, 22479, 49471, 20149, 0 };
            const std::uint32_t dim11333JoeKuoD6Init[]   =   { 1, 1, 1, 15, 25, 13, 63, 117, 97, 449, 1331, 229, 6027, 1023, 26705, 15283, 60385, 0 };
            const std::uint32_t dim11334JoeKuoD6Init[]   =   { 1, 1, 7, 5, 5, 37, 3, 79, 337, 861, 1549, 915, 7303, 1503, 19245, 60721, 45313, 0 };
            const std::uint32_t dim11335JoeKuoD6Init[]   =   { 1, 3, 7, 15, 19, 1, 11, 39, 505, 757, 1627, 2137, 3209, 7651, 31291, 45913, 26851, 0 };
            const std::uint32_t dim11336JoeKuoD6Init[]   =   { 1, 3, 1, 5, 25, 21, 85, 233, 171, 269, 367, 1651, 3961, 2487, 1977, 7027, 2725, 0 };
            const std::uint32_t dim11337JoeKuoD6Init[]   =   { 1, 1, 5, 15, 13, 23, 81, 145, 201, 323, 425, 2785, 1149, 12617, 11451, 23205, 117691, 0 };
            const std::uint32_t dim11338JoeKuoD6Init[]   =   { 1, 1, 7, 11, 29, 37, 69, 141, 15, 773, 1299, 2147, 8129, 12227, 27811, 58701, 103637, 0 };
            const std::uint32_t dim11339JoeKuoD6Init[]   =   { 1, 3, 5, 13, 3, 33, 29, 227, 261, 221, 823, 1399, 5107, 2423, 23809, 42175, 28207, 0 };
            const std::uint32_t dim11340JoeKuoD6Init[]   =   { 1, 3, 1, 15, 21, 1, 121, 255, 259, 441, 45, 1899, 2489, 4155, 18317, 52695, 607, 0 };
            const std::uint32_t dim11341JoeKuoD6Init[]   =   { 1, 3, 5, 9, 25, 43, 115, 111, 329, 997, 753, 1513, 6949, 3197, 28275, 48855, 25089, 0 };
            const std::uint32_t dim11342JoeKuoD6Init[]   =   { 1, 3, 3, 3, 25, 9, 21, 213, 111, 173, 913, 1465, 4437, 9725, 1455, 53517, 81843, 0 };
            const std::uint32_t dim11343JoeKuoD6Init[]   =   { 1, 3, 5, 5, 5, 25, 3, 159, 19, 203, 181, 3447, 6395, 2145, 11289, 16797, 59567, 0 };
            const std::uint32_t dim11344JoeKuoD6Init[]   =   { 1, 3, 3, 1, 29, 25, 43, 115, 257, 833, 379, 941, 4389, 5795, 12593, 2471, 127149, 0 };
            const std::uint32_t dim11345JoeKuoD6Init[]   =   { 1, 3, 1, 9, 3, 15, 81, 141, 155, 515, 1677, 2569, 1105, 15653, 24143, 3439, 17317, 0 };
            const std::uint32_t dim11346JoeKuoD6Init[]   =   { 1, 3, 1, 13, 27, 13, 103, 87, 27, 971, 671, 629, 4943, 13897, 4003, 21507, 40193, 0 };
            const std::uint32_t dim11347JoeKuoD6Init[]   =   { 1, 3, 5, 9, 1, 49, 11, 15, 511, 837, 1953, 1585, 1867, 9095, 543, 16993, 115187, 0 };
            const std::uint32_t dim11348JoeKuoD6Init[]   =   { 1, 1, 5, 11, 21, 49, 37, 61, 9, 629, 1025, 1635, 4047, 15491, 28481, 43235, 53165, 0 };
            const std::uint32_t dim11349JoeKuoD6Init[]   =   { 1, 1, 5, 7, 15, 57, 121, 119, 405, 29, 655, 3085, 7131, 14761, 2273, 47113, 8603, 0 };
            const std::uint32_t dim11350JoeKuoD6Init[]   =   { 1, 1, 3, 3, 11, 45, 51, 107, 367, 235, 675, 3777, 6081, 16319, 19499, 36893, 25579, 0 };
            const std::uint32_t dim11351JoeKuoD6Init[]   =   { 1, 1, 7, 11, 1, 13, 43, 159, 415, 423, 1223, 2201, 1089, 10189, 12457, 26691, 3603, 0 };
            const std::uint32_t dim11352JoeKuoD6Init[]   =   { 1, 1, 3, 3, 3, 37, 109, 67, 487, 785, 637, 3931, 929, 14153, 25283, 483, 14371, 0 };
            const std::uint32_t dim11353JoeKuoD6Init[]   =   { 1, 1, 7, 9, 31, 59, 9, 245, 479, 113, 1419, 3265, 8131, 11123, 32519, 12141, 82059, 0 };
            const std::uint32_t dim11354JoeKuoD6Init[]   =   { 1, 1, 1, 7, 25, 25, 31, 13, 81, 217, 997, 1161, 1049, 5487, 8487, 57807, 126115, 0 };
            const std::uint32_t dim11355JoeKuoD6Init[]   =   { 1, 1, 3, 15, 1, 23, 63, 39, 503, 933, 1915, 687, 547, 779, 7689, 38607, 125229, 0 };
            const std::uint32_t dim11356JoeKuoD6Init[]   =   { 1, 1, 3, 3, 31, 49, 51, 87, 99, 327, 783, 3487, 7307, 2759, 22781, 56343, 126805, 0 };
            const std::uint32_t dim11357JoeKuoD6Init[]   =   { 1, 3, 3, 11, 27, 43, 99, 197, 275, 19, 775, 329, 3815, 14277, 3363, 26375, 75427, 0 };
            const std::uint32_t dim11358JoeKuoD6Init[]   =   { 1, 1, 5, 15, 15, 19, 65, 109, 103, 411, 1591, 2569, 1981, 4773, 7861, 6303, 127421, 0 };
            const std::uint32_t dim11359JoeKuoD6Init[]   =   { 1, 3, 1, 13, 1, 53, 107, 151, 317, 201, 1053, 2701, 5039, 2179, 10085, 31727, 85579, 0 };
            const std::uint32_t dim11360JoeKuoD6Init[]   =   { 1, 3, 1, 9, 5, 55, 71, 143, 187, 29, 1363, 2403, 2675, 2187, 12123, 32825, 56461, 0 };
            const std::uint32_t dim11361JoeKuoD6Init[]   =   { 1, 1, 7, 11, 5, 57, 91, 95, 85, 597, 925, 11, 1915, 9159, 9997, 29565, 111655, 0 };
            const std::uint32_t dim11362JoeKuoD6Init[]   =   { 1, 1, 5, 9, 25, 57, 79, 189, 205, 687, 471, 601, 5343, 9031, 7853, 6079, 40567, 0 };
            const std::uint32_t dim11363JoeKuoD6Init[]   =   { 1, 1, 3, 1, 31, 53, 67, 191, 511, 369, 1273, 3859, 4253, 14469, 3427, 17691, 22599, 0 };
            const std::uint32_t dim11364JoeKuoD6Init[]   =   { 1, 1, 3, 9, 17, 53, 101, 219, 41, 663, 635, 3889, 2197, 8125, 8313, 14957, 111445, 0 };
            const std::uint32_t dim11365JoeKuoD6Init[]   =   { 1, 1, 5, 5, 7, 49, 113, 9, 399, 257, 617, 63, 2773, 4411, 1193, 54449, 89003, 0 };
            const std::uint32_t dim11366JoeKuoD6Init[]   =   { 1, 1, 7, 11, 13, 29, 77, 73, 161, 419, 985, 303, 2237, 15217, 26621, 20441, 113955, 0 };
            const std::uint32_t dim11367JoeKuoD6Init[]   =   { 1, 3, 3, 9, 17, 39, 37, 139, 289, 421, 1021, 2635, 2805, 5815, 9101, 48077, 114009, 0 };
            const std::uint32_t dim11368JoeKuoD6Init[]   =   { 1, 1, 1, 15, 25, 43, 71, 35, 103, 827, 1301, 3567, 3425, 3689, 14453, 10733, 81257, 0 };
            const std::uint32_t dim11369JoeKuoD6Init[]   =   { 1, 3, 5, 5, 15, 31, 41, 161, 481, 231, 1135, 3045, 439, 11785, 14863, 39729, 59539, 0 };
            const std::uint32_t dim11370JoeKuoD6Init[]   =   { 1, 1, 5, 7, 27, 9, 81, 141, 395, 105, 41, 3719, 3105, 13685, 7451, 31381, 82907, 0 };
            const std::uint32_t dim11371JoeKuoD6Init[]   =   { 1, 3, 1, 13, 15, 25, 127, 231, 433, 837, 1923, 1301, 2479, 3243, 21605, 55789, 11311, 0 };
            const std::uint32_t dim11372JoeKuoD6Init[]   =   { 1, 3, 5, 7, 17, 5, 27, 111, 217, 445, 1245, 1029, 7663, 10291, 16483, 37503, 110205, 0 };
            const std::uint32_t dim11373JoeKuoD6Init[]   =   { 1, 1, 1, 7, 31, 21, 51, 235, 487, 457, 1687, 2947, 5067, 13779, 7671, 7257, 119141, 0 };
            const std::uint32_t dim11374JoeKuoD6Init[]   =   { 1, 1, 5, 13, 25, 31, 59, 183, 33, 887, 469, 813, 7939, 11775, 5795, 26227, 57703, 0 };
            const std::uint32_t dim11375JoeKuoD6Init[]   =   { 1, 3, 3, 15, 17, 7, 19, 87, 365, 177, 1157, 1023, 3055, 15439, 27187, 32593, 112507, 0 };
            const std::uint32_t dim11376JoeKuoD6Init[]   =   { 1, 1, 1, 9, 19, 49, 103, 239, 207, 409, 1613, 2793, 5477, 11221, 21611, 19963, 99333, 0 };
            const std::uint32_t dim11377JoeKuoD6Init[]   =   { 1, 3, 3, 11, 17, 1, 103, 77, 93, 197, 1883, 4053, 4613, 11571, 1841, 23189, 4235, 0 };
            const std::uint32_t dim11378JoeKuoD6Init[]   =   { 1, 3, 5, 9, 9, 49, 29, 231, 167, 593, 1909, 2457, 323, 10549, 6551, 45597, 96591, 0 };
            const std::uint32_t dim11379JoeKuoD6Init[]   =   { 1, 1, 7, 11, 15, 39, 33, 61, 13, 879, 1589, 2169, 125, 2427, 13029, 24919, 14147, 0 };
            const std::uint32_t dim11380JoeKuoD6Init[]   =   { 1, 3, 5, 5, 25, 53, 49, 255, 263, 917, 1997, 171, 2945, 14243, 12983, 21821, 119547, 0 };
            const std::uint32_t dim11381JoeKuoD6Init[]   =   { 1, 1, 1, 15, 5, 25, 113, 235, 311, 377, 1059, 1365, 3457, 8699, 18617, 25119, 110659, 0 };
            const std::uint32_t dim11382JoeKuoD6Init[]   =   { 1, 1, 5, 1, 9, 61, 1, 137, 301, 85, 1527, 3831, 923, 13753, 20909, 14007, 22939, 0 };
            const std::uint32_t dim11383JoeKuoD6Init[]   =   { 1, 1, 7, 9, 23, 17, 31, 107, 55, 293, 425, 3513, 3503, 10075, 6299, 40007, 54355, 0 };
            const std::uint32_t dim11384JoeKuoD6Init[]   =   { 1, 3, 5, 5, 27, 39, 95, 187, 239, 949, 531, 3541, 99, 6339, 32295, 10377, 111287, 0 };
            const std::uint32_t dim11385JoeKuoD6Init[]   =   { 1, 1, 5, 15, 19, 39, 23, 89, 185, 47, 87, 1721, 2471, 13221, 13201, 31, 12897, 0 };
            const std::uint32_t dim11386JoeKuoD6Init[]   =   { 1, 3, 1, 9, 7, 7, 109, 241, 39, 687, 175, 139, 583, 1629, 19775, 6371, 121879, 0 };
            const std::uint32_t dim11387JoeKuoD6Init[]   =   { 1, 1, 1, 13, 13, 9, 73, 153, 367, 425, 217, 3981, 5203, 1111, 12333, 59799, 105259, 0 };
            const std::uint32_t dim11388JoeKuoD6Init[]   =   { 1, 1, 3, 5, 7, 33, 27, 123, 335, 727, 1619, 3999, 7799, 2807, 2251, 45835, 113193, 0 };
            const std::uint32_t dim11389JoeKuoD6Init[]   =   { 1, 3, 1, 7, 25, 3, 49, 163, 447, 555, 647, 1461, 5881, 15755, 32233, 48915, 96203, 0 };
            const std::uint32_t dim11390JoeKuoD6Init[]   =   { 1, 3, 7, 7, 21, 11, 61, 101, 323, 165, 1489, 2933, 3363, 8471, 4311, 65279, 123813, 0 };
            const std::uint32_t dim11391JoeKuoD6Init[]   =   { 1, 3, 1, 1, 15, 1, 101, 225, 473, 479, 1237, 113, 7591, 2883, 3891, 53703, 14607, 0 };
            const std::uint32_t dim11392JoeKuoD6Init[]   =   { 1, 3, 5, 3, 17, 51, 23, 31, 487, 957, 1623, 2329, 2801, 6213, 7523, 14131, 23893, 0 };
            const std::uint32_t dim11393JoeKuoD6Init[]   =   { 1, 1, 5, 7, 9, 39, 93, 105, 13, 481, 53, 3785, 5621, 11889, 993, 23611, 73651, 0 };
            const std::uint32_t dim11394JoeKuoD6Init[]   =   { 1, 3, 7, 15, 21, 57, 97, 69, 339, 289, 1805, 2661, 1165, 6079, 1127, 51285, 54453, 0 };
            const std::uint32_t dim11395JoeKuoD6Init[]   =   { 1, 1, 3, 3, 3, 3, 1, 179, 123, 1011, 1363, 231, 6983, 9499, 91, 52573, 32565, 0 };
            const std::uint32_t dim11396JoeKuoD6Init[]   =   { 1, 3, 3, 15, 5, 37, 97, 7, 189, 547, 1965, 3821, 4907, 8181, 12857, 7907, 19361, 0 };
            const std::uint32_t dim11397JoeKuoD6Init[]   =   { 1, 1, 5, 3, 29, 33, 45, 99, 359, 337, 1377, 577, 3117, 9545, 30093, 26147, 128509, 0 };
            const std::uint32_t dim11398JoeKuoD6Init[]   =   { 1, 3, 5, 11, 7, 49, 99, 249, 37, 755, 383, 2845, 4153, 695, 11099, 33653, 105155, 0 };
            const std::uint32_t dim11399JoeKuoD6Init[]   =   { 1, 3, 1, 1, 19, 3, 3, 177, 97, 323, 1367, 213, 4391, 11223, 26497, 12289, 39047, 0 };
            const std::uint32_t dim11400JoeKuoD6Init[]   =   { 1, 1, 3, 7, 3, 33, 73, 199, 339, 479, 1797, 3905, 2849, 5667, 18015, 36653, 83491, 0 };
            const std::uint32_t dim11401JoeKuoD6Init[]   =   { 1, 1, 5, 3, 27, 59, 27, 241, 49, 161, 451, 3993, 2489, 10681, 11895, 60405, 47021, 0 };
            const std::uint32_t dim11402JoeKuoD6Init[]   =   { 1, 1, 7, 5, 9, 23, 115, 131, 383, 895, 1591, 585, 2571, 7485, 31535, 12871, 95717, 0 };
            const std::uint32_t dim11403JoeKuoD6Init[]   =   { 1, 1, 1, 15, 13, 49, 3, 157, 311, 159, 1239, 159, 5643, 6405, 11763, 34609, 75259, 0 };
            const std::uint32_t dim11404JoeKuoD6Init[]   =   { 1, 1, 1, 13, 11, 41, 119, 3, 165, 943, 2035, 179, 357, 14591, 20099, 4787, 12659, 0 };
            const std::uint32_t dim11405JoeKuoD6Init[]   =   { 1, 1, 5, 11, 13, 9, 67, 139, 259, 947, 1559, 283, 1557, 11297, 29753, 21953, 100317, 0 };
            const std::uint32_t dim11406JoeKuoD6Init[]   =   { 1, 1, 7, 11, 13, 39, 105, 83, 109, 723, 1643, 3599, 1471, 13653, 4583, 18595, 91935, 0 };
            const std::uint32_t dim11407JoeKuoD6Init[]   =   { 1, 1, 5, 9, 25, 5, 69, 189, 209, 779, 1421, 467, 849, 12887, 10317, 3005, 100813, 0 };
            const std::uint32_t dim11408JoeKuoD6Init[]   =   { 1, 3, 7, 11, 19, 1, 93, 239, 333, 713, 1525, 813, 5913, 10811, 7077, 20573, 86999, 0 };
            const std::uint32_t dim11409JoeKuoD6Init[]   =   { 1, 3, 1, 5, 25, 1, 107, 153, 225, 889, 1319, 497, 2193, 11511, 17553, 23733, 83179, 0 };
            const std::uint32_t dim11410JoeKuoD6Init[]   =   { 1, 3, 3, 3, 5, 45, 51, 37, 443, 851, 263, 4067, 2629, 10887, 29081, 30489, 1161, 0 };
            const std::uint32_t dim11411JoeKuoD6Init[]   =   { 1, 1, 3, 9, 25, 19, 115, 31, 347, 641, 1103, 1121, 7051, 14071, 16663, 48517, 24655, 0 };
            const std::uint32_t dim11412JoeKuoD6Init[]   =   { 1, 1, 3, 15, 11, 33, 123, 181, 225, 437, 875, 1997, 209, 5487, 1989, 6745, 38423, 0 };
            const std::uint32_t dim11413JoeKuoD6Init[]   =   { 1, 3, 7, 5, 27, 5, 105, 203, 51, 683, 1523, 347, 6881, 4353, 4531, 29589, 108053, 0 };
            const std::uint32_t dim11414JoeKuoD6Init[]   =   { 1, 1, 3, 9, 15, 33, 127, 145, 125, 429, 915, 1307, 1495, 3553, 26797, 36819, 121375, 0 };
            const std::uint32_t dim11415JoeKuoD6Init[]   =   { 1, 3, 5, 15, 7, 1, 55, 99, 7, 405, 885, 59, 5359, 13969, 32037, 53399, 77293, 0 };
            const std::uint32_t dim11416JoeKuoD6Init[]   =   { 1, 1, 7, 1, 29, 31, 89, 69, 405, 837, 1949, 2337, 1139, 14129, 16867, 15167, 21117, 0 };
            const std::uint32_t dim11417JoeKuoD6Init[]   =   { 1, 1, 3, 5, 3, 25, 61, 175, 135, 109, 959, 501, 13, 16057, 25031, 16321, 27617, 0 };
            const std::uint32_t dim11418JoeKuoD6Init[]   =   { 1, 3, 1, 5, 17, 39, 59, 113, 25, 707, 1641, 3489, 6193, 10085, 13837, 57851, 77475, 0 };
            const std::uint32_t dim11419JoeKuoD6Init[]   =   { 1, 1, 3, 5, 17, 35, 111, 163, 253, 641, 715, 1101, 4411, 10771, 20241, 46415, 114719, 0 };
            const std::uint32_t dim11420JoeKuoD6Init[]   =   { 1, 3, 1, 1, 7, 11, 77, 59, 71, 869, 1505, 751, 4367, 9603, 29735, 7333, 62487, 0 };
            const std::uint32_t dim11421JoeKuoD6Init[]   =   { 1, 3, 7, 9, 3, 51, 93, 195, 497, 659, 1563, 3801, 6933, 9089, 10891, 9853, 93611, 0 };
            const std::uint32_t dim11422JoeKuoD6Init[]   =   { 1, 3, 1, 7, 21, 47, 61, 117, 293, 281, 1547, 3437, 4947, 12119, 21425, 5591, 23951, 0 };
            const std::uint32_t dim11423JoeKuoD6Init[]   =   { 1, 1, 7, 13, 19, 59, 121, 249, 147, 759, 1963, 465, 7785, 7015, 81, 47869, 123845, 0 };
            const std::uint32_t dim11424JoeKuoD6Init[]   =   { 1, 1, 7, 13, 5, 35, 45, 69, 167, 263, 979, 2855, 1845, 5531, 17167, 7363, 89233, 0 };
            const std::uint32_t dim11425JoeKuoD6Init[]   =   { 1, 3, 3, 3, 17, 43, 109, 193, 389, 867, 1403, 1271, 7127, 13977, 22547, 53997, 24475, 0 };
            const std::uint32_t dim11426JoeKuoD6Init[]   =   { 1, 1, 1, 5, 25, 43, 47, 163, 417, 967, 819, 2433, 439, 8499, 29705, 32697, 109963, 0 };
            const std::uint32_t dim11427JoeKuoD6Init[]   =   { 1, 1, 1, 15, 19, 5, 83, 237, 431, 697, 1383, 2499, 6907, 9033, 12147, 23479, 17649, 0 };
            const std::uint32_t dim11428JoeKuoD6Init[]   =   { 1, 3, 5, 13, 27, 35, 103, 95, 239, 903, 537, 601, 417, 15859, 16533, 16753, 128229, 0 };
            const std::uint32_t dim11429JoeKuoD6Init[]   =   { 1, 1, 3, 1, 11, 55, 57, 9, 229, 135, 805, 2745, 2023, 12645, 29135, 39051, 17065, 0 };
            const std::uint32_t dim11430JoeKuoD6Init[]   =   { 1, 3, 5, 3, 13, 25, 77, 29, 449, 31, 1733, 1451, 3895, 11551, 1011, 22817, 35959, 0 };
            const std::uint32_t dim11431JoeKuoD6Init[]   =   { 1, 3, 3, 3, 1, 31, 93, 47, 255, 393, 571, 443, 6079, 6245, 11773, 42087, 40651, 0 };
            const std::uint32_t dim11432JoeKuoD6Init[]   =   { 1, 3, 1, 5, 17, 49, 119, 219, 375, 337, 29, 3409, 3187, 15243, 25853, 44385, 103675, 0 };
            const std::uint32_t dim11433JoeKuoD6Init[]   =   { 1, 3, 7, 15, 15, 21, 79, 109, 81, 119, 603, 1665, 7813, 3485, 11801, 48693, 108307, 0 };
            const std::uint32_t dim11434JoeKuoD6Init[]   =   { 1, 1, 1, 15, 9, 5, 103, 141, 181, 841, 7, 1217, 7713, 4843, 9089, 53641, 3029, 0 };
            const std::uint32_t dim11435JoeKuoD6Init[]   =   { 1, 3, 3, 1, 29, 47, 13, 179, 439, 387, 1553, 3141, 947, 4893, 29119, 30865, 14207, 0 };
            const std::uint32_t dim11436JoeKuoD6Init[]   =   { 1, 1, 1, 15, 29, 1, 41, 135, 43, 673, 1527, 883, 3211, 5195, 30219, 47133, 56819, 0 };
            const std::uint32_t dim11437JoeKuoD6Init[]   =   { 1, 3, 5, 13, 13, 47, 97, 219, 277, 397, 1901, 821, 1961, 705, 7291, 19435, 123563, 0 };
            const std::uint32_t dim11438JoeKuoD6Init[]   =   { 1, 1, 7, 15, 5, 49, 93, 59, 221, 205, 115, 559, 5633, 5819, 6923, 18301, 72639, 0 };
            const std::uint32_t dim11439JoeKuoD6Init[]   =   { 1, 3, 5, 13, 29, 49, 25, 203, 125, 385, 487, 1897, 2177, 6859, 6105, 763, 36673, 0 };
            const std::uint32_t dim11440JoeKuoD6Init[]   =   { 1, 3, 3, 9, 23, 63, 9, 115, 489, 89, 1113, 1351, 8181, 2569, 18263, 32619, 24795, 0 };
            const std::uint32_t dim11441JoeKuoD6Init[]   =   { 1, 1, 5, 11, 25, 51, 97, 155, 15, 139, 1275, 3479, 5851, 3099, 7417, 57155, 90185, 0 };
            const std::uint32_t dim11442JoeKuoD6Init[]   =   { 1, 3, 1, 11, 1, 37, 67, 221, 493, 475, 1881, 2277, 4365, 9411, 16629, 65229, 28803, 0 };
            const std::uint32_t dim11443JoeKuoD6Init[]   =   { 1, 3, 1, 1, 15, 53, 39, 141, 453, 151, 335, 795, 1515, 2719, 24197, 21153, 129549, 0 };
            const std::uint32_t dim11444JoeKuoD6Init[]   =   { 1, 1, 1, 7, 19, 31, 59, 123, 73, 149, 469, 1199, 3603, 1539, 29157, 50031, 22109, 0 };
            const std::uint32_t dim11445JoeKuoD6Init[]   =   { 1, 1, 3, 15, 23, 51, 45, 211, 423, 553, 1289, 1125, 6347, 6711, 23761, 14109, 17261, 0 };
            const std::uint32_t dim11446JoeKuoD6Init[]   =   { 1, 3, 5, 13, 5, 7, 35, 185, 263, 791, 161, 325, 4771, 11913, 31595, 56675, 68615, 0 };
            const std::uint32_t dim11447JoeKuoD6Init[]   =   { 1, 1, 5, 9, 19, 27, 89, 147, 55, 197, 1695, 99, 755, 15115, 1933, 41439, 85063, 0 };
            const std::uint32_t dim11448JoeKuoD6Init[]   =   { 1, 1, 7, 7, 17, 11, 103, 55, 281, 707, 1973, 2055, 5015, 5713, 3717, 44149, 8033, 0 };
            const std::uint32_t dim11449JoeKuoD6Init[]   =   { 1, 3, 1, 5, 21, 49, 55, 93, 161, 565, 81, 3241, 3709, 8185, 16935, 60369, 118127, 0 };
            const std::uint32_t dim11450JoeKuoD6Init[]   =   { 1, 3, 7, 9, 27, 1, 105, 133, 397, 351, 1021, 739, 161, 9971, 24733, 29239, 68853, 0 };
            const std::uint32_t dim11451JoeKuoD6Init[]   =   { 1, 1, 7, 1, 1, 19, 97, 243, 73, 969, 313, 399, 2955, 2467, 18265, 60637, 35457, 0 };
            const std::uint32_t dim11452JoeKuoD6Init[]   =   { 1, 3, 1, 11, 29, 25, 35, 35, 469, 143, 1195, 911, 1023, 14685, 10933, 16449, 102113, 0 };
            const std::uint32_t dim11453JoeKuoD6Init[]   =   { 1, 1, 5, 3, 31, 21, 65, 181, 13, 235, 501, 3621, 3567, 8771, 32747, 59231, 91551, 0 };
            const std::uint32_t dim11454JoeKuoD6Init[]   =   { 1, 1, 1, 13, 29, 21, 13, 33, 193, 565, 203, 3927, 4749, 9897, 26109, 14221, 27733, 0 };
            const std::uint32_t dim11455JoeKuoD6Init[]   =   { 1, 1, 1, 5, 29, 41, 7, 125, 391, 295, 533, 2135, 3107, 7711, 27811, 55767, 78821, 0 };
            const std::uint32_t dim11456JoeKuoD6Init[]   =   { 1, 1, 7, 3, 19, 25, 117, 195, 155, 685, 147, 2049, 3751, 4585, 24893, 36895, 80371, 0 };
            const std::uint32_t dim11457JoeKuoD6Init[]   =   { 1, 3, 5, 5, 23, 41, 9, 125, 315, 809, 1019, 1453, 4605, 13753, 30641, 50677, 94781, 0 };
            const std::uint32_t dim11458JoeKuoD6Init[]   =   { 1, 1, 1, 7, 27, 45, 103, 199, 37, 291, 651, 185, 6715, 15387, 30873, 63051, 123231, 0 };
            const std::uint32_t dim11459JoeKuoD6Init[]   =   { 1, 1, 5, 7, 17, 5, 75, 129, 401, 107, 1681, 2039, 299, 12399, 30947, 26327, 91589, 0 };
            const std::uint32_t dim11460JoeKuoD6Init[]   =   { 1, 3, 3, 15, 17, 19, 109, 19, 493, 797, 209, 929, 2821, 395, 22173, 27803, 87953, 0 };
            const std::uint32_t dim11461JoeKuoD6Init[]   =   { 1, 3, 7, 5, 7, 5, 71, 159, 483, 389, 1817, 4093, 963, 4253, 31267, 63919, 62113, 0 };
            const std::uint32_t dim11462JoeKuoD6Init[]   =   { 1, 3, 3, 15, 9, 49, 89, 49, 15, 61, 2041, 2357, 2173, 3349, 32565, 23207, 21177, 0 };
            const std::uint32_t dim11463JoeKuoD6Init[]   =   { 1, 1, 1, 13, 15, 21, 31, 143, 387, 371, 567, 1903, 3793, 9559, 7055, 31251, 13663, 0 };
            const std::uint32_t dim11464JoeKuoD6Init[]   =   { 1, 1, 3, 13, 3, 7, 49, 31, 255, 581, 627, 1947, 2965, 2787, 8275, 59785, 19979, 0 };
            const std::uint32_t dim11465JoeKuoD6Init[]   =   { 1, 3, 3, 13, 29, 47, 53, 133, 301, 253, 1215, 3409, 5745, 247, 31585, 5555, 31011, 0 };
            const std::uint32_t dim11466JoeKuoD6Init[]   =   { 1, 3, 7, 15, 23, 49, 1, 89, 141, 423, 707, 645, 7955, 10485, 27223, 35867, 45461, 0 };
            const std::uint32_t dim11467JoeKuoD6Init[]   =   { 1, 1, 3, 3, 29, 25, 123, 63, 197, 429, 169, 3229, 3797, 4029, 29947, 52781, 16065, 0 };
            const std::uint32_t dim11468JoeKuoD6Init[]   =   { 1, 3, 3, 7, 29, 17, 83, 95, 199, 253, 133, 265, 6723, 6207, 12863, 61311, 21937, 0 };
            const std::uint32_t dim11469JoeKuoD6Init[]   =   { 1, 3, 7, 13, 19, 61, 89, 151, 249, 597, 1389, 717, 5111, 3285, 6251, 50237, 108703, 0 };
            const std::uint32_t dim11470JoeKuoD6Init[]   =   { 1, 3, 5, 11, 1, 23, 35, 61, 143, 45, 625, 1693, 4943, 2213, 9317, 7601, 28359, 0 };
            const std::uint32_t dim11471JoeKuoD6Init[]   =   { 1, 3, 3, 15, 29, 43, 115, 23, 167, 355, 977, 439, 4767, 9967, 22997, 54725, 125637, 0 };
            const std::uint32_t dim11472JoeKuoD6Init[]   =   { 1, 3, 7, 1, 29, 45, 83, 71, 395, 247, 1, 113, 6393, 12445, 16137, 35125, 102053, 0 };
            const std::uint32_t dim11473JoeKuoD6Init[]   =   { 1, 1, 1, 7, 17, 55, 17, 159, 33, 237, 207, 1297, 5611, 6023, 17709, 60905, 3533, 0 };
            const std::uint32_t dim11474JoeKuoD6Init[]   =   { 1, 3, 1, 13, 27, 57, 27, 235, 141, 917, 1655, 659, 939, 559, 2651, 705, 80141, 0 };
            const std::uint32_t dim11475JoeKuoD6Init[]   =   { 1, 3, 7, 3, 3, 17, 111, 117, 467, 129, 1105, 3457, 2093, 8513, 19941, 22111, 54597, 0 };
            const std::uint32_t dim11476JoeKuoD6Init[]   =   { 1, 3, 7, 3, 5, 17, 59, 195, 23, 547, 1799, 1427, 391, 4043, 10407, 31055, 38495, 0 };
            const std::uint32_t dim11477JoeKuoD6Init[]   =   { 1, 1, 1, 7, 21, 9, 71, 33, 209, 773, 1243, 3239, 3763, 15229, 9609, 24395, 56145, 0 };
            const std::uint32_t dim11478JoeKuoD6Init[]   =   { 1, 3, 5, 13, 13, 45, 71, 91, 23, 553, 665, 1753, 5173, 4355, 14317, 42517, 32307, 0 };
            const std::uint32_t dim11479JoeKuoD6Init[]   =   { 1, 3, 5, 11, 31, 3, 37, 95, 63, 425, 1611, 2983, 5075, 1375, 14305, 11099, 101203, 0 };
            const std::uint32_t dim11480JoeKuoD6Init[]   =   { 1, 1, 3, 1, 21, 7, 15, 141, 389, 871, 617, 271, 1037, 13569, 13019, 58899, 54097, 0 };
            const std::uint32_t dim11481JoeKuoD6Init[]   =   { 1, 3, 7, 1, 13, 25, 21, 251, 467, 373, 1539, 4065, 1871, 791, 26315, 64187, 119455, 0 };
            const std::uint32_t dim11482JoeKuoD6Init[]   =   { 1, 3, 1, 3, 25, 37, 43, 9, 187, 323, 409, 443, 2861, 14145, 26185, 24049, 109613, 0 };
            const std::uint32_t dim11483JoeKuoD6Init[]   =   { 1, 1, 3, 7, 21, 61, 3, 81, 445, 673, 1269, 613, 1279, 8209, 22911, 48017, 54181, 0 };
            const std::uint32_t dim11484JoeKuoD6Init[]   =   { 1, 1, 1, 15, 25, 63, 71, 147, 217, 491, 183, 977, 4967, 3471, 8791, 11843, 68005, 0 };
            const std::uint32_t dim11485JoeKuoD6Init[]   =   { 1, 1, 1, 5, 25, 43, 13, 237, 57, 919, 1641, 399, 4269, 7357, 3465, 63901, 61329, 0 };
            const std::uint32_t dim11486JoeKuoD6Init[]   =   { 1, 1, 7, 15, 27, 57, 47, 187, 295, 117, 1223, 2963, 4995, 13279, 25107, 56089, 37293, 0 };
            const std::uint32_t dim11487JoeKuoD6Init[]   =   { 1, 1, 5, 13, 29, 19, 83, 121, 129, 931, 1933, 1141, 3125, 3321, 22019, 52729, 119643, 0 };
            const std::uint32_t dim11488JoeKuoD6Init[]   =   { 1, 1, 1, 1, 21, 19, 49, 241, 227, 57, 1919, 113, 6993, 4687, 1043, 5247, 15565, 0 };
            const std::uint32_t dim11489JoeKuoD6Init[]   =   { 1, 3, 3, 15, 5, 21, 65, 129, 485, 173, 1663, 2419, 4279, 4167, 25827, 28457, 68219, 0 };
            const std::uint32_t dim11490JoeKuoD6Init[]   =   { 1, 1, 3, 1, 17, 9, 65, 21, 487, 875, 1111, 1679, 6451, 14825, 23931, 16053, 79687, 0 };
            const std::uint32_t dim11491JoeKuoD6Init[]   =   { 1, 3, 3, 5, 13, 5, 49, 15, 267, 389, 1111, 1505, 5815, 6285, 26075, 167, 70325, 0 };
            const std::uint32_t dim11492JoeKuoD6Init[]   =   { 1, 1, 3, 11, 5, 15, 57, 171, 407, 497, 1979, 2819, 1267, 6893, 6601, 30971, 24477, 0 };
            const std::uint32_t dim11493JoeKuoD6Init[]   =   { 1, 1, 1, 15, 7, 5, 69, 181, 195, 847, 1245, 4019, 2469, 1407, 17013, 43437, 16307, 0 };
            const std::uint32_t dim11494JoeKuoD6Init[]   =   { 1, 3, 1, 11, 15, 17, 115, 197, 215, 35, 1489, 659, 4725, 11339, 30259, 52539, 13365, 0 };
            const std::uint32_t dim11495JoeKuoD6Init[]   =   { 1, 1, 1, 13, 23, 43, 21, 33, 17, 969, 1321, 2469, 4371, 7685, 6817, 20179, 113483, 0 };
            const std::uint32_t dim11496JoeKuoD6Init[]   =   { 1, 3, 7, 3, 31, 11, 79, 55, 123, 263, 1061, 2087, 183, 11623, 20703, 60291, 115261, 0 };
            const std::uint32_t dim11497JoeKuoD6Init[]   =   { 1, 1, 5, 13, 5, 53, 21, 71, 399, 165, 1997, 2667, 7361, 8863, 27859, 17235, 77623, 0 };
            const std::uint32_t dim11498JoeKuoD6Init[]   =   { 1, 3, 3, 15, 21, 55, 27, 31, 371, 289, 253, 1453, 105, 7035, 14787, 2281, 128359, 0 };
            const std::uint32_t dim11499JoeKuoD6Init[]   =   { 1, 1, 3, 15, 23, 29, 3, 143, 47, 255, 115, 2741, 6773, 16267, 5975, 3689, 97497, 0 };
            const std::uint32_t dim11500JoeKuoD6Init[]   =   { 1, 1, 1, 15, 9, 57, 109, 43, 359, 365, 1577, 4091, 7399, 10521, 7983, 56119, 65451, 0 };
            const std::uint32_t dim11501JoeKuoD6Init[]   =   { 1, 3, 7, 7, 29, 55, 115, 155, 121, 679, 663, 2345, 3765, 4493, 9555, 24043, 41467, 0 };
            const std::uint32_t dim11502JoeKuoD6Init[]   =   { 1, 1, 3, 1, 19, 55, 67, 255, 355, 701, 2027, 3703, 7839, 1701, 7657, 36429, 36623, 0 };
            const std::uint32_t dim11503JoeKuoD6Init[]   =   { 1, 3, 5, 5, 29, 7, 31, 123, 21, 901, 1581, 3993, 5105, 9715, 18347, 27415, 19253, 0 };
            const std::uint32_t dim11504JoeKuoD6Init[]   =   { 1, 3, 5, 3, 3, 53, 121, 105, 51, 577, 157, 2151, 5105, 7855, 8595, 24457, 55931, 0 };
            const std::uint32_t dim11505JoeKuoD6Init[]   =   { 1, 3, 1, 9, 23, 25, 67, 115, 79, 809, 1215, 943, 1075, 7103, 729, 18791, 115977, 0 };
            const std::uint32_t dim11506JoeKuoD6Init[]   =   { 1, 3, 1, 13, 3, 57, 105, 161, 277, 393, 1671, 2765, 5781, 13429, 24075, 10931, 50951, 0 };
            const std::uint32_t dim11507JoeKuoD6Init[]   =   { 1, 3, 5, 9, 19, 61, 9, 227, 455, 541, 721, 2855, 949, 10159, 13801, 48199, 26747, 0 };
            const std::uint32_t dim11508JoeKuoD6Init[]   =   { 1, 3, 1, 3, 25, 61, 53, 177, 441, 697, 1845, 3573, 6673, 9691, 911, 46387, 64727, 0 };
            const std::uint32_t dim11509JoeKuoD6Init[]   =   { 1, 1, 1, 11, 7, 13, 95, 221, 455, 967, 869, 883, 6301, 5261, 18401, 35745, 114645, 0 };
            const std::uint32_t dim11510JoeKuoD6Init[]   =   { 1, 3, 1, 11, 15, 7, 115, 217, 235, 539, 491, 603, 2201, 241, 25445, 29773, 122695, 0 };
            const std::uint32_t dim11511JoeKuoD6Init[]   =   { 1, 1, 5, 3, 19, 9, 71, 193, 131, 927, 1931, 3981, 7537, 10811, 27285, 45865, 106171, 0 };
            const std::uint32_t dim11512JoeKuoD6Init[]   =   { 1, 1, 7, 5, 5, 21, 107, 77, 363, 733, 1011, 3259, 5263, 15043, 19153, 32117, 129409, 0 };
            const std::uint32_t dim11513JoeKuoD6Init[]   =   { 1, 1, 3, 13, 21, 5, 9, 103, 369, 699, 329, 1065, 895, 13211, 19017, 5359, 38335, 0 };
            const std::uint32_t dim11514JoeKuoD6Init[]   =   { 1, 1, 7, 15, 21, 11, 73, 153, 371, 753, 805, 3519, 5839, 1809, 7201, 8189, 68361, 0 };
            const std::uint32_t dim11515JoeKuoD6Init[]   =   { 1, 3, 7, 9, 27, 45, 25, 175, 317, 381, 961, 619, 4827, 15161, 19091, 29369, 21097, 0 };
            const std::uint32_t dim11516JoeKuoD6Init[]   =   { 1, 1, 5, 5, 7, 7, 21, 69, 23, 589, 1413, 653, 911, 13599, 18349, 47307, 64047, 0 };
            const std::uint32_t dim11517JoeKuoD6Init[]   =   { 1, 1, 1, 13, 27, 23, 87, 249, 135, 727, 375, 3641, 1489, 13053, 5151, 62689, 101347, 0 };
            const std::uint32_t dim11518JoeKuoD6Init[]   =   { 1, 1, 5, 11, 7, 39, 1, 109, 203, 961, 973, 1181, 2357, 5123, 31481, 58345, 52705, 0 };
            const std::uint32_t dim11519JoeKuoD6Init[]   =   { 1, 1, 1, 15, 25, 15, 85, 49, 77, 235, 1761, 2731, 4157, 2057, 27587, 30299, 52997, 0 };
            const std::uint32_t dim11520JoeKuoD6Init[]   =   { 1, 1, 5, 3, 1, 13, 47, 219, 51, 521, 625, 3243, 7093, 10823, 9559, 58191, 95573, 0 };
            const std::uint32_t dim11521JoeKuoD6Init[]   =   { 1, 3, 5, 13, 27, 63, 13, 7, 167, 909, 1559, 2103, 1807, 943, 28997, 31015, 85407, 0 };
            const std::uint32_t dim11522JoeKuoD6Init[]   =   { 1, 1, 3, 5, 17, 21, 101, 163, 477, 223, 175, 3435, 7071, 5121, 28015, 33365, 121057, 0 };
            const std::uint32_t dim11523JoeKuoD6Init[]   =   { 1, 3, 7, 1, 11, 35, 111, 41, 261, 45, 1009, 2827, 4019, 5029, 22289, 20235, 13481, 0 };
            const std::uint32_t dim11524JoeKuoD6Init[]   =   { 1, 3, 5, 5, 15, 41, 109, 7, 329, 447, 65, 1317, 6169, 15947, 31191, 47091, 60643, 0 };
            const std::uint32_t dim11525JoeKuoD6Init[]   =   { 1, 3, 7, 7, 21, 13, 29, 113, 511, 407, 1211, 2065, 455, 10049, 5745, 48589, 48669, 0 };
            const std::uint32_t dim11526JoeKuoD6Init[]   =   { 1, 1, 5, 5, 21, 45, 89, 19, 279, 165, 1897, 957, 8045, 565, 4959, 37173, 100773, 0 };
            const std::uint32_t dim11527JoeKuoD6Init[]   =   { 1, 3, 1, 15, 9, 17, 99, 143, 489, 633, 1721, 1255, 3655, 10083, 29079, 17109, 10035, 0 };
            const std::uint32_t dim11528JoeKuoD6Init[]   =   { 1, 1, 3, 3, 3, 23, 47, 9, 255, 169, 1103, 1799, 7899, 7673, 19259, 61919, 112831, 0 };
            const std::uint32_t dim11529JoeKuoD6Init[]   =   { 1, 1, 5, 5, 31, 37, 83, 229, 93, 575, 1589, 2353, 185, 7783, 9413, 9617, 123197, 0 };
            const std::uint32_t dim11530JoeKuoD6Init[]   =   { 1, 3, 5, 7, 31, 7, 113, 255, 231, 309, 1215, 737, 3635, 14631, 28737, 45127, 111399, 0 };
            const std::uint32_t dim11531JoeKuoD6Init[]   =   { 1, 1, 7, 1, 11, 5, 55, 235, 369, 983, 873, 655, 6277, 11425, 11191, 38231, 88941, 0 };
            const std::uint32_t dim11532JoeKuoD6Init[]   =   { 1, 3, 1, 9, 3, 1, 119, 93, 245, 167, 853, 2543, 203, 5313, 14129, 6283, 107117, 0 };
            const std::uint32_t dim11533JoeKuoD6Init[]   =   { 1, 3, 3, 13, 21, 33, 59, 167, 435, 163, 1873, 3341, 2895, 13205, 14147, 19567, 100127, 0 };
            const std::uint32_t dim11534JoeKuoD6Init[]   =   { 1, 1, 5, 9, 7, 15, 39, 81, 475, 511, 1585, 63, 6861, 10055, 3577, 48999, 80979, 0 };
            const std::uint32_t dim11535JoeKuoD6Init[]   =   { 1, 1, 5, 13, 21, 29, 17, 3, 499, 739, 1257, 2925, 8179, 13367, 18879, 19917, 109907, 0 };
            const std::uint32_t dim11536JoeKuoD6Init[]   =   { 1, 3, 7, 13, 15, 57, 109, 19, 265, 579, 233, 2507, 5059, 14713, 9549, 41915, 56199, 0 };
            const std::uint32_t dim11537JoeKuoD6Init[]   =   { 1, 3, 3, 5, 31, 25, 85, 163, 187, 795, 1597, 1963, 473, 4673, 4555, 51365, 73817, 0 };
            const std::uint32_t dim11538JoeKuoD6Init[]   =   { 1, 3, 3, 13, 25, 35, 71, 251, 33, 971, 235, 1919, 6705, 14657, 23417, 56377, 21071, 0 };
            const std::uint32_t dim11539JoeKuoD6Init[]   =   { 1, 3, 3, 11, 3, 29, 85, 193, 11, 831, 29, 1233, 6199, 11991, 9205, 3323, 23749, 0 };
            const std::uint32_t dim11540JoeKuoD6Init[]   =   { 1, 3, 7, 7, 11, 15, 1, 17, 87, 665, 1593, 2331, 845, 7821, 89, 7057, 114975, 0 };
            const std::uint32_t dim11541JoeKuoD6Init[]   =   { 1, 1, 5, 11, 9, 37, 39, 79, 455, 397, 1431, 1541, 7629, 15133, 21395, 35619, 123801, 0 };
            const std::uint32_t dim11542JoeKuoD6Init[]   =   { 1, 1, 1, 7, 11, 59, 67, 45, 169, 869, 1547, 2947, 3025, 12967, 29927, 22181, 44783, 0 };
            const std::uint32_t dim11543JoeKuoD6Init[]   =   { 1, 1, 5, 7, 3, 57, 123, 253, 369, 537, 83, 1147, 3469, 9775, 14137, 38899, 101143, 0 };
            const std::uint32_t dim11544JoeKuoD6Init[]   =   { 1, 3, 5, 3, 19, 35, 11, 215, 343, 677, 1873, 1211, 3129, 9017, 29595, 1291, 39397, 0 };
            const std::uint32_t dim11545JoeKuoD6Init[]   =   { 1, 1, 7, 3, 25, 7, 61, 229, 187, 839, 747, 3347, 4321, 13201, 19665, 56951, 85273, 0 };
            const std::uint32_t dim11546JoeKuoD6Init[]   =   { 1, 1, 1, 1, 11, 5, 51, 41, 227, 895, 553, 2673, 6581, 6583, 15429, 33211, 100599, 0 };
            const std::uint32_t dim11547JoeKuoD6Init[]   =   { 1, 3, 3, 5, 21, 27, 91, 65, 213, 341, 723, 567, 4761, 11549, 15041, 23079, 55245, 0 };
            const std::uint32_t dim11548JoeKuoD6Init[]   =   { 1, 1, 3, 1, 15, 43, 83, 57, 473, 453, 1351, 2055, 5769, 3887, 29481, 57915, 14017, 0 };
            const std::uint32_t dim11549JoeKuoD6Init[]   =   { 1, 3, 3, 3, 21, 29, 121, 137, 99, 527, 711, 1169, 7869, 6245, 25423, 38989, 87019, 0 };
            const std::uint32_t dim11550JoeKuoD6Init[]   =   { 1, 1, 5, 11, 9, 61, 125, 7, 207, 245, 1019, 635, 7099, 13133, 11809, 56705, 18801, 0 };
            const std::uint32_t dim11551JoeKuoD6Init[]   =   { 1, 3, 7, 9, 15, 31, 37, 205, 439, 651, 255, 971, 4311, 7137, 11821, 45041, 31081, 0 };
            const std::uint32_t dim11552JoeKuoD6Init[]   =   { 1, 1, 5, 9, 7, 55, 51, 147, 371, 881, 359, 3021, 1141, 14515, 14605, 64067, 98231, 0 };
            const std::uint32_t dim11553JoeKuoD6Init[]   =   { 1, 3, 1, 3, 29, 9, 109, 21, 437, 321, 753, 3227, 2929, 14787, 2451, 54331, 115921, 0 };
            const std::uint32_t dim11554JoeKuoD6Init[]   =   { 1, 3, 5, 7, 1, 29, 13, 167, 89, 185, 409, 209, 6625, 5237, 22513, 2095, 26427, 0 };
            const std::uint32_t dim11555JoeKuoD6Init[]   =   { 1, 1, 1, 3, 3, 31, 25, 145, 27, 345, 957, 823, 7873, 9469, 29115, 12455, 39447, 0 };
            const std::uint32_t dim11556JoeKuoD6Init[]   =   { 1, 1, 3, 3, 31, 15, 99, 181, 247, 165, 441, 59, 1181, 2851, 1337, 4929, 31079, 0 };
            const std::uint32_t dim11557JoeKuoD6Init[]   =   { 1, 1, 3, 11, 3, 47, 41, 53, 41, 435, 945, 3839, 8083, 4927, 26919, 24689, 61015, 0 };
            const std::uint32_t dim11558JoeKuoD6Init[]   =   { 1, 3, 3, 9, 7, 21, 121, 233, 493, 271, 549, 1627, 5861, 377, 20751, 52927, 3649, 0 };
            const std::uint32_t dim11559JoeKuoD6Init[]   =   { 1, 1, 1, 7, 15, 49, 29, 149, 57, 513, 873, 93, 337, 12559, 24287, 27771, 28207, 0 };
            const std::uint32_t dim11560JoeKuoD6Init[]   =   { 1, 1, 5, 7, 7, 7, 75, 161, 419, 601, 55, 2599, 5325, 12419, 26755, 5103, 10231, 0 };
            const std::uint32_t dim11561JoeKuoD6Init[]   =   { 1, 3, 5, 15, 3, 55, 67, 183, 7, 371, 141, 4093, 4567, 13971, 3327, 20701, 78819, 0 };
            const std::uint32_t dim11562JoeKuoD6Init[]   =   { 1, 1, 1, 13, 15, 41, 45, 29, 375, 235, 1985, 1051, 5863, 7043, 11143, 59381, 55007, 0 };
            const std::uint32_t dim11563JoeKuoD6Init[]   =   { 1, 3, 1, 15, 15, 29, 15, 101, 395, 39, 1839, 1689, 429, 405, 29337, 28573, 10599, 0 };
            const std::uint32_t dim11564JoeKuoD6Init[]   =   { 1, 3, 3, 11, 7, 5, 11, 153, 235, 227, 561, 1037, 2283, 6657, 6729, 17939, 29809, 0 };
            const std::uint32_t dim11565JoeKuoD6Init[]   =   { 1, 1, 1, 5, 15, 59, 33, 69, 275, 447, 661, 2071, 5811, 10463, 32707, 64503, 106313, 0 };
            const std::uint32_t dim11566JoeKuoD6Init[]   =   { 1, 1, 7, 1, 21, 53, 21, 235, 497, 309, 1207, 1613, 7739, 12785, 7743, 37671, 29197, 0 };
            const std::uint32_t dim11567JoeKuoD6Init[]   =   { 1, 3, 5, 9, 9, 51, 33, 105, 275, 917, 1911, 3607, 865, 899, 5405, 59593, 113965, 0 };
            const std::uint32_t dim11568JoeKuoD6Init[]   =   { 1, 3, 1, 7, 7, 63, 51, 83, 481, 347, 1323, 3549, 2873, 12527, 16515, 61077, 63239, 0 };
            const std::uint32_t dim11569JoeKuoD6Init[]   =   { 1, 1, 1, 1, 13, 21, 87, 139, 461, 215, 1173, 1197, 2091, 11247, 25647, 23443, 105761, 0 };
            const std::uint32_t dim11570JoeKuoD6Init[]   =   { 1, 1, 1, 1, 27, 33, 21, 27, 365, 75, 351, 2111, 3897, 13325, 4821, 41355, 95681, 0 };
            const std::uint32_t dim11571JoeKuoD6Init[]   =   { 1, 3, 5, 5, 15, 41, 15, 93, 397, 461, 1993, 321, 4375, 1205, 18417, 37549, 30181, 0 };
            const std::uint32_t dim11572JoeKuoD6Init[]   =   { 1, 3, 5, 15, 1, 49, 101, 129, 215, 773, 1265, 2245, 2517, 16261, 32149, 3545, 27631, 0 };
            const std::uint32_t dim11573JoeKuoD6Init[]   =   { 1, 1, 1, 15, 5, 5, 3, 127, 265, 721, 875, 3117, 2177, 7843, 15871, 22687, 89347, 0 };
            const std::uint32_t dim11574JoeKuoD6Init[]   =   { 1, 3, 7, 11, 29, 23, 69, 41, 155, 257, 563, 509, 6105, 9169, 18341, 25373, 127397, 0 };
            const std::uint32_t dim11575JoeKuoD6Init[]   =   { 1, 1, 5, 13, 31, 23, 65, 131, 131, 61, 1979, 2737, 3793, 3617, 14385, 189, 84567, 0 };
            const std::uint32_t dim11576JoeKuoD6Init[]   =   { 1, 1, 1, 13, 21, 33, 43, 97, 83, 903, 1971, 3209, 5391, 7703, 13795, 3895, 78045, 0 };
            const std::uint32_t dim11577JoeKuoD6Init[]   =   { 1, 3, 3, 5, 17, 53, 113, 237, 269, 83, 589, 4029, 3309, 14531, 11359, 25803, 25525, 0 };
            const std::uint32_t dim11578JoeKuoD6Init[]   =   { 1, 1, 7, 1, 21, 35, 43, 73, 251, 705, 1737, 3341, 1581, 9663, 6251, 16329, 44491, 0 };
            const std::uint32_t dim11579JoeKuoD6Init[]   =   { 1, 3, 3, 7, 17, 5, 65, 19, 203, 717, 807, 1759, 6907, 15801, 30369, 2655, 69565, 0 };
            const std::uint32_t dim11580JoeKuoD6Init[]   =   { 1, 1, 1, 1, 31, 21, 75, 221, 115, 395, 1495, 2739, 1745, 5981, 28045, 56581, 130695, 0 };
            const std::uint32_t dim11581JoeKuoD6Init[]   =   { 1, 3, 1, 9, 27, 5, 113, 123, 367, 701, 647, 117, 2389, 12309, 1747, 23421, 21583, 0 };
            const std::uint32_t dim11582JoeKuoD6Init[]   =   { 1, 1, 1, 15, 27, 57, 95, 81, 347, 765, 1435, 1727, 153, 6051, 27085, 62787, 40903, 0 };
            const std::uint32_t dim11583JoeKuoD6Init[]   =   { 1, 1, 3, 11, 23, 29, 23, 29, 169, 653, 835, 357, 5113, 5293, 11779, 23567, 64569, 0 };
            const std::uint32_t dim11584JoeKuoD6Init[]   =   { 1, 1, 7, 13, 31, 7, 101, 235, 99, 247, 1267, 509, 3927, 14317, 3217, 24389, 34215, 0 };
            const std::uint32_t dim11585JoeKuoD6Init[]   =   { 1, 3, 3, 5, 21, 27, 33, 229, 33, 551, 815, 3551, 4261, 13325, 31117, 40689, 66549, 0 };
            const std::uint32_t dim11586JoeKuoD6Init[]   =   { 1, 3, 7, 1, 23, 1, 99, 11, 139, 569, 365, 1233, 3281, 7817, 8833, 47699, 97825, 0 };
            const std::uint32_t dim11587JoeKuoD6Init[]   =   { 1, 1, 3, 1, 19, 39, 19, 151, 25, 73, 1271, 1435, 3109, 2571, 9191, 48257, 61001, 0 };
            const std::uint32_t dim11588JoeKuoD6Init[]   =   { 1, 3, 7, 1, 23, 63, 1, 115, 159, 943, 1637, 1443, 809, 10705, 12563, 63111, 96343, 0 };
            const std::uint32_t dim11589JoeKuoD6Init[]   =   { 1, 1, 7, 15, 5, 17, 65, 157, 45, 199, 371, 2497, 4367, 9109, 31955, 64253, 69279, 0 };
            const std::uint32_t dim11590JoeKuoD6Init[]   =   { 1, 3, 3, 15, 29, 45, 103, 183, 87, 543, 97, 1545, 2719, 5619, 28871, 4049, 111825, 0 };
            const std::uint32_t dim11591JoeKuoD6Init[]   =   { 1, 1, 5, 7, 27, 63, 65, 241, 103, 483, 579, 3589, 5673, 13283, 24193, 31993, 72713, 0 };
            const std::uint32_t dim11592JoeKuoD6Init[]   =   { 1, 3, 7, 9, 21, 35, 59, 183, 459, 211, 753, 3941, 5389, 10535, 2895, 44307, 26577, 0 };
            const std::uint32_t dim11593JoeKuoD6Init[]   =   { 1, 3, 1, 3, 9, 11, 15, 141, 159, 853, 1975, 4027, 8053, 16129, 32687, 29117, 67507, 0 };
            const std::uint32_t dim11594JoeKuoD6Init[]   =   { 1, 3, 3, 1, 19, 51, 55, 167, 85, 869, 437, 457, 7879, 2097, 4403, 2139, 10589, 0 };
            const std::uint32_t dim11595JoeKuoD6Init[]   =   { 1, 3, 3, 15, 19, 33, 63, 229, 197, 269, 1189, 317, 5087, 3147, 787, 64317, 43293, 0 };
            const std::uint32_t dim11596JoeKuoD6Init[]   =   { 1, 3, 5, 11, 25, 25, 121, 37, 371, 117, 1683, 2921, 671, 11353, 32273, 57597, 56901, 0 };
            const std::uint32_t dim11597JoeKuoD6Init[]   =   { 1, 3, 7, 7, 9, 37, 91, 159, 195, 1, 77, 2085, 985, 9999, 5639, 25041, 66393, 0 };
            const std::uint32_t dim11598JoeKuoD6Init[]   =   { 1, 1, 7, 5, 11, 17, 67, 21, 301, 971, 591, 3809, 4795, 12301, 16977, 27495, 98539, 0 };
            const std::uint32_t dim11599JoeKuoD6Init[]   =   { 1, 3, 1, 9, 13, 53, 83, 205, 111, 609, 631, 23, 1781, 15401, 1563, 34367, 40345, 0 };
            const std::uint32_t dim11600JoeKuoD6Init[]   =   { 1, 3, 7, 1, 31, 23, 101, 47, 55, 905, 953, 733, 5173, 5937, 17703, 31077, 49707, 0 };
            const std::uint32_t dim11601JoeKuoD6Init[]   =   { 1, 3, 5, 3, 5, 3, 127, 171, 511, 289, 685, 1157, 6521, 3301, 3017, 58857, 55289, 0 };
            const std::uint32_t dim11602JoeKuoD6Init[]   =   { 1, 1, 5, 1, 1, 29, 59, 7, 423, 83, 797, 2633, 2015, 1657, 7575, 39819, 181, 0 };
            const std::uint32_t dim11603JoeKuoD6Init[]   =   { 1, 3, 5, 15, 25, 27, 39, 99, 83, 381, 401, 1033, 867, 15645, 28643, 34917, 53215, 0 };
            const std::uint32_t dim11604JoeKuoD6Init[]   =   { 1, 3, 5, 15, 17, 1, 67, 63, 355, 841, 681, 2807, 531, 15295, 7859, 64031, 121519, 0 };
            const std::uint32_t dim11605JoeKuoD6Init[]   =   { 1, 3, 1, 5, 21, 57, 63, 247, 467, 101, 129, 2627, 4763, 479, 11145, 8861, 69803, 0 };
            const std::uint32_t dim11606JoeKuoD6Init[]   =   { 1, 3, 1, 15, 13, 13, 77, 39, 297, 401, 1653, 659, 3909, 13179, 10477, 45967, 1665, 0 };
            const std::uint32_t dim11607JoeKuoD6Init[]   =   { 1, 3, 7, 5, 29, 17, 35, 157, 309, 747, 1717, 1279, 6103, 3509, 17499, 22989, 43157, 0 };
            const std::uint32_t dim11608JoeKuoD6Init[]   =   { 1, 1, 1, 7, 11, 51, 55, 119, 145, 505, 179, 3979, 1237, 12801, 15921, 13561, 69161, 0 };
            const std::uint32_t dim11609JoeKuoD6Init[]   =   { 1, 1, 5, 7, 13, 9, 73, 203, 247, 257, 1607, 1183, 6237, 12327, 5059, 51645, 88781, 0 };
            const std::uint32_t dim11610JoeKuoD6Init[]   =   { 1, 3, 5, 9, 1, 9, 27, 59, 235, 81, 689, 2457, 893, 6107, 27643, 40145, 2329, 0 };
            const std::uint32_t dim11611JoeKuoD6Init[]   =   { 1, 1, 1, 11, 11, 19, 65, 63, 27, 513, 1473, 2955, 8037, 4991, 22035, 41965, 82589, 0 };
            const std::uint32_t dim11612JoeKuoD6Init[]   =   { 1, 3, 1, 1, 9, 53, 97, 95, 247, 379, 259, 2789, 1433, 15299, 18309, 51813, 63271, 0 };
            const std::uint32_t dim11613JoeKuoD6Init[]   =   { 1, 1, 5, 1, 11, 41, 69, 193, 391, 27, 1511, 1575, 1161, 14741, 25193, 31149, 79573, 0 };
            const std::uint32_t dim11614JoeKuoD6Init[]   =   { 1, 3, 7, 15, 19, 31, 101, 9, 111, 427, 531, 1335, 767, 15075, 28373, 54015, 108021, 0 };
            const std::uint32_t dim11615JoeKuoD6Init[]   =   { 1, 3, 1, 3, 29, 17, 83, 163, 179, 703, 2027, 3027, 5267, 16111, 23929, 9653, 38633, 0 };
            const std::uint32_t dim11616JoeKuoD6Init[]   =   { 1, 3, 5, 9, 3, 7, 111, 1, 311, 143, 1563, 2605, 301, 2447, 5009, 63767, 37529, 0 };
            const std::uint32_t dim11617JoeKuoD6Init[]   =   { 1, 3, 5, 5, 23, 23, 97, 11, 475, 741, 1385, 2491, 1717, 14587, 6289, 27651, 21873, 0 };
            const std::uint32_t dim11618JoeKuoD6Init[]   =   { 1, 1, 5, 1, 31, 31, 119, 93, 209, 861, 1591, 1233, 3469, 9799, 5969, 35965, 110841, 0 };
            const std::uint32_t dim11619JoeKuoD6Init[]   =   { 1, 1, 5, 13, 19, 31, 69, 107, 423, 651, 757, 665, 1297, 9985, 14983, 3153, 26425, 0 };
            const std::uint32_t dim11620JoeKuoD6Init[]   =   { 1, 1, 5, 3, 23, 5, 89, 77, 461, 799, 683, 2885, 845, 12847, 26721, 13145, 88689, 0 };
            const std::uint32_t dim11621JoeKuoD6Init[]   =   { 1, 1, 3, 3, 19, 3, 41, 71, 247, 293, 1047, 2349, 6815, 2413, 13683, 51421, 110737, 0 };
            const std::uint32_t dim11622JoeKuoD6Init[]   =   { 1, 3, 3, 9, 19, 51, 91, 193, 447, 305, 751, 1757, 1547, 12683, 4645, 39767, 6433, 0 };
            const std::uint32_t dim11623JoeKuoD6Init[]   =   { 1, 1, 7, 1, 11, 51, 83, 175, 461, 259, 1337, 175, 877, 15895, 22487, 8079, 71291, 0 };
            const std::uint32_t dim11624JoeKuoD6Init[]   =   { 1, 1, 1, 11, 13, 23, 19, 69, 285, 629, 563, 2433, 815, 4851, 10617, 59949, 59119, 0 };
            const std::uint32_t dim11625JoeKuoD6Init[]   =   { 1, 3, 5, 5, 19, 49, 47, 27, 343, 579, 197, 35, 7051, 2441, 30091, 9645, 101899, 0 };
            const std::uint32_t dim11626JoeKuoD6Init[]   =   { 1, 1, 3, 3, 21, 25, 125, 215, 159, 259, 1915, 2193, 4213, 16157, 8665, 10967, 112793, 0 };
            const std::uint32_t dim11627JoeKuoD6Init[]   =   { 1, 1, 5, 11, 29, 11, 53, 45, 121, 533, 257, 1749, 6311, 7715, 12037, 12003, 38987, 0 };
            const std::uint32_t dim11628JoeKuoD6Init[]   =   { 1, 3, 1, 11, 25, 31, 93, 191, 231, 801, 361, 1275, 5031, 7927, 26333, 39795, 45875, 0 };
            const std::uint32_t dim11629JoeKuoD6Init[]   =   { 1, 1, 5, 1, 7, 37, 117, 35, 257, 225, 1769, 1805, 1593, 1507, 27741, 31561, 52107, 0 };
            const std::uint32_t dim11630JoeKuoD6Init[]   =   { 1, 1, 3, 3, 27, 23, 55, 5, 137, 677, 459, 2821, 1331, 5845, 17751, 17557, 60495, 0 };
            const std::uint32_t dim11631JoeKuoD6Init[]   =   { 1, 1, 7, 7, 5, 47, 85, 17, 287, 757, 2013, 2233, 2975, 13769, 23199, 32117, 84429, 0 };
            const std::uint32_t dim11632JoeKuoD6Init[]   =   { 1, 3, 3, 11, 1, 15, 39, 133, 79, 915, 147, 1489, 2319, 13715, 31317, 46785, 64147, 0 };
            const std::uint32_t dim11633JoeKuoD6Init[]   =   { 1, 1, 3, 11, 1, 25, 83, 69, 395, 537, 895, 565, 2781, 12685, 7831, 36369, 27871, 0 };
            const std::uint32_t dim11634JoeKuoD6Init[]   =   { 1, 1, 1, 1, 13, 17, 59, 179, 509, 979, 315, 3495, 1773, 16375, 27873, 18065, 20285, 0 };
            const std::uint32_t dim11635JoeKuoD6Init[]   =   { 1, 1, 5, 1, 27, 31, 39, 251, 121, 899, 751, 1603, 7501, 425, 25791, 35407, 110405, 0 };
            const std::uint32_t dim11636JoeKuoD6Init[]   =   { 1, 1, 7, 11, 11, 3, 107, 247, 79, 349, 405, 3469, 2201, 8007, 22891, 7901, 11413, 0 };
            const std::uint32_t dim11637JoeKuoD6Init[]   =   { 1, 1, 1, 11, 15, 55, 121, 151, 127, 239, 115, 611, 6191, 15435, 19831, 64745, 110473, 0 };
            const std::uint32_t dim11638JoeKuoD6Init[]   =   { 1, 1, 7, 1, 21, 25, 57, 11, 31, 823, 1855, 2337, 7655, 10845, 22167, 36977, 94265, 0 };
            const std::uint32_t dim11639JoeKuoD6Init[]   =   { 1, 3, 5, 1, 31, 11, 117, 97, 341, 953, 1499, 2487, 559, 8609, 6321, 20669, 28945, 0 };
            const std::uint32_t dim11640JoeKuoD6Init[]   =   { 1, 3, 7, 1, 5, 27, 15, 161, 83, 139, 75, 3645, 5227, 16199, 1833, 21767, 67579, 0 };
            const std::uint32_t dim11641JoeKuoD6Init[]   =   { 1, 1, 7, 5, 31, 35, 75, 115, 451, 773, 1987, 1069, 651, 961, 16317, 18391, 56519, 0 };
            const std::uint32_t dim11642JoeKuoD6Init[]   =   { 1, 1, 1, 1, 31, 11, 23, 255, 215, 251, 867, 2381, 2351, 13189, 17705, 33569, 102361, 0 };
            const std::uint32_t dim11643JoeKuoD6Init[]   =   { 1, 3, 7, 1, 17, 49, 49, 125, 445, 947, 1985, 2113, 3025, 6277, 1981, 33329, 99413, 0 };
            const std::uint32_t dim11644JoeKuoD6Init[]   =   { 1, 3, 3, 3, 27, 7, 59, 109, 37, 777, 1359, 2157, 3185, 7317, 30887, 10499, 126563, 0 };
            const std::uint32_t dim11645JoeKuoD6Init[]   =   { 1, 3, 3, 9, 27, 5, 99, 167, 457, 363, 2031, 1805, 4661, 8695, 4667, 61129, 81143, 0 };
            const std::uint32_t dim11646JoeKuoD6Init[]   =   { 1, 1, 5, 13, 5, 47, 95, 249, 289, 631, 1739, 2947, 7169, 13019, 10429, 16197, 11539, 0 };
            const std::uint32_t dim11647JoeKuoD6Init[]   =   { 1, 3, 7, 15, 27, 45, 93, 131, 269, 835, 399, 1133, 6509, 1279, 3635, 17977, 38667, 0 };
            const std::uint32_t dim11648JoeKuoD6Init[]   =   { 1, 1, 5, 3, 17, 51, 1, 77, 105, 237, 995, 2643, 6921, 6707, 30129, 1543, 94501, 0 };
            const std::uint32_t dim11649JoeKuoD6Init[]   =   { 1, 1, 1, 7, 29, 1, 117, 33, 141, 805, 1553, 3943, 45, 8911, 24191, 45191, 36525, 0 };
            const std::uint32_t dim11650JoeKuoD6Init[]   =   { 1, 1, 7, 7, 31, 21, 97, 29, 179, 345, 1059, 701, 7709, 15831, 22923, 57233, 58961, 0 };
            const std::uint32_t dim11651JoeKuoD6Init[]   =   { 1, 1, 3, 15, 15, 5, 85, 227, 13, 351, 1167, 3283, 6833, 565, 21019, 53249, 4639, 0 };
            const std::uint32_t dim11652JoeKuoD6Init[]   =   { 1, 3, 3, 5, 27, 1, 5, 89, 101, 295, 481, 2397, 1459, 3729, 3703, 25109, 69237, 0 };
            const std::uint32_t dim11653JoeKuoD6Init[]   =   { 1, 3, 7, 13, 31, 37, 69, 147, 505, 487, 1701, 1145, 2061, 10067, 18269, 13049, 92091, 0 };
            const std::uint32_t dim11654JoeKuoD6Init[]   =   { 1, 3, 3, 1, 29, 39, 33, 199, 499, 377, 1081, 3787, 4843, 16287, 23397, 19083, 91381, 0 };
            const std::uint32_t dim11655JoeKuoD6Init[]   =   { 1, 1, 1, 13, 21, 61, 121, 251, 511, 615, 625, 2245, 5951, 16165, 2155, 37301, 68319, 0 };
            const std::uint32_t dim11656JoeKuoD6Init[]   =   { 1, 1, 1, 15, 19, 35, 57, 99, 1, 97, 1177, 3109, 7213, 5447, 25251, 24803, 107449, 0 };
            const std::uint32_t dim11657JoeKuoD6Init[]   =   { 1, 3, 1, 11, 11, 59, 95, 135, 329, 931, 843, 2847, 463, 10725, 3933, 32325, 44545, 0 };
            const std::uint32_t dim11658JoeKuoD6Init[]   =   { 1, 1, 7, 13, 13, 57, 29, 175, 11, 701, 231, 2907, 5555, 16159, 1249, 38049, 40115, 0 };
            const std::uint32_t dim11659JoeKuoD6Init[]   =   { 1, 1, 5, 15, 23, 37, 47, 221, 465, 631, 57, 1189, 2083, 6561, 10725, 8015, 21231, 0 };
            const std::uint32_t dim11660JoeKuoD6Init[]   =   { 1, 3, 7, 5, 9, 25, 31, 47, 139, 639, 999, 2909, 39, 16227, 16967, 30555, 125541, 0 };
            const std::uint32_t dim11661JoeKuoD6Init[]   =   { 1, 3, 3, 9, 5, 3, 9, 9, 43, 999, 159, 3063, 3661, 7089, 28929, 55305, 105521, 0 };
            const std::uint32_t dim11662JoeKuoD6Init[]   =   { 1, 3, 1, 11, 17, 7, 3, 57, 457, 753, 135, 3721, 1111, 7267, 12603, 50511, 85433, 0 };
            const std::uint32_t dim11663JoeKuoD6Init[]   =   { 1, 3, 5, 1, 27, 3, 107, 187, 247, 891, 1311, 423, 1767, 14769, 22119, 36225, 94267, 0 };
            const std::uint32_t dim11664JoeKuoD6Init[]   =   { 1, 3, 5, 15, 1, 13, 65, 35, 435, 557, 1755, 1343, 2647, 179, 7781, 62903, 18741, 0 };
            const std::uint32_t dim11665JoeKuoD6Init[]   =   { 1, 1, 7, 15, 29, 57, 63, 227, 407, 163, 1207, 2717, 2731, 1737, 6379, 14937, 46683, 0 };
            const std::uint32_t dim11666JoeKuoD6Init[]   =   { 1, 1, 1, 9, 25, 35, 93, 1, 77, 677, 875, 3787, 3075, 14033, 23017, 3487, 14999, 0 };
            const std::uint32_t dim11667JoeKuoD6Init[]   =   { 1, 3, 3, 9, 3, 45, 115, 61, 437, 823, 1401, 459, 301, 5519, 31003, 64499, 1757, 0 };
            const std::uint32_t dim11668JoeKuoD6Init[]   =   { 1, 3, 1, 11, 23, 37, 69, 215, 197, 961, 1501, 2953, 3679, 6775, 24679, 44215, 52357, 0 };
            const std::uint32_t dim11669JoeKuoD6Init[]   =   { 1, 3, 1, 15, 29, 23, 1, 133, 451, 677, 687, 1269, 5987, 11975, 11929, 63691, 48683, 0 };
            const std::uint32_t dim11670JoeKuoD6Init[]   =   { 1, 1, 1, 7, 13, 31, 13, 71, 355, 345, 1193, 3421, 7601, 7413, 6719, 28681, 97605, 0 };
            const std::uint32_t dim11671JoeKuoD6Init[]   =   { 1, 1, 5, 13, 23, 3, 15, 253, 109, 17, 341, 471, 1131, 14901, 31783, 41369, 64139, 0 };
            const std::uint32_t dim11672JoeKuoD6Init[]   =   { 1, 1, 3, 1, 25, 25, 85, 157, 443, 83, 269, 3789, 7977, 7783, 28433, 30563, 82805, 0 };
            const std::uint32_t dim11673JoeKuoD6Init[]   =   { 1, 1, 7, 5, 3, 11, 83, 63, 253, 349, 217, 2733, 4183, 2759, 7617, 41749, 14015, 0 };
            const std::uint32_t dim11674JoeKuoD6Init[]   =   { 1, 1, 5, 7, 7, 7, 91, 201, 449, 247, 889, 3829, 3529, 14253, 24091, 33521, 6049, 0 };
            const std::uint32_t dim11675JoeKuoD6Init[]   =   { 1, 1, 3, 7, 25, 7, 123, 161, 227, 965, 511, 619, 4359, 11833, 12859, 26091, 3867, 0 };
            const std::uint32_t dim11676JoeKuoD6Init[]   =   { 1, 1, 7, 9, 5, 41, 71, 111, 95, 261, 1809, 3835, 7625, 12085, 28885, 64829, 48981, 0 };
            const std::uint32_t dim11677JoeKuoD6Init[]   =   { 1, 1, 5, 3, 13, 55, 57, 79, 457, 785, 653, 1429, 3879, 13559, 3953, 18205, 5777, 0 };
            const std::uint32_t dim11678JoeKuoD6Init[]   =   { 1, 3, 5, 9, 23, 25, 107, 255, 151, 191, 119, 3367, 1081, 12691, 3575, 38171, 42573, 0 };
            const std::uint32_t dim11679JoeKuoD6Init[]   =   { 1, 1, 7, 15, 3, 23, 115, 233, 265, 187, 1961, 1303, 5101, 1035, 6803, 14557, 4527, 0 };
            const std::uint32_t dim11680JoeKuoD6Init[]   =   { 1, 1, 3, 11, 19, 37, 45, 167, 17, 793, 1361, 3571, 5889, 14421, 20453, 5093, 59927, 0 };
            const std::uint32_t dim11681JoeKuoD6Init[]   =   { 1, 1, 7, 15, 3, 53, 1, 11, 159, 389, 171, 2351, 7189, 3109, 1541, 53595, 24247, 0 };
            const std::uint32_t dim11682JoeKuoD6Init[]   =   { 1, 1, 7, 1, 7, 43, 75, 175, 253, 687, 1811, 3277, 447, 8711, 14281, 53265, 7379, 0 };
            const std::uint32_t dim11683JoeKuoD6Init[]   =   { 1, 1, 5, 3, 21, 45, 113, 25, 309, 31, 1765, 305, 1423, 115, 26421, 50267, 122115, 0 };
            const std::uint32_t dim11684JoeKuoD6Init[]   =   { 1, 3, 5, 13, 15, 47, 17, 17, 445, 775, 243, 3959, 7263, 9375, 12017, 57399, 58203, 0 };
            const std::uint32_t dim11685JoeKuoD6Init[]   =   { 1, 3, 3, 1, 31, 37, 37, 213, 125, 929, 243, 1011, 2841, 4499, 16961, 12639, 23381, 0 };
            const std::uint32_t dim11686JoeKuoD6Init[]   =   { 1, 3, 1, 3, 7, 53, 31, 165, 311, 239, 731, 1759, 1769, 203, 23201, 20267, 33381, 0 };
            const std::uint32_t dim11687JoeKuoD6Init[]   =   { 1, 3, 3, 11, 1, 1, 73, 57, 497, 693, 693, 861, 5587, 16307, 8559, 28785, 91147, 0 };
            const std::uint32_t dim11688JoeKuoD6Init[]   =   { 1, 3, 1, 3, 11, 61, 11, 241, 473, 479, 1831, 1771, 25, 10217, 32683, 40165, 98433, 0 };
            const std::uint32_t dim11689JoeKuoD6Init[]   =   { 1, 1, 5, 3, 17, 51, 39, 27, 189, 631, 689, 2849, 1849, 9143, 19263, 32729, 23031, 0 };
            const std::uint32_t dim11690JoeKuoD6Init[]   =   { 1, 1, 5, 9, 15, 39, 103, 83, 485, 689, 1561, 55, 5219, 12069, 32225, 7781, 114299, 0 };
            const std::uint32_t dim11691JoeKuoD6Init[]   =   { 1, 1, 1, 1, 31, 49, 71, 145, 485, 907, 1551, 3931, 4081, 2159, 24747, 6953, 15887, 0 };
            const std::uint32_t dim11692JoeKuoD6Init[]   =   { 1, 1, 3, 7, 27, 61, 57, 153, 15, 881, 271, 267, 5827, 7625, 18179, 3769, 42211, 0 };
            const std::uint32_t dim11693JoeKuoD6Init[]   =   { 1, 3, 1, 3, 21, 49, 65, 177, 341, 851, 1825, 3347, 113, 8077, 1117, 9463, 115821, 0 };
            const std::uint32_t dim11694JoeKuoD6Init[]   =   { 1, 3, 5, 11, 27, 17, 75, 35, 475, 389, 313, 2187, 7005, 911, 21921, 10979, 13705, 0 };
            const std::uint32_t dim11695JoeKuoD6Init[]   =   { 1, 1, 5, 9, 1, 49, 15, 21, 163, 355, 193, 3473, 4451, 5325, 28343, 251, 125963, 0 };
            const std::uint32_t dim11696JoeKuoD6Init[]   =   { 1, 3, 7, 1, 9, 63, 9, 129, 453, 887, 1841, 597, 1989, 14755, 7847, 7581, 251, 0 };
            const std::uint32_t dim11697JoeKuoD6Init[]   =   { 1, 3, 7, 13, 31, 15, 123, 3, 427, 101, 1039, 1355, 3653, 2871, 28937, 31243, 108827, 0 };
            const std::uint32_t dim11698JoeKuoD6Init[]   =   { 1, 3, 7, 13, 3, 17, 71, 243, 145, 747, 1933, 1105, 455, 6355, 20321, 60075, 31575, 0 };
            const std::uint32_t dim11699JoeKuoD6Init[]   =   { 1, 3, 5, 5, 11, 25, 95, 85, 461, 459, 313, 173, 1413, 15761, 31481, 63793, 29047, 0 };
            const std::uint32_t dim11700JoeKuoD6Init[]   =   { 1, 3, 7, 7, 3, 5, 3, 95, 107, 995, 1203, 2965, 2419, 5325, 17667, 40205, 91059, 0 };
            const std::uint32_t dim11701JoeKuoD6Init[]   =   { 1, 1, 3, 9, 25, 3, 113, 79, 359, 69, 93, 1539, 483, 12701, 19075, 35021, 17929, 0 };
            const std::uint32_t dim11702JoeKuoD6Init[]   =   { 1, 3, 5, 1, 31, 35, 67, 97, 105, 381, 973, 1355, 3901, 3847, 12343, 64309, 29835, 0 };
            const std::uint32_t dim11703JoeKuoD6Init[]   =   { 1, 3, 7, 1, 11, 33, 117, 237, 449, 101, 317, 23, 5157, 8187, 28839, 29465, 97485, 0 };
            const std::uint32_t dim11704JoeKuoD6Init[]   =   { 1, 3, 5, 5, 1, 49, 93, 71, 89, 607, 1143, 3271, 5825, 8529, 18479, 23859, 40571, 0 };
            const std::uint32_t dim11705JoeKuoD6Init[]   =   { 1, 3, 1, 3, 13, 35, 79, 9, 315, 943, 1199, 1521, 2023, 11745, 8273, 27643, 89545, 0 };
            const std::uint32_t dim11706JoeKuoD6Init[]   =   { 1, 3, 5, 1, 21, 3, 15, 111, 19, 895, 1539, 3331, 6741, 9087, 5231, 13435, 60645, 0 };
            const std::uint32_t dim11707JoeKuoD6Init[]   =   { 1, 3, 1, 9, 25, 9, 109, 253, 263, 425, 915, 1955, 659, 6249, 11803, 34523, 22645, 0 };
            const std::uint32_t dim11708JoeKuoD6Init[]   =   { 1, 1, 1, 9, 15, 23, 13, 79, 369, 689, 565, 743, 3897, 8837, 13753, 17213, 86801, 0 };
            const std::uint32_t dim11709JoeKuoD6Init[]   =   { 1, 1, 1, 5, 31, 27, 111, 231, 25, 617, 897, 1325, 4885, 5731, 2027, 34639, 67863, 0 };
            const std::uint32_t dim11710JoeKuoD6Init[]   =   { 1, 1, 3, 13, 1, 9, 29, 23, 95, 113, 1035, 2729, 6555, 335, 24795, 35387, 31301, 0 };
            const std::uint32_t dim11711JoeKuoD6Init[]   =   { 1, 1, 1, 7, 3, 53, 91, 143, 167, 773, 207, 31, 4993, 7953, 26997, 40031, 113939, 0 };
            const std::uint32_t dim11712JoeKuoD6Init[]   =   { 1, 1, 3, 5, 17, 43, 121, 231, 411, 575, 1621, 3079, 535, 3313, 19443, 58271, 54207, 0 };
            const std::uint32_t dim11713JoeKuoD6Init[]   =   { 1, 1, 1, 7, 11, 41, 61, 81, 97, 91, 1987, 981, 3745, 819, 23785, 48331, 63761, 0 };
            const std::uint32_t dim11714JoeKuoD6Init[]   =   { 1, 1, 5, 13, 7, 29, 25, 73, 355, 669, 241, 65, 2249, 5551, 5217, 58573, 34049, 0 };
            const std::uint32_t dim11715JoeKuoD6Init[]   =   { 1, 1, 7, 11, 1, 45, 125, 107, 127, 639, 1989, 2727, 2103, 8985, 30249, 40037, 40931, 0 };
            const std::uint32_t dim11716JoeKuoD6Init[]   =   { 1, 1, 5, 13, 21, 59, 99, 131, 359, 615, 665, 577, 2559, 3555, 11355, 26213, 76427, 0 };
            const std::uint32_t dim11717JoeKuoD6Init[]   =   { 1, 3, 3, 1, 19, 9, 85, 111, 381, 661, 561, 3419, 1355, 8473, 329, 4989, 9087, 0 };
            const std::uint32_t dim11718JoeKuoD6Init[]   =   { 1, 1, 7, 5, 11, 23, 33, 95, 343, 9, 1579, 2663, 6245, 267, 7187, 25381, 103181, 0 };
            const std::uint32_t dim11719JoeKuoD6Init[]   =   { 1, 1, 7, 11, 23, 7, 113, 49, 89, 587, 1221, 409, 873, 15531, 2721, 44519, 25349, 0 };
            const std::uint32_t dim11720JoeKuoD6Init[]   =   { 1, 3, 3, 1, 17, 17, 45, 239, 453, 639, 1433, 2829, 6009, 12447, 9393, 59979, 93343, 0 };
            const std::uint32_t dim11721JoeKuoD6Init[]   =   { 1, 1, 3, 15, 19, 61, 125, 101, 219, 327, 1551, 1623, 951, 8379, 21009, 64089, 21891, 0 };
            const std::uint32_t dim11722JoeKuoD6Init[]   =   { 1, 1, 5, 7, 23, 5, 111, 43, 57, 71, 407, 4027, 4869, 12033, 19941, 51969, 120115, 0 };
            const std::uint32_t dim11723JoeKuoD6Init[]   =   { 1, 3, 7, 15, 17, 49, 31, 145, 185, 169, 1559, 4011, 5293, 7559, 23487, 12213, 2757, 0 };
            const std::uint32_t dim11724JoeKuoD6Init[]   =   { 1, 3, 7, 3, 3, 59, 119, 3, 509, 539, 1623, 539, 1405, 3913, 213, 30293, 68497, 0 };
            const std::uint32_t dim11725JoeKuoD6Init[]   =   { 1, 1, 1, 9, 15, 43, 67, 171, 397, 233, 379, 1681, 6877, 9169, 19667, 1971, 115347, 0 };
            const std::uint32_t dim11726JoeKuoD6Init[]   =   { 1, 1, 5, 15, 1, 45, 25, 133, 99, 181, 1825, 3485, 5633, 4629, 30181, 15761, 87161, 0 };
            const std::uint32_t dim11727JoeKuoD6Init[]   =   { 1, 1, 5, 3, 5, 55, 97, 117, 303, 591, 733, 3631, 4305, 169, 5361, 64491, 71793, 0 };
            const std::uint32_t dim11728JoeKuoD6Init[]   =   { 1, 1, 5, 11, 19, 9, 5, 147, 223, 51, 1763, 3899, 7393, 8107, 19619, 60509, 61427, 0 };
            const std::uint32_t dim11729JoeKuoD6Init[]   =   { 1, 1, 1, 15, 15, 3, 103, 15, 423, 649, 613, 1387, 6229, 4147, 17517, 225, 35697, 0 };
            const std::uint32_t dim11730JoeKuoD6Init[]   =   { 1, 3, 1, 3, 21, 57, 77, 193, 203, 649, 631, 3753, 4259, 3983, 27707, 33623, 83857, 0 };
            const std::uint32_t dim11731JoeKuoD6Init[]   =   { 1, 3, 3, 5, 11, 37, 95, 201, 83, 643, 1639, 153, 7683, 15249, 23859, 27021, 43321, 0 };
            const std::uint32_t dim11732JoeKuoD6Init[]   =   { 1, 3, 5, 13, 23, 31, 69, 215, 303, 433, 1325, 1013, 2903, 12659, 3813, 34497, 59651, 0 };
            const std::uint32_t dim11733JoeKuoD6Init[]   =   { 1, 3, 1, 9, 15, 39, 113, 253, 173, 393, 19, 2343, 2939, 8871, 29741, 2141, 121675, 0 };
            const std::uint32_t dim11734JoeKuoD6Init[]   =   { 1, 1, 7, 9, 7, 9, 91, 211, 169, 299, 507, 2849, 1321, 15397, 23949, 32387, 108691, 0 };
            const std::uint32_t dim11735JoeKuoD6Init[]   =   { 1, 1, 7, 13, 1, 21, 119, 127, 229, 253, 39, 323, 1831, 121, 17385, 45511, 43743, 0 };
            const std::uint32_t dim11736JoeKuoD6Init[]   =   { 1, 1, 1, 15, 25, 25, 97, 209, 375, 945, 1343, 2205, 1701, 13085, 25547, 55555, 129395, 0 };
            const std::uint32_t dim11737JoeKuoD6Init[]   =   { 1, 1, 1, 5, 31, 25, 91, 255, 163, 169, 703, 1607, 4731, 7413, 10013, 10925, 109151, 0 };
            const std::uint32_t dim11738JoeKuoD6Init[]   =   { 1, 3, 3, 9, 15, 47, 71, 219, 9, 37, 231, 3227, 3447, 8129, 23421, 30113, 120725, 0 };
            const std::uint32_t dim11739JoeKuoD6Init[]   =   { 1, 3, 3, 11, 15, 47, 93, 203, 299, 865, 151, 3999, 1245, 8487, 13355, 27373, 93583, 0 };
            const std::uint32_t dim11740JoeKuoD6Init[]   =   { 1, 3, 7, 5, 13, 7, 97, 81, 271, 95, 513, 365, 5039, 403, 5285, 29475, 129347, 0 };
            const std::uint32_t dim11741JoeKuoD6Init[]   =   { 1, 1, 7, 7, 9, 27, 25, 207, 161, 785, 1453, 3031, 763, 2313, 29347, 61457, 52561, 0 };
            const std::uint32_t dim11742JoeKuoD6Init[]   =   { 1, 3, 3, 11, 25, 25, 39, 61, 165, 803, 1435, 3643, 299, 13751, 24239, 53955, 94889, 0 };
            const std::uint32_t dim11743JoeKuoD6Init[]   =   { 1, 3, 5, 9, 9, 13, 63, 221, 123, 947, 905, 913, 953, 7429, 25409, 43017, 2217, 0 };
            const std::uint32_t dim11744JoeKuoD6Init[]   =   { 1, 1, 3, 3, 31, 19, 107, 211, 503, 675, 1921, 3027, 1273, 5699, 20683, 55605, 119803, 0 };
            const std::uint32_t dim11745JoeKuoD6Init[]   =   { 1, 1, 3, 3, 9, 17, 115, 183, 325, 259, 2013, 1505, 6999, 11573, 5315, 18731, 9405, 0 };
            const std::uint32_t dim11746JoeKuoD6Init[]   =   { 1, 3, 1, 5, 29, 37, 81, 145, 5, 851, 1803, 2011, 6655, 3601, 11325, 17137, 68501, 0 };
            const std::uint32_t dim11747JoeKuoD6Init[]   =   { 1, 3, 5, 1, 25, 51, 111, 19, 75, 765, 1843, 139, 7253, 12967, 13387, 48631, 124881, 0 };
            const std::uint32_t dim11748JoeKuoD6Init[]   =   { 1, 3, 3, 7, 15, 29, 7, 231, 13, 901, 1913, 3817, 3993, 3049, 32367, 4201, 90837, 0 };
            const std::uint32_t dim11749JoeKuoD6Init[]   =   { 1, 3, 1, 11, 27, 5, 109, 57, 81, 147, 1141, 2153, 5255, 6367, 189, 5959, 88843, 0 };
            const std::uint32_t dim11750JoeKuoD6Init[]   =   { 1, 3, 5, 5, 19, 35, 17, 149, 407, 889, 1583, 1727, 465, 10785, 6043, 21785, 80935, 0 };
            const std::uint32_t dim11751JoeKuoD6Init[]   =   { 1, 1, 3, 7, 15, 21, 105, 249, 427, 491, 923, 3189, 8103, 3875, 18347, 35799, 36703, 0 };
            const std::uint32_t dim11752JoeKuoD6Init[]   =   { 1, 1, 3, 15, 3, 45, 93, 197, 265, 309, 1909, 1635, 1743, 9499, 21897, 36889, 67449, 0 };
            const std::uint32_t dim11753JoeKuoD6Init[]   =   { 1, 3, 1, 11, 15, 57, 31, 231, 363, 879, 1377, 1941, 6969, 10721, 21933, 33419, 102939, 0 };
            const std::uint32_t dim11754JoeKuoD6Init[]   =   { 1, 1, 3, 9, 3, 57, 49, 51, 71, 991, 885, 1367, 2937, 9301, 29893, 9867, 113711, 0 };
            const std::uint32_t dim11755JoeKuoD6Init[]   =   { 1, 3, 7, 7, 11, 59, 123, 247, 51, 659, 1323, 3371, 3417, 12295, 2021, 62753, 28059, 0 };
            const std::uint32_t dim11756JoeKuoD6Init[]   =   { 1, 1, 7, 11, 3, 57, 53, 1, 203, 287, 219, 3531, 1365, 6235, 30187, 4479, 29567, 0 };
            const std::uint32_t dim11757JoeKuoD6Init[]   =   { 1, 1, 7, 9, 5, 41, 41, 39, 137, 495, 149, 2421, 7365, 11381, 25403, 16063, 47491, 0 };
            const std::uint32_t dim11758JoeKuoD6Init[]   =   { 1, 1, 5, 13, 25, 25, 47, 25, 213, 661, 1345, 883, 7573, 3291, 21303, 8033, 102639, 0 };
            const std::uint32_t dim11759JoeKuoD6Init[]   =   { 1, 1, 5, 3, 9, 49, 75, 221, 455, 139, 1533, 3155, 1023, 7249, 10129, 63165, 1713, 0 };
            const std::uint32_t dim11760JoeKuoD6Init[]   =   { 1, 3, 5, 11, 17, 1, 23, 241, 83, 359, 1243, 2791, 2975, 6271, 19035, 55057, 7625, 0 };
            const std::uint32_t dim11761JoeKuoD6Init[]   =   { 1, 3, 1, 9, 17, 61, 109, 255, 447, 939, 899, 551, 7049, 4247, 17333, 43369, 30105, 0 };
            const std::uint32_t dim11762JoeKuoD6Init[]   =   { 1, 1, 3, 5, 3, 31, 79, 39, 225, 605, 1893, 3523, 5391, 6879, 18619, 2339, 108295, 0 };
            const std::uint32_t dim11763JoeKuoD6Init[]   =   { 1, 1, 5, 1, 29, 15, 123, 39, 239, 57, 843, 2799, 4755, 4993, 23383, 45559, 48359, 0 };
            const std::uint32_t dim11764JoeKuoD6Init[]   =   { 1, 1, 5, 5, 7, 5, 99, 1, 351, 213, 1061, 721, 343, 16071, 29641, 55607, 76727, 0 };
            const std::uint32_t dim11765JoeKuoD6Init[]   =   { 1, 3, 1, 7, 9, 9, 15, 25, 87, 595, 71, 3769, 2583, 10105, 28639, 48899, 49753, 0 };
            const std::uint32_t dim11766JoeKuoD6Init[]   =   { 1, 3, 5, 3, 31, 29, 99, 77, 323, 615, 581, 1725, 2471, 16263, 4903, 205, 55441, 0 };
            const std::uint32_t dim11767JoeKuoD6Init[]   =   { 1, 1, 5, 11, 17, 53, 47, 53, 125, 717, 867, 1251, 4009, 13981, 10165, 4769, 117431, 0 };
            const std::uint32_t dim11768JoeKuoD6Init[]   =   { 1, 1, 3, 7, 7, 19, 119, 27, 163, 11, 693, 3197, 3981, 12591, 26017, 62113, 48391, 0 };
            const std::uint32_t dim11769JoeKuoD6Init[]   =   { 1, 1, 3, 15, 13, 17, 13, 81, 19, 821, 677, 233, 5227, 14855, 18269, 18895, 90041, 0 };
            const std::uint32_t dim11770JoeKuoD6Init[]   =   { 1, 1, 3, 9, 27, 61, 125, 221, 415, 183, 1137, 1879, 3451, 3599, 27317, 53449, 35499, 0 };
            const std::uint32_t dim11771JoeKuoD6Init[]   =   { 1, 3, 3, 15, 3, 27, 53, 93, 17, 405, 373, 2531, 3121, 2299, 1593, 34623, 102389, 0 };
            const std::uint32_t dim11772JoeKuoD6Init[]   =   { 1, 1, 1, 11, 23, 19, 85, 87, 209, 17, 1805, 4067, 7401, 6097, 5865, 61383, 42971, 0 };
            const std::uint32_t dim11773JoeKuoD6Init[]   =   { 1, 1, 7, 9, 29, 43, 99, 125, 385, 347, 97, 1121, 1533, 10545, 17383, 48649, 78443, 0 };
            const std::uint32_t dim11774JoeKuoD6Init[]   =   { 1, 3, 3, 13, 7, 9, 95, 105, 463, 911, 357, 423, 5701, 2389, 16307, 17817, 108775, 0 };
            const std::uint32_t dim11775JoeKuoD6Init[]   =   { 1, 3, 5, 11, 21, 21, 79, 53, 511, 995, 1709, 1715, 6031, 10507, 10735, 48817, 28569, 0 };
            const std::uint32_t dim11776JoeKuoD6Init[]   =   { 1, 3, 5, 7, 31, 49, 43, 109, 267, 981, 1529, 3611, 3379, 1295, 27489, 46721, 58423, 0 };
            const std::uint32_t dim11777JoeKuoD6Init[]   =   { 1, 3, 3, 11, 3, 31, 21, 3, 79, 31, 1885, 3029, 6337, 15457, 8995, 9955, 95019, 0 };
            const std::uint32_t dim11778JoeKuoD6Init[]   =   { 1, 1, 7, 13, 9, 9, 77, 73, 111, 769, 813, 1599, 5925, 1063, 12151, 54125, 67723, 0 };
            const std::uint32_t dim11779JoeKuoD6Init[]   =   { 1, 1, 1, 7, 13, 5, 43, 201, 379, 199, 769, 3227, 3995, 1543, 21903, 10651, 122007, 0 };
            const std::uint32_t dim11780JoeKuoD6Init[]   =   { 1, 3, 7, 13, 11, 53, 83, 201, 231, 137, 617, 2395, 2513, 6659, 9387, 15653, 96927, 0 };
            const std::uint32_t dim11781JoeKuoD6Init[]   =   { 1, 3, 1, 13, 29, 19, 97, 57, 231, 985, 805, 1169, 831, 15867, 20195, 53533, 99735, 0 };
            const std::uint32_t dim11782JoeKuoD6Init[]   =   { 1, 1, 3, 13, 19, 15, 19, 39, 99, 31, 421, 755, 7439, 4927, 19893, 15449, 47937, 0 };
            const std::uint32_t dim11783JoeKuoD6Init[]   =   { 1, 3, 3, 9, 1, 17, 71, 37, 289, 537, 69, 3687, 6537, 12295, 28403, 6627, 72991, 0 };
            const std::uint32_t dim11784JoeKuoD6Init[]   =   { 1, 3, 3, 15, 31, 53, 21, 223, 451, 309, 895, 3923, 3149, 5167, 1979, 31425, 53485, 0 };
            const std::uint32_t dim11785JoeKuoD6Init[]   =   { 1, 3, 1, 1, 29, 7, 5, 197, 445, 455, 185, 633, 897, 4561, 28833, 39477, 46665, 0 };
            const std::uint32_t dim11786JoeKuoD6Init[]   =   { 1, 1, 3, 9, 29, 19, 45, 239, 323, 1005, 101, 2083, 7403, 10401, 987, 32301, 58141, 0 };
            const std::uint32_t dim11787JoeKuoD6Init[]   =   { 1, 3, 3, 5, 31, 17, 7, 141, 245, 301, 1607, 3381, 7517, 6663, 6327, 15321, 19963, 0 };
            const std::uint32_t dim11788JoeKuoD6Init[]   =   { 1, 1, 7, 5, 5, 37, 109, 31, 285, 767, 1689, 2961, 5511, 15415, 32011, 14889, 7237, 0 };
            const std::uint32_t dim11789JoeKuoD6Init[]   =   { 1, 1, 3, 7, 31, 35, 47, 157, 407, 719, 1213, 1241, 2475, 10321, 11547, 52641, 21603, 0 };
            const std::uint32_t dim11790JoeKuoD6Init[]   =   { 1, 1, 1, 7, 5, 45, 35, 137, 403, 321, 1151, 529, 6297, 3059, 27791, 18387, 101431, 0 };
            const std::uint32_t dim11791JoeKuoD6Init[]   =   { 1, 1, 3, 11, 21, 19, 97, 121, 377, 325, 741, 1601, 1115, 6233, 19089, 40491, 53259, 0 };
            const std::uint32_t dim11792JoeKuoD6Init[]   =   { 1, 1, 1, 9, 3, 13, 83, 243, 443, 91, 1455, 1875, 3327, 7245, 12735, 14943, 44163, 0 };
            const std::uint32_t dim11793JoeKuoD6Init[]   =   { 1, 3, 5, 11, 1, 15, 107, 211, 25, 125, 623, 1319, 6133, 12177, 1377, 32547, 110919, 0 };
            const std::uint32_t dim11794JoeKuoD6Init[]   =   { 1, 1, 3, 3, 7, 39, 23, 99, 433, 581, 53, 3421, 733, 12767, 23595, 22957, 88821, 0 };
            const std::uint32_t dim11795JoeKuoD6Init[]   =   { 1, 1, 1, 13, 5, 53, 103, 127, 409, 379, 1155, 3097, 6529, 11685, 22147, 46003, 59771, 0 };
            const std::uint32_t dim11796JoeKuoD6Init[]   =   { 1, 3, 3, 3, 15, 37, 9, 67, 237, 79, 697, 1943, 1021, 3217, 16013, 14727, 105729, 0 };
            const std::uint32_t dim11797JoeKuoD6Init[]   =   { 1, 1, 7, 1, 9, 43, 55, 79, 63, 553, 871, 2881, 6487, 4667, 24263, 41995, 60907, 0 };
            const std::uint32_t dim11798JoeKuoD6Init[]   =   { 1, 1, 7, 7, 23, 31, 55, 23, 451, 593, 85, 43, 965, 12491, 15121, 16129, 90639, 0 };
            const std::uint32_t dim11799JoeKuoD6Init[]   =   { 1, 1, 7, 13, 11, 53, 21, 123, 237, 147, 511, 2105, 5961, 4465, 4015, 19069, 89203, 0 };
            const std::uint32_t dim11800JoeKuoD6Init[]   =   { 1, 3, 5, 1, 1, 39, 59, 239, 391, 91, 923, 85, 1047, 1489, 31119, 58485, 129171, 0 };
            const std::uint32_t dim11801JoeKuoD6Init[]   =   { 1, 3, 5, 13, 3, 21, 35, 205, 219, 795, 901, 2465, 5887, 275, 22003, 29659, 50589, 0 };
            const std::uint32_t dim11802JoeKuoD6Init[]   =   { 1, 3, 1, 5, 1, 35, 127, 147, 159, 791, 1643, 1811, 1199, 3851, 9681, 19845, 127075, 0 };
            const std::uint32_t dim11803JoeKuoD6Init[]   =   { 1, 3, 3, 7, 17, 19, 13, 223, 395, 971, 125, 181, 4455, 13305, 30433, 46161, 122277, 0 };
            const std::uint32_t dim11804JoeKuoD6Init[]   =   { 1, 3, 1, 3, 19, 1, 15, 71, 425, 459, 655, 2251, 5525, 7611, 5819, 1255, 43107, 0 };
            const std::uint32_t dim11805JoeKuoD6Init[]   =   { 1, 1, 5, 15, 3, 9, 83, 191, 439, 663, 399, 2263, 1857, 15421, 2079, 2381, 59193, 0 };
            const std::uint32_t dim11806JoeKuoD6Init[]   =   { 1, 3, 5, 5, 1, 7, 9, 77, 347, 419, 1329, 3173, 7295, 3631, 13435, 3217, 18053, 0 };
            const std::uint32_t dim11807JoeKuoD6Init[]   =   { 1, 3, 3, 7, 29, 39, 35, 71, 119, 745, 603, 2247, 377, 3297, 30983, 27857, 105739, 0 };
            const std::uint32_t dim11808JoeKuoD6Init[]   =   { 1, 1, 5, 13, 9, 59, 57, 239, 247, 921, 1383, 2315, 241, 4435, 24661, 6129, 122727, 0 };
            const std::uint32_t dim11809JoeKuoD6Init[]   =   { 1, 1, 5, 7, 3, 15, 39, 165, 27, 803, 609, 3081, 6009, 12665, 24155, 51647, 3857, 0 };
            const std::uint32_t dim11810JoeKuoD6Init[]   =   { 1, 3, 5, 11, 27, 41, 61, 255, 195, 169, 557, 1739, 4029, 1791, 471, 16321, 49801, 0 };
            const std::uint32_t dim11811JoeKuoD6Init[]   =   { 1, 3, 7, 13, 17, 45, 35, 177, 109, 113, 551, 219, 4065, 303, 15489, 25427, 12349, 0 };
            const std::uint32_t dim11812JoeKuoD6Init[]   =   { 1, 3, 5, 5, 25, 15, 79, 165, 231, 867, 483, 3563, 6611, 11277, 3193, 37455, 127373, 0 };
            const std::uint32_t dim11813JoeKuoD6Init[]   =   { 1, 3, 3, 11, 25, 21, 47, 255, 27, 543, 485, 2675, 5893, 3029, 3857, 50967, 14681, 0 };
            const std::uint32_t dim11814JoeKuoD6Init[]   =   { 1, 3, 7, 11, 3, 23, 81, 135, 77, 227, 417, 1733, 5175, 15295, 15985, 50329, 48641, 0 };
            const std::uint32_t dim11815JoeKuoD6Init[]   =   { 1, 3, 5, 1, 3, 47, 33, 67, 201, 235, 1299, 3703, 1959, 8091, 11115, 10869, 9595, 0 };
            const std::uint32_t dim11816JoeKuoD6Init[]   =   { 1, 3, 7, 13, 1, 45, 61, 49, 471, 923, 1827, 2175, 1433, 3473, 3781, 7923, 121525, 0 };
            const std::uint32_t dim11817JoeKuoD6Init[]   =   { 1, 3, 5, 7, 25, 59, 113, 19, 415, 839, 167, 3549, 7435, 6573, 767, 2751, 18383, 0 };
            const std::uint32_t dim11818JoeKuoD6Init[]   =   { 1, 3, 3, 1, 5, 11, 125, 241, 395, 423, 955, 2551, 963, 8197, 30253, 10473, 28505, 0 };
            const std::uint32_t dim11819JoeKuoD6Init[]   =   { 1, 1, 1, 3, 5, 31, 69, 103, 153, 505, 1507, 2827, 165, 4943, 8343, 54253, 87593, 0 };
            const std::uint32_t dim11820JoeKuoD6Init[]   =   { 1, 3, 3, 1, 7, 37, 27, 75, 251, 623, 965, 1907, 6063, 761, 765, 10103, 43479, 0 };
            const std::uint32_t dim11821JoeKuoD6Init[]   =   { 1, 1, 1, 13, 7, 21, 53, 219, 267, 57, 959, 579, 2951, 13797, 3249, 29895, 47467, 0 };
            const std::uint32_t dim11822JoeKuoD6Init[]   =   { 1, 1, 5, 9, 13, 7, 85, 107, 3, 635, 1235, 1339, 3263, 3895, 25911, 7521, 34149, 0 };
            const std::uint32_t dim11823JoeKuoD6Init[]   =   { 1, 1, 5, 15, 29, 37, 73, 43, 413, 993, 499, 719, 1557, 14397, 11245, 58197, 127901, 0 };
            const std::uint32_t dim11824JoeKuoD6Init[]   =   { 1, 1, 5, 15, 9, 37, 87, 57, 63, 337, 927, 1887, 6407, 11237, 23233, 53567, 120449, 0 };
            const std::uint32_t dim11825JoeKuoD6Init[]   =   { 1, 1, 3, 7, 27, 11, 85, 227, 159, 849, 647, 1977, 4623, 7343, 8089, 4251, 26609, 0 };
            const std::uint32_t dim11826JoeKuoD6Init[]   =   { 1, 1, 5, 11, 11, 3, 105, 191, 189, 627, 367, 3935, 6647, 13069, 26195, 23137, 56427, 0 };
            const std::uint32_t dim11827JoeKuoD6Init[]   =   { 1, 1, 3, 3, 29, 51, 39, 3, 437, 1011, 1061, 1747, 3051, 11165, 8155, 9723, 41035, 0 };
            const std::uint32_t dim11828JoeKuoD6Init[]   =   { 1, 3, 7, 15, 9, 43, 79, 195, 265, 395, 1349, 337, 911, 15767, 3593, 42859, 70181, 0 };
            const std::uint32_t dim11829JoeKuoD6Init[]   =   { 1, 3, 7, 7, 11, 47, 11, 85, 489, 801, 1177, 3861, 3517, 9209, 27505, 12291, 35691, 0 };
            const std::uint32_t dim11830JoeKuoD6Init[]   =   { 1, 1, 3, 9, 15, 61, 71, 123, 287, 419, 1079, 3489, 3519, 12739, 21341, 24323, 33961, 0 };
            const std::uint32_t dim11831JoeKuoD6Init[]   =   { 1, 3, 7, 3, 9, 17, 119, 137, 389, 391, 601, 1875, 2197, 5271, 13289, 43597, 43279, 0 };
            const std::uint32_t dim11832JoeKuoD6Init[]   =   { 1, 3, 7, 15, 29, 35, 41, 171, 183, 701, 1673, 981, 5479, 21, 11353, 64953, 88189, 0 };
            const std::uint32_t dim11833JoeKuoD6Init[]   =   { 1, 3, 3, 13, 15, 35, 35, 81, 297, 245, 475, 393, 5401, 12369, 21129, 65213, 125013, 0 };
            const std::uint32_t dim11834JoeKuoD6Init[]   =   { 1, 1, 7, 13, 15, 57, 25, 143, 389, 111, 1219, 2195, 769, 9005, 10367, 39435, 3631, 0 };
            const std::uint32_t dim11835JoeKuoD6Init[]   =   { 1, 3, 3, 13, 9, 29, 9, 47, 127, 377, 1195, 1221, 5751, 15481, 10537, 29909, 112691, 0 };
            const std::uint32_t dim11836JoeKuoD6Init[]   =   { 1, 1, 3, 5, 17, 47, 29, 1, 299, 651, 1023, 1601, 5917, 3781, 18421, 42393, 51789, 0 };
            const std::uint32_t dim11837JoeKuoD6Init[]   =   { 1, 3, 3, 15, 31, 51, 101, 147, 367, 159, 359, 705, 3773, 8649, 31373, 5733, 58287, 0 };
            const std::uint32_t dim11838JoeKuoD6Init[]   =   { 1, 3, 5, 11, 11, 51, 55, 79, 147, 917, 1945, 1725, 289, 12777, 30099, 3013, 91527, 0 };
            const std::uint32_t dim11839JoeKuoD6Init[]   =   { 1, 1, 7, 13, 1, 51, 33, 27, 169, 573, 117, 2479, 761, 1283, 32723, 13589, 88821, 0 };
            const std::uint32_t dim11840JoeKuoD6Init[]   =   { 1, 1, 1, 3, 23, 13, 33, 207, 137, 391, 1309, 4093, 6889, 827, 9331, 57113, 110193, 0 };
            const std::uint32_t dim11841JoeKuoD6Init[]   =   { 1, 1, 1, 13, 15, 57, 115, 53, 59, 443, 1, 3545, 6923, 6603, 8631, 41703, 8519, 0 };
            const std::uint32_t dim11842JoeKuoD6Init[]   =   { 1, 1, 5, 5, 25, 29, 53, 153, 107, 423, 1829, 2469, 1843, 889, 31727, 20701, 6343, 0 };
            const std::uint32_t dim11843JoeKuoD6Init[]   =   { 1, 1, 7, 13, 11, 41, 7, 219, 77, 663, 329, 2639, 1111, 1293, 16771, 20731, 46973, 0 };
            const std::uint32_t dim11844JoeKuoD6Init[]   =   { 1, 3, 3, 15, 23, 19, 45, 107, 111, 155, 1595, 1821, 471, 6089, 21587, 49259, 85393, 0 };
            const std::uint32_t dim11845JoeKuoD6Init[]   =   { 1, 3, 1, 3, 27, 21, 39, 227, 359, 885, 449, 2615, 3519, 5377, 16017, 57159, 82399, 0 };
            const std::uint32_t dim11846JoeKuoD6Init[]   =   { 1, 3, 3, 15, 31, 33, 77, 33, 87, 821, 701, 2859, 1777, 3007, 16757, 5447, 3557, 0 };
            const std::uint32_t dim11847JoeKuoD6Init[]   =   { 1, 1, 1, 15, 11, 31, 127, 79, 363, 341, 169, 3451, 6351, 6867, 13511, 833, 103151, 0 };
            const std::uint32_t dim11848JoeKuoD6Init[]   =   { 1, 3, 5, 7, 27, 23, 5, 67, 159, 535, 103, 843, 8187, 6891, 19169, 22565, 95255, 0 };
            const std::uint32_t dim11849JoeKuoD6Init[]   =   { 1, 3, 5, 5, 15, 27, 53, 49, 343, 815, 1203, 1031, 6359, 1337, 1629, 47783, 103391, 0 };
            const std::uint32_t dim11850JoeKuoD6Init[]   =   { 1, 3, 1, 1, 13, 19, 51, 185, 45, 549, 619, 2247, 2541, 10421, 31507, 60785, 87139, 0 };
            const std::uint32_t dim11851JoeKuoD6Init[]   =   { 1, 3, 1, 15, 29, 9, 47, 127, 41, 767, 1375, 2183, 7169, 12855, 15021, 377, 69327, 0 };
            const std::uint32_t dim11852JoeKuoD6Init[]   =   { 1, 1, 3, 9, 5, 23, 23, 203, 101, 809, 1155, 2885, 3901, 3081, 1827, 65373, 106133, 0 };
            const std::uint32_t dim11853JoeKuoD6Init[]   =   { 1, 3, 3, 13, 3, 21, 73, 135, 353, 905, 1757, 1361, 3801, 15541, 2261, 17159, 18037, 0 };
            const std::uint32_t dim11854JoeKuoD6Init[]   =   { 1, 1, 7, 7, 27, 23, 57, 33, 225, 407, 1709, 1159, 6353, 13341, 15883, 17339, 50423, 0 };
            const std::uint32_t dim11855JoeKuoD6Init[]   =   { 1, 1, 3, 15, 13, 21, 33, 91, 183, 975, 1623, 3187, 5495, 8947, 7031, 19687, 104483, 0 };
            const std::uint32_t dim11856JoeKuoD6Init[]   =   { 1, 3, 5, 7, 17, 25, 77, 1, 335, 85, 1783, 2617, 4463, 3807, 12883, 24487, 66205, 0 };
            const std::uint32_t dim11857JoeKuoD6Init[]   =   { 1, 1, 3, 15, 23, 37, 83, 93, 211, 757, 903, 2681, 49, 435, 21057, 63635, 36489, 0 };
            const std::uint32_t dim11858JoeKuoD6Init[]   =   { 1, 3, 1, 13, 3, 45, 63, 57, 65, 21, 627, 1467, 51, 15887, 27465, 59227, 108233, 0 };
            const std::uint32_t dim11859JoeKuoD6Init[]   =   { 1, 1, 7, 5, 15, 41, 53, 57, 301, 677, 803, 1675, 6937, 3159, 14281, 22355, 37783, 0 };
            const std::uint32_t dim11860JoeKuoD6Init[]   =   { 1, 1, 5, 13, 15, 43, 39, 245, 191, 875, 1505, 2085, 3903, 185, 24461, 28939, 98771, 0 };
            const std::uint32_t dim11861JoeKuoD6Init[]   =   { 1, 1, 7, 9, 17, 25, 29, 31, 439, 159, 533, 3177, 4155, 403, 23735, 61817, 121909, 0 };
            const std::uint32_t dim11862JoeKuoD6Init[]   =   { 1, 1, 3, 15, 29, 43, 111, 47, 483, 513, 63, 2423, 4979, 5159, 15499, 33391, 51575, 0 };
            const std::uint32_t dim11863JoeKuoD6Init[]   =   { 1, 1, 5, 15, 15, 43, 13, 41, 445, 929, 1365, 2023, 6173, 6067, 30969, 51457, 51179, 0 };
            const std::uint32_t dim11864JoeKuoD6Init[]   =   { 1, 3, 3, 11, 15, 17, 93, 235, 159, 599, 635, 1113, 1017, 7413, 7737, 20051, 79127, 0 };
            const std::uint32_t dim11865JoeKuoD6Init[]   =   { 1, 1, 1, 15, 5, 19, 81, 65, 479, 119, 1831, 2515, 2929, 15395, 31607, 29969, 49935, 0 };
            const std::uint32_t dim11866JoeKuoD6Init[]   =   { 1, 3, 1, 13, 23, 47, 45, 151, 51, 217, 803, 3265, 5907, 14371, 8287, 25659, 27655, 0 };
            const std::uint32_t dim11867JoeKuoD6Init[]   =   { 1, 1, 1, 13, 13, 53, 11, 63, 501, 487, 1683, 1147, 4693, 2761, 19359, 2215, 112393, 0 };
            const std::uint32_t dim11868JoeKuoD6Init[]   =   { 1, 3, 3, 1, 31, 15, 61, 237, 129, 119, 135, 39, 6509, 3753, 16997, 3841, 24521, 0 };
            const std::uint32_t dim11869JoeKuoD6Init[]   =   { 1, 3, 5, 7, 5, 27, 113, 251, 217, 923, 229, 2259, 5241, 6331, 6773, 41929, 89605, 0 };
            const std::uint32_t dim11870JoeKuoD6Init[]   =   { 1, 1, 5, 9, 17, 41, 21, 185, 95, 137, 1151, 195, 913, 531, 15731, 22893, 93521, 0 };
            const std::uint32_t dim11871JoeKuoD6Init[]   =   { 1, 1, 5, 1, 29, 57, 123, 11, 345, 581, 227, 1539, 7527, 8537, 16429, 8437, 18953, 0 };
            const std::uint32_t dim11872JoeKuoD6Init[]   =   { 1, 1, 3, 7, 7, 21, 103, 239, 115, 513, 1287, 3717, 331, 5453, 18943, 17247, 64975, 0 };
            const std::uint32_t dim11873JoeKuoD6Init[]   =   { 1, 3, 7, 11, 21, 37, 79, 83, 93, 155, 1297, 1371, 1109, 6569, 21137, 29237, 24007, 0 };
            const std::uint32_t dim11874JoeKuoD6Init[]   =   { 1, 1, 1, 13, 17, 11, 127, 89, 397, 497, 1017, 721, 2837, 5623, 31745, 52243, 107225, 0 };
            const std::uint32_t dim11875JoeKuoD6Init[]   =   { 1, 1, 7, 9, 15, 43, 29, 215, 449, 233, 313, 2587, 2903, 2735, 4539, 50481, 85279, 0 };
            const std::uint32_t dim11876JoeKuoD6Init[]   =   { 1, 1, 3, 15, 13, 35, 109, 211, 299, 255, 1595, 533, 1801, 13965, 25277, 52347, 13447, 0 };
            const std::uint32_t dim11877JoeKuoD6Init[]   =   { 1, 1, 1, 15, 9, 23, 115, 119, 207, 973, 1339, 1315, 6465, 9917, 4593, 65435, 2515, 0 };
            const std::uint32_t dim11878JoeKuoD6Init[]   =   { 1, 3, 3, 3, 7, 25, 115, 115, 213, 845, 1445, 1217, 1563, 12491, 5197, 44409, 79895, 0 };
            const std::uint32_t dim11879JoeKuoD6Init[]   =   { 1, 1, 1, 3, 9, 33, 31, 203, 19, 895, 1145, 2893, 4807, 7501, 6999, 54883, 13797, 0 };
            const std::uint32_t dim11880JoeKuoD6Init[]   =   { 1, 1, 3, 1, 19, 51, 73, 29, 451, 533, 83, 2477, 335, 9703, 9747, 57427, 69443, 0 };
            const std::uint32_t dim11881JoeKuoD6Init[]   =   { 1, 1, 7, 5, 21, 11, 53, 133, 165, 291, 591, 1419, 3661, 4697, 21363, 53467, 84063, 0 };
            const std::uint32_t dim11882JoeKuoD6Init[]   =   { 1, 1, 7, 3, 13, 7, 85, 49, 193, 289, 1531, 709, 2351, 12085, 28553, 57145, 129517, 0 };
            const std::uint32_t dim11883JoeKuoD6Init[]   =   { 1, 1, 1, 1, 17, 19, 13, 213, 75, 977, 811, 1813, 7293, 13795, 28569, 28133, 11949, 0 };
            const std::uint32_t dim11884JoeKuoD6Init[]   =   { 1, 1, 5, 1, 27, 11, 47, 89, 271, 65, 1651, 2331, 3289, 6227, 15027, 19959, 22945, 0 };
            const std::uint32_t dim11885JoeKuoD6Init[]   =   { 1, 3, 7, 9, 17, 37, 17, 245, 249, 501, 405, 951, 3005, 9757, 10265, 35575, 70529, 0 };
            const std::uint32_t dim11886JoeKuoD6Init[]   =   { 1, 3, 1, 15, 21, 47, 15, 75, 113, 45, 125, 1393, 3361, 13477, 24325, 39743, 67409, 0 };
            const std::uint32_t dim11887JoeKuoD6Init[]   =   { 1, 3, 5, 1, 13, 3, 33, 51, 463, 241, 1421, 1607, 3937, 3405, 26653, 33955, 97915, 0 };
            const std::uint32_t dim11888JoeKuoD6Init[]   =   { 1, 3, 7, 13, 29, 17, 41, 193, 461, 787, 459, 4019, 1887, 13831, 9387, 25215, 69801, 0 };
            const std::uint32_t dim11889JoeKuoD6Init[]   =   { 1, 3, 1, 11, 31, 55, 13, 235, 85, 953, 109, 233, 1893, 13225, 26165, 59237, 15845, 0 };
            const std::uint32_t dim11890JoeKuoD6Init[]   =   { 1, 1, 1, 13, 11, 43, 127, 193, 143, 831, 875, 2471, 7011, 3063, 21979, 42113, 80581, 0 };
            const std::uint32_t dim11891JoeKuoD6Init[]   =   { 1, 3, 7, 1, 5, 1, 63, 55, 349, 525, 441, 2695, 3301, 15737, 13355, 16727, 25001, 0 };
            const std::uint32_t dim11892JoeKuoD6Init[]   =   { 1, 3, 7, 7, 31, 23, 87, 99, 331, 101, 1341, 3, 1447, 9507, 18627, 2503, 57597, 0 };
            const std::uint32_t dim11893JoeKuoD6Init[]   =   { 1, 1, 1, 9, 11, 19, 89, 141, 269, 31, 1933, 429, 7765, 5905, 15327, 25913, 17281, 0 };
            const std::uint32_t dim11894JoeKuoD6Init[]   =   { 1, 3, 1, 9, 23, 61, 75, 15, 121, 635, 1409, 615, 7841, 11993, 1637, 26073, 70763, 0 };
            const std::uint32_t dim11895JoeKuoD6Init[]   =   { 1, 3, 3, 1, 5, 63, 85, 3, 443, 87, 1201, 275, 3457, 16187, 26839, 16593, 36335, 0 };
            const std::uint32_t dim11896JoeKuoD6Init[]   =   { 1, 1, 5, 5, 27, 61, 1, 145, 287, 563, 1135, 2703, 733, 10209, 3937, 23807, 56857, 0 };
            const std::uint32_t dim11897JoeKuoD6Init[]   =   { 1, 3, 3, 7, 1, 41, 97, 155, 305, 395, 1607, 1171, 1061, 12301, 8041, 12111, 66831, 0 };
            const std::uint32_t dim11898JoeKuoD6Init[]   =   { 1, 3, 7, 15, 9, 61, 127, 225, 125, 231, 87, 2433, 6951, 2999, 24859, 61685, 111943, 0 };
            const std::uint32_t dim11899JoeKuoD6Init[]   =   { 1, 3, 5, 15, 13, 39, 87, 57, 305, 469, 1929, 1559, 1383, 2779, 3883, 845, 45181, 0 };
            const std::uint32_t dim11900JoeKuoD6Init[]   =   { 1, 1, 1, 15, 19, 1, 23, 41, 207, 731, 501, 1147, 6543, 5011, 483, 56889, 48993, 0 };
            const std::uint32_t dim11901JoeKuoD6Init[]   =   { 1, 3, 3, 15, 21, 35, 75, 129, 441, 497, 953, 201, 6849, 2893, 6351, 62163, 84127, 0 };
            const std::uint32_t dim11902JoeKuoD6Init[]   =   { 1, 1, 1, 9, 21, 31, 91, 79, 345, 649, 1529, 805, 4931, 12887, 30167, 52305, 92561, 0 };
            const std::uint32_t dim11903JoeKuoD6Init[]   =   { 1, 1, 5, 1, 3, 21, 121, 223, 67, 185, 801, 889, 7443, 8419, 19929, 11451, 11487, 0 };
            const std::uint32_t dim11904JoeKuoD6Init[]   =   { 1, 1, 3, 15, 21, 51, 119, 31, 197, 773, 617, 2055, 799, 9105, 12353, 33635, 27589, 0 };
            const std::uint32_t dim11905JoeKuoD6Init[]   =   { 1, 3, 5, 3, 27, 11, 41, 105, 289, 877, 1175, 3111, 3161, 12537, 18001, 38061, 59089, 0 };
            const std::uint32_t dim11906JoeKuoD6Init[]   =   { 1, 3, 3, 5, 3, 27, 101, 253, 225, 915, 1757, 1601, 3391, 10443, 3983, 58427, 93391, 0 };
            const std::uint32_t dim11907JoeKuoD6Init[]   =   { 1, 3, 1, 7, 9, 43, 85, 115, 169, 285, 1267, 3791, 2701, 5599, 10099, 48105, 45219, 0 };
            const std::uint32_t dim11908JoeKuoD6Init[]   =   { 1, 1, 7, 13, 25, 57, 35, 223, 265, 451, 1913, 2715, 8017, 3725, 7079, 34611, 61159, 0 };
            const std::uint32_t dim11909JoeKuoD6Init[]   =   { 1, 1, 3, 7, 23, 27, 93, 195, 449, 845, 865, 655, 4263, 12743, 7467, 7929, 7095, 0 };
            const std::uint32_t dim11910JoeKuoD6Init[]   =   { 1, 3, 5, 5, 29, 51, 109, 123, 227, 693, 2033, 3829, 7187, 4027, 17861, 45093, 7355, 0 };
            const std::uint32_t dim11911JoeKuoD6Init[]   =   { 1, 1, 1, 11, 27, 31, 127, 75, 443, 479, 865, 1377, 711, 3791, 27235, 17405, 25975, 0 };
            const std::uint32_t dim11912JoeKuoD6Init[]   =   { 1, 3, 5, 7, 1, 49, 79, 167, 471, 453, 211, 265, 8163, 6517, 3413, 17283, 51961, 0 };
            const std::uint32_t dim11913JoeKuoD6Init[]   =   { 1, 3, 1, 5, 17, 29, 15, 239, 385, 239, 425, 2197, 3553, 14913, 14889, 31645, 67477, 0 };
            const std::uint32_t dim11914JoeKuoD6Init[]   =   { 1, 3, 3, 5, 1, 11, 25, 105, 367, 253, 1395, 2077, 2613, 4535, 18215, 37657, 48283, 0 };
            const std::uint32_t dim11915JoeKuoD6Init[]   =   { 1, 3, 3, 1, 1, 41, 7, 161, 437, 659, 833, 3175, 2063, 14497, 6655, 8817, 127321, 0 };
            const std::uint32_t dim11916JoeKuoD6Init[]   =   { 1, 3, 1, 11, 17, 27, 3, 51, 75, 183, 1889, 287, 5429, 14007, 14445, 47395, 94543, 0 };
            const std::uint32_t dim11917JoeKuoD6Init[]   =   { 1, 1, 7, 13, 29, 9, 109, 19, 73, 3, 1529, 457, 6413, 4113, 14733, 24455, 44623, 0 };
            const std::uint32_t dim11918JoeKuoD6Init[]   =   { 1, 3, 1, 15, 15, 31, 83, 25, 263, 229, 1801, 377, 1703, 8571, 10393, 52021, 100937, 0 };
            const std::uint32_t dim11919JoeKuoD6Init[]   =   { 1, 3, 5, 9, 25, 57, 79, 19, 117, 437, 275, 3439, 6393, 2111, 8317, 3521, 96927, 0 };
            const std::uint32_t dim11920JoeKuoD6Init[]   =   { 1, 3, 1, 13, 27, 43, 103, 171, 361, 949, 347, 809, 5819, 2763, 10447, 35129, 46985, 0 };
            const std::uint32_t dim11921JoeKuoD6Init[]   =   { 1, 3, 5, 11, 17, 1, 27, 37, 473, 851, 1057, 831, 4373, 5179, 18193, 48731, 64317, 0 };
            const std::uint32_t dim11922JoeKuoD6Init[]   =   { 1, 3, 1, 7, 17, 5, 19, 217, 439, 549, 1983, 2473, 6059, 5271, 10279, 7793, 114357, 0 };
            const std::uint32_t dim11923JoeKuoD6Init[]   =   { 1, 3, 1, 5, 25, 19, 99, 65, 507, 527, 825, 2517, 2299, 1725, 9913, 5779, 12207, 0 };
            const std::uint32_t dim11924JoeKuoD6Init[]   =   { 1, 3, 1, 1, 29, 41, 119, 27, 411, 475, 461, 1885, 2339, 4945, 24665, 13621, 78129, 0 };
            const std::uint32_t dim11925JoeKuoD6Init[]   =   { 1, 3, 1, 11, 27, 29, 119, 155, 487, 29, 1545, 675, 1417, 6119, 12451, 21345, 39377, 0 };
            const std::uint32_t dim11926JoeKuoD6Init[]   =   { 1, 1, 3, 7, 19, 5, 111, 227, 49, 307, 549, 737, 4793, 13885, 22971, 18653, 69573, 0 };
            const std::uint32_t dim11927JoeKuoD6Init[]   =   { 1, 3, 3, 1, 27, 59, 87, 7, 379, 497, 903, 591, 6105, 1957, 25849, 55957, 120181, 0 };
            const std::uint32_t dim11928JoeKuoD6Init[]   =   { 1, 3, 5, 15, 19, 31, 43, 1, 35, 341, 311, 1343, 3625, 16181, 31047, 59679, 89231, 0 };
            const std::uint32_t dim11929JoeKuoD6Init[]   =   { 1, 1, 1, 15, 21, 19, 93, 229, 49, 597, 1465, 2027, 5935, 12269, 20239, 17861, 26311, 0 };
            const std::uint32_t dim11930JoeKuoD6Init[]   =   { 1, 1, 1, 1, 3, 31, 115, 87, 129, 419, 871, 2469, 3807, 4473, 25025, 36923, 67959, 0 };
            const std::uint32_t dim11931JoeKuoD6Init[]   =   { 1, 1, 1, 3, 23, 31, 41, 247, 295, 369, 1131, 2183, 8097, 7609, 4387, 37565, 50177, 0 };
            const std::uint32_t dim11932JoeKuoD6Init[]   =   { 1, 3, 1, 11, 9, 17, 111, 249, 417, 775, 217, 1435, 6295, 5065, 2967, 55361, 91933, 0 };
            const std::uint32_t dim11933JoeKuoD6Init[]   =   { 1, 3, 5, 7, 19, 21, 71, 219, 411, 31, 335, 2915, 3687, 5691, 12405, 34659, 76721, 0 };
            const std::uint32_t dim11934JoeKuoD6Init[]   =   { 1, 3, 5, 13, 29, 31, 95, 203, 149, 399, 547, 2529, 2485, 3371, 20219, 33647, 34217, 0 };
            const std::uint32_t dim11935JoeKuoD6Init[]   =   { 1, 3, 5, 13, 31, 41, 97, 115, 427, 35, 1319, 2335, 715, 2541, 4507, 49395, 33895, 0 };
            const std::uint32_t dim11936JoeKuoD6Init[]   =   { 1, 3, 7, 15, 3, 49, 3, 49, 153, 93, 1343, 1035, 5685, 15855, 15751, 27663, 99553, 0 };
            const std::uint32_t dim11937JoeKuoD6Init[]   =   { 1, 1, 7, 5, 27, 7, 53, 135, 453, 981, 1767, 3503, 1259, 11973, 23259, 41051, 96593, 0 };
            const std::uint32_t dim11938JoeKuoD6Init[]   =   { 1, 1, 7, 9, 5, 59, 57, 141, 41, 639, 1681, 145, 7019, 6621, 14221, 12051, 71871, 0 };
            const std::uint32_t dim11939JoeKuoD6Init[]   =   { 1, 1, 3, 1, 13, 39, 7, 187, 7, 919, 1555, 2111, 6507, 2099, 10643, 22851, 82033, 0 };
            const std::uint32_t dim11940JoeKuoD6Init[]   =   { 1, 3, 7, 9, 25, 59, 27, 225, 239, 715, 1115, 2309, 7785, 11849, 8991, 54305, 107305, 0 };
            const std::uint32_t dim11941JoeKuoD6Init[]   =   { 1, 1, 7, 11, 21, 51, 1, 223, 481, 195, 2005, 2651, 6797, 12201, 11013, 1843, 65167, 0 };
            const std::uint32_t dim11942JoeKuoD6Init[]   =   { 1, 3, 3, 11, 27, 3, 117, 5, 255, 595, 399, 1329, 1437, 12061, 32679, 16655, 76235, 0 };
            const std::uint32_t dim11943JoeKuoD6Init[]   =   { 1, 1, 7, 13, 21, 1, 35, 159, 329, 37, 1247, 2663, 3889, 14603, 25799, 45363, 87963, 0 };
            const std::uint32_t dim11944JoeKuoD6Init[]   =   { 1, 1, 7, 7, 7, 11, 53, 215, 351, 329, 1039, 969, 4449, 14785, 28617, 25953, 78663, 0 };
            const std::uint32_t dim11945JoeKuoD6Init[]   =   { 1, 1, 7, 7, 27, 17, 19, 223, 143, 433, 789, 1941, 5527, 711, 25097, 4571, 121975, 0 };
            const std::uint32_t dim11946JoeKuoD6Init[]   =   { 1, 3, 1, 13, 11, 47, 31, 249, 325, 1003, 509, 2741, 3953, 1691, 12661, 16097, 80211, 0 };
            const std::uint32_t dim11947JoeKuoD6Init[]   =   { 1, 3, 7, 9, 27, 11, 21, 129, 25, 57, 1523, 3631, 2639, 2541, 14249, 34539, 70551, 0 };
            const std::uint32_t dim11948JoeKuoD6Init[]   =   { 1, 1, 5, 3, 31, 47, 47, 73, 71, 783, 1353, 2157, 2563, 14015, 997, 31611, 118649, 0 };
            const std::uint32_t dim11949JoeKuoD6Init[]   =   { 1, 1, 5, 5, 25, 35, 25, 207, 349, 503, 121, 3455, 5783, 10899, 12745, 35117, 36679, 0 };
            const std::uint32_t dim11950JoeKuoD6Init[]   =   { 1, 3, 1, 3, 11, 39, 123, 177, 19, 441, 1979, 1257, 1351, 4253, 15145, 44559, 59379, 0 };
            const std::uint32_t dim11951JoeKuoD6Init[]   =   { 1, 3, 7, 3, 7, 35, 41, 203, 439, 1013, 1055, 1165, 1043, 11183, 1795, 31253, 113693, 0 };
            const std::uint32_t dim11952JoeKuoD6Init[]   =   { 1, 3, 1, 13, 7, 43, 57, 1, 229, 345, 631, 841, 7923, 5971, 20489, 47917, 66833, 0 };
            const std::uint32_t dim11953JoeKuoD6Init[]   =   { 1, 1, 1, 15, 27, 5, 31, 117, 153, 755, 1207, 619, 8185, 4329, 9979, 57255, 79045, 0 };
            const std::uint32_t dim11954JoeKuoD6Init[]   =   { 1, 3, 3, 7, 23, 1, 7, 227, 337, 417, 1895, 765, 7799, 13599, 27253, 4485, 112391, 0 };
            const std::uint32_t dim11955JoeKuoD6Init[]   =   { 1, 3, 5, 13, 27, 63, 5, 87, 101, 351, 953, 2235, 1587, 5479, 26529, 34165, 83303, 0 };
            const std::uint32_t dim11956JoeKuoD6Init[]   =   { 1, 1, 5, 15, 1, 43, 63, 193, 143, 711, 1779, 3531, 1355, 16253, 14595, 32343, 131021, 0 };
            const std::uint32_t dim11957JoeKuoD6Init[]   =   { 1, 1, 1, 9, 29, 37, 29, 71, 11, 877, 1301, 2415, 5593, 1855, 25223, 6805, 12901, 0 };
            const std::uint32_t dim11958JoeKuoD6Init[]   =   { 1, 1, 7, 9, 31, 5, 49, 63, 185, 373, 129, 1695, 7841, 4477, 17809, 42771, 120221, 0 };
            const std::uint32_t dim11959JoeKuoD6Init[]   =   { 1, 1, 5, 3, 15, 43, 49, 45, 47, 775, 699, 2787, 7831, 4189, 18317, 63933, 83669, 0 };
            const std::uint32_t dim11960JoeKuoD6Init[]   =   { 1, 3, 5, 3, 23, 33, 85, 255, 119, 685, 1245, 1647, 1999, 13063, 9241, 49017, 32619, 0 };
            const std::uint32_t dim11961JoeKuoD6Init[]   =   { 1, 1, 7, 15, 29, 15, 125, 233, 189, 411, 1251, 3459, 7213, 10081, 4403, 56819, 17103, 0 };
            const std::uint32_t dim11962JoeKuoD6Init[]   =   { 1, 3, 3, 11, 21, 13, 93, 125, 213, 793, 1057, 2363, 661, 12213, 2259, 3787, 91451, 0 };
            const std::uint32_t dim11963JoeKuoD6Init[]   =   { 1, 3, 5, 5, 19, 35, 5, 153, 507, 691, 1743, 1777, 7579, 14229, 10155, 18529, 35945, 0 };
            const std::uint32_t dim11964JoeKuoD6Init[]   =   { 1, 3, 7, 5, 27, 35, 13, 77, 189, 793, 877, 643, 2787, 5817, 22589, 58363, 49059, 0 };
            const std::uint32_t dim11965JoeKuoD6Init[]   =   { 1, 3, 7, 9, 9, 37, 21, 251, 119, 895, 1023, 91, 4317, 10943, 7355, 36961, 36903, 0 };
            const std::uint32_t dim11966JoeKuoD6Init[]   =   { 1, 3, 3, 13, 19, 49, 15, 105, 399, 29, 1903, 3503, 3453, 15429, 31503, 57815, 34009, 0 };
            const std::uint32_t dim11967JoeKuoD6Init[]   =   { 1, 1, 5, 1, 19, 35, 49, 97, 335, 665, 1871, 887, 4713, 517, 9571, 41601, 9673, 0 };
            const std::uint32_t dim11968JoeKuoD6Init[]   =   { 1, 3, 5, 13, 29, 45, 111, 233, 251, 407, 1135, 2791, 6525, 11633, 22295, 65381, 117511, 0 };
            const std::uint32_t dim11969JoeKuoD6Init[]   =   { 1, 1, 3, 3, 17, 7, 65, 43, 391, 91, 315, 3559, 479, 7337, 25629, 785, 19855, 0 };
            const std::uint32_t dim11970JoeKuoD6Init[]   =   { 1, 1, 5, 9, 29, 31, 67, 17, 381, 875, 1001, 415, 2263, 4415, 11263, 309, 117623, 0 };
            const std::uint32_t dim11971JoeKuoD6Init[]   =   { 1, 1, 7, 11, 25, 1, 59, 61, 247, 649, 687, 907, 1037, 13935, 7229, 39769, 92755, 0 };
            const std::uint32_t dim11972JoeKuoD6Init[]   =   { 1, 3, 5, 15, 21, 51, 27, 79, 343, 785, 1567, 1349, 7991, 8531, 11243, 61351, 21297, 0 };
            const std::uint32_t dim11973JoeKuoD6Init[]   =   { 1, 1, 1, 3, 31, 41, 67, 169, 83, 959, 813, 1953, 2467, 12369, 31431, 50761, 75731, 0 };
            const std::uint32_t dim11974JoeKuoD6Init[]   =   { 1, 1, 5, 11, 25, 37, 83, 163, 3, 161, 1249, 3009, 7167, 5473, 10561, 44899, 130879, 0 };
            const std::uint32_t dim11975JoeKuoD6Init[]   =   { 1, 1, 7, 11, 9, 61, 61, 113, 81, 205, 731, 3887, 5525, 13415, 25181, 11557, 59343, 0 };
            const std::uint32_t dim11976JoeKuoD6Init[]   =   { 1, 3, 7, 5, 19, 27, 107, 89, 295, 715, 1439, 1285, 5813, 8895, 7233, 32905, 3273, 0 };
            const std::uint32_t dim11977JoeKuoD6Init[]   =   { 1, 1, 5, 1, 29, 11, 125, 253, 445, 295, 1721, 1271, 2203, 2215, 7613, 55655, 112157, 0 };
            const std::uint32_t dim11978JoeKuoD6Init[]   =   { 1, 1, 5, 11, 11, 13, 111, 55, 19, 551, 1365, 477, 2513, 12311, 22485, 23291, 92447, 0 };
            const std::uint32_t dim11979JoeKuoD6Init[]   =   { 1, 1, 7, 11, 9, 5, 3, 109, 507, 441, 1767, 1781, 3077, 219, 29293, 21237, 71159, 0 };
            const std::uint32_t dim11980JoeKuoD6Init[]   =   { 1, 1, 3, 11, 3, 45, 99, 113, 367, 569, 1907, 1281, 51, 13693, 14639, 32999, 77461, 0 };
            const std::uint32_t dim11981JoeKuoD6Init[]   =   { 1, 3, 5, 11, 5, 19, 97, 11, 473, 937, 1623, 1507, 3245, 9331, 16005, 37505, 40085, 0 };
            const std::uint32_t dim11982JoeKuoD6Init[]   =   { 1, 1, 7, 13, 21, 61, 103, 111, 35, 141, 61, 1043, 1989, 1311, 29021, 2617, 89915, 0 };
            const std::uint32_t dim11983JoeKuoD6Init[]   =   { 1, 3, 7, 15, 19, 31, 39, 175, 371, 459, 1293, 1645, 1125, 1199, 4811, 55721, 76071, 0 };
            const std::uint32_t dim11984JoeKuoD6Init[]   =   { 1, 1, 7, 3, 3, 35, 17, 7, 91, 317, 1615, 3559, 191, 2579, 15027, 58711, 36009, 0 };
            const std::uint32_t dim11985JoeKuoD6Init[]   =   { 1, 1, 1, 13, 1, 27, 45, 87, 443, 443, 853, 3917, 1437, 4053, 14861, 2897, 109853, 0 };
            const std::uint32_t dim11986JoeKuoD6Init[]   =   { 1, 1, 5, 3, 21, 47, 73, 195, 115, 517, 1781, 2341, 805, 5679, 12053, 29113, 100479, 0 };
            const std::uint32_t dim11987JoeKuoD6Init[]   =   { 1, 1, 7, 1, 25, 27, 61, 167, 203, 57, 527, 1071, 7131, 8403, 9943, 11503, 33081, 0 };
            const std::uint32_t dim11988JoeKuoD6Init[]   =   { 1, 1, 5, 13, 31, 43, 35, 195, 177, 229, 1401, 4011, 2363, 15787, 21125, 32103, 62337, 0 };
            const std::uint32_t dim11989JoeKuoD6Init[]   =   { 1, 1, 5, 11, 19, 13, 3, 249, 119, 35, 747, 1419, 5451, 13043, 19813, 54859, 94825, 0 };
            const std::uint32_t dim11990JoeKuoD6Init[]   =   { 1, 3, 1, 9, 17, 13, 51, 125, 391, 157, 1199, 1805, 1763, 11831, 20915, 38547, 14221, 0 };
            const std::uint32_t dim11991JoeKuoD6Init[]   =   { 1, 1, 7, 1, 23, 61, 25, 69, 435, 183, 1379, 1211, 5529, 9447, 4575, 14127, 91867, 0 };
            const std::uint32_t dim11992JoeKuoD6Init[]   =   { 1, 3, 3, 15, 11, 15, 101, 135, 419, 685, 1097, 787, 2045, 3393, 26221, 23653, 116917, 0 };
            const std::uint32_t dim11993JoeKuoD6Init[]   =   { 1, 3, 1, 11, 29, 23, 13, 153, 27, 683, 1569, 413, 261, 10291, 23763, 15579, 39337, 0 };
            const std::uint32_t dim11994JoeKuoD6Init[]   =   { 1, 3, 7, 7, 19, 23, 121, 23, 339, 165, 1137, 2791, 319, 16111, 14847, 28171, 79237, 0 };
            const std::uint32_t dim11995JoeKuoD6Init[]   =   { 1, 3, 1, 5, 9, 59, 33, 19, 191, 707, 1883, 1683, 1161, 12905, 12299, 22201, 19811, 0 };
            const std::uint32_t dim11996JoeKuoD6Init[]   =   { 1, 3, 1, 3, 27, 11, 69, 199, 415, 251, 1079, 1709, 4539, 7867, 21321, 33617, 53459, 0 };
            const std::uint32_t dim11997JoeKuoD6Init[]   =   { 1, 1, 3, 9, 19, 59, 21, 95, 275, 213, 1819, 721, 6271, 11845, 9573, 16105, 12755, 0 };
            const std::uint32_t dim11998JoeKuoD6Init[]   =   { 1, 1, 1, 15, 23, 7, 91, 235, 43, 95, 913, 715, 3229, 12339, 23089, 30963, 129525, 0 };
            const std::uint32_t dim11999JoeKuoD6Init[]   =   { 1, 1, 7, 9, 7, 41, 43, 131, 485, 621, 1293, 1955, 5215, 6545, 29225, 53587, 46901, 0 };
            const std::uint32_t dim12000JoeKuoD6Init[]   =   { 1, 3, 1, 5, 7, 57, 97, 199, 225, 707, 1223, 1829, 497, 12587, 24551, 12907, 82411, 0 };
            const std::uint32_t dim12001JoeKuoD6Init[]   =   { 1, 1, 3, 7, 21, 9, 63, 15, 263, 957, 155, 4021, 4455, 2025, 16981, 19743, 88619, 0 };
            const std::uint32_t dim12002JoeKuoD6Init[]   =   { 1, 1, 7, 5, 31, 3, 27, 45, 369, 747, 1559, 1429, 8049, 15069, 19897, 50067, 52861, 0 };
            const std::uint32_t dim12003JoeKuoD6Init[]   =   { 1, 1, 5, 13, 23, 35, 91, 139, 73, 275, 207, 2709, 3801, 12755, 19155, 61629, 5513, 0 };
            const std::uint32_t dim12004JoeKuoD6Init[]   =   { 1, 1, 5, 7, 5, 25, 33, 45, 325, 847, 81, 891, 3191, 14115, 25095, 39867, 3839, 0 };
            const std::uint32_t dim12005JoeKuoD6Init[]   =   { 1, 3, 5, 13, 9, 31, 31, 113, 507, 833, 691, 2041, 4873, 81, 21365, 35265, 37627, 0 };
            const std::uint32_t dim12006JoeKuoD6Init[]   =   { 1, 1, 5, 13, 9, 51, 127, 131, 285, 683, 593, 3411, 6685, 3601, 12255, 8337, 80597, 0 };
            const std::uint32_t dim12007JoeKuoD6Init[]   =   { 1, 1, 5, 15, 29, 13, 79, 199, 157, 421, 1697, 2063, 2213, 4141, 21045, 45785, 124023, 0 };
            const std::uint32_t dim12008JoeKuoD6Init[]   =   { 1, 3, 1, 11, 19, 5, 79, 57, 71, 373, 487, 671, 3671, 9093, 20989, 48477, 104951, 0 };
            const std::uint32_t dim12009JoeKuoD6Init[]   =   { 1, 3, 5, 15, 13, 7, 39, 243, 507, 739, 1905, 3431, 4141, 9345, 27877, 64735, 112997, 0 };
            const std::uint32_t dim12010JoeKuoD6Init[]   =   { 1, 3, 3, 5, 17, 25, 31, 243, 393, 61, 199, 2825, 6981, 5887, 22289, 9201, 77689, 0 };
            const std::uint32_t dim12011JoeKuoD6Init[]   =   { 1, 3, 5, 15, 15, 63, 77, 39, 463, 883, 671, 3285, 6925, 15085, 1665, 64005, 130619, 0 };
            const std::uint32_t dim12012JoeKuoD6Init[]   =   { 1, 3, 3, 11, 21, 15, 7, 115, 9, 879, 1097, 3993, 3929, 9809, 22105, 9549, 31819, 0 };
            const std::uint32_t dim12013JoeKuoD6Init[]   =   { 1, 1, 7, 15, 3, 9, 19, 97, 327, 105, 1915, 205, 3873, 1229, 29915, 57375, 108217, 0 };
            const std::uint32_t dim12014JoeKuoD6Init[]   =   { 1, 1, 3, 11, 29, 41, 77, 11, 183, 73, 1651, 3739, 3911, 8695, 15339, 19293, 1827, 0 };
            const std::uint32_t dim12015JoeKuoD6Init[]   =   { 1, 1, 1, 5, 23, 49, 35, 175, 99, 49, 615, 1733, 6901, 2351, 18765, 55553, 99791, 0 };
            const std::uint32_t dim12016JoeKuoD6Init[]   =   { 1, 3, 7, 3, 25, 17, 67, 161, 507, 941, 35, 2619, 339, 791, 6485, 64277, 123867, 0 };
            const std::uint32_t dim12017JoeKuoD6Init[]   =   { 1, 1, 3, 13, 11, 9, 79, 193, 75, 391, 1753, 3537, 6971, 6607, 11933, 4447, 87793, 0 };
            const std::uint32_t dim12018JoeKuoD6Init[]   =   { 1, 1, 1, 5, 19, 9, 63, 203, 51, 395, 1365, 2393, 7265, 11709, 13721, 4519, 118765, 0 };
            const std::uint32_t dim12019JoeKuoD6Init[]   =   { 1, 1, 3, 9, 17, 53, 29, 103, 325, 973, 903, 785, 7535, 9951, 8121, 12603, 38679, 0 };
            const std::uint32_t dim12020JoeKuoD6Init[]   =   { 1, 3, 1, 7, 7, 63, 1, 123, 439, 181, 1373, 2705, 995, 10789, 7495, 54543, 120109, 0 };
            const std::uint32_t dim12021JoeKuoD6Init[]   =   { 1, 1, 7, 3, 17, 13, 79, 179, 165, 965, 1537, 3753, 3497, 12127, 6983, 48605, 113057, 0 };
            const std::uint32_t dim12022JoeKuoD6Init[]   =   { 1, 1, 5, 7, 3, 7, 41, 25, 267, 633, 19, 1317, 3445, 12377, 27881, 55249, 40841, 0 };
            const std::uint32_t dim12023JoeKuoD6Init[]   =   { 1, 3, 5, 1, 31, 55, 43, 129, 411, 281, 1, 851, 2419, 7943, 13721, 39371, 114557, 0 };
            const std::uint32_t dim12024JoeKuoD6Init[]   =   { 1, 1, 7, 7, 23, 19, 83, 37, 9, 161, 125, 3179, 7973, 9703, 23199, 32723, 130915, 0 };
            const std::uint32_t dim12025JoeKuoD6Init[]   =   { 1, 1, 7, 5, 27, 21, 11, 219, 403, 239, 1723, 2957, 3029, 9911, 10981, 35421, 74025, 0 };
            const std::uint32_t dim12026JoeKuoD6Init[]   =   { 1, 3, 1, 1, 31, 59, 69, 77, 395, 1, 157, 1259, 4913, 2089, 17619, 51033, 130899, 0 };
            const std::uint32_t dim12027JoeKuoD6Init[]   =   { 1, 3, 3, 3, 19, 11, 83, 237, 103, 921, 487, 1833, 8187, 3811, 18887, 9389, 80927, 0 };
            const std::uint32_t dim12028JoeKuoD6Init[]   =   { 1, 3, 7, 3, 17, 51, 107, 209, 187, 831, 1501, 1337, 803, 10361, 11347, 65291, 42219, 0 };
            const std::uint32_t dim12029JoeKuoD6Init[]   =   { 1, 3, 3, 15, 7, 29, 61, 25, 413, 257, 1185, 4009, 7463, 1839, 6645, 28389, 14449, 0 };
            const std::uint32_t dim12030JoeKuoD6Init[]   =   { 1, 3, 1, 9, 5, 31, 83, 55, 375, 399, 945, 997, 7649, 12631, 7691, 53325, 50173, 0 };
            const std::uint32_t dim12031JoeKuoD6Init[]   =   { 1, 1, 5, 9, 13, 9, 83, 37, 487, 975, 487, 3587, 7285, 7505, 10155, 673, 126505, 0 };
            const std::uint32_t dim12032JoeKuoD6Init[]   =   { 1, 3, 5, 7, 21, 3, 35, 21, 367, 323, 1579, 3351, 5465, 13719, 17033, 42573, 55079, 0 };
            const std::uint32_t dim12033JoeKuoD6Init[]   =   { 1, 3, 3, 15, 11, 27, 121, 109, 267, 855, 1417, 3839, 6535, 1051, 29355, 23815, 76031, 0 };
            const std::uint32_t dim12034JoeKuoD6Init[]   =   { 1, 1, 7, 9, 5, 31, 35, 53, 369, 137, 1545, 927, 825, 1333, 13637, 11003, 96963, 0 };
            const std::uint32_t dim12035JoeKuoD6Init[]   =   { 1, 1, 5, 3, 29, 41, 31, 85, 35, 477, 227, 3325, 1213, 681, 14591, 31325, 12199, 0 };
            const std::uint32_t dim12036JoeKuoD6Init[]   =   { 1, 3, 7, 11, 11, 11, 33, 255, 335, 747, 855, 31, 6101, 293, 20423, 47521, 62573, 0 };
            const std::uint32_t dim12037JoeKuoD6Init[]   =   { 1, 1, 1, 15, 31, 15, 33, 175, 321, 441, 1197, 3579, 4989, 9275, 30485, 1077, 122947, 0 };
            const std::uint32_t dim12038JoeKuoD6Init[]   =   { 1, 3, 5, 15, 23, 21, 127, 223, 249, 373, 1309, 1469, 5701, 9097, 29897, 26627, 38489, 0 };
            const std::uint32_t dim12039JoeKuoD6Init[]   =   { 1, 3, 7, 3, 3, 35, 83, 149, 259, 315, 1467, 1953, 6035, 7961, 10901, 25171, 130713, 0 };
            const std::uint32_t dim12040JoeKuoD6Init[]   =   { 1, 1, 3, 9, 7, 63, 55, 33, 375, 421, 151, 1721, 1999, 14937, 17539, 48323, 97345, 0 };
            const std::uint32_t dim12041JoeKuoD6Init[]   =   { 1, 1, 5, 5, 3, 21, 47, 19, 227, 131, 1591, 3779, 929, 13879, 13489, 19805, 20135, 0 };
            const std::uint32_t dim12042JoeKuoD6Init[]   =   { 1, 1, 7, 1, 31, 25, 87, 125, 213, 135, 809, 3067, 5035, 7407, 2193, 31423, 123973, 0 };
            const std::uint32_t dim12043JoeKuoD6Init[]   =   { 1, 3, 5, 13, 17, 19, 77, 169, 345, 115, 227, 649, 3609, 15063, 1895, 17533, 95859, 0 };
            const std::uint32_t dim12044JoeKuoD6Init[]   =   { 1, 3, 5, 15, 17, 29, 17, 11, 145, 601, 1871, 851, 8161, 14029, 10039, 4247, 62393, 0 };
            const std::uint32_t dim12045JoeKuoD6Init[]   =   { 1, 1, 7, 13, 25, 5, 49, 231, 261, 71, 335, 4081, 7915, 11367, 17087, 26041, 128737, 0 };
            const std::uint32_t dim12046JoeKuoD6Init[]   =   { 1, 1, 1, 13, 13, 21, 77, 113, 373, 1005, 109, 2877, 3001, 15011, 2465, 37015, 69049, 0 };
            const std::uint32_t dim12047JoeKuoD6Init[]   =   { 1, 1, 3, 15, 31, 33, 119, 121, 41, 9, 1567, 577, 1687, 12117, 17049, 675, 10729, 0 };
            const std::uint32_t dim12048JoeKuoD6Init[]   =   { 1, 3, 5, 11, 31, 7, 47, 41, 127, 81, 273, 1649, 975, 3953, 17021, 24163, 12599, 0 };
            const std::uint32_t dim12049JoeKuoD6Init[]   =   { 1, 3, 1, 3, 27, 41, 75, 237, 317, 85, 1995, 2255, 2191, 6441, 26629, 25797, 97681, 0 };
            const std::uint32_t dim12050JoeKuoD6Init[]   =   { 1, 1, 1, 3, 11, 5, 31, 109, 227, 977, 59, 793, 3305, 10905, 16529, 21345, 2403, 0 };
            const std::uint32_t dim12051JoeKuoD6Init[]   =   { 1, 3, 5, 9, 9, 37, 107, 129, 421, 383, 1415, 885, 3383, 9547, 7303, 41745, 59919, 0 };
            const std::uint32_t dim12052JoeKuoD6Init[]   =   { 1, 1, 7, 7, 29, 27, 59, 177, 97, 299, 1019, 1393, 7763, 5715, 9253, 58035, 23431, 0 };
            const std::uint32_t dim12053JoeKuoD6Init[]   =   { 1, 3, 3, 3, 23, 13, 51, 101, 75, 857, 1699, 2687, 3983, 10427, 19845, 49503, 96033, 0 };
            const std::uint32_t dim12054JoeKuoD6Init[]   =   { 1, 1, 1, 7, 21, 51, 25, 71, 265, 999, 1259, 625, 775, 11045, 20769, 42597, 115521, 0 };
            const std::uint32_t dim12055JoeKuoD6Init[]   =   { 1, 3, 1, 13, 25, 47, 21, 245, 201, 667, 1193, 1087, 407, 6057, 14929, 35291, 57615, 0 };
            const std::uint32_t dim12056JoeKuoD6Init[]   =   { 1, 1, 1, 7, 27, 25, 93, 85, 321, 1009, 1045, 1901, 349, 11393, 10917, 10413, 94125, 0 };
            const std::uint32_t dim12057JoeKuoD6Init[]   =   { 1, 1, 1, 15, 3, 63, 59, 51, 307, 135, 785, 1921, 6921, 5689, 8487, 21061, 69903, 0 };
            const std::uint32_t dim12058JoeKuoD6Init[]   =   { 1, 3, 7, 1, 13, 47, 59, 155, 107, 573, 843, 2849, 6685, 5927, 31747, 21541, 94271, 0 };
            const std::uint32_t dim12059JoeKuoD6Init[]   =   { 1, 1, 7, 15, 23, 7, 85, 169, 209, 527, 1027, 3745, 4773, 14893, 10789, 1243, 87133, 0 };
            const std::uint32_t dim12060JoeKuoD6Init[]   =   { 1, 1, 5, 9, 1, 1, 53, 57, 245, 899, 1785, 1951, 7651, 10909, 30167, 40789, 66965, 0 };
            const std::uint32_t dim12061JoeKuoD6Init[]   =   { 1, 1, 1, 7, 17, 33, 65, 79, 455, 677, 157, 1313, 1573, 9697, 4161, 4609, 42783, 0 };
            const std::uint32_t dim12062JoeKuoD6Init[]   =   { 1, 3, 7, 7, 27, 15, 109, 113, 239, 521, 563, 2493, 1471, 15817, 14515, 48465, 66009, 0 };
            const std::uint32_t dim12063JoeKuoD6Init[]   =   { 1, 3, 5, 3, 29, 33, 125, 169, 483, 593, 1665, 657, 3799, 15829, 29591, 25813, 40987, 0 };
            const std::uint32_t dim12064JoeKuoD6Init[]   =   { 1, 3, 1, 11, 15, 25, 21, 215, 341, 241, 1599, 3807, 6633, 15137, 15377, 56881, 47499, 0 };
            const std::uint32_t dim12065JoeKuoD6Init[]   =   { 1, 3, 3, 3, 15, 49, 89, 117, 191, 641, 675, 2671, 4243, 1617, 20261, 42669, 119173, 0 };
            const std::uint32_t dim12066JoeKuoD6Init[]   =   { 1, 1, 1, 13, 13, 43, 73, 103, 183, 239, 555, 2121, 4889, 1431, 20601, 21545, 11809, 0 };
            const std::uint32_t dim12067JoeKuoD6Init[]   =   { 1, 3, 1, 9, 9, 9, 121, 51, 77, 455, 1481, 427, 1961, 12149, 21273, 16295, 21909, 0 };
            const std::uint32_t dim12068JoeKuoD6Init[]   =   { 1, 1, 5, 11, 19, 55, 37, 63, 493, 663, 945, 2191, 2491, 11545, 7407, 36295, 94293, 0 };
            const std::uint32_t dim12069JoeKuoD6Init[]   =   { 1, 3, 5, 15, 25, 35, 103, 33, 171, 425, 409, 5, 2519, 2239, 30557, 20007, 69079, 0 };
            const std::uint32_t dim12070JoeKuoD6Init[]   =   { 1, 1, 5, 11, 13, 29, 71, 21, 35, 833, 191, 365, 7013, 12413, 10227, 56705, 61705, 0 };
            const std::uint32_t dim12071JoeKuoD6Init[]   =   { 1, 1, 1, 1, 21, 13, 87, 113, 63, 537, 283, 925, 2147, 1683, 31239, 2775, 131021, 0 };
            const std::uint32_t dim12072JoeKuoD6Init[]   =   { 1, 1, 3, 9, 23, 1, 117, 19, 487, 235, 877, 149, 369, 9615, 12501, 60175, 35741, 0 };
            const std::uint32_t dim12073JoeKuoD6Init[]   =   { 1, 1, 7, 9, 5, 25, 107, 199, 339, 755, 245, 2861, 1119, 14683, 2221, 5227, 81479, 0 };
            const std::uint32_t dim12074JoeKuoD6Init[]   =   { 1, 1, 1, 15, 5, 15, 37, 63, 511, 219, 783, 3245, 5563, 13231, 22311, 16803, 10393, 0 };
            const std::uint32_t dim12075JoeKuoD6Init[]   =   { 1, 3, 7, 5, 1, 15, 9, 21, 287, 991, 555, 771, 7683, 1661, 6553, 43735, 118713, 0 };
            const std::uint32_t dim12076JoeKuoD6Init[]   =   { 1, 3, 1, 3, 3, 29, 119, 157, 13, 599, 537, 2921, 5207, 11621, 1515, 6351, 118429, 0 };
            const std::uint32_t dim12077JoeKuoD6Init[]   =   { 1, 1, 5, 1, 27, 39, 111, 117, 481, 25, 549, 913, 6427, 7703, 23099, 50501, 7617, 0 };
            const std::uint32_t dim12078JoeKuoD6Init[]   =   { 1, 1, 7, 5, 29, 63, 43, 151, 63, 43, 197, 3165, 3879, 12435, 461, 64475, 60597, 0 };
            const std::uint32_t dim12079JoeKuoD6Init[]   =   { 1, 3, 1, 11, 31, 35, 59, 207, 387, 441, 1293, 2117, 3751, 12653, 2811, 42585, 33297, 0 };
            const std::uint32_t dim12080JoeKuoD6Init[]   =   { 1, 3, 7, 15, 27, 47, 13, 15, 135, 433, 615, 1, 171, 11503, 27117, 64635, 122191, 0 };
            const std::uint32_t dim12081JoeKuoD6Init[]   =   { 1, 1, 7, 1, 23, 23, 107, 135, 311, 395, 373, 2771, 81, 12513, 16739, 6715, 94999, 0 };
            const std::uint32_t dim12082JoeKuoD6Init[]   =   { 1, 3, 5, 7, 19, 9, 21, 139, 307, 231, 65, 59, 7767, 2897, 3503, 58163, 48807, 0 };
            const std::uint32_t dim12083JoeKuoD6Init[]   =   { 1, 3, 5, 13, 23, 5, 51, 247, 125, 911, 1395, 1337, 3215, 15811, 12729, 21495, 22597, 0 };
            const std::uint32_t dim12084JoeKuoD6Init[]   =   { 1, 3, 5, 5, 1, 19, 123, 125, 197, 533, 1699, 1397, 3473, 15201, 24493, 3395, 98261, 0 };
            const std::uint32_t dim12085JoeKuoD6Init[]   =   { 1, 1, 3, 7, 29, 39, 69, 97, 353, 293, 1103, 543, 5015, 9913, 6965, 61921, 122073, 0 };
            const std::uint32_t dim12086JoeKuoD6Init[]   =   { 1, 1, 3, 13, 19, 41, 117, 253, 449, 231, 865, 3055, 4751, 3277, 22863, 3249, 38359, 0 };
            const std::uint32_t dim12087JoeKuoD6Init[]   =   { 1, 3, 5, 13, 9, 7, 107, 17, 251, 501, 1925, 3733, 5035, 13213, 12535, 13705, 73047, 0 };
            const std::uint32_t dim12088JoeKuoD6Init[]   =   { 1, 3, 7, 5, 23, 5, 83, 45, 457, 667, 913, 1167, 7063, 10915, 10911, 20501, 61823, 0 };
            const std::uint32_t dim12089JoeKuoD6Init[]   =   { 1, 3, 3, 13, 7, 15, 29, 223, 503, 713, 667, 3989, 5927, 5909, 27633, 17615, 97931, 0 };
            const std::uint32_t dim12090JoeKuoD6Init[]   =   { 1, 3, 7, 13, 19, 53, 25, 41, 311, 327, 1323, 3361, 1095, 12701, 1065, 34155, 34705, 0 };
            const std::uint32_t dim12091JoeKuoD6Init[]   =   { 1, 1, 7, 7, 11, 35, 63, 73, 179, 477, 467, 4043, 3097, 16089, 12749, 18233, 50299, 0 };
            const std::uint32_t dim12092JoeKuoD6Init[]   =   { 1, 3, 3, 13, 5, 27, 31, 207, 357, 469, 607, 961, 7393, 6707, 25833, 22337, 119083, 0 };
            const std::uint32_t dim12093JoeKuoD6Init[]   =   { 1, 1, 3, 3, 7, 53, 47, 55, 267, 107, 1307, 2151, 793, 15605, 12153, 13075, 76529, 0 };
            const std::uint32_t dim12094JoeKuoD6Init[]   =   { 1, 3, 5, 1, 13, 35, 63, 191, 375, 221, 1603, 2049, 5363, 1481, 32271, 22635, 118603, 0 };
            const std::uint32_t dim12095JoeKuoD6Init[]   =   { 1, 1, 1, 11, 17, 63, 13, 3, 353, 943, 443, 141, 7441, 12335, 4499, 15923, 63677, 0 };
            const std::uint32_t dim12096JoeKuoD6Init[]   =   { 1, 3, 7, 13, 21, 51, 125, 61, 203, 1, 707, 3893, 4627, 3125, 14629, 62721, 85101, 0 };
            const std::uint32_t dim12097JoeKuoD6Init[]   =   { 1, 1, 3, 5, 31, 23, 63, 241, 41, 721, 599, 1761, 2593, 1685, 31247, 7811, 87561, 0 };
            const std::uint32_t dim12098JoeKuoD6Init[]   =   { 1, 1, 7, 9, 7, 53, 51, 9, 303, 675, 1261, 1591, 4363, 15, 29723, 54533, 103869, 0 };
            const std::uint32_t dim12099JoeKuoD6Init[]   =   { 1, 3, 5, 7, 27, 21, 103, 113, 463, 379, 635, 2363, 607, 11445, 22475, 58433, 93071, 0 };
            const std::uint32_t dim12100JoeKuoD6Init[]   =   { 1, 1, 5, 5, 5, 63, 23, 67, 399, 279, 829, 945, 6545, 14951, 5135, 22889, 87625, 0 };
            const std::uint32_t dim12101JoeKuoD6Init[]   =   { 1, 1, 7, 15, 1, 59, 69, 123, 169, 821, 1125, 2051, 3375, 11691, 1379, 57461, 124209, 0 };
            const std::uint32_t dim12102JoeKuoD6Init[]   =   { 1, 1, 5, 15, 31, 57, 51, 59, 297, 459, 701, 241, 2801, 11893, 4007, 13165, 79403, 0 };
            const std::uint32_t dim12103JoeKuoD6Init[]   =   { 1, 1, 5, 9, 11, 41, 79, 47, 19, 529, 21, 1871, 371, 6269, 7433, 36183, 96113, 0 };
            const std::uint32_t dim12104JoeKuoD6Init[]   =   { 1, 1, 7, 5, 29, 3, 33, 191, 119, 501, 1637, 2903, 3347, 4581, 17407, 18169, 10595, 0 };
            const std::uint32_t dim12105JoeKuoD6Init[]   =   { 1, 3, 5, 11, 9, 35, 95, 193, 413, 727, 1157, 3331, 5993, 1781, 22653, 3975, 110557, 0 };
            const std::uint32_t dim12106JoeKuoD6Init[]   =   { 1, 1, 1, 1, 23, 5, 35, 65, 57, 515, 569, 4031, 7983, 4603, 29419, 44847, 63601, 0 };
            const std::uint32_t dim12107JoeKuoD6Init[]   =   { 1, 3, 1, 7, 21, 5, 77, 23, 317, 803, 723, 3229, 7171, 2883, 10943, 50323, 108579, 0 };
            const std::uint32_t dim12108JoeKuoD6Init[]   =   { 1, 3, 5, 11, 15, 53, 75, 127, 177, 19, 501, 1201, 5113, 9069, 8817, 14725, 104737, 0 };
            const std::uint32_t dim12109JoeKuoD6Init[]   =   { 1, 3, 7, 9, 7, 39, 5, 121, 409, 103, 1075, 451, 7603, 16023, 32557, 43159, 94385, 0 };
            const std::uint32_t dim12110JoeKuoD6Init[]   =   { 1, 3, 1, 11, 29, 57, 123, 141, 57, 945, 1777, 2427, 2359, 12839, 7325, 7945, 129811, 0 };
            const std::uint32_t dim12111JoeKuoD6Init[]   =   { 1, 3, 5, 15, 5, 3, 17, 55, 467, 61, 131, 2891, 6331, 5859, 20437, 49425, 80731, 0 };
            const std::uint32_t dim12112JoeKuoD6Init[]   =   { 1, 1, 1, 15, 29, 13, 127, 181, 361, 1019, 1675, 2755, 6533, 8957, 14691, 4285, 65459, 0 };
            const std::uint32_t dim12113JoeKuoD6Init[]   =   { 1, 1, 7, 11, 23, 43, 111, 183, 103, 269, 229, 3291, 1873, 11349, 29319, 64829, 19639, 0 };
            const std::uint32_t dim12114JoeKuoD6Init[]   =   { 1, 3, 7, 11, 15, 63, 1, 253, 489, 863, 1707, 2769, 3201, 7901, 18161, 12515, 130237, 0 };
            const std::uint32_t dim12115JoeKuoD6Init[]   =   { 1, 3, 1, 7, 1, 25, 43, 159, 505, 511, 1745, 1421, 6779, 11103, 23535, 61129, 124571, 0 };
            const std::uint32_t dim12116JoeKuoD6Init[]   =   { 1, 1, 3, 13, 19, 33, 17, 243, 481, 617, 1061, 1891, 7165, 6821, 18505, 8965, 70179, 0 };
            const std::uint32_t dim12117JoeKuoD6Init[]   =   { 1, 1, 7, 13, 17, 17, 65, 23, 255, 361, 1873, 1605, 2041, 11119, 11419, 63131, 49207, 0 };
            const std::uint32_t dim12118JoeKuoD6Init[]   =   { 1, 1, 5, 13, 15, 57, 27, 223, 199, 529, 1115, 1513, 8083, 11713, 21005, 50741, 122223, 0 };
            const std::uint32_t dim12119JoeKuoD6Init[]   =   { 1, 3, 5, 15, 29, 35, 107, 85, 141, 505, 1553, 1283, 4581, 5077, 9461, 59853, 23219, 0 };
            const std::uint32_t dim12120JoeKuoD6Init[]   =   { 1, 3, 5, 11, 11, 45, 53, 195, 199, 773, 1911, 721, 1563, 3769, 3267, 30673, 80313, 0 };
            const std::uint32_t dim12121JoeKuoD6Init[]   =   { 1, 3, 7, 7, 21, 37, 9, 129, 431, 79, 1559, 2125, 7781, 6441, 23533, 46919, 25315, 0 };
            const std::uint32_t dim12122JoeKuoD6Init[]   =   { 1, 1, 5, 15, 11, 61, 77, 231, 349, 647, 225, 85, 6789, 12557, 6505, 21985, 54965, 0 };
            const std::uint32_t dim12123JoeKuoD6Init[]   =   { 1, 1, 5, 1, 19, 21, 33, 211, 347, 491, 1119, 1619, 3739, 11255, 26705, 59691, 35337, 0 };
            const std::uint32_t dim12124JoeKuoD6Init[]   =   { 1, 1, 3, 3, 29, 15, 7, 23, 279, 145, 699, 289, 475, 1681, 3201, 64477, 24919, 0 };
            const std::uint32_t dim12125JoeKuoD6Init[]   =   { 1, 1, 7, 7, 23, 53, 75, 71, 315, 403, 1521, 1417, 3749, 11243, 3951, 61039, 51143, 0 };
            const std::uint32_t dim12126JoeKuoD6Init[]   =   { 1, 3, 7, 3, 15, 21, 81, 219, 249, 387, 1405, 3495, 7143, 2599, 25435, 15259, 66069, 0 };
            const std::uint32_t dim12127JoeKuoD6Init[]   =   { 1, 1, 5, 7, 31, 9, 63, 55, 409, 421, 1851, 847, 1593, 10447, 2833, 13209, 47285, 0 };
            const std::uint32_t dim12128JoeKuoD6Init[]   =   { 1, 1, 3, 7, 15, 3, 35, 49, 253, 21, 1705, 357, 2751, 9671, 12429, 4549, 118691, 0 };
            const std::uint32_t dim12129JoeKuoD6Init[]   =   { 1, 1, 5, 15, 1, 3, 97, 197, 43, 923, 1273, 663, 4291, 12357, 28221, 15291, 60989, 0 };
            const std::uint32_t dim12130JoeKuoD6Init[]   =   { 1, 1, 7, 7, 15, 3, 35, 115, 449, 641, 743, 1855, 359, 10983, 2831, 43983, 56465, 0 };
            const std::uint32_t dim12131JoeKuoD6Init[]   =   { 1, 3, 7, 11, 1, 51, 69, 27, 29, 187, 1673, 1273, 7987, 1223, 8971, 53805, 4413, 0 };
            const std::uint32_t dim12132JoeKuoD6Init[]   =   { 1, 1, 3, 11, 1, 55, 91, 241, 35, 97, 1027, 3967, 703, 3535, 21681, 55825, 50423, 0 };
            const std::uint32_t dim12133JoeKuoD6Init[]   =   { 1, 1, 7, 11, 21, 53, 111, 125, 11, 355, 1585, 3603, 1705, 16311, 7045, 15503, 63625, 0 };
            const std::uint32_t dim12134JoeKuoD6Init[]   =   { 1, 1, 5, 15, 25, 47, 31, 29, 333, 361, 1831, 1545, 7751, 8679, 32453, 61755, 94637, 0 };
            const std::uint32_t dim12135JoeKuoD6Init[]   =   { 1, 1, 3, 3, 23, 3, 79, 11, 367, 551, 281, 1273, 5097, 12527, 473, 33855, 85783, 0 };
            const std::uint32_t dim12136JoeKuoD6Init[]   =   { 1, 1, 1, 15, 27, 21, 107, 121, 187, 495, 1877, 1957, 3647, 13263, 30729, 18131, 33689, 0 };
            const std::uint32_t dim12137JoeKuoD6Init[]   =   { 1, 1, 5, 13, 3, 43, 41, 53, 127, 299, 839, 3327, 7929, 9921, 29471, 18075, 34283, 0 };
            const std::uint32_t dim12138JoeKuoD6Init[]   =   { 1, 1, 7, 13, 31, 5, 59, 75, 335, 929, 379, 139, 7121, 9281, 31161, 3177, 2615, 0 };
            const std::uint32_t dim12139JoeKuoD6Init[]   =   { 1, 3, 7, 1, 11, 19, 81, 199, 425, 639, 497, 693, 1271, 7363, 10543, 52513, 130549, 0 };
            const std::uint32_t dim12140JoeKuoD6Init[]   =   { 1, 3, 3, 7, 21, 41, 101, 67, 363, 5, 1455, 1433, 81, 15609, 16231, 13285, 38995, 0 };
            const std::uint32_t dim12141JoeKuoD6Init[]   =   { 1, 1, 3, 15, 11, 19, 123, 177, 429, 27, 141, 3095, 5379, 2241, 29877, 59383, 25199, 0 };
            const std::uint32_t dim12142JoeKuoD6Init[]   =   { 1, 1, 7, 7, 19, 63, 93, 217, 279, 349, 149, 2479, 2355, 6475, 29993, 37941, 58715, 0 };
            const std::uint32_t dim12143JoeKuoD6Init[]   =   { 1, 3, 7, 3, 21, 23, 59, 177, 489, 817, 1209, 1629, 5805, 3137, 23767, 62967, 16609, 0 };
            const std::uint32_t dim12144JoeKuoD6Init[]   =   { 1, 3, 3, 7, 9, 55, 59, 31, 191, 891, 833, 1059, 3007, 2331, 385, 58247, 110697, 0 };
            const std::uint32_t dim12145JoeKuoD6Init[]   =   { 1, 1, 3, 3, 11, 61, 9, 189, 79, 621, 209, 2785, 2959, 4133, 20691, 45605, 117089, 0 };
            const std::uint32_t dim12146JoeKuoD6Init[]   =   { 1, 3, 3, 5, 5, 47, 31, 1, 451, 765, 2027, 2327, 1725, 14341, 7997, 6449, 77893, 0 };
            const std::uint32_t dim12147JoeKuoD6Init[]   =   { 1, 1, 7, 1, 7, 27, 27, 129, 227, 505, 1461, 783, 945, 12653, 17913, 61631, 41875, 0 };
            const std::uint32_t dim12148JoeKuoD6Init[]   =   { 1, 1, 1, 11, 13, 41, 41, 221, 483, 825, 451, 493, 1717, 10389, 7805, 37707, 30733, 0 };
            const std::uint32_t dim12149JoeKuoD6Init[]   =   { 1, 1, 5, 3, 31, 31, 75, 3, 323, 83, 563, 919, 7387, 1673, 6157, 7415, 14947, 0 };
            const std::uint32_t dim12150JoeKuoD6Init[]   =   { 1, 1, 7, 13, 19, 37, 29, 93, 153, 491, 1033, 1389, 6361, 11133, 20049, 24585, 107325, 0 };
            const std::uint32_t dim12151JoeKuoD6Init[]   =   { 1, 1, 1, 15, 3, 35, 79, 251, 383, 665, 2033, 3165, 3411, 15965, 28281, 56521, 56479, 0 };
            const std::uint32_t dim12152JoeKuoD6Init[]   =   { 1, 3, 1, 15, 23, 1, 87, 145, 443, 405, 635, 1597, 1455, 5983, 12741, 55133, 2815, 0 };
            const std::uint32_t dim12153JoeKuoD6Init[]   =   { 1, 1, 1, 13, 11, 25, 19, 129, 23, 913, 1121, 223, 1991, 13449, 30443, 50573, 108467, 0 };
            const std::uint32_t dim12154JoeKuoD6Init[]   =   { 1, 1, 7, 11, 29, 31, 49, 51, 415, 293, 173, 4091, 159, 2679, 30643, 58725, 109287, 0 };
            const std::uint32_t dim12155JoeKuoD6Init[]   =   { 1, 1, 1, 7, 15, 53, 69, 231, 387, 693, 1299, 1383, 7935, 10313, 22403, 59341, 3347, 0 };
            const std::uint32_t dim12156JoeKuoD6Init[]   =   { 1, 3, 3, 5, 9, 21, 111, 11, 469, 109, 1565, 3107, 2975, 12491, 26773, 33245, 27589, 0 };
            const std::uint32_t dim12157JoeKuoD6Init[]   =   { 1, 1, 3, 5, 3, 9, 103, 127, 345, 301, 857, 2035, 3269, 13819, 7555, 5197, 94557, 0 };
            const std::uint32_t dim12158JoeKuoD6Init[]   =   { 1, 3, 7, 3, 31, 3, 61, 253, 221, 359, 1281, 1405, 4819, 1329, 17773, 29539, 127043, 0 };
            const std::uint32_t dim12159JoeKuoD6Init[]   =   { 1, 1, 7, 11, 17, 47, 105, 253, 253, 531, 119, 2009, 6125, 9387, 13141, 29079, 28361, 0 };
            const std::uint32_t dim12160JoeKuoD6Init[]   =   { 1, 1, 3, 5, 21, 13, 21, 223, 79, 819, 1425, 1001, 6517, 8883, 29997, 30637, 7717, 0 };
            const std::uint32_t dim12161JoeKuoD6Init[]   =   { 1, 3, 1, 3, 1, 23, 113, 69, 235, 95, 1873, 689, 4611, 13209, 12681, 16057, 114071, 0 };
            const std::uint32_t dim12162JoeKuoD6Init[]   =   { 1, 3, 3, 13, 25, 21, 93, 55, 253, 373, 1659, 829, 6539, 7453, 28195, 33131, 92559, 0 };
            const std::uint32_t dim12163JoeKuoD6Init[]   =   { 1, 1, 3, 11, 25, 29, 81, 235, 429, 811, 1867, 2923, 5949, 4423, 93, 64631, 48357, 0 };
            const std::uint32_t dim12164JoeKuoD6Init[]   =   { 1, 3, 5, 13, 29, 27, 35, 15, 105, 849, 247, 3999, 6441, 12443, 19817, 49897, 21515, 0 };
            const std::uint32_t dim12165JoeKuoD6Init[]   =   { 1, 1, 5, 15, 13, 59, 3, 199, 267, 463, 655, 3875, 2895, 13411, 5081, 22069, 6053, 0 };
            const std::uint32_t dim12166JoeKuoD6Init[]   =   { 1, 1, 5, 9, 5, 13, 111, 83, 281, 543, 629, 1349, 1863, 9523, 19201, 39229, 78265, 0 };
            const std::uint32_t dim12167JoeKuoD6Init[]   =   { 1, 3, 7, 1, 29, 23, 109, 75, 347, 643, 97, 1981, 2797, 11201, 28355, 54105, 45551, 0 };
            const std::uint32_t dim12168JoeKuoD6Init[]   =   { 1, 3, 1, 7, 9, 5, 77, 17, 179, 957, 621, 779, 7117, 1491, 11563, 10131, 98335, 0 };
            const std::uint32_t dim12169JoeKuoD6Init[]   =   { 1, 3, 3, 1, 3, 53, 39, 217, 309, 105, 485, 3123, 3143, 2359, 4923, 22307, 120319, 0 };
            const std::uint32_t dim12170JoeKuoD6Init[]   =   { 1, 1, 7, 7, 11, 5, 65, 165, 321, 455, 625, 2417, 999, 14999, 6777, 13319, 43399, 0 };
            const std::uint32_t dim12171JoeKuoD6Init[]   =   { 1, 1, 7, 3, 11, 55, 43, 119, 135, 129, 581, 3593, 3475, 14667, 30509, 5007, 120135, 0 };
            const std::uint32_t dim12172JoeKuoD6Init[]   =   { 1, 1, 1, 11, 7, 17, 95, 169, 401, 87, 1425, 1821, 7619, 3605, 10993, 35837, 87311, 0 };
            const std::uint32_t dim12173JoeKuoD6Init[]   =   { 1, 1, 7, 11, 11, 35, 29, 63, 395, 301, 373, 2457, 6859, 1915, 11215, 41075, 78219, 0 };
            const std::uint32_t dim12174JoeKuoD6Init[]   =   { 1, 3, 5, 7, 25, 3, 97, 43, 273, 459, 103, 3441, 71, 10269, 29893, 46053, 104801, 0 };
            const std::uint32_t dim12175JoeKuoD6Init[]   =   { 1, 3, 3, 7, 31, 3, 121, 255, 73, 783, 977, 513, 6527, 1189, 8925, 23245, 22287, 0 };
            const std::uint32_t dim12176JoeKuoD6Init[]   =   { 1, 3, 3, 13, 15, 53, 51, 135, 465, 341, 263, 1687, 4085, 14257, 18745, 46945, 115475, 0 };
            const std::uint32_t dim12177JoeKuoD6Init[]   =   { 1, 3, 1, 5, 31, 1, 1, 91, 511, 771, 1501, 2613, 991, 3859, 28911, 65417, 201, 0 };
            const std::uint32_t dim12178JoeKuoD6Init[]   =   { 1, 1, 7, 1, 27, 21, 107, 153, 163, 949, 811, 3087, 3443, 5621, 28795, 58311, 63763, 0 };
            const std::uint32_t dim12179JoeKuoD6Init[]   =   { 1, 1, 7, 5, 29, 29, 57, 175, 29, 821, 1545, 2643, 725, 16225, 29111, 19675, 129995, 0 };
            const std::uint32_t dim12180JoeKuoD6Init[]   =   { 1, 1, 7, 3, 31, 31, 61, 155, 265, 323, 1829, 3891, 6393, 8573, 10627, 10839, 78683, 0 };
            const std::uint32_t dim12181JoeKuoD6Init[]   =   { 1, 3, 5, 7, 29, 7, 67, 181, 313, 731, 1761, 1681, 3673, 8939, 811, 48931, 82021, 0 };
            const std::uint32_t dim12182JoeKuoD6Init[]   =   { 1, 3, 1, 3, 11, 51, 81, 67, 173, 881, 855, 3627, 1613, 4825, 7035, 36261, 64899, 0 };
            const std::uint32_t dim12183JoeKuoD6Init[]   =   { 1, 3, 7, 7, 15, 53, 123, 41, 265, 817, 807, 3875, 7675, 16225, 13313, 62217, 47647, 0 };
            const std::uint32_t dim12184JoeKuoD6Init[]   =   { 1, 1, 3, 13, 23, 47, 125, 155, 403, 651, 1693, 2185, 5565, 9947, 20893, 11287, 118943, 0 };
            const std::uint32_t dim12185JoeKuoD6Init[]   =   { 1, 3, 7, 3, 19, 47, 69, 5, 209, 259, 367, 3929, 7579, 12687, 18109, 51885, 128281, 0 };
            const std::uint32_t dim12186JoeKuoD6Init[]   =   { 1, 1, 7, 5, 27, 41, 45, 41, 205, 1001, 1509, 2649, 1141, 5355, 10265, 34131, 112111, 0 };
            const std::uint32_t dim12187JoeKuoD6Init[]   =   { 1, 3, 7, 5, 19, 41, 103, 63, 49, 25, 271, 793, 3217, 4741, 2563, 61333, 113205, 0 };
            const std::uint32_t dim12188JoeKuoD6Init[]   =   { 1, 3, 3, 15, 15, 35, 13, 233, 277, 673, 545, 545, 7419, 6707, 1867, 58873, 110027, 0 };
            const std::uint32_t dim12189JoeKuoD6Init[]   =   { 1, 1, 7, 3, 9, 23, 67, 55, 3, 1019, 2001, 2909, 7311, 9295, 26953, 43217, 54597, 0 };
            const std::uint32_t dim12190JoeKuoD6Init[]   =   { 1, 3, 5, 7, 13, 33, 67, 27, 75, 569, 1777, 791, 1223, 1805, 19167, 60537, 60039, 0 };
            const std::uint32_t dim12191JoeKuoD6Init[]   =   { 1, 1, 5, 13, 15, 61, 49, 59, 289, 907, 1055, 3579, 8169, 12119, 25479, 32867, 65343, 0 };
            const std::uint32_t dim12192JoeKuoD6Init[]   =   { 1, 3, 5, 9, 5, 63, 91, 225, 377, 469, 891, 891, 5115, 11487, 30151, 44357, 120077, 0 };
            const std::uint32_t dim12193JoeKuoD6Init[]   =   { 1, 1, 1, 15, 29, 59, 19, 51, 295, 585, 149, 497, 5837, 11629, 7825, 18129, 113797, 0 };
            const std::uint32_t dim12194JoeKuoD6Init[]   =   { 1, 1, 3, 7, 31, 25, 77, 209, 183, 337, 1753, 2703, 2559, 11847, 17349, 27359, 21771, 0 };
            const std::uint32_t dim12195JoeKuoD6Init[]   =   { 1, 1, 7, 7, 13, 23, 69, 61, 353, 339, 833, 1935, 4333, 10521, 20331, 62145, 59245, 0 };
            const std::uint32_t dim12196JoeKuoD6Init[]   =   { 1, 1, 5, 13, 19, 57, 35, 59, 203, 99, 487, 2747, 637, 8213, 27053, 29, 64335, 0 };
            const std::uint32_t dim12197JoeKuoD6Init[]   =   { 1, 3, 5, 7, 27, 5, 71, 147, 339, 313, 913, 2845, 5713, 4383, 18969, 54871, 51931, 0 };
            const std::uint32_t dim12198JoeKuoD6Init[]   =   { 1, 1, 1, 5, 7, 23, 19, 11, 111, 543, 311, 1519, 387, 10175, 18209, 14115, 123421, 0 };
            const std::uint32_t dim12199JoeKuoD6Init[]   =   { 1, 3, 7, 11, 7, 7, 123, 193, 417, 65, 1317, 3821, 2315, 14527, 14113, 25873, 23977, 0 };
            const std::uint32_t dim12200JoeKuoD6Init[]   =   { 1, 1, 3, 15, 21, 11, 3, 37, 115, 395, 877, 1227, 6997, 4357, 11397, 52855, 24899, 0 };
            const std::uint32_t dim12201JoeKuoD6Init[]   =   { 1, 1, 7, 5, 15, 45, 45, 17, 441, 605, 429, 739, 4759, 5249, 11311, 55049, 56909, 0 };
            const std::uint32_t dim12202JoeKuoD6Init[]   =   { 1, 1, 1, 5, 3, 5, 77, 31, 407, 703, 385, 235, 7751, 617, 16013, 27269, 66971, 0 };
            const std::uint32_t dim12203JoeKuoD6Init[]   =   { 1, 3, 3, 15, 25, 27, 19, 251, 465, 197, 1039, 3261, 4557, 4821, 16083, 43997, 61371, 0 };
            const std::uint32_t dim12204JoeKuoD6Init[]   =   { 1, 3, 3, 15, 21, 45, 13, 139, 213, 797, 619, 2125, 3805, 4149, 11427, 59807, 104587, 0 };
            const std::uint32_t dim12205JoeKuoD6Init[]   =   { 1, 3, 1, 1, 29, 27, 25, 7, 371, 535, 1613, 1083, 4221, 8913, 10601, 6447, 17619, 0 };
            const std::uint32_t dim12206JoeKuoD6Init[]   =   { 1, 1, 3, 3, 13, 35, 37, 127, 285, 899, 307, 123, 129, 14035, 26503, 64103, 27155, 0 };
            const std::uint32_t dim12207JoeKuoD6Init[]   =   { 1, 1, 7, 7, 27, 25, 45, 245, 271, 281, 69, 3505, 7087, 1529, 7121, 30327, 89131, 0 };
            const std::uint32_t dim12208JoeKuoD6Init[]   =   { 1, 1, 3, 11, 13, 57, 31, 23, 455, 427, 1683, 3019, 5827, 8817, 12943, 321, 39951, 0 };
            const std::uint32_t dim12209JoeKuoD6Init[]   =   { 1, 3, 1, 3, 31, 41, 69, 211, 385, 275, 1569, 2265, 4017, 11057, 15, 16619, 126967, 0 };
            const std::uint32_t dim12210JoeKuoD6Init[]   =   { 1, 3, 3, 1, 27, 27, 21, 145, 125, 929, 1371, 1469, 1591, 5283, 4651, 1265, 17161, 0 };
            const std::uint32_t dim12211JoeKuoD6Init[]   =   { 1, 3, 7, 5, 29, 31, 41, 141, 49, 967, 1421, 663, 6089, 3831, 11353, 38809, 108605, 0 };
            const std::uint32_t dim12212JoeKuoD6Init[]   =   { 1, 1, 7, 15, 11, 23, 91, 31, 9, 717, 265, 1729, 3563, 8145, 20441, 22933, 103683, 0 };
            const std::uint32_t dim12213JoeKuoD6Init[]   =   { 1, 1, 7, 3, 17, 13, 47, 13, 241, 1017, 1803, 2091, 7379, 2941, 11783, 36189, 53513, 0 };
            const std::uint32_t dim12214JoeKuoD6Init[]   =   { 1, 3, 1, 11, 31, 63, 107, 79, 427, 385, 1497, 1265, 5135, 13597, 27343, 56733, 100595, 0 };
            const std::uint32_t dim12215JoeKuoD6Init[]   =   { 1, 3, 7, 3, 9, 15, 119, 29, 205, 151, 1453, 3575, 3627, 7815, 3553, 31457, 14267, 0 };
            const std::uint32_t dim12216JoeKuoD6Init[]   =   { 1, 3, 1, 7, 15, 21, 73, 47, 417, 29, 1231, 2477, 161, 15997, 4457, 3939, 43929, 0 };
            const std::uint32_t dim12217JoeKuoD6Init[]   =   { 1, 1, 5, 5, 19, 49, 103, 251, 359, 69, 669, 299, 8161, 10579, 13999, 26859, 92199, 0 };
            const std::uint32_t dim12218JoeKuoD6Init[]   =   { 1, 1, 3, 1, 9, 27, 81, 7, 115, 29, 1067, 1933, 3061, 2885, 27883, 65227, 59365, 0 };
            const std::uint32_t dim12219JoeKuoD6Init[]   =   { 1, 1, 1, 5, 23, 17, 1, 113, 495, 155, 1673, 3945, 8053, 7935, 3537, 65141, 11809, 0 };
            const std::uint32_t dim12220JoeKuoD6Init[]   =   { 1, 1, 1, 15, 15, 59, 61, 213, 303, 851, 1893, 615, 6659, 9351, 16621, 6097, 114383, 0 };
            const std::uint32_t dim12221JoeKuoD6Init[]   =   { 1, 3, 1, 7, 19, 11, 95, 127, 277, 677, 1631, 2563, 3295, 7029, 4059, 44079, 128857, 0 };
            const std::uint32_t dim12222JoeKuoD6Init[]   =   { 1, 3, 7, 11, 27, 49, 99, 43, 279, 771, 123, 2969, 699, 12915, 22039, 62257, 79359, 0 };
            const std::uint32_t dim12223JoeKuoD6Init[]   =   { 1, 1, 7, 3, 19, 45, 45, 113, 251, 883, 715, 1541, 1573, 3345, 23855, 62681, 57591, 0 };
            const std::uint32_t dim12224JoeKuoD6Init[]   =   { 1, 1, 5, 15, 11, 1, 51, 15, 135, 519, 961, 1447, 4425, 2139, 3309, 35111, 74143, 0 };
            const std::uint32_t dim12225JoeKuoD6Init[]   =   { 1, 3, 7, 7, 17, 39, 109, 25, 11, 549, 315, 2175, 685, 11837, 9151, 6277, 45011, 0 };
            const std::uint32_t dim12226JoeKuoD6Init[]   =   { 1, 1, 1, 9, 27, 7, 95, 1, 385, 167, 453, 1027, 4105, 16351, 19, 10375, 62833, 0 };
            const std::uint32_t dim12227JoeKuoD6Init[]   =   { 1, 3, 7, 13, 17, 19, 107, 11, 441, 171, 185, 3567, 1245, 12161, 30257, 48105, 87105, 0 };
            const std::uint32_t dim12228JoeKuoD6Init[]   =   { 1, 3, 3, 9, 15, 5, 109, 225, 85, 919, 513, 3559, 5411, 9009, 27391, 25115, 84875, 0 };
            const std::uint32_t dim12229JoeKuoD6Init[]   =   { 1, 3, 3, 7, 11, 37, 81, 51, 121, 25, 1897, 2121, 6425, 16087, 4259, 29501, 118067, 0 };
            const std::uint32_t dim12230JoeKuoD6Init[]   =   { 1, 1, 7, 3, 5, 53, 73, 127, 137, 739, 543, 1723, 1163, 2791, 18519, 1459, 50869, 0 };
            const std::uint32_t dim12231JoeKuoD6Init[]   =   { 1, 1, 3, 11, 29, 51, 101, 189, 193, 839, 25, 3109, 3035, 3917, 23929, 38577, 129705, 0 };
            const std::uint32_t dim12232JoeKuoD6Init[]   =   { 1, 3, 7, 15, 9, 29, 93, 101, 271, 791, 1257, 1843, 2701, 8205, 15195, 9109, 120835, 0 };
            const std::uint32_t dim12233JoeKuoD6Init[]   =   { 1, 3, 3, 5, 29, 47, 31, 135, 483, 385, 1395, 2955, 7291, 12885, 9491, 14581, 66293, 0 };
            const std::uint32_t dim12234JoeKuoD6Init[]   =   { 1, 1, 7, 1, 5, 37, 105, 149, 63, 617, 1611, 3025, 3177, 15463, 3373, 3503, 95001, 0 };
            const std::uint32_t dim12235JoeKuoD6Init[]   =   { 1, 1, 5, 13, 1, 57, 19, 35, 127, 423, 1221, 1547, 4083, 347, 17131, 60087, 27437, 0 };
            const std::uint32_t dim12236JoeKuoD6Init[]   =   { 1, 3, 7, 9, 25, 1, 105, 39, 25, 921, 1897, 1729, 2207, 7761, 24197, 457, 64241, 0 };
            const std::uint32_t dim12237JoeKuoD6Init[]   =   { 1, 3, 7, 9, 15, 21, 13, 113, 379, 1021, 489, 1757, 5869, 4833, 24717, 52227, 3209, 0 };
            const std::uint32_t dim12238JoeKuoD6Init[]   =   { 1, 3, 1, 5, 9, 61, 25, 41, 183, 473, 383, 2259, 6939, 3, 32161, 6319, 93099, 0 };
            const std::uint32_t dim12239JoeKuoD6Init[]   =   { 1, 1, 5, 13, 13, 47, 97, 3, 357, 837, 1655, 485, 4251, 12153, 9013, 25121, 51877, 0 };
            const std::uint32_t dim12240JoeKuoD6Init[]   =   { 1, 1, 1, 15, 7, 59, 65, 119, 467, 313, 1333, 2007, 5165, 13935, 13679, 3999, 81811, 0 };
            const std::uint32_t dim12241JoeKuoD6Init[]   =   { 1, 1, 5, 13, 13, 1, 63, 117, 449, 13, 1017, 1583, 7599, 3669, 32699, 59455, 32363, 0 };
            const std::uint32_t dim12242JoeKuoD6Init[]   =   { 1, 1, 7, 9, 7, 15, 37, 251, 167, 25, 1085, 2067, 2771, 5737, 20661, 19231, 59547, 0 };
            const std::uint32_t dim12243JoeKuoD6Init[]   =   { 1, 1, 5, 13, 29, 11, 63, 37, 281, 657, 1567, 2879, 7601, 15617, 16527, 51695, 5583, 0 };
            const std::uint32_t dim12244JoeKuoD6Init[]   =   { 1, 1, 5, 3, 31, 17, 19, 65, 315, 413, 927, 3617, 4089, 11899, 3759, 47991, 1685, 0 };
            const std::uint32_t dim12245JoeKuoD6Init[]   =   { 1, 1, 1, 1, 13, 47, 89, 91, 379, 429, 283, 3765, 2923, 14955, 26399, 9579, 39817, 0 };
            const std::uint32_t dim12246JoeKuoD6Init[]   =   { 1, 1, 1, 9, 1, 17, 91, 119, 327, 291, 39, 2883, 6265, 553, 7559, 60577, 34393, 0 };
            const std::uint32_t dim12247JoeKuoD6Init[]   =   { 1, 3, 5, 5, 9, 33, 123, 219, 103, 529, 181, 1321, 6815, 2411, 10555, 43911, 18889, 0 };
            const std::uint32_t dim12248JoeKuoD6Init[]   =   { 1, 1, 5, 7, 9, 13, 7, 45, 427, 523, 1189, 255, 2103, 7217, 16249, 14631, 90409, 0 };
            const std::uint32_t dim12249JoeKuoD6Init[]   =   { 1, 1, 1, 9, 11, 35, 55, 71, 89, 637, 1417, 411, 5305, 10125, 20715, 62927, 4993, 0 };
            const std::uint32_t dim12250JoeKuoD6Init[]   =   { 1, 3, 1, 9, 1, 59, 27, 221, 267, 797, 1081, 951, 1369, 2677, 20763, 63301, 61963, 0 };
            const std::uint32_t dim12251JoeKuoD6Init[]   =   { 1, 3, 5, 5, 17, 9, 67, 177, 89, 953, 1329, 1649, 989, 7773, 28747, 26231, 42331, 0 };
            const std::uint32_t dim12252JoeKuoD6Init[]   =   { 1, 3, 3, 9, 23, 35, 17, 145, 53, 519, 1173, 2079, 2593, 3633, 32005, 30573, 55651, 0 };
            const std::uint32_t dim12253JoeKuoD6Init[]   =   { 1, 1, 7, 7, 17, 41, 47, 253, 107, 843, 9, 323, 2391, 3267, 25813, 1741, 93493, 0 };
            const std::uint32_t dim12254JoeKuoD6Init[]   =   { 1, 1, 1, 9, 31, 43, 47, 91, 235, 569, 2017, 2385, 5055, 5747, 26471, 48819, 47315, 0 };
            const std::uint32_t dim12255JoeKuoD6Init[]   =   { 1, 3, 5, 9, 1, 17, 87, 91, 55, 287, 995, 2577, 1151, 9119, 22791, 50899, 16423, 0 };
            const std::uint32_t dim12256JoeKuoD6Init[]   =   { 1, 3, 7, 1, 3, 29, 9, 193, 269, 201, 325, 2209, 1061, 7957, 23265, 65083, 27575, 0 };
            const std::uint32_t dim12257JoeKuoD6Init[]   =   { 1, 3, 7, 15, 27, 23, 37, 239, 165, 959, 1965, 2105, 1581, 6621, 17315, 49255, 62487, 0 };
            const std::uint32_t dim12258JoeKuoD6Init[]   =   { 1, 3, 7, 7, 11, 31, 73, 145, 429, 421, 571, 3375, 2797, 15889, 26523, 12315, 48061, 0 };
            const std::uint32_t dim12259JoeKuoD6Init[]   =   { 1, 3, 3, 15, 23, 27, 105, 75, 497, 137, 475, 1343, 537, 10499, 27807, 46623, 32435, 0 };
            const std::uint32_t dim12260JoeKuoD6Init[]   =   { 1, 1, 7, 15, 15, 11, 51, 107, 225, 557, 1461, 3447, 1243, 13827, 23675, 26139, 54603, 0 };
            const std::uint32_t dim12261JoeKuoD6Init[]   =   { 1, 3, 5, 5, 7, 25, 51, 3, 85, 371, 1503, 3217, 1779, 7141, 29471, 42247, 107699, 0 };
            const std::uint32_t dim12262JoeKuoD6Init[]   =   { 1, 3, 7, 15, 23, 53, 127, 229, 241, 165, 1985, 1921, 5917, 15743, 18349, 23981, 58241, 0 };
            const std::uint32_t dim12263JoeKuoD6Init[]   =   { 1, 1, 3, 13, 9, 63, 49, 67, 21, 57, 377, 1807, 5603, 13651, 28039, 3745, 4903, 0 };
            const std::uint32_t dim12264JoeKuoD6Init[]   =   { 1, 3, 7, 11, 1, 43, 17, 95, 79, 343, 1939, 2349, 5195, 3047, 4325, 27829, 53809, 0 };
            const std::uint32_t dim12265JoeKuoD6Init[]   =   { 1, 1, 5, 9, 7, 43, 111, 221, 493, 151, 1635, 3949, 6661, 4861, 17661, 61909, 4975, 0 };
            const std::uint32_t dim12266JoeKuoD6Init[]   =   { 1, 3, 1, 3, 31, 47, 63, 45, 401, 153, 1139, 2125, 6639, 14093, 31607, 20645, 52245, 0 };
            const std::uint32_t dim12267JoeKuoD6Init[]   =   { 1, 1, 3, 1, 19, 31, 59, 139, 285, 749, 751, 775, 7795, 14917, 30295, 61037, 12315, 0 };
            const std::uint32_t dim12268JoeKuoD6Init[]   =   { 1, 3, 3, 9, 15, 55, 79, 183, 373, 663, 497, 2589, 4955, 5409, 23527, 2683, 5487, 0 };
            const std::uint32_t dim12269JoeKuoD6Init[]   =   { 1, 3, 7, 11, 25, 47, 53, 225, 197, 109, 1937, 1375, 7347, 7353, 2335, 21775, 14877, 0 };
            const std::uint32_t dim12270JoeKuoD6Init[]   =   { 1, 3, 1, 9, 23, 61, 51, 221, 129, 57, 115, 1031, 6793, 14773, 3331, 24951, 94761, 0 };
            const std::uint32_t dim12271JoeKuoD6Init[]   =   { 1, 1, 5, 15, 31, 9, 69, 117, 295, 147, 673, 3627, 7167, 13835, 20593, 53163, 83033, 0 };
            const std::uint32_t dim12272JoeKuoD6Init[]   =   { 1, 3, 7, 9, 15, 63, 111, 225, 147, 863, 691, 629, 7485, 483, 21835, 46251, 94645, 0 };
            const std::uint32_t dim12273JoeKuoD6Init[]   =   { 1, 3, 3, 3, 11, 41, 23, 159, 133, 787, 1617, 629, 5047, 4465, 29051, 47499, 7211, 0 };
            const std::uint32_t dim12274JoeKuoD6Init[]   =   { 1, 1, 3, 13, 21, 61, 29, 159, 73, 165, 917, 2577, 7237, 11807, 3767, 56861, 51395, 0 };
            const std::uint32_t dim12275JoeKuoD6Init[]   =   { 1, 1, 5, 3, 15, 31, 37, 233, 283, 265, 1645, 3843, 1971, 4989, 26823, 15243, 74931, 0 };
            const std::uint32_t dim12276JoeKuoD6Init[]   =   { 1, 3, 7, 11, 9, 51, 7, 119, 237, 905, 1211, 3041, 7641, 3387, 8373, 38961, 68925, 0 };
            const std::uint32_t dim12277JoeKuoD6Init[]   =   { 1, 1, 7, 3, 17, 53, 55, 195, 57, 957, 2027, 3965, 2993, 411, 13947, 58349, 32169, 0 };
            const std::uint32_t dim12278JoeKuoD6Init[]   =   { 1, 1, 7, 9, 7, 37, 55, 93, 173, 769, 1381, 3977, 5293, 5051, 21455, 45547, 64653, 0 };
            const std::uint32_t dim12279JoeKuoD6Init[]   =   { 1, 3, 5, 7, 1, 41, 89, 161, 315, 361, 1675, 2993, 3281, 13043, 19003, 22129, 130379, 0 };
            const std::uint32_t dim12280JoeKuoD6Init[]   =   { 1, 3, 1, 9, 13, 37, 85, 197, 465, 177, 661, 943, 541, 11117, 9751, 4193, 98291, 0 };
            const std::uint32_t dim12281JoeKuoD6Init[]   =   { 1, 1, 3, 7, 21, 7, 67, 17, 41, 817, 1159, 1483, 6937, 10079, 3639, 27887, 14541, 0 };
            const std::uint32_t dim12282JoeKuoD6Init[]   =   { 1, 3, 3, 15, 17, 63, 69, 215, 437, 883, 1857, 3319, 3107, 16279, 10709, 30433, 52551, 0 };
            const std::uint32_t dim12283JoeKuoD6Init[]   =   { 1, 1, 3, 11, 1, 5, 69, 37, 419, 999, 1711, 875, 3807, 10811, 16345, 61155, 116043, 0 };
            const std::uint32_t dim12284JoeKuoD6Init[]   =   { 1, 3, 7, 13, 17, 7, 57, 237, 81, 691, 1143, 4075, 2481, 643, 8091, 8243, 80111, 0 };
            const std::uint32_t dim12285JoeKuoD6Init[]   =   { 1, 1, 7, 7, 17, 61, 73, 215, 113, 885, 159, 2243, 1177, 10981, 10123, 48995, 123349, 0 };
            const std::uint32_t dim12286JoeKuoD6Init[]   =   { 1, 1, 1, 7, 31, 47, 99, 15, 371, 343, 1483, 1985, 25, 11125, 8357, 10677, 130895, 0 };
            const std::uint32_t dim12287JoeKuoD6Init[]   =   { 1, 3, 1, 13, 25, 41, 83, 37, 129, 493, 641, 185, 6607, 7213, 13285, 10439, 73227, 0 };
            const std::uint32_t dim12288JoeKuoD6Init[]   =   { 1, 1, 5, 7, 17, 15, 93, 53, 281, 91, 115, 3675, 3081, 9825, 23653, 40095, 91803, 0 };
            const std::uint32_t dim12289JoeKuoD6Init[]   =   { 1, 1, 1, 5, 3, 25, 39, 207, 419, 361, 953, 2823, 8105, 15763, 29199, 61607, 32633, 0 };
            const std::uint32_t dim12290JoeKuoD6Init[]   =   { 1, 1, 3, 1, 31, 51, 55, 3, 277, 639, 191, 1783, 139, 29, 16659, 30199, 69109, 0 };
            const std::uint32_t dim12291JoeKuoD6Init[]   =   { 1, 1, 1, 7, 31, 59, 25, 13, 239, 617, 115, 1787, 5757, 9927, 2417, 37313, 115135, 0 };
            const std::uint32_t dim12292JoeKuoD6Init[]   =   { 1, 1, 3, 5, 19, 35, 5, 187, 483, 823, 1875, 163, 4235, 853, 23679, 50899, 94981, 0 };
            const std::uint32_t dim12293JoeKuoD6Init[]   =   { 1, 3, 3, 11, 9, 39, 121, 201, 189, 543, 1493, 1215, 351, 16063, 1701, 56559, 108053, 0 };
            const std::uint32_t dim12294JoeKuoD6Init[]   =   { 1, 3, 1, 7, 1, 39, 31, 163, 347, 307, 349, 4081, 1729, 16265, 363, 28297, 50631, 0 };
            const std::uint32_t dim12295JoeKuoD6Init[]   =   { 1, 3, 7, 13, 21, 55, 127, 161, 75, 9, 1285, 1839, 5283, 5667, 10979, 22185, 7581, 0 };
            const std::uint32_t dim12296JoeKuoD6Init[]   =   { 1, 1, 3, 5, 13, 45, 17, 181, 117, 395, 1685, 663, 3441, 5359, 7157, 27759, 102343, 0 };
            const std::uint32_t dim12297JoeKuoD6Init[]   =   { 1, 3, 1, 7, 7, 31, 97, 187, 383, 769, 1469, 4007, 5521, 13973, 49, 43823, 75649, 0 };
            const std::uint32_t dim12298JoeKuoD6Init[]   =   { 1, 3, 5, 7, 31, 13, 47, 11, 335, 961, 321, 3367, 1903, 503, 8409, 1101, 58215, 0 };
            const std::uint32_t dim12299JoeKuoD6Init[]   =   { 1, 1, 7, 7, 25, 49, 39, 1, 453, 419, 333, 1759, 2287, 6243, 10723, 13687, 56853, 0 };
            const std::uint32_t dim12300JoeKuoD6Init[]   =   { 1, 3, 3, 7, 11, 55, 125, 197, 19, 591, 1969, 511, 2501, 8429, 29467, 27917, 63457, 0 };
            const std::uint32_t dim12301JoeKuoD6Init[]   =   { 1, 1, 3, 11, 11, 43, 35, 213, 231, 119, 379, 3761, 4891, 5677, 20317, 5459, 55487, 0 };
            const std::uint32_t dim12302JoeKuoD6Init[]   =   { 1, 1, 5, 7, 21, 9, 127, 59, 97, 963, 847, 2131, 7907, 11409, 8785, 48197, 96907, 0 };
            const std::uint32_t dim12303JoeKuoD6Init[]   =   { 1, 3, 5, 3, 23, 7, 45, 95, 179, 691, 1571, 3091, 6359, 9105, 26021, 26925, 43, 0 };
            const std::uint32_t dim12304JoeKuoD6Init[]   =   { 1, 3, 3, 7, 21, 7, 11, 219, 439, 465, 1983, 117, 4639, 8387, 27637, 15883, 5567, 0 };
            const std::uint32_t dim12305JoeKuoD6Init[]   =   { 1, 1, 7, 3, 1, 3, 51, 205, 425, 133, 563, 1317, 533, 1227, 8361, 23407, 39825, 0 };
            const std::uint32_t dim12306JoeKuoD6Init[]   =   { 1, 1, 5, 3, 3, 39, 19, 69, 477, 605, 3, 1887, 2077, 13673, 2763, 64415, 104519, 0 };
            const std::uint32_t dim12307JoeKuoD6Init[]   =   { 1, 1, 5, 15, 11, 45, 89, 245, 177, 591, 1313, 587, 4781, 5103, 26401, 12643, 38959, 0 };
            const std::uint32_t dim12308JoeKuoD6Init[]   =   { 1, 1, 1, 5, 11, 13, 15, 95, 271, 99, 2001, 2701, 6065, 3527, 7423, 37525, 117161, 0 };
            const std::uint32_t dim12309JoeKuoD6Init[]   =   { 1, 3, 7, 7, 21, 17, 111, 149, 373, 591, 1461, 809, 3877, 8635, 13209, 31439, 64285, 0 };
            const std::uint32_t dim12310JoeKuoD6Init[]   =   { 1, 3, 1, 15, 25, 51, 55, 161, 357, 181, 41, 2345, 3553, 9917, 30123, 40683, 122497, 0 };
            const std::uint32_t dim12311JoeKuoD6Init[]   =   { 1, 3, 7, 15, 5, 55, 119, 239, 291, 665, 1537, 3309, 2519, 12397, 25897, 51529, 28673, 0 };
            const std::uint32_t dim12312JoeKuoD6Init[]   =   { 1, 1, 1, 9, 25, 45, 21, 119, 19, 145, 313, 2509, 1031, 3319, 14863, 10759, 22577, 0 };
            const std::uint32_t dim12313JoeKuoD6Init[]   =   { 1, 3, 1, 15, 1, 61, 87, 229, 511, 83, 79, 51, 1407, 16293, 26217, 25839, 86207, 0 };
            const std::uint32_t dim12314JoeKuoD6Init[]   =   { 1, 3, 7, 7, 23, 43, 89, 11, 43, 801, 569, 3273, 315, 9537, 681, 34783, 97101, 0 };
            const std::uint32_t dim12315JoeKuoD6Init[]   =   { 1, 1, 5, 1, 13, 31, 77, 115, 501, 669, 27, 3765, 6789, 9139, 30587, 45995, 102433, 0 };
            const std::uint32_t dim12316JoeKuoD6Init[]   =   { 1, 1, 7, 1, 15, 21, 57, 197, 243, 353, 71, 341, 7319, 8467, 9779, 15755, 4185, 0 };
            const std::uint32_t dim12317JoeKuoD6Init[]   =   { 1, 1, 1, 1, 17, 21, 3, 185, 277, 585, 265, 3189, 3975, 353, 8541, 23905, 21881, 0 };
            const std::uint32_t dim12318JoeKuoD6Init[]   =   { 1, 3, 5, 3, 5, 23, 113, 253, 343, 73, 1419, 2529, 4333, 2007, 14307, 60591, 55411, 0 };
            const std::uint32_t dim12319JoeKuoD6Init[]   =   { 1, 1, 7, 3, 25, 35, 109, 173, 351, 487, 1551, 3207, 1189, 5091, 3581, 4699, 22085, 0 };
            const std::uint32_t dim12320JoeKuoD6Init[]   =   { 1, 1, 3, 11, 9, 9, 71, 173, 17, 595, 2015, 2543, 4889, 6025, 15265, 6459, 3977, 0 };
            const std::uint32_t dim12321JoeKuoD6Init[]   =   { 1, 3, 5, 15, 11, 13, 11, 189, 431, 307, 317, 3131, 1421, 10863, 5311, 25273, 43187, 0 };
            const std::uint32_t dim12322JoeKuoD6Init[]   =   { 1, 1, 1, 7, 7, 41, 103, 231, 321, 327, 1849, 2485, 6461, 10259, 4577, 52951, 33053, 0 };
            const std::uint32_t dim12323JoeKuoD6Init[]   =   { 1, 3, 3, 15, 11, 33, 73, 155, 453, 597, 575, 2119, 327, 4227, 32271, 7429, 102007, 0 };
            const std::uint32_t dim12324JoeKuoD6Init[]   =   { 1, 1, 3, 7, 15, 9, 95, 177, 21, 245, 257, 3637, 821, 16351, 1733, 10635, 59885, 0 };
            const std::uint32_t dim12325JoeKuoD6Init[]   =   { 1, 1, 3, 7, 23, 41, 107, 147, 57, 877, 1609, 3275, 339, 12997, 5989, 62293, 21549, 0 };
            const std::uint32_t dim12326JoeKuoD6Init[]   =   { 1, 1, 7, 13, 19, 39, 111, 229, 321, 487, 873, 3365, 4915, 251, 30629, 45775, 73549, 0 };
            const std::uint32_t dim12327JoeKuoD6Init[]   =   { 1, 1, 1, 13, 25, 61, 43, 111, 135, 463, 1921, 1723, 7505, 13805, 30633, 51683, 7353, 0 };
            const std::uint32_t dim12328JoeKuoD6Init[]   =   { 1, 1, 1, 1, 31, 41, 35, 205, 375, 189, 635, 3589, 3507, 8131, 13437, 22823, 68451, 0 };
            const std::uint32_t dim12329JoeKuoD6Init[]   =   { 1, 3, 7, 5, 31, 47, 13, 229, 105, 195, 685, 529, 39, 2651, 6821, 11043, 112123, 0 };
            const std::uint32_t dim12330JoeKuoD6Init[]   =   { 1, 3, 7, 13, 3, 23, 21, 203, 89, 957, 1577, 1711, 585, 3937, 17681, 55577, 61075, 0 };
            const std::uint32_t dim12331JoeKuoD6Init[]   =   { 1, 3, 3, 3, 17, 37, 49, 7, 287, 183, 1185, 2979, 2103, 1217, 22105, 11677, 19603, 0 };
            const std::uint32_t dim12332JoeKuoD6Init[]   =   { 1, 1, 1, 9, 29, 35, 93, 179, 403, 563, 441, 3485, 6909, 12647, 3885, 60089, 29275, 0 };
            const std::uint32_t dim12333JoeKuoD6Init[]   =   { 1, 3, 3, 9, 15, 37, 49, 103, 509, 77, 495, 921, 2599, 14735, 30951, 22779, 47747, 0 };
            const std::uint32_t dim12334JoeKuoD6Init[]   =   { 1, 3, 3, 11, 17, 45, 43, 235, 379, 51, 925, 89, 2241, 10273, 27649, 8101, 93977, 0 };
            const std::uint32_t dim12335JoeKuoD6Init[]   =   { 1, 3, 3, 3, 11, 7, 25, 163, 405, 997, 847, 2743, 4705, 7041, 10997, 50189, 10775, 0 };
            const std::uint32_t dim12336JoeKuoD6Init[]   =   { 1, 1, 1, 13, 19, 43, 3, 125, 37, 41, 5, 965, 2681, 3737, 29057, 37777, 119537, 0 };
            const std::uint32_t dim12337JoeKuoD6Init[]   =   { 1, 1, 1, 1, 11, 27, 101, 67, 73, 199, 1739, 2835, 5837, 10595, 9865, 38493, 99323, 0 };
            const std::uint32_t dim12338JoeKuoD6Init[]   =   { 1, 3, 1, 13, 27, 43, 21, 79, 419, 847, 843, 2563, 8133, 10295, 10127, 30839, 104863, 0 };
            const std::uint32_t dim12339JoeKuoD6Init[]   =   { 1, 3, 3, 11, 15, 37, 71, 251, 157, 971, 165, 1647, 2583, 205, 23555, 55297, 106893, 0 };
            const std::uint32_t dim12340JoeKuoD6Init[]   =   { 1, 1, 5, 15, 1, 21, 113, 107, 287, 727, 71, 2655, 1435, 11125, 15257, 18899, 37737, 0 };
            const std::uint32_t dim12341JoeKuoD6Init[]   =   { 1, 1, 3, 3, 27, 49, 17, 85, 57, 237, 349, 4049, 1103, 2523, 3919, 36587, 128595, 0 };
            const std::uint32_t dim12342JoeKuoD6Init[]   =   { 1, 3, 5, 9, 13, 1, 65, 13, 361, 409, 413, 2153, 5953, 10651, 25383, 49777, 65399, 0 };
            const std::uint32_t dim12343JoeKuoD6Init[]   =   { 1, 1, 7, 9, 19, 47, 69, 127, 121, 925, 57, 2775, 4981, 3643, 4077, 3081, 56093, 0 };
            const std::uint32_t dim12344JoeKuoD6Init[]   =   { 1, 3, 3, 13, 1, 53, 45, 13, 489, 445, 623, 3547, 1659, 1899, 11971, 3725, 12445, 0 };
            const std::uint32_t dim12345JoeKuoD6Init[]   =   { 1, 3, 7, 11, 13, 9, 59, 157, 125, 975, 1283, 297, 3609, 3179, 31341, 54727, 112515, 0 };
            const std::uint32_t dim12346JoeKuoD6Init[]   =   { 1, 1, 1, 13, 23, 63, 69, 249, 159, 593, 47, 3957, 757, 14693, 26345, 18839, 111263, 0 };
            const std::uint32_t dim12347JoeKuoD6Init[]   =   { 1, 1, 1, 1, 31, 37, 37, 199, 7, 425, 337, 1475, 271, 16215, 12089, 16765, 13519, 0 };
            const std::uint32_t dim12348JoeKuoD6Init[]   =   { 1, 1, 7, 11, 31, 59, 121, 139, 413, 807, 737, 1235, 3505, 5859, 14205, 31939, 4713, 0 };
            const std::uint32_t dim12349JoeKuoD6Init[]   =   { 1, 1, 1, 9, 21, 51, 113, 159, 345, 807, 635, 523, 5535, 13307, 4239, 14847, 23711, 0 };
            const std::uint32_t dim12350JoeKuoD6Init[]   =   { 1, 3, 5, 13, 31, 7, 33, 1, 293, 271, 1829, 2535, 6333, 12037, 29401, 35009, 37789, 0 };
            const std::uint32_t dim12351JoeKuoD6Init[]   =   { 1, 1, 7, 3, 7, 57, 31, 45, 177, 475, 843, 1265, 585, 16099, 29293, 52407, 56131, 0 };
            const std::uint32_t dim12352JoeKuoD6Init[]   =   { 1, 3, 3, 11, 1, 25, 117, 205, 139, 141, 1229, 903, 1883, 11269, 30493, 3979, 4263, 0 };
            const std::uint32_t dim12353JoeKuoD6Init[]   =   { 1, 1, 5, 13, 25, 43, 9, 237, 347, 869, 1765, 1389, 1931, 13331, 17325, 45999, 121201, 0 };
            const std::uint32_t dim12354JoeKuoD6Init[]   =   { 1, 3, 3, 11, 3, 13, 95, 49, 389, 53, 491, 1467, 5105, 16053, 6305, 15759, 51991, 0 };
            const std::uint32_t dim12355JoeKuoD6Init[]   =   { 1, 3, 5, 15, 1, 53, 85, 69, 75, 409, 1299, 1245, 7951, 10709, 9157, 3509, 103975, 0 };
            const std::uint32_t dim12356JoeKuoD6Init[]   =   { 1, 1, 1, 13, 1, 33, 97, 235, 463, 413, 1759, 1891, 1781, 5261, 5759, 201, 69199, 0 };
            const std::uint32_t dim12357JoeKuoD6Init[]   =   { 1, 1, 3, 13, 21, 27, 101, 143, 123, 705, 969, 2461, 6057, 13091, 6077, 38311, 30379, 0 };
            const std::uint32_t dim12358JoeKuoD6Init[]   =   { 1, 3, 3, 1, 13, 11, 73, 33, 495, 513, 763, 3089, 421, 13663, 30169, 56599, 38847, 0 };
            const std::uint32_t dim12359JoeKuoD6Init[]   =   { 1, 1, 7, 13, 13, 31, 91, 63, 233, 137, 859, 2449, 539, 12461, 13477, 31605, 58919, 0 };
            const std::uint32_t dim12360JoeKuoD6Init[]   =   { 1, 1, 1, 9, 13, 49, 107, 45, 451, 707, 1735, 1881, 3451, 9131, 25481, 10841, 116067, 0 };
            const std::uint32_t dim12361JoeKuoD6Init[]   =   { 1, 3, 7, 1, 27, 21, 51, 117, 63, 53, 575, 3325, 1099, 11181, 23609, 47141, 115421, 0 };
            const std::uint32_t dim12362JoeKuoD6Init[]   =   { 1, 3, 1, 13, 25, 29, 53, 135, 165, 319, 1695, 341, 8157, 10671, 7095, 60749, 31513, 0 };
            const std::uint32_t dim12363JoeKuoD6Init[]   =   { 1, 1, 7, 5, 3, 53, 123, 137, 449, 87, 951, 693, 6943, 15331, 1515, 24019, 56613, 0 };
            const std::uint32_t dim12364JoeKuoD6Init[]   =   { 1, 3, 7, 5, 25, 17, 43, 251, 301, 203, 633, 1271, 6253, 4475, 10773, 25003, 67599, 0 };
            const std::uint32_t dim12365JoeKuoD6Init[]   =   { 1, 1, 3, 9, 1, 25, 117, 159, 13, 155, 851, 2497, 6155, 6549, 27909, 24423, 82357, 0 };
            const std::uint32_t dim12366JoeKuoD6Init[]   =   { 1, 1, 1, 1, 21, 59, 103, 43, 291, 111, 1355, 401, 5129, 16017, 25947, 15391, 46745, 0 };
            const std::uint32_t dim12367JoeKuoD6Init[]   =   { 1, 1, 1, 13, 13, 51, 95, 111, 17, 963, 1535, 3003, 6163, 11377, 6787, 57275, 109559, 0 };
            const std::uint32_t dim12368JoeKuoD6Init[]   =   { 1, 1, 5, 11, 11, 3, 85, 207, 489, 117, 269, 747, 5719, 8501, 7307, 59223, 18941, 0 };
            const std::uint32_t dim12369JoeKuoD6Init[]   =   { 1, 1, 5, 1, 9, 53, 41, 255, 271, 995, 1939, 2739, 2221, 14841, 22617, 10643, 6427, 0 };
            const std::uint32_t dim12370JoeKuoD6Init[]   =   { 1, 3, 3, 9, 7, 55, 109, 143, 427, 45, 579, 115, 2061, 8447, 29469, 5523, 129063, 0 };
            const std::uint32_t dim12371JoeKuoD6Init[]   =   { 1, 3, 7, 5, 23, 63, 119, 31, 53, 821, 135, 2677, 807, 4685, 24391, 55165, 88079, 0 };
            const std::uint32_t dim12372JoeKuoD6Init[]   =   { 1, 3, 5, 9, 15, 11, 73, 177, 243, 375, 115, 1633, 7983, 15039, 21169, 25325, 128479, 0 };
            const std::uint32_t dim12373JoeKuoD6Init[]   =   { 1, 3, 3, 5, 21, 51, 13, 51, 75, 993, 77, 209, 2761, 451, 11987, 40297, 2383, 0 };
            const std::uint32_t dim12374JoeKuoD6Init[]   =   { 1, 3, 7, 1, 19, 9, 11, 161, 19, 851, 1313, 1169, 4405, 7493, 23935, 37323, 107387, 0 };
            const std::uint32_t dim12375JoeKuoD6Init[]   =   { 1, 3, 5, 15, 5, 11, 79, 129, 507, 247, 811, 1145, 3893, 5205, 11309, 38205, 2051, 0 };
            const std::uint32_t dim12376JoeKuoD6Init[]   =   { 1, 1, 5, 1, 11, 13, 33, 155, 21, 185, 771, 3261, 981, 743, 12479, 22611, 25321, 0 };
            const std::uint32_t dim12377JoeKuoD6Init[]   =   { 1, 1, 5, 9, 7, 25, 11, 235, 429, 563, 1647, 1429, 1385, 14411, 3831, 19769, 67599, 0 };
            const std::uint32_t dim12378JoeKuoD6Init[]   =   { 1, 3, 3, 5, 5, 7, 109, 117, 251, 823, 669, 2043, 1843, 11829, 27051, 35865, 11461, 0 };
            const std::uint32_t dim12379JoeKuoD6Init[]   =   { 1, 3, 5, 5, 7, 3, 45, 63, 305, 99, 393, 1765, 1711, 15569, 27295, 16555, 77631, 0 };
            const std::uint32_t dim12380JoeKuoD6Init[]   =   { 1, 3, 5, 11, 23, 33, 49, 125, 85, 677, 1589, 2667, 5723, 15619, 30415, 39561, 122763, 0 };
            const std::uint32_t dim12381JoeKuoD6Init[]   =   { 1, 3, 7, 13, 27, 21, 99, 209, 481, 123, 1285, 115, 6517, 11753, 11365, 44959, 89, 0 };
            const std::uint32_t dim12382JoeKuoD6Init[]   =   { 1, 1, 1, 7, 15, 15, 45, 151, 489, 169, 933, 2987, 657, 3095, 6745, 131, 37767, 0 };
            const std::uint32_t dim12383JoeKuoD6Init[]   =   { 1, 3, 1, 15, 1, 37, 99, 137, 151, 891, 715, 383, 1293, 719, 10957, 5557, 92841, 0 };
            const std::uint32_t dim12384JoeKuoD6Init[]   =   { 1, 1, 1, 3, 27, 59, 93, 49, 473, 313, 431, 1129, 5995, 13101, 13185, 7091, 109677, 0 };
            const std::uint32_t dim12385JoeKuoD6Init[]   =   { 1, 3, 3, 7, 1, 41, 55, 135, 271, 527, 1919, 1093, 2579, 3725, 22853, 31613, 4729, 0 };
            const std::uint32_t dim12386JoeKuoD6Init[]   =   { 1, 1, 7, 1, 7, 13, 63, 255, 219, 837, 117, 2323, 4295, 15697, 8607, 47047, 117869, 0 };
            const std::uint32_t dim12387JoeKuoD6Init[]   =   { 1, 1, 1, 7, 29, 29, 55, 171, 437, 733, 491, 1037, 7221, 5705, 31819, 19583, 103991, 0 };
            const std::uint32_t dim12388JoeKuoD6Init[]   =   { 1, 3, 7, 1, 31, 19, 65, 39, 151, 517, 1985, 2251, 6147, 12983, 28263, 35891, 7545, 0 };
            const std::uint32_t dim12389JoeKuoD6Init[]   =   { 1, 1, 7, 7, 21, 41, 97, 253, 427, 391, 849, 611, 4827, 10807, 6267, 22513, 62803, 0 };
            const std::uint32_t dim12390JoeKuoD6Init[]   =   { 1, 3, 7, 7, 25, 9, 49, 245, 491, 39, 603, 1853, 5655, 3517, 10745, 55069, 121497, 0 };
            const std::uint32_t dim12391JoeKuoD6Init[]   =   { 1, 3, 1, 5, 9, 39, 109, 195, 283, 141, 2007, 3, 1267, 13053, 8387, 48665, 48877, 0 };
            const std::uint32_t dim12392JoeKuoD6Init[]   =   { 1, 1, 3, 7, 27, 61, 49, 43, 229, 497, 2015, 1345, 3195, 7139, 13453, 56993, 15099, 0 };
            const std::uint32_t dim12393JoeKuoD6Init[]   =   { 1, 3, 5, 11, 31, 53, 87, 97, 385, 387, 1107, 3287, 2517, 7421, 1007, 37421, 124113, 0 };
            const std::uint32_t dim12394JoeKuoD6Init[]   =   { 1, 3, 3, 11, 9, 55, 51, 215, 181, 419, 863, 3149, 5815, 15579, 28527, 34715, 61375, 0 };
            const std::uint32_t dim12395JoeKuoD6Init[]   =   { 1, 3, 3, 3, 31, 57, 5, 35, 445, 957, 1897, 105, 2533, 10255, 19795, 49127, 38491, 0 };
            const std::uint32_t dim12396JoeKuoD6Init[]   =   { 1, 3, 3, 13, 25, 53, 1, 159, 443, 541, 439, 3377, 5511, 9667, 26777, 32599, 36981, 0 };
            const std::uint32_t dim12397JoeKuoD6Init[]   =   { 1, 1, 1, 3, 23, 29, 97, 131, 59, 143, 1601, 2765, 4569, 11081, 6027, 38641, 100745, 0 };
            const std::uint32_t dim12398JoeKuoD6Init[]   =   { 1, 3, 3, 15, 9, 15, 19, 35, 321, 935, 465, 2707, 4799, 7455, 12743, 31029, 114149, 0 };
            const std::uint32_t dim12399JoeKuoD6Init[]   =   { 1, 1, 1, 1, 11, 51, 23, 79, 387, 701, 107, 623, 231, 12571, 7719, 3061, 79605, 0 };
            const std::uint32_t dim12400JoeKuoD6Init[]   =   { 1, 3, 5, 15, 17, 49, 109, 83, 185, 295, 853, 219, 3615, 535, 32001, 6655, 4185, 0 };
            const std::uint32_t dim12401JoeKuoD6Init[]   =   { 1, 3, 3, 15, 15, 7, 35, 151, 305, 705, 1383, 1595, 5595, 11995, 15491, 49119, 83383, 0 };
            const std::uint32_t dim12402JoeKuoD6Init[]   =   { 1, 3, 7, 9, 3, 25, 57, 47, 359, 719, 1937, 1403, 1399, 10827, 24181, 29141, 79017, 0 };
            const std::uint32_t dim12403JoeKuoD6Init[]   =   { 1, 3, 5, 1, 1, 21, 21, 245, 361, 485, 1521, 3935, 1587, 8653, 25871, 49449, 103413, 0 };
            const std::uint32_t dim12404JoeKuoD6Init[]   =   { 1, 3, 3, 3, 9, 61, 31, 69, 401, 261, 1217, 3069, 4045, 12437, 32017, 15113, 10769, 0 };
            const std::uint32_t dim12405JoeKuoD6Init[]   =   { 1, 3, 1, 1, 21, 33, 123, 87, 481, 793, 625, 4087, 1361, 11077, 18835, 13287, 40107, 0 };
            const std::uint32_t dim12406JoeKuoD6Init[]   =   { 1, 3, 7, 3, 9, 49, 101, 213, 467, 77, 1691, 2621, 4411, 8025, 30247, 13691, 20559, 0 };
            const std::uint32_t dim12407JoeKuoD6Init[]   =   { 1, 1, 1, 9, 29, 49, 47, 135, 1, 337, 1649, 389, 3845, 7213, 19527, 2619, 78841, 0 };
            const std::uint32_t dim12408JoeKuoD6Init[]   =   { 1, 3, 7, 9, 23, 23, 47, 97, 493, 767, 137, 1467, 7015, 2883, 12749, 9267, 12441, 0 };
            const std::uint32_t dim12409JoeKuoD6Init[]   =   { 1, 1, 3, 15, 9, 57, 53, 19, 401, 385, 1159, 1185, 6977, 14027, 3183, 59119, 42065, 0 };
            const std::uint32_t dim12410JoeKuoD6Init[]   =   { 1, 1, 1, 15, 21, 33, 83, 251, 147, 395, 321, 443, 6893, 1877, 6687, 28863, 86531, 0 };
            const std::uint32_t dim12411JoeKuoD6Init[]   =   { 1, 3, 3, 1, 3, 47, 27, 247, 121, 827, 1399, 4079, 7545, 11691, 27915, 28811, 17099, 0 };
            const std::uint32_t dim12412JoeKuoD6Init[]   =   { 1, 3, 5, 7, 5, 59, 73, 69, 117, 897, 905, 3273, 2935, 11077, 32443, 60959, 16081, 0 };
            const std::uint32_t dim12413JoeKuoD6Init[]   =   { 1, 1, 7, 5, 27, 49, 107, 169, 75, 435, 1913, 2089, 5733, 2361, 5163, 52239, 87411, 0 };
            const std::uint32_t dim12414JoeKuoD6Init[]   =   { 1, 1, 7, 13, 1, 13, 123, 89, 427, 301, 1217, 1491, 5361, 10381, 28971, 57655, 108607, 0 };
            const std::uint32_t dim12415JoeKuoD6Init[]   =   { 1, 1, 7, 11, 13, 5, 23, 151, 117, 369, 623, 2263, 2609, 109, 32485, 52133, 69391, 0 };
            const std::uint32_t dim12416JoeKuoD6Init[]   =   { 1, 3, 7, 11, 7, 33, 127, 43, 123, 203, 775, 3215, 5115, 1805, 14581, 46791, 128781, 0 };
            const std::uint32_t dim12417JoeKuoD6Init[]   =   { 1, 3, 3, 1, 7, 23, 37, 99, 1, 719, 293, 2727, 6859, 683, 13241, 17839, 4215, 0 };
            const std::uint32_t dim12418JoeKuoD6Init[]   =   { 1, 1, 1, 13, 27, 41, 93, 25, 59, 947, 971, 1523, 4443, 1209, 32317, 58651, 11121, 0 };
            const std::uint32_t dim12419JoeKuoD6Init[]   =   { 1, 1, 1, 3, 31, 33, 23, 87, 349, 265, 445, 3489, 783, 7833, 5767, 59295, 45057, 0 };
            const std::uint32_t dim12420JoeKuoD6Init[]   =   { 1, 1, 1, 1, 15, 47, 19, 15, 217, 837, 2043, 2805, 4701, 5873, 1517, 46743, 61655, 0 };
            const std::uint32_t dim12421JoeKuoD6Init[]   =   { 1, 3, 7, 1, 27, 27, 9, 107, 25, 897, 955, 3763, 821, 1535, 14557, 38537, 128737, 0 };
            const std::uint32_t dim12422JoeKuoD6Init[]   =   { 1, 3, 3, 7, 19, 49, 121, 217, 401, 975, 1189, 715, 3113, 4219, 4885, 57861, 6833, 0 };
            const std::uint32_t dim12423JoeKuoD6Init[]   =   { 1, 3, 3, 1, 17, 59, 53, 15, 259, 791, 2035, 499, 7707, 13685, 14367, 20155, 91033, 0 };
            const std::uint32_t dim12424JoeKuoD6Init[]   =   { 1, 3, 5, 5, 11, 11, 69, 237, 139, 73, 541, 1135, 2647, 14109, 18113, 8051, 31917, 0 };
            const std::uint32_t dim12425JoeKuoD6Init[]   =   { 1, 1, 1, 15, 11, 23, 89, 181, 295, 743, 29, 4009, 4683, 13989, 4575, 38865, 30449, 0 };
            const std::uint32_t dim12426JoeKuoD6Init[]   =   { 1, 1, 1, 11, 21, 63, 31, 121, 55, 153, 1143, 4059, 3247, 11725, 17659, 48935, 118369, 0 };
            const std::uint32_t dim12427JoeKuoD6Init[]   =   { 1, 1, 7, 9, 17, 29, 27, 167, 69, 957, 2009, 2795, 3161, 3493, 16365, 43637, 102321, 0 };
            const std::uint32_t dim12428JoeKuoD6Init[]   =   { 1, 3, 5, 13, 27, 23, 17, 7, 345, 253, 631, 1389, 2523, 9993, 32619, 46731, 4757, 0 };
            const std::uint32_t dim12429JoeKuoD6Init[]   =   { 1, 1, 1, 11, 17, 1, 41, 107, 25, 183, 1361, 1211, 3607, 12713, 16011, 42987, 36415, 0 };
            const std::uint32_t dim12430JoeKuoD6Init[]   =   { 1, 1, 7, 5, 13, 29, 33, 69, 261, 213, 73, 3737, 3867, 503, 28225, 53735, 91695, 0 };
            const std::uint32_t dim12431JoeKuoD6Init[]   =   { 1, 3, 7, 7, 21, 63, 75, 39, 259, 367, 487, 2087, 5411, 1925, 29589, 39019, 73283, 0 };
            const std::uint32_t dim12432JoeKuoD6Init[]   =   { 1, 3, 1, 7, 29, 29, 25, 191, 91, 509, 1485, 853, 7011, 13321, 27769, 10249, 87341, 0 };
            const std::uint32_t dim12433JoeKuoD6Init[]   =   { 1, 1, 7, 7, 1, 9, 115, 71, 321, 913, 1679, 2129, 771, 9217, 4731, 24353, 35631, 0 };
            const std::uint32_t dim12434JoeKuoD6Init[]   =   { 1, 3, 1, 13, 5, 45, 53, 255, 429, 805, 1983, 1437, 2677, 6337, 22221, 55455, 39855, 0 };
            const std::uint32_t dim12435JoeKuoD6Init[]   =   { 1, 1, 1, 1, 1, 5, 111, 231, 321, 961, 371, 3825, 3623, 3985, 32151, 6113, 130687, 0 };
            const std::uint32_t dim12436JoeKuoD6Init[]   =   { 1, 3, 7, 3, 15, 29, 103, 181, 261, 149, 1161, 1745, 1765, 1677, 20051, 47033, 84997, 0 };
            const std::uint32_t dim12437JoeKuoD6Init[]   =   { 1, 3, 7, 1, 25, 21, 7, 229, 407, 673, 1525, 1207, 3099, 14849, 22103, 45695, 85951, 0 };
            const std::uint32_t dim12438JoeKuoD6Init[]   =   { 1, 3, 7, 1, 9, 5, 105, 149, 181, 81, 1589, 3477, 5387, 7943, 29203, 50355, 39001, 0 };
            const std::uint32_t dim12439JoeKuoD6Init[]   =   { 1, 3, 7, 1, 21, 31, 39, 121, 397, 1023, 711, 623, 6193, 12315, 11101, 11911, 50033, 0 };
            const std::uint32_t dim12440JoeKuoD6Init[]   =   { 1, 3, 7, 3, 7, 19, 73, 69, 201, 337, 1037, 3663, 2679, 5153, 28171, 24455, 74685, 0 };
            const std::uint32_t dim12441JoeKuoD6Init[]   =   { 1, 3, 1, 1, 21, 35, 121, 111, 217, 809, 507, 1347, 4439, 4601, 26371, 23595, 3583, 0 };
            const std::uint32_t dim12442JoeKuoD6Init[]   =   { 1, 3, 3, 7, 1, 51, 83, 231, 419, 597, 305, 3405, 5831, 11845, 1861, 48671, 105315, 0 };
            const std::uint32_t dim12443JoeKuoD6Init[]   =   { 1, 3, 1, 15, 25, 37, 103, 141, 495, 727, 1919, 2821, 4689, 6727, 27117, 2259, 54559, 0 };
            const std::uint32_t dim12444JoeKuoD6Init[]   =   { 1, 3, 5, 3, 27, 55, 5, 117, 199, 979, 1745, 401, 7967, 5345, 29747, 54085, 124765, 0 };
            const std::uint32_t dim12445JoeKuoD6Init[]   =   { 1, 3, 3, 15, 23, 61, 1, 29, 489, 131, 583, 389, 6033, 8007, 22933, 44513, 111845, 0 };
            const std::uint32_t dim12446JoeKuoD6Init[]   =   { 1, 1, 7, 13, 3, 55, 119, 147, 181, 485, 793, 3593, 6971, 2227, 28507, 62393, 127303, 0 };
            const std::uint32_t dim12447JoeKuoD6Init[]   =   { 1, 1, 5, 3, 29, 53, 37, 59, 213, 283, 1809, 3685, 2677, 5761, 19705, 47079, 3477, 0 };
            const std::uint32_t dim12448JoeKuoD6Init[]   =   { 1, 1, 1, 7, 21, 63, 91, 13, 347, 605, 589, 415, 5737, 10281, 30941, 25609, 67973, 0 };
            const std::uint32_t dim12449JoeKuoD6Init[]   =   { 1, 1, 3, 1, 27, 49, 87, 161, 507, 693, 59, 1375, 6737, 1029, 14731, 32335, 51961, 0 };
            const std::uint32_t dim12450JoeKuoD6Init[]   =   { 1, 3, 3, 9, 11, 15, 121, 121, 151, 335, 221, 3099, 1999, 1047, 20891, 23015, 95809, 0 };
            const std::uint32_t dim12451JoeKuoD6Init[]   =   { 1, 1, 7, 7, 1, 49, 63, 227, 113, 161, 863, 801, 2559, 7737, 27619, 27419, 128009, 0 };
            const std::uint32_t dim12452JoeKuoD6Init[]   =   { 1, 1, 7, 1, 25, 59, 67, 111, 435, 309, 807, 2107, 8077, 9671, 6739, 53757, 41259, 0 };
            const std::uint32_t dim12453JoeKuoD6Init[]   =   { 1, 3, 7, 3, 3, 19, 7, 111, 237, 981, 1717, 3131, 6631, 467, 13103, 61435, 126469, 0 };
            const std::uint32_t dim12454JoeKuoD6Init[]   =   { 1, 1, 7, 9, 19, 31, 59, 185, 199, 111, 351, 611, 6355, 1095, 28549, 32871, 44537, 0 };
            const std::uint32_t dim12455JoeKuoD6Init[]   =   { 1, 1, 3, 11, 23, 25, 31, 1, 461, 83, 1723, 1711, 3679, 10963, 14927, 17377, 911, 0 };
            const std::uint32_t dim12456JoeKuoD6Init[]   =   { 1, 1, 5, 13, 3, 37, 127, 159, 199, 223, 1097, 3033, 5825, 13777, 22189, 44305, 20509, 0 };
            const std::uint32_t dim12457JoeKuoD6Init[]   =   { 1, 1, 5, 15, 13, 49, 17, 79, 289, 601, 1023, 657, 1687, 14477, 15929, 4279, 68007, 0 };
            const std::uint32_t dim12458JoeKuoD6Init[]   =   { 1, 1, 5, 7, 29, 3, 45, 225, 65, 711, 1039, 3585, 4957, 9041, 22761, 26649, 95627, 0 };
            const std::uint32_t dim12459JoeKuoD6Init[]   =   { 1, 3, 5, 5, 13, 29, 33, 211, 461, 799, 1437, 1057, 485, 9535, 8133, 57527, 12873, 0 };
            const std::uint32_t dim12460JoeKuoD6Init[]   =   { 1, 1, 3, 3, 15, 43, 53, 15, 395, 561, 1371, 3543, 7707, 2399, 13311, 25641, 58865, 0 };
            const std::uint32_t dim12461JoeKuoD6Init[]   =   { 1, 3, 1, 7, 1, 9, 115, 39, 249, 87, 835, 97, 8137, 6665, 11951, 21045, 76387, 0 };
            const std::uint32_t dim12462JoeKuoD6Init[]   =   { 1, 3, 3, 9, 5, 63, 115, 163, 331, 1007, 733, 4027, 2911, 5329, 6967, 3535, 107293, 0 };
            const std::uint32_t dim12463JoeKuoD6Init[]   =   { 1, 3, 1, 11, 5, 55, 81, 63, 345, 535, 1093, 207, 4053, 9129, 10397, 26641, 95171, 0 };
            const std::uint32_t dim12464JoeKuoD6Init[]   =   { 1, 1, 3, 3, 13, 27, 65, 37, 255, 69, 19, 2565, 4329, 11223, 18131, 18701, 31111, 0 };
            const std::uint32_t dim12465JoeKuoD6Init[]   =   { 1, 3, 7, 7, 25, 57, 81, 189, 227, 377, 829, 1583, 1343, 4643, 23485, 47463, 83535, 0 };
            const std::uint32_t dim12466JoeKuoD6Init[]   =   { 1, 3, 5, 9, 13, 33, 103, 75, 501, 803, 427, 1171, 1187, 2655, 24187, 32907, 120239, 0 };
            const std::uint32_t dim12467JoeKuoD6Init[]   =   { 1, 3, 1, 7, 31, 63, 21, 137, 241, 63, 1925, 2193, 1135, 11159, 14685, 28397, 59, 0 };
            const std::uint32_t dim12468JoeKuoD6Init[]   =   { 1, 1, 7, 1, 15, 7, 85, 87, 493, 63, 561, 1069, 5481, 12253, 25149, 35283, 16123, 0 };
            const std::uint32_t dim12469JoeKuoD6Init[]   =   { 1, 3, 3, 5, 19, 17, 23, 95, 429, 805, 1343, 2243, 233, 7219, 6549, 21477, 83679, 0 };
            const std::uint32_t dim12470JoeKuoD6Init[]   =   { 1, 3, 3, 1, 3, 55, 83, 107, 131, 311, 741, 781, 6227, 10059, 3903, 235, 45971, 0 };
            const std::uint32_t dim12471JoeKuoD6Init[]   =   { 1, 1, 3, 13, 21, 43, 79, 149, 367, 755, 463, 221, 5117, 7015, 17599, 64665, 37443, 0 };
            const std::uint32_t dim12472JoeKuoD6Init[]   =   { 1, 1, 7, 15, 3, 59, 107, 13, 213, 287, 1505, 2131, 6965, 12873, 23973, 8449, 24829, 0 };
            const std::uint32_t dim12473JoeKuoD6Init[]   =   { 1, 3, 5, 11, 25, 45, 39, 17, 175, 749, 1179, 3349, 6723, 12543, 3557, 34521, 103197, 0 };
            const std::uint32_t dim12474JoeKuoD6Init[]   =   { 1, 1, 3, 13, 23, 41, 21, 25, 91, 941, 879, 4015, 137, 12949, 17245, 41903, 39803, 0 };
            const std::uint32_t dim12475JoeKuoD6Init[]   =   { 1, 1, 7, 15, 11, 33, 45, 127, 321, 895, 1543, 4013, 6179, 14209, 13317, 46803, 99891, 0 };
            const std::uint32_t dim12476JoeKuoD6Init[]   =   { 1, 3, 3, 13, 13, 11, 101, 11, 177, 869, 509, 2323, 449, 16379, 31965, 2899, 59229, 0 };
            const std::uint32_t dim12477JoeKuoD6Init[]   =   { 1, 1, 5, 7, 15, 37, 113, 237, 463, 489, 1145, 1629, 3101, 10305, 31705, 29957, 99665, 0 };
            const std::uint32_t dim12478JoeKuoD6Init[]   =   { 1, 3, 5, 7, 21, 29, 45, 133, 367, 657, 1315, 537, 6069, 8141, 31479, 32983, 57, 0 };
            const std::uint32_t dim12479JoeKuoD6Init[]   =   { 1, 1, 3, 9, 13, 39, 109, 125, 467, 975, 829, 4007, 773, 6639, 8793, 4579, 60547, 0 };
            const std::uint32_t dim12480JoeKuoD6Init[]   =   { 1, 1, 1, 15, 21, 5, 113, 51, 159, 501, 1921, 4095, 5603, 16055, 16649, 50229, 49863, 0 };
            const std::uint32_t dim12481JoeKuoD6Init[]   =   { 1, 1, 5, 13, 9, 21, 77, 187, 355, 299, 1017, 491, 6725, 4177, 16739, 15909, 84069, 0 };
            const std::uint32_t dim12482JoeKuoD6Init[]   =   { 1, 3, 7, 5, 13, 13, 51, 19, 159, 339, 735, 933, 2523, 11435, 20793, 21975, 19007, 0 };
            const std::uint32_t dim12483JoeKuoD6Init[]   =   { 1, 1, 7, 5, 1, 11, 61, 111, 129, 643, 1741, 945, 7349, 11579, 24793, 1751, 2367, 0 };
            const std::uint32_t dim12484JoeKuoD6Init[]   =   { 1, 1, 5, 5, 29, 45, 63, 177, 507, 277, 1789, 729, 4277, 10099, 28985, 43009, 2319, 0 };
            const std::uint32_t dim12485JoeKuoD6Init[]   =   { 1, 3, 3, 13, 19, 53, 73, 227, 487, 131, 1227, 3735, 3979, 7383, 6923, 31979, 6651, 0 };
            const std::uint32_t dim12486JoeKuoD6Init[]   =   { 1, 3, 3, 15, 7, 47, 31, 255, 317, 621, 497, 4069, 5249, 15093, 18013, 6891, 81893, 0 };
            const std::uint32_t dim12487JoeKuoD6Init[]   =   { 1, 1, 7, 5, 17, 23, 119, 27, 55, 555, 221, 2693, 1757, 11117, 23409, 21135, 122977, 0 };
            const std::uint32_t dim12488JoeKuoD6Init[]   =   { 1, 1, 5, 1, 15, 17, 127, 109, 75, 1017, 1167, 2975, 3249, 5399, 12599, 50779, 78215, 0 };
            const std::uint32_t dim12489JoeKuoD6Init[]   =   { 1, 3, 5, 5, 1, 13, 65, 199, 101, 75, 513, 493, 6931, 9363, 5607, 16331, 69219, 0 };
            const std::uint32_t dim12490JoeKuoD6Init[]   =   { 1, 1, 1, 15, 19, 37, 63, 177, 397, 645, 905, 1599, 609, 14291, 14681, 46719, 117745, 0 };
            const std::uint32_t dim12491JoeKuoD6Init[]   =   { 1, 3, 7, 13, 3, 57, 63, 49, 67, 913, 1659, 1857, 3595, 9219, 11341, 39735, 82275, 0 };
            const std::uint32_t dim12492JoeKuoD6Init[]   =   { 1, 1, 5, 11, 19, 1, 5, 181, 55, 763, 469, 2417, 2349, 12437, 22589, 17867, 95701, 0 };
            const std::uint32_t dim12493JoeKuoD6Init[]   =   { 1, 3, 7, 13, 1, 9, 11, 159, 103, 737, 1989, 59, 4711, 8093, 31703, 45663, 92913, 0 };
            const std::uint32_t dim12494JoeKuoD6Init[]   =   { 1, 3, 3, 11, 15, 9, 35, 217, 299, 479, 1539, 2605, 2003, 8841, 27261, 28853, 98877, 0 };
            const std::uint32_t dim12495JoeKuoD6Init[]   =   { 1, 1, 5, 5, 15, 45, 73, 159, 205, 1017, 159, 3659, 2377, 3651, 6489, 19711, 109959, 0 };
            const std::uint32_t dim12496JoeKuoD6Init[]   =   { 1, 1, 3, 15, 7, 41, 7, 47, 357, 433, 211, 111, 2565, 8637, 15917, 47887, 128513, 0 };
            const std::uint32_t dim12497JoeKuoD6Init[]   =   { 1, 3, 7, 3, 25, 9, 33, 33, 5, 805, 1541, 3333, 7257, 9011, 4813, 53195, 52469, 0 };
            const std::uint32_t dim12498JoeKuoD6Init[]   =   { 1, 1, 7, 15, 27, 3, 11, 57, 415, 371, 563, 2515, 149, 6555, 31273, 51465, 2989, 0 };
            const std::uint32_t dim12499JoeKuoD6Init[]   =   { 1, 1, 1, 11, 3, 41, 25, 175, 499, 879, 1145, 1083, 7857, 10497, 16991, 23351, 115353, 0 };
            const std::uint32_t dim12500JoeKuoD6Init[]   =   { 1, 1, 3, 15, 15, 9, 39, 239, 285, 413, 989, 2927, 7205, 79, 20101, 30115, 113933, 0 };
            const std::uint32_t dim12501JoeKuoD6Init[]   =   { 1, 1, 7, 5, 13, 29, 29, 69, 25, 533, 1731, 1391, 4065, 12597, 19167, 51989, 101273, 0 };
            const std::uint32_t dim12502JoeKuoD6Init[]   =   { 1, 1, 5, 3, 9, 41, 83, 127, 197, 627, 173, 273, 593, 15733, 19285, 26517, 107877, 0 };
            const std::uint32_t dim12503JoeKuoD6Init[]   =   { 1, 1, 1, 5, 29, 17, 89, 163, 125, 473, 1577, 2435, 3379, 3057, 1829, 64325, 111719, 0 };
            const std::uint32_t dim12504JoeKuoD6Init[]   =   { 1, 3, 1, 11, 1, 29, 97, 53, 421, 941, 1737, 3337, 2715, 1633, 28485, 30369, 116047, 0 };
            const std::uint32_t dim12505JoeKuoD6Init[]   =   { 1, 1, 5, 13, 25, 43, 39, 85, 385, 129, 819, 1647, 3527, 12319, 573, 58703, 29463, 0 };
            const std::uint32_t dim12506JoeKuoD6Init[]   =   { 1, 3, 3, 9, 23, 59, 31, 215, 49, 451, 645, 3687, 4507, 9359, 28161, 34609, 123409, 0 };
            const std::uint32_t dim12507JoeKuoD6Init[]   =   { 1, 3, 1, 9, 13, 25, 97, 239, 203, 31, 1465, 1089, 7665, 3007, 22465, 28389, 119869, 0 };
            const std::uint32_t dim12508JoeKuoD6Init[]   =   { 1, 3, 3, 1, 29, 51, 19, 83, 443, 193, 647, 3125, 7269, 3031, 9967, 40447, 102179, 0 };
            const std::uint32_t dim12509JoeKuoD6Init[]   =   { 1, 3, 5, 15, 5, 63, 125, 55, 295, 787, 559, 3309, 7491, 9907, 5775, 15155, 41793, 0 };
            const std::uint32_t dim12510JoeKuoD6Init[]   =   { 1, 3, 7, 7, 21, 61, 125, 207, 43, 159, 539, 435, 1945, 725, 797, 47489, 43099, 0 };
            const std::uint32_t dim12511JoeKuoD6Init[]   =   { 1, 1, 5, 7, 11, 11, 61, 103, 23, 693, 493, 1045, 4435, 9009, 22075, 24839, 125431, 0 };
            const std::uint32_t dim12512JoeKuoD6Init[]   =   { 1, 3, 1, 9, 13, 61, 83, 181, 373, 949, 1397, 247, 5079, 10933, 31887, 14147, 55121, 0 };
            const std::uint32_t dim12513JoeKuoD6Init[]   =   { 1, 1, 7, 15, 31, 47, 87, 219, 357, 409, 943, 2993, 7615, 7071, 14179, 41489, 104401, 0 };
            const std::uint32_t dim12514JoeKuoD6Init[]   =   { 1, 3, 3, 1, 11, 15, 87, 241, 389, 761, 1523, 3049, 2111, 11581, 5493, 11301, 32017, 0 };
            const std::uint32_t dim12515JoeKuoD6Init[]   =   { 1, 1, 7, 11, 29, 39, 37, 63, 411, 671, 1789, 3541, 5651, 11721, 10871, 53867, 112895, 0 };
            const std::uint32_t dim12516JoeKuoD6Init[]   =   { 1, 3, 3, 1, 23, 21, 99, 161, 467, 197, 1263, 451, 5469, 7667, 22139, 31599, 8345, 0 };
            const std::uint32_t dim12517JoeKuoD6Init[]   =   { 1, 3, 1, 3, 11, 41, 13, 79, 3, 377, 1865, 2297, 1383, 14033, 17141, 24787, 127911, 0 };
            const std::uint32_t dim12518JoeKuoD6Init[]   =   { 1, 1, 1, 1, 5, 11, 5, 181, 323, 853, 831, 1599, 3939, 6391, 22817, 37969, 9997, 0 };
            const std::uint32_t dim12519JoeKuoD6Init[]   =   { 1, 1, 3, 11, 29, 61, 11, 171, 181, 631, 757, 3879, 4779, 16183, 5969, 7909, 42855, 0 };
            const std::uint32_t dim12520JoeKuoD6Init[]   =   { 1, 3, 3, 15, 19, 17, 107, 187, 19, 743, 909, 1963, 2131, 2107, 659, 35829, 57905, 0 };
            const std::uint32_t dim12521JoeKuoD6Init[]   =   { 1, 1, 7, 1, 31, 29, 67, 99, 353, 715, 65, 3907, 1931, 1289, 9217, 60635, 32737, 0 };
            const std::uint32_t dim12522JoeKuoD6Init[]   =   { 1, 3, 3, 13, 3, 17, 19, 173, 263, 203, 1233, 1407, 933, 8905, 26905, 63343, 64963, 0 };
            const std::uint32_t dim12523JoeKuoD6Init[]   =   { 1, 3, 1, 13, 21, 43, 97, 79, 163, 529, 1571, 1027, 4339, 16235, 9189, 29203, 36789, 0 };
            const std::uint32_t dim12524JoeKuoD6Init[]   =   { 1, 1, 7, 1, 31, 1, 117, 247, 193, 333, 1797, 3515, 285, 2803, 25345, 9101, 110569, 0 };
            const std::uint32_t dim12525JoeKuoD6Init[]   =   { 1, 1, 5, 11, 17, 63, 45, 167, 35, 925, 569, 3687, 6739, 12453, 26171, 28249, 73827, 0 };
            const std::uint32_t dim12526JoeKuoD6Init[]   =   { 1, 1, 5, 1, 19, 49, 107, 183, 435, 305, 1191, 2711, 891, 15813, 13449, 23489, 89749, 0 };
            const std::uint32_t dim12527JoeKuoD6Init[]   =   { 1, 1, 1, 11, 7, 53, 105, 17, 433, 351, 1151, 4077, 5371, 10183, 18895, 13229, 101219, 0 };
            const std::uint32_t dim12528JoeKuoD6Init[]   =   { 1, 3, 7, 9, 21, 33, 27, 125, 177, 607, 817, 2689, 2123, 2037, 29643, 27219, 44591, 0 };
            const std::uint32_t dim12529JoeKuoD6Init[]   =   { 1, 3, 5, 11, 27, 51, 29, 161, 469, 349, 1445, 3613, 1487, 961, 29017, 2235, 45905, 0 };
            const std::uint32_t dim12530JoeKuoD6Init[]   =   { 1, 1, 3, 11, 7, 15, 37, 195, 329, 875, 559, 1361, 7373, 7143, 15059, 59205, 37167, 0 };
            const std::uint32_t dim12531JoeKuoD6Init[]   =   { 1, 1, 5, 1, 7, 25, 27, 211, 301, 369, 227, 123, 4415, 15993, 4829, 43801, 83639, 0 };
            const std::uint32_t dim12532JoeKuoD6Init[]   =   { 1, 1, 3, 5, 25, 37, 31, 205, 69, 275, 855, 1407, 2989, 11001, 16963, 31497, 3505, 0 };
            const std::uint32_t dim12533JoeKuoD6Init[]   =   { 1, 1, 7, 7, 25, 33, 81, 181, 197, 717, 207, 535, 8083, 5765, 2523, 40347, 27245, 0 };
            const std::uint32_t dim12534JoeKuoD6Init[]   =   { 1, 3, 1, 5, 13, 3, 107, 143, 233, 419, 1831, 2149, 7277, 13449, 31609, 48345, 82621, 0 };
            const std::uint32_t dim12535JoeKuoD6Init[]   =   { 1, 3, 5, 9, 31, 35, 39, 113, 415, 803, 1479, 3169, 8015, 4659, 2445, 9159, 91625, 0 };
            const std::uint32_t dim12536JoeKuoD6Init[]   =   { 1, 3, 1, 5, 27, 25, 83, 165, 459, 955, 1535, 377, 5531, 2945, 18285, 18097, 21589, 0 };
            const std::uint32_t dim12537JoeKuoD6Init[]   =   { 1, 1, 1, 15, 13, 23, 11, 159, 471, 951, 1971, 677, 2641, 3227, 14761, 39421, 29841, 0 };
            const std::uint32_t dim12538JoeKuoD6Init[]   =   { 1, 1, 7, 11, 19, 37, 101, 97, 373, 559, 105, 905, 897, 15309, 14979, 52029, 38989, 0 };
            const std::uint32_t dim12539JoeKuoD6Init[]   =   { 1, 1, 5, 15, 31, 43, 71, 75, 481, 997, 5, 1005, 4987, 7907, 16237, 43075, 94827, 0 };
            const std::uint32_t dim12540JoeKuoD6Init[]   =   { 1, 3, 5, 11, 23, 55, 123, 91, 183, 307, 97, 1999, 3341, 4717, 19643, 9455, 26555, 0 };
            const std::uint32_t dim12541JoeKuoD6Init[]   =   { 1, 1, 7, 3, 29, 61, 75, 197, 125, 579, 145, 1333, 85, 15655, 28177, 6169, 43289, 0 };
            const std::uint32_t dim12542JoeKuoD6Init[]   =   { 1, 3, 7, 13, 21, 15, 1, 221, 293, 991, 35, 2701, 2909, 7333, 27319, 32281, 77861, 0 };
            const std::uint32_t dim12543JoeKuoD6Init[]   =   { 1, 1, 3, 1, 17, 11, 81, 209, 499, 125, 105, 2987, 3891, 9531, 27963, 39611, 43633, 0 };
            const std::uint32_t dim12544JoeKuoD6Init[]   =   { 1, 3, 3, 3, 29, 45, 51, 63, 209, 75, 1321, 4055, 7851, 12329, 8371, 59513, 49105, 0 };
            const std::uint32_t dim12545JoeKuoD6Init[]   =   { 1, 1, 7, 5, 9, 63, 59, 127, 445, 899, 1857, 3737, 625, 15021, 25177, 21007, 25935, 0 };
            const std::uint32_t dim12546JoeKuoD6Init[]   =   { 1, 1, 5, 9, 9, 57, 25, 63, 235, 191, 1527, 1783, 1401, 1813, 2553, 1241, 100029, 0 };
            const std::uint32_t dim12547JoeKuoD6Init[]   =   { 1, 3, 1, 11, 27, 5, 49, 39, 505, 653, 1083, 921, 1045, 11337, 25499, 36211, 75851, 0 };
            const std::uint32_t dim12548JoeKuoD6Init[]   =   { 1, 3, 3, 1, 29, 19, 71, 93, 223, 153, 561, 1657, 5821, 14181, 1275, 24633, 114787, 0 };
            const std::uint32_t dim12549JoeKuoD6Init[]   =   { 1, 1, 1, 9, 7, 13, 17, 239, 457, 731, 1811, 3015, 4465, 5865, 2387, 30455, 17405, 0 };
            const std::uint32_t dim12550JoeKuoD6Init[]   =   { 1, 3, 5, 1, 7, 45, 117, 207, 7, 645, 131, 863, 6443, 14455, 11885, 39257, 126431, 0 };
            const std::uint32_t dim12551JoeKuoD6Init[]   =   { 1, 1, 3, 5, 17, 23, 3, 27, 475, 731, 431, 1967, 981, 12727, 1301, 17647, 62481, 0 };
            const std::uint32_t dim12552JoeKuoD6Init[]   =   { 1, 1, 1, 13, 11, 53, 105, 109, 105, 461, 1787, 2851, 1299, 9925, 13055, 58301, 24483, 0 };
            const std::uint32_t dim12553JoeKuoD6Init[]   =   { 1, 1, 1, 11, 7, 35, 11, 173, 247, 289, 1269, 361, 2059, 5051, 25731, 58085, 21387, 0 };
            const std::uint32_t dim12554JoeKuoD6Init[]   =   { 1, 3, 1, 5, 9, 31, 59, 151, 435, 519, 1863, 2255, 2585, 10033, 29189, 27189, 25023, 0 };
            const std::uint32_t dim12555JoeKuoD6Init[]   =   { 1, 1, 5, 5, 25, 17, 53, 189, 187, 847, 369, 3287, 6047, 2385, 26045, 48821, 23335, 0 };
            const std::uint32_t dim12556JoeKuoD6Init[]   =   { 1, 1, 1, 9, 15, 55, 79, 21, 433, 131, 1677, 3681, 6173, 9189, 15053, 12971, 81135, 0 };
            const std::uint32_t dim12557JoeKuoD6Init[]   =   { 1, 1, 3, 5, 29, 5, 11, 213, 151, 77, 1493, 3959, 7675, 7689, 10381, 15871, 123463, 0 };
            const std::uint32_t dim12558JoeKuoD6Init[]   =   { 1, 3, 7, 11, 19, 47, 31, 81, 207, 789, 1945, 2671, 1987, 6363, 26401, 9799, 59531, 0 };
            const std::uint32_t dim12559JoeKuoD6Init[]   =   { 1, 1, 1, 7, 17, 7, 83, 181, 339, 423, 267, 2251, 1847, 14883, 13423, 27223, 81799, 0 };
            const std::uint32_t dim12560JoeKuoD6Init[]   =   { 1, 3, 5, 15, 9, 9, 73, 95, 197, 267, 743, 2369, 6417, 3555, 9885, 6373, 87651, 0 };
            const std::uint32_t dim12561JoeKuoD6Init[]   =   { 1, 1, 3, 13, 21, 29, 57, 59, 395, 631, 993, 17, 2939, 14117, 27521, 61387, 74927, 0 };
            const std::uint32_t dim12562JoeKuoD6Init[]   =   { 1, 1, 3, 13, 1, 29, 23, 151, 381, 591, 1217, 2295, 4403, 15865, 4325, 31329, 56989, 0 };
            const std::uint32_t dim12563JoeKuoD6Init[]   =   { 1, 3, 5, 1, 27, 7, 111, 79, 287, 945, 1237, 2857, 1461, 2477, 10929, 17117, 98677, 0 };
            const std::uint32_t dim12564JoeKuoD6Init[]   =   { 1, 1, 1, 5, 15, 35, 109, 39, 391, 57, 1783, 3133, 5563, 7721, 12651, 3437, 46697, 0 };
            const std::uint32_t dim12565JoeKuoD6Init[]   =   { 1, 3, 5, 5, 13, 47, 123, 51, 383, 91, 641, 1607, 4461, 7, 6427, 42755, 130097, 0 };
            const std::uint32_t dim12566JoeKuoD6Init[]   =   { 1, 1, 5, 5, 25, 49, 33, 59, 351, 1003, 301, 2721, 7705, 5447, 21367, 63007, 112465, 0 };
            const std::uint32_t dim12567JoeKuoD6Init[]   =   { 1, 1, 5, 13, 31, 11, 73, 1, 359, 201, 1465, 187, 7385, 12817, 12911, 17775, 77937, 0 };
            const std::uint32_t dim12568JoeKuoD6Init[]   =   { 1, 3, 1, 15, 29, 5, 117, 69, 79, 93, 947, 133, 1049, 13907, 3611, 42123, 8041, 0 };
            const std::uint32_t dim12569JoeKuoD6Init[]   =   { 1, 1, 7, 7, 29, 17, 71, 171, 357, 619, 1199, 3817, 6889, 9607, 19075, 15539, 54939, 0 };
            const std::uint32_t dim12570JoeKuoD6Init[]   =   { 1, 1, 1, 7, 23, 29, 91, 227, 119, 865, 943, 381, 5289, 189, 15917, 13875, 31095, 0 };
            const std::uint32_t dim12571JoeKuoD6Init[]   =   { 1, 1, 7, 1, 9, 49, 93, 175, 105, 61, 1285, 3659, 2383, 505, 12337, 43801, 67035, 0 };
            const std::uint32_t dim12572JoeKuoD6Init[]   =   { 1, 3, 5, 1, 31, 47, 75, 17, 455, 231, 1887, 2295, 2533, 733, 29001, 22001, 119423, 0 };
            const std::uint32_t dim12573JoeKuoD6Init[]   =   { 1, 3, 7, 3, 5, 5, 69, 205, 459, 805, 1257, 3283, 3305, 6845, 1405, 56051, 63453, 0 };
            const std::uint32_t dim12574JoeKuoD6Init[]   =   { 1, 3, 3, 3, 19, 57, 65, 149, 175, 683, 1719, 637, 4951, 13645, 30455, 22379, 105369, 0 };
            const std::uint32_t dim12575JoeKuoD6Init[]   =   { 1, 3, 1, 11, 31, 27, 69, 13, 191, 645, 1563, 3897, 2387, 2269, 12999, 42217, 100853, 0 };
            const std::uint32_t dim12576JoeKuoD6Init[]   =   { 1, 3, 1, 13, 31, 7, 11, 227, 267, 373, 1249, 2591, 4769, 303, 5865, 59911, 4991, 0 };
            const std::uint32_t dim12577JoeKuoD6Init[]   =   { 1, 3, 7, 11, 7, 31, 87, 205, 45, 785, 1947, 1965, 5851, 7501, 89, 38897, 91939, 0 };
            const std::uint32_t dim12578JoeKuoD6Init[]   =   { 1, 3, 5, 9, 21, 37, 79, 181, 163, 355, 1129, 3439, 5103, 15903, 2935, 22505, 97451, 0 };
            const std::uint32_t dim12579JoeKuoD6Init[]   =   { 1, 1, 3, 9, 7, 37, 107, 255, 69, 133, 551, 1357, 31, 7059, 29195, 30151, 81785, 0 };
            const std::uint32_t dim12580JoeKuoD6Init[]   =   { 1, 3, 3, 5, 3, 51, 3, 143, 305, 697, 1041, 1267, 7635, 1483, 649, 28275, 65059, 0 };
            const std::uint32_t dim12581JoeKuoD6Init[]   =   { 1, 3, 1, 7, 11, 13, 113, 81, 159, 993, 797, 3207, 3787, 13005, 29393, 51107, 42709, 0 };
            const std::uint32_t dim12582JoeKuoD6Init[]   =   { 1, 1, 3, 13, 7, 11, 113, 195, 349, 377, 2033, 197, 147, 13839, 5405, 29577, 64535, 0 };
            const std::uint32_t dim12583JoeKuoD6Init[]   =   { 1, 3, 1, 9, 1, 1, 77, 73, 383, 463, 1871, 1589, 1805, 2085, 5195, 17805, 33159, 0 };
            const std::uint32_t dim12584JoeKuoD6Init[]   =   { 1, 1, 1, 9, 25, 37, 123, 119, 507, 515, 1547, 139, 7501, 4725, 30195, 18199, 41145, 0 };
            const std::uint32_t dim12585JoeKuoD6Init[]   =   { 1, 3, 3, 7, 17, 33, 99, 11, 487, 343, 403, 337, 3831, 6031, 20375, 2071, 39795, 0 };
            const std::uint32_t dim12586JoeKuoD6Init[]   =   { 1, 1, 5, 1, 13, 57, 59, 11, 391, 953, 597, 1411, 3929, 13963, 15003, 59385, 12293, 0 };
            const std::uint32_t dim12587JoeKuoD6Init[]   =   { 1, 3, 1, 15, 23, 61, 67, 129, 63, 555, 433, 631, 2725, 317, 10121, 9217, 124371, 0 };
            const std::uint32_t dim12588JoeKuoD6Init[]   =   { 1, 1, 5, 7, 19, 23, 17, 45, 75, 819, 1879, 2315, 1439, 2643, 26561, 19209, 16081, 0 };
            const std::uint32_t dim12589JoeKuoD6Init[]   =   { 1, 3, 5, 7, 5, 35, 121, 233, 91, 89, 1741, 3015, 4223, 9605, 22795, 55845, 47167, 0 };
            const std::uint32_t dim12590JoeKuoD6Init[]   =   { 1, 3, 7, 7, 13, 23, 11, 51, 91, 367, 773, 1303, 2151, 14423, 22263, 28413, 107461, 0 };
            const std::uint32_t dim12591JoeKuoD6Init[]   =   { 1, 1, 1, 11, 29, 17, 49, 53, 379, 819, 1551, 2907, 5805, 2167, 16123, 9263, 43903, 0 };
            const std::uint32_t dim12592JoeKuoD6Init[]   =   { 1, 3, 1, 13, 19, 27, 33, 127, 131, 697, 489, 3289, 1895, 3243, 19497, 32419, 55741, 0 };
            const std::uint32_t dim12593JoeKuoD6Init[]   =   { 1, 3, 1, 15, 7, 51, 91, 45, 251, 829, 2015, 2659, 151, 3327, 25281, 49291, 106343, 0 };
            const std::uint32_t dim12594JoeKuoD6Init[]   =   { 1, 1, 5, 5, 27, 11, 85, 45, 203, 413, 293, 3067, 4109, 959, 22337, 38767, 75829, 0 };
            const std::uint32_t dim12595JoeKuoD6Init[]   =   { 1, 1, 3, 5, 21, 35, 65, 173, 315, 423, 171, 3837, 817, 10153, 5517, 18115, 117437, 0 };
            const std::uint32_t dim12596JoeKuoD6Init[]   =   { 1, 1, 1, 7, 9, 29, 101, 55, 253, 37, 1717, 7, 3181, 1067, 20637, 54773, 106777, 0 };
            const std::uint32_t dim12597JoeKuoD6Init[]   =   { 1, 3, 7, 11, 13, 11, 87, 83, 83, 969, 589, 3625, 3373, 3921, 24487, 34235, 96289, 0 };
            const std::uint32_t dim12598JoeKuoD6Init[]   =   { 1, 3, 1, 11, 25, 35, 65, 131, 491, 167, 449, 2949, 5807, 5649, 7569, 37363, 106819, 0 };
            const std::uint32_t dim12599JoeKuoD6Init[]   =   { 1, 1, 5, 1, 9, 37, 33, 237, 79, 163, 1791, 3499, 4951, 2009, 16183, 10121, 40221, 0 };
            const std::uint32_t dim12600JoeKuoD6Init[]   =   { 1, 1, 5, 15, 21, 49, 123, 53, 27, 273, 1655, 3713, 5699, 1659, 31985, 6779, 10195, 0 };
            const std::uint32_t dim12601JoeKuoD6Init[]   =   { 1, 3, 5, 11, 27, 37, 93, 17, 263, 41, 1583, 703, 7689, 6667, 15497, 15255, 67153, 0 };
            const std::uint32_t dim12602JoeKuoD6Init[]   =   { 1, 1, 5, 9, 19, 13, 121, 39, 321, 177, 711, 3223, 3859, 14775, 19061, 40587, 97199, 0 };
            const std::uint32_t dim12603JoeKuoD6Init[]   =   { 1, 3, 7, 9, 23, 11, 93, 243, 3, 811, 679, 1103, 7579, 14147, 20255, 22485, 117179, 0 };
            const std::uint32_t dim12604JoeKuoD6Init[]   =   { 1, 3, 3, 5, 23, 9, 21, 243, 27, 501, 1273, 1501, 5331, 15663, 19483, 10637, 90905, 0 };
            const std::uint32_t dim12605JoeKuoD6Init[]   =   { 1, 3, 1, 15, 13, 11, 89, 37, 63, 463, 731, 3615, 3923, 4677, 21329, 1069, 57565, 0 };
            const std::uint32_t dim12606JoeKuoD6Init[]   =   { 1, 1, 1, 13, 19, 39, 63, 59, 389, 367, 1285, 2005, 8103, 4179, 3805, 55475, 126589, 0 };
            const std::uint32_t dim12607JoeKuoD6Init[]   =   { 1, 3, 5, 11, 27, 57, 27, 63, 365, 171, 665, 2035, 2831, 15955, 11551, 26741, 121059, 0 };
            const std::uint32_t dim12608JoeKuoD6Init[]   =   { 1, 3, 3, 3, 23, 19, 13, 7, 331, 613, 1783, 733, 7465, 1089, 4683, 15695, 31125, 0 };
            const std::uint32_t dim12609JoeKuoD6Init[]   =   { 1, 1, 5, 3, 3, 23, 95, 157, 303, 987, 307, 2679, 6173, 6633, 17727, 30901, 76109, 0 };
            const std::uint32_t dim12610JoeKuoD6Init[]   =   { 1, 1, 1, 1, 11, 21, 111, 81, 31, 727, 1133, 4083, 5811, 2707, 31749, 42939, 92225, 0 };
            const std::uint32_t dim12611JoeKuoD6Init[]   =   { 1, 3, 1, 11, 29, 21, 31, 115, 351, 213, 201, 3511, 3707, 12821, 8845, 59789, 59721, 0 };
            const std::uint32_t dim12612JoeKuoD6Init[]   =   { 1, 3, 5, 9, 7, 27, 65, 1, 305, 937, 1201, 2045, 2431, 12275, 24431, 3317, 119671, 0 };
            const std::uint32_t dim12613JoeKuoD6Init[]   =   { 1, 1, 7, 11, 19, 43, 107, 107, 261, 933, 1125, 1875, 1943, 7477, 20759, 57853, 29459, 0 };
            const std::uint32_t dim12614JoeKuoD6Init[]   =   { 1, 1, 3, 3, 17, 43, 79, 19, 167, 341, 237, 677, 725, 2353, 12003, 48921, 20707, 0 };
            const std::uint32_t dim12615JoeKuoD6Init[]   =   { 1, 3, 3, 5, 31, 39, 91, 81, 121, 59, 737, 1767, 4407, 9159, 10237, 25361, 38891, 0 };
            const std::uint32_t dim12616JoeKuoD6Init[]   =   { 1, 1, 5, 7, 31, 47, 37, 47, 171, 623, 597, 2807, 4875, 15139, 18809, 24279, 36563, 0 };
            const std::uint32_t dim12617JoeKuoD6Init[]   =   { 1, 3, 5, 3, 3, 7, 31, 135, 81, 777, 1055, 337, 4309, 9575, 11075, 54429, 30097, 0 };
            const std::uint32_t dim12618JoeKuoD6Init[]   =   { 1, 1, 5, 1, 3, 57, 53, 25, 117, 961, 947, 257, 2645, 6935, 27511, 54051, 129095, 0 };
            const std::uint32_t dim12619JoeKuoD6Init[]   =   { 1, 1, 1, 15, 23, 45, 11, 173, 407, 373, 1051, 3519, 1875, 1291, 4393, 9047, 102159, 0 };
            const std::uint32_t dim12620JoeKuoD6Init[]   =   { 1, 1, 3, 5, 9, 51, 23, 253, 261, 339, 505, 3601, 265, 8375, 7241, 40715, 114439, 0 };
            const std::uint32_t dim12621JoeKuoD6Init[]   =   { 1, 1, 7, 7, 3, 63, 5, 233, 259, 947, 1367, 2699, 6029, 9371, 6567, 39961, 31621, 0 };
            const std::uint32_t dim12622JoeKuoD6Init[]   =   { 1, 1, 3, 3, 25, 43, 73, 61, 305, 257, 235, 421, 6621, 1025, 18831, 44525, 87665, 0 };
            const std::uint32_t dim12623JoeKuoD6Init[]   =   { 1, 3, 5, 7, 19, 33, 77, 163, 191, 115, 1275, 3551, 3521, 6767, 30209, 48895, 114185, 0 };
            const std::uint32_t dim12624JoeKuoD6Init[]   =   { 1, 1, 3, 3, 29, 37, 3, 165, 267, 807, 967, 2893, 3287, 12249, 21411, 19291, 91781, 0 };
            const std::uint32_t dim12625JoeKuoD6Init[]   =   { 1, 1, 5, 5, 27, 55, 51, 137, 429, 775, 1525, 3911, 5367, 5981, 24373, 16331, 31887, 0 };
            const std::uint32_t dim12626JoeKuoD6Init[]   =   { 1, 1, 5, 11, 17, 49, 37, 243, 509, 563, 1381, 2013, 7341, 10509, 10049, 29135, 32709, 0 };
            const std::uint32_t dim12627JoeKuoD6Init[]   =   { 1, 1, 3, 13, 1, 33, 119, 5, 477, 701, 1329, 1023, 2091, 12895, 6443, 1053, 44741, 0 };
            const std::uint32_t dim12628JoeKuoD6Init[]   =   { 1, 3, 5, 7, 13, 19, 1, 113, 3, 481, 1555, 2857, 3519, 7903, 16153, 62909, 78877, 0 };
            const std::uint32_t dim12629JoeKuoD6Init[]   =   { 1, 1, 7, 11, 7, 27, 47, 175, 87, 605, 411, 4065, 8059, 5023, 27719, 3111, 62247, 0 };
            const std::uint32_t dim12630JoeKuoD6Init[]   =   { 1, 3, 1, 15, 27, 37, 71, 77, 297, 647, 1651, 2543, 3925, 4827, 28587, 49663, 56581, 0 };
            const std::uint32_t dim12631JoeKuoD6Init[]   =   { 1, 3, 5, 1, 19, 49, 63, 9, 43, 243, 931, 3577, 2371, 10513, 13691, 27739, 61011, 0 };
            const std::uint32_t dim12632JoeKuoD6Init[]   =   { 1, 1, 3, 1, 23, 27, 53, 149, 157, 735, 1087, 1529, 6613, 2493, 4879, 26771, 123711, 0 };
            const std::uint32_t dim12633JoeKuoD6Init[]   =   { 1, 3, 7, 13, 5, 3, 43, 3, 343, 497, 943, 3443, 4335, 4779, 4033, 25871, 10965, 0 };
            const std::uint32_t dim12634JoeKuoD6Init[]   =   { 1, 3, 5, 1, 5, 11, 93, 73, 199, 455, 421, 3495, 4381, 717, 21033, 41287, 44743, 0 };
            const std::uint32_t dim12635JoeKuoD6Init[]   =   { 1, 1, 3, 9, 13, 33, 77, 143, 81, 57, 1061, 3205, 2411, 1347, 23149, 21913, 119331, 0 };
            const std::uint32_t dim12636JoeKuoD6Init[]   =   { 1, 3, 1, 7, 1, 15, 45, 247, 119, 905, 457, 3939, 4865, 11191, 27705, 46315, 68367, 0 };
            const std::uint32_t dim12637JoeKuoD6Init[]   =   { 1, 3, 3, 15, 31, 5, 55, 169, 381, 1009, 1893, 2751, 411, 8653, 30367, 54919, 23541, 0 };
            const std::uint32_t dim12638JoeKuoD6Init[]   =   { 1, 3, 7, 1, 29, 27, 77, 239, 109, 125, 355, 2759, 2229, 3435, 16241, 53309, 613, 0 };
            const std::uint32_t dim12639JoeKuoD6Init[]   =   { 1, 3, 1, 3, 11, 27, 33, 167, 311, 1003, 1635, 2479, 1831, 6225, 17711, 30185, 87043, 0 };
            const std::uint32_t dim12640JoeKuoD6Init[]   =   { 1, 3, 7, 13, 7, 61, 3, 243, 55, 259, 461, 3357, 121, 9107, 19393, 3719, 71403, 0 };
            const std::uint32_t dim12641JoeKuoD6Init[]   =   { 1, 1, 7, 15, 23, 25, 55, 89, 241, 297, 113, 59, 4799, 381, 29127, 811, 91149, 0 };
            const std::uint32_t dim12642JoeKuoD6Init[]   =   { 1, 1, 3, 3, 13, 35, 43, 163, 69, 69, 1949, 2383, 887, 2349, 12539, 167, 23697, 0 };
            const std::uint32_t dim12643JoeKuoD6Init[]   =   { 1, 3, 3, 11, 3, 45, 23, 149, 55, 963, 1293, 2715, 1401, 16081, 12821, 2129, 26835, 0 };
            const std::uint32_t dim12644JoeKuoD6Init[]   =   { 1, 3, 3, 13, 29, 47, 21, 249, 141, 179, 627, 329, 6377, 12049, 11715, 1447, 119359, 0 };
            const std::uint32_t dim12645JoeKuoD6Init[]   =   { 1, 1, 5, 13, 7, 59, 103, 189, 401, 169, 455, 1197, 1881, 12679, 4533, 25561, 79281, 0 };
            const std::uint32_t dim12646JoeKuoD6Init[]   =   { 1, 1, 7, 15, 21, 59, 97, 77, 397, 487, 647, 2277, 269, 713, 17741, 37387, 100143, 0 };
            const std::uint32_t dim12647JoeKuoD6Init[]   =   { 1, 3, 5, 1, 1, 43, 31, 201, 21, 805, 1533, 1407, 4719, 2673, 22757, 7605, 72485, 0 };
            const std::uint32_t dim12648JoeKuoD6Init[]   =   { 1, 1, 3, 11, 27, 25, 99, 135, 225, 367, 1311, 683, 7193, 8209, 17081, 55709, 3029, 0 };
            const std::uint32_t dim12649JoeKuoD6Init[]   =   { 1, 3, 5, 5, 17, 9, 59, 27, 153, 353, 647, 2919, 1877, 5359, 19787, 46237, 7, 0 };
            const std::uint32_t dim12650JoeKuoD6Init[]   =   { 1, 3, 3, 15, 11, 39, 75, 223, 489, 57, 1355, 3941, 6603, 12883, 20909, 24065, 53543, 0 };
            const std::uint32_t dim12651JoeKuoD6Init[]   =   { 1, 1, 3, 9, 17, 47, 61, 49, 397, 23, 2019, 37, 23, 8967, 10357, 54419, 27279, 0 };
            const std::uint32_t dim12652JoeKuoD6Init[]   =   { 1, 1, 1, 7, 31, 43, 87, 111, 293, 969, 1431, 2275, 3131, 2915, 24595, 63049, 71517, 0 };
            const std::uint32_t dim12653JoeKuoD6Init[]   =   { 1, 1, 3, 11, 11, 63, 89, 33, 95, 299, 593, 3353, 7389, 841, 1895, 64835, 19915, 0 };
            const std::uint32_t dim12654JoeKuoD6Init[]   =   { 1, 1, 1, 3, 13, 63, 51, 3, 327, 401, 1289, 2699, 5599, 5101, 3189, 23415, 53429, 0 };
            const std::uint32_t dim12655JoeKuoD6Init[]   =   { 1, 1, 7, 13, 27, 15, 57, 201, 365, 643, 171, 2417, 1763, 7567, 5323, 50911, 24281, 0 };
            const std::uint32_t dim12656JoeKuoD6Init[]   =   { 1, 3, 3, 13, 31, 37, 31, 243, 225, 431, 379, 1565, 1567, 11477, 4641, 58823, 88565, 0 };
            const std::uint32_t dim12657JoeKuoD6Init[]   =   { 1, 3, 3, 7, 13, 39, 79, 169, 401, 177, 2023, 1703, 5563, 15619, 21445, 59287, 30141, 0 };
            const std::uint32_t dim12658JoeKuoD6Init[]   =   { 1, 3, 3, 15, 17, 47, 13, 163, 361, 353, 1435, 2083, 4109, 14105, 28585, 1721, 119133, 0 };
            const std::uint32_t dim12659JoeKuoD6Init[]   =   { 1, 3, 3, 3, 29, 41, 97, 131, 501, 415, 1735, 2315, 6499, 11417, 3879, 3957, 47117, 0 };
            const std::uint32_t dim12660JoeKuoD6Init[]   =   { 1, 1, 3, 13, 5, 25, 29, 65, 235, 949, 1571, 927, 515, 7519, 23123, 4127, 71019, 0 };
            const std::uint32_t dim12661JoeKuoD6Init[]   =   { 1, 1, 5, 13, 1, 41, 5, 137, 487, 711, 561, 2495, 5367, 6955, 9453, 54499, 118373, 0 };
            const std::uint32_t dim12662JoeKuoD6Init[]   =   { 1, 3, 3, 5, 27, 15, 23, 237, 95, 873, 1949, 1579, 7089, 8837, 30463, 9903, 61919, 0 };
            const std::uint32_t dim12663JoeKuoD6Init[]   =   { 1, 3, 1, 13, 5, 5, 15, 5, 429, 617, 383, 2495, 409, 15541, 11209, 20625, 58493, 0 };
            const std::uint32_t dim12664JoeKuoD6Init[]   =   { 1, 1, 7, 11, 25, 21, 113, 219, 459, 777, 289, 2435, 6665, 83, 22997, 6561, 82923, 0 };
            const std::uint32_t dim12665JoeKuoD6Init[]   =   { 1, 1, 1, 7, 19, 53, 37, 249, 273, 639, 2007, 1463, 7819, 9013, 19539, 41235, 58059, 0 };
            const std::uint32_t dim12666JoeKuoD6Init[]   =   { 1, 1, 3, 11, 13, 51, 97, 55, 237, 159, 1305, 3705, 2527, 13065, 13873, 10275, 3769, 0 };
            const std::uint32_t dim12667JoeKuoD6Init[]   =   { 1, 1, 5, 7, 13, 49, 41, 13, 301, 461, 1169, 3805, 7163, 4133, 17255, 48283, 87059, 0 };
            const std::uint32_t dim12668JoeKuoD6Init[]   =   { 1, 3, 7, 15, 9, 19, 45, 195, 445, 145, 543, 2839, 315, 10991, 3317, 46501, 29209, 0 };
            const std::uint32_t dim12669JoeKuoD6Init[]   =   { 1, 1, 3, 5, 23, 51, 53, 119, 217, 747, 1307, 3039, 5523, 5891, 21035, 56471, 80305, 0 };
            const std::uint32_t dim12670JoeKuoD6Init[]   =   { 1, 3, 1, 3, 23, 17, 97, 71, 7, 839, 229, 3407, 3025, 1989, 16599, 38755, 11139, 0 };
            const std::uint32_t dim12671JoeKuoD6Init[]   =   { 1, 1, 7, 7, 7, 19, 67, 43, 293, 191, 1549, 1621, 7083, 11633, 1899, 4515, 89753, 0 };
            const std::uint32_t dim12672JoeKuoD6Init[]   =   { 1, 3, 7, 11, 1, 23, 17, 63, 265, 709, 453, 1309, 6861, 7257, 17705, 28565, 15231, 0 };
            const std::uint32_t dim12673JoeKuoD6Init[]   =   { 1, 3, 5, 13, 1, 53, 99, 79, 241, 771, 497, 987, 2353, 6931, 227, 57781, 109583, 0 };
            const std::uint32_t dim12674JoeKuoD6Init[]   =   { 1, 3, 3, 5, 31, 47, 17, 97, 93, 119, 2045, 3597, 7983, 4993, 30659, 3419, 32803, 0 };
            const std::uint32_t dim12675JoeKuoD6Init[]   =   { 1, 3, 7, 1, 11, 41, 3, 7, 155, 627, 979, 2405, 7467, 6763, 28523, 56493, 1291, 0 };
            const std::uint32_t dim12676JoeKuoD6Init[]   =   { 1, 1, 1, 7, 3, 43, 13, 187, 415, 1001, 667, 1371, 8075, 12855, 27215, 9399, 70657, 0 };
            const std::uint32_t dim12677JoeKuoD6Init[]   =   { 1, 3, 1, 9, 29, 53, 117, 17, 443, 381, 507, 643, 5891, 10725, 20251, 497, 101313, 0 };
            const std::uint32_t dim12678JoeKuoD6Init[]   =   { 1, 3, 3, 1, 31, 47, 59, 75, 173, 347, 1, 117, 3639, 10231, 863, 56795, 56107, 0 };
            const std::uint32_t dim12679JoeKuoD6Init[]   =   { 1, 3, 1, 15, 11, 41, 97, 251, 177, 275, 1849, 1281, 3659, 9709, 16239, 7445, 47661, 0 };
            const std::uint32_t dim12680JoeKuoD6Init[]   =   { 1, 3, 3, 5, 13, 1, 27, 251, 89, 863, 685, 3915, 2201, 4313, 32083, 37171, 120885, 0 };
            const std::uint32_t dim12681JoeKuoD6Init[]   =   { 1, 3, 3, 3, 3, 11, 77, 135, 147, 475, 505, 611, 4763, 9445, 28639, 51343, 119093, 0 };
            const std::uint32_t dim12682JoeKuoD6Init[]   =   { 1, 3, 7, 1, 11, 9, 67, 73, 375, 977, 1011, 1621, 6623, 8077, 26321, 7461, 130637, 0 };
            const std::uint32_t dim12683JoeKuoD6Init[]   =   { 1, 3, 5, 15, 15, 59, 63, 217, 117, 375, 1151, 3451, 5843, 13221, 20673, 10817, 57711, 0 };
            const std::uint32_t dim12684JoeKuoD6Init[]   =   { 1, 1, 3, 5, 19, 5, 9, 101, 321, 815, 451, 719, 523, 1299, 27823, 48041, 45939, 0 };
            const std::uint32_t dim12685JoeKuoD6Init[]   =   { 1, 1, 1, 9, 5, 49, 59, 59, 409, 5, 1075, 21, 7837, 4543, 3085, 55473, 89309, 0 };
            const std::uint32_t dim12686JoeKuoD6Init[]   =   { 1, 3, 3, 13, 9, 31, 93, 181, 153, 795, 713, 933, 6001, 9075, 29781, 14029, 46361, 0 };
            const std::uint32_t dim12687JoeKuoD6Init[]   =   { 1, 3, 5, 3, 9, 21, 79, 129, 361, 627, 743, 3041, 5381, 3627, 12581, 35183, 83183, 0 };
            const std::uint32_t dim12688JoeKuoD6Init[]   =   { 1, 3, 3, 3, 29, 29, 93, 187, 341, 727, 181, 133, 6525, 5673, 2739, 23349, 62505, 0 };
            const std::uint32_t dim12689JoeKuoD6Init[]   =   { 1, 3, 5, 13, 27, 59, 127, 149, 321, 613, 1543, 1537, 2909, 5139, 3755, 49285, 35183, 0 };
            const std::uint32_t dim12690JoeKuoD6Init[]   =   { 1, 3, 3, 9, 5, 31, 19, 173, 137, 19, 799, 1847, 3897, 15775, 22411, 55405, 95713, 0 };
            const std::uint32_t dim12691JoeKuoD6Init[]   =   { 1, 3, 5, 5, 31, 1, 87, 97, 481, 797, 459, 793, 4339, 5443, 31717, 6691, 68841, 0 };
            const std::uint32_t dim12692JoeKuoD6Init[]   =   { 1, 3, 3, 5, 3, 9, 123, 21, 393, 683, 1007, 971, 729, 7113, 2811, 51183, 37093, 0 };
            const std::uint32_t dim12693JoeKuoD6Init[]   =   { 1, 3, 5, 5, 27, 31, 19, 227, 123, 937, 763, 2117, 3825, 9151, 95, 54963, 62919, 0 };
            const std::uint32_t dim12694JoeKuoD6Init[]   =   { 1, 3, 1, 3, 23, 21, 21, 7, 7, 165, 99, 3073, 91, 8725, 17613, 47119, 41441, 0 };
            const std::uint32_t dim12695JoeKuoD6Init[]   =   { 1, 3, 7, 9, 29, 49, 117, 49, 205, 605, 1567, 3323, 1559, 10949, 14349, 34951, 99901, 0 };
            const std::uint32_t dim12696JoeKuoD6Init[]   =   { 1, 1, 1, 1, 15, 41, 31, 133, 439, 305, 719, 147, 6849, 5947, 31749, 45171, 15265, 0 };
            const std::uint32_t dim12697JoeKuoD6Init[]   =   { 1, 1, 5, 11, 19, 37, 13, 253, 385, 625, 1801, 1191, 547, 12025, 17971, 54127, 97323, 0 };
            const std::uint32_t dim12698JoeKuoD6Init[]   =   { 1, 3, 5, 5, 27, 9, 57, 245, 59, 211, 1195, 763, 6743, 6309, 25759, 26633, 27497, 0 };
            const std::uint32_t dim12699JoeKuoD6Init[]   =   { 1, 3, 5, 5, 9, 51, 49, 29, 213, 855, 305, 3961, 3187, 6815, 19015, 2539, 81705, 0 };
            const std::uint32_t dim12700JoeKuoD6Init[]   =   { 1, 1, 5, 7, 11, 61, 123, 163, 127, 871, 463, 2279, 5931, 2913, 23215, 40215, 91373, 0 };
            const std::uint32_t dim12701JoeKuoD6Init[]   =   { 1, 1, 7, 1, 29, 57, 55, 189, 285, 603, 747, 3753, 3359, 10277, 25319, 17569, 80125, 0 };
            const std::uint32_t dim12702JoeKuoD6Init[]   =   { 1, 3, 1, 9, 7, 53, 9, 55, 117, 495, 2045, 2487, 1625, 775, 17773, 62159, 79537, 0 };
            const std::uint32_t dim12703JoeKuoD6Init[]   =   { 1, 1, 5, 1, 1, 11, 67, 79, 57, 677, 2045, 3913, 853, 3581, 10509, 35097, 24585, 0 };
            const std::uint32_t dim12704JoeKuoD6Init[]   =   { 1, 3, 7, 7, 19, 15, 13, 237, 297, 807, 657, 2229, 2931, 10283, 49, 56485, 113889, 0 };
            const std::uint32_t dim12705JoeKuoD6Init[]   =   { 1, 3, 5, 13, 11, 23, 37, 229, 253, 411, 39, 1069, 3683, 12141, 11087, 64875, 62991, 0 };
            const std::uint32_t dim12706JoeKuoD6Init[]   =   { 1, 1, 1, 1, 13, 11, 21, 227, 305, 1021, 1039, 3095, 4621, 5723, 31989, 30681, 58487, 0 };
            const std::uint32_t dim12707JoeKuoD6Init[]   =   { 1, 3, 3, 5, 17, 47, 127, 65, 85, 961, 277, 549, 2111, 4183, 771, 11921, 111489, 0 };
            const std::uint32_t dim12708JoeKuoD6Init[]   =   { 1, 3, 3, 5, 31, 39, 89, 51, 277, 705, 375, 1603, 2793, 7425, 25065, 44945, 48391, 0 };
            const std::uint32_t dim12709JoeKuoD6Init[]   =   { 1, 1, 5, 7, 9, 45, 21, 217, 183, 65, 625, 1239, 4241, 8043, 13615, 5611, 82501, 0 };
            const std::uint32_t dim12710JoeKuoD6Init[]   =   { 1, 1, 7, 13, 15, 51, 29, 35, 73, 601, 233, 3117, 3031, 4229, 4299, 62761, 45291, 0 };
            const std::uint32_t dim12711JoeKuoD6Init[]   =   { 1, 3, 5, 5, 27, 55, 7, 1, 333, 501, 913, 1939, 5131, 5597, 1271, 30195, 20947, 0 };
            const std::uint32_t dim12712JoeKuoD6Init[]   =   { 1, 3, 5, 15, 19, 27, 43, 111, 435, 615, 811, 2113, 2503, 7553, 1619, 24773, 40881, 0 };
            const std::uint32_t dim12713JoeKuoD6Init[]   =   { 1, 3, 5, 11, 11, 31, 21, 147, 151, 141, 527, 1839, 339, 1225, 29621, 19691, 22031, 0 };
            const std::uint32_t dim12714JoeKuoD6Init[]   =   { 1, 1, 3, 13, 23, 35, 61, 181, 221, 837, 241, 3033, 1849, 12563, 11387, 3027, 33419, 0 };
            const std::uint32_t dim12715JoeKuoD6Init[]   =   { 1, 3, 3, 7, 1, 39, 125, 249, 231, 575, 1847, 197, 3969, 12945, 10257, 27227, 94097, 0 };
            const std::uint32_t dim12716JoeKuoD6Init[]   =   { 1, 3, 1, 11, 19, 7, 85, 119, 37, 253, 1575, 447, 6947, 14399, 32095, 15385, 62917, 0 };
            const std::uint32_t dim12717JoeKuoD6Init[]   =   { 1, 3, 7, 11, 23, 53, 113, 193, 253, 651, 1717, 447, 4055, 13675, 18479, 28375, 66475, 0 };
            const std::uint32_t dim12718JoeKuoD6Init[]   =   { 1, 1, 7, 3, 17, 27, 13, 209, 67, 271, 121, 1565, 2589, 8033, 3939, 14181, 111787, 0 };
            const std::uint32_t dim12719JoeKuoD6Init[]   =   { 1, 1, 3, 3, 5, 57, 75, 87, 165, 947, 967, 3353, 2055, 16195, 3701, 62637, 58343, 0 };
            const std::uint32_t dim12720JoeKuoD6Init[]   =   { 1, 1, 7, 13, 31, 41, 125, 111, 253, 257, 57, 679, 3333, 8259, 26331, 15883, 95023, 0 };
            const std::uint32_t dim12721JoeKuoD6Init[]   =   { 1, 3, 7, 11, 1, 47, 5, 249, 353, 271, 1121, 1935, 4971, 8447, 9983, 55959, 66179, 0 };
            const std::uint32_t dim12722JoeKuoD6Init[]   =   { 1, 3, 5, 11, 1, 61, 101, 43, 97, 241, 687, 4027, 4319, 4905, 12357, 51099, 97093, 0 };
            const std::uint32_t dim12723JoeKuoD6Init[]   =   { 1, 1, 3, 15, 25, 25, 117, 139, 475, 961, 1585, 2795, 2411, 11049, 18209, 15511, 43193, 0 };
            const std::uint32_t dim12724JoeKuoD6Init[]   =   { 1, 3, 3, 9, 9, 11, 107, 15, 189, 27, 289, 3111, 851, 3401, 31981, 7181, 47533, 0 };
            const std::uint32_t dim12725JoeKuoD6Init[]   =   { 1, 1, 5, 15, 31, 57, 37, 77, 205, 707, 1505, 1343, 629, 13335, 6719, 35405, 38905, 0 };
            const std::uint32_t dim12726JoeKuoD6Init[]   =   { 1, 3, 7, 7, 21, 63, 35, 125, 507, 285, 621, 2257, 3009, 13703, 9761, 54927, 16925, 0 };
            const std::uint32_t dim12727JoeKuoD6Init[]   =   { 1, 1, 1, 11, 11, 53, 37, 17, 167, 663, 1349, 1395, 7721, 9329, 2161, 37093, 52425, 0 };
            const std::uint32_t dim12728JoeKuoD6Init[]   =   { 1, 1, 7, 9, 1, 15, 113, 53, 87, 133, 131, 847, 609, 14737, 1639, 15511, 46987, 0 };
            const std::uint32_t dim12729JoeKuoD6Init[]   =   { 1, 1, 7, 7, 25, 21, 125, 149, 201, 791, 1323, 2817, 1141, 289, 14349, 64461, 76575, 0 };
            const std::uint32_t dim12730JoeKuoD6Init[]   =   { 1, 3, 3, 7, 15, 1, 123, 227, 83, 967, 2039, 3205, 715, 10787, 11235, 50375, 66911, 0 };
            const std::uint32_t dim12731JoeKuoD6Init[]   =   { 1, 3, 3, 11, 9, 45, 41, 57, 327, 903, 1705, 3947, 3173, 1035, 25529, 15217, 80795, 0 };
            const std::uint32_t dim12732JoeKuoD6Init[]   =   { 1, 3, 1, 13, 15, 63, 69, 57, 479, 277, 1641, 3465, 2629, 9901, 5781, 55101, 33049, 0 };
            const std::uint32_t dim12733JoeKuoD6Init[]   =   { 1, 1, 3, 3, 31, 25, 57, 189, 491, 335, 373, 3069, 1623, 10781, 6559, 27057, 111491, 0 };
            const std::uint32_t dim12734JoeKuoD6Init[]   =   { 1, 3, 3, 15, 19, 57, 67, 225, 343, 93, 315, 1011, 4437, 10371, 27927, 51269, 65653, 0 };
            const std::uint32_t dim12735JoeKuoD6Init[]   =   { 1, 3, 5, 5, 21, 43, 105, 153, 65, 167, 369, 3167, 785, 7509, 3753, 9035, 29039, 0 };
            const std::uint32_t dim12736JoeKuoD6Init[]   =   { 1, 1, 7, 3, 17, 9, 113, 21, 175, 967, 13, 2701, 5667, 9761, 20267, 33497, 88819, 0 };
            const std::uint32_t dim12737JoeKuoD6Init[]   =   { 1, 1, 1, 7, 9, 61, 121, 205, 283, 259, 2027, 2361, 3995, 6787, 26867, 61681, 96149, 0 };
            const std::uint32_t dim12738JoeKuoD6Init[]   =   { 1, 3, 3, 13, 31, 37, 125, 151, 317, 947, 423, 2907, 6905, 13247, 27997, 4755, 73173, 0 };
            const std::uint32_t dim12739JoeKuoD6Init[]   =   { 1, 1, 7, 13, 1, 63, 85, 75, 33, 483, 85, 1583, 4783, 14003, 31147, 12643, 99447, 0 };
            const std::uint32_t dim12740JoeKuoD6Init[]   =   { 1, 1, 1, 7, 31, 5, 93, 179, 213, 857, 3, 1015, 1481, 2413, 28759, 13941, 24851, 0 };
            const std::uint32_t dim12741JoeKuoD6Init[]   =   { 1, 1, 5, 5, 5, 35, 73, 57, 469, 885, 1951, 3599, 5555, 7259, 22599, 7627, 109227, 0 };
            const std::uint32_t dim12742JoeKuoD6Init[]   =   { 1, 1, 5, 13, 1, 1, 69, 107, 473, 793, 1851, 887, 2241, 7851, 21821, 25431, 118565, 0 };
            const std::uint32_t dim12743JoeKuoD6Init[]   =   { 1, 1, 1, 3, 15, 51, 57, 175, 91, 113, 1671, 925, 2187, 1097, 28793, 45819, 41855, 0 };
            const std::uint32_t dim12744JoeKuoD6Init[]   =   { 1, 1, 3, 3, 15, 51, 99, 177, 379, 713, 1273, 3245, 5515, 14657, 28981, 1197, 29283, 0 };
            const std::uint32_t dim12745JoeKuoD6Init[]   =   { 1, 3, 3, 15, 13, 27, 29, 7, 17, 373, 779, 1589, 3077, 13673, 31029, 43765, 74339, 0 };
            const std::uint32_t dim12746JoeKuoD6Init[]   =   { 1, 1, 3, 1, 25, 17, 15, 223, 219, 569, 155, 1307, 7143, 7975, 22581, 53223, 44271, 0 };
            const std::uint32_t dim12747JoeKuoD6Init[]   =   { 1, 1, 1, 7, 11, 23, 67, 177, 189, 267, 1799, 2453, 2367, 4193, 1827, 10191, 12265, 0 };
            const std::uint32_t dim12748JoeKuoD6Init[]   =   { 1, 3, 3, 11, 3, 29, 121, 231, 211, 191, 1803, 1171, 6801, 4007, 14111, 42951, 8311, 0 };
            const std::uint32_t dim12749JoeKuoD6Init[]   =   { 1, 3, 3, 11, 9, 23, 11, 231, 349, 47, 1645, 345, 3681, 12227, 29955, 32131, 391, 0 };
            const std::uint32_t dim12750JoeKuoD6Init[]   =   { 1, 1, 3, 11, 27, 17, 17, 49, 463, 173, 1993, 2339, 3763, 1931, 29969, 55579, 114805, 0 };
            const std::uint32_t dim12751JoeKuoD6Init[]   =   { 1, 3, 5, 15, 5, 21, 105, 69, 173, 771, 815, 3807, 577, 12589, 32193, 37601, 23961, 0 };
            const std::uint32_t dim12752JoeKuoD6Init[]   =   { 1, 1, 3, 9, 21, 63, 57, 213, 327, 765, 333, 2065, 719, 6159, 15769, 49335, 2289, 0 };
            const std::uint32_t dim12753JoeKuoD6Init[]   =   { 1, 3, 3, 1, 27, 51, 13, 87, 465, 729, 507, 2811, 6721, 14279, 31733, 56165, 78169, 0 };
            const std::uint32_t dim12754JoeKuoD6Init[]   =   { 1, 1, 1, 9, 25, 1, 47, 37, 407, 623, 1409, 3703, 4491, 3037, 8129, 13547, 50517, 0 };
            const std::uint32_t dim12755JoeKuoD6Init[]   =   { 1, 3, 5, 13, 5, 51, 127, 225, 215, 377, 1013, 2387, 4237, 1317, 5245, 17535, 100707, 0 };
            const std::uint32_t dim12756JoeKuoD6Init[]   =   { 1, 3, 5, 13, 31, 25, 123, 243, 317, 505, 483, 1743, 3097, 4139, 4525, 63143, 47665, 0 };
            const std::uint32_t dim12757JoeKuoD6Init[]   =   { 1, 3, 3, 13, 27, 19, 21, 187, 211, 471, 1931, 2877, 3635, 9233, 12385, 15741, 50843, 0 };
            const std::uint32_t dim12758JoeKuoD6Init[]   =   { 1, 1, 3, 13, 23, 33, 71, 45, 371, 621, 1057, 1605, 6329, 3763, 8613, 2965, 8141, 0 };
            const std::uint32_t dim12759JoeKuoD6Init[]   =   { 1, 1, 5, 7, 7, 17, 33, 209, 293, 35, 1665, 3721, 6245, 14567, 15349, 16195, 59757, 0 };
            const std::uint32_t dim12760JoeKuoD6Init[]   =   { 1, 1, 7, 7, 31, 19, 47, 83, 277, 323, 1225, 969, 2193, 10175, 27657, 50265, 9817, 0 };
            const std::uint32_t dim12761JoeKuoD6Init[]   =   { 1, 1, 5, 7, 15, 21, 103, 95, 189, 737, 309, 357, 5953, 9701, 15757, 20753, 88647, 0 };
            const std::uint32_t dim12762JoeKuoD6Init[]   =   { 1, 1, 5, 13, 5, 13, 61, 235, 333, 889, 1559, 1653, 1871, 10631, 18067, 47037, 9507, 0 };
            const std::uint32_t dim12763JoeKuoD6Init[]   =   { 1, 3, 7, 1, 31, 61, 69, 159, 41, 107, 807, 1517, 3551, 3435, 6151, 50025, 126949, 0 };
            const std::uint32_t dim12764JoeKuoD6Init[]   =   { 1, 1, 7, 15, 7, 41, 55, 103, 9, 105, 1397, 3955, 7723, 3389, 32435, 36005, 73733, 0 };
            const std::uint32_t dim12765JoeKuoD6Init[]   =   { 1, 1, 1, 13, 15, 59, 43, 151, 321, 215, 411, 3103, 7455, 14041, 1673, 56425, 59085, 0 };
            const std::uint32_t dim12766JoeKuoD6Init[]   =   { 1, 1, 1, 1, 5, 39, 81, 183, 509, 455, 753, 3743, 227, 7807, 23747, 42289, 122765, 0 };
            const std::uint32_t dim12767JoeKuoD6Init[]   =   { 1, 1, 7, 3, 9, 29, 89, 131, 141, 851, 1221, 67, 3117, 1329, 13151, 36827, 34313, 0 };
            const std::uint32_t dim12768JoeKuoD6Init[]   =   { 1, 3, 1, 5, 9, 29, 11, 189, 389, 79, 1903, 835, 6043, 8953, 18985, 8305, 51939, 0 };
            const std::uint32_t dim12769JoeKuoD6Init[]   =   { 1, 3, 5, 3, 9, 49, 47, 43, 193, 917, 795, 2719, 5709, 9993, 30637, 26841, 93113, 0 };
            const std::uint32_t dim12770JoeKuoD6Init[]   =   { 1, 3, 7, 5, 13, 15, 85, 169, 315, 963, 617, 1191, 6739, 11535, 3423, 6695, 2047, 0 };
            const std::uint32_t dim12771JoeKuoD6Init[]   =   { 1, 3, 1, 3, 5, 49, 41, 255, 131, 255, 825, 1485, 7005, 10107, 3913, 4731, 33199, 0 };
            const std::uint32_t dim12772JoeKuoD6Init[]   =   { 1, 3, 1, 9, 27, 63, 109, 29, 183, 381, 591, 617, 1187, 4381, 30543, 9933, 109785, 0 };
            const std::uint32_t dim12773JoeKuoD6Init[]   =   { 1, 3, 7, 7, 13, 29, 125, 105, 353, 677, 623, 1553, 5435, 10853, 16663, 42277, 64333, 0 };
            const std::uint32_t dim12774JoeKuoD6Init[]   =   { 1, 3, 3, 11, 3, 47, 49, 41, 249, 497, 963, 237, 625, 11303, 6871, 60441, 39559, 0 };
            const std::uint32_t dim12775JoeKuoD6Init[]   =   { 1, 3, 3, 1, 1, 27, 107, 253, 59, 445, 1761, 2865, 7117, 2363, 4007, 46047, 10811, 0 };
            const std::uint32_t dim12776JoeKuoD6Init[]   =   { 1, 3, 5, 5, 25, 13, 17, 107, 321, 691, 351, 577, 5001, 9437, 12451, 44997, 42727, 0 };
            const std::uint32_t dim12777JoeKuoD6Init[]   =   { 1, 3, 1, 9, 1, 31, 87, 117, 111, 379, 1989, 1155, 4777, 8563, 14585, 33375, 66985, 0 };
            const std::uint32_t dim12778JoeKuoD6Init[]   =   { 1, 3, 5, 5, 9, 51, 79, 135, 89, 929, 277, 763, 5569, 15545, 28393, 56921, 102093, 0 };
            const std::uint32_t dim12779JoeKuoD6Init[]   =   { 1, 1, 3, 7, 7, 55, 15, 37, 3, 439, 577, 2051, 101, 13655, 11959, 38127, 6639, 0 };
            const std::uint32_t dim12780JoeKuoD6Init[]   =   { 1, 1, 3, 9, 21, 11, 27, 221, 465, 565, 1313, 1405, 2421, 10543, 18369, 33751, 87785, 0 };
            const std::uint32_t dim12781JoeKuoD6Init[]   =   { 1, 3, 5, 11, 21, 39, 105, 231, 469, 711, 997, 427, 5797, 3249, 15141, 29413, 66509, 0 };
            const std::uint32_t dim12782JoeKuoD6Init[]   =   { 1, 3, 7, 5, 25, 31, 111, 37, 229, 773, 193, 553, 673, 4693, 24441, 8713, 121203, 0 };
            const std::uint32_t dim12783JoeKuoD6Init[]   =   { 1, 3, 1, 9, 23, 27, 103, 7, 183, 549, 1433, 2831, 3383, 13229, 10005, 14135, 15967, 0 };
            const std::uint32_t dim12784JoeKuoD6Init[]   =   { 1, 3, 3, 11, 11, 59, 11, 251, 373, 399, 255, 1177, 5493, 13559, 29037, 23405, 79495, 0 };
            const std::uint32_t dim12785JoeKuoD6Init[]   =   { 1, 3, 1, 11, 25, 45, 69, 115, 153, 259, 527, 9, 5807, 6015, 3765, 61621, 8645, 0 };
            const std::uint32_t dim12786JoeKuoD6Init[]   =   { 1, 3, 3, 9, 19, 5, 113, 191, 345, 655, 429, 3975, 4297, 5723, 5345, 64457, 79031, 0 };
            const std::uint32_t dim12787JoeKuoD6Init[]   =   { 1, 3, 7, 7, 15, 59, 5, 87, 289, 1005, 931, 2403, 485, 16043, 15623, 39253, 61377, 0 };
            const std::uint32_t dim12788JoeKuoD6Init[]   =   { 1, 3, 3, 9, 17, 53, 31, 9, 217, 711, 1007, 1375, 2733, 13735, 19825, 59741, 83827, 0 };
            const std::uint32_t dim12789JoeKuoD6Init[]   =   { 1, 1, 3, 15, 11, 11, 41, 195, 79, 1013, 1353, 1961, 7365, 7533, 13315, 8441, 90705, 0 };
            const std::uint32_t dim12790JoeKuoD6Init[]   =   { 1, 1, 5, 7, 23, 17, 93, 165, 371, 495, 865, 2753, 15, 10729, 16553, 6039, 96721, 0 };
            const std::uint32_t dim12791JoeKuoD6Init[]   =   { 1, 3, 3, 3, 25, 25, 67, 119, 485, 63, 75, 2365, 4711, 16129, 5589, 50621, 1203, 0 };
            const std::uint32_t dim12792JoeKuoD6Init[]   =   { 1, 1, 7, 1, 27, 57, 49, 79, 479, 79, 683, 753, 345, 2007, 18983, 42729, 56369, 0 };
            const std::uint32_t dim12793JoeKuoD6Init[]   =   { 1, 1, 7, 7, 1, 23, 9, 155, 425, 735, 1625, 2271, 7875, 11219, 12147, 52351, 55845, 0 };
            const std::uint32_t dim12794JoeKuoD6Init[]   =   { 1, 1, 1, 9, 13, 11, 67, 139, 259, 59, 1593, 1207, 237, 11683, 24719, 27689, 115617, 0 };
            const std::uint32_t dim12795JoeKuoD6Init[]   =   { 1, 1, 5, 7, 7, 15, 9, 171, 35, 131, 133, 3939, 1401, 6347, 4051, 64235, 68581, 0 };
            const std::uint32_t dim12796JoeKuoD6Init[]   =   { 1, 3, 3, 1, 27, 21, 29, 119, 201, 527, 763, 203, 1139, 3951, 3341, 17023, 13493, 0 };
            const std::uint32_t dim12797JoeKuoD6Init[]   =   { 1, 1, 1, 15, 27, 31, 97, 203, 255, 573, 781, 4095, 3381, 363, 32733, 34517, 77973, 0 };
            const std::uint32_t dim12798JoeKuoD6Init[]   =   { 1, 1, 3, 9, 29, 9, 115, 207, 267, 513, 1071, 3943, 5045, 10071, 6627, 18043, 44289, 0 };
            const std::uint32_t dim12799JoeKuoD6Init[]   =   { 1, 1, 7, 7, 29, 25, 51, 31, 305, 239, 197, 3825, 2363, 4903, 16237, 37571, 66545, 0 };
            const std::uint32_t dim12800JoeKuoD6Init[]   =   { 1, 1, 5, 11, 29, 11, 63, 145, 185, 359, 249, 1179, 105, 1745, 28819, 40513, 74525, 0 };
            const std::uint32_t dim12801JoeKuoD6Init[]   =   { 1, 1, 7, 1, 15, 35, 39, 5, 139, 119, 2047, 3369, 2857, 11037, 30523, 24813, 89209, 0 };
            const std::uint32_t dim12802JoeKuoD6Init[]   =   { 1, 1, 5, 11, 9, 41, 97, 15, 357, 95, 361, 3, 3227, 8445, 16541, 30661, 84215, 0 };
            const std::uint32_t dim12803JoeKuoD6Init[]   =   { 1, 1, 7, 5, 11, 55, 77, 19, 331, 621, 893, 577, 1025, 1561, 32331, 59469, 67065, 0 };
            const std::uint32_t dim12804JoeKuoD6Init[]   =   { 1, 3, 7, 7, 17, 53, 55, 65, 295, 391, 445, 33, 5361, 669, 6447, 3833, 129463, 0 };
            const std::uint32_t dim12805JoeKuoD6Init[]   =   { 1, 3, 7, 5, 21, 5, 83, 207, 485, 597, 1429, 581, 6831, 2885, 24669, 35211, 69549, 0 };
            const std::uint32_t dim12806JoeKuoD6Init[]   =   { 1, 3, 3, 1, 3, 33, 69, 199, 427, 893, 1823, 1291, 4533, 11779, 18515, 17597, 79159, 0 };
            const std::uint32_t dim12807JoeKuoD6Init[]   =   { 1, 3, 1, 1, 17, 41, 91, 21, 509, 875, 777, 639, 4009, 12103, 12947, 58395, 36625, 0 };
            const std::uint32_t dim12808JoeKuoD6Init[]   =   { 1, 1, 7, 15, 13, 11, 19, 243, 365, 661, 1193, 279, 6055, 13921, 5811, 14337, 105375, 0 };
            const std::uint32_t dim12809JoeKuoD6Init[]   =   { 1, 3, 7, 3, 3, 51, 101, 175, 83, 921, 523, 3909, 8003, 1295, 4153, 4757, 107881, 0 };
            const std::uint32_t dim12810JoeKuoD6Init[]   =   { 1, 1, 1, 3, 19, 15, 39, 125, 401, 399, 381, 1123, 2339, 12231, 13387, 50829, 79263, 0 };
            const std::uint32_t dim12811JoeKuoD6Init[]   =   { 1, 3, 1, 1, 15, 13, 55, 181, 53, 671, 1929, 1003, 521, 15279, 1837, 11877, 79241, 0 };
            const std::uint32_t dim12812JoeKuoD6Init[]   =   { 1, 3, 3, 9, 23, 45, 21, 37, 1, 701, 1253, 2595, 6261, 4139, 24443, 6655, 109755, 0 };
            const std::uint32_t dim12813JoeKuoD6Init[]   =   { 1, 3, 7, 1, 1, 13, 57, 41, 95, 985, 1613, 3487, 7509, 213, 32139, 27869, 123589, 0 };
            const std::uint32_t dim12814JoeKuoD6Init[]   =   { 1, 3, 7, 11, 15, 27, 27, 97, 167, 755, 1331, 3961, 3067, 13827, 8983, 8755, 77847, 0 };
            const std::uint32_t dim12815JoeKuoD6Init[]   =   { 1, 1, 5, 13, 5, 59, 51, 193, 339, 837, 137, 3807, 2617, 14449, 11035, 16827, 24531, 0 };
            const std::uint32_t dim12816JoeKuoD6Init[]   =   { 1, 1, 7, 15, 17, 37, 67, 99, 261, 743, 275, 33, 8107, 4959, 9683, 19757, 36471, 0 };
            const std::uint32_t dim12817JoeKuoD6Init[]   =   { 1, 3, 5, 5, 29, 7, 107, 95, 235, 761, 1205, 3125, 4791, 4645, 25623, 6463, 121887, 0 };
            const std::uint32_t dim12818JoeKuoD6Init[]   =   { 1, 3, 1, 1, 19, 19, 73, 189, 243, 669, 489, 1927, 1651, 11391, 30699, 64719, 60359, 0 };
            const std::uint32_t dim12819JoeKuoD6Init[]   =   { 1, 3, 7, 3, 29, 47, 7, 21, 299, 739, 1605, 749, 5755, 11579, 793, 36845, 14695, 0 };
            const std::uint32_t dim12820JoeKuoD6Init[]   =   { 1, 1, 5, 15, 17, 53, 107, 49, 103, 505, 1191, 2881, 7435, 7515, 24237, 5397, 47003, 0 };
            const std::uint32_t dim12821JoeKuoD6Init[]   =   { 1, 1, 7, 15, 25, 45, 121, 157, 313, 709, 1519, 2195, 5487, 1789, 32401, 4197, 9329, 0 };
            const std::uint32_t dim12822JoeKuoD6Init[]   =   { 1, 3, 3, 11, 21, 17, 77, 153, 275, 765, 1943, 3395, 5807, 12809, 29891, 42579, 75565, 0 };
            const std::uint32_t dim12823JoeKuoD6Init[]   =   { 1, 3, 5, 11, 11, 3, 63, 9, 223, 441, 1047, 441, 867, 3399, 15813, 13, 25293, 0 };
            const std::uint32_t dim12824JoeKuoD6Init[]   =   { 1, 1, 7, 1, 17, 25, 1, 7, 211, 117, 1417, 1057, 3369, 13211, 11437, 20877, 114867, 0 };
            const std::uint32_t dim12825JoeKuoD6Init[]   =   { 1, 1, 1, 15, 5, 41, 89, 165, 343, 447, 55, 1013, 8179, 12295, 18615, 23885, 46149, 0 };
            const std::uint32_t dim12826JoeKuoD6Init[]   =   { 1, 1, 5, 1, 15, 37, 109, 141, 323, 151, 1669, 1365, 3047, 13145, 30355, 12377, 102467, 0 };
            const std::uint32_t dim12827JoeKuoD6Init[]   =   { 1, 1, 3, 15, 15, 49, 83, 127, 285, 715, 981, 1153, 3019, 11071, 24229, 63807, 16315, 0 };
            const std::uint32_t dim12828JoeKuoD6Init[]   =   { 1, 1, 3, 1, 23, 35, 21, 179, 83, 929, 1033, 643, 3591, 10363, 7739, 259, 106879, 0 };
            const std::uint32_t dim12829JoeKuoD6Init[]   =   { 1, 1, 5, 7, 19, 9, 63, 241, 387, 851, 1709, 1161, 7469, 2093, 6169, 6085, 29851, 0 };
            const std::uint32_t dim12830JoeKuoD6Init[]   =   { 1, 3, 7, 5, 17, 59, 99, 87, 189, 853, 193, 1191, 5683, 15865, 27791, 55575, 13479, 0 };
            const std::uint32_t dim12831JoeKuoD6Init[]   =   { 1, 3, 3, 3, 25, 51, 81, 129, 365, 319, 179, 2863, 511, 14471, 3689, 59505, 80105, 0 };
            const std::uint32_t dim12832JoeKuoD6Init[]   =   { 1, 1, 1, 15, 5, 33, 69, 35, 429, 715, 1781, 783, 1089, 8969, 26987, 23519, 34227, 0 };
            const std::uint32_t dim12833JoeKuoD6Init[]   =   { 1, 3, 5, 9, 1, 51, 9, 121, 325, 945, 2025, 1985, 7337, 10837, 21299, 20591, 76905, 0 };
            const std::uint32_t dim12834JoeKuoD6Init[]   =   { 1, 3, 7, 3, 15, 51, 19, 109, 297, 491, 15, 1905, 1479, 1997, 18129, 43861, 84925, 0 };
            const std::uint32_t dim12835JoeKuoD6Init[]   =   { 1, 1, 3, 5, 7, 21, 1, 137, 207, 943, 1171, 2019, 6687, 10683, 20937, 34033, 43907, 0 };
            const std::uint32_t dim12836JoeKuoD6Init[]   =   { 1, 1, 1, 11, 25, 21, 47, 227, 247, 933, 471, 955, 4299, 5605, 18469, 62357, 98273, 0 };
            const std::uint32_t dim12837JoeKuoD6Init[]   =   { 1, 1, 5, 13, 21, 39, 41, 23, 493, 311, 1401, 537, 2919, 11519, 12597, 58321, 41401, 0 };
            const std::uint32_t dim12838JoeKuoD6Init[]   =   { 1, 1, 7, 5, 31, 55, 93, 151, 219, 765, 1247, 2775, 7167, 13413, 17071, 57969, 114069, 0 };
            const std::uint32_t dim12839JoeKuoD6Init[]   =   { 1, 3, 1, 15, 31, 41, 85, 161, 379, 337, 1639, 933, 3511, 925, 3523, 52379, 18421, 0 };
            const std::uint32_t dim12840JoeKuoD6Init[]   =   { 1, 3, 3, 11, 17, 17, 71, 11, 291, 305, 1295, 1175, 1803, 6247, 26523, 46467, 126999, 0 };
            const std::uint32_t dim12841JoeKuoD6Init[]   =   { 1, 1, 1, 13, 9, 43, 113, 7, 1, 443, 719, 3045, 2527, 5233, 13969, 50463, 115629, 0 };
            const std::uint32_t dim12842JoeKuoD6Init[]   =   { 1, 1, 1, 13, 9, 31, 87, 119, 351, 53, 985, 2017, 1187, 10429, 13719, 41383, 12749, 0 };
            const std::uint32_t dim12843JoeKuoD6Init[]   =   { 1, 1, 1, 15, 23, 17, 5, 215, 383, 299, 305, 3577, 7707, 6927, 28591, 44287, 65697, 0 };
            const std::uint32_t dim12844JoeKuoD6Init[]   =   { 1, 1, 5, 7, 23, 61, 89, 235, 97, 463, 237, 2117, 5503, 13693, 28231, 7745, 73631, 0 };
            const std::uint32_t dim12845JoeKuoD6Init[]   =   { 1, 3, 7, 3, 17, 43, 73, 245, 145, 267, 855, 187, 6167, 3999, 9935, 14347, 57727, 0 };
            const std::uint32_t dim12846JoeKuoD6Init[]   =   { 1, 1, 7, 3, 25, 47, 11, 221, 425, 527, 1341, 3973, 4635, 16321, 30021, 48547, 109409, 0 };
            const std::uint32_t dim12847JoeKuoD6Init[]   =   { 1, 3, 1, 13, 5, 11, 41, 191, 121, 219, 1315, 583, 2997, 5883, 31689, 64835, 35351, 0 };
            const std::uint32_t dim12848JoeKuoD6Init[]   =   { 1, 1, 3, 3, 15, 47, 49, 115, 107, 757, 329, 1653, 4633, 14605, 1579, 62413, 88685, 0 };
            const std::uint32_t dim12849JoeKuoD6Init[]   =   { 1, 1, 1, 5, 19, 47, 63, 131, 427, 335, 269, 3581, 7613, 15685, 16957, 30487, 94965, 0 };
            const std::uint32_t dim12850JoeKuoD6Init[]   =   { 1, 1, 3, 15, 31, 11, 77, 115, 467, 249, 247, 651, 3769, 3701, 21627, 36219, 77309, 0 };
            const std::uint32_t dim12851JoeKuoD6Init[]   =   { 1, 3, 1, 5, 5, 29, 45, 21, 37, 733, 1773, 2467, 2747, 9391, 5449, 23285, 20089, 0 };
            const std::uint32_t dim12852JoeKuoD6Init[]   =   { 1, 3, 5, 13, 29, 31, 51, 199, 77, 711, 1313, 3303, 2675, 177, 7915, 37129, 123641, 0 };
            const std::uint32_t dim12853JoeKuoD6Init[]   =   { 1, 3, 7, 15, 17, 17, 99, 43, 9, 699, 491, 669, 1313, 1377, 30015, 59261, 97321, 0 };
            const std::uint32_t dim12854JoeKuoD6Init[]   =   { 1, 3, 1, 13, 9, 13, 21, 199, 249, 775, 399, 897, 2205, 15357, 17281, 3193, 255, 0 };
            const std::uint32_t dim12855JoeKuoD6Init[]   =   { 1, 3, 1, 13, 7, 23, 7, 181, 65, 253, 199, 333, 6507, 4409, 13319, 30165, 95191, 0 };
            const std::uint32_t dim12856JoeKuoD6Init[]   =   { 1, 3, 3, 1, 31, 9, 31, 71, 301, 867, 1655, 2065, 597, 15247, 3019, 31763, 91889, 0 };
            const std::uint32_t dim12857JoeKuoD6Init[]   =   { 1, 3, 5, 5, 3, 35, 113, 133, 39, 1013, 991, 3521, 5805, 87, 32393, 28619, 34325, 0 };
            const std::uint32_t dim12858JoeKuoD6Init[]   =   { 1, 3, 1, 9, 15, 27, 45, 85, 61, 99, 1085, 3251, 7085, 4137, 27443, 42581, 94031, 0 };
            const std::uint32_t dim12859JoeKuoD6Init[]   =   { 1, 1, 5, 7, 11, 49, 97, 129, 339, 259, 821, 165, 833, 11383, 21629, 17473, 2947, 0 };
            const std::uint32_t dim12860JoeKuoD6Init[]   =   { 1, 3, 3, 3, 11, 7, 27, 231, 169, 847, 1767, 1823, 3855, 14277, 12457, 55825, 14377, 0 };
            const std::uint32_t dim12861JoeKuoD6Init[]   =   { 1, 1, 7, 3, 27, 5, 47, 193, 207, 747, 271, 3155, 1097, 2229, 4919, 22327, 12659, 0 };
            const std::uint32_t dim12862JoeKuoD6Init[]   =   { 1, 1, 5, 3, 27, 29, 105, 199, 31, 73, 1741, 2173, 4577, 3917, 31513, 45983, 118015, 0 };
            const std::uint32_t dim12863JoeKuoD6Init[]   =   { 1, 1, 3, 1, 19, 5, 23, 249, 35, 891, 1105, 1907, 5453, 1877, 1965, 3169, 107091, 0 };
            const std::uint32_t dim12864JoeKuoD6Init[]   =   { 1, 1, 7, 9, 11, 47, 57, 171, 255, 661, 1925, 2223, 525, 4775, 12327, 8067, 47083, 0 };
            const std::uint32_t dim12865JoeKuoD6Init[]   =   { 1, 3, 3, 11, 29, 43, 37, 33, 459, 117, 7, 1739, 3585, 7429, 2217, 9533, 95299, 0 };
            const std::uint32_t dim12866JoeKuoD6Init[]   =   { 1, 1, 5, 11, 23, 3, 33, 13, 45, 201, 467, 597, 4891, 2673, 32407, 56935, 121991, 0 };
            const std::uint32_t dim12867JoeKuoD6Init[]   =   { 1, 1, 7, 5, 29, 63, 7, 59, 417, 547, 17, 3701, 5775, 1079, 26527, 47187, 14827, 0 };
            const std::uint32_t dim12868JoeKuoD6Init[]   =   { 1, 1, 5, 3, 27, 11, 85, 129, 377, 497, 1659, 1965, 581, 15075, 31265, 195, 62307, 0 };
            const std::uint32_t dim12869JoeKuoD6Init[]   =   { 1, 1, 3, 9, 3, 57, 33, 57, 279, 955, 741, 955, 6501, 8069, 27305, 15363, 34715, 0 };
            const std::uint32_t dim12870JoeKuoD6Init[]   =   { 1, 3, 7, 13, 29, 23, 25, 171, 201, 529, 661, 4089, 5755, 12459, 31269, 9763, 53217, 0 };
            const std::uint32_t dim12871JoeKuoD6Init[]   =   { 1, 3, 7, 1, 3, 19, 27, 201, 261, 421, 1487, 2907, 547, 15791, 7661, 42871, 116343, 0 };
            const std::uint32_t dim12872JoeKuoD6Init[]   =   { 1, 3, 7, 9, 5, 59, 51, 91, 7, 399, 2001, 661, 6577, 7473, 5439, 29073, 3391, 0 };
            const std::uint32_t dim12873JoeKuoD6Init[]   =   { 1, 1, 7, 1, 23, 39, 119, 105, 113, 913, 1097, 2547, 8143, 11409, 23197, 59527, 55677, 0 };
            const std::uint32_t dim12874JoeKuoD6Init[]   =   { 1, 3, 3, 15, 31, 35, 103, 207, 247, 801, 1821, 1995, 4437, 12891, 659, 15687, 53, 0 };
            const std::uint32_t dim12875JoeKuoD6Init[]   =   { 1, 3, 3, 5, 13, 5, 45, 187, 231, 661, 1553, 2909, 3715, 4499, 14773, 5957, 24171, 0 };
            const std::uint32_t dim12876JoeKuoD6Init[]   =   { 1, 1, 1, 11, 3, 53, 93, 29, 379, 713, 299, 445, 2815, 9825, 30941, 22413, 91563, 0 };
            const std::uint32_t dim12877JoeKuoD6Init[]   =   { 1, 3, 1, 1, 27, 31, 111, 83, 349, 895, 1007, 2649, 7139, 5863, 27739, 53099, 6837, 0 };
            const std::uint32_t dim12878JoeKuoD6Init[]   =   { 1, 3, 1, 5, 23, 57, 121, 229, 487, 405, 2001, 2761, 3011, 2219, 10711, 31139, 83809, 0 };
            const std::uint32_t dim12879JoeKuoD6Init[]   =   { 1, 3, 7, 5, 13, 51, 37, 181, 359, 909, 2001, 793, 1143, 9219, 5111, 23021, 126081, 0 };
            const std::uint32_t dim12880JoeKuoD6Init[]   =   { 1, 3, 1, 13, 27, 27, 99, 25, 189, 129, 1831, 1005, 8119, 2557, 26985, 63447, 89693, 0 };
            const std::uint32_t dim12881JoeKuoD6Init[]   =   { 1, 1, 7, 5, 1, 21, 79, 33, 99, 7, 433, 1343, 3121, 3705, 477, 41191, 13749, 0 };
            const std::uint32_t dim12882JoeKuoD6Init[]   =   { 1, 1, 5, 5, 29, 53, 75, 243, 35, 461, 1399, 129, 177, 6533, 22209, 23503, 43819, 0 };
            const std::uint32_t dim12883JoeKuoD6Init[]   =   { 1, 3, 7, 7, 31, 37, 109, 9, 255, 263, 35, 3451, 7629, 9849, 10387, 3165, 120623, 0 };
            const std::uint32_t dim12884JoeKuoD6Init[]   =   { 1, 3, 5, 3, 27, 53, 93, 111, 239, 723, 293, 1481, 4427, 13623, 1989, 47705, 122069, 0 };
            const std::uint32_t dim12885JoeKuoD6Init[]   =   { 1, 3, 7, 7, 31, 37, 37, 213, 191, 627, 1821, 3621, 2875, 15759, 17525, 50969, 35311, 0 };
            const std::uint32_t dim12886JoeKuoD6Init[]   =   { 1, 3, 5, 5, 11, 41, 87, 233, 79, 251, 25, 1385, 3527, 7853, 5541, 36519, 42779, 0 };
            const std::uint32_t dim12887JoeKuoD6Init[]   =   { 1, 3, 1, 5, 9, 1, 117, 11, 61, 879, 553, 383, 6237, 15207, 3057, 28051, 59149, 0 };
            const std::uint32_t dim12888JoeKuoD6Init[]   =   { 1, 1, 1, 15, 15, 7, 37, 133, 81, 815, 893, 2281, 2459, 15325, 20107, 2289, 34535, 0 };
            const std::uint32_t dim12889JoeKuoD6Init[]   =   { 1, 1, 5, 11, 17, 3, 45, 159, 409, 643, 969, 1289, 4353, 10465, 16233, 55561, 111667, 0 };
            const std::uint32_t dim12890JoeKuoD6Init[]   =   { 1, 1, 5, 13, 23, 1, 79, 127, 485, 1013, 629, 791, 853, 9247, 26333, 1123, 17313, 0 };
            const std::uint32_t dim12891JoeKuoD6Init[]   =   { 1, 1, 5, 11, 27, 17, 97, 157, 479, 421, 1739, 3257, 2419, 6673, 2759, 19399, 120305, 0 };
            const std::uint32_t dim12892JoeKuoD6Init[]   =   { 1, 3, 5, 1, 3, 43, 71, 55, 111, 949, 1957, 3777, 3409, 8229, 26585, 49221, 33639, 0 };
            const std::uint32_t dim12893JoeKuoD6Init[]   =   { 1, 3, 7, 9, 17, 45, 71, 71, 417, 1007, 213, 1069, 2693, 5065, 23489, 33363, 120459, 0 };
            const std::uint32_t dim12894JoeKuoD6Init[]   =   { 1, 1, 1, 1, 25, 47, 81, 251, 341, 101, 1941, 1133, 3205, 4141, 26561, 56095, 37193, 0 };
            const std::uint32_t dim12895JoeKuoD6Init[]   =   { 1, 1, 3, 7, 25, 45, 97, 95, 135, 871, 949, 3489, 7593, 10717, 26163, 12711, 76989, 0 };
            const std::uint32_t dim12896JoeKuoD6Init[]   =   { 1, 3, 1, 9, 3, 11, 35, 7, 471, 509, 1335, 385, 1297, 11201, 28553, 51609, 45351, 0 };
            const std::uint32_t dim12897JoeKuoD6Init[]   =   { 1, 1, 5, 11, 21, 23, 105, 31, 125, 5, 1721, 1503, 7807, 13093, 24873, 18467, 30183, 0 };
            const std::uint32_t dim12898JoeKuoD6Init[]   =   { 1, 3, 7, 15, 15, 57, 61, 213, 79, 655, 517, 1031, 6719, 4807, 12805, 2605, 35407, 0 };
            const std::uint32_t dim12899JoeKuoD6Init[]   =   { 1, 1, 3, 15, 21, 5, 93, 61, 103, 945, 935, 115, 1281, 7735, 20723, 37211, 50039, 0 };
            const std::uint32_t dim12900JoeKuoD6Init[]   =   { 1, 3, 3, 15, 19, 51, 79, 187, 127, 205, 121, 701, 6065, 15185, 29343, 58249, 25331, 0 };
            const std::uint32_t dim12901JoeKuoD6Init[]   =   { 1, 3, 3, 15, 17, 49, 23, 163, 201, 809, 1203, 687, 1777, 695, 18779, 31571, 118383, 0 };
            const std::uint32_t dim12902JoeKuoD6Init[]   =   { 1, 1, 1, 5, 25, 45, 121, 223, 233, 193, 1459, 1889, 5537, 4421, 13659, 4591, 112563, 0 };
            const std::uint32_t dim12903JoeKuoD6Init[]   =   { 1, 3, 5, 3, 31, 37, 109, 15, 381, 373, 993, 3633, 641, 4411, 32265, 46481, 49195, 0 };
            const std::uint32_t dim12904JoeKuoD6Init[]   =   { 1, 3, 3, 11, 19, 21, 39, 67, 447, 829, 1163, 55, 2153, 15045, 6643, 48235, 59261, 0 };
            const std::uint32_t dim12905JoeKuoD6Init[]   =   { 1, 3, 3, 1, 7, 63, 37, 71, 35, 601, 1719, 447, 8009, 7235, 13225, 44103, 82409, 0 };
            const std::uint32_t dim12906JoeKuoD6Init[]   =   { 1, 3, 3, 7, 13, 33, 69, 115, 207, 807, 109, 2989, 3727, 9017, 29095, 11377, 122401, 0 };
            const std::uint32_t dim12907JoeKuoD6Init[]   =   { 1, 1, 3, 15, 9, 9, 57, 197, 115, 73, 1277, 1727, 5275, 11897, 12157, 34763, 58273, 0 };
            const std::uint32_t dim12908JoeKuoD6Init[]   =   { 1, 1, 3, 15, 19, 19, 127, 105, 289, 663, 877, 1303, 4901, 8897, 4803, 36853, 93361, 0 };
            const std::uint32_t dim12909JoeKuoD6Init[]   =   { 1, 1, 3, 7, 23, 29, 121, 29, 439, 795, 1469, 523, 7767, 12061, 15613, 57343, 21291, 0 };
            const std::uint32_t dim12910JoeKuoD6Init[]   =   { 1, 1, 1, 9, 25, 29, 15, 165, 383, 233, 91, 2065, 2741, 7809, 5325, 48581, 65551, 0 };
            const std::uint32_t dim12911JoeKuoD6Init[]   =   { 1, 1, 5, 15, 29, 19, 103, 143, 283, 597, 1055, 3525, 6115, 11083, 22497, 42893, 86849, 0 };
            const std::uint32_t dim12912JoeKuoD6Init[]   =   { 1, 1, 1, 15, 13, 43, 75, 157, 267, 519, 1231, 929, 1585, 16137, 1045, 4353, 63473, 0 };
            const std::uint32_t dim12913JoeKuoD6Init[]   =   { 1, 1, 1, 9, 17, 25, 73, 227, 145, 921, 1845, 2057, 3099, 15523, 8993, 14135, 37811, 0 };
            const std::uint32_t dim12914JoeKuoD6Init[]   =   { 1, 3, 3, 15, 17, 57, 107, 215, 271, 841, 1543, 2803, 625, 15359, 13341, 36879, 83191, 0 };
            const std::uint32_t dim12915JoeKuoD6Init[]   =   { 1, 3, 5, 13, 3, 17, 127, 81, 193, 253, 71, 3205, 1157, 1313, 27341, 49657, 96539, 0 };
            const std::uint32_t dim12916JoeKuoD6Init[]   =   { 1, 3, 1, 5, 27, 43, 1, 111, 23, 963, 1853, 925, 7401, 13999, 29797, 47125, 59955, 0 };
            const std::uint32_t dim12917JoeKuoD6Init[]   =   { 1, 3, 3, 1, 31, 55, 107, 121, 37, 159, 61, 577, 5711, 6745, 20077, 42333, 37105, 0 };
            const std::uint32_t dim12918JoeKuoD6Init[]   =   { 1, 1, 5, 3, 31, 11, 1, 7, 295, 515, 203, 707, 2919, 9619, 8877, 45143, 101861, 0 };
            const std::uint32_t dim12919JoeKuoD6Init[]   =   { 1, 3, 7, 11, 5, 23, 71, 9, 99, 947, 1141, 1651, 1903, 13607, 15433, 55005, 127639, 0 };
            const std::uint32_t dim12920JoeKuoD6Init[]   =   { 1, 1, 7, 3, 13, 61, 25, 111, 239, 243, 1069, 3551, 3339, 743, 29921, 21313, 54953, 0 };
            const std::uint32_t dim12921JoeKuoD6Init[]   =   { 1, 1, 3, 3, 23, 7, 21, 47, 367, 871, 1647, 2183, 2615, 2257, 30447, 25761, 110221, 0 };
            const std::uint32_t dim12922JoeKuoD6Init[]   =   { 1, 3, 7, 15, 13, 51, 115, 19, 277, 463, 475, 3467, 7313, 2477, 10841, 13585, 61449, 0 };
            const std::uint32_t dim12923JoeKuoD6Init[]   =   { 1, 1, 7, 9, 1, 27, 111, 209, 391, 621, 1047, 549, 2013, 549, 24213, 6369, 68691, 0 };
            const std::uint32_t dim12924JoeKuoD6Init[]   =   { 1, 1, 1, 11, 19, 59, 11, 107, 79, 1013, 357, 1729, 889, 12823, 6537, 35717, 42761, 0 };
            const std::uint32_t dim12925JoeKuoD6Init[]   =   { 1, 1, 3, 15, 29, 41, 49, 177, 309, 293, 1035, 1481, 1395, 2009, 7917, 365, 28981, 0 };
            const std::uint32_t dim12926JoeKuoD6Init[]   =   { 1, 3, 7, 11, 31, 19, 51, 113, 479, 347, 353, 929, 1089, 3373, 2807, 55201, 23137, 0 };
            const std::uint32_t dim12927JoeKuoD6Init[]   =   { 1, 3, 1, 15, 7, 55, 79, 191, 267, 701, 1885, 1241, 7085, 9835, 24239, 7609, 13967, 0 };
            const std::uint32_t dim12928JoeKuoD6Init[]   =   { 1, 1, 3, 15, 25, 33, 69, 5, 93, 375, 435, 2401, 1591, 8173, 17293, 20281, 63809, 0 };
            const std::uint32_t dim12929JoeKuoD6Init[]   =   { 1, 3, 5, 3, 9, 49, 63, 47, 217, 773, 1241, 1131, 7521, 15607, 24341, 20353, 122801, 0 };
            const std::uint32_t dim12930JoeKuoD6Init[]   =   { 1, 3, 7, 15, 21, 1, 57, 159, 279, 987, 1641, 3883, 1659, 7875, 24857, 33273, 88933, 0 };
            const std::uint32_t dim12931JoeKuoD6Init[]   =   { 1, 1, 3, 11, 3, 23, 45, 31, 279, 643, 1285, 471, 137, 15871, 13927, 52361, 118901, 0 };
            const std::uint32_t dim12932JoeKuoD6Init[]   =   { 1, 3, 1, 15, 27, 51, 83, 19, 299, 213, 1001, 897, 2751, 13085, 20841, 24891, 113173, 0 };
            const std::uint32_t dim12933JoeKuoD6Init[]   =   { 1, 1, 7, 5, 5, 27, 77, 77, 165, 489, 359, 1607, 3903, 16241, 641, 25999, 29279, 0 };
            const std::uint32_t dim12934JoeKuoD6Init[]   =   { 1, 3, 3, 7, 15, 23, 103, 49, 259, 519, 641, 1577, 3713, 12181, 287, 29483, 58505, 0 };
            const std::uint32_t dim12935JoeKuoD6Init[]   =   { 1, 1, 7, 13, 11, 29, 125, 45, 45, 167, 261, 2735, 2421, 15457, 5965, 44005, 82141, 0 };
            const std::uint32_t dim12936JoeKuoD6Init[]   =   { 1, 1, 3, 9, 25, 21, 9, 3, 57, 1017, 1359, 79, 6789, 7805, 20683, 25695, 38893, 0 };
            const std::uint32_t dim12937JoeKuoD6Init[]   =   { 1, 1, 7, 1, 29, 53, 87, 171, 51, 5, 9, 3033, 787, 10611, 15913, 35703, 70459, 0 };
            const std::uint32_t dim12938JoeKuoD6Init[]   =   { 1, 1, 3, 5, 1, 33, 111, 139, 477, 33, 1287, 3615, 5235, 15491, 2915, 47821, 55257, 0 };
            const std::uint32_t dim12939JoeKuoD6Init[]   =   { 1, 1, 1, 13, 5, 23, 55, 225, 303, 587, 1595, 307, 3809, 8093, 13297, 63213, 104317, 0 };
            const std::uint32_t dim12940JoeKuoD6Init[]   =   { 1, 1, 3, 15, 31, 29, 13, 33, 267, 481, 1039, 3805, 2549, 861, 12483, 61829, 127725, 0 };
            const std::uint32_t dim12941JoeKuoD6Init[]   =   { 1, 3, 5, 11, 23, 17, 23, 117, 333, 167, 1965, 1387, 5453, 15545, 123, 12991, 36281, 0 };
            const std::uint32_t dim12942JoeKuoD6Init[]   =   { 1, 3, 5, 1, 3, 9, 25, 55, 497, 951, 1377, 993, 6089, 4801, 32719, 31579, 126663, 0 };
            const std::uint32_t dim12943JoeKuoD6Init[]   =   { 1, 3, 5, 11, 15, 37, 103, 51, 509, 585, 769, 425, 835, 14027, 30265, 55735, 36655, 0 };
            const std::uint32_t dim12944JoeKuoD6Init[]   =   { 1, 1, 1, 13, 9, 49, 105, 61, 493, 3, 1663, 815, 8105, 16361, 32477, 30437, 61519, 0 };
            const std::uint32_t dim12945JoeKuoD6Init[]   =   { 1, 3, 7, 11, 29, 23, 105, 87, 119, 399, 1405, 1515, 7017, 12729, 13769, 29741, 30921, 0 };
            const std::uint32_t dim12946JoeKuoD6Init[]   =   { 1, 3, 7, 13, 13, 7, 93, 227, 489, 843, 923, 3373, 759, 5105, 9059, 21079, 101335, 0 };
            const std::uint32_t dim12947JoeKuoD6Init[]   =   { 1, 1, 1, 1, 29, 53, 119, 227, 171, 363, 289, 827, 425, 12827, 25791, 21587, 109567, 0 };
            const std::uint32_t dim12948JoeKuoD6Init[]   =   { 1, 1, 5, 11, 29, 29, 53, 127, 441, 219, 1049, 275, 525, 5535, 20907, 9299, 76319, 0 };
            const std::uint32_t dim12949JoeKuoD6Init[]   =   { 1, 3, 7, 15, 3, 53, 109, 61, 275, 391, 1147, 2953, 1439, 4417, 679, 10949, 35101, 0 };
            const std::uint32_t dim12950JoeKuoD6Init[]   =   { 1, 1, 5, 13, 9, 1, 109, 137, 249, 835, 721, 129, 2883, 13043, 31827, 36741, 107167, 0 };
            const std::uint32_t dim12951JoeKuoD6Init[]   =   { 1, 1, 5, 9, 27, 17, 117, 121, 111, 433, 743, 1987, 6839, 8439, 2533, 62135, 54281, 0 };
            const std::uint32_t dim12952JoeKuoD6Init[]   =   { 1, 3, 5, 15, 11, 61, 117, 103, 409, 485, 1047, 469, 2245, 7193, 2541, 9399, 88127, 0 };
            const std::uint32_t dim12953JoeKuoD6Init[]   =   { 1, 3, 1, 9, 3, 49, 111, 201, 87, 181, 1243, 3261, 1827, 10385, 13045, 58331, 107729, 0 };
            const std::uint32_t dim12954JoeKuoD6Init[]   =   { 1, 3, 5, 15, 13, 29, 61, 223, 227, 733, 1757, 755, 4231, 13537, 1509, 54623, 120221, 0 };
            const std::uint32_t dim12955JoeKuoD6Init[]   =   { 1, 1, 1, 15, 13, 9, 7, 233, 391, 689, 355, 1203, 5811, 7759, 2647, 54949, 51891, 0 };
            const std::uint32_t dim12956JoeKuoD6Init[]   =   { 1, 1, 3, 1, 3, 27, 95, 51, 497, 315, 915, 1055, 2917, 167, 1849, 26591, 102729, 0 };
            const std::uint32_t dim12957JoeKuoD6Init[]   =   { 1, 3, 7, 13, 1, 51, 3, 113, 437, 449, 1889, 2887, 4735, 5693, 8191, 12847, 52651, 0 };
            const std::uint32_t dim12958JoeKuoD6Init[]   =   { 1, 1, 7, 13, 1, 45, 41, 221, 403, 185, 1653, 1809, 6405, 9193, 1381, 36677, 43255, 0 };
            const std::uint32_t dim12959JoeKuoD6Init[]   =   { 1, 1, 5, 1, 25, 51, 109, 245, 291, 809, 1381, 3235, 5933, 10185, 18663, 15589, 39539, 0 };
            const std::uint32_t dim12960JoeKuoD6Init[]   =   { 1, 3, 3, 1, 27, 29, 3, 227, 275, 705, 489, 681, 323, 7453, 26005, 13791, 115219, 0 };
            const std::uint32_t dim12961JoeKuoD6Init[]   =   { 1, 3, 5, 1, 3, 51, 101, 75, 157, 529, 45, 3105, 3617, 13081, 21665, 50065, 117823, 0 };
            const std::uint32_t dim12962JoeKuoD6Init[]   =   { 1, 3, 5, 15, 9, 43, 41, 169, 391, 455, 1375, 253, 1257, 14427, 16325, 11571, 26361, 0 };
            const std::uint32_t dim12963JoeKuoD6Init[]   =   { 1, 1, 5, 7, 5, 41, 81, 173, 275, 225, 301, 335, 5473, 1509, 20897, 21951, 103967, 0 };
            const std::uint32_t dim12964JoeKuoD6Init[]   =   { 1, 3, 5, 1, 13, 27, 107, 19, 221, 609, 823, 1193, 665, 4947, 11967, 57373, 21665, 0 };
            const std::uint32_t dim12965JoeKuoD6Init[]   =   { 1, 3, 7, 13, 7, 11, 109, 59, 193, 103, 943, 595, 5121, 6159, 2103, 52863, 57541, 0 };
            const std::uint32_t dim12966JoeKuoD6Init[]   =   { 1, 3, 5, 3, 5, 51, 85, 227, 465, 1013, 601, 1687, 7615, 5991, 8635, 64487, 69967, 0 };
            const std::uint32_t dim12967JoeKuoD6Init[]   =   { 1, 3, 1, 11, 29, 49, 79, 25, 447, 119, 569, 383, 5261, 6209, 21965, 40863, 96593, 0 };
            const std::uint32_t dim12968JoeKuoD6Init[]   =   { 1, 1, 3, 13, 9, 49, 59, 93, 369, 789, 1373, 425, 3565, 13357, 17783, 46435, 129653, 0 };
            const std::uint32_t dim12969JoeKuoD6Init[]   =   { 1, 3, 7, 5, 5, 39, 51, 15, 421, 531, 1855, 2105, 5335, 8509, 20841, 44997, 48235, 0 };
            const std::uint32_t dim12970JoeKuoD6Init[]   =   { 1, 3, 7, 3, 27, 47, 113, 1, 453, 565, 1843, 243, 7663, 10697, 7725, 24485, 49435, 0 };
            const std::uint32_t dim12971JoeKuoD6Init[]   =   { 1, 1, 1, 11, 25, 25, 47, 1, 475, 831, 1833, 391, 5173, 14873, 14263, 36061, 26781, 0 };
            const std::uint32_t dim12972JoeKuoD6Init[]   =   { 1, 1, 7, 15, 21, 13, 5, 169, 241, 235, 547, 1565, 2053, 6877, 12811, 22213, 106907, 0 };
            const std::uint32_t dim12973JoeKuoD6Init[]   =   { 1, 3, 7, 1, 21, 11, 101, 115, 243, 985, 1389, 2189, 563, 12453, 14951, 58889, 48079, 0 };
            const std::uint32_t dim12974JoeKuoD6Init[]   =   { 1, 1, 5, 7, 9, 37, 33, 241, 337, 453, 1955, 1731, 4445, 8887, 27715, 63975, 95891, 0 };
            const std::uint32_t dim12975JoeKuoD6Init[]   =   { 1, 1, 5, 1, 23, 21, 95, 237, 241, 991, 1159, 2417, 2279, 8941, 20987, 39773, 79327, 0 };
            const std::uint32_t dim12976JoeKuoD6Init[]   =   { 1, 3, 3, 1, 19, 39, 73, 253, 137, 1009, 1793, 4007, 2017, 7503, 16689, 29013, 41571, 0 };
            const std::uint32_t dim12977JoeKuoD6Init[]   =   { 1, 3, 7, 15, 3, 63, 77, 11, 293, 495, 339, 3525, 5747, 1807, 11705, 55807, 54163, 0 };
            const std::uint32_t dim12978JoeKuoD6Init[]   =   { 1, 3, 7, 3, 25, 41, 127, 23, 113, 807, 387, 3529, 2173, 11217, 21257, 61169, 47749, 0 };
            const std::uint32_t dim12979JoeKuoD6Init[]   =   { 1, 3, 3, 5, 27, 5, 43, 55, 207, 995, 811, 1473, 481, 4317, 2015, 49161, 94711, 0 };
            const std::uint32_t dim12980JoeKuoD6Init[]   =   { 1, 3, 1, 9, 21, 61, 41, 147, 425, 353, 1943, 2455, 379, 10729, 3045, 16013, 44527, 0 };
            const std::uint32_t dim12981JoeKuoD6Init[]   =   { 1, 3, 1, 5, 17, 43, 109, 231, 313, 277, 939, 3491, 5883, 2297, 4763, 33403, 62395, 0 };
            const std::uint32_t dim12982JoeKuoD6Init[]   =   { 1, 1, 3, 9, 1, 49, 37, 145, 383, 467, 621, 2873, 873, 6163, 16475, 49045, 115599, 0 };
            const std::uint32_t dim12983JoeKuoD6Init[]   =   { 1, 1, 1, 9, 5, 15, 125, 157, 459, 727, 807, 2769, 5531, 11531, 4277, 42301, 16969, 0 };
            const std::uint32_t dim12984JoeKuoD6Init[]   =   { 1, 1, 3, 1, 15, 23, 39, 121, 163, 537, 409, 1217, 8007, 5671, 19681, 25371, 69227, 0 };
            const std::uint32_t dim12985JoeKuoD6Init[]   =   { 1, 3, 7, 9, 23, 1, 93, 41, 267, 995, 1917, 3441, 6237, 7233, 30215, 31945, 33967, 0 };
            const std::uint32_t dim12986JoeKuoD6Init[]   =   { 1, 1, 1, 15, 7, 5, 123, 53, 359, 677, 1061, 1649, 651, 14079, 30211, 14827, 123175, 0 };
            const std::uint32_t dim12987JoeKuoD6Init[]   =   { 1, 3, 1, 5, 11, 19, 121, 135, 167, 293, 493, 949, 5459, 11785, 21445, 57161, 129737, 0 };
            const std::uint32_t dim12988JoeKuoD6Init[]   =   { 1, 1, 3, 13, 19, 39, 43, 55, 149, 549, 479, 925, 341, 1151, 12007, 23473, 10671, 0 };
            const std::uint32_t dim12989JoeKuoD6Init[]   =   { 1, 3, 5, 9, 7, 41, 37, 103, 381, 373, 1767, 3959, 3001, 7903, 24033, 55123, 93627, 0 };
            const std::uint32_t dim12990JoeKuoD6Init[]   =   { 1, 3, 3, 3, 31, 27, 93, 175, 393, 575, 703, 3715, 6043, 11763, 7613, 15907, 56821, 0 };
            const std::uint32_t dim12991JoeKuoD6Init[]   =   { 1, 3, 3, 13, 3, 13, 75, 85, 89, 851, 1171, 3075, 5265, 10293, 14745, 32153, 89877, 0 };
            const std::uint32_t dim12992JoeKuoD6Init[]   =   { 1, 1, 7, 11, 1, 25, 101, 149, 187, 197, 1485, 1555, 1599, 7413, 23275, 27093, 73483, 0 };
            const std::uint32_t dim12993JoeKuoD6Init[]   =   { 1, 3, 1, 1, 19, 15, 63, 111, 211, 197, 77, 1683, 3159, 235, 32601, 35715, 59537, 0 };
            const std::uint32_t dim12994JoeKuoD6Init[]   =   { 1, 3, 5, 11, 23, 61, 91, 135, 403, 669, 267, 2507, 2931, 7813, 5047, 40027, 111705, 0 };
            const std::uint32_t dim12995JoeKuoD6Init[]   =   { 1, 1, 5, 13, 7, 5, 65, 37, 87, 405, 335, 1095, 3717, 1717, 31551, 28181, 47407, 0 };
            const std::uint32_t dim12996JoeKuoD6Init[]   =   { 1, 1, 5, 13, 3, 43, 67, 99, 507, 861, 1063, 3003, 6095, 11079, 6919, 41597, 97709, 0 };
            const std::uint32_t dim12997JoeKuoD6Init[]   =   { 1, 1, 3, 1, 7, 23, 109, 161, 321, 499, 549, 363, 2061, 6519, 1531, 1969, 83845, 0 };
            const std::uint32_t dim12998JoeKuoD6Init[]   =   { 1, 3, 7, 5, 17, 39, 55, 59, 455, 433, 601, 365, 7987, 2207, 3463, 31755, 94203, 0 };
            const std::uint32_t dim12999JoeKuoD6Init[]   =   { 1, 3, 5, 5, 29, 61, 79, 101, 125, 1011, 867, 2935, 3269, 13601, 21935, 50355, 65883, 0 };
            const std::uint32_t dim13000JoeKuoD6Init[]   =   { 1, 1, 1, 5, 3, 41, 101, 107, 299, 125, 81, 2421, 2937, 787, 19479, 25803, 74473, 0 };
            const std::uint32_t dim13001JoeKuoD6Init[]   =   { 1, 3, 3, 1, 3, 15, 73, 13, 167, 387, 75, 601, 415, 6927, 32277, 16709, 12477, 0 };
            const std::uint32_t dim13002JoeKuoD6Init[]   =   { 1, 1, 5, 1, 19, 37, 53, 45, 139, 737, 159, 2299, 6219, 11613, 22873, 18303, 56875, 0 };
            const std::uint32_t dim13003JoeKuoD6Init[]   =   { 1, 1, 3, 9, 23, 15, 17, 37, 373, 445, 1369, 2997, 49, 13901, 13155, 37375, 29063, 0 };
            const std::uint32_t dim13004JoeKuoD6Init[]   =   { 1, 3, 3, 11, 17, 1, 45, 91, 445, 631, 1297, 1907, 3765, 13893, 29379, 17939, 36573, 0 };
            const std::uint32_t dim13005JoeKuoD6Init[]   =   { 1, 1, 7, 13, 11, 31, 101, 165, 413, 305, 361, 4019, 3183, 2321, 7819, 49275, 101041, 0 };
            const std::uint32_t dim13006JoeKuoD6Init[]   =   { 1, 1, 7, 1, 13, 43, 125, 165, 357, 293, 1343, 2219, 4189, 6095, 28509, 27763, 53871, 0 };
            const std::uint32_t dim13007JoeKuoD6Init[]   =   { 1, 3, 3, 11, 29, 33, 105, 71, 297, 637, 1493, 3797, 5525, 15093, 21647, 57647, 1467, 0 };
            const std::uint32_t dim13008JoeKuoD6Init[]   =   { 1, 1, 1, 13, 19, 7, 5, 141, 71, 221, 923, 1039, 4777, 9481, 1267, 55345, 116061, 0 };
            const std::uint32_t dim13009JoeKuoD6Init[]   =   { 1, 1, 7, 11, 19, 43, 57, 243, 21, 217, 1075, 569, 3735, 10477, 18595, 34133, 70391, 0 };
            const std::uint32_t dim13010JoeKuoD6Init[]   =   { 1, 3, 3, 1, 21, 61, 7, 135, 401, 101, 321, 2959, 7371, 3303, 23023, 28163, 19833, 0 };
            const std::uint32_t dim13011JoeKuoD6Init[]   =   { 1, 1, 3, 9, 31, 43, 27, 243, 297, 145, 663, 3951, 4283, 10421, 9355, 30381, 68317, 0 };
            const std::uint32_t dim13012JoeKuoD6Init[]   =   { 1, 3, 7, 13, 29, 53, 101, 253, 49, 129, 831, 513, 5567, 5063, 157, 6465, 90983, 0 };
            const std::uint32_t dim13013JoeKuoD6Init[]   =   { 1, 1, 5, 15, 27, 29, 3, 231, 503, 173, 913, 3971, 7685, 9679, 32243, 967, 73195, 0 };
            const std::uint32_t dim13014JoeKuoD6Init[]   =   { 1, 1, 1, 15, 19, 55, 127, 3, 405, 239, 1063, 3473, 7543, 4049, 14509, 22657, 5611, 0 };
            const std::uint32_t dim13015JoeKuoD6Init[]   =   { 1, 3, 7, 1, 21, 39, 61, 249, 421, 401, 1667, 1981, 5503, 9191, 24027, 35049, 12199, 0 };
            const std::uint32_t dim13016JoeKuoD6Init[]   =   { 1, 3, 5, 5, 27, 1, 99, 83, 287, 997, 721, 1345, 2197, 6335, 4245, 42575, 102635, 0 };
            const std::uint32_t dim13017JoeKuoD6Init[]   =   { 1, 3, 3, 1, 31, 7, 103, 107, 387, 273, 951, 2475, 1275, 15607, 2159, 55083, 86107, 0 };
            const std::uint32_t dim13018JoeKuoD6Init[]   =   { 1, 3, 3, 5, 21, 59, 69, 55, 121, 601, 5, 1871, 7161, 4583, 23867, 7933, 3125, 0 };
            const std::uint32_t dim13019JoeKuoD6Init[]   =   { 1, 1, 1, 15, 17, 41, 51, 45, 383, 579, 713, 275, 1395, 11665, 30521, 11683, 126493, 0 };
            const std::uint32_t dim13020JoeKuoD6Init[]   =   { 1, 1, 1, 15, 17, 47, 15, 139, 175, 283, 1377, 827, 5753, 8855, 26437, 59219, 105601, 0 };
            const std::uint32_t dim13021JoeKuoD6Init[]   =   { 1, 1, 7, 11, 13, 3, 27, 141, 137, 851, 767, 2575, 7685, 11719, 24401, 52547, 127299, 0 };
            const std::uint32_t dim13022JoeKuoD6Init[]   =   { 1, 3, 3, 9, 11, 41, 75, 69, 167, 897, 1213, 3723, 6773, 12141, 28033, 19695, 128545, 0 };
            const std::uint32_t dim13023JoeKuoD6Init[]   =   { 1, 1, 5, 13, 7, 61, 55, 131, 465, 169, 1669, 711, 5901, 10769, 11273, 23809, 63625, 0 };
            const std::uint32_t dim13024JoeKuoD6Init[]   =   { 1, 1, 5, 1, 27, 25, 35, 167, 83, 921, 251, 2571, 6723, 14767, 26715, 21699, 60779, 0 };
            const std::uint32_t dim13025JoeKuoD6Init[]   =   { 1, 3, 1, 9, 15, 5, 59, 241, 405, 323, 1917, 1161, 6079, 13443, 13079, 58617, 63381, 0 };
            const std::uint32_t dim13026JoeKuoD6Init[]   =   { 1, 3, 1, 5, 9, 5, 79, 123, 87, 395, 667, 2787, 3711, 3613, 1803, 17885, 78975, 0 };
            const std::uint32_t dim13027JoeKuoD6Init[]   =   { 1, 3, 3, 5, 17, 45, 61, 107, 485, 163, 33, 1491, 7131, 59, 27327, 8043, 14907, 0 };
            const std::uint32_t dim13028JoeKuoD6Init[]   =   { 1, 3, 1, 11, 27, 37, 5, 251, 115, 339, 1621, 2013, 3517, 2213, 10145, 47121, 84485, 0 };
            const std::uint32_t dim13029JoeKuoD6Init[]   =   { 1, 3, 3, 1, 9, 11, 71, 25, 363, 867, 1485, 3897, 3339, 7599, 20777, 52009, 127097, 0 };
            const std::uint32_t dim13030JoeKuoD6Init[]   =   { 1, 1, 3, 9, 25, 37, 29, 231, 183, 315, 399, 879, 6169, 6355, 3729, 9187, 19405, 0 };
            const std::uint32_t dim13031JoeKuoD6Init[]   =   { 1, 3, 5, 3, 31, 37, 127, 71, 171, 687, 1237, 151, 7391, 2395, 11979, 23381, 117879, 0 };
            const std::uint32_t dim13032JoeKuoD6Init[]   =   { 1, 1, 1, 13, 13, 43, 71, 235, 131, 79, 1321, 235, 2221, 1133, 13509, 12205, 44771, 0 };
            const std::uint32_t dim13033JoeKuoD6Init[]   =   { 1, 3, 7, 5, 29, 51, 125, 191, 153, 35, 1657, 2141, 3701, 7177, 31723, 15189, 55441, 0 };
            const std::uint32_t dim13034JoeKuoD6Init[]   =   { 1, 1, 5, 1, 5, 35, 13, 165, 461, 255, 1825, 1531, 6195, 7717, 973, 12367, 71747, 0 };
            const std::uint32_t dim13035JoeKuoD6Init[]   =   { 1, 3, 1, 9, 13, 57, 25, 83, 389, 405, 227, 1037, 3805, 15653, 25365, 47991, 54315, 0 };
            const std::uint32_t dim13036JoeKuoD6Init[]   =   { 1, 1, 1, 13, 17, 55, 113, 151, 145, 951, 1849, 2205, 6513, 7845, 7947, 59429, 44911, 0 };
            const std::uint32_t dim13037JoeKuoD6Init[]   =   { 1, 3, 5, 3, 25, 9, 99, 159, 183, 445, 153, 3053, 2537, 1787, 19029, 60047, 128203, 0 };
            const std::uint32_t dim13038JoeKuoD6Init[]   =   { 1, 1, 5, 5, 31, 37, 13, 11, 271, 491, 1141, 1827, 3751, 9471, 7579, 35969, 95245, 0 };
            const std::uint32_t dim13039JoeKuoD6Init[]   =   { 1, 3, 3, 15, 1, 43, 9, 109, 13, 991, 345, 1577, 947, 3197, 16747, 8127, 116937, 0 };
            const std::uint32_t dim13040JoeKuoD6Init[]   =   { 1, 3, 3, 15, 11, 17, 103, 89, 33, 741, 1855, 2879, 3899, 9535, 15119, 56165, 86055, 0 };
            const std::uint32_t dim13041JoeKuoD6Init[]   =   { 1, 3, 5, 1, 31, 41, 57, 205, 69, 163, 1383, 2087, 6483, 6281, 32079, 40825, 28709, 0 };
            const std::uint32_t dim13042JoeKuoD6Init[]   =   { 1, 1, 1, 13, 23, 57, 103, 247, 421, 773, 1733, 3249, 6681, 9675, 11669, 51673, 86189, 0 };
            const std::uint32_t dim13043JoeKuoD6Init[]   =   { 1, 1, 5, 15, 7, 37, 63, 123, 77, 941, 277, 1061, 803, 2135, 15745, 47413, 73843, 0 };
            const std::uint32_t dim13044JoeKuoD6Init[]   =   { 1, 1, 3, 5, 19, 15, 35, 59, 321, 527, 1669, 2929, 513, 4453, 20521, 19781, 115501, 0 };
            const std::uint32_t dim13045JoeKuoD6Init[]   =   { 1, 1, 7, 3, 23, 1, 99, 251, 129, 271, 1555, 1191, 2445, 11533, 11921, 19131, 80653, 0 };
            const std::uint32_t dim13046JoeKuoD6Init[]   =   { 1, 1, 7, 15, 15, 33, 79, 89, 113, 517, 1655, 43, 6255, 15415, 19559, 63309, 16857, 0 };
            const std::uint32_t dim13047JoeKuoD6Init[]   =   { 1, 3, 5, 1, 13, 61, 87, 159, 65, 875, 163, 663, 7651, 8775, 32505, 39313, 83331, 0 };
            const std::uint32_t dim13048JoeKuoD6Init[]   =   { 1, 1, 7, 15, 27, 19, 63, 117, 427, 233, 1243, 755, 3201, 5153, 31959, 64545, 69219, 0 };
            const std::uint32_t dim13049JoeKuoD6Init[]   =   { 1, 1, 5, 3, 3, 27, 15, 11, 427, 431, 107, 2433, 6923, 7503, 31347, 64849, 14541, 0 };
            const std::uint32_t dim13050JoeKuoD6Init[]   =   { 1, 1, 3, 11, 7, 23, 53, 253, 483, 63, 1749, 2989, 5219, 7361, 6423, 1503, 95431, 0 };
            const std::uint32_t dim13051JoeKuoD6Init[]   =   { 1, 1, 5, 9, 1, 19, 23, 25, 301, 665, 1457, 2423, 6623, 9771, 2755, 8963, 51037, 0 };
            const std::uint32_t dim13052JoeKuoD6Init[]   =   { 1, 3, 3, 7, 21, 1, 3, 131, 377, 897, 15, 437, 4075, 7669, 31529, 64123, 101249, 0 };
            const std::uint32_t dim13053JoeKuoD6Init[]   =   { 1, 3, 5, 3, 31, 41, 99, 27, 397, 393, 1895, 2249, 3925, 6393, 2839, 375, 56721, 0 };
            const std::uint32_t dim13054JoeKuoD6Init[]   =   { 1, 3, 7, 15, 1, 45, 65, 113, 85, 557, 857, 2281, 1395, 2055, 2405, 34541, 63719, 0 };
            const std::uint32_t dim13055JoeKuoD6Init[]   =   { 1, 3, 1, 15, 7, 43, 21, 29, 15, 229, 1287, 3005, 339, 5833, 21867, 21643, 37557, 0 };
            const std::uint32_t dim13056JoeKuoD6Init[]   =   { 1, 3, 7, 3, 3, 51, 67, 119, 423, 539, 1995, 4039, 2999, 2787, 29327, 62687, 11893, 0 };
            const std::uint32_t dim13057JoeKuoD6Init[]   =   { 1, 3, 7, 3, 25, 23, 85, 11, 105, 523, 889, 2983, 2031, 2049, 16119, 41925, 38345, 0 };
            const std::uint32_t dim13058JoeKuoD6Init[]   =   { 1, 3, 7, 3, 13, 63, 59, 65, 183, 695, 293, 3301, 7895, 13915, 25847, 22819, 92189, 0 };
            const std::uint32_t dim13059JoeKuoD6Init[]   =   { 1, 1, 3, 3, 7, 27, 101, 229, 435, 227, 1759, 1275, 5781, 6079, 25125, 64833, 69577, 0 };
            const std::uint32_t dim13060JoeKuoD6Init[]   =   { 1, 1, 3, 1, 29, 1, 61, 45, 193, 441, 687, 841, 4491, 10683, 13989, 60461, 78071, 0 };
            const std::uint32_t dim13061JoeKuoD6Init[]   =   { 1, 3, 1, 9, 5, 33, 99, 229, 181, 675, 1629, 1855, 4719, 9585, 8059, 26363, 31161, 0 };
            const std::uint32_t dim13062JoeKuoD6Init[]   =   { 1, 3, 1, 11, 11, 37, 79, 53, 163, 49, 1173, 1715, 8087, 6535, 14985, 24069, 118597, 0 };
            const std::uint32_t dim13063JoeKuoD6Init[]   =   { 1, 1, 7, 15, 9, 59, 123, 79, 237, 131, 1693, 2525, 6339, 9843, 24309, 24969, 37645, 0 };
            const std::uint32_t dim13064JoeKuoD6Init[]   =   { 1, 3, 3, 7, 19, 49, 85, 133, 415, 239, 555, 2581, 6523, 2733, 19665, 19989, 105585, 0 };
            const std::uint32_t dim13065JoeKuoD6Init[]   =   { 1, 3, 3, 7, 23, 37, 31, 121, 59, 7, 2031, 2893, 6429, 10305, 21221, 20105, 38879, 0 };
            const std::uint32_t dim13066JoeKuoD6Init[]   =   { 1, 3, 1, 13, 23, 21, 93, 93, 343, 641, 411, 971, 1777, 2135, 22895, 9055, 114457, 0 };
            const std::uint32_t dim13067JoeKuoD6Init[]   =   { 1, 3, 5, 3, 15, 33, 23, 7, 59, 413, 277, 3551, 7737, 2285, 7951, 5013, 94469, 0 };
            const std::uint32_t dim13068JoeKuoD6Init[]   =   { 1, 3, 1, 15, 25, 1, 109, 245, 153, 187, 1099, 1071, 145, 6735, 10327, 3921, 62123, 0 };
            const std::uint32_t dim13069JoeKuoD6Init[]   =   { 1, 1, 7, 11, 11, 53, 51, 123, 277, 281, 1763, 3161, 7639, 14515, 29725, 3919, 5525, 0 };
            const std::uint32_t dim13070JoeKuoD6Init[]   =   { 1, 3, 3, 15, 27, 47, 109, 121, 317, 221, 187, 617, 1331, 5401, 861, 62465, 9227, 0 };
            const std::uint32_t dim13071JoeKuoD6Init[]   =   { 1, 3, 3, 15, 27, 25, 101, 111, 469, 85, 1285, 1621, 5393, 1367, 17115, 35141, 126989, 0 };
            const std::uint32_t dim13072JoeKuoD6Init[]   =   { 1, 3, 5, 1, 15, 23, 25, 249, 69, 17, 1103, 2603, 59, 15637, 22051, 29243, 53113, 0 };
            const std::uint32_t dim13073JoeKuoD6Init[]   =   { 1, 3, 1, 9, 17, 49, 73, 13, 207, 963, 379, 3561, 6447, 7895, 18651, 8109, 3943, 0 };
            const std::uint32_t dim13074JoeKuoD6Init[]   =   { 1, 3, 5, 11, 7, 41, 55, 85, 481, 831, 593, 4093, 1151, 12353, 24231, 46091, 80967, 0 };
            const std::uint32_t dim13075JoeKuoD6Init[]   =   { 1, 3, 7, 7, 5, 39, 47, 187, 427, 1007, 813, 3617, 6063, 12981, 18573, 34061, 85741, 0 };
            const std::uint32_t dim13076JoeKuoD6Init[]   =   { 1, 3, 3, 11, 9, 17, 29, 141, 341, 485, 1075, 4067, 7247, 11295, 31803, 18347, 54985, 0 };
            const std::uint32_t dim13077JoeKuoD6Init[]   =   { 1, 1, 3, 7, 17, 25, 7, 29, 355, 35, 1753, 669, 4123, 4293, 22875, 36677, 61201, 0 };
            const std::uint32_t dim13078JoeKuoD6Init[]   =   { 1, 1, 5, 9, 13, 45, 29, 153, 169, 387, 1275, 3161, 4937, 5331, 16203, 43925, 129231, 0 };
            const std::uint32_t dim13079JoeKuoD6Init[]   =   { 1, 3, 3, 9, 19, 27, 109, 95, 499, 929, 1627, 3215, 6097, 15837, 5655, 29877, 122513, 0 };
            const std::uint32_t dim13080JoeKuoD6Init[]   =   { 1, 3, 7, 11, 1, 25, 15, 41, 65, 411, 289, 883, 5069, 8405, 11159, 57357, 114253, 0 };
            const std::uint32_t dim13081JoeKuoD6Init[]   =   { 1, 1, 3, 11, 31, 57, 39, 89, 77, 321, 1667, 871, 6429, 1005, 18905, 13877, 9305, 0 };
            const std::uint32_t dim13082JoeKuoD6Init[]   =   { 1, 1, 7, 7, 27, 57, 23, 37, 281, 625, 1871, 565, 5979, 13925, 22591, 2375, 8577, 0 };
            const std::uint32_t dim13083JoeKuoD6Init[]   =   { 1, 1, 1, 7, 31, 35, 91, 221, 495, 811, 1321, 2235, 4287, 3009, 5745, 35013, 93715, 0 };
            const std::uint32_t dim13084JoeKuoD6Init[]   =   { 1, 1, 7, 3, 11, 53, 17, 13, 319, 225, 117, 3365, 537, 5249, 14219, 23879, 4321, 0 };
            const std::uint32_t dim13085JoeKuoD6Init[]   =   { 1, 3, 5, 1, 31, 57, 35, 95, 257, 933, 471, 627, 6733, 8707, 25173, 44291, 105041, 0 };
            const std::uint32_t dim13086JoeKuoD6Init[]   =   { 1, 1, 3, 3, 31, 53, 69, 19, 277, 669, 497, 3957, 2781, 14107, 27741, 53519, 41057, 0 };
            const std::uint32_t dim13087JoeKuoD6Init[]   =   { 1, 1, 3, 15, 11, 21, 11, 25, 257, 665, 491, 2119, 3893, 14401, 29147, 3369, 116569, 0 };
            const std::uint32_t dim13088JoeKuoD6Init[]   =   { 1, 3, 1, 1, 13, 49, 31, 231, 217, 711, 1987, 1487, 7073, 473, 28781, 51283, 86049, 0 };
            const std::uint32_t dim13089JoeKuoD6Init[]   =   { 1, 1, 1, 5, 23, 31, 119, 115, 381, 179, 1725, 2323, 8013, 15191, 13255, 57813, 95437, 0 };
            const std::uint32_t dim13090JoeKuoD6Init[]   =   { 1, 1, 3, 15, 15, 37, 83, 223, 259, 605, 2013, 4089, 395, 2063, 11735, 51931, 74677, 0 };
            const std::uint32_t dim13091JoeKuoD6Init[]   =   { 1, 1, 7, 3, 1, 61, 107, 169, 213, 789, 425, 2309, 225, 1305, 20697, 26281, 60129, 0 };
            const std::uint32_t dim13092JoeKuoD6Init[]   =   { 1, 1, 5, 15, 27, 15, 69, 169, 289, 931, 1491, 3711, 6875, 7723, 21103, 31795, 53955, 0 };
            const std::uint32_t dim13093JoeKuoD6Init[]   =   { 1, 1, 1, 3, 3, 43, 49, 205, 247, 817, 2037, 2305, 7935, 255, 18835, 49423, 90727, 0 };
            const std::uint32_t dim13094JoeKuoD6Init[]   =   { 1, 3, 7, 9, 17, 3, 95, 239, 431, 665, 1271, 3559, 5703, 14607, 9723, 11807, 122937, 0 };
            const std::uint32_t dim13095JoeKuoD6Init[]   =   { 1, 3, 5, 13, 5, 15, 13, 111, 375, 895, 833, 813, 5451, 13841, 1321, 25273, 25443, 0 };
            const std::uint32_t dim13096JoeKuoD6Init[]   =   { 1, 1, 3, 1, 11, 49, 3, 97, 467, 631, 51, 3577, 1777, 15965, 6837, 38827, 68627, 0 };
            const std::uint32_t dim13097JoeKuoD6Init[]   =   { 1, 1, 7, 1, 3, 11, 73, 155, 77, 623, 811, 337, 6837, 10925, 2097, 28325, 97487, 0 };
            const std::uint32_t dim13098JoeKuoD6Init[]   =   { 1, 1, 1, 3, 29, 35, 9, 215, 415, 143, 1837, 3723, 73, 11305, 23187, 19995, 52987, 0 };
            const std::uint32_t dim13099JoeKuoD6Init[]   =   { 1, 1, 7, 1, 25, 39, 35, 67, 245, 295, 1143, 2043, 1049, 629, 14111, 62893, 86899, 0 };
            const std::uint32_t dim13100JoeKuoD6Init[]   =   { 1, 3, 7, 5, 3, 41, 123, 97, 241, 743, 259, 3163, 2289, 6363, 24033, 10789, 44117, 0 };
            const std::uint32_t dim13101JoeKuoD6Init[]   =   { 1, 3, 1, 7, 25, 33, 33, 17, 359, 567, 901, 3595, 179, 8671, 841, 24787, 4367, 0 };
            const std::uint32_t dim13102JoeKuoD6Init[]   =   { 1, 3, 1, 13, 5, 13, 57, 185, 321, 727, 789, 3081, 5345, 9721, 32029, 11663, 55695, 0 };
            const std::uint32_t dim13103JoeKuoD6Init[]   =   { 1, 1, 7, 7, 5, 51, 85, 255, 329, 263, 297, 1687, 6799, 10973, 8265, 19615, 115333, 0 };
            const std::uint32_t dim13104JoeKuoD6Init[]   =   { 1, 1, 1, 5, 29, 27, 55, 167, 465, 73, 661, 137, 7831, 2571, 15373, 64223, 27335, 0 };
            const std::uint32_t dim13105JoeKuoD6Init[]   =   { 1, 3, 7, 13, 5, 23, 77, 15, 345, 21, 1729, 3231, 967, 12573, 31415, 24249, 110525, 0 };
            const std::uint32_t dim13106JoeKuoD6Init[]   =   { 1, 1, 7, 9, 31, 37, 41, 119, 169, 891, 1845, 2139, 1747, 1147, 21983, 11617, 25963, 0 };
            const std::uint32_t dim13107JoeKuoD6Init[]   =   { 1, 3, 3, 7, 23, 5, 1, 11, 95, 795, 1371, 2631, 3241, 6935, 17353, 25013, 89765, 0 };
            const std::uint32_t dim13108JoeKuoD6Init[]   =   { 1, 3, 1, 7, 19, 3, 121, 19, 389, 117, 1905, 3135, 7601, 12541, 20855, 38613, 15005, 0 };
            const std::uint32_t dim13109JoeKuoD6Init[]   =   { 1, 3, 3, 5, 17, 43, 91, 99, 113, 545, 1955, 37, 3411, 15173, 24961, 28761, 15245, 0 };
            const std::uint32_t dim13110JoeKuoD6Init[]   =   { 1, 3, 3, 13, 25, 9, 83, 17, 17, 271, 1133, 3851, 4607, 11017, 14867, 20677, 42881, 0 };
            const std::uint32_t dim13111JoeKuoD6Init[]   =   { 1, 1, 5, 15, 5, 9, 99, 179, 263, 623, 441, 2577, 189, 11595, 21505, 27215, 54081, 0 };
            const std::uint32_t dim13112JoeKuoD6Init[]   =   { 1, 1, 7, 1, 1, 63, 123, 119, 245, 467, 169, 3075, 909, 3581, 14571, 33071, 6261, 0 };
            const std::uint32_t dim13113JoeKuoD6Init[]   =   { 1, 1, 1, 13, 9, 35, 47, 161, 47, 893, 57, 703, 3373, 4167, 26555, 51265, 1391, 0 };
            const std::uint32_t dim13114JoeKuoD6Init[]   =   { 1, 3, 1, 13, 9, 61, 9, 5, 47, 259, 579, 113, 355, 14539, 25757, 10119, 96869, 0 };
            const std::uint32_t dim13115JoeKuoD6Init[]   =   { 1, 1, 5, 11, 3, 5, 61, 231, 291, 21, 1711, 2981, 4727, 14287, 12149, 40275, 51809, 0 };
            const std::uint32_t dim13116JoeKuoD6Init[]   =   { 1, 3, 5, 3, 21, 5, 87, 251, 373, 679, 949, 1023, 5183, 14549, 4135, 54927, 20369, 0 };
            const std::uint32_t dim13117JoeKuoD6Init[]   =   { 1, 3, 3, 11, 7, 43, 127, 97, 469, 81, 1843, 3955, 125, 8607, 27185, 50761, 122753, 0 };
            const std::uint32_t dim13118JoeKuoD6Init[]   =   { 1, 3, 5, 5, 25, 61, 1, 55, 333, 949, 1005, 1051, 6291, 8343, 9627, 37739, 116911, 0 };
            const std::uint32_t dim13119JoeKuoD6Init[]   =   { 1, 3, 3, 13, 21, 9, 67, 225, 179, 837, 2009, 3171, 217, 5629, 23451, 63171, 53225, 0 };
            const std::uint32_t dim13120JoeKuoD6Init[]   =   { 1, 3, 7, 1, 23, 15, 91, 163, 351, 883, 579, 3923, 2641, 12735, 24955, 1131, 65119, 0 };
            const std::uint32_t dim13121JoeKuoD6Init[]   =   { 1, 1, 1, 11, 29, 5, 113, 217, 171, 535, 913, 2419, 3843, 12365, 8287, 27367, 57369, 0 };
            const std::uint32_t dim13122JoeKuoD6Init[]   =   { 1, 1, 5, 11, 9, 41, 57, 243, 123, 159, 1517, 2653, 4307, 4243, 2801, 43131, 18435, 0 };
            const std::uint32_t dim13123JoeKuoD6Init[]   =   { 1, 1, 7, 9, 23, 59, 83, 159, 57, 723, 1635, 7, 1463, 121, 541, 7657, 83917, 0 };
            const std::uint32_t dim13124JoeKuoD6Init[]   =   { 1, 3, 7, 7, 23, 27, 125, 103, 247, 1019, 1063, 3979, 8085, 6449, 12443, 63427, 106235, 0 };
            const std::uint32_t dim13125JoeKuoD6Init[]   =   { 1, 1, 7, 5, 9, 31, 23, 83, 503, 605, 1731, 3341, 7427, 14571, 5981, 39043, 42965, 0 };
            const std::uint32_t dim13126JoeKuoD6Init[]   =   { 1, 3, 5, 1, 17, 49, 109, 171, 301, 951, 1879, 1317, 457, 8085, 6803, 62521, 67871, 0 };
            const std::uint32_t dim13127JoeKuoD6Init[]   =   { 1, 1, 7, 11, 11, 27, 1, 71, 335, 137, 265, 1267, 6399, 14823, 925, 49895, 19731, 0 };
            const std::uint32_t dim13128JoeKuoD6Init[]   =   { 1, 3, 1, 13, 3, 35, 75, 253, 211, 483, 1495, 3695, 3033, 14643, 1861, 51269, 32655, 0 };
            const std::uint32_t dim13129JoeKuoD6Init[]   =   { 1, 3, 7, 1, 5, 17, 63, 1, 83, 435, 2007, 2023, 57, 8639, 27067, 4039, 1955, 0 };
            const std::uint32_t dim13130JoeKuoD6Init[]   =   { 1, 3, 5, 15, 27, 51, 59, 47, 77, 131, 507, 559, 645, 16067, 20989, 15565, 39925, 0 };
            const std::uint32_t dim13131JoeKuoD6Init[]   =   { 1, 3, 3, 5, 11, 15, 63, 121, 39, 1019, 1027, 2821, 3297, 13769, 18587, 14199, 82251, 0 };
            const std::uint32_t dim13132JoeKuoD6Init[]   =   { 1, 1, 5, 1, 31, 11, 89, 75, 147, 1007, 917, 3519, 5097, 5695, 15185, 14819, 38597, 0 };
            const std::uint32_t dim13133JoeKuoD6Init[]   =   { 1, 3, 3, 3, 15, 7, 127, 55, 83, 887, 1901, 75, 639, 713, 13631, 27447, 106707, 0 };
            const std::uint32_t dim13134JoeKuoD6Init[]   =   { 1, 3, 3, 15, 27, 25, 85, 163, 187, 959, 815, 1403, 6129, 6515, 31597, 28307, 30077, 0 };
            const std::uint32_t dim13135JoeKuoD6Init[]   =   { 1, 3, 1, 13, 5, 19, 117, 89, 11, 489, 845, 2899, 3695, 3279, 22355, 38759, 85849, 0 };
            const std::uint32_t dim13136JoeKuoD6Init[]   =   { 1, 3, 1, 7, 25, 59, 109, 185, 87, 591, 825, 1119, 7439, 5451, 17959, 51299, 76693, 0 };
            const std::uint32_t dim13137JoeKuoD6Init[]   =   { 1, 1, 7, 5, 25, 29, 115, 249, 185, 529, 593, 103, 1739, 4769, 25925, 3317, 102445, 0 };
            const std::uint32_t dim13138JoeKuoD6Init[]   =   { 1, 1, 3, 1, 3, 35, 19, 255, 279, 295, 1075, 2817, 3513, 7501, 15885, 21653, 113447, 0 };
            const std::uint32_t dim13139JoeKuoD6Init[]   =   { 1, 3, 1, 5, 27, 1, 21, 137, 303, 981, 631, 2339, 397, 13075, 28815, 50925, 44379, 0 };
            const std::uint32_t dim13140JoeKuoD6Init[]   =   { 1, 1, 7, 7, 31, 31, 59, 129, 105, 181, 1041, 2685, 1061, 1721, 30365, 6873, 30011, 0 };
            const std::uint32_t dim13141JoeKuoD6Init[]   =   { 1, 1, 3, 1, 19, 31, 125, 39, 9, 631, 1239, 1061, 6313, 9639, 5991, 27293, 84635, 0 };
            const std::uint32_t dim13142JoeKuoD6Init[]   =   { 1, 3, 3, 11, 17, 59, 17, 241, 195, 175, 1845, 251, 3323, 13399, 20493, 15241, 69303, 0 };
            const std::uint32_t dim13143JoeKuoD6Init[]   =   { 1, 1, 5, 3, 9, 19, 59, 25, 49, 359, 263, 4045, 1527, 6703, 555, 26413, 42757, 0 };
            const std::uint32_t dim13144JoeKuoD6Init[]   =   { 1, 1, 5, 9, 23, 5, 7, 223, 247, 407, 1079, 1069, 3417, 14795, 5015, 2965, 99059, 0 };
            const std::uint32_t dim13145JoeKuoD6Init[]   =   { 1, 3, 7, 5, 27, 47, 9, 37, 47, 181, 819, 2049, 2643, 9231, 8173, 33495, 91321, 0 };
            const std::uint32_t dim13146JoeKuoD6Init[]   =   { 1, 3, 5, 11, 5, 27, 5, 237, 349, 653, 1443, 137, 7969, 5961, 24749, 37523, 88921, 0 };
            const std::uint32_t dim13147JoeKuoD6Init[]   =   { 1, 3, 7, 13, 11, 51, 49, 71, 339, 195, 1239, 3479, 2771, 15217, 23729, 7839, 32633, 0 };
            const std::uint32_t dim13148JoeKuoD6Init[]   =   { 1, 1, 5, 5, 5, 13, 103, 185, 13, 273, 1793, 761, 5327, 8659, 32599, 38181, 121115, 0 };
            const std::uint32_t dim13149JoeKuoD6Init[]   =   { 1, 3, 7, 15, 17, 55, 69, 151, 231, 421, 1679, 3657, 8001, 12599, 13761, 13517, 130199, 0 };
            const std::uint32_t dim13150JoeKuoD6Init[]   =   { 1, 1, 5, 3, 5, 15, 15, 61, 489, 219, 925, 2329, 3415, 10779, 31297, 63805, 13375, 0 };
            const std::uint32_t dim13151JoeKuoD6Init[]   =   { 1, 1, 7, 9, 7, 11, 87, 45, 39, 885, 87, 1877, 8135, 1247, 25685, 23631, 65579, 0 };
            const std::uint32_t dim13152JoeKuoD6Init[]   =   { 1, 3, 3, 7, 1, 17, 31, 75, 455, 535, 509, 2151, 1737, 7579, 12727, 25139, 32659, 0 };
            const std::uint32_t dim13153JoeKuoD6Init[]   =   { 1, 3, 5, 7, 15, 27, 111, 145, 99, 767, 167, 3391, 2155, 7895, 3405, 47451, 65185, 0 };
            const std::uint32_t dim13154JoeKuoD6Init[]   =   { 1, 1, 1, 3, 23, 31, 15, 53, 59, 787, 431, 2691, 71, 2843, 13469, 54029, 2233, 0 };
            const std::uint32_t dim13155JoeKuoD6Init[]   =   { 1, 1, 5, 1, 5, 39, 57, 31, 75, 507, 811, 2747, 317, 13545, 7395, 65161, 87987, 0 };
            const std::uint32_t dim13156JoeKuoD6Init[]   =   { 1, 3, 5, 5, 13, 17, 11, 89, 371, 337, 913, 2775, 27, 4923, 24013, 62955, 65185, 0 };
            const std::uint32_t dim13157JoeKuoD6Init[]   =   { 1, 3, 3, 7, 9, 27, 91, 187, 17, 443, 807, 853, 6243, 12351, 8123, 4203, 61021, 0 };
            const std::uint32_t dim13158JoeKuoD6Init[]   =   { 1, 1, 1, 5, 9, 33, 101, 211, 205, 701, 1289, 1253, 653, 8591, 13009, 48525, 77051, 0 };
            const std::uint32_t dim13159JoeKuoD6Init[]   =   { 1, 3, 5, 11, 5, 19, 1, 67, 259, 355, 15, 2169, 6785, 2019, 8675, 1019, 85903, 0 };
            const std::uint32_t dim13160JoeKuoD6Init[]   =   { 1, 3, 7, 5, 27, 31, 103, 163, 369, 685, 659, 2009, 5819, 10437, 17311, 35083, 122125, 0 };
            const std::uint32_t dim13161JoeKuoD6Init[]   =   { 1, 3, 5, 7, 19, 13, 93, 113, 377, 359, 1697, 4063, 4379, 9321, 7335, 25491, 85939, 0 };
            const std::uint32_t dim13162JoeKuoD6Init[]   =   { 1, 3, 3, 5, 7, 25, 41, 225, 355, 257, 743, 2067, 7627, 14317, 7385, 25187, 63103, 0 };
            const std::uint32_t dim13163JoeKuoD6Init[]   =   { 1, 1, 7, 7, 17, 43, 75, 1, 95, 547, 1937, 2263, 1709, 5067, 22651, 55733, 44619, 0 };
            const std::uint32_t dim13164JoeKuoD6Init[]   =   { 1, 1, 7, 3, 5, 27, 45, 23, 107, 547, 1733, 1169, 6709, 861, 4439, 55381, 96447, 0 };
            const std::uint32_t dim13165JoeKuoD6Init[]   =   { 1, 1, 7, 11, 25, 23, 127, 159, 489, 945, 843, 3715, 5215, 2131, 9681, 35515, 108109, 0 };
            const std::uint32_t dim13166JoeKuoD6Init[]   =   { 1, 1, 3, 7, 5, 1, 67, 59, 83, 745, 1337, 855, 6087, 14319, 13405, 36261, 49091, 0 };
            const std::uint32_t dim13167JoeKuoD6Init[]   =   { 1, 3, 1, 1, 13, 27, 41, 155, 463, 709, 1111, 2017, 4701, 8663, 29703, 45311, 113347, 0 };
            const std::uint32_t dim13168JoeKuoD6Init[]   =   { 1, 1, 7, 5, 1, 11, 83, 101, 283, 505, 893, 705, 2331, 5127, 21793, 28095, 59055, 0 };
            const std::uint32_t dim13169JoeKuoD6Init[]   =   { 1, 1, 5, 9, 25, 7, 97, 155, 71, 569, 1481, 897, 6177, 13367, 12163, 18171, 24785, 0 };
            const std::uint32_t dim13170JoeKuoD6Init[]   =   { 1, 3, 5, 11, 19, 25, 7, 15, 511, 369, 957, 1247, 6097, 11181, 17265, 24777, 87377, 0 };
            const std::uint32_t dim13171JoeKuoD6Init[]   =   { 1, 3, 1, 7, 11, 9, 39, 191, 9, 793, 867, 2779, 3447, 3805, 21025, 64719, 15669, 0 };
            const std::uint32_t dim13172JoeKuoD6Init[]   =   { 1, 1, 3, 1, 31, 43, 107, 103, 175, 131, 1525, 993, 635, 14383, 26835, 15929, 109977, 0 };
            const std::uint32_t dim13173JoeKuoD6Init[]   =   { 1, 1, 1, 3, 19, 17, 99, 249, 47, 467, 853, 2805, 3155, 1565, 17291, 18865, 11039, 0 };
            const std::uint32_t dim13174JoeKuoD6Init[]   =   { 1, 1, 5, 13, 25, 61, 91, 67, 361, 947, 1909, 3403, 945, 3481, 16703, 50227, 43963, 0 };
            const std::uint32_t dim13175JoeKuoD6Init[]   =   { 1, 3, 1, 3, 19, 27, 31, 219, 185, 579, 1539, 315, 4421, 9473, 30289, 48477, 61365, 0 };
            const std::uint32_t dim13176JoeKuoD6Init[]   =   { 1, 1, 3, 1, 23, 11, 101, 1, 133, 305, 1107, 1145, 1733, 13275, 221, 5071, 81987, 0 };
            const std::uint32_t dim13177JoeKuoD6Init[]   =   { 1, 1, 1, 13, 7, 61, 47, 5, 137, 979, 1183, 2049, 5263, 6515, 5585, 6093, 119689, 0 };
            const std::uint32_t dim13178JoeKuoD6Init[]   =   { 1, 3, 1, 5, 19, 47, 83, 115, 215, 901, 1685, 755, 2327, 13297, 6847, 40329, 19225, 0 };
            const std::uint32_t dim13179JoeKuoD6Init[]   =   { 1, 1, 3, 3, 3, 13, 31, 127, 199, 655, 55, 2183, 5031, 945, 6073, 54729, 108281, 0 };
            const std::uint32_t dim13180JoeKuoD6Init[]   =   { 1, 1, 1, 1, 11, 51, 37, 19, 73, 205, 1377, 1881, 3679, 4487, 14693, 41735, 27349, 0 };
            const std::uint32_t dim13181JoeKuoD6Init[]   =   { 1, 3, 7, 13, 1, 35, 37, 73, 45, 973, 209, 529, 5283, 9765, 26367, 12697, 8685, 0 };
            const std::uint32_t dim13182JoeKuoD6Init[]   =   { 1, 3, 3, 9, 3, 45, 115, 35, 475, 663, 487, 3613, 4151, 15623, 3057, 31519, 87545, 0 };
            const std::uint32_t dim13183JoeKuoD6Init[]   =   { 1, 3, 7, 5, 23, 13, 25, 255, 355, 433, 1671, 667, 7463, 14189, 14107, 1531, 11695, 0 };
            const std::uint32_t dim13184JoeKuoD6Init[]   =   { 1, 1, 7, 3, 15, 25, 37, 127, 265, 493, 1763, 2721, 4335, 13753, 5947, 18375, 29911, 0 };
            const std::uint32_t dim13185JoeKuoD6Init[]   =   { 1, 1, 3, 15, 1, 55, 25, 69, 335, 157, 1923, 1757, 5689, 6731, 723, 6471, 57415, 0 };
            const std::uint32_t dim13186JoeKuoD6Init[]   =   { 1, 3, 3, 3, 1, 15, 127, 227, 401, 395, 503, 3783, 1737, 8785, 16287, 34949, 91683, 0 };
            const std::uint32_t dim13187JoeKuoD6Init[]   =   { 1, 3, 5, 15, 23, 29, 55, 119, 115, 855, 657, 3729, 5309, 14773, 5647, 25953, 67303, 0 };
            const std::uint32_t dim13188JoeKuoD6Init[]   =   { 1, 3, 5, 13, 23, 25, 1, 187, 67, 389, 359, 619, 2523, 11203, 11049, 60345, 53931, 0 };
            const std::uint32_t dim13189JoeKuoD6Init[]   =   { 1, 3, 1, 7, 7, 45, 99, 123, 495, 797, 939, 3387, 7563, 16289, 8309, 14917, 99867, 0 };
            const std::uint32_t dim13190JoeKuoD6Init[]   =   { 1, 3, 5, 11, 29, 49, 89, 205, 447, 541, 1279, 1153, 7277, 5393, 8743, 41057, 100119, 0 };
            const std::uint32_t dim13191JoeKuoD6Init[]   =   { 1, 1, 1, 9, 1, 7, 43, 165, 259, 311, 993, 1381, 3363, 577, 4023, 443, 101785, 0 };
            const std::uint32_t dim13192JoeKuoD6Init[]   =   { 1, 1, 7, 9, 25, 55, 93, 63, 423, 787, 549, 1039, 383, 15855, 6013, 51399, 60007, 0 };
            const std::uint32_t dim13193JoeKuoD6Init[]   =   { 1, 3, 3, 1, 5, 17, 103, 91, 309, 85, 1319, 3869, 559, 3993, 18111, 17753, 66681, 0 };
            const std::uint32_t dim13194JoeKuoD6Init[]   =   { 1, 3, 7, 9, 1, 11, 87, 151, 311, 597, 811, 3955, 275, 6555, 17005, 26763, 31227, 0 };
            const std::uint32_t dim13195JoeKuoD6Init[]   =   { 1, 1, 3, 11, 19, 51, 41, 101, 183, 1003, 1635, 2061, 3305, 12925, 7223, 4859, 24433, 0 };
            const std::uint32_t dim13196JoeKuoD6Init[]   =   { 1, 3, 7, 11, 7, 43, 79, 53, 43, 429, 947, 2533, 7005, 15147, 13435, 33997, 21201, 0 };
            const std::uint32_t dim13197JoeKuoD6Init[]   =   { 1, 1, 3, 5, 15, 17, 61, 41, 383, 465, 1439, 3503, 3981, 14469, 5075, 25953, 70461, 0 };
            const std::uint32_t dim13198JoeKuoD6Init[]   =   { 1, 1, 1, 13, 21, 53, 25, 59, 59, 195, 665, 3367, 2777, 9179, 24207, 56729, 94241, 0 };
            const std::uint32_t dim13199JoeKuoD6Init[]   =   { 1, 3, 7, 15, 27, 13, 41, 147, 415, 351, 961, 3811, 1605, 14231, 31789, 41189, 50265, 0 };
            const std::uint32_t dim13200JoeKuoD6Init[]   =   { 1, 3, 3, 7, 31, 39, 85, 219, 323, 657, 423, 1579, 3623, 7663, 14631, 47169, 88795, 0 };
            const std::uint32_t dim13201JoeKuoD6Init[]   =   { 1, 3, 1, 3, 1, 3, 125, 65, 259, 3, 1897, 2203, 347, 4101, 23841, 20217, 117407, 0 };
            const std::uint32_t dim13202JoeKuoD6Init[]   =   { 1, 1, 3, 7, 29, 1, 75, 255, 413, 237, 1531, 2103, 6847, 10395, 9817, 9383, 60679, 0 };
            const std::uint32_t dim13203JoeKuoD6Init[]   =   { 1, 3, 5, 3, 7, 63, 17, 83, 375, 835, 1707, 3227, 327, 2205, 25025, 47471, 39967, 0 };
            const std::uint32_t dim13204JoeKuoD6Init[]   =   { 1, 3, 7, 7, 9, 51, 23, 189, 157, 351, 755, 2695, 3923, 3481, 12159, 1041, 94563, 0 };
            const std::uint32_t dim13205JoeKuoD6Init[]   =   { 1, 1, 3, 11, 25, 27, 39, 19, 221, 795, 523, 695, 3257, 8045, 2643, 43239, 13291, 0 };
            const std::uint32_t dim13206JoeKuoD6Init[]   =   { 1, 3, 3, 5, 29, 1, 33, 117, 477, 147, 1117, 1943, 7967, 15999, 10673, 13349, 89471, 0 };
            const std::uint32_t dim13207JoeKuoD6Init[]   =   { 1, 1, 3, 9, 17, 51, 55, 115, 147, 687, 1751, 3685, 3099, 15369, 371, 55673, 67951, 0 };
            const std::uint32_t dim13208JoeKuoD6Init[]   =   { 1, 1, 7, 1, 5, 25, 67, 31, 103, 439, 1581, 705, 3855, 15985, 7151, 56511, 23697, 0 };
            const std::uint32_t dim13209JoeKuoD6Init[]   =   { 1, 3, 5, 3, 21, 7, 11, 123, 121, 1009, 277, 623, 7913, 7525, 4759, 19245, 16735, 0 };
            const std::uint32_t dim13210JoeKuoD6Init[]   =   { 1, 1, 5, 11, 7, 57, 103, 147, 199, 209, 233, 3665, 4215, 13511, 16393, 37873, 120857, 0 };
            const std::uint32_t dim13211JoeKuoD6Init[]   =   { 1, 1, 7, 9, 27, 45, 29, 97, 279, 379, 1683, 1965, 1183, 11389, 20445, 38435, 56893, 0 };
            const std::uint32_t dim13212JoeKuoD6Init[]   =   { 1, 3, 5, 5, 27, 23, 89, 169, 329, 659, 393, 903, 6217, 6459, 27327, 2843, 44889, 0 };
            const std::uint32_t dim13213JoeKuoD6Init[]   =   { 1, 1, 1, 15, 3, 53, 109, 83, 195, 5, 1865, 729, 3627, 13307, 20761, 50375, 60379, 0 };
            const std::uint32_t dim13214JoeKuoD6Init[]   =   { 1, 1, 1, 13, 25, 57, 17, 185, 359, 797, 469, 2637, 973, 2731, 25299, 15169, 90187, 0 };
            const std::uint32_t dim13215JoeKuoD6Init[]   =   { 1, 3, 5, 1, 19, 39, 87, 161, 117, 565, 1737, 3995, 6487, 5067, 18531, 38803, 45453, 0 };
            const std::uint32_t dim13216JoeKuoD6Init[]   =   { 1, 1, 1, 5, 19, 3, 93, 85, 479, 369, 469, 1407, 475, 7775, 12273, 34417, 65611, 0 };
            const std::uint32_t dim13217JoeKuoD6Init[]   =   { 1, 1, 3, 15, 31, 11, 105, 19, 281, 711, 713, 3423, 797, 11215, 31409, 44891, 110413, 0 };
            const std::uint32_t dim13218JoeKuoD6Init[]   =   { 1, 1, 3, 11, 13, 17, 59, 111, 59, 431, 1517, 2159, 1697, 12309, 16293, 2097, 107273, 0 };
            const std::uint32_t dim13219JoeKuoD6Init[]   =   { 1, 3, 5, 15, 25, 19, 97, 107, 97, 563, 247, 3691, 2775, 10631, 15113, 25721, 12995, 0 };
            const std::uint32_t dim13220JoeKuoD6Init[]   =   { 1, 1, 5, 3, 31, 25, 47, 201, 231, 123, 1923, 2287, 1711, 12271, 1573, 6605, 72991, 0 };
            const std::uint32_t dim13221JoeKuoD6Init[]   =   { 1, 1, 5, 5, 27, 17, 109, 125, 423, 1, 819, 3041, 685, 8791, 19697, 13107, 67681, 0 };
            const std::uint32_t dim13222JoeKuoD6Init[]   =   { 1, 1, 5, 3, 5, 63, 115, 95, 117, 715, 1523, 1231, 8171, 1615, 9819, 14361, 87075, 0 };
            const std::uint32_t dim13223JoeKuoD6Init[]   =   { 1, 1, 7, 7, 7, 35, 35, 175, 349, 853, 1665, 3101, 6051, 10737, 933, 40591, 9419, 0 };
            const std::uint32_t dim13224JoeKuoD6Init[]   =   { 1, 1, 1, 3, 23, 49, 65, 23, 103, 837, 403, 3799, 6515, 15363, 28079, 36381, 59523, 0 };
            const std::uint32_t dim13225JoeKuoD6Init[]   =   { 1, 3, 1, 15, 15, 25, 119, 181, 229, 685, 1047, 2397, 4855, 15393, 2371, 42441, 30151, 0 };
            const std::uint32_t dim13226JoeKuoD6Init[]   =   { 1, 3, 7, 11, 15, 5, 13, 93, 219, 203, 475, 523, 5827, 6579, 26759, 29795, 108463, 0 };
            const std::uint32_t dim13227JoeKuoD6Init[]   =   { 1, 1, 7, 13, 25, 53, 75, 195, 443, 1003, 501, 2543, 5453, 3119, 19225, 59631, 16413, 0 };
            const std::uint32_t dim13228JoeKuoD6Init[]   =   { 1, 1, 7, 13, 13, 25, 93, 211, 191, 1005, 1567, 3057, 3001, 1125, 6237, 35725, 108257, 0 };
            const std::uint32_t dim13229JoeKuoD6Init[]   =   { 1, 1, 3, 7, 21, 11, 57, 205, 487, 263, 1801, 3235, 1819, 10875, 6063, 26211, 54699, 0 };
            const std::uint32_t dim13230JoeKuoD6Init[]   =   { 1, 3, 3, 7, 11, 59, 89, 217, 15, 991, 1343, 1247, 277, 13377, 18499, 64987, 26053, 0 };
            const std::uint32_t dim13231JoeKuoD6Init[]   =   { 1, 3, 3, 1, 15, 51, 111, 69, 137, 817, 1207, 1729, 3877, 9873, 18449, 50749, 57457, 0 };
            const std::uint32_t dim13232JoeKuoD6Init[]   =   { 1, 3, 3, 5, 3, 39, 97, 147, 327, 257, 1547, 769, 7077, 5221, 13679, 44237, 70053, 0 };
            const std::uint32_t dim13233JoeKuoD6Init[]   =   { 1, 1, 5, 11, 19, 15, 79, 187, 335, 645, 1235, 4041, 4831, 10847, 28135, 48353, 64921, 0 };
            const std::uint32_t dim13234JoeKuoD6Init[]   =   { 1, 1, 7, 9, 3, 43, 41, 149, 71, 205, 1513, 2801, 6785, 3187, 25401, 55367, 114491, 0 };
            const std::uint32_t dim13235JoeKuoD6Init[]   =   { 1, 1, 7, 1, 25, 11, 37, 205, 365, 435, 147, 1303, 587, 14563, 32461, 28983, 86157, 0 };
            const std::uint32_t dim13236JoeKuoD6Init[]   =   { 1, 1, 7, 1, 31, 11, 51, 37, 401, 343, 1677, 991, 501, 11993, 14781, 37055, 30161, 0 };
            const std::uint32_t dim13237JoeKuoD6Init[]   =   { 1, 3, 5, 9, 9, 21, 95, 45, 447, 957, 943, 3997, 4033, 8371, 25007, 52827, 50207, 0 };
            const std::uint32_t dim13238JoeKuoD6Init[]   =   { 1, 1, 7, 1, 9, 45, 3, 255, 297, 341, 215, 3631, 7049, 7625, 4145, 50109, 48615, 0 };
            const std::uint32_t dim13239JoeKuoD6Init[]   =   { 1, 3, 3, 9, 27, 49, 41, 143, 291, 343, 719, 311, 3819, 7699, 17631, 64785, 49239, 0 };
            const std::uint32_t dim13240JoeKuoD6Init[]   =   { 1, 1, 7, 3, 27, 35, 61, 183, 153, 781, 979, 1465, 3315, 14893, 29847, 18461, 74949, 0 };
            const std::uint32_t dim13241JoeKuoD6Init[]   =   { 1, 3, 5, 15, 19, 61, 39, 219, 279, 909, 1295, 1681, 8021, 957, 7675, 14001, 77669, 0 };
            const std::uint32_t dim13242JoeKuoD6Init[]   =   { 1, 3, 1, 5, 15, 59, 127, 85, 229, 649, 503, 3267, 2465, 5637, 2729, 24831, 44791, 0 };
            const std::uint32_t dim13243JoeKuoD6Init[]   =   { 1, 3, 7, 11, 23, 55, 61, 191, 345, 255, 105, 1361, 3913, 7655, 8865, 1825, 80619, 0 };
            const std::uint32_t dim13244JoeKuoD6Init[]   =   { 1, 3, 3, 13, 29, 15, 53, 19, 1, 651, 917, 2043, 2333, 13695, 28225, 16457, 11287, 0 };
            const std::uint32_t dim13245JoeKuoD6Init[]   =   { 1, 1, 3, 13, 15, 53, 41, 211, 13, 287, 383, 3923, 665, 10343, 4803, 22199, 90521, 0 };
            const std::uint32_t dim13246JoeKuoD6Init[]   =   { 1, 3, 7, 11, 23, 27, 127, 241, 11, 451, 495, 2779, 319, 13119, 5575, 43043, 11659, 0 };
            const std::uint32_t dim13247JoeKuoD6Init[]   =   { 1, 1, 1, 7, 17, 53, 55, 39, 233, 273, 1873, 843, 7885, 329, 6809, 33119, 116017, 0 };
            const std::uint32_t dim13248JoeKuoD6Init[]   =   { 1, 1, 1, 7, 21, 41, 23, 113, 283, 265, 1535, 2371, 3975, 6293, 22497, 65349, 48653, 0 };
            const std::uint32_t dim13249JoeKuoD6Init[]   =   { 1, 3, 7, 9, 25, 21, 61, 135, 245, 777, 679, 2603, 565, 3251, 32469, 12707, 40297, 0 };
            const std::uint32_t dim13250JoeKuoD6Init[]   =   { 1, 1, 1, 5, 31, 49, 35, 215, 445, 669, 779, 2231, 5399, 5853, 17941, 33973, 126141, 0 };
            const std::uint32_t dim13251JoeKuoD6Init[]   =   { 1, 3, 5, 5, 3, 31, 45, 235, 51, 65, 295, 3755, 8101, 821, 28331, 38837, 55235, 0 };
            const std::uint32_t dim13252JoeKuoD6Init[]   =   { 1, 1, 5, 15, 23, 15, 37, 197, 59, 455, 1875, 1745, 7565, 8039, 15901, 63129, 36095, 0 };
            const std::uint32_t dim13253JoeKuoD6Init[]   =   { 1, 1, 5, 11, 7, 1, 77, 235, 309, 245, 1539, 1421, 3401, 1477, 12655, 19851, 86147, 0 };
            const std::uint32_t dim13254JoeKuoD6Init[]   =   { 1, 1, 3, 9, 27, 9, 113, 127, 167, 213, 161, 4065, 1275, 10699, 26111, 26213, 129091, 0 };
            const std::uint32_t dim13255JoeKuoD6Init[]   =   { 1, 3, 5, 9, 9, 17, 109, 205, 23, 145, 1261, 51, 5855, 7411, 20551, 5801, 47841, 0 };
            const std::uint32_t dim13256JoeKuoD6Init[]   =   { 1, 1, 3, 3, 15, 1, 1, 39, 431, 601, 177, 525, 6951, 6271, 27031, 37157, 73979, 0 };
            const std::uint32_t dim13257JoeKuoD6Init[]   =   { 1, 3, 1, 3, 19, 61, 11, 131, 31, 223, 959, 3531, 2433, 15675, 29201, 49277, 43977, 0 };
            const std::uint32_t dim13258JoeKuoD6Init[]   =   { 1, 1, 5, 9, 5, 27, 57, 3, 503, 755, 1261, 3659, 6685, 10041, 24739, 12201, 19753, 0 };
            const std::uint32_t dim13259JoeKuoD6Init[]   =   { 1, 1, 7, 3, 31, 27, 7, 191, 7, 415, 1665, 1413, 7493, 2645, 23577, 46331, 9481, 0 };
            const std::uint32_t dim13260JoeKuoD6Init[]   =   { 1, 1, 5, 1, 29, 59, 99, 231, 33, 613, 1347, 2671, 1767, 15685, 26583, 44699, 73511, 0 };
            const std::uint32_t dim13261JoeKuoD6Init[]   =   { 1, 1, 3, 3, 9, 47, 93, 87, 45, 549, 219, 2141, 233, 10239, 30325, 14985, 70325, 0 };
            const std::uint32_t dim13262JoeKuoD6Init[]   =   { 1, 1, 3, 3, 21, 39, 81, 179, 319, 853, 93, 2869, 59, 6675, 22391, 16089, 33949, 0 };
            const std::uint32_t dim13263JoeKuoD6Init[]   =   { 1, 1, 3, 7, 31, 19, 73, 249, 175, 57, 1717, 3557, 2307, 4595, 22045, 33291, 123003, 0 };
            const std::uint32_t dim13264JoeKuoD6Init[]   =   { 1, 1, 1, 3, 7, 23, 81, 229, 387, 1001, 1371, 17, 667, 3043, 30507, 44613, 32239, 0 };
            const std::uint32_t dim13265JoeKuoD6Init[]   =   { 1, 1, 7, 15, 15, 59, 83, 99, 101, 863, 333, 845, 7547, 13345, 7599, 51, 10963, 0 };
            const std::uint32_t dim13266JoeKuoD6Init[]   =   { 1, 1, 1, 3, 15, 55, 73, 37, 429, 711, 1315, 2911, 5109, 953, 14721, 25551, 33527, 0 };
            const std::uint32_t dim13267JoeKuoD6Init[]   =   { 1, 1, 5, 9, 11, 57, 75, 107, 449, 293, 1267, 2633, 5291, 9939, 12365, 1975, 75705, 0 };
            const std::uint32_t dim13268JoeKuoD6Init[]   =   { 1, 3, 3, 7, 19, 51, 111, 233, 369, 873, 1419, 425, 6587, 11371, 29613, 28041, 77405, 0 };
            const std::uint32_t dim13269JoeKuoD6Init[]   =   { 1, 3, 1, 15, 11, 1, 65, 185, 301, 25, 75, 1353, 6879, 11519, 24093, 65223, 130659, 0 };
            const std::uint32_t dim13270JoeKuoD6Init[]   =   { 1, 1, 3, 3, 17, 17, 33, 177, 467, 841, 949, 1119, 7869, 5835, 22175, 20439, 98923, 0 };
            const std::uint32_t dim13271JoeKuoD6Init[]   =   { 1, 3, 1, 9, 1, 19, 1, 9, 487, 425, 1095, 1995, 693, 12661, 27717, 56167, 34829, 0 };
            const std::uint32_t dim13272JoeKuoD6Init[]   =   { 1, 1, 7, 7, 27, 57, 85, 159, 109, 801, 477, 3953, 3195, 11079, 26885, 59833, 4971, 0 };
            const std::uint32_t dim13273JoeKuoD6Init[]   =   { 1, 1, 1, 15, 25, 9, 89, 231, 499, 623, 1385, 3753, 4781, 15263, 12721, 17511, 67327, 0 };
            const std::uint32_t dim13274JoeKuoD6Init[]   =   { 1, 1, 3, 7, 9, 11, 103, 65, 319, 681, 1423, 2355, 6243, 399, 8483, 23697, 107995, 0 };
            const std::uint32_t dim13275JoeKuoD6Init[]   =   { 1, 1, 1, 1, 5, 7, 63, 117, 151, 905, 163, 3813, 6931, 13161, 15131, 63067, 15649, 0 };
            const std::uint32_t dim13276JoeKuoD6Init[]   =   { 1, 3, 3, 3, 13, 57, 69, 199, 283, 153, 617, 123, 3125, 3057, 8121, 14483, 28085, 0 };
            const std::uint32_t dim13277JoeKuoD6Init[]   =   { 1, 3, 7, 15, 25, 45, 25, 179, 91, 457, 681, 537, 243, 4369, 11395, 17565, 47875, 0 };
            const std::uint32_t dim13278JoeKuoD6Init[]   =   { 1, 3, 1, 13, 29, 51, 101, 23, 143, 715, 1725, 791, 6001, 4283, 10689, 49237, 5231, 0 };
            const std::uint32_t dim13279JoeKuoD6Init[]   =   { 1, 3, 3, 5, 27, 41, 39, 17, 501, 587, 1067, 1859, 9, 13449, 31257, 17675, 99769, 0 };
            const std::uint32_t dim13280JoeKuoD6Init[]   =   { 1, 1, 1, 3, 15, 57, 119, 195, 15, 779, 761, 733, 3505, 4815, 23167, 411, 52303, 0 };
            const std::uint32_t dim13281JoeKuoD6Init[]   =   { 1, 3, 1, 13, 9, 31, 5, 141, 19, 487, 739, 577, 4383, 1951, 24293, 45503, 111923, 0 };
            const std::uint32_t dim13282JoeKuoD6Init[]   =   { 1, 3, 1, 11, 25, 37, 107, 245, 89, 107, 1969, 1569, 7475, 11795, 6123, 45311, 52251, 0 };
            const std::uint32_t dim13283JoeKuoD6Init[]   =   { 1, 1, 7, 11, 15, 9, 67, 141, 199, 91, 819, 3721, 6251, 6107, 9393, 14941, 98545, 0 };
            const std::uint32_t dim13284JoeKuoD6Init[]   =   { 1, 3, 3, 11, 23, 9, 31, 211, 339, 665, 1507, 2255, 3589, 11495, 28393, 2017, 106735, 0 };
            const std::uint32_t dim13285JoeKuoD6Init[]   =   { 1, 3, 5, 11, 27, 13, 105, 217, 173, 337, 1573, 837, 3771, 8645, 28749, 27501, 45045, 0 };
            const std::uint32_t dim13286JoeKuoD6Init[]   =   { 1, 1, 5, 1, 11, 43, 99, 217, 131, 545, 1323, 3089, 5689, 785, 9043, 29961, 17855, 0 };
            const std::uint32_t dim13287JoeKuoD6Init[]   =   { 1, 1, 3, 9, 31, 41, 61, 239, 271, 123, 1583, 397, 4243, 12197, 9847, 12341, 130533, 0 };
            const std::uint32_t dim13288JoeKuoD6Init[]   =   { 1, 3, 5, 3, 27, 11, 33, 31, 77, 403, 823, 2791, 3475, 4201, 15967, 39149, 107137, 0 };
            const std::uint32_t dim13289JoeKuoD6Init[]   =   { 1, 3, 1, 11, 9, 5, 103, 145, 85, 341, 1615, 729, 7209, 10289, 20807, 54167, 15613, 0 };
            const std::uint32_t dim13290JoeKuoD6Init[]   =   { 1, 3, 7, 1, 29, 33, 91, 219, 171, 367, 907, 3645, 1059, 9031, 247, 13231, 14323, 0 };
            const std::uint32_t dim13291JoeKuoD6Init[]   =   { 1, 1, 1, 7, 19, 15, 65, 61, 221, 941, 1005, 1447, 3513, 8917, 17399, 52471, 64245, 0 };
            const std::uint32_t dim13292JoeKuoD6Init[]   =   { 1, 1, 5, 7, 5, 35, 15, 253, 325, 313, 2015, 3239, 1633, 9745, 11617, 10575, 35877, 0 };
            const std::uint32_t dim13293JoeKuoD6Init[]   =   { 1, 3, 5, 3, 13, 1, 115, 207, 227, 637, 1119, 781, 2897, 1573, 16499, 43167, 20631, 0 };
            const std::uint32_t dim13294JoeKuoD6Init[]   =   { 1, 3, 5, 9, 17, 47, 117, 7, 303, 719, 975, 1167, 2463, 5255, 28237, 33495, 57133, 0 };
            const std::uint32_t dim13295JoeKuoD6Init[]   =   { 1, 3, 5, 11, 5, 43, 123, 63, 19, 97, 1423, 695, 5985, 5923, 5755, 22721, 5411, 0 };
            const std::uint32_t dim13296JoeKuoD6Init[]   =   { 1, 3, 1, 9, 9, 25, 87, 197, 325, 827, 1679, 1561, 101, 3951, 17453, 33537, 121431, 0 };
            const std::uint32_t dim13297JoeKuoD6Init[]   =   { 1, 1, 7, 5, 13, 33, 3, 191, 171, 37, 619, 1917, 7525, 14103, 25807, 25455, 57455, 0 };
            const std::uint32_t dim13298JoeKuoD6Init[]   =   { 1, 3, 3, 1, 9, 35, 93, 159, 455, 115, 479, 665, 477, 4483, 29751, 45047, 41251, 0 };
            const std::uint32_t dim13299JoeKuoD6Init[]   =   { 1, 3, 1, 3, 11, 47, 41, 199, 511, 475, 151, 1163, 239, 6731, 4461, 39845, 99555, 0 };
            const std::uint32_t dim13300JoeKuoD6Init[]   =   { 1, 1, 5, 7, 9, 5, 49, 221, 503, 637, 1323, 3303, 4137, 6675, 17709, 49233, 38325, 0 };
            const std::uint32_t dim13301JoeKuoD6Init[]   =   { 1, 1, 5, 15, 1, 43, 55, 67, 291, 393, 237, 3555, 4171, 909, 8655, 46309, 61799, 0 };
            const std::uint32_t dim13302JoeKuoD6Init[]   =   { 1, 3, 5, 3, 3, 37, 125, 249, 509, 611, 983, 4093, 1633, 10063, 10811, 60033, 40999, 0 };
            const std::uint32_t dim13303JoeKuoD6Init[]   =   { 1, 3, 5, 11, 1, 37, 75, 255, 279, 545, 1999, 833, 2789, 14601, 16707, 64703, 53545, 0 };
            const std::uint32_t dim13304JoeKuoD6Init[]   =   { 1, 1, 5, 7, 3, 15, 59, 11, 17, 711, 721, 765, 3747, 13549, 28641, 47437, 42261, 0 };
            const std::uint32_t dim13305JoeKuoD6Init[]   =   { 1, 3, 7, 1, 3, 45, 65, 45, 279, 929, 933, 2215, 7095, 14593, 6047, 40747, 109789, 0 };
            const std::uint32_t dim13306JoeKuoD6Init[]   =   { 1, 3, 7, 15, 15, 55, 89, 155, 345, 515, 1005, 2921, 1761, 1095, 28463, 20971, 62451, 0 };
            const std::uint32_t dim13307JoeKuoD6Init[]   =   { 1, 3, 3, 1, 1, 41, 35, 149, 481, 171, 305, 1411, 237, 4515, 32375, 22645, 741, 0 };
            const std::uint32_t dim13308JoeKuoD6Init[]   =   { 1, 1, 1, 15, 17, 1, 123, 235, 221, 495, 1693, 3109, 6453, 8827, 23775, 9303, 30237, 0 };
            const std::uint32_t dim13309JoeKuoD6Init[]   =   { 1, 3, 3, 5, 7, 63, 37, 13, 457, 159, 1683, 2207, 1731, 3341, 7415, 21073, 119417, 0 };
            const std::uint32_t dim13310JoeKuoD6Init[]   =   { 1, 1, 7, 15, 21, 27, 5, 67, 267, 919, 203, 1129, 4029, 3407, 16767, 35485, 66903, 0 };
            const std::uint32_t dim13311JoeKuoD6Init[]   =   { 1, 1, 1, 5, 15, 29, 99, 5, 219, 677, 443, 3799, 2461, 747, 20885, 32661, 44079, 0 };
            const std::uint32_t dim13312JoeKuoD6Init[]   =   { 1, 1, 1, 1, 3, 55, 53, 151, 195, 587, 1155, 2439, 3817, 8735, 30849, 54107, 14113, 0 };
            const std::uint32_t dim13313JoeKuoD6Init[]   =   { 1, 1, 1, 9, 29, 15, 89, 175, 373, 925, 301, 3749, 5439, 2653, 22819, 41201, 77043, 0 };
            const std::uint32_t dim13314JoeKuoD6Init[]   =   { 1, 1, 1, 1, 25, 49, 29, 129, 331, 539, 1247, 773, 7891, 5905, 19571, 17919, 6815, 0 };
            const std::uint32_t dim13315JoeKuoD6Init[]   =   { 1, 1, 3, 15, 5, 63, 123, 133, 141, 383, 1893, 573, 629, 3939, 9455, 50433, 111415, 0 };
            const std::uint32_t dim13316JoeKuoD6Init[]   =   { 1, 1, 7, 9, 15, 33, 119, 159, 17, 511, 1841, 427, 3911, 8609, 4215, 9799, 84397, 0 };
            const std::uint32_t dim13317JoeKuoD6Init[]   =   { 1, 1, 7, 3, 9, 25, 63, 247, 235, 635, 915, 3423, 5421, 7021, 9203, 18121, 3683, 0 };
            const std::uint32_t dim13318JoeKuoD6Init[]   =   { 1, 3, 1, 1, 25, 11, 105, 1, 491, 137, 1923, 103, 3371, 3543, 5173, 36777, 23417, 0 };
            const std::uint32_t dim13319JoeKuoD6Init[]   =   { 1, 3, 3, 13, 19, 37, 93, 191, 101, 193, 351, 839, 7147, 5477, 29225, 45307, 1455, 0 };
            const std::uint32_t dim13320JoeKuoD6Init[]   =   { 1, 3, 1, 5, 11, 17, 95, 239, 105, 407, 395, 919, 3317, 14825, 23447, 4897, 128363, 0 };
            const std::uint32_t dim13321JoeKuoD6Init[]   =   { 1, 1, 1, 11, 27, 47, 83, 137, 163, 673, 1291, 3041, 4559, 7217, 23613, 19477, 93805, 0 };
            const std::uint32_t dim13322JoeKuoD6Init[]   =   { 1, 1, 1, 15, 25, 51, 37, 9, 23, 757, 1921, 2649, 5677, 11421, 10231, 1775, 124709, 0 };
            const std::uint32_t dim13323JoeKuoD6Init[]   =   { 1, 3, 1, 13, 31, 37, 37, 163, 59, 975, 1203, 1425, 1255, 3259, 16681, 38101, 118165, 0 };
            const std::uint32_t dim13324JoeKuoD6Init[]   =   { 1, 1, 3, 11, 17, 17, 31, 23, 169, 305, 3, 1631, 6853, 7019, 14539, 57663, 70377, 0 };
            const std::uint32_t dim13325JoeKuoD6Init[]   =   { 1, 1, 7, 3, 15, 61, 113, 31, 497, 935, 473, 819, 1223, 13907, 5075, 45177, 20255, 0 };
            const std::uint32_t dim13326JoeKuoD6Init[]   =   { 1, 3, 7, 13, 9, 41, 123, 121, 497, 877, 915, 3323, 4815, 4175, 25979, 38751, 107099, 0 };
            const std::uint32_t dim13327JoeKuoD6Init[]   =   { 1, 1, 3, 7, 13, 33, 31, 167, 331, 595, 517, 1237, 1947, 1905, 28155, 52431, 93065, 0 };
            const std::uint32_t dim13328JoeKuoD6Init[]   =   { 1, 3, 1, 1, 11, 51, 7, 151, 323, 211, 523, 2929, 233, 3633, 2785, 6043, 100101, 0 };
            const std::uint32_t dim13329JoeKuoD6Init[]   =   { 1, 1, 7, 13, 29, 3, 125, 247, 121, 567, 857, 3225, 7461, 15413, 773, 54939, 67443, 0 };
            const std::uint32_t dim13330JoeKuoD6Init[]   =   { 1, 1, 1, 15, 19, 29, 101, 179, 369, 115, 1777, 3223, 1499, 12487, 41, 50607, 111137, 0 };
            const std::uint32_t dim13331JoeKuoD6Init[]   =   { 1, 1, 3, 1, 9, 59, 21, 25, 173, 357, 1143, 1353, 3907, 10743, 30325, 39211, 116671, 0 };
            const std::uint32_t dim13332JoeKuoD6Init[]   =   { 1, 1, 7, 15, 9, 63, 67, 229, 7, 399, 2037, 3531, 6393, 4273, 9365, 52009, 118093, 0 };
            const std::uint32_t dim13333JoeKuoD6Init[]   =   { 1, 1, 7, 1, 31, 21, 5, 251, 433, 1, 481, 4041, 6179, 825, 8671, 20597, 103257, 0 };
            const std::uint32_t dim13334JoeKuoD6Init[]   =   { 1, 1, 7, 1, 15, 41, 69, 93, 47, 17, 1901, 2671, 4739, 1883, 30239, 50763, 108295, 0 };
            const std::uint32_t dim13335JoeKuoD6Init[]   =   { 1, 3, 7, 15, 29, 19, 63, 213, 475, 133, 43, 955, 2001, 555, 10479, 1333, 52807, 0 };
            const std::uint32_t dim13336JoeKuoD6Init[]   =   { 1, 3, 3, 15, 27, 13, 91, 109, 71, 333, 1971, 3355, 2175, 11457, 31101, 30217, 68263, 0 };
            const std::uint32_t dim13337JoeKuoD6Init[]   =   { 1, 1, 5, 1, 21, 33, 51, 169, 365, 475, 1015, 985, 7217, 15453, 7727, 49843, 57733, 0 };
            const std::uint32_t dim13338JoeKuoD6Init[]   =   { 1, 1, 7, 1, 11, 37, 67, 135, 429, 403, 1663, 2037, 7849, 3757, 6373, 38703, 46393, 0 };
            const std::uint32_t dim13339JoeKuoD6Init[]   =   { 1, 1, 1, 3, 15, 3, 29, 101, 327, 643, 47, 1805, 6873, 1659, 31097, 34847, 46843, 0 };
            const std::uint32_t dim13340JoeKuoD6Init[]   =   { 1, 3, 1, 15, 9, 45, 7, 189, 175, 955, 45, 3545, 3595, 7443, 2913, 54501, 63279, 0 };
            const std::uint32_t dim13341JoeKuoD6Init[]   =   { 1, 3, 7, 11, 1, 39, 59, 179, 209, 121, 445, 4077, 4851, 15161, 29133, 13543, 106247, 0 };
            const std::uint32_t dim13342JoeKuoD6Init[]   =   { 1, 3, 7, 7, 5, 53, 73, 107, 409, 639, 1731, 1921, 999, 14445, 17629, 3667, 74819, 0 };
            const std::uint32_t dim13343JoeKuoD6Init[]   =   { 1, 3, 3, 9, 23, 41, 117, 195, 497, 425, 627, 1599, 7715, 1401, 7217, 61113, 67135, 0 };
            const std::uint32_t dim13344JoeKuoD6Init[]   =   { 1, 1, 5, 13, 9, 33, 97, 115, 233, 833, 1041, 1755, 5317, 12703, 25709, 62293, 2569, 0 };
            const std::uint32_t dim13345JoeKuoD6Init[]   =   { 1, 1, 1, 11, 1, 7, 27, 151, 325, 905, 1279, 4093, 7495, 9803, 17339, 7977, 24009, 0 };
            const std::uint32_t dim13346JoeKuoD6Init[]   =   { 1, 3, 1, 11, 25, 59, 89, 175, 67, 139, 1507, 411, 7863, 9585, 14869, 46655, 126021, 0 };
            const std::uint32_t dim13347JoeKuoD6Init[]   =   { 1, 3, 3, 15, 29, 5, 111, 251, 69, 177, 519, 901, 4331, 5341, 22031, 3851, 114369, 0 };
            const std::uint32_t dim13348JoeKuoD6Init[]   =   { 1, 3, 5, 3, 19, 9, 83, 69, 411, 673, 1549, 3429, 3647, 12601, 17177, 16161, 114561, 0 };
            const std::uint32_t dim13349JoeKuoD6Init[]   =   { 1, 1, 5, 5, 21, 15, 65, 179, 405, 571, 1245, 3693, 7471, 12109, 20177, 28783, 124339, 0 };
            const std::uint32_t dim13350JoeKuoD6Init[]   =   { 1, 1, 5, 5, 9, 61, 69, 99, 9, 829, 1823, 3803, 1181, 3073, 10069, 28689, 21347, 0 };
            const std::uint32_t dim13351JoeKuoD6Init[]   =   { 1, 1, 5, 1, 3, 11, 25, 99, 241, 957, 1137, 7, 3809, 7073, 21217, 49447, 41425, 0 };
            const std::uint32_t dim13352JoeKuoD6Init[]   =   { 1, 3, 1, 9, 15, 59, 13, 29, 467, 893, 1667, 31, 3269, 12599, 28673, 17101, 81591, 0 };
            const std::uint32_t dim13353JoeKuoD6Init[]   =   { 1, 3, 7, 3, 15, 55, 79, 177, 1, 891, 217, 2725, 6171, 7779, 16173, 1003, 37093, 0 };
            const std::uint32_t dim13354JoeKuoD6Init[]   =   { 1, 3, 7, 11, 15, 61, 13, 181, 421, 83, 905, 1089, 4597, 3291, 23243, 53123, 21315, 0 };
            const std::uint32_t dim13355JoeKuoD6Init[]   =   { 1, 1, 3, 3, 21, 63, 113, 149, 203, 379, 583, 1955, 8087, 9155, 23019, 17757, 1537, 0 };
            const std::uint32_t dim13356JoeKuoD6Init[]   =   { 1, 3, 5, 9, 27, 41, 61, 207, 213, 253, 693, 273, 1835, 14135, 11519, 40819, 50999, 0 };
            const std::uint32_t dim13357JoeKuoD6Init[]   =   { 1, 3, 5, 3, 1, 51, 71, 237, 355, 327, 1903, 133, 6075, 4685, 29689, 48723, 67791, 0 };
            const std::uint32_t dim13358JoeKuoD6Init[]   =   { 1, 3, 5, 9, 21, 13, 101, 23, 95, 369, 1657, 989, 4081, 1373, 29005, 7247, 53923, 0 };
            const std::uint32_t dim13359JoeKuoD6Init[]   =   { 1, 1, 7, 13, 15, 3, 71, 189, 345, 771, 251, 937, 1041, 3017, 27279, 1635, 32581, 0 };
            const std::uint32_t dim13360JoeKuoD6Init[]   =   { 1, 1, 5, 7, 23, 63, 99, 43, 237, 189, 1549, 25, 63, 14089, 14387, 51423, 57193, 0 };
            const std::uint32_t dim13361JoeKuoD6Init[]   =   { 1, 1, 7, 15, 13, 55, 89, 87, 95, 241, 827, 501, 2341, 14357, 831, 27101, 98285, 0 };
            const std::uint32_t dim13362JoeKuoD6Init[]   =   { 1, 1, 1, 9, 29, 29, 125, 81, 73, 123, 329, 2617, 1259, 4415, 30007, 19467, 117847, 0 };
            const std::uint32_t dim13363JoeKuoD6Init[]   =   { 1, 3, 1, 11, 15, 63, 85, 121, 409, 885, 1197, 423, 2673, 12107, 1127, 14119, 90541, 0 };
            const std::uint32_t dim13364JoeKuoD6Init[]   =   { 1, 3, 1, 3, 1, 35, 117, 149, 213, 925, 923, 1013, 3547, 6877, 3467, 47893, 38645, 0 };
            const std::uint32_t dim13365JoeKuoD6Init[]   =   { 1, 1, 3, 15, 3, 21, 87, 199, 197, 851, 1711, 3449, 1771, 1727, 11651, 51903, 99835, 0 };
            const std::uint32_t dim13366JoeKuoD6Init[]   =   { 1, 3, 3, 1, 5, 27, 57, 243, 465, 173, 697, 4011, 6177, 3019, 31317, 24699, 53151, 0 };
            const std::uint32_t dim13367JoeKuoD6Init[]   =   { 1, 3, 5, 7, 7, 51, 61, 177, 489, 381, 493, 1975, 3143, 8003, 7735, 46363, 110705, 0 };
            const std::uint32_t dim13368JoeKuoD6Init[]   =   { 1, 1, 7, 5, 27, 45, 69, 33, 229, 725, 2033, 3655, 3027, 11795, 2941, 7921, 117605, 0 };
            const std::uint32_t dim13369JoeKuoD6Init[]   =   { 1, 3, 1, 7, 3, 37, 91, 255, 13, 651, 49, 309, 7425, 11641, 3661, 3929, 94199, 0 };
            const std::uint32_t dim13370JoeKuoD6Init[]   =   { 1, 3, 7, 5, 7, 47, 121, 203, 297, 941, 1585, 3659, 265, 159, 30729, 31825, 343, 0 };
            const std::uint32_t dim13371JoeKuoD6Init[]   =   { 1, 3, 5, 9, 3, 25, 95, 215, 125, 105, 37, 943, 4095, 8169, 26763, 20975, 122307, 0 };
            const std::uint32_t dim13372JoeKuoD6Init[]   =   { 1, 1, 3, 15, 9, 13, 81, 25, 51, 15, 599, 835, 6723, 9487, 25219, 60401, 48749, 0 };
            const std::uint32_t dim13373JoeKuoD6Init[]   =   { 1, 3, 3, 15, 15, 47, 41, 219, 77, 43, 1705, 2363, 7005, 7137, 17687, 665, 116097, 0 };
            const std::uint32_t dim13374JoeKuoD6Init[]   =   { 1, 3, 5, 1, 17, 33, 71, 3, 253, 355, 117, 1995, 3339, 11789, 13563, 58889, 18553, 0 };
            const std::uint32_t dim13375JoeKuoD6Init[]   =   { 1, 3, 5, 1, 21, 33, 89, 177, 9, 951, 1593, 1419, 3295, 9617, 31661, 7841, 119939, 0 };
            const std::uint32_t dim13376JoeKuoD6Init[]   =   { 1, 3, 3, 1, 31, 35, 25, 9, 379, 271, 923, 2387, 3351, 5869, 4501, 6855, 28273, 0 };
            const std::uint32_t dim13377JoeKuoD6Init[]   =   { 1, 1, 5, 9, 11, 15, 127, 79, 405, 579, 395, 2469, 5847, 7589, 17577, 61717, 6493, 0 };
            const std::uint32_t dim13378JoeKuoD6Init[]   =   { 1, 3, 7, 13, 29, 13, 99, 209, 79, 469, 5, 2231, 89, 1557, 5123, 47169, 46529, 0 };
            const std::uint32_t dim13379JoeKuoD6Init[]   =   { 1, 3, 7, 9, 13, 35, 119, 53, 7, 351, 601, 901, 5407, 13673, 6929, 38311, 2659, 0 };
            const std::uint32_t dim13380JoeKuoD6Init[]   =   { 1, 3, 7, 9, 13, 23, 61, 255, 113, 331, 367, 2979, 2741, 6971, 26447, 6861, 116267, 0 };
            const std::uint32_t dim13381JoeKuoD6Init[]   =   { 1, 1, 3, 3, 25, 57, 93, 5, 387, 87, 1765, 1277, 8175, 11185, 4377, 9779, 95569, 0 };
            const std::uint32_t dim13382JoeKuoD6Init[]   =   { 1, 1, 7, 11, 29, 43, 31, 155, 111, 409, 733, 1919, 2681, 8435, 5877, 35439, 15435, 0 };
            const std::uint32_t dim13383JoeKuoD6Init[]   =   { 1, 1, 1, 7, 19, 33, 109, 125, 51, 733, 997, 3467, 5081, 8371, 263, 31461, 46117, 0 };
            const std::uint32_t dim13384JoeKuoD6Init[]   =   { 1, 3, 3, 7, 27, 61, 57, 75, 317, 247, 1535, 3757, 4617, 15627, 11191, 3581, 64475, 0 };
            const std::uint32_t dim13385JoeKuoD6Init[]   =   { 1, 3, 3, 1, 31, 7, 95, 151, 159, 475, 559, 379, 361, 5953, 5551, 20313, 64015, 0 };
            const std::uint32_t dim13386JoeKuoD6Init[]   =   { 1, 1, 5, 1, 11, 31, 71, 77, 493, 697, 345, 1809, 611, 14319, 6591, 23657, 44071, 0 };
            const std::uint32_t dim13387JoeKuoD6Init[]   =   { 1, 1, 1, 13, 5, 1, 9, 233, 229, 397, 1201, 1817, 7409, 11521, 3753, 35611, 123037, 0 };
            const std::uint32_t dim13388JoeKuoD6Init[]   =   { 1, 3, 7, 15, 9, 15, 85, 163, 99, 867, 265, 1021, 129, 11059, 123, 27185, 68435, 0 };
            const std::uint32_t dim13389JoeKuoD6Init[]   =   { 1, 3, 1, 11, 25, 43, 105, 165, 291, 977, 463, 2699, 5361, 9951, 29735, 63501, 86235, 0 };
            const std::uint32_t dim13390JoeKuoD6Init[]   =   { 1, 3, 7, 13, 9, 33, 39, 145, 441, 233, 373, 193, 1451, 7975, 2871, 64431, 43339, 0 };
            const std::uint32_t dim13391JoeKuoD6Init[]   =   { 1, 1, 7, 13, 15, 25, 45, 27, 319, 719, 1801, 447, 3027, 769, 271, 37227, 26447, 0 };
            const std::uint32_t dim13392JoeKuoD6Init[]   =   { 1, 1, 5, 1, 29, 1, 59, 59, 121, 251, 387, 55, 5957, 10527, 24227, 38841, 29115, 0 };
            const std::uint32_t dim13393JoeKuoD6Init[]   =   { 1, 3, 1, 5, 31, 25, 67, 191, 137, 849, 631, 953, 3103, 9737, 28993, 49413, 60709, 0 };
            const std::uint32_t dim13394JoeKuoD6Init[]   =   { 1, 3, 3, 15, 7, 5, 37, 179, 357, 961, 1649, 441, 5287, 4161, 24013, 39661, 76233, 0 };
            const std::uint32_t dim13395JoeKuoD6Init[]   =   { 1, 1, 5, 1, 9, 1, 47, 209, 219, 1021, 969, 2343, 5675, 7137, 14247, 50305, 72613, 0 };
            const std::uint32_t dim13396JoeKuoD6Init[]   =   { 1, 1, 3, 1, 9, 43, 43, 47, 35, 97, 617, 1033, 2387, 14155, 17049, 53333, 108619, 0 };
            const std::uint32_t dim13397JoeKuoD6Init[]   =   { 1, 3, 1, 3, 1, 45, 11, 171, 349, 65, 909, 1801, 1075, 10905, 7395, 19997, 128205, 0 };
            const std::uint32_t dim13398JoeKuoD6Init[]   =   { 1, 1, 7, 11, 19, 39, 117, 175, 459, 791, 1383, 3473, 6937, 8447, 10077, 13353, 122063, 0 };
            const std::uint32_t dim13399JoeKuoD6Init[]   =   { 1, 3, 3, 9, 3, 27, 115, 29, 135, 305, 1023, 2517, 1981, 4969, 18149, 35565, 120785, 0 };
            const std::uint32_t dim13400JoeKuoD6Init[]   =   { 1, 3, 3, 11, 15, 23, 27, 115, 411, 805, 841, 2205, 5997, 5141, 10679, 25235, 81989, 0 };
            const std::uint32_t dim13401JoeKuoD6Init[]   =   { 1, 1, 3, 9, 11, 63, 27, 185, 337, 891, 1447, 1397, 8009, 4453, 23077, 37599, 93389, 0 };
            const std::uint32_t dim13402JoeKuoD6Init[]   =   { 1, 1, 5, 13, 27, 11, 77, 11, 447, 81, 1603, 2317, 6499, 6631, 27305, 51049, 40967, 0 };
            const std::uint32_t dim13403JoeKuoD6Init[]   =   { 1, 3, 7, 1, 7, 43, 83, 33, 69, 119, 139, 1391, 4879, 3759, 31211, 29203, 110229, 0 };
            const std::uint32_t dim13404JoeKuoD6Init[]   =   { 1, 3, 7, 15, 31, 59, 53, 97, 135, 233, 1421, 587, 2985, 3627, 7355, 53829, 51581, 0 };
            const std::uint32_t dim13405JoeKuoD6Init[]   =   { 1, 3, 7, 15, 1, 37, 39, 225, 147, 37, 327, 2819, 6081, 4337, 22063, 21177, 91065, 0 };
            const std::uint32_t dim13406JoeKuoD6Init[]   =   { 1, 1, 3, 1, 13, 31, 61, 133, 433, 243, 131, 3625, 6389, 335, 24029, 33217, 80833, 0 };
            const std::uint32_t dim13407JoeKuoD6Init[]   =   { 1, 1, 7, 11, 21, 39, 95, 181, 35, 499, 677, 3935, 1379, 6791, 12633, 13671, 28317, 0 };
            const std::uint32_t dim13408JoeKuoD6Init[]   =   { 1, 3, 1, 5, 7, 57, 5, 229, 389, 197, 1523, 1221, 609, 10449, 6389, 9279, 53871, 0 };
            const std::uint32_t dim13409JoeKuoD6Init[]   =   { 1, 3, 5, 7, 1, 39, 69, 131, 387, 839, 1375, 3841, 81, 7395, 5837, 32067, 51183, 0 };
            const std::uint32_t dim13410JoeKuoD6Init[]   =   { 1, 1, 5, 3, 5, 27, 107, 171, 53, 923, 345, 445, 1101, 11201, 20563, 30889, 72361, 0 };
            const std::uint32_t dim13411JoeKuoD6Init[]   =   { 1, 3, 7, 11, 19, 7, 99, 219, 485, 403, 293, 3967, 7517, 4765, 11331, 55, 92641, 0 };
            const std::uint32_t dim13412JoeKuoD6Init[]   =   { 1, 1, 7, 13, 19, 9, 73, 31, 405, 513, 941, 3645, 7075, 8109, 21431, 52791, 120927, 0 };
            const std::uint32_t dim13413JoeKuoD6Init[]   =   { 1, 1, 1, 15, 29, 33, 75, 65, 479, 47, 35, 4023, 4853, 2793, 29895, 2711, 83779, 0 };
            const std::uint32_t dim13414JoeKuoD6Init[]   =   { 1, 1, 3, 15, 11, 1, 9, 149, 503, 845, 647, 1233, 4355, 3623, 3197, 36015, 24839, 0 };
            const std::uint32_t dim13415JoeKuoD6Init[]   =   { 1, 1, 7, 1, 31, 35, 59, 25, 393, 503, 227, 3243, 301, 11121, 32463, 38185, 69969, 0 };
            const std::uint32_t dim13416JoeKuoD6Init[]   =   { 1, 1, 1, 7, 9, 15, 11, 89, 19, 605, 1657, 3335, 1967, 29, 28619, 42301, 79909, 0 };
            const std::uint32_t dim13417JoeKuoD6Init[]   =   { 1, 3, 7, 7, 19, 29, 111, 55, 299, 733, 547, 395, 4831, 1991, 7357, 25781, 115129, 0 };
            const std::uint32_t dim13418JoeKuoD6Init[]   =   { 1, 1, 3, 7, 5, 33, 31, 101, 163, 389, 1163, 1843, 4105, 14209, 29261, 5821, 17929, 0 };
            const std::uint32_t dim13419JoeKuoD6Init[]   =   { 1, 3, 5, 1, 11, 23, 53, 227, 497, 695, 313, 3305, 6549, 15401, 9339, 40283, 60531, 0 };
            const std::uint32_t dim13420JoeKuoD6Init[]   =   { 1, 3, 5, 5, 3, 29, 77, 149, 509, 747, 85, 2561, 4435, 14475, 22887, 38177, 24535, 0 };
            const std::uint32_t dim13421JoeKuoD6Init[]   =   { 1, 1, 7, 1, 1, 33, 7, 77, 153, 369, 689, 3325, 1173, 16203, 1499, 36627, 66915, 0 };
            const std::uint32_t dim13422JoeKuoD6Init[]   =   { 1, 1, 5, 11, 23, 61, 95, 61, 289, 71, 653, 2817, 365, 7391, 1613, 48901, 57471, 0 };
            const std::uint32_t dim13423JoeKuoD6Init[]   =   { 1, 3, 3, 7, 15, 29, 65, 133, 15, 921, 1601, 1941, 6917, 10945, 20101, 59809, 9017, 0 };
            const std::uint32_t dim13424JoeKuoD6Init[]   =   { 1, 3, 3, 15, 7, 51, 95, 53, 87, 1017, 1039, 3405, 1967, 9855, 4905, 4651, 83487, 0 };
            const std::uint32_t dim13425JoeKuoD6Init[]   =   { 1, 3, 5, 13, 23, 27, 31, 179, 121, 597, 829, 4003, 2487, 3977, 3087, 26791, 28305, 138357, 0 };
            const std::uint32_t dim13426JoeKuoD6Init[]   =   { 1, 1, 5, 5, 5, 39, 95, 117, 461, 117, 109, 2571, 7651, 12361, 17921, 555, 33353, 186427, 0 };
            const std::uint32_t dim13427JoeKuoD6Init[]   =   { 1, 1, 3, 13, 23, 47, 89, 125, 271, 609, 215, 3861, 6883, 3217, 2547, 54943, 60565, 215939, 0 };
            const std::uint32_t dim13428JoeKuoD6Init[]   =   { 1, 1, 7, 15, 25, 61, 47, 93, 219, 919, 1551, 1417, 2753, 4353, 9201, 46423, 31227, 150649, 0 };
            const std::uint32_t dim13429JoeKuoD6Init[]   =   { 1, 1, 1, 3, 29, 39, 11, 61, 137, 809, 147, 2715, 5455, 9431, 5725, 46135, 118193, 54099, 0 };
            const std::uint32_t dim13430JoeKuoD6Init[]   =   { 1, 1, 3, 1, 25, 37, 83, 211, 423, 779, 1731, 2827, 883, 10477, 28771, 21723, 114333, 56293, 0 };
            const std::uint32_t dim13431JoeKuoD6Init[]   =   { 1, 1, 5, 5, 27, 17, 21, 125, 495, 655, 1803, 3555, 1997, 15593, 29705, 48537, 53935, 179773, 0 };
            const std::uint32_t dim13432JoeKuoD6Init[]   =   { 1, 1, 7, 5, 19, 63, 55, 15, 469, 769, 967, 3047, 1713, 11655, 15313, 29965, 78857, 223391, 0 };
            const std::uint32_t dim13433JoeKuoD6Init[]   =   { 1, 3, 3, 5, 27, 33, 51, 171, 417, 243, 1203, 3505, 2533, 2695, 219, 57423, 5145, 143165, 0 };
            const std::uint32_t dim13434JoeKuoD6Init[]   =   { 1, 3, 5, 9, 5, 19, 95, 97, 1, 863, 693, 2977, 4839, 6649, 22587, 40745, 113839, 69131, 0 };
            const std::uint32_t dim13435JoeKuoD6Init[]   =   { 1, 3, 5, 1, 31, 39, 53, 85, 509, 5, 359, 1947, 3279, 5433, 21763, 46713, 37289, 35911, 0 };
            const std::uint32_t dim13436JoeKuoD6Init[]   =   { 1, 3, 7, 13, 17, 35, 59, 63, 95, 667, 1775, 2165, 7861, 15731, 12159, 36179, 115457, 184819, 0 };
            const std::uint32_t dim13437JoeKuoD6Init[]   =   { 1, 3, 3, 15, 19, 51, 7, 83, 367, 573, 503, 535, 333, 13041, 7187, 14479, 57473, 242951, 0 };
            const std::uint32_t dim13438JoeKuoD6Init[]   =   { 1, 3, 5, 1, 7, 27, 65, 201, 365, 445, 985, 1175, 6391, 7345, 19935, 29085, 103001, 231855, 0 };
            const std::uint32_t dim13439JoeKuoD6Init[]   =   { 1, 3, 5, 13, 15, 61, 95, 125, 135, 217, 1787, 417, 7641, 11825, 14531, 48497, 125087, 73279, 0 };
            const std::uint32_t dim13440JoeKuoD6Init[]   =   { 1, 1, 5, 13, 7, 25, 77, 99, 341, 447, 1711, 137, 2749, 3465, 26255, 719, 102595, 112825, 0 };
            const std::uint32_t dim13441JoeKuoD6Init[]   =   { 1, 1, 7, 7, 15, 13, 127, 57, 359, 591, 713, 409, 1293, 4979, 7035, 11369, 85255, 207241, 0 };
            const std::uint32_t dim13442JoeKuoD6Init[]   =   { 1, 3, 3, 5, 1, 45, 123, 183, 297, 375, 1269, 1197, 2389, 6269, 24549, 44643, 75893, 161509, 0 };
            const std::uint32_t dim13443JoeKuoD6Init[]   =   { 1, 1, 5, 7, 17, 55, 67, 51, 449, 383, 2037, 871, 1359, 15317, 22055, 4655, 18065, 258271, 0 };
            const std::uint32_t dim13444JoeKuoD6Init[]   =   { 1, 1, 3, 11, 21, 27, 59, 205, 145, 195, 1747, 1121, 1061, 8879, 31455, 56541, 74765, 183047, 0 };
            const std::uint32_t dim13445JoeKuoD6Init[]   =   { 1, 1, 5, 15, 1, 11, 69, 157, 13, 185, 1355, 467, 4383, 13103, 21679, 35169, 33427, 32113, 0 };
            const std::uint32_t dim13446JoeKuoD6Init[]   =   { 1, 3, 1, 3, 29, 41, 15, 209, 313, 61, 1749, 2457, 1897, 15595, 24441, 39913, 40499, 5179, 0 };
            const std::uint32_t dim13447JoeKuoD6Init[]   =   { 1, 3, 7, 15, 25, 41, 87, 125, 239, 73, 207, 2043, 1133, 12845, 8533, 16339, 117913, 118677, 0 };
            const std::uint32_t dim13448JoeKuoD6Init[]   =   { 1, 1, 3, 15, 25, 9, 15, 97, 395, 99, 2017, 1003, 847, 2535, 11753, 54769, 54011, 73541, 0 };
            const std::uint32_t dim13449JoeKuoD6Init[]   =   { 1, 1, 7, 15, 11, 61, 13, 49, 319, 871, 893, 165, 3957, 8683, 31197, 39491, 58705, 213411, 0 };
            const std::uint32_t dim13450JoeKuoD6Init[]   =   { 1, 3, 7, 3, 17, 43, 29, 81, 461, 595, 541, 243, 5587, 13083, 29981, 16187, 124601, 89543, 0 };
            const std::uint32_t dim13451JoeKuoD6Init[]   =   { 1, 1, 5, 11, 7, 5, 61, 43, 445, 115, 1705, 419, 4627, 15063, 16053, 26249, 112243, 208711, 0 };
            const std::uint32_t dim13452JoeKuoD6Init[]   =   { 1, 3, 3, 9, 27, 21, 89, 49, 41, 859, 681, 2043, 7445, 9591, 13443, 36981, 66785, 227899, 0 };
            const std::uint32_t dim13453JoeKuoD6Init[]   =   { 1, 1, 3, 5, 11, 55, 51, 45, 41, 739, 1199, 191, 4563, 4035, 3657, 12189, 52879, 33961, 0 };
            const std::uint32_t dim13454JoeKuoD6Init[]   =   { 1, 1, 1, 3, 17, 59, 47, 217, 389, 783, 1501, 517, 6311, 7903, 1371, 50617, 41723, 116473, 0 };
            const std::uint32_t dim13455JoeKuoD6Init[]   =   { 1, 1, 5, 13, 29, 39, 101, 203, 101, 479, 1337, 2647, 6447, 563, 2593, 16533, 122535, 25587, 0 };
            const std::uint32_t dim13456JoeKuoD6Init[]   =   { 1, 1, 3, 3, 27, 21, 75, 173, 289, 279, 665, 3177, 559, 8539, 10903, 16779, 128219, 125907, 0 };
            const std::uint32_t dim13457JoeKuoD6Init[]   =   { 1, 1, 1, 11, 27, 1, 61, 247, 113, 585, 331, 3443, 5939, 5213, 27289, 57057, 17349, 62359, 0 };
            const std::uint32_t dim13458JoeKuoD6Init[]   =   { 1, 3, 5, 15, 21, 41, 67, 47, 121, 11, 545, 3609, 7745, 3669, 9045, 8377, 97655, 99631, 0 };
            const std::uint32_t dim13459JoeKuoD6Init[]   =   { 1, 3, 5, 9, 11, 15, 111, 61, 67, 775, 579, 3421, 7827, 13607, 32373, 43531, 86149, 238827, 0 };
            const std::uint32_t dim13460JoeKuoD6Init[]   =   { 1, 1, 1, 1, 9, 45, 79, 153, 331, 399, 1777, 3515, 3363, 3499, 13461, 48651, 21731, 220611, 0 };
            const std::uint32_t dim13461JoeKuoD6Init[]   =   { 1, 1, 1, 1, 31, 57, 117, 223, 139, 725, 1115, 3203, 8185, 11983, 20245, 55913, 36803, 68101, 0 };
            const std::uint32_t dim13462JoeKuoD6Init[]   =   { 1, 1, 1, 3, 31, 57, 53, 79, 225, 307, 1645, 3311, 643, 6587, 12037, 12453, 83461, 195503, 0 };
            const std::uint32_t dim13463JoeKuoD6Init[]   =   { 1, 3, 1, 7, 23, 25, 65, 233, 273, 97, 37, 1563, 3635, 9299, 24367, 42761, 55, 128675, 0 };
            const std::uint32_t dim13464JoeKuoD6Init[]   =   { 1, 3, 3, 11, 29, 21, 97, 143, 447, 345, 389, 381, 1403, 685, 309, 11103, 69769, 194441, 0 };
            const std::uint32_t dim13465JoeKuoD6Init[]   =   { 1, 3, 3, 11, 23, 55, 119, 71, 23, 291, 1241, 1723, 5025, 4499, 26617, 22875, 62185, 240321, 0 };
            const std::uint32_t dim13466JoeKuoD6Init[]   =   { 1, 1, 7, 11, 19, 63, 31, 131, 393, 99, 1061, 3805, 7477, 15357, 8269, 26067, 113349, 239333, 0 };
            const std::uint32_t dim13467JoeKuoD6Init[]   =   { 1, 3, 5, 1, 5, 37, 77, 83, 37, 759, 1297, 3067, 5369, 5977, 7531, 49079, 94503, 192765, 0 };
            const std::uint32_t dim13468JoeKuoD6Init[]   =   { 1, 1, 7, 1, 23, 9, 119, 137, 469, 73, 2001, 2629, 2681, 2295, 2055, 44027, 47627, 45283, 0 };
            const std::uint32_t dim13469JoeKuoD6Init[]   =   { 1, 3, 1, 7, 31, 17, 61, 137, 241, 325, 1417, 2383, 4171, 2495, 215, 59593, 98495, 74727, 0 };
            const std::uint32_t dim13470JoeKuoD6Init[]   =   { 1, 1, 7, 13, 7, 5, 59, 189, 131, 865, 1963, 1811, 5629, 16189, 16397, 58069, 72081, 191457, 0 };
            const std::uint32_t dim13471JoeKuoD6Init[]   =   { 1, 1, 7, 15, 23, 33, 93, 247, 395, 643, 693, 3587, 4375, 5519, 9449, 37515, 11455, 218337, 0 };
            const std::uint32_t dim13472JoeKuoD6Init[]   =   { 1, 1, 3, 1, 27, 63, 113, 91, 477, 55, 1461, 1547, 4743, 699, 21639, 1815, 169, 34239, 0 };
            const std::uint32_t dim13473JoeKuoD6Init[]   =   { 1, 1, 5, 15, 29, 37, 19, 19, 247, 771, 695, 319, 1779, 10553, 16165, 60507, 87161, 86967, 0 };
            const std::uint32_t dim13474JoeKuoD6Init[]   =   { 1, 1, 7, 1, 25, 61, 13, 167, 251, 861, 1717, 1533, 7323, 3945, 20879, 37759, 129689, 35901, 0 };
            const std::uint32_t dim13475JoeKuoD6Init[]   =   { 1, 3, 3, 7, 7, 61, 11, 25, 187, 949, 1393, 1743, 745, 16313, 5293, 16921, 17619, 237705, 0 };
            const std::uint32_t dim13476JoeKuoD6Init[]   =   { 1, 3, 5, 11, 7, 27, 11, 107, 299, 711, 149, 1581, 7747, 14285, 6411, 52209, 79043, 61117, 0 };
            const std::uint32_t dim13477JoeKuoD6Init[]   =   { 1, 1, 5, 1, 17, 19, 91, 185, 53, 699, 1185, 4007, 1099, 1965, 20239, 19547, 120859, 234149, 0 };
            const std::uint32_t dim13478JoeKuoD6Init[]   =   { 1, 1, 5, 5, 13, 61, 117, 187, 149, 957, 837, 3549, 6221, 501, 24755, 47975, 67007, 12329, 0 };
            const std::uint32_t dim13479JoeKuoD6Init[]   =   { 1, 1, 3, 15, 21, 41, 55, 81, 397, 403, 1699, 1057, 6125, 11987, 3103, 43361, 21277, 156577, 0 };
            const std::uint32_t dim13480JoeKuoD6Init[]   =   { 1, 1, 5, 11, 5, 27, 5, 177, 387, 859, 809, 3919, 4085, 1535, 6009, 13265, 3065, 217945, 0 };
            const std::uint32_t dim13481JoeKuoD6Init[]   =   { 1, 3, 1, 13, 15, 57, 107, 81, 437, 305, 879, 1691, 3685, 11415, 3749, 46999, 113933, 10515, 0 };
            const std::uint32_t dim13482JoeKuoD6Init[]   =   { 1, 1, 7, 13, 9, 43, 59, 223, 189, 329, 829, 2033, 1835, 8255, 8121, 46463, 61433, 86453, 0 };
            const std::uint32_t dim13483JoeKuoD6Init[]   =   { 1, 3, 1, 9, 11, 49, 63, 125, 11, 987, 2017, 2623, 4753, 13889, 57, 24755, 108489, 175383, 0 };
            const std::uint32_t dim13484JoeKuoD6Init[]   =   { 1, 1, 1, 3, 25, 33, 39, 151, 405, 657, 1755, 957, 5557, 7611, 25839, 51385, 92713, 64009, 0 };
            const std::uint32_t dim13485JoeKuoD6Init[]   =   { 1, 3, 7, 9, 17, 17, 115, 89, 225, 715, 1085, 543, 1047, 15053, 14359, 43301, 31455, 156555, 0 };
            const std::uint32_t dim13486JoeKuoD6Init[]   =   { 1, 1, 7, 11, 11, 21, 115, 5, 371, 1003, 1053, 1713, 5921, 7277, 799, 62483, 28079, 222319, 0 };
            const std::uint32_t dim13487JoeKuoD6Init[]   =   { 1, 1, 3, 3, 31, 15, 127, 213, 459, 229, 1477, 1863, 1021, 14881, 16299, 5953, 121455, 49659, 0 };
            const std::uint32_t dim13488JoeKuoD6Init[]   =   { 1, 1, 5, 9, 3, 39, 87, 219, 57, 479, 69, 2777, 8105, 11975, 14743, 26205, 93303, 45311, 0 };
            const std::uint32_t dim13489JoeKuoD6Init[]   =   { 1, 1, 5, 13, 3, 43, 55, 139, 19, 715, 2035, 2993, 2945, 9075, 6275, 32233, 103127, 49523, 0 };
            const std::uint32_t dim13490JoeKuoD6Init[]   =   { 1, 3, 1, 13, 19, 31, 109, 211, 261, 231, 697, 383, 2173, 14617, 11877, 37009, 5485, 236549, 0 };
            const std::uint32_t dim13491JoeKuoD6Init[]   =   { 1, 1, 5, 3, 5, 23, 91, 115, 369, 11, 1021, 519, 655, 4461, 23743, 56981, 51687, 114845, 0 };
            const std::uint32_t dim13492JoeKuoD6Init[]   =   { 1, 3, 7, 9, 29, 23, 19, 127, 17, 369, 1537, 2705, 4993, 1869, 15447, 28127, 73609, 97683, 0 };
            const std::uint32_t dim13493JoeKuoD6Init[]   =   { 1, 1, 3, 9, 17, 61, 97, 187, 213, 861, 725, 3205, 103, 12729, 2915, 28389, 83123, 124065, 0 };
            const std::uint32_t dim13494JoeKuoD6Init[]   =   { 1, 3, 1, 1, 5, 61, 47, 187, 471, 137, 1595, 707, 2449, 14315, 16409, 41467, 37533, 1649, 0 };
            const std::uint32_t dim13495JoeKuoD6Init[]   =   { 1, 3, 5, 5, 7, 39, 1, 245, 361, 43, 1259, 3149, 3449, 15723, 6225, 27445, 80529, 215349, 0 };
            const std::uint32_t dim13496JoeKuoD6Init[]   =   { 1, 3, 3, 11, 17, 27, 37, 47, 157, 345, 1437, 3219, 5663, 7299, 23925, 34067, 102379, 42767, 0 };
            const std::uint32_t dim13497JoeKuoD6Init[]   =   { 1, 3, 5, 13, 21, 59, 43, 189, 17, 303, 1949, 3627, 3495, 7981, 18115, 34221, 43511, 255257, 0 };
            const std::uint32_t dim13498JoeKuoD6Init[]   =   { 1, 3, 7, 15, 3, 29, 81, 243, 321, 853, 595, 2451, 1713, 11859, 27689, 12849, 24505, 9547, 0 };
            const std::uint32_t dim13499JoeKuoD6Init[]   =   { 1, 3, 1, 3, 7, 7, 89, 183, 51, 901, 253, 2421, 7453, 15827, 21451, 58653, 51933, 239113, 0 };
            const std::uint32_t dim13500JoeKuoD6Init[]   =   { 1, 1, 7, 3, 21, 59, 93, 25, 219, 805, 1699, 3777, 3683, 5351, 5481, 44797, 651, 32161, 0 };
            const std::uint32_t dim13501JoeKuoD6Init[]   =   { 1, 3, 7, 5, 31, 15, 15, 167, 305, 545, 331, 3765, 8191, 5763, 16965, 7239, 73735, 1049, 0 };
            const std::uint32_t dim13502JoeKuoD6Init[]   =   { 1, 3, 1, 15, 13, 19, 59, 107, 213, 39, 1547, 3413, 6175, 16195, 4635, 8945, 60301, 196697, 0 };
            const std::uint32_t dim13503JoeKuoD6Init[]   =   { 1, 1, 3, 1, 29, 17, 51, 61, 261, 951, 643, 2329, 2235, 9171, 11265, 3523, 89781, 227125, 0 };
            const std::uint32_t dim13504JoeKuoD6Init[]   =   { 1, 3, 5, 1, 1, 51, 75, 199, 479, 899, 1425, 3697, 2039, 4503, 11789, 16853, 94607, 236887, 0 };
            const std::uint32_t dim13505JoeKuoD6Init[]   =   { 1, 3, 1, 9, 19, 43, 111, 41, 385, 677, 1067, 3391, 7819, 13663, 17713, 10155, 124243, 56005, 0 };
            const std::uint32_t dim13506JoeKuoD6Init[]   =   { 1, 3, 5, 3, 15, 3, 105, 23, 307, 955, 843, 1277, 6697, 11903, 8901, 36129, 51685, 251115, 0 };
            const std::uint32_t dim13507JoeKuoD6Init[]   =   { 1, 3, 1, 5, 27, 35, 95, 57, 207, 49, 1559, 171, 4703, 511, 4169, 23241, 111447, 173109, 0 };
            const std::uint32_t dim13508JoeKuoD6Init[]   =   { 1, 3, 1, 13, 23, 5, 31, 15, 223, 673, 1333, 2243, 2479, 7489, 31891, 33909, 96803, 227027, 0 };
            const std::uint32_t dim13509JoeKuoD6Init[]   =   { 1, 3, 5, 11, 5, 45, 19, 13, 367, 475, 1719, 3947, 5295, 2319, 20697, 181, 16925, 80239, 0 };
            const std::uint32_t dim13510JoeKuoD6Init[]   =   { 1, 1, 5, 13, 15, 47, 89, 15, 153, 73, 523, 3529, 5401, 15881, 13779, 32123, 82347, 58749, 0 };
            const std::uint32_t dim13511JoeKuoD6Init[]   =   { 1, 3, 5, 7, 5, 7, 123, 217, 261, 65, 685, 2175, 3289, 7473, 17857, 48335, 94183, 216857, 0 };
            const std::uint32_t dim13512JoeKuoD6Init[]   =   { 1, 3, 7, 13, 7, 23, 85, 25, 231, 19, 1179, 2705, 6433, 10827, 1969, 51521, 76775, 260291, 0 };
            const std::uint32_t dim13513JoeKuoD6Init[]   =   { 1, 3, 3, 13, 9, 39, 5, 141, 475, 777, 1809, 1975, 2347, 12611, 28303, 15239, 45429, 170015, 0 };
            const std::uint32_t dim13514JoeKuoD6Init[]   =   { 1, 1, 7, 7, 31, 31, 39, 19, 317, 897, 739, 275, 2261, 16013, 1123, 33181, 96603, 37563, 0 };
            const std::uint32_t dim13515JoeKuoD6Init[]   =   { 1, 1, 7, 13, 31, 55, 87, 239, 193, 435, 625, 2153, 3979, 15537, 19937, 50621, 48273, 31381, 0 };
            const std::uint32_t dim13516JoeKuoD6Init[]   =   { 1, 1, 1, 15, 1, 57, 73, 237, 361, 749, 379, 2511, 501, 10783, 2787, 36983, 12393, 14345, 0 };
            const std::uint32_t dim13517JoeKuoD6Init[]   =   { 1, 1, 1, 3, 25, 33, 85, 25, 83, 939, 139, 2601, 6385, 16041, 28463, 38977, 28163, 232165, 0 };
            const std::uint32_t dim13518JoeKuoD6Init[]   =   { 1, 3, 5, 3, 9, 19, 119, 171, 499, 19, 569, 353, 1619, 6235, 24431, 47401, 48125, 168819, 0 };
            const std::uint32_t dim13519JoeKuoD6Init[]   =   { 1, 1, 1, 3, 9, 27, 121, 137, 411, 391, 1437, 1339, 7475, 3889, 15451, 34809, 69807, 162851, 0 };
            const std::uint32_t dim13520JoeKuoD6Init[]   =   { 1, 3, 5, 11, 31, 39, 41, 3, 171, 35, 81, 2713, 1077, 10697, 12343, 52133, 52825, 152255, 0 };
            const std::uint32_t dim13521JoeKuoD6Init[]   =   { 1, 1, 3, 11, 17, 51, 83, 19, 357, 207, 897, 2167, 1333, 4111, 29295, 65371, 73447, 61765, 0 };
            const std::uint32_t dim13522JoeKuoD6Init[]   =   { 1, 1, 3, 7, 9, 59, 17, 135, 365, 931, 1203, 277, 5531, 4213, 12969, 2617, 591, 154539, 0 };
            const std::uint32_t dim13523JoeKuoD6Init[]   =   { 1, 3, 7, 11, 1, 53, 31, 49, 135, 603, 227, 911, 7371, 8559, 27195, 33065, 71351, 245255, 0 };
            const std::uint32_t dim13524JoeKuoD6Init[]   =   { 1, 1, 7, 1, 15, 5, 31, 135, 197, 791, 1531, 2567, 2545, 15515, 25417, 27431, 15571, 176829, 0 };
            const std::uint32_t dim13525JoeKuoD6Init[]   =   { 1, 3, 1, 1, 15, 7, 89, 217, 505, 859, 1329, 2285, 7921, 11839, 7699, 56867, 112483, 3895, 0 };
            const std::uint32_t dim13526JoeKuoD6Init[]   =   { 1, 3, 1, 3, 27, 57, 37, 117, 491, 815, 275, 381, 7443, 3297, 1523, 34211, 97589, 232261, 0 };
            const std::uint32_t dim13527JoeKuoD6Init[]   =   { 1, 1, 3, 3, 29, 63, 69, 153, 297, 423, 1435, 3927, 7265, 13223, 17607, 21201, 57929, 73037, 0 };
            const std::uint32_t dim13528JoeKuoD6Init[]   =   { 1, 3, 1, 3, 23, 41, 1, 167, 121, 217, 973, 2149, 3807, 9895, 29635, 1625, 99829, 218541, 0 };
            const std::uint32_t dim13529JoeKuoD6Init[]   =   { 1, 3, 5, 7, 31, 33, 53, 165, 51, 119, 7, 1655, 6521, 5481, 9503, 6833, 80483, 252111, 0 };
            const std::uint32_t dim13530JoeKuoD6Init[]   =   { 1, 1, 7, 1, 5, 63, 25, 219, 165, 893, 1665, 2789, 1113, 9277, 3151, 12625, 82403, 59749, 0 };
            const std::uint32_t dim13531JoeKuoD6Init[]   =   { 1, 3, 7, 3, 21, 13, 127, 127, 145, 993, 715, 1947, 7501, 4385, 11759, 2179, 26039, 28027, 0 };
            const std::uint32_t dim13532JoeKuoD6Init[]   =   { 1, 3, 5, 9, 23, 27, 123, 1, 231, 709, 1615, 1433, 5991, 1045, 16269, 123, 110249, 154819, 0 };
            const std::uint32_t dim13533JoeKuoD6Init[]   =   { 1, 1, 1, 5, 17, 11, 123, 151, 387, 905, 991, 1571, 4463, 6765, 31905, 59307, 75175, 204571, 0 };
            const std::uint32_t dim13534JoeKuoD6Init[]   =   { 1, 3, 1, 11, 27, 49, 1, 181, 77, 1023, 807, 3479, 7965, 4633, 17495, 5991, 77081, 249343, 0 };
            const std::uint32_t dim13535JoeKuoD6Init[]   =   { 1, 3, 1, 1, 13, 53, 105, 79, 269, 173, 1319, 1695, 1215, 3651, 25063, 34949, 77243, 214671, 0 };
            const std::uint32_t dim13536JoeKuoD6Init[]   =   { 1, 1, 1, 1, 3, 19, 103, 233, 1, 507, 721, 1797, 5025, 405, 13027, 23693, 89963, 25771, 0 };
            const std::uint32_t dim13537JoeKuoD6Init[]   =   { 1, 3, 5, 9, 21, 53, 1, 241, 405, 707, 1807, 3615, 1199, 11155, 27741, 53931, 55091, 248677, 0 };
            const std::uint32_t dim13538JoeKuoD6Init[]   =   { 1, 3, 5, 7, 27, 27, 39, 77, 475, 845, 1393, 3779, 5261, 13017, 13517, 18595, 64485, 180577, 0 };
            const std::uint32_t dim13539JoeKuoD6Init[]   =   { 1, 1, 3, 5, 7, 21, 95, 59, 203, 233, 1167, 3457, 3965, 4321, 14885, 6335, 78353, 39341, 0 };
            const std::uint32_t dim13540JoeKuoD6Init[]   =   { 1, 1, 7, 13, 27, 19, 27, 133, 419, 507, 945, 3595, 131, 7981, 31451, 62347, 19151, 256127, 0 };
            const std::uint32_t dim13541JoeKuoD6Init[]   =   { 1, 3, 7, 3, 7, 15, 9, 173, 257, 983, 223, 2881, 6911, 3681, 26183, 38943, 112171, 148627, 0 };
            const std::uint32_t dim13542JoeKuoD6Init[]   =   { 1, 3, 3, 15, 5, 49, 91, 205, 303, 183, 775, 3841, 4943, 14417, 23013, 59337, 85835, 181771, 0 };
            const std::uint32_t dim13543JoeKuoD6Init[]   =   { 1, 3, 5, 9, 21, 1, 117, 27, 509, 263, 1215, 893, 6677, 3275, 20831, 5045, 127323, 62589, 0 };
            const std::uint32_t dim13544JoeKuoD6Init[]   =   { 1, 1, 1, 3, 17, 61, 77, 239, 379, 649, 1151, 2359, 2659, 13853, 30589, 55873, 50359, 184125, 0 };
            const std::uint32_t dim13545JoeKuoD6Init[]   =   { 1, 1, 7, 5, 17, 33, 95, 111, 245, 873, 1721, 3079, 7753, 12889, 27107, 8267, 119413, 249045, 0 };
            const std::uint32_t dim13546JoeKuoD6Init[]   =   { 1, 1, 1, 15, 13, 23, 59, 169, 449, 283, 913, 2099, 5337, 4307, 3701, 16395, 112987, 14183, 0 };
            const std::uint32_t dim13547JoeKuoD6Init[]   =   { 1, 1, 5, 3, 5, 15, 3, 249, 97, 849, 1551, 3437, 1247, 10915, 24073, 53723, 40345, 37215, 0 };
            const std::uint32_t dim13548JoeKuoD6Init[]   =   { 1, 1, 1, 5, 21, 59, 109, 79, 9, 827, 1329, 405, 3821, 8415, 11239, 1003, 78967, 112627, 0 };
            const std::uint32_t dim13549JoeKuoD6Init[]   =   { 1, 1, 1, 11, 21, 7, 21, 45, 327, 365, 865, 1409, 1273, 15675, 21425, 45367, 22279, 240943, 0 };
            const std::uint32_t dim13550JoeKuoD6Init[]   =   { 1, 3, 3, 7, 3, 19, 83, 163, 381, 547, 195, 1537, 7905, 9057, 1309, 41135, 118857, 101725, 0 };
            const std::uint32_t dim13551JoeKuoD6Init[]   =   { 1, 1, 5, 9, 11, 19, 107, 247, 309, 343, 1697, 699, 7137, 12815, 18405, 42673, 505, 104801, 0 };
            const std::uint32_t dim13552JoeKuoD6Init[]   =   { 1, 3, 5, 3, 13, 43, 55, 15, 441, 843, 1153, 3739, 67, 11053, 30985, 55329, 57301, 190991, 0 };
            const std::uint32_t dim13553JoeKuoD6Init[]   =   { 1, 1, 5, 3, 23, 41, 9, 239, 227, 145, 1895, 2645, 945, 6421, 2859, 16173, 97043, 234649, 0 };
            const std::uint32_t dim13554JoeKuoD6Init[]   =   { 1, 3, 1, 3, 23, 47, 57, 207, 441, 279, 1951, 3041, 2465, 6143, 27669, 41171, 89627, 2489, 0 };
            const std::uint32_t dim13555JoeKuoD6Init[]   =   { 1, 3, 1, 11, 7, 9, 19, 51, 345, 187, 1699, 1483, 15, 10321, 25277, 34889, 85225, 259071, 0 };
            const std::uint32_t dim13556JoeKuoD6Init[]   =   { 1, 1, 1, 15, 27, 15, 79, 51, 407, 757, 611, 3955, 1123, 14659, 11273, 56639, 64727, 183077, 0 };
            const std::uint32_t dim13557JoeKuoD6Init[]   =   { 1, 3, 7, 1, 13, 61, 89, 157, 29, 561, 791, 995, 4233, 11351, 16335, 47041, 108671, 120115, 0 };
            const std::uint32_t dim13558JoeKuoD6Init[]   =   { 1, 3, 3, 15, 17, 35, 15, 223, 57, 7, 961, 3327, 7287, 5537, 26231, 3289, 106555, 109781, 0 };
            const std::uint32_t dim13559JoeKuoD6Init[]   =   { 1, 3, 7, 15, 17, 3, 25, 121, 349, 995, 1353, 2991, 3071, 3583, 26173, 42343, 60495, 44035, 0 };
            const std::uint32_t dim13560JoeKuoD6Init[]   =   { 1, 3, 1, 11, 5, 5, 83, 249, 427, 173, 1733, 45, 3277, 7911, 18091, 61305, 130251, 31849, 0 };
            const std::uint32_t dim13561JoeKuoD6Init[]   =   { 1, 1, 1, 9, 3, 23, 23, 127, 371, 1011, 573, 1769, 1707, 15351, 30077, 61139, 122963, 203481, 0 };
            const std::uint32_t dim13562JoeKuoD6Init[]   =   { 1, 1, 1, 13, 27, 41, 97, 29, 461, 207, 1393, 707, 5633, 7155, 13455, 7305, 107539, 136413, 0 };
            const std::uint32_t dim13563JoeKuoD6Init[]   =   { 1, 1, 1, 9, 3, 13, 61, 115, 297, 333, 1679, 127, 8049, 3129, 31845, 40039, 77087, 6831, 0 };
            const std::uint32_t dim13564JoeKuoD6Init[]   =   { 1, 3, 3, 11, 27, 25, 49, 29, 423, 193, 1955, 2927, 5679, 3537, 16911, 47065, 126803, 129957, 0 };
            const std::uint32_t dim13565JoeKuoD6Init[]   =   { 1, 1, 1, 3, 21, 31, 25, 187, 301, 883, 1301, 415, 1515, 14761, 227, 24377, 54415, 64553, 0 };
            const std::uint32_t dim13566JoeKuoD6Init[]   =   { 1, 3, 7, 7, 3, 5, 69, 221, 357, 587, 1387, 3719, 5355, 10569, 14731, 22515, 107237, 1673, 0 };
            const std::uint32_t dim13567JoeKuoD6Init[]   =   { 1, 1, 3, 15, 27, 7, 89, 23, 213, 655, 779, 1641, 1793, 1499, 27279, 59423, 56715, 90313, 0 };
            const std::uint32_t dim13568JoeKuoD6Init[]   =   { 1, 3, 3, 7, 3, 33, 85, 181, 509, 327, 353, 1625, 4995, 15627, 17071, 31885, 122423, 100337, 0 };
            const std::uint32_t dim13569JoeKuoD6Init[]   =   { 1, 3, 5, 9, 7, 39, 45, 157, 279, 211, 1163, 3283, 4419, 10187, 22397, 42119, 25105, 163925, 0 };
            const std::uint32_t dim13570JoeKuoD6Init[]   =   { 1, 3, 3, 15, 17, 37, 75, 65, 501, 765, 1171, 2451, 309, 551, 15573, 65497, 106435, 20817, 0 };
            const std::uint32_t dim13571JoeKuoD6Init[]   =   { 1, 1, 3, 1, 13, 1, 79, 117, 5, 285, 953, 2401, 2479, 15765, 25677, 63611, 91807, 78153, 0 };
            const std::uint32_t dim13572JoeKuoD6Init[]   =   { 1, 1, 5, 15, 1, 7, 123, 159, 217, 307, 1779, 2625, 101, 13887, 31721, 55769, 94899, 183427, 0 };
            const std::uint32_t dim13573JoeKuoD6Init[]   =   { 1, 3, 5, 5, 11, 13, 59, 205, 221, 871, 753, 823, 547, 11055, 31621, 54379, 23631, 137027, 0 };
            const std::uint32_t dim13574JoeKuoD6Init[]   =   { 1, 3, 3, 7, 5, 17, 7, 31, 37, 237, 1633, 969, 4123, 6643, 28499, 3277, 130223, 37465, 0 };
            const std::uint32_t dim13575JoeKuoD6Init[]   =   { 1, 3, 7, 5, 29, 41, 65, 159, 487, 61, 1217, 4093, 487, 15257, 13379, 46641, 88043, 107425, 0 };
            const std::uint32_t dim13576JoeKuoD6Init[]   =   { 1, 1, 7, 7, 19, 29, 87, 119, 13, 877, 467, 2661, 7733, 9303, 20069, 8445, 126159, 69421, 0 };
            const std::uint32_t dim13577JoeKuoD6Init[]   =   { 1, 3, 1, 13, 1, 57, 77, 241, 185, 479, 859, 2397, 1167, 6545, 20715, 50701, 107781, 149965, 0 };
            const std::uint32_t dim13578JoeKuoD6Init[]   =   { 1, 1, 5, 1, 1, 3, 19, 31, 473, 685, 1455, 1537, 1843, 4051, 17475, 56717, 70257, 112815, 0 };
            const std::uint32_t dim13579JoeKuoD6Init[]   =   { 1, 3, 7, 15, 9, 21, 19, 201, 13, 551, 1053, 1291, 3793, 7923, 30425, 55513, 30033, 70597, 0 };
            const std::uint32_t dim13580JoeKuoD6Init[]   =   { 1, 3, 1, 15, 21, 47, 127, 117, 199, 655, 1979, 1291, 8017, 11769, 9071, 12029, 112369, 2529, 0 };
            const std::uint32_t dim13581JoeKuoD6Init[]   =   { 1, 3, 5, 1, 15, 3, 25, 199, 101, 997, 597, 2485, 6509, 11913, 19573, 13985, 56165, 249, 0 };
            const std::uint32_t dim13582JoeKuoD6Init[]   =   { 1, 1, 7, 3, 19, 45, 107, 229, 241, 747, 1219, 3133, 3675, 4441, 13933, 64571, 95445, 250713, 0 };
            const std::uint32_t dim13583JoeKuoD6Init[]   =   { 1, 3, 1, 5, 11, 31, 89, 119, 503, 99, 75, 349, 7479, 15161, 6365, 62461, 39443, 188455, 0 };
            const std::uint32_t dim13584JoeKuoD6Init[]   =   { 1, 1, 5, 13, 25, 31, 65, 237, 259, 329, 89, 1283, 6033, 4401, 7655, 38837, 62367, 76555, 0 };
            const std::uint32_t dim13585JoeKuoD6Init[]   =   { 1, 1, 1, 7, 19, 61, 109, 41, 361, 89, 171, 2319, 3625, 8905, 24461, 36135, 28515, 101547, 0 };
            const std::uint32_t dim13586JoeKuoD6Init[]   =   { 1, 3, 5, 3, 5, 45, 123, 227, 339, 79, 309, 2619, 1621, 1295, 6395, 6717, 119933, 187231, 0 };
            const std::uint32_t dim13587JoeKuoD6Init[]   =   { 1, 1, 1, 3, 3, 45, 91, 225, 269, 475, 1159, 2599, 5087, 4141, 28375, 22413, 56235, 256559, 0 };
            const std::uint32_t dim13588JoeKuoD6Init[]   =   { 1, 1, 1, 13, 7, 51, 27, 65, 65, 381, 169, 1759, 4653, 9885, 25839, 19851, 4965, 249097, 0 };
            const std::uint32_t dim13589JoeKuoD6Init[]   =   { 1, 3, 7, 11, 25, 11, 83, 137, 419, 277, 503, 2823, 2759, 8173, 9405, 23731, 116087, 9735, 0 };
            const std::uint32_t dim13590JoeKuoD6Init[]   =   { 1, 1, 5, 5, 27, 17, 123, 145, 41, 85, 1099, 1087, 1465, 7063, 8585, 39427, 15479, 243967, 0 };
            const std::uint32_t dim13591JoeKuoD6Init[]   =   { 1, 1, 7, 3, 21, 53, 105, 185, 101, 763, 593, 2649, 3273, 5655, 12233, 11761, 27093, 121347, 0 };
            const std::uint32_t dim13592JoeKuoD6Init[]   =   { 1, 1, 1, 5, 11, 55, 107, 167, 179, 681, 741, 1821, 4297, 14677, 9949, 9647, 60465, 36999, 0 };
            const std::uint32_t dim13593JoeKuoD6Init[]   =   { 1, 1, 1, 7, 25, 43, 95, 71, 161, 517, 1475, 1989, 6273, 13295, 19681, 51773, 93523, 33441, 0 };
            const std::uint32_t dim13594JoeKuoD6Init[]   =   { 1, 3, 1, 13, 23, 59, 95, 177, 73, 707, 37, 421, 3747, 14207, 17159, 4957, 20161, 26185, 0 };
            const std::uint32_t dim13595JoeKuoD6Init[]   =   { 1, 1, 7, 13, 13, 1, 19, 153, 445, 429, 1911, 3515, 639, 16015, 833, 54347, 87717, 82175, 0 };
            const std::uint32_t dim13596JoeKuoD6Init[]   =   { 1, 3, 5, 9, 1, 9, 115, 87, 341, 651, 1583, 807, 559, 13579, 9647, 37277, 125555, 169655, 0 };
            const std::uint32_t dim13597JoeKuoD6Init[]   =   { 1, 1, 3, 5, 13, 23, 117, 229, 205, 803, 1381, 2773, 7099, 4031, 597, 37135, 11643, 92325, 0 };
            const std::uint32_t dim13598JoeKuoD6Init[]   =   { 1, 3, 7, 9, 27, 15, 33, 147, 1, 799, 1511, 2609, 1419, 5991, 15571, 56995, 97695, 223969, 0 };
            const std::uint32_t dim13599JoeKuoD6Init[]   =   { 1, 3, 1, 3, 17, 9, 17, 189, 407, 355, 765, 2545, 1079, 15253, 4785, 5187, 80775, 238775, 0 };
            const std::uint32_t dim13600JoeKuoD6Init[]   =   { 1, 1, 3, 1, 31, 29, 3, 159, 263, 325, 125, 2221, 6369, 5717, 13985, 33829, 21375, 134249, 0 };
            const std::uint32_t dim13601JoeKuoD6Init[]   =   { 1, 3, 7, 3, 5, 29, 39, 75, 183, 155, 1017, 637, 921, 9561, 14893, 59695, 38325, 15503, 0 };
            const std::uint32_t dim13602JoeKuoD6Init[]   =   { 1, 1, 3, 13, 9, 31, 43, 71, 241, 661, 325, 357, 431, 903, 5039, 24535, 94241, 228605, 0 };
            const std::uint32_t dim13603JoeKuoD6Init[]   =   { 1, 3, 1, 1, 17, 37, 93, 47, 25, 207, 611, 415, 6473, 15979, 2025, 19003, 8941, 248779, 0 };
            const std::uint32_t dim13604JoeKuoD6Init[]   =   { 1, 1, 7, 15, 19, 17, 81, 201, 121, 11, 1975, 1289, 4405, 7851, 9707, 20057, 33749, 187161, 0 };
            const std::uint32_t dim13605JoeKuoD6Init[]   =   { 1, 1, 3, 5, 29, 31, 47, 99, 435, 795, 947, 1299, 4011, 8315, 12827, 48071, 86567, 154655, 0 };
            const std::uint32_t dim13606JoeKuoD6Init[]   =   { 1, 1, 5, 3, 9, 59, 115, 191, 177, 65, 1835, 3989, 1819, 14325, 8939, 25337, 16099, 200577, 0 };
            const std::uint32_t dim13607JoeKuoD6Init[]   =   { 1, 3, 7, 9, 15, 47, 7, 195, 413, 1013, 1607, 3317, 6979, 13243, 275, 34125, 66069, 90201, 0 };
            const std::uint32_t dim13608JoeKuoD6Init[]   =   { 1, 1, 3, 3, 29, 3, 51, 137, 341, 393, 897, 351, 1937, 6793, 12551, 18873, 110949, 133925, 0 };
            const std::uint32_t dim13609JoeKuoD6Init[]   =   { 1, 3, 5, 9, 29, 41, 79, 169, 113, 123, 1229, 1885, 6153, 1549, 31729, 41949, 74083, 41387, 0 };
            const std::uint32_t dim13610JoeKuoD6Init[]   =   { 1, 3, 1, 15, 31, 49, 7, 233, 305, 435, 1299, 3037, 2387, 15431, 817, 11783, 24067, 116527, 0 };
            const std::uint32_t dim13611JoeKuoD6Init[]   =   { 1, 3, 5, 13, 7, 17, 49, 33, 133, 45, 689, 2381, 2649, 2433, 27535, 21755, 88611, 200585, 0 };
            const std::uint32_t dim13612JoeKuoD6Init[]   =   { 1, 1, 5, 11, 1, 61, 87, 97, 91, 433, 313, 2541, 5289, 5769, 17963, 5719, 12165, 146849, 0 };
            const std::uint32_t dim13613JoeKuoD6Init[]   =   { 1, 3, 7, 13, 17, 21, 37, 191, 489, 847, 841, 3567, 7339, 15233, 23973, 1209, 99741, 243303, 0 };
            const std::uint32_t dim13614JoeKuoD6Init[]   =   { 1, 3, 1, 1, 5, 21, 11, 39, 69, 751, 1679, 143, 6187, 2963, 695, 45763, 126749, 243841, 0 };
            const std::uint32_t dim13615JoeKuoD6Init[]   =   { 1, 3, 3, 9, 21, 55, 43, 73, 133, 417, 495, 2899, 5681, 13049, 30241, 44519, 19095, 30673, 0 };
            const std::uint32_t dim13616JoeKuoD6Init[]   =   { 1, 1, 5, 9, 17, 51, 121, 205, 273, 597, 1325, 3755, 5113, 12287, 21323, 17947, 23807, 20025, 0 };
            const std::uint32_t dim13617JoeKuoD6Init[]   =   { 1, 1, 7, 7, 21, 11, 25, 33, 207, 13, 1639, 1971, 7401, 11771, 7879, 59027, 111981, 65451, 0 };
            const std::uint32_t dim13618JoeKuoD6Init[]   =   { 1, 3, 5, 15, 3, 15, 121, 23, 199, 839, 937, 3659, 5379, 2139, 31631, 17215, 65349, 157413, 0 };
            const std::uint32_t dim13619JoeKuoD6Init[]   =   { 1, 1, 1, 7, 3, 7, 81, 49, 17, 693, 1819, 2737, 7329, 49, 1655, 42317, 31385, 11435, 0 };
            const std::uint32_t dim13620JoeKuoD6Init[]   =   { 1, 3, 5, 15, 25, 51, 121, 133, 457, 159, 869, 855, 3529, 2691, 147, 58621, 78379, 148519, 0 };
            const std::uint32_t dim13621JoeKuoD6Init[]   =   { 1, 1, 3, 7, 1, 53, 109, 81, 37, 553, 1921, 3081, 2665, 12665, 13887, 1035, 16987, 48883, 0 };
            const std::uint32_t dim13622JoeKuoD6Init[]   =   { 1, 1, 5, 1, 19, 1, 121, 97, 143, 871, 1401, 2879, 5657, 5479, 14011, 65131, 56011, 241055, 0 };
            const std::uint32_t dim13623JoeKuoD6Init[]   =   { 1, 1, 7, 5, 9, 21, 9, 43, 331, 183, 1313, 2495, 6905, 2763, 29567, 7579, 95169, 130937, 0 };
            const std::uint32_t dim13624JoeKuoD6Init[]   =   { 1, 3, 7, 3, 3, 37, 65, 195, 339, 527, 1383, 3063, 7749, 11109, 8097, 27257, 107615, 134241, 0 };
            const std::uint32_t dim13625JoeKuoD6Init[]   =   { 1, 1, 1, 5, 25, 25, 63, 179, 135, 65, 169, 2709, 5435, 12119, 21549, 59847, 129639, 220163, 0 };
            const std::uint32_t dim13626JoeKuoD6Init[]   =   { 1, 3, 5, 1, 3, 17, 87, 181, 9, 923, 731, 3397, 7079, 3281, 10455, 35471, 20439, 206209, 0 };
            const std::uint32_t dim13627JoeKuoD6Init[]   =   { 1, 1, 1, 5, 31, 25, 15, 89, 381, 675, 1217, 3175, 707, 585, 1695, 57771, 92433, 203523, 0 };
            const std::uint32_t dim13628JoeKuoD6Init[]   =   { 1, 3, 5, 15, 5, 7, 9, 87, 461, 1017, 869, 1541, 7833, 3117, 24917, 13917, 104797, 149045, 0 };
            const std::uint32_t dim13629JoeKuoD6Init[]   =   { 1, 1, 7, 15, 13, 49, 9, 89, 165, 827, 657, 1977, 7471, 15437, 25785, 1455, 52803, 198793, 0 };
            const std::uint32_t dim13630JoeKuoD6Init[]   =   { 1, 3, 1, 15, 3, 39, 27, 205, 325, 345, 965, 1439, 4403, 10717, 9591, 46845, 123983, 76181, 0 };
            const std::uint32_t dim13631JoeKuoD6Init[]   =   { 1, 3, 1, 1, 25, 23, 97, 135, 367, 179, 1563, 75, 455, 3517, 21539, 59565, 43449, 139495, 0 };
            const std::uint32_t dim13632JoeKuoD6Init[]   =   { 1, 1, 5, 15, 13, 27, 55, 21, 1, 505, 1349, 409, 2491, 5299, 15771, 59389, 110377, 209275, 0 };
            const std::uint32_t dim13633JoeKuoD6Init[]   =   { 1, 1, 7, 9, 31, 15, 63, 91, 3, 559, 419, 1237, 1157, 5811, 24335, 19215, 12581, 148813, 0 };
            const std::uint32_t dim13634JoeKuoD6Init[]   =   { 1, 1, 7, 13, 23, 3, 81, 127, 33, 931, 867, 2905, 1011, 16207, 1543, 54309, 10611, 152733, 0 };
            const std::uint32_t dim13635JoeKuoD6Init[]   =   { 1, 3, 5, 7, 21, 19, 45, 101, 439, 537, 267, 945, 8007, 9383, 13211, 21867, 5731, 150203, 0 };
            const std::uint32_t dim13636JoeKuoD6Init[]   =   { 1, 1, 3, 9, 29, 3, 31, 219, 217, 775, 1011, 445, 2663, 1691, 9837, 5727, 116283, 128627, 0 };
            const std::uint32_t dim13637JoeKuoD6Init[]   =   { 1, 3, 3, 3, 21, 1, 97, 239, 457, 925, 1923, 1693, 1187, 13437, 8529, 22081, 633, 76109, 0 };
            const std::uint32_t dim13638JoeKuoD6Init[]   =   { 1, 3, 7, 7, 19, 5, 9, 15, 337, 855, 1563, 3159, 2799, 4103, 2013, 47789, 77027, 22425, 0 };
            const std::uint32_t dim13639JoeKuoD6Init[]   =   { 1, 1, 3, 15, 15, 41, 27, 77, 489, 377, 1953, 305, 5081, 1895, 5117, 51455, 71859, 190289, 0 };
            const std::uint32_t dim13640JoeKuoD6Init[]   =   { 1, 1, 5, 7, 7, 7, 13, 25, 115, 657, 223, 3185, 5327, 2559, 5147, 22237, 91933, 195429, 0 };
            const std::uint32_t dim13641JoeKuoD6Init[]   =   { 1, 1, 3, 5, 5, 19, 3, 197, 371, 237, 555, 2873, 3401, 3329, 29165, 4593, 111677, 244025, 0 };
            const std::uint32_t dim13642JoeKuoD6Init[]   =   { 1, 3, 5, 15, 15, 55, 29, 75, 329, 623, 279, 2831, 4489, 7803, 24119, 12959, 59783, 135213, 0 };
            const std::uint32_t dim13643JoeKuoD6Init[]   =   { 1, 3, 5, 13, 31, 21, 93, 77, 401, 353, 893, 917, 4813, 8027, 7847, 55315, 60213, 102763, 0 };
            const std::uint32_t dim13644JoeKuoD6Init[]   =   { 1, 1, 5, 13, 29, 49, 91, 35, 79, 625, 1539, 509, 823, 2239, 30867, 21729, 33195, 38189, 0 };
            const std::uint32_t dim13645JoeKuoD6Init[]   =   { 1, 3, 3, 3, 19, 11, 39, 145, 5, 329, 1653, 3205, 4431, 9291, 30369, 63173, 72317, 236103, 0 };
            const std::uint32_t dim13646JoeKuoD6Init[]   =   { 1, 3, 3, 15, 27, 9, 111, 191, 249, 845, 1845, 2097, 6529, 9559, 25757, 29085, 2615, 175759, 0 };
            const std::uint32_t dim13647JoeKuoD6Init[]   =   { 1, 3, 7, 1, 17, 59, 119, 125, 213, 995, 601, 2517, 1225, 2301, 13031, 40881, 31623, 165799, 0 };
            const std::uint32_t dim13648JoeKuoD6Init[]   =   { 1, 3, 3, 13, 25, 61, 97, 157, 347, 931, 1731, 3697, 5815, 7309, 30605, 3853, 72395, 103609, 0 };
            const std::uint32_t dim13649JoeKuoD6Init[]   =   { 1, 1, 7, 5, 23, 13, 51, 117, 495, 683, 777, 1629, 5683, 801, 4907, 24935, 9457, 214131, 0 };
            const std::uint32_t dim13650JoeKuoD6Init[]   =   { 1, 1, 5, 9, 1, 29, 107, 253, 195, 921, 345, 1451, 2253, 12723, 571, 12009, 34149, 140659, 0 };
            const std::uint32_t dim13651JoeKuoD6Init[]   =   { 1, 1, 5, 9, 31, 17, 93, 5, 455, 205, 1439, 1199, 7371, 12973, 16455, 675, 60561, 99575, 0 };
            const std::uint32_t dim13652JoeKuoD6Init[]   =   { 1, 3, 3, 3, 31, 37, 115, 49, 31, 285, 2029, 1369, 3443, 2411, 10367, 44859, 26737, 195703, 0 };
            const std::uint32_t dim13653JoeKuoD6Init[]   =   { 1, 1, 3, 1, 15, 39, 113, 37, 257, 3, 817, 2901, 4029, 12595, 30475, 34883, 109133, 92159, 0 };
            const std::uint32_t dim13654JoeKuoD6Init[]   =   { 1, 1, 7, 5, 9, 1, 9, 101, 317, 167, 1975, 411, 6875, 6951, 4401, 59483, 129813, 78289, 0 };
            const std::uint32_t dim13655JoeKuoD6Init[]   =   { 1, 1, 7, 9, 9, 5, 73, 7, 57, 907, 1887, 2923, 961, 8521, 873, 33791, 114485, 43081, 0 };
            const std::uint32_t dim13656JoeKuoD6Init[]   =   { 1, 1, 5, 7, 13, 45, 91, 179, 499, 197, 1337, 1321, 5307, 15503, 20449, 60813, 97393, 255741, 0 };
            const std::uint32_t dim13657JoeKuoD6Init[]   =   { 1, 1, 1, 5, 25, 13, 69, 221, 207, 823, 845, 3845, 6743, 5123, 27447, 2079, 100635, 124157, 0 };
            const std::uint32_t dim13658JoeKuoD6Init[]   =   { 1, 3, 5, 11, 13, 39, 121, 209, 137, 63, 1479, 323, 5347, 9797, 17785, 55541, 108713, 243347, 0 };
            const std::uint32_t dim13659JoeKuoD6Init[]   =   { 1, 1, 3, 9, 29, 45, 43, 81, 115, 979, 727, 423, 1133, 8757, 27833, 39907, 104663, 33067, 0 };
            const std::uint32_t dim13660JoeKuoD6Init[]   =   { 1, 3, 5, 1, 13, 61, 49, 17, 409, 567, 1035, 2299, 3711, 15485, 7767, 27809, 1275, 96455, 0 };
            const std::uint32_t dim13661JoeKuoD6Init[]   =   { 1, 1, 5, 9, 5, 33, 13, 9, 505, 459, 747, 4079, 4271, 6925, 13933, 31349, 5793, 68381, 0 };
            const std::uint32_t dim13662JoeKuoD6Init[]   =   { 1, 3, 3, 11, 15, 47, 15, 187, 349, 847, 817, 3551, 6059, 6451, 32615, 1635, 108889, 48003, 0 };
            const std::uint32_t dim13663JoeKuoD6Init[]   =   { 1, 3, 5, 7, 3, 31, 11, 255, 367, 295, 1079, 2981, 5583, 10771, 25359, 16083, 24163, 111201, 0 };
            const std::uint32_t dim13664JoeKuoD6Init[]   =   { 1, 3, 5, 5, 7, 5, 127, 19, 343, 849, 287, 1471, 7299, 1209, 31349, 33473, 4989, 229181, 0 };
            const std::uint32_t dim13665JoeKuoD6Init[]   =   { 1, 1, 3, 9, 25, 61, 7, 65, 77, 745, 1871, 2427, 3669, 8965, 11177, 5531, 115801, 34327, 0 };
            const std::uint32_t dim13666JoeKuoD6Init[]   =   { 1, 3, 3, 15, 1, 57, 125, 167, 173, 875, 347, 2317, 6687, 4339, 10573, 7841, 16241, 192225, 0 };
            const std::uint32_t dim13667JoeKuoD6Init[]   =   { 1, 3, 1, 3, 15, 37, 45, 189, 75, 1017, 1919, 3401, 329, 2539, 32697, 60801, 52017, 192611, 0 };
            const std::uint32_t dim13668JoeKuoD6Init[]   =   { 1, 3, 1, 5, 1, 23, 43, 55, 1, 443, 1769, 1633, 5225, 6855, 5419, 65139, 22237, 17415, 0 };
            const std::uint32_t dim13669JoeKuoD6Init[]   =   { 1, 3, 5, 15, 25, 7, 107, 209, 325, 367, 373, 1855, 1313, 12899, 30137, 19007, 9911, 11791, 0 };
            const std::uint32_t dim13670JoeKuoD6Init[]   =   { 1, 3, 7, 13, 3, 57, 123, 93, 279, 469, 1817, 3409, 565, 3997, 14119, 58341, 59691, 163323, 0 };
            const std::uint32_t dim13671JoeKuoD6Init[]   =   { 1, 1, 3, 9, 3, 3, 69, 109, 47, 487, 1895, 2003, 7309, 9803, 9527, 52211, 31213, 41521, 0 };
            const std::uint32_t dim13672JoeKuoD6Init[]   =   { 1, 1, 7, 7, 9, 15, 101, 227, 75, 501, 25, 1481, 4847, 13279, 28673, 11069, 61987, 5365, 0 };
            const std::uint32_t dim13673JoeKuoD6Init[]   =   { 1, 3, 1, 1, 25, 5, 47, 125, 97, 969, 1077, 1185, 6033, 13927, 18149, 34255, 14353, 66323, 0 };
            const std::uint32_t dim13674JoeKuoD6Init[]   =   { 1, 1, 3, 1, 25, 41, 19, 69, 385, 585, 1049, 3497, 3615, 13211, 18855, 61303, 115739, 42639, 0 };
            const std::uint32_t dim13675JoeKuoD6Init[]   =   { 1, 3, 7, 7, 13, 15, 13, 133, 497, 265, 1809, 4073, 5673, 7543, 30823, 13505, 76167, 98683, 0 };
            const std::uint32_t dim13676JoeKuoD6Init[]   =   { 1, 1, 5, 5, 3, 59, 47, 191, 419, 505, 2035, 329, 553, 1561, 27885, 39767, 102611, 12689, 0 };
            const std::uint32_t dim13677JoeKuoD6Init[]   =   { 1, 3, 7, 3, 27, 49, 27, 133, 305, 537, 385, 335, 2417, 14891, 31299, 26201, 124655, 150545, 0 };
            const std::uint32_t dim13678JoeKuoD6Init[]   =   { 1, 1, 1, 9, 7, 1, 27, 105, 347, 481, 2043, 1645, 4367, 10335, 16457, 48713, 64699, 63595, 0 };
            const std::uint32_t dim13679JoeKuoD6Init[]   =   { 1, 1, 3, 3, 7, 57, 125, 209, 299, 525, 591, 1265, 7557, 15113, 19319, 56269, 43919, 215435, 0 };
            const std::uint32_t dim13680JoeKuoD6Init[]   =   { 1, 1, 1, 11, 29, 59, 119, 245, 63, 919, 1913, 3969, 545, 1033, 20975, 61327, 36783, 124303, 0 };
            const std::uint32_t dim13681JoeKuoD6Init[]   =   { 1, 1, 7, 7, 11, 63, 45, 135, 405, 931, 753, 2559, 5475, 2107, 6437, 6055, 43497, 133571, 0 };
            const std::uint32_t dim13682JoeKuoD6Init[]   =   { 1, 3, 1, 13, 31, 39, 39, 141, 231, 83, 69, 473, 1095, 13617, 10909, 49861, 98029, 235003, 0 };
            const std::uint32_t dim13683JoeKuoD6Init[]   =   { 1, 3, 7, 13, 13, 41, 73, 107, 505, 359, 957, 1599, 7617, 1843, 25531, 63755, 96295, 167955, 0 };
            const std::uint32_t dim13684JoeKuoD6Init[]   =   { 1, 3, 3, 11, 13, 41, 61, 65, 165, 507, 1007, 1695, 91, 8781, 15017, 12063, 95331, 179853, 0 };
            const std::uint32_t dim13685JoeKuoD6Init[]   =   { 1, 3, 7, 7, 29, 19, 7, 95, 303, 641, 581, 3539, 4495, 13549, 20195, 20845, 16961, 95053, 0 };
            const std::uint32_t dim13686JoeKuoD6Init[]   =   { 1, 1, 7, 5, 15, 27, 13, 155, 345, 341, 1583, 2207, 2497, 6509, 24343, 3109, 71431, 184871, 0 };
            const std::uint32_t dim13687JoeKuoD6Init[]   =   { 1, 1, 3, 15, 31, 35, 37, 249, 71, 1005, 681, 3457, 3387, 13797, 8781, 11789, 16825, 11133, 0 };
            const std::uint32_t dim13688JoeKuoD6Init[]   =   { 1, 3, 7, 11, 5, 29, 121, 139, 77, 859, 163, 2749, 6401, 16303, 22659, 11817, 61667, 119993, 0 };
            const std::uint32_t dim13689JoeKuoD6Init[]   =   { 1, 1, 7, 11, 15, 45, 71, 87, 293, 981, 1581, 2789, 4117, 12791, 13611, 489, 74823, 71263, 0 };
            const std::uint32_t dim13690JoeKuoD6Init[]   =   { 1, 1, 3, 9, 15, 21, 59, 167, 469, 723, 1609, 2111, 6359, 10781, 1043, 51039, 24429, 14605, 0 };
            const std::uint32_t dim13691JoeKuoD6Init[]   =   { 1, 3, 3, 9, 13, 25, 1, 43, 61, 869, 1919, 601, 8003, 15841, 10141, 33187, 124991, 94205, 0 };
            const std::uint32_t dim13692JoeKuoD6Init[]   =   { 1, 1, 7, 5, 23, 13, 67, 43, 167, 667, 1743, 2523, 2245, 9287, 8115, 64995, 121371, 188321, 0 };
            const std::uint32_t dim13693JoeKuoD6Init[]   =   { 1, 1, 1, 9, 13, 19, 45, 249, 21, 751, 239, 4035, 4549, 8905, 9377, 47535, 78135, 210429, 0 };
            const std::uint32_t dim13694JoeKuoD6Init[]   =   { 1, 1, 3, 7, 5, 43, 13, 227, 75, 785, 631, 205, 3475, 9735, 17867, 61407, 75897, 51151, 0 };
            const std::uint32_t dim13695JoeKuoD6Init[]   =   { 1, 3, 3, 9, 31, 21, 11, 53, 247, 717, 1505, 3903, 3249, 3185, 29007, 48795, 43413, 158653, 0 };
            const std::uint32_t dim13696JoeKuoD6Init[]   =   { 1, 1, 5, 11, 19, 9, 37, 159, 183, 521, 743, 2877, 2291, 10317, 1211, 17951, 16335, 66439, 0 };
            const std::uint32_t dim13697JoeKuoD6Init[]   =   { 1, 1, 3, 7, 3, 41, 15, 113, 125, 391, 201, 3841, 255, 15381, 16801, 47219, 119691, 51811, 0 };
            const std::uint32_t dim13698JoeKuoD6Init[]   =   { 1, 1, 3, 1, 1, 29, 79, 181, 481, 969, 297, 625, 7449, 5813, 5915, 20011, 44853, 231933, 0 };
            const std::uint32_t dim13699JoeKuoD6Init[]   =   { 1, 1, 1, 5, 5, 49, 63, 171, 93, 107, 1083, 1277, 121, 4421, 18951, 61155, 66643, 120049, 0 };
            const std::uint32_t dim13700JoeKuoD6Init[]   =   { 1, 3, 7, 5, 25, 59, 111, 197, 459, 217, 1819, 1603, 5581, 11361, 17721, 57475, 11171, 186577, 0 };
            const std::uint32_t dim13701JoeKuoD6Init[]   =   { 1, 3, 3, 1, 25, 19, 29, 157, 25, 595, 501, 2145, 7513, 10323, 11107, 13269, 21763, 9427, 0 };
            const std::uint32_t dim13702JoeKuoD6Init[]   =   { 1, 3, 7, 3, 9, 49, 119, 117, 445, 91, 227, 1203, 6245, 9575, 30653, 65429, 64987, 81249, 0 };
            const std::uint32_t dim13703JoeKuoD6Init[]   =   { 1, 1, 5, 5, 5, 5, 77, 77, 425, 789, 467, 3931, 4815, 11195, 21939, 59513, 78547, 238035, 0 };
            const std::uint32_t dim13704JoeKuoD6Init[]   =   { 1, 3, 1, 11, 11, 29, 115, 37, 423, 997, 1231, 3987, 5057, 14533, 18005, 51513, 71851, 258137, 0 };
            const std::uint32_t dim13705JoeKuoD6Init[]   =   { 1, 3, 1, 1, 27, 31, 7, 223, 23, 59, 1465, 2045, 6677, 15707, 25101, 22269, 46995, 89141, 0 };
            const std::uint32_t dim13706JoeKuoD6Init[]   =   { 1, 1, 1, 5, 21, 7, 115, 133, 407, 373, 1495, 2551, 6947, 3309, 14903, 5683, 67345, 139381, 0 };
            const std::uint32_t dim13707JoeKuoD6Init[]   =   { 1, 1, 5, 3, 13, 31, 5, 221, 187, 9, 165, 2295, 1239, 5665, 14543, 3963, 4931, 8269, 0 };
            const std::uint32_t dim13708JoeKuoD6Init[]   =   { 1, 3, 5, 13, 15, 5, 37, 171, 419, 665, 765, 1619, 1561, 1661, 5873, 25595, 34827, 215599, 0 };
            const std::uint32_t dim13709JoeKuoD6Init[]   =   { 1, 3, 1, 15, 13, 33, 45, 107, 275, 771, 1105, 2895, 187, 5173, 21179, 35047, 50825, 176775, 0 };
            const std::uint32_t dim13710JoeKuoD6Init[]   =   { 1, 3, 7, 5, 17, 5, 59, 195, 441, 625, 1205, 207, 4703, 10627, 17123, 61785, 100779, 258597, 0 };
            const std::uint32_t dim13711JoeKuoD6Init[]   =   { 1, 1, 1, 13, 17, 3, 13, 201, 241, 657, 153, 289, 5213, 2129, 13447, 28807, 25405, 33803, 0 };
            const std::uint32_t dim13712JoeKuoD6Init[]   =   { 1, 3, 1, 9, 19, 9, 51, 133, 159, 743, 1023, 291, 7137, 6949, 30419, 13449, 111505, 212393, 0 };
            const std::uint32_t dim13713JoeKuoD6Init[]   =   { 1, 3, 5, 7, 31, 29, 79, 211, 425, 93, 1173, 1957, 6737, 1725, 30703, 43237, 119747, 157395, 0 };
            const std::uint32_t dim13714JoeKuoD6Init[]   =   { 1, 1, 7, 3, 17, 21, 39, 19, 485, 663, 19, 761, 1525, 11059, 12833, 17567, 61123, 124801, 0 };
            const std::uint32_t dim13715JoeKuoD6Init[]   =   { 1, 1, 7, 3, 7, 25, 17, 199, 413, 821, 1561, 3855, 1871, 14041, 7525, 19383, 51017, 213357, 0 };
            const std::uint32_t dim13716JoeKuoD6Init[]   =   { 1, 3, 3, 9, 25, 11, 63, 83, 217, 587, 47, 3775, 767, 9191, 5127, 9133, 97689, 122949, 0 };
            const std::uint32_t dim13717JoeKuoD6Init[]   =   { 1, 1, 1, 9, 19, 7, 89, 125, 23, 813, 1277, 2965, 1939, 1453, 6349, 53127, 109813, 63767, 0 };
            const std::uint32_t dim13718JoeKuoD6Init[]   =   { 1, 1, 5, 15, 29, 63, 117, 37, 185, 69, 1823, 2791, 4125, 11757, 14847, 15567, 126141, 185951, 0 };
            const std::uint32_t dim13719JoeKuoD6Init[]   =   { 1, 3, 7, 1, 23, 11, 15, 113, 209, 785, 229, 3207, 97, 2489, 4587, 14253, 30421, 51027, 0 };
            const std::uint32_t dim13720JoeKuoD6Init[]   =   { 1, 3, 1, 7, 7, 33, 57, 51, 219, 233, 89, 3781, 2055, 4163, 10935, 51913, 63507, 18645, 0 };
            const std::uint32_t dim13721JoeKuoD6Init[]   =   { 1, 3, 1, 7, 7, 55, 107, 187, 109, 867, 955, 139, 4979, 8627, 5835, 28761, 72061, 99413, 0 };
            const std::uint32_t dim13722JoeKuoD6Init[]   =   { 1, 1, 1, 3, 5, 59, 17, 121, 511, 29, 1009, 2875, 2459, 1817, 11741, 13869, 72543, 70485, 0 };
            const std::uint32_t dim13723JoeKuoD6Init[]   =   { 1, 1, 5, 1, 27, 19, 125, 65, 379, 803, 411, 2403, 719, 10683, 23351, 18113, 66773, 252223, 0 };
            const std::uint32_t dim13724JoeKuoD6Init[]   =   { 1, 1, 7, 9, 31, 51, 65, 233, 171, 357, 1465, 1609, 4263, 15207, 18825, 48831, 69459, 211321, 0 };
            const std::uint32_t dim13725JoeKuoD6Init[]   =   { 1, 1, 3, 3, 5, 35, 53, 245, 469, 1011, 759, 455, 4487, 9835, 10349, 61755, 73279, 186049, 0 };
            const std::uint32_t dim13726JoeKuoD6Init[]   =   { 1, 1, 7, 3, 27, 19, 105, 193, 403, 907, 295, 1445, 1867, 8867, 7821, 45309, 129069, 83953, 0 };
            const std::uint32_t dim13727JoeKuoD6Init[]   =   { 1, 1, 7, 7, 7, 51, 85, 97, 473, 837, 201, 501, 2929, 9457, 6473, 3653, 126991, 218069, 0 };
            const std::uint32_t dim13728JoeKuoD6Init[]   =   { 1, 3, 3, 5, 25, 49, 85, 223, 127, 563, 239, 1975, 119, 6029, 19349, 59533, 44173, 142229, 0 };
            const std::uint32_t dim13729JoeKuoD6Init[]   =   { 1, 1, 3, 7, 23, 11, 27, 49, 467, 701, 2037, 2367, 5829, 12533, 9641, 38629, 90505, 132013, 0 };
            const std::uint32_t dim13730JoeKuoD6Init[]   =   { 1, 1, 7, 1, 13, 25, 79, 107, 37, 331, 355, 3639, 4875, 6635, 21703, 18289, 36257, 201857, 0 };
            const std::uint32_t dim13731JoeKuoD6Init[]   =   { 1, 1, 5, 1, 3, 39, 25, 101, 199, 401, 1495, 3683, 5447, 12313, 19707, 20853, 66821, 73959, 0 };
            const std::uint32_t dim13732JoeKuoD6Init[]   =   { 1, 1, 1, 9, 15, 9, 3, 231, 479, 97, 221, 973, 839, 1757, 8759, 45625, 44691, 139803, 0 };
            const std::uint32_t dim13733JoeKuoD6Init[]   =   { 1, 1, 7, 15, 9, 51, 23, 233, 311, 83, 287, 4035, 2087, 4245, 25457, 43105, 104903, 132811, 0 };
            const std::uint32_t dim13734JoeKuoD6Init[]   =   { 1, 1, 1, 9, 5, 13, 33, 167, 363, 67, 601, 2143, 5495, 1277, 14615, 32759, 34935, 158625, 0 };
            const std::uint32_t dim13735JoeKuoD6Init[]   =   { 1, 1, 5, 11, 5, 63, 35, 49, 183, 705, 377, 2607, 2947, 10119, 15631, 60247, 99309, 25747, 0 };
            const std::uint32_t dim13736JoeKuoD6Init[]   =   { 1, 3, 7, 5, 7, 3, 127, 109, 165, 767, 1873, 3825, 441, 11957, 2581, 38309, 129623, 77451, 0 };
            const std::uint32_t dim13737JoeKuoD6Init[]   =   { 1, 3, 1, 7, 19, 53, 101, 117, 505, 363, 1399, 1015, 631, 8309, 17507, 28941, 42585, 116283, 0 };
            const std::uint32_t dim13738JoeKuoD6Init[]   =   { 1, 1, 7, 7, 9, 27, 127, 195, 499, 225, 153, 517, 3909, 9801, 3787, 32829, 6599, 190807, 0 };
            const std::uint32_t dim13739JoeKuoD6Init[]   =   { 1, 1, 5, 1, 3, 49, 125, 235, 255, 329, 909, 1685, 759, 2287, 3479, 23491, 71157, 81457, 0 };
            const std::uint32_t dim13740JoeKuoD6Init[]   =   { 1, 1, 3, 9, 19, 21, 93, 37, 259, 69, 219, 1943, 4747, 13951, 14945, 46099, 87189, 222287, 0 };
            const std::uint32_t dim13741JoeKuoD6Init[]   =   { 1, 1, 7, 5, 21, 33, 61, 227, 167, 569, 1355, 2997, 4917, 10765, 7015, 54335, 125543, 112867, 0 };
            const std::uint32_t dim13742JoeKuoD6Init[]   =   { 1, 1, 5, 3, 25, 35, 97, 23, 365, 159, 1211, 1283, 979, 8993, 21323, 6863, 46869, 36169, 0 };
            const std::uint32_t dim13743JoeKuoD6Init[]   =   { 1, 1, 7, 13, 15, 49, 45, 209, 397, 785, 47, 2307, 4749, 2735, 29525, 54921, 23321, 216197, 0 };
            const std::uint32_t dim13744JoeKuoD6Init[]   =   { 1, 1, 1, 11, 31, 23, 27, 127, 197, 595, 29, 773, 3291, 6355, 11891, 6635, 99871, 177531, 0 };
            const std::uint32_t dim13745JoeKuoD6Init[]   =   { 1, 1, 7, 11, 9, 49, 85, 59, 211, 307, 1821, 3947, 4175, 11287, 27889, 107, 46463, 237129, 0 };
            const std::uint32_t dim13746JoeKuoD6Init[]   =   { 1, 3, 3, 7, 31, 31, 9, 49, 365, 189, 1211, 943, 337, 13809, 16941, 17053, 70125, 149865, 0 };
            const std::uint32_t dim13747JoeKuoD6Init[]   =   { 1, 3, 1, 13, 9, 21, 67, 1, 365, 77, 1701, 559, 3461, 8961, 13801, 16111, 65239, 157713, 0 };
            const std::uint32_t dim13748JoeKuoD6Init[]   =   { 1, 3, 7, 13, 19, 49, 29, 233, 361, 1011, 1617, 2989, 2387, 14027, 4021, 28791, 33155, 171449, 0 };
            const std::uint32_t dim13749JoeKuoD6Init[]   =   { 1, 1, 5, 13, 31, 19, 77, 69, 49, 513, 1411, 77, 4993, 907, 23483, 20129, 29491, 138187, 0 };
            const std::uint32_t dim13750JoeKuoD6Init[]   =   { 1, 3, 3, 11, 23, 33, 19, 55, 307, 455, 1783, 3997, 6411, 3355, 8815, 39883, 124381, 49667, 0 };
            const std::uint32_t dim13751JoeKuoD6Init[]   =   { 1, 3, 3, 15, 27, 7, 25, 243, 275, 27, 23, 3039, 6497, 15975, 5877, 58611, 6317, 209119, 0 };
            const std::uint32_t dim13752JoeKuoD6Init[]   =   { 1, 3, 1, 5, 7, 21, 97, 247, 297, 181, 773, 3095, 2441, 15683, 29609, 50431, 92813, 723, 0 };
            const std::uint32_t dim13753JoeKuoD6Init[]   =   { 1, 1, 1, 3, 17, 25, 69, 171, 27, 83, 173, 163, 7915, 13547, 5915, 20275, 101613, 225081, 0 };
            const std::uint32_t dim13754JoeKuoD6Init[]   =   { 1, 1, 7, 15, 19, 13, 53, 95, 171, 889, 131, 1979, 2537, 7749, 77, 49293, 68875, 159125, 0 };
            const std::uint32_t dim13755JoeKuoD6Init[]   =   { 1, 1, 1, 5, 11, 7, 7, 29, 397, 435, 1495, 2263, 3677, 11121, 1269, 5415, 44427, 249943, 0 };
            const std::uint32_t dim13756JoeKuoD6Init[]   =   { 1, 3, 1, 5, 23, 21, 13, 185, 231, 757, 1647, 663, 1273, 11641, 25563, 46793, 54231, 113143, 0 };
            const std::uint32_t dim13757JoeKuoD6Init[]   =   { 1, 3, 3, 7, 11, 21, 83, 109, 409, 923, 1541, 2805, 1781, 6903, 9093, 37327, 60923, 167271, 0 };
            const std::uint32_t dim13758JoeKuoD6Init[]   =   { 1, 3, 7, 5, 29, 37, 87, 85, 93, 749, 875, 2869, 1023, 13303, 26865, 30971, 40863, 237075, 0 };
            const std::uint32_t dim13759JoeKuoD6Init[]   =   { 1, 1, 7, 13, 21, 25, 39, 213, 303, 265, 1251, 2963, 3819, 8507, 23239, 52625, 123375, 58553, 0 };
            const std::uint32_t dim13760JoeKuoD6Init[]   =   { 1, 1, 1, 1, 3, 1, 7, 67, 339, 583, 3, 2489, 5481, 12241, 21695, 31351, 39389, 131925, 0 };
            const std::uint32_t dim13761JoeKuoD6Init[]   =   { 1, 1, 5, 11, 11, 3, 95, 23, 133, 415, 77, 1891, 4083, 7097, 26455, 28689, 83047, 49759, 0 };
            const std::uint32_t dim13762JoeKuoD6Init[]   =   { 1, 3, 7, 15, 19, 31, 65, 189, 489, 461, 1255, 1897, 3361, 12223, 9721, 45937, 102695, 113431, 0 };
            const std::uint32_t dim13763JoeKuoD6Init[]   =   { 1, 3, 1, 5, 9, 57, 3, 225, 241, 769, 1003, 2255, 7655, 4837, 25267, 35845, 49545, 24931, 0 };
            const std::uint32_t dim13764JoeKuoD6Init[]   =   { 1, 1, 1, 1, 1, 43, 3, 217, 397, 419, 1189, 2037, 5941, 4341, 19851, 13773, 15225, 167581, 0 };
            const std::uint32_t dim13765JoeKuoD6Init[]   =   { 1, 1, 1, 9, 3, 27, 65, 49, 115, 787, 1637, 1867, 7265, 8541, 1587, 58987, 82161, 19997, 0 };
            const std::uint32_t dim13766JoeKuoD6Init[]   =   { 1, 3, 7, 11, 17, 17, 93, 103, 309, 159, 781, 3179, 5759, 7661, 5693, 48531, 127375, 141449, 0 };
            const std::uint32_t dim13767JoeKuoD6Init[]   =   { 1, 3, 7, 5, 13, 39, 79, 241, 7, 137, 219, 523, 541, 4787, 23327, 41665, 111017, 118901, 0 };
            const std::uint32_t dim13768JoeKuoD6Init[]   =   { 1, 1, 3, 15, 31, 23, 107, 221, 295, 935, 1165, 2463, 1635, 10205, 18057, 28217, 51755, 85579, 0 };
            const std::uint32_t dim13769JoeKuoD6Init[]   =   { 1, 3, 1, 11, 23, 47, 7, 59, 75, 603, 1237, 2601, 6873, 12735, 32181, 46849, 106363, 171753, 0 };
            const std::uint32_t dim13770JoeKuoD6Init[]   =   { 1, 1, 7, 13, 15, 31, 3, 113, 355, 955, 919, 1807, 7903, 5485, 1733, 64759, 15817, 93829, 0 };
            const std::uint32_t dim13771JoeKuoD6Init[]   =   { 1, 1, 3, 15, 11, 33, 95, 67, 511, 971, 343, 41, 2849, 10695, 24487, 8971, 129279, 197635, 0 };
            const std::uint32_t dim13772JoeKuoD6Init[]   =   { 1, 3, 1, 13, 13, 47, 77, 127, 193, 191, 1185, 3321, 1685, 1421, 28675, 12593, 86689, 186763, 0 };
            const std::uint32_t dim13773JoeKuoD6Init[]   =   { 1, 3, 7, 13, 1, 11, 123, 91, 287, 751, 11, 2753, 7153, 5253, 21817, 10459, 122225, 105775, 0 };
            const std::uint32_t dim13774JoeKuoD6Init[]   =   { 1, 3, 3, 13, 1, 17, 121, 13, 391, 253, 1323, 1515, 2067, 8009, 5173, 59543, 109511, 156821, 0 };
            const std::uint32_t dim13775JoeKuoD6Init[]   =   { 1, 1, 5, 3, 7, 1, 119, 151, 281, 859, 675, 2923, 6627, 16071, 24653, 41325, 118413, 191981, 0 };
            const std::uint32_t dim13776JoeKuoD6Init[]   =   { 1, 3, 5, 3, 31, 17, 57, 255, 473, 455, 203, 173, 345, 1477, 27939, 39289, 105081, 136179, 0 };
            const std::uint32_t dim13777JoeKuoD6Init[]   =   { 1, 3, 3, 7, 1, 35, 29, 81, 337, 483, 951, 955, 4343, 14827, 17427, 59919, 81883, 114289, 0 };
            const std::uint32_t dim13778JoeKuoD6Init[]   =   { 1, 3, 5, 11, 3, 39, 49, 177, 335, 57, 173, 1827, 5729, 2689, 12109, 13247, 117559, 31735, 0 };
            const std::uint32_t dim13779JoeKuoD6Init[]   =   { 1, 3, 1, 3, 9, 9, 41, 97, 37, 897, 545, 2289, 7917, 5701, 21953, 1863, 33727, 28451, 0 };
            const std::uint32_t dim13780JoeKuoD6Init[]   =   { 1, 1, 5, 3, 29, 61, 59, 129, 387, 965, 285, 3503, 1651, 10423, 24861, 31853, 38491, 155187, 0 };
            const std::uint32_t dim13781JoeKuoD6Init[]   =   { 1, 3, 1, 13, 23, 33, 13, 161, 133, 29, 1073, 1491, 3687, 6821, 24153, 3675, 33771, 230087, 0 };
            const std::uint32_t dim13782JoeKuoD6Init[]   =   { 1, 1, 7, 7, 29, 23, 23, 55, 189, 203, 641, 3391, 1217, 3199, 32531, 43103, 24007, 85613, 0 };
            const std::uint32_t dim13783JoeKuoD6Init[]   =   { 1, 1, 1, 11, 7, 57, 117, 245, 467, 861, 1265, 2827, 2761, 2817, 15679, 53223, 47245, 139871, 0 };
            const std::uint32_t dim13784JoeKuoD6Init[]   =   { 1, 1, 3, 15, 25, 1, 125, 237, 489, 1003, 515, 1117, 4427, 4877, 8685, 46211, 19889, 82491, 0 };
            const std::uint32_t dim13785JoeKuoD6Init[]   =   { 1, 1, 3, 3, 25, 3, 63, 217, 485, 699, 161, 1459, 2973, 15949, 30681, 30991, 13933, 86505, 0 };
            const std::uint32_t dim13786JoeKuoD6Init[]   =   { 1, 1, 7, 9, 27, 57, 23, 217, 401, 613, 277, 2827, 7111, 2133, 17489, 62059, 7273, 170917, 0 };
            const std::uint32_t dim13787JoeKuoD6Init[]   =   { 1, 1, 3, 13, 7, 19, 39, 63, 203, 1001, 279, 879, 4293, 10121, 969, 11571, 96427, 218969, 0 };
            const std::uint32_t dim13788JoeKuoD6Init[]   =   { 1, 3, 7, 7, 5, 21, 113, 203, 77, 971, 1351, 1097, 2581, 7519, 16049, 10565, 5055, 241561, 0 };
            const std::uint32_t dim13789JoeKuoD6Init[]   =   { 1, 3, 3, 11, 1, 21, 93, 111, 221, 31, 1245, 1499, 2289, 2299, 23457, 49221, 68879, 125029, 0 };
            const std::uint32_t dim13790JoeKuoD6Init[]   =   { 1, 1, 7, 3, 15, 19, 57, 189, 243, 785, 399, 3147, 6107, 2327, 6275, 9993, 53051, 34053, 0 };
            const std::uint32_t dim13791JoeKuoD6Init[]   =   { 1, 3, 7, 15, 5, 63, 7, 193, 115, 579, 1987, 765, 7871, 14179, 26383, 61455, 14241, 123515, 0 };
            const std::uint32_t dim13792JoeKuoD6Init[]   =   { 1, 3, 7, 13, 19, 13, 91, 225, 295, 675, 1995, 1145, 4929, 5163, 1101, 60681, 76777, 146875, 0 };
            const std::uint32_t dim13793JoeKuoD6Init[]   =   { 1, 3, 7, 15, 21, 37, 57, 89, 297, 143, 717, 4021, 3259, 8869, 21189, 39333, 125045, 94469, 0 };
            const std::uint32_t dim13794JoeKuoD6Init[]   =   { 1, 1, 5, 9, 27, 35, 69, 121, 433, 39, 889, 915, 4055, 11479, 24757, 53455, 17503, 113295, 0 };
            const std::uint32_t dim13795JoeKuoD6Init[]   =   { 1, 1, 3, 3, 23, 19, 81, 191, 33, 865, 59, 603, 2819, 4919, 22495, 25089, 73905, 44971, 0 };
            const std::uint32_t dim13796JoeKuoD6Init[]   =   { 1, 3, 3, 11, 19, 45, 125, 229, 143, 167, 867, 671, 2225, 16099, 14909, 14937, 78063, 135143, 0 };
            const std::uint32_t dim13797JoeKuoD6Init[]   =   { 1, 1, 7, 11, 21, 55, 73, 247, 211, 895, 1147, 17, 2119, 3261, 19815, 28055, 50139, 178459, 0 };
            const std::uint32_t dim13798JoeKuoD6Init[]   =   { 1, 1, 3, 1, 19, 3, 37, 221, 243, 459, 1539, 3899, 4597, 5503, 23015, 57019, 62637, 177821, 0 };
            const std::uint32_t dim13799JoeKuoD6Init[]   =   { 1, 3, 1, 3, 9, 5, 91, 3, 319, 609, 1241, 3953, 5569, 8757, 6453, 8083, 55285, 38297, 0 };
            const std::uint32_t dim13800JoeKuoD6Init[]   =   { 1, 3, 5, 15, 9, 51, 37, 53, 137, 95, 123, 157, 15, 7421, 22469, 49787, 96245, 199309, 0 };
            const std::uint32_t dim13801JoeKuoD6Init[]   =   { 1, 3, 1, 1, 29, 61, 85, 211, 437, 1013, 1251, 61, 157, 4325, 24247, 1065, 24875, 31509, 0 };
            const std::uint32_t dim13802JoeKuoD6Init[]   =   { 1, 3, 1, 13, 7, 43, 13, 171, 53, 567, 77, 3781, 5077, 6691, 32485, 24253, 83919, 159371, 0 };
            const std::uint32_t dim13803JoeKuoD6Init[]   =   { 1, 1, 1, 13, 15, 15, 19, 53, 325, 309, 53, 1857, 7361, 8831, 31751, 44749, 109265, 227875, 0 };
            const std::uint32_t dim13804JoeKuoD6Init[]   =   { 1, 3, 7, 3, 31, 19, 113, 253, 361, 697, 1137, 2029, 3673, 10323, 10455, 24935, 7325, 43673, 0 };
            const std::uint32_t dim13805JoeKuoD6Init[]   =   { 1, 3, 1, 1, 17, 31, 3, 55, 121, 967, 1701, 2171, 4393, 11937, 3987, 5139, 68913, 134233, 0 };
            const std::uint32_t dim13806JoeKuoD6Init[]   =   { 1, 1, 7, 15, 23, 37, 121, 241, 297, 419, 373, 1219, 739, 4567, 28593, 61267, 95711, 201299, 0 };
            const std::uint32_t dim13807JoeKuoD6Init[]   =   { 1, 1, 1, 9, 23, 31, 101, 243, 163, 333, 1707, 2553, 5285, 12827, 5051, 14165, 505, 253585, 0 };
            const std::uint32_t dim13808JoeKuoD6Init[]   =   { 1, 1, 1, 9, 11, 29, 81, 45, 101, 235, 1079, 4091, 1069, 3439, 23599, 6699, 71783, 236943, 0 };
            const std::uint32_t dim13809JoeKuoD6Init[]   =   { 1, 3, 7, 11, 29, 49, 99, 59, 1, 267, 887, 2941, 6717, 7501, 22549, 53393, 34569, 34671, 0 };
            const std::uint32_t dim13810JoeKuoD6Init[]   =   { 1, 3, 1, 15, 23, 13, 113, 47, 11, 79, 989, 1025, 35, 10475, 8079, 33121, 32477, 178595, 0 };
            const std::uint32_t dim13811JoeKuoD6Init[]   =   { 1, 3, 7, 1, 21, 19, 51, 31, 393, 171, 553, 2221, 7017, 8567, 21803, 51803, 83737, 196409, 0 };
            const std::uint32_t dim13812JoeKuoD6Init[]   =   { 1, 1, 3, 3, 1, 27, 117, 207, 37, 733, 2001, 2575, 4849, 5609, 743, 35987, 109993, 227663, 0 };
            const std::uint32_t dim13813JoeKuoD6Init[]   =   { 1, 1, 7, 15, 29, 47, 85, 213, 335, 633, 849, 3269, 7723, 4651, 355, 54565, 58829, 22781, 0 };
            const std::uint32_t dim13814JoeKuoD6Init[]   =   { 1, 3, 7, 5, 5, 3, 91, 243, 17, 85, 1983, 3909, 1839, 10403, 503, 28451, 3221, 215397, 0 };
            const std::uint32_t dim13815JoeKuoD6Init[]   =   { 1, 1, 1, 15, 13, 3, 9, 25, 249, 113, 1619, 2313, 6461, 2323, 14319, 59635, 9569, 220583, 0 };
            const std::uint32_t dim13816JoeKuoD6Init[]   =   { 1, 3, 5, 7, 31, 59, 41, 43, 43, 921, 647, 2141, 7011, 2749, 24711, 19067, 107895, 107145, 0 };
            const std::uint32_t dim13817JoeKuoD6Init[]   =   { 1, 1, 3, 3, 15, 63, 41, 241, 181, 729, 843, 3569, 2645, 2727, 25331, 23067, 115421, 86025, 0 };
            const std::uint32_t dim13818JoeKuoD6Init[]   =   { 1, 3, 1, 15, 11, 47, 9, 183, 341, 775, 1067, 1317, 6835, 7873, 2653, 33517, 103979, 196761, 0 };
            const std::uint32_t dim13819JoeKuoD6Init[]   =   { 1, 1, 3, 13, 29, 11, 105, 9, 49, 823, 1343, 759, 1263, 12413, 26047, 54285, 57319, 215387, 0 };
            const std::uint32_t dim13820JoeKuoD6Init[]   =   { 1, 1, 5, 13, 21, 55, 75, 149, 63, 737, 1305, 929, 4149, 2793, 24505, 11541, 74765, 8207, 0 };
            const std::uint32_t dim13821JoeKuoD6Init[]   =   { 1, 3, 5, 9, 25, 1, 43, 157, 303, 395, 301, 1561, 5963, 3501, 2259, 59777, 100953, 16051, 0 };
            const std::uint32_t dim13822JoeKuoD6Init[]   =   { 1, 3, 1, 13, 19, 25, 33, 209, 11, 95, 655, 595, 3081, 10345, 26615, 45129, 84023, 158079, 0 };
            const std::uint32_t dim13823JoeKuoD6Init[]   =   { 1, 3, 1, 9, 31, 61, 103, 203, 471, 215, 1103, 759, 1197, 3333, 15859, 36103, 31563, 5987, 0 };
            const std::uint32_t dim13824JoeKuoD6Init[]   =   { 1, 1, 1, 7, 1, 49, 121, 227, 153, 793, 1723, 1033, 6875, 6683, 2503, 57213, 97967, 120383, 0 };
            const std::uint32_t dim13825JoeKuoD6Init[]   =   { 1, 3, 7, 11, 3, 15, 35, 181, 19, 249, 755, 1385, 3297, 4665, 2761, 22717, 126199, 85065, 0 };
            const std::uint32_t dim13826JoeKuoD6Init[]   =   { 1, 3, 7, 15, 5, 45, 17, 55, 111, 597, 553, 1203, 7183, 8465, 28523, 50073, 90889, 187205, 0 };
            const std::uint32_t dim13827JoeKuoD6Init[]   =   { 1, 3, 3, 9, 31, 57, 13, 139, 291, 881, 501, 2051, 617, 5151, 28225, 44777, 31645, 6805, 0 };
            const std::uint32_t dim13828JoeKuoD6Init[]   =   { 1, 3, 5, 13, 1, 23, 107, 1, 201, 35, 1673, 2281, 7663, 1115, 25061, 59615, 127955, 169685, 0 };
            const std::uint32_t dim13829JoeKuoD6Init[]   =   { 1, 1, 3, 15, 15, 5, 17, 75, 307, 591, 1661, 855, 4239, 13359, 20027, 51871, 35241, 32769, 0 };
            const std::uint32_t dim13830JoeKuoD6Init[]   =   { 1, 1, 1, 15, 5, 23, 59, 205, 223, 103, 1889, 141, 6157, 9187, 23571, 15267, 1941, 119173, 0 };
            const std::uint32_t dim13831JoeKuoD6Init[]   =   { 1, 3, 5, 9, 27, 63, 59, 11, 279, 493, 209, 4087, 1055, 9841, 31753, 37459, 27757, 213151, 0 };
            const std::uint32_t dim13832JoeKuoD6Init[]   =   { 1, 1, 3, 11, 31, 33, 13, 87, 285, 847, 2005, 3431, 253, 15157, 31359, 45303, 114337, 42541, 0 };
            const std::uint32_t dim13833JoeKuoD6Init[]   =   { 1, 1, 1, 7, 7, 3, 17, 203, 133, 321, 241, 1323, 5639, 10953, 10069, 4941, 17077, 54493, 0 };
            const std::uint32_t dim13834JoeKuoD6Init[]   =   { 1, 1, 7, 1, 9, 5, 125, 5, 421, 609, 645, 1927, 3785, 2295, 1491, 23019, 85497, 161231, 0 };
            const std::uint32_t dim13835JoeKuoD6Init[]   =   { 1, 3, 3, 11, 19, 35, 115, 95, 353, 773, 2025, 2621, 2821, 6361, 29589, 20989, 99645, 90387, 0 };
            const std::uint32_t dim13836JoeKuoD6Init[]   =   { 1, 3, 1, 15, 23, 3, 71, 253, 467, 307, 1109, 2695, 7175, 15087, 1587, 48229, 104307, 218905, 0 };
            const std::uint32_t dim13837JoeKuoD6Init[]   =   { 1, 3, 3, 5, 17, 29, 107, 153, 371, 205, 7, 597, 7393, 2345, 20149, 47417, 37983, 200683, 0 };
            const std::uint32_t dim13838JoeKuoD6Init[]   =   { 1, 1, 7, 1, 3, 55, 113, 117, 241, 923, 1217, 3825, 2635, 8007, 12673, 9533, 7121, 3825, 0 };
            const std::uint32_t dim13839JoeKuoD6Init[]   =   { 1, 1, 1, 3, 21, 63, 25, 111, 31, 151, 67, 3735, 7833, 749, 28743, 59291, 4989, 93329, 0 };
            const std::uint32_t dim13840JoeKuoD6Init[]   =   { 1, 3, 5, 13, 31, 5, 91, 153, 235, 1019, 431, 1951, 7501, 8483, 19625, 57789, 13203, 36693, 0 };
            const std::uint32_t dim13841JoeKuoD6Init[]   =   { 1, 1, 7, 3, 15, 51, 99, 29, 403, 343, 1903, 907, 3255, 4149, 29551, 18885, 74391, 96119, 0 };
            const std::uint32_t dim13842JoeKuoD6Init[]   =   { 1, 1, 7, 11, 31, 11, 63, 213, 437, 879, 359, 555, 7549, 14269, 31489, 51001, 76857, 237305, 0 };
            const std::uint32_t dim13843JoeKuoD6Init[]   =   { 1, 1, 1, 15, 23, 21, 31, 227, 311, 273, 253, 2439, 7217, 2191, 31743, 47669, 62279, 201305, 0 };
            const std::uint32_t dim13844JoeKuoD6Init[]   =   { 1, 3, 5, 11, 3, 43, 97, 121, 363, 91, 201, 1095, 5267, 633, 19111, 36099, 23035, 205655, 0 };
            const std::uint32_t dim13845JoeKuoD6Init[]   =   { 1, 3, 1, 9, 21, 31, 39, 11, 227, 699, 473, 2109, 2757, 13821, 31181, 40493, 57279, 260085, 0 };
            const std::uint32_t dim13846JoeKuoD6Init[]   =   { 1, 1, 5, 7, 27, 57, 65, 11, 173, 709, 1139, 3735, 5291, 16053, 32579, 25275, 79865, 196033, 0 };
            const std::uint32_t dim13847JoeKuoD6Init[]   =   { 1, 1, 1, 9, 19, 35, 83, 153, 287, 207, 593, 2177, 3243, 10433, 24583, 881, 71865, 250223, 0 };
            const std::uint32_t dim13848JoeKuoD6Init[]   =   { 1, 3, 3, 9, 3, 35, 107, 3, 193, 1011, 463, 1643, 2733, 2157, 6329, 24583, 116901, 226385, 0 };
            const std::uint32_t dim13849JoeKuoD6Init[]   =   { 1, 3, 1, 11, 3, 47, 39, 33, 495, 137, 1591, 1335, 1347, 4527, 389, 43341, 80163, 5219, 0 };
            const std::uint32_t dim13850JoeKuoD6Init[]   =   { 1, 3, 3, 5, 19, 51, 121, 135, 93, 891, 13, 1339, 5187, 5005, 12823, 14465, 73845, 119685, 0 };
            const std::uint32_t dim13851JoeKuoD6Init[]   =   { 1, 3, 7, 7, 19, 1, 57, 193, 325, 49, 813, 5, 4431, 1119, 13625, 43613, 127989, 42669, 0 };
            const std::uint32_t dim13852JoeKuoD6Init[]   =   { 1, 3, 5, 15, 11, 33, 7, 45, 215, 469, 1059, 4095, 3549, 11839, 5463, 21383, 4831, 188345, 0 };
            const std::uint32_t dim13853JoeKuoD6Init[]   =   { 1, 1, 1, 13, 5, 61, 7, 161, 99, 623, 1589, 1045, 2385, 8899, 19327, 41373, 109241, 111895, 0 };
            const std::uint32_t dim13854JoeKuoD6Init[]   =   { 1, 1, 5, 7, 11, 39, 115, 41, 21, 491, 1221, 2805, 4311, 7137, 3151, 1387, 24633, 94679, 0 };
            const std::uint32_t dim13855JoeKuoD6Init[]   =   { 1, 1, 3, 7, 3, 39, 71, 175, 443, 187, 1727, 2535, 5099, 1881, 21639, 5717, 48589, 95037, 0 };
            const std::uint32_t dim13856JoeKuoD6Init[]   =   { 1, 1, 1, 11, 25, 21, 37, 227, 407, 73, 721, 3515, 381, 981, 21389, 5205, 31851, 140457, 0 };
            const std::uint32_t dim13857JoeKuoD6Init[]   =   { 1, 3, 3, 3, 27, 35, 13, 129, 457, 315, 253, 2545, 5469, 6695, 25223, 20115, 38039, 133655, 0 };
            const std::uint32_t dim13858JoeKuoD6Init[]   =   { 1, 1, 3, 11, 21, 47, 77, 231, 87, 245, 2039, 2515, 2873, 1711, 3361, 62123, 67117, 239047, 0 };
            const std::uint32_t dim13859JoeKuoD6Init[]   =   { 1, 1, 7, 7, 29, 21, 39, 175, 477, 813, 447, 1109, 7391, 14631, 4437, 42539, 13003, 75403, 0 };
            const std::uint32_t dim13860JoeKuoD6Init[]   =   { 1, 3, 1, 11, 11, 9, 119, 19, 99, 483, 61, 1883, 3415, 2137, 30415, 34519, 115191, 24437, 0 };
            const std::uint32_t dim13861JoeKuoD6Init[]   =   { 1, 1, 1, 9, 7, 47, 115, 233, 419, 427, 1605, 3821, 6243, 10861, 28495, 48265, 80811, 147701, 0 };
            const std::uint32_t dim13862JoeKuoD6Init[]   =   { 1, 3, 5, 5, 11, 61, 51, 155, 279, 463, 31, 1559, 2837, 8795, 4049, 13651, 109227, 52131, 0 };
            const std::uint32_t dim13863JoeKuoD6Init[]   =   { 1, 1, 7, 9, 25, 33, 97, 79, 477, 83, 923, 3293, 6381, 3063, 23293, 35381, 82867, 233189, 0 };
            const std::uint32_t dim13864JoeKuoD6Init[]   =   { 1, 1, 1, 9, 11, 39, 109, 189, 219, 1021, 137, 2041, 2719, 1763, 31787, 29377, 96287, 179685, 0 };
            const std::uint32_t dim13865JoeKuoD6Init[]   =   { 1, 3, 7, 5, 3, 15, 37, 179, 77, 751, 709, 893, 7705, 1563, 7843, 29843, 1107, 35919, 0 };
            const std::uint32_t dim13866JoeKuoD6Init[]   =   { 1, 3, 3, 3, 29, 17, 123, 201, 275, 487, 1979, 1361, 7523, 13783, 10129, 16877, 127049, 163221, 0 };
            const std::uint32_t dim13867JoeKuoD6Init[]   =   { 1, 1, 1, 9, 27, 35, 69, 167, 509, 133, 1073, 3773, 265, 8455, 12341, 127, 115075, 94537, 0 };
            const std::uint32_t dim13868JoeKuoD6Init[]   =   { 1, 3, 7, 9, 13, 35, 57, 83, 123, 211, 739, 253, 3907, 5405, 3229, 46837, 77483, 5915, 0 };
            const std::uint32_t dim13869JoeKuoD6Init[]   =   { 1, 1, 7, 3, 7, 27, 71, 235, 133, 803, 611, 529, 4449, 16113, 8151, 36519, 34561, 36361, 0 };
            const std::uint32_t dim13870JoeKuoD6Init[]   =   { 1, 1, 3, 1, 31, 9, 123, 85, 407, 415, 353, 3239, 673, 4641, 25883, 61117, 7669, 240851, 0 };
            const std::uint32_t dim13871JoeKuoD6Init[]   =   { 1, 1, 5, 11, 29, 9, 49, 31, 3, 249, 1769, 3325, 503, 1397, 30677, 22515, 81279, 90309, 0 };
            const std::uint32_t dim13872JoeKuoD6Init[]   =   { 1, 3, 5, 3, 15, 63, 121, 253, 421, 279, 497, 3881, 6977, 11061, 5883, 38347, 8351, 118123, 0 };
            const std::uint32_t dim13873JoeKuoD6Init[]   =   { 1, 1, 1, 13, 1, 27, 3, 91, 281, 563, 1283, 1893, 7593, 12171, 27041, 7769, 95691, 13791, 0 };
            const std::uint32_t dim13874JoeKuoD6Init[]   =   { 1, 1, 3, 3, 29, 59, 87, 153, 337, 819, 787, 2631, 1889, 13869, 29237, 57097, 91621, 4011, 0 };
            const std::uint32_t dim13875JoeKuoD6Init[]   =   { 1, 1, 1, 15, 7, 49, 1, 83, 299, 353, 131, 1635, 3723, 16209, 1061, 50669, 68083, 133443, 0 };
            const std::uint32_t dim13876JoeKuoD6Init[]   =   { 1, 3, 5, 5, 27, 17, 5, 239, 285, 831, 1487, 721, 4891, 4265, 23753, 43921, 116709, 105027, 0 };
            const std::uint32_t dim13877JoeKuoD6Init[]   =   { 1, 1, 7, 7, 5, 35, 63, 97, 215, 447, 353, 495, 8119, 12537, 9679, 58641, 65057, 21999, 0 };
            const std::uint32_t dim13878JoeKuoD6Init[]   =   { 1, 3, 7, 5, 23, 43, 69, 115, 59, 603, 493, 1665, 5003, 13607, 28491, 4439, 11855, 228183, 0 };
            const std::uint32_t dim13879JoeKuoD6Init[]   =   { 1, 3, 3, 3, 15, 35, 19, 63, 241, 357, 979, 2891, 3105, 14085, 10539, 62335, 130903, 163153, 0 };
            const std::uint32_t dim13880JoeKuoD6Init[]   =   { 1, 3, 5, 3, 23, 51, 23, 193, 129, 171, 1913, 1025, 6397, 15657, 19611, 57455, 87531, 51039, 0 };
            const std::uint32_t dim13881JoeKuoD6Init[]   =   { 1, 1, 3, 9, 1, 9, 7, 239, 87, 527, 1401, 2703, 4021, 3845, 29269, 48217, 61091, 131949, 0 };
            const std::uint32_t dim13882JoeKuoD6Init[]   =   { 1, 3, 1, 5, 17, 45, 59, 223, 287, 295, 1959, 3985, 3671, 14605, 18949, 34147, 51251, 10271, 0 };
            const std::uint32_t dim13883JoeKuoD6Init[]   =   { 1, 3, 5, 9, 5, 49, 63, 105, 43, 157, 1827, 495, 5823, 6323, 6601, 51379, 64411, 204103, 0 };
            const std::uint32_t dim13884JoeKuoD6Init[]   =   { 1, 1, 7, 1, 11, 31, 117, 9, 13, 965, 177, 1247, 2487, 9849, 20367, 49287, 2193, 235689, 0 };
            const std::uint32_t dim13885JoeKuoD6Init[]   =   { 1, 1, 3, 11, 19, 31, 23, 215, 489, 657, 801, 3937, 379, 12083, 14969, 37857, 39027, 63985, 0 };
            const std::uint32_t dim13886JoeKuoD6Init[]   =   { 1, 1, 5, 1, 9, 59, 53, 187, 341, 65, 1251, 767, 4897, 13263, 17439, 26625, 122107, 163653, 0 };
            const std::uint32_t dim13887JoeKuoD6Init[]   =   { 1, 1, 3, 13, 31, 41, 125, 253, 481, 107, 233, 2305, 3321, 7303, 28585, 12787, 83307, 31497, 0 };
            const std::uint32_t dim13888JoeKuoD6Init[]   =   { 1, 1, 3, 13, 25, 41, 55, 83, 101, 115, 549, 531, 3085, 9497, 27989, 28257, 121075, 189671, 0 };
            const std::uint32_t dim13889JoeKuoD6Init[]   =   { 1, 3, 5, 11, 13, 53, 121, 85, 355, 275, 1925, 2117, 1349, 5903, 2041, 20963, 60803, 1121, 0 };
            const std::uint32_t dim13890JoeKuoD6Init[]   =   { 1, 1, 5, 5, 13, 7, 125, 63, 311, 187, 1127, 643, 6137, 845, 23945, 9403, 451, 53027, 0 };
            const std::uint32_t dim13891JoeKuoD6Init[]   =   { 1, 1, 3, 7, 19, 31, 27, 239, 337, 61, 641, 1693, 7289, 5675, 30067, 41091, 124607, 36971, 0 };
            const std::uint32_t dim13892JoeKuoD6Init[]   =   { 1, 3, 1, 13, 25, 61, 11, 81, 165, 129, 241, 711, 5193, 13017, 30821, 35239, 110809, 60909, 0 };
            const std::uint32_t dim13893JoeKuoD6Init[]   =   { 1, 3, 3, 13, 15, 13, 71, 19, 87, 499, 1395, 1191, 1445, 2687, 4691, 16773, 114269, 186237, 0 };
            const std::uint32_t dim13894JoeKuoD6Init[]   =   { 1, 3, 3, 15, 1, 49, 33, 109, 241, 5, 431, 461, 3865, 14029, 9827, 54455, 52159, 211585, 0 };
            const std::uint32_t dim13895JoeKuoD6Init[]   =   { 1, 3, 5, 7, 31, 27, 115, 113, 367, 591, 873, 1447, 6819, 7011, 14095, 55243, 4039, 226985, 0 };
            const std::uint32_t dim13896JoeKuoD6Init[]   =   { 1, 1, 7, 3, 1, 19, 69, 239, 417, 833, 1867, 3111, 2617, 12781, 5531, 17345, 75717, 139667, 0 };
            const std::uint32_t dim13897JoeKuoD6Init[]   =   { 1, 1, 5, 11, 11, 63, 23, 141, 221, 897, 1269, 2185, 6057, 8865, 20449, 58255, 27073, 158305, 0 };
            const std::uint32_t dim13898JoeKuoD6Init[]   =   { 1, 3, 3, 5, 23, 23, 121, 39, 457, 935, 691, 2329, 7055, 2821, 12669, 28713, 82321, 245783, 0 };
            const std::uint32_t dim13899JoeKuoD6Init[]   =   { 1, 1, 1, 9, 27, 9, 35, 23, 139, 823, 703, 917, 1281, 12155, 11681, 26083, 119445, 181489, 0 };
            const std::uint32_t dim13900JoeKuoD6Init[]   =   { 1, 1, 3, 7, 27, 21, 35, 243, 17, 633, 1665, 3419, 6301, 16099, 17477, 24983, 128455, 127501, 0 };
            const std::uint32_t dim13901JoeKuoD6Init[]   =   { 1, 3, 1, 1, 17, 19, 59, 165, 487, 985, 597, 689, 7103, 14475, 6985, 29755, 115977, 105943, 0 };
            const std::uint32_t dim13902JoeKuoD6Init[]   =   { 1, 1, 5, 5, 23, 41, 67, 175, 3, 571, 1501, 3315, 6111, 1847, 28975, 54117, 66605, 69997, 0 };
            const std::uint32_t dim13903JoeKuoD6Init[]   =   { 1, 3, 5, 5, 13, 37, 113, 75, 383, 297, 1187, 2055, 3433, 14651, 30393, 29647, 126403, 32265, 0 };
            const std::uint32_t dim13904JoeKuoD6Init[]   =   { 1, 1, 3, 5, 31, 29, 25, 169, 465, 219, 81, 2019, 4255, 6003, 7425, 53269, 31105, 211937, 0 };
            const std::uint32_t dim13905JoeKuoD6Init[]   =   { 1, 3, 7, 11, 13, 7, 11, 195, 327, 883, 1295, 3721, 1197, 7585, 5693, 993, 125017, 12007, 0 };
            const std::uint32_t dim13906JoeKuoD6Init[]   =   { 1, 3, 3, 7, 5, 37, 71, 37, 63, 651, 669, 3445, 3959, 249, 10599, 22329, 107701, 107729, 0 };
            const std::uint32_t dim13907JoeKuoD6Init[]   =   { 1, 1, 1, 9, 7, 47, 21, 181, 395, 345, 757, 481, 2759, 8157, 19847, 55743, 63137, 224765, 0 };
            const std::uint32_t dim13908JoeKuoD6Init[]   =   { 1, 3, 5, 9, 29, 3, 61, 35, 271, 157, 549, 843, 2907, 91, 16325, 4241, 94495, 78861, 0 };
            const std::uint32_t dim13909JoeKuoD6Init[]   =   { 1, 3, 1, 9, 17, 11, 53, 243, 49, 911, 1193, 793, 901, 3727, 21849, 33987, 565, 154171, 0 };
            const std::uint32_t dim13910JoeKuoD6Init[]   =   { 1, 1, 5, 1, 9, 5, 89, 81, 65, 111, 781, 3775, 591, 4987, 29833, 58159, 7253, 206447, 0 };
            const std::uint32_t dim13911JoeKuoD6Init[]   =   { 1, 3, 1, 7, 3, 59, 77, 83, 173, 545, 103, 2541, 8095, 10797, 11111, 62351, 88827, 55081, 0 };
            const std::uint32_t dim13912JoeKuoD6Init[]   =   { 1, 1, 3, 11, 29, 37, 19, 47, 145, 19, 513, 3269, 2205, 5317, 19207, 38051, 5413, 78089, 0 };
            const std::uint32_t dim13913JoeKuoD6Init[]   =   { 1, 1, 5, 9, 21, 57, 75, 249, 21, 879, 1377, 3407, 6123, 11917, 12493, 44873, 113539, 114717, 0 };
            const std::uint32_t dim13914JoeKuoD6Init[]   =   { 1, 3, 3, 9, 7, 55, 121, 57, 491, 39, 1561, 2625, 639, 13553, 1159, 43071, 68869, 248837, 0 };
            const std::uint32_t dim13915JoeKuoD6Init[]   =   { 1, 1, 1, 11, 25, 19, 107, 239, 171, 1001, 69, 4095, 49, 9569, 22613, 59865, 54959, 70031, 0 };
            const std::uint32_t dim13916JoeKuoD6Init[]   =   { 1, 1, 3, 13, 27, 15, 105, 205, 205, 581, 1965, 1535, 6531, 15935, 7623, 33695, 9317, 44257, 0 };
            const std::uint32_t dim13917JoeKuoD6Init[]   =   { 1, 1, 1, 3, 3, 51, 115, 185, 315, 763, 211, 339, 7083, 4895, 23277, 14165, 101731, 218903, 0 };
            const std::uint32_t dim13918JoeKuoD6Init[]   =   { 1, 1, 3, 13, 29, 1, 69, 55, 423, 781, 183, 1417, 151, 14507, 5217, 27757, 52447, 145913, 0 };
            const std::uint32_t dim13919JoeKuoD6Init[]   =   { 1, 3, 1, 11, 29, 39, 29, 151, 85, 387, 885, 507, 133, 9819, 12627, 30951, 79839, 206267, 0 };
            const std::uint32_t dim13920JoeKuoD6Init[]   =   { 1, 3, 3, 7, 1, 53, 99, 141, 91, 51, 143, 1751, 3989, 6811, 7339, 52141, 43473, 18615, 0 };
            const std::uint32_t dim13921JoeKuoD6Init[]   =   { 1, 3, 3, 15, 27, 11, 29, 37, 387, 655, 2019, 1135, 3619, 12995, 12755, 26063, 109419, 103875, 0 };
            const std::uint32_t dim13922JoeKuoD6Init[]   =   { 1, 3, 3, 13, 31, 15, 93, 231, 195, 261, 1055, 2363, 1123, 3927, 6907, 365, 27043, 157049, 0 };
            const std::uint32_t dim13923JoeKuoD6Init[]   =   { 1, 1, 1, 15, 7, 29, 105, 199, 507, 437, 117, 2963, 7801, 6291, 19261, 30377, 92205, 20723, 0 };
            const std::uint32_t dim13924JoeKuoD6Init[]   =   { 1, 1, 1, 9, 29, 19, 75, 189, 3, 387, 1491, 2291, 7739, 12993, 11835, 10873, 54583, 207963, 0 };
            const std::uint32_t dim13925JoeKuoD6Init[]   =   { 1, 3, 7, 3, 23, 11, 25, 105, 57, 713, 1291, 3293, 4693, 13859, 27541, 31529, 65929, 245143, 0 };
            const std::uint32_t dim13926JoeKuoD6Init[]   =   { 1, 1, 7, 7, 19, 13, 19, 189, 253, 337, 351, 1751, 6173, 12207, 24483, 31381, 82035, 157143, 0 };
            const std::uint32_t dim13927JoeKuoD6Init[]   =   { 1, 3, 3, 11, 11, 49, 117, 177, 301, 417, 855, 2433, 5619, 7339, 30361, 29251, 20411, 184981, 0 };
            const std::uint32_t dim13928JoeKuoD6Init[]   =   { 1, 1, 1, 1, 11, 55, 77, 99, 209, 781, 1193, 2841, 783, 1485, 19413, 52255, 19529, 253927, 0 };
            const std::uint32_t dim13929JoeKuoD6Init[]   =   { 1, 3, 1, 3, 15, 49, 85, 191, 389, 411, 479, 341, 4985, 6193, 19099, 11497, 103285, 162333, 0 };
            const std::uint32_t dim13930JoeKuoD6Init[]   =   { 1, 3, 1, 3, 11, 31, 71, 91, 357, 615, 2007, 3601, 5393, 8079, 16811, 54127, 26049, 116341, 0 };
            const std::uint32_t dim13931JoeKuoD6Init[]   =   { 1, 1, 3, 15, 9, 39, 121, 53, 43, 617, 905, 3629, 6327, 13453, 1435, 24113, 7523, 228523, 0 };
            const std::uint32_t dim13932JoeKuoD6Init[]   =   { 1, 3, 5, 11, 21, 51, 11, 125, 33, 935, 1069, 2807, 4951, 13261, 17611, 38779, 62203, 135759, 0 };
            const std::uint32_t dim13933JoeKuoD6Init[]   =   { 1, 1, 1, 13, 29, 59, 53, 245, 219, 423, 809, 1109, 7255, 14679, 25247, 43235, 129565, 72649, 0 };
            const std::uint32_t dim13934JoeKuoD6Init[]   =   { 1, 3, 5, 7, 27, 29, 119, 91, 297, 407, 187, 2829, 5637, 13851, 14073, 461, 64081, 33971, 0 };
            const std::uint32_t dim13935JoeKuoD6Init[]   =   { 1, 1, 5, 11, 15, 27, 29, 233, 487, 859, 1021, 3117, 1439, 16021, 31315, 35775, 117363, 131635, 0 };
            const std::uint32_t dim13936JoeKuoD6Init[]   =   { 1, 1, 5, 3, 3, 1, 91, 229, 327, 777, 393, 3853, 3455, 1785, 13749, 25173, 51575, 167237, 0 };
            const std::uint32_t dim13937JoeKuoD6Init[]   =   { 1, 3, 7, 9, 27, 7, 15, 71, 283, 71, 1783, 1357, 5581, 3143, 26075, 47751, 71001, 157107, 0 };
            const std::uint32_t dim13938JoeKuoD6Init[]   =   { 1, 3, 3, 7, 23, 9, 69, 21, 333, 223, 1735, 1057, 8091, 1927, 8507, 40901, 40233, 164115, 0 };
            const std::uint32_t dim13939JoeKuoD6Init[]   =   { 1, 3, 7, 3, 11, 49, 29, 81, 215, 289, 1137, 765, 6385, 5935, 3435, 11991, 30867, 60745, 0 };
            const std::uint32_t dim13940JoeKuoD6Init[]   =   { 1, 1, 1, 1, 7, 39, 33, 173, 225, 533, 1927, 3607, 1059, 8779, 2649, 6801, 103963, 167471, 0 };
            const std::uint32_t dim13941JoeKuoD6Init[]   =   { 1, 3, 3, 15, 27, 51, 107, 3, 195, 87, 739, 1425, 747, 1501, 22245, 59233, 124867, 79753, 0 };
            const std::uint32_t dim13942JoeKuoD6Init[]   =   { 1, 1, 3, 3, 13, 41, 125, 101, 225, 749, 221, 2735, 6441, 11353, 3943, 35329, 53437, 149063, 0 };
            const std::uint32_t dim13943JoeKuoD6Init[]   =   { 1, 3, 3, 15, 3, 53, 75, 77, 1, 907, 573, 1909, 363, 6913, 559, 58489, 1053, 25513, 0 };
            const std::uint32_t dim13944JoeKuoD6Init[]   =   { 1, 1, 7, 11, 7, 15, 91, 155, 447, 555, 473, 3625, 7529, 16307, 32241, 64077, 46943, 85717, 0 };
            const std::uint32_t dim13945JoeKuoD6Init[]   =   { 1, 1, 1, 13, 9, 61, 91, 41, 101, 107, 1081, 2511, 2881, 14095, 3861, 22771, 32687, 77287, 0 };
            const std::uint32_t dim13946JoeKuoD6Init[]   =   { 1, 3, 3, 7, 21, 3, 51, 177, 203, 861, 1507, 1177, 2369, 11735, 1667, 28607, 97671, 123263, 0 };
            const std::uint32_t dim13947JoeKuoD6Init[]   =   { 1, 1, 1, 3, 5, 57, 13, 127, 353, 65, 663, 3849, 3579, 5521, 11765, 63427, 76349, 102517, 0 };
            const std::uint32_t dim13948JoeKuoD6Init[]   =   { 1, 1, 7, 11, 27, 55, 79, 249, 397, 77, 1543, 3787, 4889, 11145, 18691, 62899, 66425, 116195, 0 };
            const std::uint32_t dim13949JoeKuoD6Init[]   =   { 1, 1, 1, 3, 5, 3, 1, 143, 73, 999, 2013, 2001, 4001, 6563, 30811, 61445, 2645, 203631, 0 };
            const std::uint32_t dim13950JoeKuoD6Init[]   =   { 1, 1, 1, 15, 1, 49, 35, 61, 493, 101, 1407, 2211, 7467, 12321, 15901, 15479, 62939, 14643, 0 };
            const std::uint32_t dim13951JoeKuoD6Init[]   =   { 1, 1, 3, 11, 21, 33, 123, 95, 449, 355, 1501, 1627, 1411, 6183, 17457, 2199, 96313, 25023, 0 };
            const std::uint32_t dim13952JoeKuoD6Init[]   =   { 1, 1, 5, 5, 13, 49, 73, 203, 83, 3, 137, 119, 3001, 10685, 18231, 60727, 31785, 158605, 0 };
            const std::uint32_t dim13953JoeKuoD6Init[]   =   { 1, 3, 1, 11, 23, 19, 123, 9, 269, 501, 2005, 3695, 3327, 5353, 12619, 12987, 18213, 29355, 0 };
            const std::uint32_t dim13954JoeKuoD6Init[]   =   { 1, 3, 1, 5, 1, 25, 99, 197, 327, 575, 773, 2009, 6653, 1807, 20381, 55725, 124359, 176893, 0 };
            const std::uint32_t dim13955JoeKuoD6Init[]   =   { 1, 1, 7, 15, 27, 9, 81, 175, 73, 727, 1907, 1237, 4983, 16123, 16479, 2283, 57805, 13593, 0 };
            const std::uint32_t dim13956JoeKuoD6Init[]   =   { 1, 1, 3, 13, 7, 13, 13, 139, 283, 721, 487, 1821, 4257, 5105, 8057, 27193, 46857, 169927, 0 };
            const std::uint32_t dim13957JoeKuoD6Init[]   =   { 1, 1, 5, 5, 29, 5, 81, 211, 441, 685, 981, 3097, 6253, 10673, 12253, 54943, 69401, 147769, 0 };
            const std::uint32_t dim13958JoeKuoD6Init[]   =   { 1, 3, 3, 1, 13, 35, 73, 145, 139, 781, 37, 803, 3607, 4327, 1153, 11325, 131025, 168729, 0 };
            const std::uint32_t dim13959JoeKuoD6Init[]   =   { 1, 3, 1, 13, 17, 41, 19, 59, 23, 561, 315, 719, 3325, 275, 12715, 59843, 16597, 81691, 0 };
            const std::uint32_t dim13960JoeKuoD6Init[]   =   { 1, 3, 1, 11, 1, 53, 11, 237, 363, 345, 331, 129, 6885, 3105, 12487, 53803, 8897, 193777, 0 };
            const std::uint32_t dim13961JoeKuoD6Init[]   =   { 1, 3, 7, 15, 3, 53, 55, 101, 389, 839, 413, 2851, 3989, 12857, 25723, 16595, 94145, 193049, 0 };
            const std::uint32_t dim13962JoeKuoD6Init[]   =   { 1, 3, 1, 7, 15, 31, 3, 115, 197, 753, 1035, 1369, 4925, 4497, 1641, 63743, 127089, 114097, 0 };
            const std::uint32_t dim13963JoeKuoD6Init[]   =   { 1, 3, 5, 5, 23, 1, 35, 99, 277, 769, 895, 581, 6969, 15339, 10309, 27101, 22611, 86179, 0 };
            const std::uint32_t dim13964JoeKuoD6Init[]   =   { 1, 1, 1, 11, 19, 17, 45, 35, 257, 313, 815, 1469, 3651, 15101, 22775, 51729, 75401, 123653, 0 };
            const std::uint32_t dim13965JoeKuoD6Init[]   =   { 1, 3, 1, 15, 5, 11, 83, 141, 373, 935, 1123, 1849, 1267, 15427, 10615, 63303, 109771, 188601, 0 };
            const std::uint32_t dim13966JoeKuoD6Init[]   =   { 1, 3, 5, 3, 29, 23, 79, 193, 261, 29, 1857, 789, 4359, 14211, 22181, 64901, 129089, 65587, 0 };
            const std::uint32_t dim13967JoeKuoD6Init[]   =   { 1, 3, 1, 3, 29, 15, 19, 239, 497, 771, 239, 2853, 2391, 8153, 31899, 53759, 127219, 78833, 0 };
            const std::uint32_t dim13968JoeKuoD6Init[]   =   { 1, 1, 7, 7, 5, 57, 9, 93, 69, 993, 193, 3629, 5761, 9339, 28073, 50035, 81635, 83119, 0 };
            const std::uint32_t dim13969JoeKuoD6Init[]   =   { 1, 1, 5, 13, 7, 35, 79, 247, 43, 1011, 1189, 2881, 1963, 8889, 9929, 50043, 112581, 224139, 0 };
            const std::uint32_t dim13970JoeKuoD6Init[]   =   { 1, 3, 3, 7, 15, 63, 85, 33, 107, 37, 45, 1271, 4735, 1151, 19793, 6589, 50875, 185061, 0 };
            const std::uint32_t dim13971JoeKuoD6Init[]   =   { 1, 3, 1, 15, 1, 63, 1, 201, 207, 179, 67, 3703, 2629, 10517, 1, 39645, 119733, 6449, 0 };
            const std::uint32_t dim13972JoeKuoD6Init[]   =   { 1, 3, 5, 1, 3, 7, 97, 101, 233, 71, 255, 3767, 8127, 8041, 25001, 7601, 129595, 131657, 0 };
            const std::uint32_t dim13973JoeKuoD6Init[]   =   { 1, 1, 7, 1, 25, 29, 105, 25, 267, 191, 267, 3141, 4445, 5043, 25203, 32055, 11035, 229031, 0 };
            const std::uint32_t dim13974JoeKuoD6Init[]   =   { 1, 1, 1, 13, 3, 1, 1, 147, 63, 259, 1171, 401, 6289, 13577, 28129, 1349, 85027, 178123, 0 };
            const std::uint32_t dim13975JoeKuoD6Init[]   =   { 1, 1, 1, 13, 1, 59, 109, 95, 49, 309, 1141, 1355, 3415, 11237, 21619, 12039, 1795, 57775, 0 };
            const std::uint32_t dim13976JoeKuoD6Init[]   =   { 1, 3, 1, 11, 19, 3, 51, 227, 277, 49, 703, 2701, 515, 8893, 20163, 65297, 114781, 225687, 0 };
            const std::uint32_t dim13977JoeKuoD6Init[]   =   { 1, 3, 7, 11, 19, 47, 121, 199, 173, 905, 1903, 1781, 2425, 13381, 25843, 23279, 87701, 10723, 0 };
            const std::uint32_t dim13978JoeKuoD6Init[]   =   { 1, 3, 1, 13, 7, 21, 17, 15, 85, 241, 119, 2361, 7921, 6077, 955, 34221, 78179, 35511, 0 };
            const std::uint32_t dim13979JoeKuoD6Init[]   =   { 1, 1, 7, 11, 9, 1, 1, 29, 445, 557, 241, 959, 6077, 3547, 30987, 48129, 79699, 236611, 0 };
            const std::uint32_t dim13980JoeKuoD6Init[]   =   { 1, 3, 1, 15, 13, 29, 57, 117, 347, 719, 1435, 307, 5209, 4009, 10517, 3373, 67667, 260101, 0 };
            const std::uint32_t dim13981JoeKuoD6Init[]   =   { 1, 1, 7, 13, 11, 41, 17, 143, 467, 993, 779, 3991, 623, 8915, 21615, 56477, 59721, 164241, 0 };
            const std::uint32_t dim13982JoeKuoD6Init[]   =   { 1, 1, 3, 7, 15, 37, 53, 33, 395, 547, 1815, 2517, 6575, 14035, 1, 10919, 25467, 117521, 0 };
            const std::uint32_t dim13983JoeKuoD6Init[]   =   { 1, 1, 3, 9, 17, 47, 45, 3, 509, 53, 1245, 883, 7917, 15445, 4169, 49637, 90933, 109469, 0 };
            const std::uint32_t dim13984JoeKuoD6Init[]   =   { 1, 3, 1, 3, 27, 37, 3, 95, 31, 665, 701, 1979, 3735, 3257, 18943, 41201, 95721, 69451, 0 };
            const std::uint32_t dim13985JoeKuoD6Init[]   =   { 1, 1, 1, 15, 19, 49, 61, 5, 115, 801, 805, 2723, 1387, 13165, 20717, 40767, 88857, 28207, 0 };
            const std::uint32_t dim13986JoeKuoD6Init[]   =   { 1, 1, 5, 9, 21, 25, 23, 179, 59, 29, 547, 1829, 4411, 6689, 22363, 43975, 52259, 187563, 0 };
            const std::uint32_t dim13987JoeKuoD6Init[]   =   { 1, 1, 5, 11, 13, 31, 97, 131, 135, 415, 53, 4015, 3629, 6613, 25541, 47221, 66483, 224545, 0 };
            const std::uint32_t dim13988JoeKuoD6Init[]   =   { 1, 3, 1, 11, 19, 13, 65, 95, 381, 759, 1319, 2997, 6321, 9203, 24483, 9925, 10799, 117119, 0 };
            const std::uint32_t dim13989JoeKuoD6Init[]   =   { 1, 3, 5, 13, 27, 17, 39, 225, 199, 125, 1125, 2673, 6787, 8861, 13139, 13849, 65459, 40183, 0 };
            const std::uint32_t dim13990JoeKuoD6Init[]   =   { 1, 1, 5, 3, 17, 55, 23, 75, 457, 959, 1507, 1267, 6857, 16141, 1889, 10779, 41331, 166075, 0 };
            const std::uint32_t dim13991JoeKuoD6Init[]   =   { 1, 3, 1, 15, 7, 55, 109, 59, 241, 431, 1281, 183, 1029, 14617, 4003, 41871, 36007, 129617, 0 };
            const std::uint32_t dim13992JoeKuoD6Init[]   =   { 1, 3, 1, 1, 27, 61, 79, 93, 217, 251, 671, 989, 7031, 10035, 15455, 13685, 95471, 997, 0 };
            const std::uint32_t dim13993JoeKuoD6Init[]   =   { 1, 1, 3, 13, 1, 5, 125, 179, 357, 537, 1303, 2653, 7319, 2075, 3861, 11743, 89659, 221705, 0 };
            const std::uint32_t dim13994JoeKuoD6Init[]   =   { 1, 1, 1, 7, 3, 55, 5, 201, 153, 639, 835, 1913, 3331, 10727, 30365, 15133, 67911, 17851, 0 };
            const std::uint32_t dim13995JoeKuoD6Init[]   =   { 1, 1, 3, 13, 21, 1, 67, 71, 265, 43, 279, 2009, 873, 4447, 32001, 50783, 76613, 63919, 0 };
            const std::uint32_t dim13996JoeKuoD6Init[]   =   { 1, 1, 3, 11, 17, 43, 19, 195, 233, 17, 1855, 1227, 3435, 4313, 6417, 51019, 130091, 124947, 0 };
            const std::uint32_t dim13997JoeKuoD6Init[]   =   { 1, 1, 7, 9, 19, 9, 95, 87, 297, 817, 1217, 3637, 2371, 7073, 387, 62121, 43507, 93927, 0 };
            const std::uint32_t dim13998JoeKuoD6Init[]   =   { 1, 3, 5, 13, 1, 15, 29, 123, 137, 425, 531, 2659, 2077, 1345, 2803, 49469, 29031, 170825, 0 };
            const std::uint32_t dim13999JoeKuoD6Init[]   =   { 1, 1, 5, 7, 15, 13, 119, 231, 139, 673, 1105, 2355, 3023, 4437, 17491, 47367, 12751, 183319, 0 };
            const std::uint32_t dim14000JoeKuoD6Init[]   =   { 1, 1, 5, 15, 19, 5, 125, 121, 509, 539, 473, 2087, 4421, 4205, 23457, 34481, 111231, 145035, 0 };
            const std::uint32_t dim14001JoeKuoD6Init[]   =   { 1, 3, 7, 5, 23, 21, 85, 23, 415, 715, 1579, 3447, 2373, 233, 19401, 54869, 15977, 138119, 0 };
            const std::uint32_t dim14002JoeKuoD6Init[]   =   { 1, 1, 3, 11, 21, 1, 37, 127, 101, 943, 79, 2119, 5679, 10749, 16209, 16715, 29421, 259735, 0 };
            const std::uint32_t dim14003JoeKuoD6Init[]   =   { 1, 3, 7, 7, 23, 25, 1, 73, 505, 979, 535, 87, 4165, 9353, 20075, 57597, 74651, 22133, 0 };
            const std::uint32_t dim14004JoeKuoD6Init[]   =   { 1, 1, 7, 3, 11, 19, 75, 213, 293, 15, 1981, 1259, 5455, 2897, 18861, 6317, 10339, 123967, 0 };
            const std::uint32_t dim14005JoeKuoD6Init[]   =   { 1, 3, 1, 3, 29, 5, 93, 169, 51, 519, 1649, 2789, 1251, 8359, 11489, 62443, 91549, 148357, 0 };
            const std::uint32_t dim14006JoeKuoD6Init[]   =   { 1, 3, 3, 13, 5, 47, 39, 163, 341, 755, 737, 2335, 2389, 8351, 26193, 58111, 18425, 129313, 0 };
            const std::uint32_t dim14007JoeKuoD6Init[]   =   { 1, 1, 3, 1, 31, 49, 101, 69, 345, 291, 1257, 1801, 1613, 1479, 4403, 21307, 44947, 68591, 0 };
            const std::uint32_t dim14008JoeKuoD6Init[]   =   { 1, 3, 3, 9, 5, 23, 65, 65, 187, 709, 883, 2199, 1037, 8679, 31527, 23561, 92225, 254215, 0 };
            const std::uint32_t dim14009JoeKuoD6Init[]   =   { 1, 3, 7, 7, 23, 13, 87, 209, 163, 705, 1199, 3007, 5469, 2453, 2691, 17841, 97045, 174149, 0 };
            const std::uint32_t dim14010JoeKuoD6Init[]   =   { 1, 1, 1, 9, 5, 35, 21, 91, 145, 559, 131, 3911, 1777, 8225, 6077, 58223, 100827, 3641, 0 };
            const std::uint32_t dim14011JoeKuoD6Init[]   =   { 1, 1, 5, 5, 7, 5, 31, 189, 117, 785, 1493, 3899, 471, 10971, 4607, 21063, 67225, 195367, 0 };
            const std::uint32_t dim14012JoeKuoD6Init[]   =   { 1, 1, 7, 5, 31, 61, 63, 163, 417, 655, 2033, 1255, 1139, 6867, 28655, 55295, 100519, 166629, 0 };
            const std::uint32_t dim14013JoeKuoD6Init[]   =   { 1, 3, 3, 3, 7, 35, 83, 55, 7, 607, 253, 915, 6801, 7505, 15929, 16829, 78469, 150947, 0 };
            const std::uint32_t dim14014JoeKuoD6Init[]   =   { 1, 3, 3, 9, 29, 3, 127, 235, 347, 3, 193, 1547, 8073, 14963, 20351, 28951, 53855, 261375, 0 };
            const std::uint32_t dim14015JoeKuoD6Init[]   =   { 1, 1, 7, 3, 31, 19, 75, 87, 23, 419, 75, 1677, 2371, 8875, 31993, 4465, 76085, 86499, 0 };
            const std::uint32_t dim14016JoeKuoD6Init[]   =   { 1, 3, 5, 7, 1, 51, 47, 161, 415, 521, 1099, 1295, 2545, 15167, 13983, 7347, 60631, 4089, 0 };
            const std::uint32_t dim14017JoeKuoD6Init[]   =   { 1, 1, 1, 9, 7, 59, 71, 187, 441, 273, 769, 2649, 3261, 12661, 23045, 32035, 104573, 120589, 0 };
            const std::uint32_t dim14018JoeKuoD6Init[]   =   { 1, 3, 7, 13, 23, 51, 113, 205, 443, 291, 475, 2961, 7615, 105, 22099, 6045, 22667, 65515, 0 };
            const std::uint32_t dim14019JoeKuoD6Init[]   =   { 1, 1, 5, 11, 1, 1, 23, 231, 413, 371, 1285, 2695, 2751, 4235, 15779, 1903, 24469, 259157, 0 };
            const std::uint32_t dim14020JoeKuoD6Init[]   =   { 1, 3, 3, 7, 7, 47, 87, 105, 311, 251, 573, 3221, 5757, 11107, 11161, 8809, 14467, 33153, 0 };
            const std::uint32_t dim14021JoeKuoD6Init[]   =   { 1, 1, 7, 1, 31, 49, 51, 31, 305, 315, 547, 1159, 2741, 3773, 13299, 40115, 62523, 108487, 0 };
            const std::uint32_t dim14022JoeKuoD6Init[]   =   { 1, 3, 1, 11, 11, 43, 33, 213, 107, 467, 1509, 4081, 4723, 2409, 1447, 42759, 64717, 161991, 0 };
            const std::uint32_t dim14023JoeKuoD6Init[]   =   { 1, 3, 7, 3, 31, 23, 25, 159, 95, 721, 1981, 3659, 4819, 10119, 25451, 10165, 31281, 238319, 0 };
            const std::uint32_t dim14024JoeKuoD6Init[]   =   { 1, 3, 1, 5, 19, 27, 67, 125, 481, 585, 43, 3697, 4997, 581, 6439, 33477, 115023, 51759, 0 };
            const std::uint32_t dim14025JoeKuoD6Init[]   =   { 1, 3, 7, 7, 15, 53, 89, 173, 369, 365, 91, 1583, 4611, 7189, 30383, 47397, 73657, 158695, 0 };
            const std::uint32_t dim14026JoeKuoD6Init[]   =   { 1, 1, 1, 15, 1, 21, 125, 13, 243, 729, 1397, 2451, 3233, 15593, 2815, 56215, 22685, 167343, 0 };
            const std::uint32_t dim14027JoeKuoD6Init[]   =   { 1, 3, 1, 13, 13, 29, 119, 223, 51, 695, 273, 2381, 4431, 4891, 29875, 49511, 111003, 174413, 0 };
            const std::uint32_t dim14028JoeKuoD6Init[]   =   { 1, 3, 3, 15, 9, 13, 19, 177, 371, 957, 255, 115, 4701, 6089, 7237, 17077, 87949, 3111, 0 };
            const std::uint32_t dim14029JoeKuoD6Init[]   =   { 1, 1, 7, 11, 29, 49, 59, 201, 145, 219, 1159, 3863, 715, 10489, 25883, 56445, 122103, 149877, 0 };
            const std::uint32_t dim14030JoeKuoD6Init[]   =   { 1, 3, 1, 13, 15, 51, 91, 109, 433, 45, 2045, 3121, 1109, 14713, 2667, 40463, 52185, 64743, 0 };
            const std::uint32_t dim14031JoeKuoD6Init[]   =   { 1, 3, 3, 7, 21, 31, 7, 155, 347, 305, 1557, 1311, 3315, 1363, 403, 62063, 114195, 44623, 0 };
            const std::uint32_t dim14032JoeKuoD6Init[]   =   { 1, 3, 5, 11, 9, 11, 11, 245, 49, 21, 239, 3043, 3525, 1055, 21891, 19153, 123689, 170195, 0 };
            const std::uint32_t dim14033JoeKuoD6Init[]   =   { 1, 1, 1, 11, 17, 51, 83, 249, 483, 489, 1063, 469, 6153, 15551, 13783, 27945, 103775, 68175, 0 };
            const std::uint32_t dim14034JoeKuoD6Init[]   =   { 1, 3, 3, 13, 11, 61, 107, 113, 503, 819, 1593, 2851, 6711, 14623, 3709, 10931, 8743, 62321, 0 };
            const std::uint32_t dim14035JoeKuoD6Init[]   =   { 1, 1, 5, 15, 5, 37, 23, 131, 329, 499, 1765, 1273, 819, 11573, 3307, 46933, 22087, 173459, 0 };
            const std::uint32_t dim14036JoeKuoD6Init[]   =   { 1, 1, 1, 3, 31, 5, 49, 57, 239, 981, 1863, 3233, 2727, 7389, 7923, 63259, 62873, 113607, 0 };
            const std::uint32_t dim14037JoeKuoD6Init[]   =   { 1, 1, 7, 7, 11, 27, 119, 137, 115, 211, 1239, 2153, 2579, 11501, 747, 31141, 129793, 151589, 0 };
            const std::uint32_t dim14038JoeKuoD6Init[]   =   { 1, 3, 3, 9, 9, 55, 121, 199, 91, 835, 521, 2433, 8123, 2045, 32553, 48993, 9935, 220537, 0 };
            const std::uint32_t dim14039JoeKuoD6Init[]   =   { 1, 3, 7, 11, 15, 57, 53, 145, 299, 623, 691, 1557, 785, 15851, 27075, 5983, 18043, 22241, 0 };
            const std::uint32_t dim14040JoeKuoD6Init[]   =   { 1, 1, 3, 1, 1, 57, 57, 195, 381, 913, 167, 333, 5541, 2323, 17001, 34817, 30795, 144051, 0 };
            const std::uint32_t dim14041JoeKuoD6Init[]   =   { 1, 3, 3, 3, 31, 1, 83, 31, 91, 855, 195, 3449, 8057, 11061, 29089, 1597, 127581, 189033, 0 };
            const std::uint32_t dim14042JoeKuoD6Init[]   =   { 1, 3, 1, 1, 21, 59, 113, 179, 13, 523, 629, 3693, 7155, 893, 17449, 46535, 18051, 9191, 0 };
            const std::uint32_t dim14043JoeKuoD6Init[]   =   { 1, 1, 1, 3, 27, 19, 75, 229, 181, 653, 1849, 501, 5871, 14769, 27461, 59193, 115013, 72227, 0 };
            const std::uint32_t dim14044JoeKuoD6Init[]   =   { 1, 3, 3, 13, 17, 41, 111, 107, 453, 299, 1699, 2871, 2955, 4215, 13919, 19785, 30339, 148445, 0 };
            const std::uint32_t dim14045JoeKuoD6Init[]   =   { 1, 3, 3, 11, 5, 19, 21, 87, 173, 439, 1651, 2393, 4137, 16285, 16093, 22953, 105663, 226575, 0 };
            const std::uint32_t dim14046JoeKuoD6Init[]   =   { 1, 3, 5, 7, 19, 61, 101, 251, 295, 89, 1695, 1359, 5797, 8587, 18753, 65223, 51079, 96169, 0 };
            const std::uint32_t dim14047JoeKuoD6Init[]   =   { 1, 1, 1, 5, 3, 1, 79, 63, 221, 601, 1385, 1963, 4601, 15217, 4861, 58295, 61043, 88523, 0 };
            const std::uint32_t dim14048JoeKuoD6Init[]   =   { 1, 3, 3, 7, 31, 63, 73, 177, 455, 487, 1009, 2103, 4753, 3143, 10121, 36509, 24753, 230869, 0 };
            const std::uint32_t dim14049JoeKuoD6Init[]   =   { 1, 1, 5, 1, 17, 27, 103, 63, 475, 665, 1189, 3513, 89, 2669, 1227, 20635, 121549, 248851, 0 };
            const std::uint32_t dim14050JoeKuoD6Init[]   =   { 1, 1, 3, 7, 25, 19, 117, 243, 337, 207, 903, 3751, 3309, 11955, 12651, 25359, 83419, 19701, 0 };
            const std::uint32_t dim14051JoeKuoD6Init[]   =   { 1, 1, 7, 15, 19, 21, 3, 235, 289, 185, 1175, 2291, 4003, 7753, 4775, 65321, 48957, 220261, 0 };
            const std::uint32_t dim14052JoeKuoD6Init[]   =   { 1, 3, 5, 11, 23, 21, 107, 65, 117, 329, 1085, 3555, 1183, 15241, 32663, 50985, 66753, 38023, 0 };
            const std::uint32_t dim14053JoeKuoD6Init[]   =   { 1, 1, 7, 9, 11, 49, 65, 17, 291, 435, 1221, 3829, 5467, 5181, 19891, 7091, 80673, 90495, 0 };
            const std::uint32_t dim14054JoeKuoD6Init[]   =   { 1, 1, 1, 15, 17, 47, 119, 173, 297, 477, 859, 3661, 8081, 8257, 20841, 55123, 11231, 193669, 0 };
            const std::uint32_t dim14055JoeKuoD6Init[]   =   { 1, 1, 7, 7, 27, 11, 119, 109, 199, 727, 1569, 3749, 4067, 11675, 30213, 58091, 64303, 92785, 0 };
            const std::uint32_t dim14056JoeKuoD6Init[]   =   { 1, 3, 7, 15, 15, 39, 101, 149, 299, 449, 1017, 723, 7731, 7929, 22465, 61583, 69851, 150507, 0 };
            const std::uint32_t dim14057JoeKuoD6Init[]   =   { 1, 3, 5, 15, 5, 13, 97, 127, 21, 673, 353, 3885, 5761, 11443, 10089, 23701, 85879, 42217, 0 };
            const std::uint32_t dim14058JoeKuoD6Init[]   =   { 1, 3, 1, 5, 27, 55, 31, 167, 69, 453, 925, 555, 5135, 2759, 27077, 14497, 94333, 108729, 0 };
            const std::uint32_t dim14059JoeKuoD6Init[]   =   { 1, 1, 7, 15, 11, 55, 9, 241, 55, 611, 149, 2605, 653, 1631, 15059, 6349, 12321, 124561, 0 };
            const std::uint32_t dim14060JoeKuoD6Init[]   =   { 1, 1, 1, 9, 3, 11, 95, 67, 443, 103, 1687, 2667, 4567, 4271, 15601, 27859, 4757, 53289, 0 };
            const std::uint32_t dim14061JoeKuoD6Init[]   =   { 1, 1, 5, 9, 23, 21, 1, 125, 105, 975, 1879, 1821, 5273, 7079, 25009, 10471, 29119, 73249, 0 };
            const std::uint32_t dim14062JoeKuoD6Init[]   =   { 1, 1, 7, 1, 31, 61, 17, 23, 485, 565, 1325, 1559, 4131, 751, 2071, 4719, 15925, 101207, 0 };
            const std::uint32_t dim14063JoeKuoD6Init[]   =   { 1, 1, 5, 5, 13, 53, 13, 93, 149, 139, 1429, 3605, 3545, 11193, 14139, 6093, 115727, 183105, 0 };
            const std::uint32_t dim14064JoeKuoD6Init[]   =   { 1, 1, 1, 7, 15, 37, 51, 77, 177, 967, 405, 563, 3047, 8499, 26787, 27609, 23613, 239679, 0 };
            const std::uint32_t dim14065JoeKuoD6Init[]   =   { 1, 1, 1, 5, 27, 37, 1, 129, 197, 133, 1329, 3673, 3143, 1059, 19209, 39027, 43787, 42821, 0 };
            const std::uint32_t dim14066JoeKuoD6Init[]   =   { 1, 3, 7, 5, 5, 47, 105, 121, 219, 777, 1569, 1359, 1955, 13207, 14895, 7829, 40499, 182911, 0 };
            const std::uint32_t dim14067JoeKuoD6Init[]   =   { 1, 3, 5, 7, 11, 41, 41, 155, 245, 383, 405, 2415, 5809, 5117, 31523, 16927, 76785, 113731, 0 };
            const std::uint32_t dim14068JoeKuoD6Init[]   =   { 1, 3, 3, 9, 9, 21, 13, 197, 409, 931, 305, 1129, 865, 12961, 5239, 35823, 82565, 226765, 0 };
            const std::uint32_t dim14069JoeKuoD6Init[]   =   { 1, 1, 5, 3, 17, 27, 59, 79, 359, 601, 979, 1355, 1657, 10479, 4741, 36391, 111527, 105139, 0 };
            const std::uint32_t dim14070JoeKuoD6Init[]   =   { 1, 3, 5, 9, 13, 43, 31, 1, 309, 723, 1049, 803, 1653, 2551, 26317, 49731, 67799, 129225, 0 };
            const std::uint32_t dim14071JoeKuoD6Init[]   =   { 1, 1, 5, 3, 1, 39, 95, 243, 499, 809, 1515, 981, 585, 7907, 16801, 43381, 117537, 99787, 0 };
            const std::uint32_t dim14072JoeKuoD6Init[]   =   { 1, 1, 5, 5, 25, 23, 15, 127, 33, 799, 647, 2923, 7805, 2681, 14773, 42751, 106861, 119657, 0 };
            const std::uint32_t dim14073JoeKuoD6Init[]   =   { 1, 3, 1, 1, 1, 47, 11, 179, 179, 659, 1061, 2511, 3601, 7107, 27887, 48427, 40559, 106043, 0 };
            const std::uint32_t dim14074JoeKuoD6Init[]   =   { 1, 1, 7, 11, 5, 33, 115, 195, 431, 383, 1571, 3485, 5741, 5775, 14891, 26389, 71723, 198861, 0 };
            const std::uint32_t dim14075JoeKuoD6Init[]   =   { 1, 1, 5, 5, 11, 55, 37, 57, 381, 607, 2017, 1981, 6113, 3771, 8827, 13335, 88587, 102791, 0 };
            const std::uint32_t dim14076JoeKuoD6Init[]   =   { 1, 1, 1, 11, 29, 23, 73, 149, 405, 581, 721, 281, 5315, 4675, 13013, 39003, 20335, 109855, 0 };
            const std::uint32_t dim14077JoeKuoD6Init[]   =   { 1, 1, 7, 15, 17, 57, 39, 51, 403, 979, 1543, 1235, 797, 5949, 26647, 15125, 33255, 152861, 0 };
            const std::uint32_t dim14078JoeKuoD6Init[]   =   { 1, 1, 5, 3, 25, 27, 7, 147, 257, 163, 1297, 2289, 693, 7771, 6341, 22323, 1653, 177669, 0 };
            const std::uint32_t dim14079JoeKuoD6Init[]   =   { 1, 1, 3, 9, 1, 39, 47, 231, 15, 705, 897, 3943, 6281, 6679, 21695, 29553, 39509, 83135, 0 };
            const std::uint32_t dim14080JoeKuoD6Init[]   =   { 1, 3, 3, 15, 17, 43, 15, 195, 31, 501, 529, 3117, 6031, 12101, 30687, 52465, 66171, 149591, 0 };
            const std::uint32_t dim14081JoeKuoD6Init[]   =   { 1, 1, 3, 5, 13, 17, 63, 41, 303, 671, 1225, 1761, 6159, 3203, 23611, 18309, 115027, 116325, 0 };
            const std::uint32_t dim14082JoeKuoD6Init[]   =   { 1, 1, 5, 13, 17, 5, 97, 155, 479, 525, 1403, 4063, 8167, 6443, 20627, 41399, 26897, 102841, 0 };
            const std::uint32_t dim14083JoeKuoD6Init[]   =   { 1, 3, 5, 9, 9, 27, 59, 177, 453, 659, 765, 431, 4209, 12679, 10719, 22473, 81597, 20057, 0 };
            const std::uint32_t dim14084JoeKuoD6Init[]   =   { 1, 3, 3, 1, 3, 37, 91, 97, 159, 845, 519, 2603, 6979, 6711, 29781, 53639, 103357, 111671, 0 };
            const std::uint32_t dim14085JoeKuoD6Init[]   =   { 1, 1, 3, 3, 25, 15, 27, 9, 503, 719, 153, 3071, 281, 5341, 32595, 13069, 6461, 160319, 0 };
            const std::uint32_t dim14086JoeKuoD6Init[]   =   { 1, 3, 3, 5, 29, 7, 119, 229, 117, 925, 465, 1703, 7277, 10631, 9429, 41011, 45181, 229239, 0 };
            const std::uint32_t dim14087JoeKuoD6Init[]   =   { 1, 1, 7, 7, 31, 63, 67, 55, 445, 39, 1363, 1369, 1061, 8555, 29263, 47341, 49563, 80445, 0 };
            const std::uint32_t dim14088JoeKuoD6Init[]   =   { 1, 1, 7, 1, 23, 23, 49, 205, 371, 101, 1963, 2763, 3475, 835, 20371, 51343, 9771, 69713, 0 };
            const std::uint32_t dim14089JoeKuoD6Init[]   =   { 1, 3, 3, 7, 3, 29, 7, 185, 511, 93, 1077, 3971, 2981, 16367, 12703, 36179, 47755, 42767, 0 };
            const std::uint32_t dim14090JoeKuoD6Init[]   =   { 1, 1, 1, 11, 27, 47, 43, 39, 129, 337, 1249, 3557, 2871, 13565, 19525, 46263, 49203, 148235, 0 };
            const std::uint32_t dim14091JoeKuoD6Init[]   =   { 1, 3, 5, 11, 19, 3, 83, 151, 425, 199, 847, 3751, 1729, 12457, 21819, 295, 53627, 17555, 0 };
            const std::uint32_t dim14092JoeKuoD6Init[]   =   { 1, 1, 3, 5, 7, 43, 21, 221, 93, 785, 1851, 3891, 2103, 5219, 31845, 58943, 42461, 160149, 0 };
            const std::uint32_t dim14093JoeKuoD6Init[]   =   { 1, 3, 5, 9, 25, 11, 43, 171, 445, 335, 1907, 3401, 815, 10341, 17779, 24895, 7727, 168143, 0 };
            const std::uint32_t dim14094JoeKuoD6Init[]   =   { 1, 3, 1, 5, 27, 25, 41, 13, 239, 233, 1861, 3409, 4325, 2227, 30197, 59329, 48501, 168799, 0 };
            const std::uint32_t dim14095JoeKuoD6Init[]   =   { 1, 3, 5, 13, 9, 55, 83, 185, 287, 83, 1545, 2803, 2177, 6195, 14455, 30541, 75731, 98915, 0 };
            const std::uint32_t dim14096JoeKuoD6Init[]   =   { 1, 3, 3, 5, 25, 19, 5, 203, 303, 703, 1861, 3867, 2683, 8223, 11107, 54785, 106053, 135543, 0 };
            const std::uint32_t dim14097JoeKuoD6Init[]   =   { 1, 1, 1, 13, 19, 7, 11, 197, 303, 541, 977, 2083, 4739, 7971, 2245, 11029, 77333, 16573, 0 };
            const std::uint32_t dim14098JoeKuoD6Init[]   =   { 1, 1, 1, 3, 11, 33, 77, 59, 283, 791, 365, 4027, 487, 10559, 4543, 58111, 91861, 102905, 0 };
            const std::uint32_t dim14099JoeKuoD6Init[]   =   { 1, 3, 7, 7, 15, 3, 19, 51, 339, 377, 929, 693, 1617, 14057, 7107, 27181, 7411, 202843, 0 };
            const std::uint32_t dim14100JoeKuoD6Init[]   =   { 1, 3, 3, 9, 19, 9, 73, 109, 333, 917, 1227, 2871, 4893, 11029, 5619, 27091, 9381, 213403, 0 };
            const std::uint32_t dim14101JoeKuoD6Init[]   =   { 1, 1, 1, 9, 9, 13, 77, 131, 163, 619, 169, 315, 1277, 13705, 16853, 1179, 86433, 135427, 0 };
            const std::uint32_t dim14102JoeKuoD6Init[]   =   { 1, 3, 5, 9, 15, 47, 57, 119, 325, 529, 893, 2395, 5159, 5481, 18689, 6457, 114733, 159999, 0 };
            const std::uint32_t dim14103JoeKuoD6Init[]   =   { 1, 3, 7, 5, 15, 9, 113, 235, 475, 93, 495, 2983, 2769, 5209, 7481, 49699, 46961, 246393, 0 };
            const std::uint32_t dim14104JoeKuoD6Init[]   =   { 1, 1, 7, 1, 5, 31, 113, 27, 359, 635, 955, 2795, 6289, 11621, 11059, 2259, 57443, 243143, 0 };
            const std::uint32_t dim14105JoeKuoD6Init[]   =   { 1, 3, 3, 13, 19, 33, 53, 141, 437, 415, 919, 1375, 2703, 13731, 31559, 14115, 50101, 85199, 0 };
            const std::uint32_t dim14106JoeKuoD6Init[]   =   { 1, 1, 7, 13, 27, 57, 111, 89, 89, 313, 1107, 4049, 2485, 269, 10197, 36995, 71381, 112795, 0 };
            const std::uint32_t dim14107JoeKuoD6Init[]   =   { 1, 1, 3, 7, 17, 23, 119, 123, 145, 213, 1273, 1707, 4005, 13815, 23495, 36359, 14391, 94287, 0 };
            const std::uint32_t dim14108JoeKuoD6Init[]   =   { 1, 1, 7, 1, 5, 49, 81, 193, 105, 1003, 413, 2975, 1725, 5647, 25447, 43501, 4431, 115489, 0 };
            const std::uint32_t dim14109JoeKuoD6Init[]   =   { 1, 3, 1, 5, 29, 13, 47, 37, 441, 955, 611, 853, 7225, 4959, 8739, 31703, 48095, 124085, 0 };
            const std::uint32_t dim14110JoeKuoD6Init[]   =   { 1, 1, 5, 15, 31, 9, 125, 53, 229, 631, 1031, 3923, 4417, 12637, 22093, 46985, 103417, 193443, 0 };
            const std::uint32_t dim14111JoeKuoD6Init[]   =   { 1, 1, 7, 1, 7, 9, 77, 11, 451, 615, 1259, 3097, 1513, 13641, 26845, 17399, 63661, 9231, 0 };
            const std::uint32_t dim14112JoeKuoD6Init[]   =   { 1, 1, 7, 13, 25, 47, 125, 1, 333, 599, 1133, 3527, 7451, 2849, 27227, 40015, 118185, 24737, 0 };
            const std::uint32_t dim14113JoeKuoD6Init[]   =   { 1, 1, 5, 5, 31, 15, 85, 37, 121, 677, 593, 2757, 739, 839, 3939, 36339, 116663, 955, 0 };
            const std::uint32_t dim14114JoeKuoD6Init[]   =   { 1, 3, 1, 11, 19, 13, 87, 109, 149, 215, 1811, 3813, 7699, 16189, 12841, 52081, 104545, 245819, 0 };
            const std::uint32_t dim14115JoeKuoD6Init[]   =   { 1, 1, 7, 3, 31, 17, 99, 23, 377, 131, 821, 1167, 4437, 15727, 20753, 8163, 43719, 7243, 0 };
            const std::uint32_t dim14116JoeKuoD6Init[]   =   { 1, 3, 7, 13, 21, 5, 5, 167, 9, 1009, 1013, 797, 6145, 2855, 19969, 59887, 3419, 238661, 0 };
            const std::uint32_t dim14117JoeKuoD6Init[]   =   { 1, 1, 7, 1, 5, 39, 47, 91, 185, 139, 959, 3149, 3423, 8909, 2045, 18187, 71935, 238605, 0 };
            const std::uint32_t dim14118JoeKuoD6Init[]   =   { 1, 3, 5, 11, 29, 63, 105, 43, 27, 221, 879, 181, 1499, 10343, 27135, 823, 4893, 101707, 0 };
            const std::uint32_t dim14119JoeKuoD6Init[]   =   { 1, 3, 5, 11, 5, 13, 59, 83, 315, 999, 1205, 939, 3661, 3081, 15551, 13791, 49027, 26843, 0 };
            const std::uint32_t dim14120JoeKuoD6Init[]   =   { 1, 1, 1, 5, 3, 57, 105, 169, 123, 463, 1471, 445, 743, 13353, 17661, 23437, 35451, 115919, 0 };
            const std::uint32_t dim14121JoeKuoD6Init[]   =   { 1, 1, 5, 11, 9, 3, 41, 63, 501, 861, 153, 1591, 1379, 5189, 24483, 8073, 43319, 248959, 0 };
            const std::uint32_t dim14122JoeKuoD6Init[]   =   { 1, 1, 7, 3, 29, 45, 51, 177, 1, 961, 1493, 2179, 3723, 1923, 1517, 44823, 81613, 194641, 0 };
            const std::uint32_t dim14123JoeKuoD6Init[]   =   { 1, 1, 5, 11, 17, 17, 61, 141, 5, 529, 379, 2509, 1487, 13141, 10877, 18603, 40569, 69639, 0 };
            const std::uint32_t dim14124JoeKuoD6Init[]   =   { 1, 1, 5, 15, 1, 15, 33, 219, 269, 557, 7, 3627, 183, 6975, 4627, 15235, 51863, 172393, 0 };
            const std::uint32_t dim14125JoeKuoD6Init[]   =   { 1, 3, 7, 9, 1, 37, 13, 75, 151, 153, 1693, 2835, 3093, 8847, 6721, 44135, 128931, 230745, 0 };
            const std::uint32_t dim14126JoeKuoD6Init[]   =   { 1, 1, 3, 13, 29, 63, 33, 153, 503, 137, 401, 2315, 2223, 10843, 4235, 37295, 103249, 183899, 0 };
            const std::uint32_t dim14127JoeKuoD6Init[]   =   { 1, 1, 7, 11, 15, 25, 49, 55, 39, 13, 269, 3119, 3445, 8265, 16781, 57239, 97489, 204841, 0 };
            const std::uint32_t dim14128JoeKuoD6Init[]   =   { 1, 1, 1, 1, 25, 57, 117, 199, 41, 351, 477, 1891, 7913, 14439, 25305, 64811, 57731, 184265, 0 };
            const std::uint32_t dim14129JoeKuoD6Init[]   =   { 1, 3, 3, 1, 13, 41, 33, 53, 381, 31, 1861, 2207, 1497, 15539, 23589, 53215, 36887, 134007, 0 };
            const std::uint32_t dim14130JoeKuoD6Init[]   =   { 1, 1, 5, 7, 15, 37, 13, 99, 17, 325, 643, 2943, 7967, 11531, 21301, 5125, 63201, 101203, 0 };
            const std::uint32_t dim14131JoeKuoD6Init[]   =   { 1, 1, 7, 11, 23, 21, 119, 151, 457, 929, 1917, 3123, 1133, 11861, 27889, 40421, 90949, 113237, 0 };
            const std::uint32_t dim14132JoeKuoD6Init[]   =   { 1, 3, 5, 9, 13, 35, 111, 83, 371, 589, 1507, 3559, 773, 5895, 31453, 40865, 124103, 250473, 0 };
            const std::uint32_t dim14133JoeKuoD6Init[]   =   { 1, 3, 3, 15, 11, 7, 93, 163, 285, 763, 2023, 1047, 3349, 13575, 22571, 21513, 56081, 204765, 0 };
            const std::uint32_t dim14134JoeKuoD6Init[]   =   { 1, 3, 3, 5, 19, 19, 47, 25, 49, 717, 1155, 3901, 407, 2699, 30961, 55647, 96043, 185559, 0 };
            const std::uint32_t dim14135JoeKuoD6Init[]   =   { 1, 1, 1, 7, 29, 1, 49, 87, 311, 435, 1235, 1041, 6595, 1639, 32495, 44245, 6593, 236331, 0 };
            const std::uint32_t dim14136JoeKuoD6Init[]   =   { 1, 3, 7, 9, 27, 13, 1, 41, 75, 953, 1635, 101, 7231, 13019, 14773, 17315, 120993, 111215, 0 };
            const std::uint32_t dim14137JoeKuoD6Init[]   =   { 1, 1, 5, 9, 23, 31, 87, 47, 83, 791, 1239, 1453, 5459, 4847, 7285, 32667, 45991, 103593, 0 };
            const std::uint32_t dim14138JoeKuoD6Init[]   =   { 1, 3, 1, 3, 27, 47, 97, 191, 5, 961, 1191, 3897, 6821, 4257, 22047, 31557, 52603, 251405, 0 };
            const std::uint32_t dim14139JoeKuoD6Init[]   =   { 1, 1, 5, 3, 23, 45, 103, 115, 287, 47, 93, 2761, 6467, 14031, 21881, 31631, 47605, 237635, 0 };
            const std::uint32_t dim14140JoeKuoD6Init[]   =   { 1, 3, 7, 15, 23, 41, 63, 239, 115, 655, 1949, 1969, 3145, 91, 16735, 49295, 117995, 40537, 0 };
            const std::uint32_t dim14141JoeKuoD6Init[]   =   { 1, 1, 7, 11, 5, 25, 99, 247, 11, 707, 1497, 785, 6055, 8521, 12179, 56363, 110131, 55449, 0 };
            const std::uint32_t dim14142JoeKuoD6Init[]   =   { 1, 1, 1, 7, 5, 31, 99, 7, 285, 281, 1207, 1173, 7637, 9595, 31413, 16597, 96157, 39059, 0 };
            const std::uint32_t dim14143JoeKuoD6Init[]   =   { 1, 3, 7, 7, 3, 49, 79, 69, 57, 523, 65, 2785, 2907, 11295, 16199, 25845, 51801, 67417, 0 };
            const std::uint32_t dim14144JoeKuoD6Init[]   =   { 1, 1, 3, 1, 1, 53, 57, 117, 1, 927, 1787, 3059, 7441, 14663, 10881, 2225, 29375, 93717, 0 };
            const std::uint32_t dim14145JoeKuoD6Init[]   =   { 1, 1, 5, 5, 29, 17, 67, 35, 475, 367, 155, 3463, 2339, 6239, 31073, 56169, 130309, 28981, 0 };
            const std::uint32_t dim14146JoeKuoD6Init[]   =   { 1, 1, 1, 5, 7, 53, 61, 105, 355, 817, 869, 2863, 6041, 11459, 4151, 61115, 100689, 32917, 0 };
            const std::uint32_t dim14147JoeKuoD6Init[]   =   { 1, 3, 5, 11, 31, 11, 33, 105, 437, 767, 101, 2979, 3911, 4859, 15551, 23545, 10705, 6271, 0 };
            const std::uint32_t dim14148JoeKuoD6Init[]   =   { 1, 1, 7, 5, 1, 17, 109, 205, 409, 893, 889, 2181, 6167, 14273, 25389, 50279, 5497, 191755, 0 };
            const std::uint32_t dim14149JoeKuoD6Init[]   =   { 1, 3, 7, 15, 29, 11, 79, 101, 123, 399, 1159, 1263, 3513, 13169, 2199, 41057, 98639, 227107, 0 };
            const std::uint32_t dim14150JoeKuoD6Init[]   =   { 1, 1, 3, 11, 13, 31, 51, 119, 257, 829, 337, 3267, 7673, 15459, 26681, 4041, 89429, 198607, 0 };
            const std::uint32_t dim14151JoeKuoD6Init[]   =   { 1, 3, 7, 11, 23, 29, 49, 159, 327, 415, 857, 2411, 2429, 11839, 20263, 61813, 31811, 225443, 0 };
            const std::uint32_t dim14152JoeKuoD6Init[]   =   { 1, 1, 3, 11, 7, 61, 61, 119, 431, 299, 1815, 2857, 7605, 7517, 15137, 13727, 73021, 199325, 0 };
            const std::uint32_t dim14153JoeKuoD6Init[]   =   { 1, 1, 7, 3, 5, 19, 51, 19, 59, 637, 591, 2999, 5997, 13487, 807, 4887, 112189, 226597, 0 };
            const std::uint32_t dim14154JoeKuoD6Init[]   =   { 1, 1, 1, 13, 21, 5, 55, 167, 463, 679, 891, 3597, 785, 7717, 17495, 51681, 55957, 48561, 0 };
            const std::uint32_t dim14155JoeKuoD6Init[]   =   { 1, 1, 5, 5, 9, 55, 55, 143, 193, 839, 785, 1713, 7457, 11591, 15803, 2479, 124663, 72631, 0 };
            const std::uint32_t dim14156JoeKuoD6Init[]   =   { 1, 3, 5, 9, 21, 27, 109, 91, 483, 905, 1369, 2573, 7173, 13977, 20131, 17637, 127477, 66457, 0 };
            const std::uint32_t dim14157JoeKuoD6Init[]   =   { 1, 1, 5, 7, 31, 17, 43, 153, 505, 413, 867, 769, 6947, 10815, 18805, 5957, 27715, 24529, 0 };
            const std::uint32_t dim14158JoeKuoD6Init[]   =   { 1, 3, 5, 9, 13, 41, 107, 199, 69, 1019, 2037, 3221, 1081, 15051, 6713, 46379, 17223, 85453, 0 };
            const std::uint32_t dim14159JoeKuoD6Init[]   =   { 1, 3, 3, 7, 23, 51, 45, 133, 227, 373, 1815, 3795, 5567, 7153, 25003, 64951, 75377, 174115, 0 };
            const std::uint32_t dim14160JoeKuoD6Init[]   =   { 1, 1, 7, 15, 7, 51, 33, 239, 113, 133, 1213, 327, 4841, 11297, 1093, 40013, 60843, 99845, 0 };
            const std::uint32_t dim14161JoeKuoD6Init[]   =   { 1, 1, 1, 11, 3, 37, 33, 107, 275, 747, 1451, 1787, 5029, 3101, 11575, 36555, 46181, 221643, 0 };
            const std::uint32_t dim14162JoeKuoD6Init[]   =   { 1, 1, 3, 3, 29, 53, 57, 67, 209, 153, 345, 2897, 5657, 8907, 14159, 9899, 102487, 237721, 0 };
            const std::uint32_t dim14163JoeKuoD6Init[]   =   { 1, 3, 1, 7, 7, 59, 17, 151, 423, 903, 2035, 861, 1057, 2399, 28547, 3659, 29583, 100651, 0 };
            const std::uint32_t dim14164JoeKuoD6Init[]   =   { 1, 1, 5, 15, 27, 53, 101, 17, 405, 869, 1253, 1923, 999, 7787, 23621, 4351, 48611, 47129, 0 };
            const std::uint32_t dim14165JoeKuoD6Init[]   =   { 1, 3, 7, 11, 13, 43, 61, 161, 43, 831, 2021, 579, 5353, 12451, 32261, 39885, 90051, 34407, 0 };
            const std::uint32_t dim14166JoeKuoD6Init[]   =   { 1, 1, 1, 5, 25, 19, 37, 33, 37, 59, 1399, 1587, 1517, 4261, 31215, 33777, 50447, 87049, 0 };
            const std::uint32_t dim14167JoeKuoD6Init[]   =   { 1, 1, 3, 1, 19, 17, 113, 31, 385, 135, 143, 3997, 1365, 2625, 22591, 8887, 31353, 240603, 0 };
            const std::uint32_t dim14168JoeKuoD6Init[]   =   { 1, 3, 7, 11, 21, 7, 55, 171, 233, 1007, 1321, 2903, 2457, 3941, 19667, 49115, 99119, 185989, 0 };
            const std::uint32_t dim14169JoeKuoD6Init[]   =   { 1, 3, 7, 9, 3, 31, 83, 99, 303, 443, 99, 2285, 1491, 15897, 21735, 1575, 74449, 59615, 0 };
            const std::uint32_t dim14170JoeKuoD6Init[]   =   { 1, 3, 1, 5, 29, 37, 125, 213, 277, 115, 255, 137, 6071, 13561, 23871, 48129, 120211, 168603, 0 };
            const std::uint32_t dim14171JoeKuoD6Init[]   =   { 1, 1, 7, 3, 9, 21, 93, 239, 399, 21, 9, 409, 3403, 9517, 6421, 17121, 65697, 251985, 0 };
            const std::uint32_t dim14172JoeKuoD6Init[]   =   { 1, 1, 1, 15, 27, 35, 17, 113, 471, 357, 1703, 871, 1803, 3495, 27437, 48343, 86425, 155245, 0 };
            const std::uint32_t dim14173JoeKuoD6Init[]   =   { 1, 3, 7, 11, 19, 45, 51, 195, 345, 77, 1403, 2527, 3405, 14057, 31965, 17375, 35107, 246545, 0 };
            const std::uint32_t dim14174JoeKuoD6Init[]   =   { 1, 3, 5, 7, 7, 5, 115, 39, 51, 261, 1883, 1793, 3423, 3613, 20399, 27267, 99875, 119719, 0 };
            const std::uint32_t dim14175JoeKuoD6Init[]   =   { 1, 3, 3, 9, 21, 23, 65, 69, 261, 79, 151, 3387, 7789, 13275, 30135, 52229, 40787, 181297, 0 };
            const std::uint32_t dim14176JoeKuoD6Init[]   =   { 1, 1, 5, 13, 19, 49, 111, 125, 433, 99, 1673, 2091, 5447, 9377, 9085, 4659, 75121, 105809, 0 };
            const std::uint32_t dim14177JoeKuoD6Init[]   =   { 1, 3, 7, 1, 3, 27, 107, 109, 245, 431, 1727, 3269, 2099, 10777, 21843, 63377, 47343, 126269, 0 };
            const std::uint32_t dim14178JoeKuoD6Init[]   =   { 1, 3, 1, 15, 7, 17, 107, 153, 37, 287, 1873, 573, 5025, 3735, 32545, 35693, 38083, 89569, 0 };
            const std::uint32_t dim14179JoeKuoD6Init[]   =   { 1, 3, 1, 3, 9, 51, 99, 247, 45, 703, 1231, 1895, 6309, 12137, 14697, 25441, 129701, 198811, 0 };
            const std::uint32_t dim14180JoeKuoD6Init[]   =   { 1, 3, 3, 11, 5, 43, 1, 31, 359, 563, 1013, 3475, 3935, 7855, 10085, 15279, 25109, 225643, 0 };
            const std::uint32_t dim14181JoeKuoD6Init[]   =   { 1, 3, 3, 3, 9, 47, 49, 193, 223, 23, 391, 847, 7233, 14955, 10645, 50535, 5415, 119791, 0 };
            const std::uint32_t dim14182JoeKuoD6Init[]   =   { 1, 3, 1, 7, 3, 7, 57, 189, 219, 287, 401, 1767, 5585, 13983, 18485, 56725, 71905, 33779, 0 };
            const std::uint32_t dim14183JoeKuoD6Init[]   =   { 1, 3, 5, 15, 23, 17, 115, 223, 35, 263, 345, 3459, 857, 1467, 30255, 50127, 72985, 62509, 0 };
            const std::uint32_t dim14184JoeKuoD6Init[]   =   { 1, 3, 1, 9, 3, 27, 125, 43, 47, 183, 1421, 319, 4273, 10701, 21761, 23947, 22531, 10855, 0 };
            const std::uint32_t dim14185JoeKuoD6Init[]   =   { 1, 1, 3, 15, 13, 55, 77, 1, 295, 841, 1115, 4093, 7993, 13309, 24851, 35411, 105201, 188543, 0 };
            const std::uint32_t dim14186JoeKuoD6Init[]   =   { 1, 3, 3, 5, 19, 39, 101, 19, 225, 997, 1999, 407, 3147, 15393, 30379, 26221, 21685, 114167, 0 };
            const std::uint32_t dim14187JoeKuoD6Init[]   =   { 1, 3, 3, 3, 23, 15, 3, 57, 45, 381, 47, 1839, 5491, 6775, 18477, 51443, 757, 183111, 0 };
            const std::uint32_t dim14188JoeKuoD6Init[]   =   { 1, 3, 3, 7, 31, 27, 107, 229, 1, 977, 125, 1137, 4873, 14381, 8705, 64641, 38447, 239887, 0 };
            const std::uint32_t dim14189JoeKuoD6Init[]   =   { 1, 1, 3, 13, 9, 35, 49, 187, 459, 407, 1677, 2007, 1091, 12385, 8911, 38221, 108681, 171641, 0 };
            const std::uint32_t dim14190JoeKuoD6Init[]   =   { 1, 1, 3, 5, 7, 61, 115, 155, 437, 829, 1041, 2191, 1489, 1269, 27613, 48713, 40095, 206057, 0 };
            const std::uint32_t dim14191JoeKuoD6Init[]   =   { 1, 3, 7, 1, 23, 1, 17, 215, 363, 119, 845, 987, 5619, 5857, 11307, 63171, 76921, 201767, 0 };
            const std::uint32_t dim14192JoeKuoD6Init[]   =   { 1, 1, 7, 9, 29, 23, 63, 247, 37, 199, 103, 1215, 913, 12865, 24089, 35101, 117677, 261393, 0 };
            const std::uint32_t dim14193JoeKuoD6Init[]   =   { 1, 1, 1, 1, 3, 19, 7, 159, 183, 275, 467, 3629, 6575, 3351, 26955, 29247, 119007, 67895, 0 };
            const std::uint32_t dim14194JoeKuoD6Init[]   =   { 1, 1, 7, 13, 1, 33, 31, 211, 103, 495, 417, 817, 7129, 10169, 11445, 41511, 73101, 185357, 0 };
            const std::uint32_t dim14195JoeKuoD6Init[]   =   { 1, 1, 3, 5, 3, 27, 99, 1, 425, 295, 131, 835, 1833, 4547, 8777, 29489, 60303, 191437, 0 };
            const std::uint32_t dim14196JoeKuoD6Init[]   =   { 1, 1, 5, 5, 31, 63, 71, 189, 317, 61, 385, 891, 2257, 8281, 17325, 12207, 125847, 28259, 0 };
            const std::uint32_t dim14197JoeKuoD6Init[]   =   { 1, 1, 3, 3, 19, 19, 97, 83, 495, 551, 1339, 1699, 3047, 13623, 27731, 28999, 101225, 146139, 0 };
            const std::uint32_t dim14198JoeKuoD6Init[]   =   { 1, 3, 5, 7, 25, 9, 37, 73, 239, 47, 583, 3337, 1329, 79, 30109, 12451, 10163, 62943, 0 };
            const std::uint32_t dim14199JoeKuoD6Init[]   =   { 1, 1, 3, 1, 9, 1, 31, 181, 231, 441, 1241, 233, 6049, 2401, 9867, 58911, 20599, 26321, 0 };
            const std::uint32_t dim14200JoeKuoD6Init[]   =   { 1, 3, 1, 15, 21, 43, 21, 43, 273, 865, 79, 2069, 3375, 16069, 12355, 56355, 9735, 243719, 0 };
            const std::uint32_t dim14201JoeKuoD6Init[]   =   { 1, 3, 5, 11, 13, 21, 5, 73, 423, 761, 1947, 2935, 3931, 5573, 83, 58251, 113115, 245767, 0 };
            const std::uint32_t dim14202JoeKuoD6Init[]   =   { 1, 3, 7, 7, 15, 49, 73, 211, 309, 635, 1257, 2185, 7151, 11959, 26885, 45955, 103503, 161709, 0 };
            const std::uint32_t dim14203JoeKuoD6Init[]   =   { 1, 3, 1, 15, 31, 53, 29, 35, 343, 87, 1833, 2483, 1847, 4709, 6105, 21961, 106541, 46741, 0 };
            const std::uint32_t dim14204JoeKuoD6Init[]   =   { 1, 1, 7, 7, 21, 43, 41, 51, 29, 521, 713, 3693, 483, 11777, 10453, 43691, 97585, 133193, 0 };
            const std::uint32_t dim14205JoeKuoD6Init[]   =   { 1, 3, 3, 11, 5, 45, 3, 179, 183, 255, 1291, 1795, 5721, 10911, 18395, 64349, 23141, 99481, 0 };
            const std::uint32_t dim14206JoeKuoD6Init[]   =   { 1, 1, 1, 5, 5, 25, 61, 169, 475, 953, 617, 559, 5945, 16377, 30063, 30079, 83305, 81745, 0 };
            const std::uint32_t dim14207JoeKuoD6Init[]   =   { 1, 1, 5, 11, 29, 59, 113, 37, 153, 807, 135, 2639, 4535, 7079, 6387, 63523, 89669, 198803, 0 };
            const std::uint32_t dim14208JoeKuoD6Init[]   =   { 1, 1, 7, 7, 19, 23, 71, 51, 165, 733, 1427, 2473, 331, 5027, 9299, 20617, 126775, 91619, 0 };
            const std::uint32_t dim14209JoeKuoD6Init[]   =   { 1, 3, 5, 7, 31, 35, 117, 235, 29, 677, 1243, 281, 6287, 535, 4783, 37781, 130929, 14193, 0 };
            const std::uint32_t dim14210JoeKuoD6Init[]   =   { 1, 1, 5, 3, 25, 1, 29, 109, 289, 631, 41, 361, 5537, 9657, 7475, 63749, 50325, 169791, 0 };
            const std::uint32_t dim14211JoeKuoD6Init[]   =   { 1, 3, 3, 15, 21, 53, 85, 43, 341, 907, 475, 3257, 2541, 10397, 30847, 63681, 121427, 192135, 0 };
            const std::uint32_t dim14212JoeKuoD6Init[]   =   { 1, 1, 1, 1, 9, 59, 59, 233, 335, 345, 1749, 4007, 1833, 7789, 21015, 48939, 15967, 201321, 0 };
            const std::uint32_t dim14213JoeKuoD6Init[]   =   { 1, 1, 1, 5, 11, 9, 101, 243, 391, 1003, 1019, 311, 3707, 10223, 21627, 8237, 53861, 159785, 0 };
            const std::uint32_t dim14214JoeKuoD6Init[]   =   { 1, 3, 7, 15, 5, 3, 109, 197, 507, 947, 833, 1161, 4021, 5575, 8081, 45381, 112597, 70407, 0 };
            const std::uint32_t dim14215JoeKuoD6Init[]   =   { 1, 1, 3, 1, 7, 63, 63, 53, 481, 1003, 43, 2503, 2303, 12593, 21403, 2965, 5377, 91491, 0 };
            const std::uint32_t dim14216JoeKuoD6Init[]   =   { 1, 1, 1, 1, 29, 45, 49, 73, 253, 197, 1245, 1509, 4747, 6207, 28321, 59193, 112687, 83719, 0 };
            const std::uint32_t dim14217JoeKuoD6Init[]   =   { 1, 1, 7, 3, 11, 51, 23, 83, 185, 643, 1427, 227, 2261, 12521, 27033, 5129, 53111, 34975, 0 };
            const std::uint32_t dim14218JoeKuoD6Init[]   =   { 1, 1, 7, 3, 5, 41, 55, 175, 447, 603, 723, 2141, 1189, 4921, 16905, 2463, 83641, 247241, 0 };
            const std::uint32_t dim14219JoeKuoD6Init[]   =   { 1, 3, 3, 13, 5, 11, 95, 59, 391, 319, 1675, 329, 7559, 11585, 28905, 27843, 106667, 15531, 0 };
            const std::uint32_t dim14220JoeKuoD6Init[]   =   { 1, 3, 3, 3, 27, 17, 103, 115, 447, 657, 267, 2541, 665, 7819, 4155, 32191, 60999, 48737, 0 };
            const std::uint32_t dim14221JoeKuoD6Init[]   =   { 1, 1, 5, 7, 7, 49, 87, 171, 457, 149, 1699, 4081, 3913, 7889, 29517, 3339, 33139, 8925, 0 };
            const std::uint32_t dim14222JoeKuoD6Init[]   =   { 1, 1, 1, 9, 11, 51, 87, 115, 429, 505, 1665, 2361, 5811, 1621, 12727, 33703, 52255, 93835, 0 };
            const std::uint32_t dim14223JoeKuoD6Init[]   =   { 1, 3, 3, 5, 27, 11, 35, 49, 281, 607, 1791, 4065, 5103, 5253, 975, 20353, 38253, 139363, 0 };
            const std::uint32_t dim14224JoeKuoD6Init[]   =   { 1, 1, 5, 9, 29, 15, 37, 141, 445, 751, 1219, 2217, 7207, 14981, 21113, 3313, 107127, 135567, 0 };
            const std::uint32_t dim14225JoeKuoD6Init[]   =   { 1, 3, 3, 15, 1, 41, 23, 27, 167, 609, 913, 631, 923, 6939, 9793, 57869, 126577, 145271, 0 };
            const std::uint32_t dim14226JoeKuoD6Init[]   =   { 1, 1, 3, 7, 27, 47, 127, 5, 213, 575, 559, 2541, 3457, 2903, 19529, 53395, 105353, 212607, 0 };
            const std::uint32_t dim14227JoeKuoD6Init[]   =   { 1, 3, 1, 13, 27, 41, 31, 111, 371, 1019, 241, 2075, 2571, 10739, 28163, 16093, 41127, 69783, 0 };
            const std::uint32_t dim14228JoeKuoD6Init[]   =   { 1, 1, 5, 1, 21, 9, 15, 141, 287, 675, 1721, 2291, 6587, 7503, 6363, 9109, 33547, 259627, 0 };
            const std::uint32_t dim14229JoeKuoD6Init[]   =   { 1, 3, 7, 3, 3, 53, 7, 153, 183, 761, 191, 3735, 2619, 11153, 19601, 33855, 82345, 72755, 0 };
            const std::uint32_t dim14230JoeKuoD6Init[]   =   { 1, 3, 1, 9, 19, 21, 41, 105, 281, 833, 981, 2733, 7179, 14691, 18365, 56283, 53719, 191601, 0 };
            const std::uint32_t dim14231JoeKuoD6Init[]   =   { 1, 1, 7, 11, 23, 1, 55, 213, 105, 517, 809, 4087, 825, 7011, 15701, 54047, 123831, 49833, 0 };
            const std::uint32_t dim14232JoeKuoD6Init[]   =   { 1, 1, 7, 13, 27, 9, 111, 57, 357, 95, 1489, 887, 5273, 2833, 8757, 9371, 44637, 94939, 0 };
            const std::uint32_t dim14233JoeKuoD6Init[]   =   { 1, 1, 3, 5, 1, 17, 43, 31, 509, 353, 401, 1077, 7567, 9657, 15065, 32017, 8491, 214477, 0 };
            const std::uint32_t dim14234JoeKuoD6Init[]   =   { 1, 1, 1, 15, 7, 59, 41, 99, 101, 845, 1479, 2153, 4281, 12839, 237, 54095, 125873, 57165, 0 };
            const std::uint32_t dim14235JoeKuoD6Init[]   =   { 1, 3, 7, 13, 5, 17, 1, 249, 309, 351, 709, 3943, 7775, 6449, 26611, 54019, 121015, 213535, 0 };
            const std::uint32_t dim14236JoeKuoD6Init[]   =   { 1, 1, 1, 5, 7, 25, 33, 149, 291, 777, 161, 2729, 117, 4999, 16781, 23383, 85161, 71689, 0 };
            const std::uint32_t dim14237JoeKuoD6Init[]   =   { 1, 1, 3, 11, 5, 63, 119, 165, 45, 135, 1723, 811, 1259, 11055, 28625, 37559, 128401, 100715, 0 };
            const std::uint32_t dim14238JoeKuoD6Init[]   =   { 1, 3, 7, 1, 1, 39, 11, 255, 423, 289, 1359, 2827, 4637, 4089, 26659, 58701, 117403, 133971, 0 };
            const std::uint32_t dim14239JoeKuoD6Init[]   =   { 1, 1, 7, 1, 25, 9, 127, 121, 147, 831, 17, 3521, 1535, 10931, 17305, 56671, 22425, 157341, 0 };
            const std::uint32_t dim14240JoeKuoD6Init[]   =   { 1, 3, 1, 15, 5, 55, 95, 95, 169, 497, 739, 2031, 339, 13461, 20619, 24553, 81805, 90789, 0 };
            const std::uint32_t dim14241JoeKuoD6Init[]   =   { 1, 1, 7, 7, 7, 19, 15, 203, 287, 673, 1033, 3857, 2761, 10835, 11039, 62329, 37893, 6119, 0 };
            const std::uint32_t dim14242JoeKuoD6Init[]   =   { 1, 1, 3, 11, 19, 35, 55, 9, 399, 443, 583, 89, 2387, 747, 9551, 9907, 96871, 175457, 0 };
            const std::uint32_t dim14243JoeKuoD6Init[]   =   { 1, 1, 3, 1, 11, 57, 121, 89, 491, 133, 545, 683, 5751, 839, 25975, 44725, 59863, 142671, 0 };
            const std::uint32_t dim14244JoeKuoD6Init[]   =   { 1, 1, 3, 1, 23, 1, 111, 177, 1, 103, 1933, 2783, 6857, 51, 14547, 5945, 14757, 39783, 0 };
            const std::uint32_t dim14245JoeKuoD6Init[]   =   { 1, 3, 7, 13, 25, 13, 51, 247, 325, 361, 1225, 15, 1929, 1729, 25293, 59495, 82111, 101809, 0 };
            const std::uint32_t dim14246JoeKuoD6Init[]   =   { 1, 3, 3, 1, 19, 37, 67, 85, 105, 589, 1273, 2995, 8017, 1613, 22189, 2549, 22671, 72813, 0 };
            const std::uint32_t dim14247JoeKuoD6Init[]   =   { 1, 3, 7, 9, 15, 41, 25, 43, 411, 663, 387, 2861, 3627, 5839, 733, 53479, 76241, 116763, 0 };
            const std::uint32_t dim14248JoeKuoD6Init[]   =   { 1, 3, 3, 3, 17, 5, 73, 153, 133, 247, 881, 2853, 6059, 2259, 10181, 63251, 107089, 22579, 0 };
            const std::uint32_t dim14249JoeKuoD6Init[]   =   { 1, 3, 1, 5, 11, 15, 17, 235, 23, 15, 521, 235, 4137, 12705, 24775, 18197, 56295, 28035, 0 };
            const std::uint32_t dim14250JoeKuoD6Init[]   =   { 1, 3, 5, 5, 13, 9, 77, 69, 19, 755, 1663, 1499, 1049, 12935, 28835, 55413, 71511, 221223, 0 };
            const std::uint32_t dim14251JoeKuoD6Init[]   =   { 1, 1, 1, 1, 27, 31, 21, 39, 197, 519, 1621, 3703, 2541, 8865, 21947, 53605, 114551, 205697, 0 };
            const std::uint32_t dim14252JoeKuoD6Init[]   =   { 1, 1, 1, 13, 11, 53, 41, 245, 495, 275, 385, 3071, 1913, 11135, 8571, 58551, 39049, 5459, 0 };
            const std::uint32_t dim14253JoeKuoD6Init[]   =   { 1, 3, 5, 5, 11, 63, 25, 173, 57, 441, 1749, 79, 3191, 7733, 13111, 23453, 118399, 101845, 0 };
            const std::uint32_t dim14254JoeKuoD6Init[]   =   { 1, 1, 3, 11, 29, 25, 119, 39, 65, 623, 517, 1325, 5981, 8381, 32031, 25585, 105537, 214241, 0 };
            const std::uint32_t dim14255JoeKuoD6Init[]   =   { 1, 3, 5, 9, 21, 43, 13, 69, 109, 311, 1893, 1941, 2491, 7815, 4067, 56749, 33761, 191145, 0 };
            const std::uint32_t dim14256JoeKuoD6Init[]   =   { 1, 1, 1, 7, 9, 5, 123, 149, 65, 729, 1967, 3089, 3757, 2333, 24587, 36047, 118105, 146277, 0 };
            const std::uint32_t dim14257JoeKuoD6Init[]   =   { 1, 3, 7, 13, 9, 35, 39, 219, 161, 93, 275, 3619, 353, 14595, 24673, 54753, 117175, 81891, 0 };
            const std::uint32_t dim14258JoeKuoD6Init[]   =   { 1, 3, 3, 13, 15, 61, 95, 135, 271, 595, 1103, 877, 747, 2535, 7733, 25509, 65673, 62089, 0 };
            const std::uint32_t dim14259JoeKuoD6Init[]   =   { 1, 3, 3, 5, 21, 21, 67, 5, 373, 377, 61, 2337, 489, 5801, 23203, 42377, 7801, 178095, 0 };
            const std::uint32_t dim14260JoeKuoD6Init[]   =   { 1, 1, 7, 5, 25, 17, 61, 133, 181, 261, 1627, 1615, 6851, 4763, 30353, 53349, 7545, 66733, 0 };
            const std::uint32_t dim14261JoeKuoD6Init[]   =   { 1, 3, 5, 7, 29, 3, 85, 231, 121, 669, 1925, 403, 777, 10605, 24125, 60819, 8253, 81209, 0 };
            const std::uint32_t dim14262JoeKuoD6Init[]   =   { 1, 1, 5, 3, 5, 5, 1, 53, 9, 445, 1339, 2643, 5527, 13757, 9409, 31993, 80845, 97863, 0 };
            const std::uint32_t dim14263JoeKuoD6Init[]   =   { 1, 1, 7, 13, 29, 49, 97, 89, 319, 349, 1739, 3615, 1113, 11791, 17429, 37195, 1159, 32211, 0 };
            const std::uint32_t dim14264JoeKuoD6Init[]   =   { 1, 3, 5, 11, 9, 61, 109, 167, 119, 499, 1157, 3615, 5773, 8839, 27915, 47837, 14945, 187225, 0 };
            const std::uint32_t dim14265JoeKuoD6Init[]   =   { 1, 1, 5, 1, 9, 3, 7, 179, 323, 279, 43, 1337, 4813, 9917, 2033, 34657, 130769, 208089, 0 };
            const std::uint32_t dim14266JoeKuoD6Init[]   =   { 1, 1, 3, 1, 31, 57, 57, 73, 21, 661, 1861, 1661, 7619, 12155, 23123, 49751, 130697, 74143, 0 };
            const std::uint32_t dim14267JoeKuoD6Init[]   =   { 1, 3, 3, 13, 11, 61, 95, 75, 227, 491, 463, 597, 2721, 12323, 26195, 53657, 44413, 68965, 0 };
            const std::uint32_t dim14268JoeKuoD6Init[]   =   { 1, 1, 7, 11, 5, 51, 103, 123, 203, 911, 203, 1641, 7009, 9479, 303, 37649, 32751, 172777, 0 };
            const std::uint32_t dim14269JoeKuoD6Init[]   =   { 1, 1, 3, 7, 11, 59, 111, 5, 271, 863, 269, 3457, 489, 10877, 8645, 62567, 24893, 201587, 0 };
            const std::uint32_t dim14270JoeKuoD6Init[]   =   { 1, 1, 5, 7, 29, 23, 127, 151, 371, 121, 1103, 3951, 3107, 15563, 6243, 1631, 75065, 107681, 0 };
            const std::uint32_t dim14271JoeKuoD6Init[]   =   { 1, 1, 7, 15, 27, 45, 43, 83, 461, 673, 715, 3245, 313, 13731, 21981, 58853, 46569, 165463, 0 };
            const std::uint32_t dim14272JoeKuoD6Init[]   =   { 1, 1, 1, 9, 7, 53, 63, 43, 3, 187, 1325, 447, 5113, 4993, 21807, 24329, 4499, 30067, 0 };
            const std::uint32_t dim14273JoeKuoD6Init[]   =   { 1, 3, 1, 9, 21, 45, 111, 231, 407, 213, 1977, 2269, 2323, 4595, 30427, 54753, 95049, 195409, 0 };
            const std::uint32_t dim14274JoeKuoD6Init[]   =   { 1, 1, 1, 9, 29, 43, 89, 201, 499, 329, 847, 3831, 5403, 13001, 6037, 14371, 25805, 169237, 0 };
            const std::uint32_t dim14275JoeKuoD6Init[]   =   { 1, 1, 1, 11, 29, 61, 61, 203, 91, 189, 1603, 939, 6575, 3195, 4731, 44923, 33627, 21683, 0 };
            const std::uint32_t dim14276JoeKuoD6Init[]   =   { 1, 3, 3, 11, 7, 57, 93, 181, 479, 99, 681, 2875, 7649, 5555, 27087, 6841, 69859, 153689, 0 };
            const std::uint32_t dim14277JoeKuoD6Init[]   =   { 1, 1, 1, 9, 17, 45, 97, 47, 91, 879, 1463, 3041, 2917, 769, 13675, 26489, 88559, 120991, 0 };
            const std::uint32_t dim14278JoeKuoD6Init[]   =   { 1, 3, 7, 1, 11, 13, 43, 9, 483, 399, 793, 3965, 2375, 4957, 17747, 50905, 56987, 231265, 0 };
            const std::uint32_t dim14279JoeKuoD6Init[]   =   { 1, 3, 3, 13, 23, 45, 69, 67, 397, 437, 1993, 2569, 8035, 8531, 27623, 53567, 123189, 242515, 0 };
            const std::uint32_t dim14280JoeKuoD6Init[]   =   { 1, 1, 1, 3, 5, 9, 21, 227, 499, 205, 431, 3711, 5307, 15773, 11337, 6349, 123507, 95941, 0 };
            const std::uint32_t dim14281JoeKuoD6Init[]   =   { 1, 3, 7, 1, 13, 15, 101, 91, 209, 611, 537, 1427, 101, 2619, 10513, 44323, 92745, 249127, 0 };
            const std::uint32_t dim14282JoeKuoD6Init[]   =   { 1, 3, 3, 1, 21, 7, 79, 241, 273, 567, 605, 2371, 5427, 15147, 20139, 40987, 75551, 236213, 0 };
            const std::uint32_t dim14283JoeKuoD6Init[]   =   { 1, 1, 7, 11, 25, 19, 77, 209, 313, 663, 115, 3697, 3641, 12461, 9877, 18331, 70809, 78923, 0 };
            const std::uint32_t dim14284JoeKuoD6Init[]   =   { 1, 1, 5, 5, 29, 45, 7, 207, 1, 357, 1089, 3861, 4161, 3209, 27845, 20947, 68909, 125179, 0 };
            const std::uint32_t dim14285JoeKuoD6Init[]   =   { 1, 3, 1, 13, 17, 11, 27, 165, 179, 489, 1611, 2801, 2385, 2971, 6777, 16149, 59811, 151043, 0 };
            const std::uint32_t dim14286JoeKuoD6Init[]   =   { 1, 1, 3, 3, 17, 53, 121, 227, 7, 71, 1855, 639, 5135, 6349, 7163, 22997, 112551, 44167, 0 };
            const std::uint32_t dim14287JoeKuoD6Init[]   =   { 1, 3, 1, 11, 15, 9, 125, 213, 485, 291, 1781, 3621, 7529, 13353, 13903, 24151, 130253, 187097, 0 };
            const std::uint32_t dim14288JoeKuoD6Init[]   =   { 1, 3, 1, 3, 1, 61, 39, 157, 455, 945, 739, 589, 7259, 7149, 16455, 12649, 72003, 152419, 0 };
            const std::uint32_t dim14289JoeKuoD6Init[]   =   { 1, 1, 3, 3, 31, 23, 17, 255, 319, 907, 563, 2571, 2149, 15323, 20289, 46061, 32769, 184353, 0 };
            const std::uint32_t dim14290JoeKuoD6Init[]   =   { 1, 3, 7, 9, 21, 51, 27, 13, 495, 909, 2039, 1435, 4791, 10037, 30119, 3405, 22535, 42247, 0 };
            const std::uint32_t dim14291JoeKuoD6Init[]   =   { 1, 1, 3, 15, 11, 25, 123, 149, 185, 635, 473, 527, 433, 10373, 18205, 853, 94619, 202507, 0 };
            const std::uint32_t dim14292JoeKuoD6Init[]   =   { 1, 1, 7, 15, 7, 39, 7, 69, 157, 533, 369, 4031, 1335, 4279, 8049, 28491, 103753, 257477, 0 };
            const std::uint32_t dim14293JoeKuoD6Init[]   =   { 1, 3, 1, 15, 29, 51, 113, 77, 5, 961, 1863, 1477, 5009, 9519, 32029, 2367, 55705, 149597, 0 };
            const std::uint32_t dim14294JoeKuoD6Init[]   =   { 1, 3, 1, 5, 19, 43, 49, 107, 59, 693, 867, 3011, 2703, 3633, 24567, 52621, 35839, 134823, 0 };
            const std::uint32_t dim14295JoeKuoD6Init[]   =   { 1, 3, 3, 7, 19, 15, 81, 105, 23, 375, 451, 3017, 1263, 7589, 24453, 21885, 57651, 52613, 0 };
            const std::uint32_t dim14296JoeKuoD6Init[]   =   { 1, 1, 3, 7, 3, 59, 19, 1, 3, 243, 1891, 2041, 4707, 15557, 28885, 5959, 22517, 237131, 0 };
            const std::uint32_t dim14297JoeKuoD6Init[]   =   { 1, 3, 7, 11, 25, 33, 105, 15, 245, 247, 1357, 1255, 7463, 4815, 13727, 41687, 112425, 58827, 0 };
            const std::uint32_t dim14298JoeKuoD6Init[]   =   { 1, 1, 7, 1, 19, 31, 37, 201, 217, 127, 927, 763, 6359, 9951, 2581, 49171, 104305, 215923, 0 };
            const std::uint32_t dim14299JoeKuoD6Init[]   =   { 1, 1, 7, 7, 13, 9, 9, 139, 363, 85, 1703, 3615, 2545, 15991, 20677, 12109, 54951, 2171, 0 };
            const std::uint32_t dim14300JoeKuoD6Init[]   =   { 1, 3, 1, 13, 27, 3, 37, 195, 185, 829, 815, 1621, 2917, 8643, 29071, 45523, 38475, 243505, 0 };
            const std::uint32_t dim14301JoeKuoD6Init[]   =   { 1, 1, 7, 3, 19, 29, 91, 85, 331, 231, 1609, 2583, 1091, 4191, 29929, 55377, 105077, 168425, 0 };
            const std::uint32_t dim14302JoeKuoD6Init[]   =   { 1, 1, 5, 3, 29, 35, 3, 61, 389, 339, 705, 473, 2075, 7373, 9699, 38809, 60415, 66423, 0 };
            const std::uint32_t dim14303JoeKuoD6Init[]   =   { 1, 3, 1, 5, 17, 25, 17, 37, 335, 787, 1891, 1861, 4325, 12721, 9675, 13671, 18655, 235443, 0 };
            const std::uint32_t dim14304JoeKuoD6Init[]   =   { 1, 3, 3, 5, 23, 13, 83, 191, 263, 325, 1847, 1717, 7089, 15709, 26567, 44489, 66523, 3107, 0 };
            const std::uint32_t dim14305JoeKuoD6Init[]   =   { 1, 3, 7, 7, 25, 29, 63, 55, 9, 481, 899, 669, 5481, 11227, 1637, 17017, 124509, 102775, 0 };
            const std::uint32_t dim14306JoeKuoD6Init[]   =   { 1, 1, 1, 5, 21, 41, 101, 93, 129, 1023, 561, 2969, 1525, 2929, 32729, 54513, 4359, 28745, 0 };
            const std::uint32_t dim14307JoeKuoD6Init[]   =   { 1, 1, 5, 13, 15, 13, 79, 9, 257, 535, 861, 2703, 6161, 6659, 10369, 7, 117467, 146651, 0 };
            const std::uint32_t dim14308JoeKuoD6Init[]   =   { 1, 1, 3, 13, 31, 11, 43, 95, 441, 921, 1323, 343, 5339, 13149, 19643, 24253, 32055, 180327, 0 };
            const std::uint32_t dim14309JoeKuoD6Init[]   =   { 1, 1, 5, 15, 11, 27, 109, 149, 255, 1021, 249, 1913, 5213, 301, 9939, 49779, 26097, 66007, 0 };
            const std::uint32_t dim14310JoeKuoD6Init[]   =   { 1, 3, 1, 11, 15, 33, 53, 159, 433, 167, 1107, 3577, 6231, 8309, 28125, 55381, 127309, 14459, 0 };
            const std::uint32_t dim14311JoeKuoD6Init[]   =   { 1, 3, 5, 9, 7, 3, 45, 139, 133, 359, 537, 805, 3931, 5181, 915, 63317, 86227, 231573, 0 };
            const std::uint32_t dim14312JoeKuoD6Init[]   =   { 1, 1, 1, 3, 11, 31, 97, 127, 117, 151, 711, 2457, 2777, 3855, 21829, 7913, 30785, 141449, 0 };
            const std::uint32_t dim14313JoeKuoD6Init[]   =   { 1, 3, 7, 13, 11, 17, 65, 63, 289, 851, 1929, 4021, 105, 5207, 17085, 64119, 48659, 31687, 0 };
            const std::uint32_t dim14314JoeKuoD6Init[]   =   { 1, 1, 7, 11, 31, 57, 63, 251, 341, 727, 505, 1851, 783, 16191, 9335, 39421, 14793, 238215, 0 };
            const std::uint32_t dim14315JoeKuoD6Init[]   =   { 1, 3, 3, 11, 23, 13, 119, 195, 117, 579, 693, 3059, 2967, 12791, 26905, 28527, 13393, 11869, 0 };
            const std::uint32_t dim14316JoeKuoD6Init[]   =   { 1, 3, 7, 11, 23, 7, 61, 143, 409, 309, 651, 3321, 4027, 1351, 10339, 18451, 18447, 235665, 0 };
            const std::uint32_t dim14317JoeKuoD6Init[]   =   { 1, 1, 1, 9, 13, 21, 7, 65, 103, 789, 973, 475, 2831, 13337, 18989, 40573, 105375, 2221, 0 };
            const std::uint32_t dim14318JoeKuoD6Init[]   =   { 1, 3, 5, 15, 3, 59, 115, 61, 365, 653, 523, 3927, 8175, 6751, 32561, 55919, 64903, 139005, 0 };
            const std::uint32_t dim14319JoeKuoD6Init[]   =   { 1, 3, 3, 13, 1, 7, 51, 63, 179, 525, 1899, 373, 3797, 6329, 5539, 32669, 65903, 154993, 0 };
            const std::uint32_t dim14320JoeKuoD6Init[]   =   { 1, 3, 1, 1, 31, 53, 87, 39, 317, 71, 1899, 925, 4719, 11645, 27125, 50391, 116491, 219271, 0 };
            const std::uint32_t dim14321JoeKuoD6Init[]   =   { 1, 3, 7, 13, 7, 23, 1, 57, 333, 277, 893, 3245, 1417, 13115, 21835, 25879, 91305, 54691, 0 };
            const std::uint32_t dim14322JoeKuoD6Init[]   =   { 1, 3, 1, 11, 27, 5, 109, 69, 221, 453, 299, 517, 609, 11959, 27789, 33107, 46559, 121673, 0 };
            const std::uint32_t dim14323JoeKuoD6Init[]   =   { 1, 3, 5, 7, 27, 7, 119, 169, 129, 643, 173, 2479, 6163, 11159, 11897, 57153, 11347, 135337, 0 };
            const std::uint32_t dim14324JoeKuoD6Init[]   =   { 1, 1, 5, 13, 13, 59, 21, 13, 429, 601, 267, 1635, 2579, 12053, 31583, 14847, 78187, 217099, 0 };
            const std::uint32_t dim14325JoeKuoD6Init[]   =   { 1, 3, 5, 9, 5, 3, 125, 159, 411, 15, 479, 933, 6307, 9707, 23491, 6501, 70993, 161365, 0 };
            const std::uint32_t dim14326JoeKuoD6Init[]   =   { 1, 1, 7, 7, 3, 33, 87, 177, 283, 825, 1935, 1545, 7071, 9975, 1795, 48277, 115725, 173439, 0 };
            const std::uint32_t dim14327JoeKuoD6Init[]   =   { 1, 3, 3, 9, 19, 63, 17, 119, 13, 337, 2021, 2221, 3237, 3253, 18661, 15479, 59377, 76095, 0 };
            const std::uint32_t dim14328JoeKuoD6Init[]   =   { 1, 1, 1, 11, 17, 15, 93, 249, 333, 171, 575, 3251, 5413, 3587, 22807, 29273, 56461, 97801, 0 };
            const std::uint32_t dim14329JoeKuoD6Init[]   =   { 1, 3, 3, 11, 13, 7, 27, 167, 389, 693, 1473, 555, 1603, 3167, 3985, 3841, 100283, 195253, 0 };
            const std::uint32_t dim14330JoeKuoD6Init[]   =   { 1, 3, 7, 1, 23, 7, 89, 231, 85, 797, 1935, 2557, 4365, 2221, 21069, 44055, 77723, 226547, 0 };
            const std::uint32_t dim14331JoeKuoD6Init[]   =   { 1, 3, 1, 5, 5, 49, 47, 187, 71, 903, 1279, 3219, 8041, 10915, 5249, 17755, 80077, 3479, 0 };
            const std::uint32_t dim14332JoeKuoD6Init[]   =   { 1, 1, 3, 13, 5, 53, 35, 25, 183, 791, 1651, 1041, 1221, 2171, 26221, 20649, 126851, 163047, 0 };
            const std::uint32_t dim14333JoeKuoD6Init[]   =   { 1, 1, 5, 9, 29, 3, 75, 31, 385, 293, 171, 3023, 2075, 14541, 30879, 13895, 67637, 87831, 0 };
            const std::uint32_t dim14334JoeKuoD6Init[]   =   { 1, 3, 5, 7, 3, 41, 115, 213, 23, 895, 361, 27, 5839, 12447, 13829, 29183, 106539, 134891, 0 };
            const std::uint32_t dim14335JoeKuoD6Init[]   =   { 1, 3, 7, 7, 11, 39, 99, 229, 195, 633, 837, 3697, 1161, 15119, 20831, 27371, 92195, 26993, 0 };
            const std::uint32_t dim14336JoeKuoD6Init[]   =   { 1, 1, 5, 9, 25, 17, 5, 169, 475, 73, 1451, 2057, 3671, 12801, 9671, 57427, 25321, 154969, 0 };
            const std::uint32_t dim14337JoeKuoD6Init[]   =   { 1, 3, 5, 11, 25, 23, 9, 145, 341, 339, 1855, 981, 8041, 569, 19851, 29521, 21767, 136505, 0 };
            const std::uint32_t dim14338JoeKuoD6Init[]   =   { 1, 1, 1, 1, 3, 9, 101, 253, 475, 529, 387, 1893, 5509, 5763, 29555, 13307, 30001, 105057, 0 };
            const std::uint32_t dim14339JoeKuoD6Init[]   =   { 1, 3, 3, 5, 17, 23, 127, 161, 375, 817, 1229, 1197, 1097, 3053, 14351, 21213, 12501, 137397, 0 };
            const std::uint32_t dim14340JoeKuoD6Init[]   =   { 1, 1, 1, 9, 7, 1, 57, 185, 281, 65, 181, 2483, 4739, 4353, 29837, 40613, 32489, 23317, 0 };
            const std::uint32_t dim14341JoeKuoD6Init[]   =   { 1, 1, 3, 9, 5, 35, 43, 191, 409, 95, 537, 2465, 515, 1633, 20887, 32535, 43863, 199885, 0 };
            const std::uint32_t dim14342JoeKuoD6Init[]   =   { 1, 3, 3, 13, 19, 49, 41, 51, 3, 979, 1623, 3323, 7711, 3707, 29417, 58011, 114467, 227499, 0 };
            const std::uint32_t dim14343JoeKuoD6Init[]   =   { 1, 1, 1, 11, 21, 7, 23, 51, 39, 25, 1971, 213, 369, 9149, 12845, 57631, 16597, 22031, 0 };
            const std::uint32_t dim14344JoeKuoD6Init[]   =   { 1, 3, 3, 11, 27, 59, 71, 37, 461, 353, 2041, 1961, 4643, 6953, 18129, 60337, 82769, 20819, 0 };
            const std::uint32_t dim14345JoeKuoD6Init[]   =   { 1, 1, 3, 11, 25, 19, 17, 5, 503, 227, 2021, 733, 2867, 201, 25779, 49811, 81167, 95437, 0 };
            const std::uint32_t dim14346JoeKuoD6Init[]   =   { 1, 3, 3, 15, 7, 53, 35, 143, 27, 937, 215, 3249, 4151, 1933, 25267, 18047, 35131, 25903, 0 };
            const std::uint32_t dim14347JoeKuoD6Init[]   =   { 1, 1, 1, 3, 3, 39, 71, 99, 291, 97, 1389, 3803, 2881, 9765, 11277, 20071, 15133, 37349, 0 };
            const std::uint32_t dim14348JoeKuoD6Init[]   =   { 1, 1, 7, 11, 9, 55, 1, 241, 391, 935, 1555, 3585, 1807, 10057, 2633, 14023, 14409, 199643, 0 };
            const std::uint32_t dim14349JoeKuoD6Init[]   =   { 1, 3, 3, 3, 19, 9, 57, 237, 107, 869, 147, 2673, 5271, 8999, 20723, 63017, 75989, 20131, 0 };
            const std::uint32_t dim14350JoeKuoD6Init[]   =   { 1, 3, 3, 3, 25, 11, 61, 77, 119, 657, 2011, 3489, 7835, 4473, 2531, 65231, 104797, 161443, 0 };
            const std::uint32_t dim14351JoeKuoD6Init[]   =   { 1, 1, 5, 5, 11, 63, 25, 93, 181, 797, 367, 3357, 5291, 5087, 28661, 34093, 75195, 165345, 0 };
            const std::uint32_t dim14352JoeKuoD6Init[]   =   { 1, 1, 1, 7, 17, 1, 77, 149, 59, 633, 1551, 1305, 7677, 8671, 17457, 64037, 104451, 112387, 0 };
            const std::uint32_t dim14353JoeKuoD6Init[]   =   { 1, 3, 1, 1, 15, 33, 37, 187, 247, 261, 1101, 3451, 7747, 12197, 22465, 30589, 12573, 204517, 0 };
            const std::uint32_t dim14354JoeKuoD6Init[]   =   { 1, 3, 3, 11, 3, 39, 71, 139, 145, 139, 101, 2815, 3457, 14033, 4531, 42133, 54147, 71259, 0 };
            const std::uint32_t dim14355JoeKuoD6Init[]   =   { 1, 3, 1, 1, 23, 37, 19, 113, 443, 57, 439, 2929, 3835, 5431, 11189, 4539, 72531, 124453, 0 };
            const std::uint32_t dim14356JoeKuoD6Init[]   =   { 1, 3, 3, 5, 3, 17, 21, 217, 41, 665, 1565, 3753, 5289, 9789, 29205, 16453, 88979, 171387, 0 };
            const std::uint32_t dim14357JoeKuoD6Init[]   =   { 1, 3, 3, 13, 27, 15, 15, 223, 231, 311, 311, 1143, 8113, 13863, 3191, 51103, 109437, 245557, 0 };
            const std::uint32_t dim14358JoeKuoD6Init[]   =   { 1, 1, 3, 13, 11, 59, 7, 191, 477, 683, 353, 2845, 7623, 9035, 453, 48429, 40111, 162859, 0 };
            const std::uint32_t dim14359JoeKuoD6Init[]   =   { 1, 3, 7, 5, 29, 37, 55, 59, 259, 851, 861, 1951, 7847, 8537, 30107, 2999, 59137, 155615, 0 };
            const std::uint32_t dim14360JoeKuoD6Init[]   =   { 1, 3, 7, 11, 3, 13, 73, 147, 393, 327, 1289, 37, 795, 1413, 19215, 28345, 124301, 23135, 0 };
            const std::uint32_t dim14361JoeKuoD6Init[]   =   { 1, 1, 5, 11, 29, 17, 107, 69, 433, 845, 1351, 2551, 807, 15315, 15511, 39475, 84879, 129405, 0 };
            const std::uint32_t dim14362JoeKuoD6Init[]   =   { 1, 3, 3, 9, 15, 3, 23, 5, 211, 871, 689, 2319, 39, 2215, 25171, 43169, 113715, 186049, 0 };
            const std::uint32_t dim14363JoeKuoD6Init[]   =   { 1, 1, 3, 7, 3, 37, 23, 9, 453, 649, 373, 1273, 1539, 6221, 27469, 44675, 13513, 131179, 0 };
            const std::uint32_t dim14364JoeKuoD6Init[]   =   { 1, 3, 1, 5, 29, 41, 119, 133, 37, 761, 1193, 2311, 4945, 7337, 17027, 12873, 51489, 160633, 0 };
            const std::uint32_t dim14365JoeKuoD6Init[]   =   { 1, 3, 1, 3, 21, 63, 75, 115, 105, 223, 933, 445, 5789, 4611, 13609, 2873, 16679, 222895, 0 };
            const std::uint32_t dim14366JoeKuoD6Init[]   =   { 1, 1, 7, 5, 17, 13, 15, 217, 193, 863, 1319, 2337, 3055, 14879, 8669, 5705, 42965, 166443, 0 };
            const std::uint32_t dim14367JoeKuoD6Init[]   =   { 1, 1, 7, 11, 3, 55, 57, 131, 289, 843, 1693, 881, 6737, 5557, 18365, 12393, 38479, 189177, 0 };
            const std::uint32_t dim14368JoeKuoD6Init[]   =   { 1, 1, 3, 5, 3, 59, 13, 123, 397, 479, 79, 569, 535, 2529, 26225, 43475, 76925, 187763, 0 };
            const std::uint32_t dim14369JoeKuoD6Init[]   =   { 1, 1, 5, 15, 15, 37, 1, 97, 489, 331, 1499, 1759, 3621, 5373, 1425, 6477, 45805, 235511, 0 };
            const std::uint32_t dim14370JoeKuoD6Init[]   =   { 1, 3, 1, 3, 7, 51, 55, 157, 61, 751, 1881, 4093, 2557, 11129, 23239, 16335, 8949, 205007, 0 };
            const std::uint32_t dim14371JoeKuoD6Init[]   =   { 1, 1, 1, 1, 13, 21, 67, 141, 85, 1023, 223, 747, 1951, 10279, 6399, 49887, 100437, 76757, 0 };
            const std::uint32_t dim14372JoeKuoD6Init[]   =   { 1, 1, 3, 11, 1, 51, 29, 33, 173, 769, 879, 2883, 417, 15031, 13377, 63919, 118803, 87969, 0 };
            const std::uint32_t dim14373JoeKuoD6Init[]   =   { 1, 1, 1, 5, 1, 1, 17, 153, 81, 691, 961, 3399, 5005, 10617, 18467, 13775, 34905, 241349, 0 };
            const std::uint32_t dim14374JoeKuoD6Init[]   =   { 1, 1, 1, 13, 7, 37, 57, 187, 389, 575, 1827, 2017, 4541, 10513, 23409, 30945, 126855, 239657, 0 };
            const std::uint32_t dim14375JoeKuoD6Init[]   =   { 1, 1, 5, 5, 17, 41, 83, 177, 285, 695, 29, 1653, 953, 6377, 13571, 58663, 9265, 100759, 0 };
            const std::uint32_t dim14376JoeKuoD6Init[]   =   { 1, 3, 5, 3, 5, 13, 27, 153, 207, 699, 1805, 947, 979, 2719, 389, 61953, 16991, 160073, 0 };
            const std::uint32_t dim14377JoeKuoD6Init[]   =   { 1, 1, 7, 13, 17, 37, 113, 185, 239, 455, 1557, 3201, 1111, 4875, 23197, 41883, 70507, 255047, 0 };
            const std::uint32_t dim14378JoeKuoD6Init[]   =   { 1, 3, 5, 11, 9, 51, 47, 137, 413, 1015, 259, 1829, 6043, 11757, 22317, 15155, 107827, 171003, 0 };
            const std::uint32_t dim14379JoeKuoD6Init[]   =   { 1, 1, 1, 13, 27, 7, 49, 91, 285, 13, 2007, 3469, 1223, 2483, 16155, 8413, 10529, 224195, 0 };
            const std::uint32_t dim14380JoeKuoD6Init[]   =   { 1, 1, 7, 3, 9, 49, 119, 81, 331, 187, 1695, 1729, 533, 6359, 7053, 34665, 37541, 100225, 0 };
            const std::uint32_t dim14381JoeKuoD6Init[]   =   { 1, 3, 7, 1, 7, 35, 115, 91, 479, 515, 1249, 121, 2885, 16383, 1777, 44205, 86459, 255885, 0 };
            const std::uint32_t dim14382JoeKuoD6Init[]   =   { 1, 1, 7, 13, 13, 27, 11, 49, 221, 829, 1787, 2889, 3875, 1679, 25333, 1323, 9813, 189373, 0 };
            const std::uint32_t dim14383JoeKuoD6Init[]   =   { 1, 3, 7, 5, 31, 5, 117, 77, 209, 619, 191, 2969, 2221, 15339, 11461, 64201, 130461, 204467, 0 };
            const std::uint32_t dim14384JoeKuoD6Init[]   =   { 1, 3, 1, 1, 29, 5, 91, 31, 313, 901, 1501, 2837, 3615, 7765, 341, 13873, 21663, 260637, 0 };
            const std::uint32_t dim14385JoeKuoD6Init[]   =   { 1, 1, 1, 9, 1, 41, 97, 15, 141, 901, 1309, 3341, 4871, 16033, 12343, 1555, 94989, 78295, 0 };
            const std::uint32_t dim14386JoeKuoD6Init[]   =   { 1, 1, 7, 3, 3, 15, 1, 29, 445, 59, 475, 3033, 4227, 3219, 6093, 58953, 92179, 49343, 0 };
            const std::uint32_t dim14387JoeKuoD6Init[]   =   { 1, 1, 5, 3, 27, 25, 109, 13, 219, 983, 131, 2517, 1161, 16063, 32737, 6077, 91183, 37457, 0 };
            const std::uint32_t dim14388JoeKuoD6Init[]   =   { 1, 3, 3, 1, 3, 1, 85, 147, 17, 543, 1475, 3873, 3719, 2737, 30977, 15953, 66077, 258979, 0 };
            const std::uint32_t dim14389JoeKuoD6Init[]   =   { 1, 3, 5, 1, 29, 9, 21, 51, 5, 985, 1177, 3287, 2183, 7301, 13713, 53403, 38439, 195863, 0 };
            const std::uint32_t dim14390JoeKuoD6Init[]   =   { 1, 1, 7, 15, 31, 53, 47, 173, 477, 439, 751, 1019, 3371, 9319, 17995, 29029, 90657, 209277, 0 };
            const std::uint32_t dim14391JoeKuoD6Init[]   =   { 1, 1, 5, 5, 17, 5, 59, 115, 375, 231, 1891, 1321, 3639, 16117, 32639, 28793, 68213, 41091, 0 };
            const std::uint32_t dim14392JoeKuoD6Init[]   =   { 1, 3, 5, 11, 17, 15, 13, 11, 459, 767, 849, 1407, 6611, 6409, 21515, 63175, 127155, 171959, 0 };
            const std::uint32_t dim14393JoeKuoD6Init[]   =   { 1, 1, 5, 1, 17, 49, 61, 161, 399, 137, 845, 2673, 2431, 15343, 389, 42337, 23031, 94811, 0 };
            const std::uint32_t dim14394JoeKuoD6Init[]   =   { 1, 1, 1, 9, 21, 23, 75, 177, 351, 197, 1619, 2443, 6829, 3773, 16399, 31949, 44975, 221363, 0 };
            const std::uint32_t dim14395JoeKuoD6Init[]   =   { 1, 1, 3, 1, 11, 19, 103, 61, 135, 863, 1427, 2657, 4553, 1277, 20249, 3973, 25467, 18847, 0 };
            const std::uint32_t dim14396JoeKuoD6Init[]   =   { 1, 3, 3, 13, 17, 31, 19, 163, 323, 195, 603, 4069, 3181, 12069, 22117, 44229, 23585, 202785, 0 };
            const std::uint32_t dim14397JoeKuoD6Init[]   =   { 1, 1, 7, 5, 17, 3, 77, 111, 491, 829, 1375, 2829, 5599, 14057, 21387, 52345, 108281, 211285, 0 };
            const std::uint32_t dim14398JoeKuoD6Init[]   =   { 1, 3, 3, 1, 17, 43, 71, 13, 321, 393, 1803, 727, 5101, 13485, 8693, 60505, 13893, 3467, 0 };
            const std::uint32_t dim14399JoeKuoD6Init[]   =   { 1, 1, 5, 1, 23, 31, 121, 15, 215, 215, 1113, 3335, 7431, 4863, 31429, 49903, 59403, 60797, 0 };
            const std::uint32_t dim14400JoeKuoD6Init[]   =   { 1, 3, 3, 9, 21, 43, 61, 171, 361, 323, 1895, 3647, 729, 8809, 9351, 14573, 93593, 17485, 0 };
            const std::uint32_t dim14401JoeKuoD6Init[]   =   { 1, 3, 3, 7, 7, 19, 45, 247, 203, 757, 1941, 3753, 5317, 13239, 18945, 26173, 43929, 66889, 0 };
            const std::uint32_t dim14402JoeKuoD6Init[]   =   { 1, 1, 1, 15, 5, 17, 11, 21, 193, 941, 517, 191, 6067, 8403, 27339, 31035, 34767, 28675, 0 };
            const std::uint32_t dim14403JoeKuoD6Init[]   =   { 1, 3, 1, 7, 27, 59, 27, 7, 491, 551, 867, 3693, 391, 9799, 11051, 28347, 57555, 23079, 0 };
            const std::uint32_t dim14404JoeKuoD6Init[]   =   { 1, 3, 3, 1, 25, 21, 63, 253, 459, 603, 107, 1229, 1433, 4263, 24341, 20493, 40165, 254725, 0 };
            const std::uint32_t dim14405JoeKuoD6Init[]   =   { 1, 3, 5, 3, 9, 7, 63, 195, 19, 973, 47, 811, 2207, 3613, 8911, 17495, 62403, 77951, 0 };
            const std::uint32_t dim14406JoeKuoD6Init[]   =   { 1, 3, 5, 11, 5, 13, 83, 125, 467, 111, 1819, 3807, 4259, 2885, 29577, 13539, 69859, 97379, 0 };
            const std::uint32_t dim14407JoeKuoD6Init[]   =   { 1, 1, 5, 15, 5, 33, 109, 203, 129, 587, 9, 3025, 2839, 11405, 11257, 7779, 30311, 14015, 0 };
            const std::uint32_t dim14408JoeKuoD6Init[]   =   { 1, 1, 7, 15, 5, 47, 103, 199, 391, 61, 129, 3511, 1295, 15067, 23919, 2941, 120463, 21665, 0 };
            const std::uint32_t dim14409JoeKuoD6Init[]   =   { 1, 1, 5, 5, 7, 7, 125, 153, 365, 815, 1423, 4053, 875, 2405, 21291, 26785, 31371, 211045, 0 };
            const std::uint32_t dim14410JoeKuoD6Init[]   =   { 1, 3, 3, 9, 31, 47, 1, 247, 197, 1019, 985, 2277, 875, 3969, 15093, 15561, 110101, 156547, 0 };
            const std::uint32_t dim14411JoeKuoD6Init[]   =   { 1, 1, 3, 1, 9, 47, 71, 125, 17, 501, 1783, 2337, 483, 12719, 22453, 16701, 102639, 152955, 0 };
            const std::uint32_t dim14412JoeKuoD6Init[]   =   { 1, 1, 3, 11, 13, 31, 9, 63, 261, 257, 319, 1443, 5011, 9799, 18639, 53081, 56879, 102335, 0 };
            const std::uint32_t dim14413JoeKuoD6Init[]   =   { 1, 3, 3, 1, 5, 59, 127, 163, 323, 997, 1755, 1445, 2285, 4935, 22123, 815, 115131, 1009, 0 };
            const std::uint32_t dim14414JoeKuoD6Init[]   =   { 1, 1, 3, 11, 11, 43, 65, 127, 137, 583, 173, 2601, 5809, 15773, 16129, 2543, 68281, 96107, 0 };
            const std::uint32_t dim14415JoeKuoD6Init[]   =   { 1, 3, 5, 9, 25, 25, 95, 73, 313, 893, 1805, 2301, 5917, 15159, 8637, 25505, 66053, 31627, 0 };
            const std::uint32_t dim14416JoeKuoD6Init[]   =   { 1, 1, 3, 7, 25, 59, 55, 13, 297, 849, 187, 359, 3745, 12655, 29293, 58581, 89799, 195867, 0 };
            const std::uint32_t dim14417JoeKuoD6Init[]   =   { 1, 1, 5, 13, 19, 5, 51, 85, 259, 59, 1003, 2991, 6605, 8405, 5221, 45607, 130729, 99641, 0 };
            const std::uint32_t dim14418JoeKuoD6Init[]   =   { 1, 3, 5, 5, 25, 61, 51, 211, 143, 233, 1465, 1165, 1769, 3021, 9491, 30335, 34787, 142605, 0 };
            const std::uint32_t dim14419JoeKuoD6Init[]   =   { 1, 3, 5, 13, 23, 9, 89, 249, 71, 179, 841, 3375, 21, 6757, 27495, 7531, 123725, 253855, 0 };
            const std::uint32_t dim14420JoeKuoD6Init[]   =   { 1, 3, 7, 13, 9, 33, 109, 103, 475, 781, 493, 2079, 6529, 13443, 2181, 26925, 31345, 142863, 0 };
            const std::uint32_t dim14421JoeKuoD6Init[]   =   { 1, 1, 7, 9, 15, 41, 17, 85, 503, 839, 533, 731, 2735, 12949, 11395, 22539, 130147, 40045, 0 };
            const std::uint32_t dim14422JoeKuoD6Init[]   =   { 1, 1, 5, 9, 25, 21, 29, 79, 405, 383, 1271, 385, 7629, 3889, 5319, 57739, 51411, 50895, 0 };
            const std::uint32_t dim14423JoeKuoD6Init[]   =   { 1, 3, 7, 5, 13, 35, 17, 97, 261, 437, 951, 1403, 2407, 11447, 13565, 10165, 100001, 253093, 0 };
            const std::uint32_t dim14424JoeKuoD6Init[]   =   { 1, 3, 1, 3, 11, 39, 31, 187, 473, 565, 351, 4007, 2621, 14463, 9009, 40679, 81069, 51131, 0 };
            const std::uint32_t dim14425JoeKuoD6Init[]   =   { 1, 3, 5, 5, 9, 17, 11, 151, 59, 249, 281, 203, 6423, 4977, 18557, 65383, 88361, 87437, 0 };
            const std::uint32_t dim14426JoeKuoD6Init[]   =   { 1, 3, 5, 7, 15, 25, 3, 157, 179, 439, 1627, 3493, 6641, 6403, 2361, 3613, 33817, 22585, 0 };
            const std::uint32_t dim14427JoeKuoD6Init[]   =   { 1, 3, 5, 1, 13, 63, 77, 195, 233, 175, 631, 1021, 637, 13231, 26187, 131, 127379, 256183, 0 };
            const std::uint32_t dim14428JoeKuoD6Init[]   =   { 1, 1, 7, 9, 5, 13, 15, 187, 55, 37, 1113, 2191, 3439, 1073, 26239, 3049, 19807, 250869, 0 };
            const std::uint32_t dim14429JoeKuoD6Init[]   =   { 1, 1, 7, 3, 13, 15, 77, 47, 317, 285, 753, 2419, 7795, 11423, 6043, 2913, 42819, 50603, 0 };
            const std::uint32_t dim14430JoeKuoD6Init[]   =   { 1, 3, 7, 15, 21, 17, 63, 71, 97, 535, 1085, 1531, 5165, 13717, 1537, 26797, 111787, 189403, 0 };
            const std::uint32_t dim14431JoeKuoD6Init[]   =   { 1, 1, 1, 7, 9, 3, 43, 209, 385, 851, 1411, 4039, 3259, 13387, 24505, 33325, 83741, 241255, 0 };
            const std::uint32_t dim14432JoeKuoD6Init[]   =   { 1, 1, 1, 1, 3, 41, 13, 43, 303, 445, 1097, 3517, 7753, 8459, 3017, 16385, 13775, 248655, 0 };
            const std::uint32_t dim14433JoeKuoD6Init[]   =   { 1, 3, 5, 15, 5, 61, 31, 57, 269, 931, 1071, 1137, 6181, 13005, 18493, 1345, 105203, 117309, 0 };
            const std::uint32_t dim14434JoeKuoD6Init[]   =   { 1, 1, 3, 13, 21, 29, 3, 179, 367, 155, 993, 117, 5849, 10181, 1175, 55769, 16025, 67669, 0 };
            const std::uint32_t dim14435JoeKuoD6Init[]   =   { 1, 1, 3, 9, 11, 9, 33, 131, 181, 1003, 253, 2759, 1877, 11851, 22959, 37823, 82737, 110329, 0 };
            const std::uint32_t dim14436JoeKuoD6Init[]   =   { 1, 1, 1, 5, 7, 5, 107, 191, 385, 129, 567, 2585, 7295, 3005, 28185, 7095, 54851, 257587, 0 };
            const std::uint32_t dim14437JoeKuoD6Init[]   =   { 1, 3, 7, 9, 21, 61, 103, 155, 503, 307, 993, 683, 1491, 14895, 9213, 34535, 17765, 12457, 0 };
            const std::uint32_t dim14438JoeKuoD6Init[]   =   { 1, 3, 3, 1, 7, 47, 27, 173, 97, 889, 853, 3995, 4943, 71, 20479, 16741, 35479, 35307, 0 };
            const std::uint32_t dim14439JoeKuoD6Init[]   =   { 1, 1, 5, 3, 15, 35, 29, 207, 117, 267, 1835, 2565, 1199, 3813, 13999, 10537, 129915, 210651, 0 };
            const std::uint32_t dim14440JoeKuoD6Init[]   =   { 1, 3, 3, 13, 5, 57, 77, 193, 11, 279, 745, 2511, 5775, 13527, 26329, 16303, 111511, 70025, 0 };
            const std::uint32_t dim14441JoeKuoD6Init[]   =   { 1, 3, 7, 9, 17, 1, 73, 1, 125, 939, 863, 2763, 1951, 3191, 5567, 59729, 32149, 149417, 0 };
            const std::uint32_t dim14442JoeKuoD6Init[]   =   { 1, 3, 3, 1, 19, 25, 119, 63, 101, 33, 77, 3587, 6367, 8275, 24957, 32087, 7031, 217291, 0 };
            const std::uint32_t dim14443JoeKuoD6Init[]   =   { 1, 1, 1, 13, 7, 25, 75, 161, 143, 353, 973, 2957, 749, 13519, 11295, 34287, 60727, 83731, 0 };
            const std::uint32_t dim14444JoeKuoD6Init[]   =   { 1, 3, 7, 7, 17, 9, 59, 45, 97, 619, 895, 1955, 8143, 2507, 4673, 39425, 35679, 152069, 0 };
            const std::uint32_t dim14445JoeKuoD6Init[]   =   { 1, 1, 5, 9, 31, 19, 115, 177, 349, 877, 525, 305, 2187, 12195, 13529, 61641, 102293, 69941, 0 };
            const std::uint32_t dim14446JoeKuoD6Init[]   =   { 1, 3, 7, 11, 23, 59, 15, 243, 511, 465, 905, 1979, 2263, 2105, 9009, 3691, 22241, 97765, 0 };
            const std::uint32_t dim14447JoeKuoD6Init[]   =   { 1, 1, 7, 9, 29, 13, 3, 207, 51, 405, 1703, 1923, 1781, 14723, 8103, 10707, 64799, 99349, 0 };
            const std::uint32_t dim14448JoeKuoD6Init[]   =   { 1, 1, 7, 5, 23, 29, 51, 63, 489, 273, 1577, 2807, 5427, 9949, 1929, 19791, 109405, 241465, 0 };
            const std::uint32_t dim14449JoeKuoD6Init[]   =   { 1, 3, 3, 7, 29, 61, 103, 55, 29, 17, 1081, 21, 5791, 9803, 19385, 45091, 118069, 61383, 0 };
            const std::uint32_t dim14450JoeKuoD6Init[]   =   { 1, 3, 1, 7, 3, 15, 75, 47, 475, 87, 1541, 3933, 1081, 12361, 29213, 64333, 7229, 226909, 0 };
            const std::uint32_t dim14451JoeKuoD6Init[]   =   { 1, 1, 5, 7, 21, 45, 19, 137, 351, 229, 1773, 1829, 5025, 12661, 18745, 54917, 10419, 176667, 0 };
            const std::uint32_t dim14452JoeKuoD6Init[]   =   { 1, 1, 1, 3, 9, 37, 81, 25, 11, 327, 1653, 2751, 2823, 12575, 30287, 46265, 17299, 93595, 0 };
            const std::uint32_t dim14453JoeKuoD6Init[]   =   { 1, 1, 1, 3, 15, 17, 43, 163, 223, 731, 631, 2813, 1723, 6089, 14245, 64339, 114291, 40331, 0 };
            const std::uint32_t dim14454JoeKuoD6Init[]   =   { 1, 3, 7, 5, 21, 45, 41, 17, 495, 61, 1369, 369, 4493, 12071, 3813, 41455, 62561, 174399, 0 };
            const std::uint32_t dim14455JoeKuoD6Init[]   =   { 1, 1, 1, 5, 9, 41, 95, 113, 109, 519, 1683, 2265, 2875, 12649, 15575, 53511, 100707, 224035, 0 };
            const std::uint32_t dim14456JoeKuoD6Init[]   =   { 1, 3, 7, 9, 29, 7, 109, 109, 283, 111, 1167, 3679, 369, 11597, 19459, 759, 128667, 172427, 0 };
            const std::uint32_t dim14457JoeKuoD6Init[]   =   { 1, 1, 1, 3, 13, 31, 97, 31, 477, 507, 835, 465, 7501, 2485, 19485, 51055, 56363, 229341, 0 };
            const std::uint32_t dim14458JoeKuoD6Init[]   =   { 1, 3, 5, 11, 3, 23, 67, 173, 99, 963, 977, 1949, 1263, 2427, 15181, 23571, 23509, 26481, 0 };
            const std::uint32_t dim14459JoeKuoD6Init[]   =   { 1, 3, 3, 1, 29, 3, 35, 191, 197, 277, 397, 205, 5945, 1069, 31789, 3551, 101901, 222609, 0 };
            const std::uint32_t dim14460JoeKuoD6Init[]   =   { 1, 1, 5, 9, 11, 23, 109, 81, 295, 7, 755, 2345, 2823, 11133, 22623, 14515, 57059, 231099, 0 };
            const std::uint32_t dim14461JoeKuoD6Init[]   =   { 1, 3, 1, 3, 21, 29, 37, 71, 111, 737, 1881, 871, 5843, 5889, 14615, 49909, 7105, 48335, 0 };
            const std::uint32_t dim14462JoeKuoD6Init[]   =   { 1, 3, 1, 15, 23, 31, 87, 181, 483, 225, 2003, 365, 1569, 11153, 14673, 30085, 56497, 203723, 0 };
            const std::uint32_t dim14463JoeKuoD6Init[]   =   { 1, 1, 3, 15, 17, 47, 99, 167, 485, 431, 1481, 2225, 1537, 8513, 19407, 34165, 27289, 84393, 0 };
            const std::uint32_t dim14464JoeKuoD6Init[]   =   { 1, 3, 7, 3, 11, 17, 115, 205, 403, 831, 1869, 3623, 5215, 15511, 11297, 25181, 127491, 155887, 0 };
            const std::uint32_t dim14465JoeKuoD6Init[]   =   { 1, 1, 7, 5, 31, 37, 23, 21, 403, 529, 1185, 3363, 6319, 2435, 2687, 39407, 121891, 133047, 0 };
            const std::uint32_t dim14466JoeKuoD6Init[]   =   { 1, 3, 7, 1, 21, 31, 43, 61, 371, 987, 1783, 3811, 6227, 13199, 31799, 28863, 49329, 73947, 0 };
            const std::uint32_t dim14467JoeKuoD6Init[]   =   { 1, 3, 1, 1, 13, 1, 5, 99, 35, 793, 483, 2573, 2249, 6345, 12793, 61917, 49419, 58011, 0 };
            const std::uint32_t dim14468JoeKuoD6Init[]   =   { 1, 3, 1, 15, 3, 45, 35, 189, 67, 447, 1455, 3575, 8191, 7907, 21559, 38211, 26945, 240679, 0 };
            const std::uint32_t dim14469JoeKuoD6Init[]   =   { 1, 1, 3, 11, 27, 49, 9, 109, 93, 473, 1465, 271, 7389, 47, 8101, 6219, 17437, 220461, 0 };
            const std::uint32_t dim14470JoeKuoD6Init[]   =   { 1, 1, 7, 3, 23, 31, 75, 61, 375, 901, 1329, 2603, 3469, 12957, 23949, 62183, 126763, 68965, 0 };
            const std::uint32_t dim14471JoeKuoD6Init[]   =   { 1, 1, 7, 9, 13, 59, 75, 233, 339, 29, 1117, 1693, 593, 15317, 29753, 3079, 43583, 79939, 0 };
            const std::uint32_t dim14472JoeKuoD6Init[]   =   { 1, 1, 5, 1, 17, 57, 81, 123, 101, 765, 1941, 3143, 7403, 9105, 23197, 28983, 128059, 5931, 0 };
            const std::uint32_t dim14473JoeKuoD6Init[]   =   { 1, 3, 5, 11, 19, 31, 89, 165, 213, 251, 965, 3203, 1621, 4323, 26877, 17109, 18321, 162413, 0 };
            const std::uint32_t dim14474JoeKuoD6Init[]   =   { 1, 3, 3, 9, 11, 59, 123, 213, 335, 267, 1767, 3317, 5189, 10149, 27921, 19331, 71541, 170501, 0 };
            const std::uint32_t dim14475JoeKuoD6Init[]   =   { 1, 3, 3, 15, 3, 3, 115, 235, 305, 219, 265, 1535, 4925, 5597, 20857, 32381, 117237, 197533, 0 };
            const std::uint32_t dim14476JoeKuoD6Init[]   =   { 1, 3, 5, 13, 13, 59, 93, 85, 419, 337, 513, 2131, 5665, 12229, 1389, 34355, 65485, 81141, 0 };
            const std::uint32_t dim14477JoeKuoD6Init[]   =   { 1, 3, 7, 7, 11, 59, 111, 219, 293, 289, 325, 623, 3853, 3775, 14771, 5945, 119451, 162861, 0 };
            const std::uint32_t dim14478JoeKuoD6Init[]   =   { 1, 3, 1, 11, 19, 33, 119, 239, 431, 803, 1119, 2445, 3203, 7219, 31963, 34519, 104953, 254491, 0 };
            const std::uint32_t dim14479JoeKuoD6Init[]   =   { 1, 3, 7, 9, 21, 53, 21, 115, 365, 419, 11, 3803, 4283, 417, 8937, 64533, 56433, 166025, 0 };
            const std::uint32_t dim14480JoeKuoD6Init[]   =   { 1, 1, 7, 3, 17, 5, 99, 143, 485, 309, 1255, 2641, 3427, 1681, 3301, 64531, 38629, 20945, 0 };
            const std::uint32_t dim14481JoeKuoD6Init[]   =   { 1, 1, 5, 1, 31, 3, 115, 217, 451, 5, 1447, 2317, 1725, 12931, 25799, 23569, 51747, 28821, 0 };
            const std::uint32_t dim14482JoeKuoD6Init[]   =   { 1, 3, 7, 3, 31, 55, 109, 107, 211, 381, 1067, 3973, 5007, 8939, 8605, 55221, 124603, 47115, 0 };
            const std::uint32_t dim14483JoeKuoD6Init[]   =   { 1, 1, 1, 11, 19, 13, 99, 241, 103, 711, 1823, 2671, 653, 10217, 14195, 39735, 54807, 105599, 0 };
            const std::uint32_t dim14484JoeKuoD6Init[]   =   { 1, 3, 3, 7, 9, 33, 43, 131, 493, 141, 827, 2909, 2847, 12879, 7879, 6263, 25981, 57323, 0 };
            const std::uint32_t dim14485JoeKuoD6Init[]   =   { 1, 1, 1, 1, 1, 41, 55, 175, 479, 725, 157, 3403, 5809, 10685, 20433, 21729, 9493, 205685, 0 };
            const std::uint32_t dim14486JoeKuoD6Init[]   =   { 1, 1, 7, 5, 1, 33, 31, 245, 109, 711, 1047, 941, 449, 1055, 16249, 45211, 48311, 171339, 0 };
            const std::uint32_t dim14487JoeKuoD6Init[]   =   { 1, 3, 3, 9, 27, 9, 113, 69, 269, 643, 1371, 3521, 4969, 5373, 11133, 63109, 42725, 126969, 0 };
            const std::uint32_t dim14488JoeKuoD6Init[]   =   { 1, 1, 5, 15, 9, 21, 1, 195, 421, 429, 1103, 2727, 463, 9801, 8955, 62841, 94687, 114509, 0 };
            const std::uint32_t dim14489JoeKuoD6Init[]   =   { 1, 1, 5, 5, 5, 47, 9, 221, 59, 115, 359, 1147, 749, 1009, 23129, 641, 39471, 23073, 0 };
            const std::uint32_t dim14490JoeKuoD6Init[]   =   { 1, 3, 5, 13, 27, 29, 19, 3, 121, 773, 625, 2757, 6377, 15867, 14563, 40391, 4351, 21153, 0 };
            const std::uint32_t dim14491JoeKuoD6Init[]   =   { 1, 1, 5, 9, 11, 25, 51, 101, 273, 541, 1761, 593, 7111, 4369, 30095, 34867, 103989, 19855, 0 };
            const std::uint32_t dim14492JoeKuoD6Init[]   =   { 1, 1, 3, 13, 27, 55, 79, 115, 105, 855, 627, 2227, 2927, 8757, 8713, 54607, 43671, 130153, 0 };
            const std::uint32_t dim14493JoeKuoD6Init[]   =   { 1, 1, 3, 5, 7, 45, 21, 71, 157, 773, 1265, 841, 2463, 2217, 6087, 28683, 21251, 72377, 0 };
            const std::uint32_t dim14494JoeKuoD6Init[]   =   { 1, 1, 3, 1, 15, 11, 117, 211, 223, 713, 545, 907, 6907, 41, 17039, 23079, 86657, 5765, 0 };
            const std::uint32_t dim14495JoeKuoD6Init[]   =   { 1, 1, 5, 3, 27, 33, 77, 137, 401, 585, 911, 1189, 2749, 3427, 2701, 2453, 84857, 176585, 0 };
            const std::uint32_t dim14496JoeKuoD6Init[]   =   { 1, 1, 1, 3, 7, 39, 73, 143, 29, 569, 939, 301, 7827, 7691, 11513, 64517, 113679, 234165, 0 };
            const std::uint32_t dim14497JoeKuoD6Init[]   =   { 1, 3, 1, 11, 29, 57, 127, 181, 175, 973, 1537, 761, 5205, 13641, 32649, 8621, 77509, 261235, 0 };
            const std::uint32_t dim14498JoeKuoD6Init[]   =   { 1, 3, 5, 5, 13, 19, 117, 225, 477, 297, 1807, 2357, 5653, 3791, 6325, 54877, 120659, 91013, 0 };
            const std::uint32_t dim14499JoeKuoD6Init[]   =   { 1, 3, 1, 1, 3, 55, 19, 99, 321, 877, 541, 511, 141, 15047, 26377, 9, 2765, 223533, 0 };
            const std::uint32_t dim14500JoeKuoD6Init[]   =   { 1, 1, 1, 11, 13, 59, 121, 147, 215, 117, 1047, 3055, 2129, 15191, 14425, 28327, 108541, 114275, 0 };
            const std::uint32_t dim14501JoeKuoD6Init[]   =   { 1, 1, 1, 15, 3, 21, 105, 61, 501, 899, 195, 2745, 5989, 4433, 19525, 35477, 22997, 241657, 0 };
            const std::uint32_t dim14502JoeKuoD6Init[]   =   { 1, 1, 3, 5, 19, 47, 77, 247, 413, 317, 1255, 2087, 4493, 2211, 9003, 22145, 94001, 50579, 0 };
            const std::uint32_t dim14503JoeKuoD6Init[]   =   { 1, 3, 7, 11, 31, 47, 25, 191, 65, 409, 1349, 2481, 7619, 223, 18051, 63609, 77187, 75483, 0 };
            const std::uint32_t dim14504JoeKuoD6Init[]   =   { 1, 1, 1, 9, 21, 59, 115, 251, 401, 91, 627, 3273, 2393, 2949, 11475, 23669, 16171, 77507, 0 };
            const std::uint32_t dim14505JoeKuoD6Init[]   =   { 1, 3, 5, 1, 19, 7, 65, 253, 217, 493, 227, 3269, 4261, 2295, 32037, 5773, 12925, 41821, 0 };
            const std::uint32_t dim14506JoeKuoD6Init[]   =   { 1, 1, 5, 11, 5, 31, 71, 205, 285, 37, 1863, 1873, 191, 16137, 2955, 51993, 91401, 206967, 0 };
            const std::uint32_t dim14507JoeKuoD6Init[]   =   { 1, 3, 1, 7, 23, 31, 21, 81, 37, 903, 817, 3447, 8067, 3087, 25831, 46247, 77255, 68365, 0 };
            const std::uint32_t dim14508JoeKuoD6Init[]   =   { 1, 1, 7, 11, 7, 43, 21, 243, 431, 633, 2047, 577, 7297, 8151, 15951, 30313, 121569, 241687, 0 };
            const std::uint32_t dim14509JoeKuoD6Init[]   =   { 1, 1, 3, 5, 7, 45, 35, 189, 381, 849, 1869, 1193, 6815, 9017, 29053, 63605, 113623, 249097, 0 };
            const std::uint32_t dim14510JoeKuoD6Init[]   =   { 1, 3, 3, 11, 13, 1, 73, 151, 197, 591, 1101, 2437, 6695, 8337, 26539, 40147, 45673, 57727, 0 };
            const std::uint32_t dim14511JoeKuoD6Init[]   =   { 1, 1, 5, 1, 19, 15, 61, 151, 37, 893, 1819, 2317, 6299, 13097, 5109, 32613, 123685, 128173, 0 };
            const std::uint32_t dim14512JoeKuoD6Init[]   =   { 1, 1, 1, 7, 25, 29, 29, 203, 179, 211, 1483, 3315, 7125, 6931, 609, 849, 117571, 26829, 0 };
            const std::uint32_t dim14513JoeKuoD6Init[]   =   { 1, 3, 3, 11, 11, 47, 33, 101, 181, 431, 183, 2777, 5269, 4177, 15727, 717, 111243, 34825, 0 };
            const std::uint32_t dim14514JoeKuoD6Init[]   =   { 1, 3, 5, 11, 17, 19, 19, 143, 137, 537, 1249, 2889, 1911, 3895, 15433, 60165, 83815, 205569, 0 };
            const std::uint32_t dim14515JoeKuoD6Init[]   =   { 1, 3, 3, 7, 9, 59, 13, 159, 307, 625, 1, 2887, 3307, 16371, 4269, 56253, 71171, 55543, 0 };
            const std::uint32_t dim14516JoeKuoD6Init[]   =   { 1, 1, 1, 11, 7, 63, 15, 53, 409, 7, 1317, 473, 7481, 10321, 27941, 4941, 40003, 194153, 0 };
            const std::uint32_t dim14517JoeKuoD6Init[]   =   { 1, 1, 1, 1, 11, 53, 93, 157, 289, 231, 31, 273, 8131, 7861, 31041, 55221, 58305, 203403, 0 };
            const std::uint32_t dim14518JoeKuoD6Init[]   =   { 1, 1, 5, 11, 15, 53, 103, 41, 439, 601, 1949, 1087, 4275, 4675, 31879, 40909, 22365, 124781, 0 };
            const std::uint32_t dim14519JoeKuoD6Init[]   =   { 1, 3, 5, 9, 1, 47, 81, 47, 197, 499, 329, 2387, 5455, 15571, 2289, 44121, 12105, 11883, 0 };
            const std::uint32_t dim14520JoeKuoD6Init[]   =   { 1, 1, 3, 3, 7, 47, 93, 33, 265, 149, 845, 723, 7783, 6651, 22939, 58027, 66959, 3991, 0 };
            const std::uint32_t dim14521JoeKuoD6Init[]   =   { 1, 1, 5, 11, 23, 35, 123, 143, 35, 981, 1269, 2853, 4547, 7877, 16181, 17155, 57605, 11589, 0 };
            const std::uint32_t dim14522JoeKuoD6Init[]   =   { 1, 1, 7, 11, 9, 57, 87, 151, 333, 743, 1939, 3273, 1047, 5033, 16061, 37237, 12013, 17669, 0 };
            const std::uint32_t dim14523JoeKuoD6Init[]   =   { 1, 3, 7, 5, 29, 15, 109, 185, 51, 159, 1353, 3041, 7821, 14053, 13643, 62045, 78475, 43603, 0 };
            const std::uint32_t dim14524JoeKuoD6Init[]   =   { 1, 3, 1, 9, 29, 25, 121, 49, 415, 561, 325, 1139, 1993, 6437, 6025, 25225, 20761, 250589, 0 };
            const std::uint32_t dim14525JoeKuoD6Init[]   =   { 1, 3, 5, 3, 15, 39, 33, 43, 437, 605, 1081, 2397, 3821, 10961, 4853, 19517, 95817, 142023, 0 };
            const std::uint32_t dim14526JoeKuoD6Init[]   =   { 1, 1, 3, 11, 23, 51, 119, 13, 227, 981, 2017, 3265, 1215, 8737, 10719, 48027, 43239, 19425, 0 };
            const std::uint32_t dim14527JoeKuoD6Init[]   =   { 1, 3, 1, 15, 5, 5, 33, 175, 509, 611, 451, 2653, 1553, 1941, 25221, 31259, 6027, 159847, 0 };
            const std::uint32_t dim14528JoeKuoD6Init[]   =   { 1, 3, 7, 11, 7, 25, 71, 61, 89, 775, 609, 2363, 4261, 10677, 1243, 44895, 49113, 209603, 0 };
            const std::uint32_t dim14529JoeKuoD6Init[]   =   { 1, 3, 5, 15, 23, 23, 3, 15, 489, 455, 1303, 745, 5311, 1639, 18317, 33729, 119303, 255359, 0 };
            const std::uint32_t dim14530JoeKuoD6Init[]   =   { 1, 3, 7, 5, 13, 53, 29, 127, 159, 67, 469, 1735, 3497, 6985, 24735, 32957, 1225, 24447, 0 };
            const std::uint32_t dim14531JoeKuoD6Init[]   =   { 1, 3, 5, 5, 9, 13, 119, 83, 387, 777, 361, 3183, 6351, 9071, 13699, 53873, 54663, 67453, 0 };
            const std::uint32_t dim14532JoeKuoD6Init[]   =   { 1, 1, 5, 9, 17, 33, 9, 159, 143, 193, 1055, 2903, 2719, 12521, 5231, 37639, 94963, 105673, 0 };
            const std::uint32_t dim14533JoeKuoD6Init[]   =   { 1, 3, 3, 1, 27, 53, 87, 49, 465, 517, 1333, 411, 4089, 9985, 12989, 59511, 49939, 223481, 0 };
            const std::uint32_t dim14534JoeKuoD6Init[]   =   { 1, 1, 5, 9, 27, 59, 35, 125, 393, 271, 1565, 2847, 8139, 15627, 16059, 55319, 11131, 35141, 0 };
            const std::uint32_t dim14535JoeKuoD6Init[]   =   { 1, 1, 1, 1, 25, 1, 27, 195, 113, 539, 1281, 2273, 4793, 695, 25599, 41145, 107431, 160137, 0 };
            const std::uint32_t dim14536JoeKuoD6Init[]   =   { 1, 3, 3, 7, 13, 7, 35, 137, 83, 995, 1671, 1701, 3157, 15583, 7637, 18947, 59675, 9421, 0 };
            const std::uint32_t dim14537JoeKuoD6Init[]   =   { 1, 1, 7, 15, 23, 37, 109, 93, 377, 885, 1843, 1867, 2013, 10535, 5717, 55463, 18307, 125537, 0 };
            const std::uint32_t dim14538JoeKuoD6Init[]   =   { 1, 3, 7, 11, 25, 33, 91, 213, 109, 599, 131, 1879, 1375, 2911, 4649, 8809, 41199, 61629, 0 };
            const std::uint32_t dim14539JoeKuoD6Init[]   =   { 1, 3, 1, 1, 11, 17, 117, 243, 427, 913, 495, 527, 4277, 8867, 3131, 14143, 81677, 177369, 0 };
            const std::uint32_t dim14540JoeKuoD6Init[]   =   { 1, 3, 7, 11, 11, 37, 71, 185, 487, 161, 1773, 837, 243, 14105, 6881, 2155, 63679, 220387, 0 };
            const std::uint32_t dim14541JoeKuoD6Init[]   =   { 1, 1, 5, 3, 11, 41, 33, 99, 495, 757, 1083, 1987, 1997, 11057, 18445, 61903, 78163, 121701, 0 };
            const std::uint32_t dim14542JoeKuoD6Init[]   =   { 1, 1, 1, 1, 23, 37, 9, 19, 411, 11, 1487, 1279, 2129, 7449, 29631, 34559, 129753, 112627, 0 };
            const std::uint32_t dim14543JoeKuoD6Init[]   =   { 1, 1, 3, 11, 31, 39, 41, 207, 141, 383, 723, 3053, 743, 4479, 12395, 56659, 130303, 152005, 0 };
            const std::uint32_t dim14544JoeKuoD6Init[]   =   { 1, 3, 1, 7, 27, 25, 19, 37, 29, 781, 1115, 2569, 4113, 14033, 18653, 1055, 50639, 70413, 0 };
            const std::uint32_t dim14545JoeKuoD6Init[]   =   { 1, 1, 3, 1, 9, 15, 109, 7, 221, 161, 569, 2915, 2717, 2439, 4257, 61851, 113183, 63139, 0 };
            const std::uint32_t dim14546JoeKuoD6Init[]   =   { 1, 3, 5, 1, 17, 45, 3, 147, 207, 769, 321, 11, 2747, 7189, 8067, 34951, 50851, 42625, 0 };
            const std::uint32_t dim14547JoeKuoD6Init[]   =   { 1, 1, 7, 11, 15, 53, 117, 161, 219, 937, 1661, 3767, 959, 10351, 26685, 40095, 109821, 140139, 0 };
            const std::uint32_t dim14548JoeKuoD6Init[]   =   { 1, 3, 3, 9, 15, 47, 61, 35, 289, 743, 1723, 2189, 749, 13499, 22897, 55385, 114953, 67191, 0 };
            const std::uint32_t dim14549JoeKuoD6Init[]   =   { 1, 3, 7, 3, 23, 19, 123, 217, 393, 889, 1665, 13, 5663, 8695, 29767, 13433, 65133, 226713, 0 };
            const std::uint32_t dim14550JoeKuoD6Init[]   =   { 1, 1, 7, 11, 5, 57, 59, 171, 321, 519, 1333, 1975, 5331, 2383, 26863, 8989, 82167, 6915, 0 };
            const std::uint32_t dim14551JoeKuoD6Init[]   =   { 1, 1, 3, 3, 7, 17, 105, 79, 7, 827, 1277, 3805, 5943, 3161, 28953, 15657, 615, 149131, 0 };
            const std::uint32_t dim14552JoeKuoD6Init[]   =   { 1, 1, 5, 1, 5, 7, 99, 65, 295, 933, 365, 1867, 1959, 10733, 26947, 29659, 121889, 200379, 0 };
            const std::uint32_t dim14553JoeKuoD6Init[]   =   { 1, 3, 1, 13, 25, 21, 89, 247, 251, 43, 1539, 1317, 1875, 9237, 20693, 58433, 16757, 25451, 0 };
            const std::uint32_t dim14554JoeKuoD6Init[]   =   { 1, 3, 3, 13, 11, 47, 73, 21, 467, 337, 1881, 2723, 7023, 2767, 12553, 65533, 20517, 203749, 0 };
            const std::uint32_t dim14555JoeKuoD6Init[]   =   { 1, 1, 1, 1, 1, 17, 85, 133, 369, 577, 71, 859, 8151, 919, 10843, 44017, 10097, 199893, 0 };
            const std::uint32_t dim14556JoeKuoD6Init[]   =   { 1, 3, 5, 5, 23, 19, 21, 233, 475, 123, 621, 687, 6945, 2373, 6447, 31243, 3525, 256545, 0 };
            const std::uint32_t dim14557JoeKuoD6Init[]   =   { 1, 1, 7, 5, 9, 5, 35, 21, 33, 353, 1429, 3249, 6159, 8757, 6213, 855, 75863, 74507, 0 };
            const std::uint32_t dim14558JoeKuoD6Init[]   =   { 1, 1, 5, 11, 29, 21, 45, 155, 369, 769, 1041, 3929, 7377, 1621, 5285, 55213, 66143, 110251, 0 };
            const std::uint32_t dim14559JoeKuoD6Init[]   =   { 1, 3, 7, 11, 13, 57, 45, 207, 259, 907, 573, 663, 7727, 12677, 5949, 57625, 42183, 217491, 0 };
            const std::uint32_t dim14560JoeKuoD6Init[]   =   { 1, 3, 5, 3, 21, 63, 113, 159, 87, 551, 1405, 2867, 239, 10941, 27633, 13947, 69689, 225771, 0 };
            const std::uint32_t dim14561JoeKuoD6Init[]   =   { 1, 1, 3, 1, 1, 59, 5, 41, 125, 707, 1457, 1, 4263, 5519, 26101, 46339, 44949, 63689, 0 };
            const std::uint32_t dim14562JoeKuoD6Init[]   =   { 1, 1, 1, 1, 11, 9, 65, 155, 3, 85, 273, 2287, 6059, 3289, 19045, 14705, 112465, 202019, 0 };
            const std::uint32_t dim14563JoeKuoD6Init[]   =   { 1, 3, 3, 3, 21, 49, 95, 75, 479, 519, 1511, 1609, 2421, 14435, 11749, 49627, 16221, 98351, 0 };
            const std::uint32_t dim14564JoeKuoD6Init[]   =   { 1, 1, 3, 5, 25, 57, 1, 39, 377, 523, 529, 701, 6749, 10109, 15845, 53301, 70979, 210997, 0 };
            const std::uint32_t dim14565JoeKuoD6Init[]   =   { 1, 3, 1, 3, 27, 29, 101, 87, 361, 1, 229, 2653, 769, 16121, 18221, 31937, 12187, 63801, 0 };
            const std::uint32_t dim14566JoeKuoD6Init[]   =   { 1, 3, 3, 1, 25, 27, 49, 235, 309, 23, 1625, 589, 1251, 10305, 26943, 38949, 82539, 135491, 0 };
            const std::uint32_t dim14567JoeKuoD6Init[]   =   { 1, 1, 7, 7, 13, 13, 13, 61, 509, 73, 201, 2309, 1601, 3145, 19867, 5623, 117455, 180681, 0 };
            const std::uint32_t dim14568JoeKuoD6Init[]   =   { 1, 3, 3, 13, 13, 47, 71, 9, 123, 719, 701, 353, 1877, 3103, 20017, 64731, 72729, 147631, 0 };
            const std::uint32_t dim14569JoeKuoD6Init[]   =   { 1, 3, 1, 7, 29, 29, 53, 97, 409, 67, 1033, 2403, 2471, 10869, 2837, 43459, 117415, 213371, 0 };
            const std::uint32_t dim14570JoeKuoD6Init[]   =   { 1, 1, 7, 1, 7, 23, 103, 157, 315, 335, 375, 3493, 4095, 5331, 7773, 64173, 23167, 21259, 0 };
            const std::uint32_t dim14571JoeKuoD6Init[]   =   { 1, 3, 5, 13, 13, 55, 107, 147, 447, 281, 401, 1897, 7887, 15005, 21645, 26007, 19673, 238931, 0 };
            const std::uint32_t dim14572JoeKuoD6Init[]   =   { 1, 3, 1, 7, 17, 39, 109, 113, 143, 59, 1095, 225, 1455, 5021, 5011, 2039, 4381, 219847, 0 };
            const std::uint32_t dim14573JoeKuoD6Init[]   =   { 1, 3, 3, 7, 1, 35, 121, 145, 297, 251, 1153, 1955, 7881, 15461, 26961, 915, 30253, 15289, 0 };
            const std::uint32_t dim14574JoeKuoD6Init[]   =   { 1, 3, 5, 15, 5, 57, 43, 157, 49, 17, 993, 4085, 5639, 9405, 28661, 30191, 73291, 76913, 0 };
            const std::uint32_t dim14575JoeKuoD6Init[]   =   { 1, 1, 7, 1, 25, 63, 117, 55, 63, 649, 1635, 2505, 2765, 2715, 30241, 62699, 19567, 65953, 0 };
            const std::uint32_t dim14576JoeKuoD6Init[]   =   { 1, 3, 5, 13, 21, 49, 111, 127, 179, 819, 1737, 2519, 815, 10541, 15821, 54203, 71767, 7091, 0 };
            const std::uint32_t dim14577JoeKuoD6Init[]   =   { 1, 1, 1, 3, 27, 41, 101, 139, 39, 995, 819, 319, 1481, 15265, 20611, 22445, 53733, 82871, 0 };
            const std::uint32_t dim14578JoeKuoD6Init[]   =   { 1, 3, 3, 13, 7, 61, 103, 203, 353, 205, 1927, 2665, 757, 12277, 31217, 22247, 14527, 26385, 0 };
            const std::uint32_t dim14579JoeKuoD6Init[]   =   { 1, 1, 7, 3, 5, 35, 87, 235, 139, 785, 417, 3975, 6753, 4267, 15201, 8747, 12491, 159979, 0 };
            const std::uint32_t dim14580JoeKuoD6Init[]   =   { 1, 3, 1, 9, 9, 11, 117, 231, 503, 933, 1461, 2657, 7771, 2161, 26723, 4853, 23215, 162315, 0 };
            const std::uint32_t dim14581JoeKuoD6Init[]   =   { 1, 1, 7, 15, 27, 25, 115, 9, 257, 89, 571, 41, 2169, 10619, 2695, 2107, 64747, 40489, 0 };
            const std::uint32_t dim14582JoeKuoD6Init[]   =   { 1, 3, 7, 9, 29, 61, 91, 117, 279, 721, 233, 177, 5509, 7599, 2379, 20297, 75425, 25051, 0 };
            const std::uint32_t dim14583JoeKuoD6Init[]   =   { 1, 1, 1, 15, 31, 41, 3, 57, 59, 47, 963, 2831, 1885, 1989, 26803, 48243, 112065, 27753, 0 };
            const std::uint32_t dim14584JoeKuoD6Init[]   =   { 1, 1, 5, 15, 9, 57, 41, 255, 179, 719, 1463, 2857, 285, 9623, 13111, 20415, 28819, 149441, 0 };
            const std::uint32_t dim14585JoeKuoD6Init[]   =   { 1, 3, 1, 9, 17, 63, 21, 79, 473, 525, 1557, 3205, 7097, 14379, 28039, 30731, 62383, 247429, 0 };
            const std::uint32_t dim14586JoeKuoD6Init[]   =   { 1, 3, 3, 13, 25, 45, 97, 213, 11, 801, 1519, 1085, 6167, 13701, 6707, 47223, 69923, 66239, 0 };
            const std::uint32_t dim14587JoeKuoD6Init[]   =   { 1, 1, 1, 13, 1, 1, 9, 21, 363, 729, 1715, 1249, 5299, 11357, 20627, 33559, 84255, 133743, 0 };
            const std::uint32_t dim14588JoeKuoD6Init[]   =   { 1, 3, 3, 13, 17, 33, 23, 255, 309, 605, 1177, 1305, 2717, 6561, 29193, 7971, 117525, 79139, 0 };
            const std::uint32_t dim14589JoeKuoD6Init[]   =   { 1, 3, 1, 1, 7, 15, 73, 171, 11, 791, 241, 2641, 5397, 10403, 22207, 64123, 124507, 63855, 0 };
            const std::uint32_t dim14590JoeKuoD6Init[]   =   { 1, 3, 1, 11, 11, 7, 109, 103, 321, 1009, 1237, 3347, 287, 2389, 16529, 7789, 3347, 97827, 0 };
            const std::uint32_t dim14591JoeKuoD6Init[]   =   { 1, 3, 3, 3, 1, 27, 17, 9, 223, 755, 559, 3811, 2997, 1543, 23197, 42371, 5837, 13809, 0 };
            const std::uint32_t dim14592JoeKuoD6Init[]   =   { 1, 3, 1, 3, 7, 57, 31, 23, 35, 329, 1155, 2525, 3029, 5495, 12005, 18045, 4539, 75789, 0 };
            const std::uint32_t dim14593JoeKuoD6Init[]   =   { 1, 1, 5, 13, 3, 31, 121, 161, 325, 869, 715, 851, 1273, 1871, 22711, 61499, 36291, 11663, 0 };
            const std::uint32_t dim14594JoeKuoD6Init[]   =   { 1, 1, 5, 11, 7, 39, 23, 139, 197, 47, 513, 373, 6859, 11217, 17725, 60949, 19299, 91425, 0 };
            const std::uint32_t dim14595JoeKuoD6Init[]   =   { 1, 1, 3, 7, 15, 63, 123, 11, 109, 829, 231, 2591, 7997, 9061, 18647, 3209, 38509, 211219, 0 };
            const std::uint32_t dim14596JoeKuoD6Init[]   =   { 1, 1, 1, 11, 13, 35, 73, 223, 325, 49, 1317, 4063, 4127, 2755, 555, 51057, 44909, 205723, 0 };
            const std::uint32_t dim14597JoeKuoD6Init[]   =   { 1, 3, 3, 13, 17, 41, 115, 141, 503, 525, 63, 2487, 3225, 959, 10623, 28577, 89127, 157269, 0 };
            const std::uint32_t dim14598JoeKuoD6Init[]   =   { 1, 3, 1, 9, 25, 9, 43, 43, 279, 111, 1141, 3033, 7229, 5725, 8277, 59141, 116811, 127945, 0 };
            const std::uint32_t dim14599JoeKuoD6Init[]   =   { 1, 3, 7, 11, 27, 27, 93, 243, 135, 333, 1475, 1259, 1583, 7191, 6831, 53485, 128819, 174211, 0 };
            const std::uint32_t dim14600JoeKuoD6Init[]   =   { 1, 3, 3, 3, 17, 17, 43, 251, 433, 1011, 1817, 2835, 7721, 2449, 9463, 23779, 31427, 88127, 0 };
            const std::uint32_t dim14601JoeKuoD6Init[]   =   { 1, 1, 3, 3, 11, 49, 61, 41, 211, 559, 1761, 1303, 2119, 5743, 25515, 60705, 54405, 241063, 0 };
            const std::uint32_t dim14602JoeKuoD6Init[]   =   { 1, 1, 3, 11, 7, 61, 15, 115, 29, 35, 187, 3137, 6177, 1449, 32723, 15917, 107851, 101077, 0 };
            const std::uint32_t dim14603JoeKuoD6Init[]   =   { 1, 3, 5, 13, 21, 7, 11, 231, 417, 73, 1175, 735, 627, 7393, 7233, 39883, 129481, 106733, 0 };
            const std::uint32_t dim14604JoeKuoD6Init[]   =   { 1, 3, 1, 15, 27, 61, 63, 201, 27, 431, 1127, 1555, 1953, 13051, 18701, 30097, 95549, 198465, 0 };
            const std::uint32_t dim14605JoeKuoD6Init[]   =   { 1, 1, 3, 1, 23, 25, 43, 85, 291, 85, 1861, 675, 7451, 14701, 3929, 10835, 25569, 154687, 0 };
            const std::uint32_t dim14606JoeKuoD6Init[]   =   { 1, 3, 7, 15, 5, 43, 91, 225, 283, 259, 1311, 3977, 585, 14803, 14117, 2121, 106981, 157577, 0 };
            const std::uint32_t dim14607JoeKuoD6Init[]   =   { 1, 1, 1, 11, 7, 51, 49, 115, 477, 861, 1115, 743, 5109, 959, 7105, 9245, 66297, 188751, 0 };
            const std::uint32_t dim14608JoeKuoD6Init[]   =   { 1, 3, 3, 11, 23, 1, 11, 111, 163, 643, 1907, 3613, 2967, 10071, 6023, 1307, 62341, 241025, 0 };
            const std::uint32_t dim14609JoeKuoD6Init[]   =   { 1, 3, 5, 5, 15, 29, 31, 43, 445, 219, 1261, 421, 6035, 6461, 25583, 817, 100509, 239637, 0 };
            const std::uint32_t dim14610JoeKuoD6Init[]   =   { 1, 1, 7, 3, 27, 51, 121, 93, 349, 125, 2013, 1671, 8049, 7807, 7291, 64413, 93625, 245611, 0 };
            const std::uint32_t dim14611JoeKuoD6Init[]   =   { 1, 3, 3, 9, 11, 1, 91, 137, 501, 617, 1513, 799, 1705, 15737, 14989, 53611, 48781, 64481, 0 };
            const std::uint32_t dim14612JoeKuoD6Init[]   =   { 1, 3, 3, 1, 21, 55, 95, 79, 383, 617, 1589, 2671, 4057, 13525, 9269, 23539, 13317, 87701, 0 };
            const std::uint32_t dim14613JoeKuoD6Init[]   =   { 1, 1, 3, 1, 29, 17, 121, 45, 91, 215, 325, 2853, 1213, 10221, 7233, 34063, 21887, 142943, 0 };
            const std::uint32_t dim14614JoeKuoD6Init[]   =   { 1, 3, 3, 11, 27, 53, 55, 149, 107, 379, 441, 585, 5697, 16353, 5613, 4323, 55315, 197603, 0 };
            const std::uint32_t dim14615JoeKuoD6Init[]   =   { 1, 3, 7, 3, 31, 9, 71, 175, 485, 35, 675, 2091, 2351, 7985, 14207, 52687, 8559, 1067, 0 };
            const std::uint32_t dim14616JoeKuoD6Init[]   =   { 1, 1, 5, 15, 29, 37, 9, 73, 357, 961, 489, 875, 7465, 3231, 27821, 42499, 127837, 117215, 0 };
            const std::uint32_t dim14617JoeKuoD6Init[]   =   { 1, 3, 7, 7, 19, 43, 75, 153, 27, 291, 2039, 2661, 5513, 13429, 27307, 5305, 44771, 200621, 0 };
            const std::uint32_t dim14618JoeKuoD6Init[]   =   { 1, 1, 1, 15, 5, 39, 61, 107, 201, 485, 319, 335, 5537, 14195, 31861, 63637, 68497, 45637, 0 };
            const std::uint32_t dim14619JoeKuoD6Init[]   =   { 1, 3, 7, 7, 23, 49, 95, 225, 25, 933, 667, 2993, 2181, 15659, 31343, 20249, 57039, 43399, 0 };
            const std::uint32_t dim14620JoeKuoD6Init[]   =   { 1, 3, 3, 7, 17, 25, 29, 243, 511, 91, 1409, 203, 2749, 7067, 12471, 41737, 32761, 7535, 0 };
            const std::uint32_t dim14621JoeKuoD6Init[]   =   { 1, 1, 7, 9, 27, 43, 63, 65, 325, 817, 1127, 2039, 6171, 5867, 10593, 17205, 95913, 207417, 0 };
            const std::uint32_t dim14622JoeKuoD6Init[]   =   { 1, 1, 7, 3, 3, 51, 107, 153, 193, 579, 593, 2915, 7641, 5157, 1131, 29793, 66579, 81903, 0 };
            const std::uint32_t dim14623JoeKuoD6Init[]   =   { 1, 1, 5, 15, 19, 61, 125, 107, 235, 513, 1897, 875, 6341, 1817, 10631, 63905, 42993, 150699, 0 };
            const std::uint32_t dim14624JoeKuoD6Init[]   =   { 1, 1, 3, 11, 27, 1, 93, 107, 325, 459, 1733, 2527, 4557, 2277, 19345, 8205, 67337, 242559, 0 };
            const std::uint32_t dim14625JoeKuoD6Init[]   =   { 1, 1, 7, 3, 3, 45, 27, 227, 201, 99, 589, 1665, 4851, 2655, 9915, 41321, 59865, 71501, 0 };
            const std::uint32_t dim14626JoeKuoD6Init[]   =   { 1, 3, 1, 9, 3, 25, 117, 199, 125, 849, 135, 1771, 4743, 13475, 23711, 17389, 52711, 200143, 0 };
            const std::uint32_t dim14627JoeKuoD6Init[]   =   { 1, 3, 1, 3, 11, 23, 67, 155, 133, 557, 1933, 3169, 1707, 16045, 11039, 13889, 71045, 245885, 0 };
            const std::uint32_t dim14628JoeKuoD6Init[]   =   { 1, 1, 5, 9, 1, 7, 99, 13, 315, 251, 1289, 225, 2847, 8451, 3139, 46829, 124745, 64825, 0 };
            const std::uint32_t dim14629JoeKuoD6Init[]   =   { 1, 3, 7, 13, 19, 45, 87, 161, 271, 401, 1995, 935, 1803, 4051, 11709, 26993, 120139, 147895, 0 };
            const std::uint32_t dim14630JoeKuoD6Init[]   =   { 1, 1, 7, 5, 15, 11, 47, 215, 51, 1019, 2039, 3767, 929, 3845, 3939, 64077, 48115, 61845, 0 };
            const std::uint32_t dim14631JoeKuoD6Init[]   =   { 1, 1, 1, 5, 1, 39, 15, 77, 179, 13, 1099, 203, 3363, 9071, 12033, 49159, 71137, 124177, 0 };
            const std::uint32_t dim14632JoeKuoD6Init[]   =   { 1, 3, 5, 5, 1, 31, 83, 219, 387, 347, 1099, 925, 4423, 5081, 15981, 35881, 79131, 248301, 0 };
            const std::uint32_t dim14633JoeKuoD6Init[]   =   { 1, 3, 7, 3, 25, 19, 53, 43, 347, 845, 1735, 3237, 2795, 2253, 2997, 43729, 122833, 124869, 0 };
            const std::uint32_t dim14634JoeKuoD6Init[]   =   { 1, 3, 5, 11, 5, 19, 93, 55, 297, 231, 239, 3335, 253, 13607, 16769, 48879, 61439, 54827, 0 };
            const std::uint32_t dim14635JoeKuoD6Init[]   =   { 1, 3, 7, 11, 11, 55, 121, 73, 19, 1017, 727, 579, 8011, 9559, 15051, 7895, 17609, 103061, 0 };
            const std::uint32_t dim14636JoeKuoD6Init[]   =   { 1, 1, 7, 5, 19, 47, 85, 195, 75, 1003, 439, 3069, 2107, 12751, 26729, 2329, 1191, 86547, 0 };
            const std::uint32_t dim14637JoeKuoD6Init[]   =   { 1, 3, 3, 9, 5, 31, 63, 227, 481, 793, 1853, 1491, 2109, 4199, 32149, 45229, 54685, 124819, 0 };
            const std::uint32_t dim14638JoeKuoD6Init[]   =   { 1, 1, 1, 3, 15, 15, 41, 45, 153, 429, 1691, 1897, 7253, 7239, 26133, 36527, 90319, 186097, 0 };
            const std::uint32_t dim14639JoeKuoD6Init[]   =   { 1, 3, 1, 13, 15, 33, 103, 113, 121, 387, 177, 1943, 3181, 5483, 18515, 38807, 22655, 59787, 0 };
            const std::uint32_t dim14640JoeKuoD6Init[]   =   { 1, 1, 5, 7, 15, 3, 53, 155, 99, 133, 579, 2129, 6881, 11091, 26715, 15485, 108071, 230881, 0 };
            const std::uint32_t dim14641JoeKuoD6Init[]   =   { 1, 1, 3, 13, 25, 61, 91, 81, 9, 1011, 1993, 2485, 3707, 11127, 21279, 15853, 104081, 203769, 0 };
            const std::uint32_t dim14642JoeKuoD6Init[]   =   { 1, 1, 7, 3, 17, 23, 37, 171, 315, 247, 275, 3215, 7139, 11739, 25859, 34803, 124601, 9169, 0 };
            const std::uint32_t dim14643JoeKuoD6Init[]   =   { 1, 3, 7, 9, 21, 29, 97, 213, 309, 865, 597, 1811, 5547, 3741, 31927, 53379, 43293, 23589, 0 };
            const std::uint32_t dim14644JoeKuoD6Init[]   =   { 1, 3, 7, 9, 7, 43, 107, 187, 485, 977, 1329, 3037, 3701, 9667, 13581, 6283, 39221, 63841, 0 };
            const std::uint32_t dim14645JoeKuoD6Init[]   =   { 1, 1, 3, 11, 3, 51, 117, 45, 293, 409, 689, 153, 1163, 10921, 22709, 30415, 120475, 120751, 0 };
            const std::uint32_t dim14646JoeKuoD6Init[]   =   { 1, 3, 5, 15, 31, 59, 57, 63, 249, 763, 1627, 3039, 4309, 14115, 25489, 35009, 126609, 146041, 0 };
            const std::uint32_t dim14647JoeKuoD6Init[]   =   { 1, 1, 1, 9, 3, 47, 21, 183, 495, 361, 1439, 407, 5757, 12645, 11425, 1923, 94511, 205127, 0 };
            const std::uint32_t dim14648JoeKuoD6Init[]   =   { 1, 3, 1, 9, 15, 5, 101, 107, 385, 175, 791, 901, 4427, 10415, 8163, 14417, 62997, 139309, 0 };
            const std::uint32_t dim14649JoeKuoD6Init[]   =   { 1, 3, 5, 3, 13, 57, 9, 99, 77, 123, 1607, 3643, 3879, 503, 6021, 60211, 106471, 221801, 0 };
            const std::uint32_t dim14650JoeKuoD6Init[]   =   { 1, 1, 7, 5, 27, 35, 11, 33, 415, 387, 1461, 741, 55, 15095, 21177, 5715, 109893, 204843, 0 };
            const std::uint32_t dim14651JoeKuoD6Init[]   =   { 1, 1, 1, 15, 7, 49, 51, 81, 157, 421, 279, 1951, 6847, 10259, 31925, 60761, 12395, 49511, 0 };
            const std::uint32_t dim14652JoeKuoD6Init[]   =   { 1, 3, 7, 11, 5, 33, 27, 135, 247, 813, 1889, 2547, 2359, 9535, 4141, 59713, 88685, 214641, 0 };
            const std::uint32_t dim14653JoeKuoD6Init[]   =   { 1, 1, 5, 15, 17, 61, 99, 103, 39, 151, 1033, 2743, 6639, 5271, 22059, 12681, 22763, 88255, 0 };
            const std::uint32_t dim14654JoeKuoD6Init[]   =   { 1, 1, 7, 13, 5, 11, 39, 139, 353, 989, 1391, 169, 3709, 735, 22965, 227, 103623, 153893, 0 };
            const std::uint32_t dim14655JoeKuoD6Init[]   =   { 1, 1, 7, 3, 9, 51, 53, 87, 411, 617, 671, 681, 5057, 6003, 23137, 30881, 2289, 187133, 0 };
            const std::uint32_t dim14656JoeKuoD6Init[]   =   { 1, 1, 7, 7, 17, 59, 77, 219, 25, 53, 145, 129, 4289, 14257, 7159, 44833, 22131, 53393, 0 };
            const std::uint32_t dim14657JoeKuoD6Init[]   =   { 1, 3, 7, 1, 9, 59, 79, 177, 149, 637, 1641, 3713, 2709, 12321, 5691, 18239, 8617, 225979, 0 };
            const std::uint32_t dim14658JoeKuoD6Init[]   =   { 1, 1, 7, 5, 9, 9, 67, 51, 451, 815, 295, 813, 1257, 179, 28769, 57241, 51753, 164873, 0 };
            const std::uint32_t dim14659JoeKuoD6Init[]   =   { 1, 3, 1, 9, 19, 61, 53, 65, 29, 503, 715, 1837, 7487, 16187, 27303, 54681, 98753, 100471, 0 };
            const std::uint32_t dim14660JoeKuoD6Init[]   =   { 1, 1, 3, 1, 15, 51, 1, 79, 179, 367, 841, 1313, 797, 4777, 1369, 13317, 65059, 204877, 0 };
            const std::uint32_t dim14661JoeKuoD6Init[]   =   { 1, 3, 5, 9, 15, 19, 109, 45, 473, 517, 1139, 15, 1997, 4245, 11169, 56417, 75017, 37957, 0 };
            const std::uint32_t dim14662JoeKuoD6Init[]   =   { 1, 1, 7, 1, 3, 41, 75, 95, 59, 503, 1439, 2633, 3527, 5363, 24357, 43659, 10387, 208319, 0 };
            const std::uint32_t dim14663JoeKuoD6Init[]   =   { 1, 1, 5, 1, 31, 7, 71, 231, 505, 241, 1579, 3517, 3995, 8269, 6793, 15883, 102779, 75589, 0 };
            const std::uint32_t dim14664JoeKuoD6Init[]   =   { 1, 3, 5, 1, 13, 61, 87, 213, 501, 307, 1629, 2715, 7245, 747, 20601, 28105, 79249, 76231, 0 };
            const std::uint32_t dim14665JoeKuoD6Init[]   =   { 1, 1, 7, 11, 5, 13, 69, 221, 485, 59, 2027, 483, 6851, 11719, 16787, 54111, 47579, 49959, 0 };
            const std::uint32_t dim14666JoeKuoD6Init[]   =   { 1, 1, 3, 15, 3, 33, 57, 75, 375, 45, 851, 1673, 8167, 867, 32087, 34157, 96701, 72893, 0 };
            const std::uint32_t dim14667JoeKuoD6Init[]   =   { 1, 1, 3, 1, 21, 31, 65, 85, 181, 453, 815, 3139, 205, 429, 7451, 50855, 41085, 137927, 0 };
            const std::uint32_t dim14668JoeKuoD6Init[]   =   { 1, 3, 1, 9, 3, 57, 99, 183, 305, 991, 809, 4021, 3131, 4459, 5839, 32493, 116541, 59329, 0 };
            const std::uint32_t dim14669JoeKuoD6Init[]   =   { 1, 3, 7, 1, 5, 19, 3, 91, 297, 715, 1081, 445, 393, 12685, 4457, 61437, 103701, 75917, 0 };
            const std::uint32_t dim14670JoeKuoD6Init[]   =   { 1, 1, 7, 15, 17, 39, 19, 255, 247, 391, 1055, 1241, 4515, 10217, 23363, 40301, 115053, 234349, 0 };
            const std::uint32_t dim14671JoeKuoD6Init[]   =   { 1, 3, 5, 1, 21, 9, 33, 243, 501, 793, 219, 3595, 2585, 5083, 15377, 35761, 90609, 93761, 0 };
            const std::uint32_t dim14672JoeKuoD6Init[]   =   { 1, 1, 5, 13, 3, 1, 5, 77, 265, 525, 1107, 1879, 1119, 2277, 30557, 43547, 81947, 134075, 0 };
            const std::uint32_t dim14673JoeKuoD6Init[]   =   { 1, 1, 7, 5, 11, 47, 71, 83, 255, 183, 515, 2591, 3933, 16025, 16727, 43421, 18725, 106675, 0 };
            const std::uint32_t dim14674JoeKuoD6Init[]   =   { 1, 3, 1, 1, 5, 17, 57, 209, 509, 421, 1247, 3153, 1835, 8777, 13285, 27699, 34001, 186553, 0 };
            const std::uint32_t dim14675JoeKuoD6Init[]   =   { 1, 1, 3, 11, 27, 19, 73, 65, 179, 115, 845, 2507, 7673, 14429, 10553, 4999, 82323, 247379, 0 };
            const std::uint32_t dim14676JoeKuoD6Init[]   =   { 1, 3, 7, 7, 17, 59, 97, 183, 407, 697, 1423, 123, 6479, 3997, 729, 31587, 114383, 61673, 0 };
            const std::uint32_t dim14677JoeKuoD6Init[]   =   { 1, 1, 5, 9, 21, 23, 21, 153, 187, 255, 125, 1469, 2639, 8099, 29689, 36415, 103959, 231621, 0 };
            const std::uint32_t dim14678JoeKuoD6Init[]   =   { 1, 1, 3, 11, 19, 59, 115, 205, 123, 133, 1953, 3471, 2495, 329, 32385, 21931, 9691, 51405, 0 };
            const std::uint32_t dim14679JoeKuoD6Init[]   =   { 1, 3, 3, 13, 7, 7, 115, 65, 301, 621, 1091, 2137, 5729, 5027, 21331, 24803, 114789, 142039, 0 };
            const std::uint32_t dim14680JoeKuoD6Init[]   =   { 1, 1, 7, 5, 31, 19, 103, 69, 503, 663, 1497, 2867, 5295, 893, 15927, 37513, 94553, 72369, 0 };
            const std::uint32_t dim14681JoeKuoD6Init[]   =   { 1, 3, 3, 15, 17, 33, 99, 249, 277, 259, 9, 99, 3073, 12017, 14847, 7685, 102499, 26489, 0 };
            const std::uint32_t dim14682JoeKuoD6Init[]   =   { 1, 1, 1, 1, 5, 23, 31, 45, 29, 483, 1977, 1129, 6925, 2273, 16573, 53039, 90251, 137191, 0 };
            const std::uint32_t dim14683JoeKuoD6Init[]   =   { 1, 3, 1, 13, 27, 47, 29, 51, 473, 895, 671, 3917, 6905, 15769, 9019, 28879, 120591, 220753, 0 };
            const std::uint32_t dim14684JoeKuoD6Init[]   =   { 1, 3, 1, 13, 27, 29, 53, 255, 507, 819, 1251, 2463, 1717, 14461, 31997, 30829, 8803, 115539, 0 };
            const std::uint32_t dim14685JoeKuoD6Init[]   =   { 1, 3, 3, 15, 27, 1, 109, 225, 451, 409, 2025, 2701, 4121, 9949, 1551, 13625, 73577, 211549, 0 };
            const std::uint32_t dim14686JoeKuoD6Init[]   =   { 1, 1, 1, 3, 23, 57, 49, 35, 365, 711, 2001, 997, 1853, 2913, 15667, 30255, 19535, 2171, 0 };
            const std::uint32_t dim14687JoeKuoD6Init[]   =   { 1, 1, 7, 1, 21, 37, 127, 3, 117, 449, 1689, 1391, 1427, 12641, 15199, 23769, 66553, 34669, 0 };
            const std::uint32_t dim14688JoeKuoD6Init[]   =   { 1, 3, 7, 9, 31, 45, 51, 137, 181, 469, 573, 89, 7257, 10991, 30705, 37827, 75071, 152885, 0 };
            const std::uint32_t dim14689JoeKuoD6Init[]   =   { 1, 3, 1, 1, 19, 13, 55, 223, 261, 353, 1497, 183, 8173, 14421, 9977, 24095, 47215, 155189, 0 };
            const std::uint32_t dim14690JoeKuoD6Init[]   =   { 1, 1, 3, 15, 15, 41, 31, 105, 459, 27, 299, 159, 2167, 14809, 9983, 2755, 121715, 35921, 0 };
            const std::uint32_t dim14691JoeKuoD6Init[]   =   { 1, 1, 3, 7, 31, 5, 85, 137, 431, 849, 1479, 2681, 167, 5727, 3211, 30765, 63295, 39509, 0 };
            const std::uint32_t dim14692JoeKuoD6Init[]   =   { 1, 1, 5, 7, 5, 51, 21, 103, 175, 927, 1115, 1507, 505, 8093, 25831, 54303, 40397, 61249, 0 };
            const std::uint32_t dim14693JoeKuoD6Init[]   =   { 1, 1, 7, 3, 23, 53, 49, 225, 7, 425, 403, 3949, 1081, 15335, 21737, 647, 107875, 236183, 0 };
            const std::uint32_t dim14694JoeKuoD6Init[]   =   { 1, 1, 5, 7, 17, 21, 85, 229, 325, 57, 601, 2785, 6417, 5135, 17917, 12861, 97675, 115457, 0 };
            const std::uint32_t dim14695JoeKuoD6Init[]   =   { 1, 1, 3, 3, 13, 23, 73, 111, 385, 47, 605, 1169, 1729, 2335, 18739, 61293, 41915, 237645, 0 };
            const std::uint32_t dim14696JoeKuoD6Init[]   =   { 1, 1, 1, 5, 31, 11, 123, 13, 465, 755, 1073, 1885, 2105, 5971, 2347, 10911, 125823, 156037, 0 };
            const std::uint32_t dim14697JoeKuoD6Init[]   =   { 1, 3, 7, 11, 17, 47, 3, 165, 227, 355, 87, 839, 7741, 12275, 28579, 25337, 87671, 224847, 0 };
            const std::uint32_t dim14698JoeKuoD6Init[]   =   { 1, 1, 5, 15, 23, 33, 9, 1, 257, 121, 1049, 1009, 187, 9935, 26093, 21921, 130247, 240291, 0 };
            const std::uint32_t dim14699JoeKuoD6Init[]   =   { 1, 1, 3, 13, 13, 27, 87, 221, 27, 117, 551, 2533, 7611, 5333, 14635, 9911, 37555, 250621, 0 };
            const std::uint32_t dim14700JoeKuoD6Init[]   =   { 1, 3, 7, 15, 29, 39, 33, 1, 495, 889, 1397, 3415, 7193, 11533, 27379, 36425, 13739, 146635, 0 };
            const std::uint32_t dim14701JoeKuoD6Init[]   =   { 1, 1, 7, 11, 1, 23, 85, 127, 79, 989, 321, 1913, 7571, 9889, 11803, 1307, 120513, 218077, 0 };
            const std::uint32_t dim14702JoeKuoD6Init[]   =   { 1, 1, 7, 5, 5, 15, 35, 9, 351, 973, 1455, 2043, 5527, 9431, 16059, 53915, 105785, 180579, 0 };
            const std::uint32_t dim14703JoeKuoD6Init[]   =   { 1, 1, 1, 13, 13, 45, 15, 41, 131, 463, 1011, 3559, 6393, 4737, 6041, 33073, 60989, 56761, 0 };
            const std::uint32_t dim14704JoeKuoD6Init[]   =   { 1, 1, 3, 9, 31, 35, 23, 133, 33, 233, 543, 957, 4913, 12441, 10293, 31611, 83383, 154551, 0 };
            const std::uint32_t dim14705JoeKuoD6Init[]   =   { 1, 3, 3, 1, 29, 37, 117, 247, 345, 197, 1617, 3333, 7901, 8343, 55, 16529, 34627, 172703, 0 };
            const std::uint32_t dim14706JoeKuoD6Init[]   =   { 1, 1, 1, 13, 23, 51, 7, 219, 503, 215, 375, 2275, 5467, 13953, 13987, 22735, 67505, 185977, 0 };
            const std::uint32_t dim14707JoeKuoD6Init[]   =   { 1, 3, 5, 5, 29, 53, 85, 147, 167, 409, 853, 667, 4431, 5227, 15535, 34375, 107135, 220637, 0 };
            const std::uint32_t dim14708JoeKuoD6Init[]   =   { 1, 3, 7, 7, 19, 3, 73, 123, 455, 539, 1735, 1423, 5337, 16311, 15469, 36071, 126437, 219249, 0 };
            const std::uint32_t dim14709JoeKuoD6Init[]   =   { 1, 1, 1, 3, 19, 49, 17, 133, 101, 1013, 683, 869, 6267, 409, 31379, 2535, 8039, 63205, 0 };
            const std::uint32_t dim14710JoeKuoD6Init[]   =   { 1, 1, 1, 13, 13, 53, 25, 31, 501, 629, 645, 1811, 3675, 13317, 17009, 7359, 85475, 249823, 0 };
            const std::uint32_t dim14711JoeKuoD6Init[]   =   { 1, 1, 3, 11, 5, 1, 41, 17, 159, 361, 1439, 2083, 1425, 7221, 9117, 59543, 59285, 188615, 0 };
            const std::uint32_t dim14712JoeKuoD6Init[]   =   { 1, 3, 7, 1, 11, 27, 71, 121, 471, 749, 1983, 3715, 6463, 5793, 1063, 18201, 189, 243751, 0 };
            const std::uint32_t dim14713JoeKuoD6Init[]   =   { 1, 3, 3, 11, 19, 17, 15, 175, 379, 683, 1491, 2385, 6981, 1183, 16829, 2103, 9309, 46119, 0 };
            const std::uint32_t dim14714JoeKuoD6Init[]   =   { 1, 1, 7, 5, 17, 39, 109, 9, 279, 309, 1, 1523, 4551, 3855, 13277, 36125, 54191, 45085, 0 };
            const std::uint32_t dim14715JoeKuoD6Init[]   =   { 1, 3, 5, 3, 9, 59, 51, 5, 431, 657, 161, 2725, 2401, 9743, 12925, 43501, 51551, 163737, 0 };
            const std::uint32_t dim14716JoeKuoD6Init[]   =   { 1, 1, 5, 3, 9, 13, 7, 177, 121, 795, 1169, 3169, 3793, 3995, 29027, 32967, 82273, 207939, 0 };
            const std::uint32_t dim14717JoeKuoD6Init[]   =   { 1, 3, 7, 13, 1, 1, 31, 91, 245, 775, 1589, 2263, 6303, 15787, 3111, 52553, 52507, 183971, 0 };
            const std::uint32_t dim14718JoeKuoD6Init[]   =   { 1, 3, 5, 11, 15, 49, 73, 191, 67, 449, 1245, 2445, 5617, 8625, 27971, 35939, 76907, 76207, 0 };
            const std::uint32_t dim14719JoeKuoD6Init[]   =   { 1, 3, 1, 11, 15, 47, 29, 91, 437, 895, 1941, 249, 2739, 15479, 29699, 7257, 39897, 65985, 0 };
            const std::uint32_t dim14720JoeKuoD6Init[]   =   { 1, 3, 5, 7, 13, 23, 45, 113, 297, 373, 1505, 2317, 7509, 12059, 13737, 29081, 87337, 221917, 0 };
            const std::uint32_t dim14721JoeKuoD6Init[]   =   { 1, 3, 3, 3, 1, 5, 13, 215, 221, 461, 1337, 3569, 2257, 12135, 14685, 39721, 16723, 234791, 0 };
            const std::uint32_t dim14722JoeKuoD6Init[]   =   { 1, 1, 7, 5, 11, 25, 71, 103, 87, 533, 779, 379, 6695, 13451, 24801, 49235, 35109, 100865, 0 };
            const std::uint32_t dim14723JoeKuoD6Init[]   =   { 1, 3, 3, 15, 13, 51, 27, 11, 279, 847, 135, 1119, 2765, 3805, 20273, 29089, 83379, 190353, 0 };
            const std::uint32_t dim14724JoeKuoD6Init[]   =   { 1, 3, 7, 5, 17, 29, 111, 35, 189, 273, 503, 541, 6691, 9051, 10403, 7559, 54787, 25403, 0 };
            const std::uint32_t dim14725JoeKuoD6Init[]   =   { 1, 3, 5, 9, 21, 29, 85, 235, 223, 677, 71, 1313, 6587, 10983, 199, 27721, 78627, 105505, 0 };
            const std::uint32_t dim14726JoeKuoD6Init[]   =   { 1, 3, 1, 3, 13, 3, 123, 115, 173, 907, 1555, 1489, 2745, 6451, 25347, 24105, 66471, 181009, 0 };
            const std::uint32_t dim14727JoeKuoD6Init[]   =   { 1, 1, 7, 1, 31, 15, 13, 97, 511, 827, 1193, 3081, 1517, 13511, 24887, 39239, 85175, 150213, 0 };
            const std::uint32_t dim14728JoeKuoD6Init[]   =   { 1, 1, 1, 5, 17, 39, 121, 67, 207, 877, 1885, 171, 2687, 13081, 27267, 58699, 118575, 213025, 0 };
            const std::uint32_t dim14729JoeKuoD6Init[]   =   { 1, 1, 3, 9, 9, 27, 101, 215, 31, 37, 1629, 3631, 3225, 9667, 31547, 41939, 38683, 150805, 0 };
            const std::uint32_t dim14730JoeKuoD6Init[]   =   { 1, 3, 1, 11, 11, 59, 17, 15, 187, 667, 747, 2193, 6749, 6019, 31805, 52433, 4141, 52613, 0 };
            const std::uint32_t dim14731JoeKuoD6Init[]   =   { 1, 3, 3, 13, 9, 1, 51, 101, 213, 881, 899, 2197, 3017, 1591, 9271, 44017, 99893, 192005, 0 };
            const std::uint32_t dim14732JoeKuoD6Init[]   =   { 1, 3, 7, 13, 23, 41, 79, 83, 123, 585, 49, 849, 2133, 12473, 6907, 15487, 45783, 46609, 0 };
            const std::uint32_t dim14733JoeKuoD6Init[]   =   { 1, 3, 7, 13, 27, 23, 71, 13, 319, 903, 1123, 933, 2603, 11631, 19953, 47001, 127751, 84547, 0 };
            const std::uint32_t dim14734JoeKuoD6Init[]   =   { 1, 1, 1, 15, 3, 61, 79, 231, 43, 217, 801, 997, 6545, 13657, 25589, 30435, 49497, 1037, 0 };
            const std::uint32_t dim14735JoeKuoD6Init[]   =   { 1, 3, 3, 3, 21, 29, 121, 35, 129, 239, 1645, 3147, 7647, 1201, 19287, 7075, 67961, 62481, 0 };
            const std::uint32_t dim14736JoeKuoD6Init[]   =   { 1, 3, 7, 7, 3, 23, 45, 177, 469, 897, 359, 2521, 2079, 985, 14993, 56813, 20667, 187341, 0 };
            const std::uint32_t dim14737JoeKuoD6Init[]   =   { 1, 3, 5, 7, 23, 53, 15, 45, 297, 93, 247, 1165, 2683, 5899, 7113, 14859, 22733, 173835, 0 };
            const std::uint32_t dim14738JoeKuoD6Init[]   =   { 1, 1, 3, 15, 23, 17, 43, 179, 103, 197, 1857, 323, 267, 12417, 2343, 41527, 12243, 112023, 0 };
            const std::uint32_t dim14739JoeKuoD6Init[]   =   { 1, 3, 7, 13, 7, 43, 75, 19, 169, 621, 735, 141, 3087, 765, 5901, 34029, 117603, 5137, 0 };
            const std::uint32_t dim14740JoeKuoD6Init[]   =   { 1, 1, 3, 5, 15, 17, 67, 177, 371, 249, 99, 1651, 3701, 343, 435, 50307, 33915, 115391, 0 };
            const std::uint32_t dim14741JoeKuoD6Init[]   =   { 1, 1, 3, 13, 19, 53, 69, 1, 435, 71, 339, 2289, 1591, 8783, 8087, 25855, 115311, 191115, 0 };
            const std::uint32_t dim14742JoeKuoD6Init[]   =   { 1, 3, 5, 11, 1, 55, 59, 7, 101, 655, 353, 483, 5681, 12721, 15973, 51377, 94921, 246365, 0 };
            const std::uint32_t dim14743JoeKuoD6Init[]   =   { 1, 3, 5, 3, 25, 23, 99, 145, 277, 741, 595, 2653, 1393, 2867, 271, 49131, 111973, 118869, 0 };
            const std::uint32_t dim14744JoeKuoD6Init[]   =   { 1, 1, 7, 13, 11, 51, 127, 27, 305, 265, 1755, 3189, 4679, 9721, 24409, 46941, 94353, 95643, 0 };
            const std::uint32_t dim14745JoeKuoD6Init[]   =   { 1, 1, 5, 11, 1, 63, 53, 149, 459, 155, 1431, 3969, 3417, 12121, 14535, 52089, 110745, 57, 0 };
            const std::uint32_t dim14746JoeKuoD6Init[]   =   { 1, 1, 5, 9, 23, 33, 17, 175, 313, 185, 101, 531, 2941, 14999, 31413, 12103, 33709, 260555, 0 };
            const std::uint32_t dim14747JoeKuoD6Init[]   =   { 1, 1, 3, 13, 3, 11, 67, 95, 211, 673, 23, 2379, 6985, 12101, 13021, 9255, 116437, 228877, 0 };
            const std::uint32_t dim14748JoeKuoD6Init[]   =   { 1, 1, 3, 15, 7, 51, 25, 109, 45, 691, 869, 485, 111, 11465, 27953, 54375, 10805, 221023, 0 };
            const std::uint32_t dim14749JoeKuoD6Init[]   =   { 1, 3, 7, 7, 17, 53, 59, 101, 221, 593, 587, 873, 931, 14617, 12067, 58655, 102437, 31675, 0 };
            const std::uint32_t dim14750JoeKuoD6Init[]   =   { 1, 1, 3, 15, 25, 57, 35, 231, 491, 671, 933, 3525, 1237, 10155, 27501, 50781, 23183, 108283, 0 };
            const std::uint32_t dim14751JoeKuoD6Init[]   =   { 1, 3, 5, 5, 31, 63, 117, 205, 199, 841, 1455, 3901, 2127, 13573, 20667, 49489, 60217, 197421, 0 };
            const std::uint32_t dim14752JoeKuoD6Init[]   =   { 1, 1, 3, 7, 15, 21, 73, 211, 421, 873, 607, 709, 9, 10985, 28653, 64579, 118145, 3095, 0 };
            const std::uint32_t dim14753JoeKuoD6Init[]   =   { 1, 1, 1, 13, 17, 53, 27, 105, 201, 399, 737, 3235, 1287, 13859, 6049, 62249, 88259, 52991, 0 };
            const std::uint32_t dim14754JoeKuoD6Init[]   =   { 1, 3, 7, 7, 25, 45, 67, 147, 275, 315, 1675, 2289, 4611, 6325, 26617, 38079, 125219, 23569, 0 };
            const std::uint32_t dim14755JoeKuoD6Init[]   =   { 1, 1, 7, 7, 9, 61, 115, 251, 297, 691, 1881, 1815, 7229, 10859, 8257, 38097, 87927, 162845, 0 };
            const std::uint32_t dim14756JoeKuoD6Init[]   =   { 1, 3, 3, 9, 9, 59, 17, 207, 433, 825, 93, 697, 7263, 15983, 14829, 47471, 17579, 151519, 0 };
            const std::uint32_t dim14757JoeKuoD6Init[]   =   { 1, 1, 1, 11, 21, 31, 7, 41, 383, 731, 2033, 3417, 4187, 5515, 10093, 15875, 78551, 2057, 0 };
            const std::uint32_t dim14758JoeKuoD6Init[]   =   { 1, 3, 7, 15, 5, 29, 7, 171, 129, 727, 1815, 1361, 6137, 10333, 22203, 361, 92437, 6545, 0 };
            const std::uint32_t dim14759JoeKuoD6Init[]   =   { 1, 1, 3, 13, 25, 45, 111, 69, 333, 365, 765, 2755, 3485, 2729, 23467, 64809, 120755, 169279, 0 };
            const std::uint32_t dim14760JoeKuoD6Init[]   =   { 1, 1, 3, 1, 19, 13, 33, 165, 157, 429, 1175, 3435, 7523, 5055, 12295, 34309, 36933, 164037, 0 };
            const std::uint32_t dim14761JoeKuoD6Init[]   =   { 1, 1, 3, 11, 31, 49, 37, 161, 465, 311, 1839, 689, 6837, 13473, 29883, 61587, 86077, 156921, 0 };
            const std::uint32_t dim14762JoeKuoD6Init[]   =   { 1, 3, 3, 1, 3, 23, 69, 159, 501, 303, 1495, 9, 6055, 545, 12247, 23413, 67247, 38137, 0 };
            const std::uint32_t dim14763JoeKuoD6Init[]   =   { 1, 1, 5, 15, 5, 39, 107, 121, 295, 167, 1055, 2703, 147, 7291, 3981, 51989, 92953, 225987, 0 };
            const std::uint32_t dim14764JoeKuoD6Init[]   =   { 1, 3, 1, 1, 21, 5, 91, 129, 57, 53, 365, 2497, 5017, 13535, 19305, 60447, 115467, 225317, 0 };
            const std::uint32_t dim14765JoeKuoD6Init[]   =   { 1, 3, 1, 7, 25, 17, 51, 15, 119, 1013, 719, 991, 2655, 12587, 15749, 11723, 18461, 155937, 0 };
            const std::uint32_t dim14766JoeKuoD6Init[]   =   { 1, 3, 7, 3, 25, 33, 59, 135, 501, 813, 235, 3775, 2781, 13137, 32673, 31643, 78881, 207651, 0 };
            const std::uint32_t dim14767JoeKuoD6Init[]   =   { 1, 1, 7, 13, 27, 51, 99, 189, 187, 577, 941, 1275, 7297, 14731, 12599, 49049, 96439, 35093, 0 };
            const std::uint32_t dim14768JoeKuoD6Init[]   =   { 1, 3, 1, 15, 9, 45, 1, 149, 305, 231, 935, 1377, 6345, 14795, 20969, 26263, 5711, 146949, 0 };
            const std::uint32_t dim14769JoeKuoD6Init[]   =   { 1, 1, 5, 9, 5, 9, 47, 127, 105, 517, 671, 67, 4639, 2477, 23109, 56707, 72131, 100709, 0 };
            const std::uint32_t dim14770JoeKuoD6Init[]   =   { 1, 3, 5, 3, 21, 23, 7, 193, 491, 197, 319, 3207, 2183, 2133, 3127, 34555, 53707, 170875, 0 };
            const std::uint32_t dim14771JoeKuoD6Init[]   =   { 1, 1, 3, 9, 5, 23, 109, 91, 359, 913, 179, 1031, 3617, 12497, 23299, 53293, 114603, 9931, 0 };
            const std::uint32_t dim14772JoeKuoD6Init[]   =   { 1, 3, 1, 5, 1, 47, 73, 103, 333, 483, 1015, 3085, 5229, 3171, 16539, 13493, 68957, 177645, 0 };
            const std::uint32_t dim14773JoeKuoD6Init[]   =   { 1, 1, 1, 9, 27, 15, 25, 255, 383, 501, 831, 2463, 237, 16065, 6991, 56503, 117303, 140573, 0 };
            const std::uint32_t dim14774JoeKuoD6Init[]   =   { 1, 1, 3, 5, 9, 25, 15, 179, 415, 729, 1163, 2649, 2907, 9591, 29129, 42775, 80537, 139897, 0 };
            const std::uint32_t dim14775JoeKuoD6Init[]   =   { 1, 1, 3, 7, 31, 15, 113, 1, 263, 685, 1953, 1479, 5143, 8585, 9057, 61479, 122065, 191541, 0 };
            const std::uint32_t dim14776JoeKuoD6Init[]   =   { 1, 3, 1, 11, 25, 47, 25, 229, 463, 197, 1123, 2665, 2345, 11701, 10435, 15205, 35437, 137619, 0 };
            const std::uint32_t dim14777JoeKuoD6Init[]   =   { 1, 3, 3, 5, 19, 57, 89, 101, 373, 283, 57, 1701, 5025, 6677, 20321, 58459, 9319, 161501, 0 };
            const std::uint32_t dim14778JoeKuoD6Init[]   =   { 1, 1, 1, 13, 3, 51, 111, 23, 325, 813, 441, 2371, 1993, 6839, 359, 9873, 33719, 208163, 0 };
            const std::uint32_t dim14779JoeKuoD6Init[]   =   { 1, 3, 1, 11, 23, 53, 35, 89, 91, 601, 433, 1671, 1919, 2115, 6355, 10639, 87305, 194185, 0 };
            const std::uint32_t dim14780JoeKuoD6Init[]   =   { 1, 1, 5, 9, 29, 31, 43, 153, 209, 835, 865, 2431, 1085, 9771, 14483, 19551, 98673, 146881, 0 };
            const std::uint32_t dim14781JoeKuoD6Init[]   =   { 1, 1, 7, 3, 7, 33, 49, 111, 111, 843, 479, 2113, 4575, 14911, 5161, 7153, 37525, 217887, 0 };
            const std::uint32_t dim14782JoeKuoD6Init[]   =   { 1, 1, 7, 9, 27, 5, 23, 217, 11, 79, 1637, 2047, 6697, 5601, 2877, 63497, 100127, 157833, 0 };
            const std::uint32_t dim14783JoeKuoD6Init[]   =   { 1, 1, 7, 11, 31, 41, 91, 39, 207, 185, 1163, 2115, 2963, 7605, 12597, 54175, 7221, 117129, 0 };
            const std::uint32_t dim14784JoeKuoD6Init[]   =   { 1, 3, 7, 13, 9, 15, 3, 47, 281, 451, 1111, 3585, 4505, 9465, 8047, 45893, 27179, 124373, 0 };
            const std::uint32_t dim14785JoeKuoD6Init[]   =   { 1, 3, 5, 11, 27, 29, 11, 221, 483, 29, 17, 1067, 6761, 39, 13419, 7263, 127547, 178951, 0 };
            const std::uint32_t dim14786JoeKuoD6Init[]   =   { 1, 3, 5, 5, 19, 3, 51, 155, 41, 251, 851, 1191, 4445, 8337, 25339, 32931, 4743, 31883, 0 };
            const std::uint32_t dim14787JoeKuoD6Init[]   =   { 1, 3, 7, 15, 9, 3, 113, 151, 239, 611, 381, 1141, 2865, 3071, 7293, 61997, 2891, 14533, 0 };
            const std::uint32_t dim14788JoeKuoD6Init[]   =   { 1, 3, 5, 3, 15, 59, 3, 37, 385, 587, 837, 2483, 5493, 10571, 26129, 44835, 63425, 246953, 0 };
            const std::uint32_t dim14789JoeKuoD6Init[]   =   { 1, 3, 5, 13, 9, 9, 93, 11, 139, 619, 581, 2859, 5481, 11941, 20661, 37463, 95369, 177009, 0 };
            const std::uint32_t dim14790JoeKuoD6Init[]   =   { 1, 1, 7, 11, 7, 17, 89, 7, 479, 377, 1631, 509, 7429, 13733, 24011, 24191, 98409, 180761, 0 };
            const std::uint32_t dim14791JoeKuoD6Init[]   =   { 1, 3, 7, 1, 5, 17, 51, 113, 181, 75, 1787, 2221, 6181, 16069, 3031, 32531, 107833, 239907, 0 };
            const std::uint32_t dim14792JoeKuoD6Init[]   =   { 1, 1, 5, 11, 3, 25, 13, 35, 311, 865, 873, 1811, 3101, 4445, 18155, 18647, 55693, 144963, 0 };
            const std::uint32_t dim14793JoeKuoD6Init[]   =   { 1, 3, 7, 13, 1, 9, 73, 189, 255, 301, 1579, 597, 6027, 15621, 27287, 14615, 76051, 143445, 0 };
            const std::uint32_t dim14794JoeKuoD6Init[]   =   { 1, 3, 1, 13, 19, 59, 11, 97, 501, 857, 1071, 3633, 8059, 2469, 16803, 49395, 73631, 114297, 0 };
            const std::uint32_t dim14795JoeKuoD6Init[]   =   { 1, 1, 1, 5, 19, 3, 59, 179, 343, 745, 497, 2965, 3841, 3119, 17707, 31577, 39801, 108819, 0 };
            const std::uint32_t dim14796JoeKuoD6Init[]   =   { 1, 3, 3, 9, 11, 17, 19, 199, 283, 229, 493, 631, 8133, 1531, 25271, 11353, 114759, 70655, 0 };
            const std::uint32_t dim14797JoeKuoD6Init[]   =   { 1, 1, 7, 7, 3, 11, 1, 95, 167, 863, 1009, 1695, 2773, 11667, 23515, 12927, 87883, 28773, 0 };
            const std::uint32_t dim14798JoeKuoD6Init[]   =   { 1, 3, 1, 15, 9, 1, 31, 243, 57, 349, 483, 659, 1971, 7971, 23797, 4403, 83837, 239261, 0 };
            const std::uint32_t dim14799JoeKuoD6Init[]   =   { 1, 3, 7, 5, 11, 17, 55, 5, 209, 233, 1969, 925, 695, 1321, 11965, 29849, 120519, 195105, 0 };
            const std::uint32_t dim14800JoeKuoD6Init[]   =   { 1, 3, 7, 11, 9, 45, 27, 9, 57, 649, 1801, 2653, 1535, 45, 8901, 28755, 26475, 112341, 0 };
            const std::uint32_t dim14801JoeKuoD6Init[]   =   { 1, 1, 3, 13, 11, 57, 103, 213, 193, 779, 541, 3685, 4191, 6105, 7199, 63659, 49673, 208361, 0 };
            const std::uint32_t dim14802JoeKuoD6Init[]   =   { 1, 3, 3, 7, 15, 15, 9, 207, 387, 429, 1213, 1703, 5753, 10261, 8705, 62783, 9643, 248591, 0 };
            const std::uint32_t dim14803JoeKuoD6Init[]   =   { 1, 3, 3, 15, 23, 17, 5, 83, 295, 685, 2003, 1723, 2799, 14699, 25171, 20275, 45597, 214107, 0 };
            const std::uint32_t dim14804JoeKuoD6Init[]   =   { 1, 1, 1, 15, 13, 33, 111, 69, 329, 273, 1303, 3377, 4151, 12547, 20411, 54845, 7839, 173939, 0 };
            const std::uint32_t dim14805JoeKuoD6Init[]   =   { 1, 1, 5, 15, 25, 31, 11, 75, 69, 501, 1485, 3659, 3889, 9715, 9633, 45313, 112377, 27799, 0 };
            const std::uint32_t dim14806JoeKuoD6Init[]   =   { 1, 1, 3, 11, 31, 27, 7, 25, 315, 593, 315, 275, 1453, 9429, 10023, 17939, 37651, 217435, 0 };
            const std::uint32_t dim14807JoeKuoD6Init[]   =   { 1, 3, 7, 7, 27, 41, 69, 95, 19, 763, 1733, 2097, 6723, 7051, 15209, 53047, 56117, 87639, 0 };
            const std::uint32_t dim14808JoeKuoD6Init[]   =   { 1, 3, 7, 5, 15, 61, 31, 19, 361, 571, 727, 405, 835, 4847, 26777, 50311, 104125, 127197, 0 };
            const std::uint32_t dim14809JoeKuoD6Init[]   =   { 1, 1, 1, 11, 11, 61, 59, 63, 409, 219, 1135, 3385, 5583, 16143, 22709, 31247, 19871, 68557, 0 };
            const std::uint32_t dim14810JoeKuoD6Init[]   =   { 1, 3, 7, 1, 11, 3, 121, 41, 135, 427, 1267, 2169, 507, 757, 12411, 50655, 75625, 1199, 0 };
            const std::uint32_t dim14811JoeKuoD6Init[]   =   { 1, 1, 7, 5, 17, 21, 89, 119, 55, 395, 979, 909, 1711, 3289, 8433, 9, 12743, 109027, 0 };
            const std::uint32_t dim14812JoeKuoD6Init[]   =   { 1, 1, 1, 13, 5, 11, 93, 35, 437, 173, 1157, 2749, 6855, 8307, 26145, 22593, 125415, 65509, 0 };
            const std::uint32_t dim14813JoeKuoD6Init[]   =   { 1, 1, 5, 3, 25, 27, 1, 173, 113, 373, 1769, 2941, 1895, 3399, 27665, 50613, 20747, 31903, 0 };
            const std::uint32_t dim14814JoeKuoD6Init[]   =   { 1, 1, 1, 1, 9, 7, 53, 73, 465, 725, 1537, 579, 83, 925, 15507, 13595, 16927, 205087, 0 };
            const std::uint32_t dim14815JoeKuoD6Init[]   =   { 1, 1, 3, 7, 7, 23, 31, 127, 27, 727, 1305, 3879, 817, 15995, 28607, 22695, 6367, 161587, 0 };
            const std::uint32_t dim14816JoeKuoD6Init[]   =   { 1, 3, 1, 7, 29, 23, 27, 117, 279, 917, 1105, 2061, 7719, 13633, 16501, 33739, 71939, 143115, 0 };
            const std::uint32_t dim14817JoeKuoD6Init[]   =   { 1, 3, 7, 11, 7, 27, 65, 133, 411, 441, 925, 1485, 2035, 3067, 14511, 58511, 120773, 228731, 0 };
            const std::uint32_t dim14818JoeKuoD6Init[]   =   { 1, 1, 3, 9, 21, 55, 27, 73, 175, 395, 1201, 2599, 3839, 11163, 5057, 3385, 43265, 105211, 0 };
            const std::uint32_t dim14819JoeKuoD6Init[]   =   { 1, 1, 1, 3, 7, 63, 91, 197, 417, 763, 1391, 3729, 2791, 1975, 23655, 50611, 110315, 86879, 0 };
            const std::uint32_t dim14820JoeKuoD6Init[]   =   { 1, 3, 3, 5, 31, 35, 67, 67, 89, 933, 1005, 1837, 5947, 2559, 27731, 25151, 102959, 81557, 0 };
            const std::uint32_t dim14821JoeKuoD6Init[]   =   { 1, 3, 3, 1, 3, 39, 57, 199, 87, 91, 1641, 3407, 2823, 10441, 26357, 56677, 17647, 86831, 0 };
            const std::uint32_t dim14822JoeKuoD6Init[]   =   { 1, 3, 5, 7, 15, 5, 49, 227, 395, 837, 1707, 1677, 1907, 13101, 1929, 61701, 1479, 80671, 0 };
            const std::uint32_t dim14823JoeKuoD6Init[]   =   { 1, 1, 1, 11, 17, 57, 37, 151, 61, 709, 2027, 2239, 3283, 5467, 17221, 40759, 91637, 258167, 0 };
            const std::uint32_t dim14824JoeKuoD6Init[]   =   { 1, 3, 5, 11, 27, 29, 121, 181, 503, 705, 225, 1111, 7183, 3219, 3233, 2085, 113619, 32959, 0 };
            const std::uint32_t dim14825JoeKuoD6Init[]   =   { 1, 1, 7, 5, 29, 31, 93, 113, 457, 161, 337, 2003, 1865, 13357, 19961, 51485, 62751, 111285, 0 };
            const std::uint32_t dim14826JoeKuoD6Init[]   =   { 1, 3, 1, 1, 23, 25, 65, 99, 11, 835, 661, 3291, 2655, 1135, 19957, 5029, 110483, 2499, 0 };
            const std::uint32_t dim14827JoeKuoD6Init[]   =   { 1, 1, 1, 1, 25, 21, 59, 203, 471, 697, 455, 1561, 3215, 609, 5097, 8715, 115705, 21441, 0 };
            const std::uint32_t dim14828JoeKuoD6Init[]   =   { 1, 1, 5, 13, 27, 37, 15, 175, 191, 975, 977, 401, 7053, 14291, 14621, 48989, 113033, 172569, 0 };
            const std::uint32_t dim14829JoeKuoD6Init[]   =   { 1, 3, 1, 1, 19, 11, 125, 53, 307, 421, 93, 2487, 5907, 2195, 30569, 21009, 20759, 246937, 0 };
            const std::uint32_t dim14830JoeKuoD6Init[]   =   { 1, 3, 7, 3, 23, 21, 103, 115, 453, 537, 473, 1069, 3007, 15111, 3477, 5635, 46423, 68633, 0 };
            const std::uint32_t dim14831JoeKuoD6Init[]   =   { 1, 3, 3, 1, 21, 1, 49, 197, 173, 775, 1877, 1309, 729, 3555, 5981, 32539, 22765, 171077, 0 };
            const std::uint32_t dim14832JoeKuoD6Init[]   =   { 1, 1, 3, 13, 19, 5, 75, 149, 441, 665, 1567, 2433, 8173, 12639, 27479, 47221, 66203, 89017, 0 };
            const std::uint32_t dim14833JoeKuoD6Init[]   =   { 1, 1, 1, 11, 1, 55, 99, 119, 491, 621, 619, 2521, 905, 11601, 26481, 2023, 127413, 220387, 0 };
            const std::uint32_t dim14834JoeKuoD6Init[]   =   { 1, 1, 7, 11, 9, 21, 57, 93, 243, 229, 1445, 997, 1317, 2327, 14141, 45787, 82295, 72823, 0 };
            const std::uint32_t dim14835JoeKuoD6Init[]   =   { 1, 3, 7, 3, 11, 7, 115, 143, 349, 507, 1047, 2573, 2491, 13351, 19019, 4857, 62781, 261261, 0 };
            const std::uint32_t dim14836JoeKuoD6Init[]   =   { 1, 1, 3, 1, 1, 13, 45, 227, 41, 947, 693, 2853, 7459, 1485, 22087, 61195, 111771, 136389, 0 };
            const std::uint32_t dim14837JoeKuoD6Init[]   =   { 1, 1, 3, 11, 13, 53, 49, 15, 425, 29, 681, 1493, 1385, 9555, 13291, 36735, 12351, 29293, 0 };
            const std::uint32_t dim14838JoeKuoD6Init[]   =   { 1, 1, 3, 1, 5, 19, 37, 45, 69, 209, 365, 3949, 6163, 5207, 9297, 21147, 71437, 40487, 0 };
            const std::uint32_t dim14839JoeKuoD6Init[]   =   { 1, 3, 3, 13, 31, 21, 9, 177, 95, 285, 1953, 1969, 7367, 7401, 12017, 9939, 11895, 213133, 0 };
            const std::uint32_t dim14840JoeKuoD6Init[]   =   { 1, 1, 7, 1, 1, 63, 103, 141, 39, 679, 123, 2941, 4335, 199, 12237, 6599, 48641, 140063, 0 };
            const std::uint32_t dim14841JoeKuoD6Init[]   =   { 1, 3, 7, 3, 31, 17, 21, 77, 65, 979, 109, 3325, 1781, 6983, 31477, 23149, 33943, 96137, 0 };
            const std::uint32_t dim14842JoeKuoD6Init[]   =   { 1, 3, 3, 5, 21, 5, 125, 117, 427, 381, 511, 2643, 409, 4945, 3167, 45879, 1469, 56077, 0 };
            const std::uint32_t dim14843JoeKuoD6Init[]   =   { 1, 3, 1, 5, 27, 43, 83, 31, 65, 645, 1205, 1387, 723, 15359, 13517, 23601, 61717, 47079, 0 };
            const std::uint32_t dim14844JoeKuoD6Init[]   =   { 1, 3, 3, 13, 15, 37, 101, 175, 225, 513, 483, 1291, 669, 5335, 16023, 287, 51819, 239803, 0 };
            const std::uint32_t dim14845JoeKuoD6Init[]   =   { 1, 3, 3, 3, 3, 1, 75, 175, 185, 949, 673, 2239, 4355, 10687, 27093, 37409, 23193, 211819, 0 };
            const std::uint32_t dim14846JoeKuoD6Init[]   =   { 1, 1, 3, 13, 21, 3, 41, 55, 243, 501, 285, 7, 6291, 7725, 17051, 45753, 115117, 14323, 0 };
            const std::uint32_t dim14847JoeKuoD6Init[]   =   { 1, 1, 1, 5, 13, 11, 51, 175, 435, 673, 67, 1525, 323, 5739, 19977, 62317, 97511, 130883, 0 };
            const std::uint32_t dim14848JoeKuoD6Init[]   =   { 1, 3, 5, 11, 7, 11, 97, 59, 295, 409, 453, 2439, 5217, 10315, 469, 31187, 17325, 158079, 0 };
            const std::uint32_t dim14849JoeKuoD6Init[]   =   { 1, 1, 3, 5, 31, 9, 15, 63, 411, 427, 277, 2687, 5021, 1507, 22453, 35559, 122081, 121669, 0 };
            const std::uint32_t dim14850JoeKuoD6Init[]   =   { 1, 3, 5, 13, 3, 21, 69, 51, 27, 571, 1981, 2729, 5733, 1225, 26821, 43763, 57355, 169279, 0 };
            const std::uint32_t dim14851JoeKuoD6Init[]   =   { 1, 1, 1, 13, 31, 37, 33, 19, 313, 341, 1141, 1689, 4511, 789, 15317, 61263, 79371, 65157, 0 };
            const std::uint32_t dim14852JoeKuoD6Init[]   =   { 1, 3, 3, 15, 27, 41, 107, 23, 499, 339, 273, 1937, 2743, 10879, 27127, 64817, 1217, 45863, 0 };
            const std::uint32_t dim14853JoeKuoD6Init[]   =   { 1, 1, 5, 9, 19, 43, 125, 223, 473, 489, 1999, 1513, 6479, 9511, 12503, 29419, 22559, 209499, 0 };
            const std::uint32_t dim14854JoeKuoD6Init[]   =   { 1, 3, 1, 13, 25, 55, 53, 61, 303, 337, 1325, 2525, 6503, 1155, 6841, 58167, 8175, 183949, 0 };
            const std::uint32_t dim14855JoeKuoD6Init[]   =   { 1, 3, 3, 11, 3, 15, 55, 105, 497, 527, 1007, 3545, 4187, 8723, 12761, 20751, 101583, 225373, 0 };
            const std::uint32_t dim14856JoeKuoD6Init[]   =   { 1, 3, 3, 9, 19, 59, 57, 215, 313, 871, 407, 2475, 879, 15147, 31945, 23939, 104073, 217619, 0 };
            const std::uint32_t dim14857JoeKuoD6Init[]   =   { 1, 1, 3, 1, 27, 23, 3, 43, 471, 757, 1525, 3003, 2779, 6731, 12423, 59621, 72935, 192283, 0 };
            const std::uint32_t dim14858JoeKuoD6Init[]   =   { 1, 3, 1, 7, 13, 23, 13, 91, 95, 745, 639, 2627, 4595, 11735, 4143, 23573, 98647, 171201, 0 };
            const std::uint32_t dim14859JoeKuoD6Init[]   =   { 1, 1, 1, 15, 3, 61, 33, 181, 351, 777, 1365, 1691, 2465, 5289, 24567, 8059, 95301, 75855, 0 };
            const std::uint32_t dim14860JoeKuoD6Init[]   =   { 1, 3, 5, 13, 1, 57, 57, 187, 1, 601, 563, 1703, 1307, 14673, 7793, 44589, 7629, 254071, 0 };
            const std::uint32_t dim14861JoeKuoD6Init[]   =   { 1, 1, 5, 13, 29, 17, 61, 233, 371, 909, 529, 185, 127, 15773, 19529, 49271, 26749, 70869, 0 };
            const std::uint32_t dim14862JoeKuoD6Init[]   =   { 1, 1, 3, 9, 21, 41, 37, 71, 505, 969, 301, 1667, 5879, 13187, 2461, 17301, 103673, 235133, 0 };
            const std::uint32_t dim14863JoeKuoD6Init[]   =   { 1, 3, 1, 3, 9, 13, 75, 63, 313, 273, 1061, 3821, 539, 9887, 19775, 17259, 93133, 217245, 0 };
            const std::uint32_t dim14864JoeKuoD6Init[]   =   { 1, 3, 5, 5, 21, 27, 9, 11, 461, 575, 507, 577, 4559, 9995, 13953, 61023, 121941, 195419, 0 };
            const std::uint32_t dim14865JoeKuoD6Init[]   =   { 1, 3, 3, 7, 17, 17, 45, 193, 271, 571, 1337, 2107, 1923, 4791, 23773, 60923, 58085, 81219, 0 };
            const std::uint32_t dim14866JoeKuoD6Init[]   =   { 1, 3, 1, 7, 11, 7, 85, 33, 231, 307, 993, 1509, 1427, 9545, 7919, 39775, 81145, 79139, 0 };
            const std::uint32_t dim14867JoeKuoD6Init[]   =   { 1, 3, 5, 3, 9, 57, 117, 187, 57, 719, 1635, 2499, 6747, 6649, 22643, 16429, 83233, 122057, 0 };
            const std::uint32_t dim14868JoeKuoD6Init[]   =   { 1, 1, 3, 11, 7, 39, 103, 221, 167, 181, 1355, 989, 3399, 9471, 10493, 57267, 106551, 158599, 0 };
            const std::uint32_t dim14869JoeKuoD6Init[]   =   { 1, 3, 1, 15, 23, 19, 29, 11, 355, 923, 1401, 509, 3647, 5663, 2353, 53217, 70687, 145613, 0 };
            const std::uint32_t dim14870JoeKuoD6Init[]   =   { 1, 3, 3, 11, 11, 5, 21, 107, 177, 429, 119, 1029, 5931, 7543, 15455, 62797, 118095, 35387, 0 };
            const std::uint32_t dim14871JoeKuoD6Init[]   =   { 1, 3, 5, 15, 19, 53, 17, 215, 279, 497, 1157, 2235, 5541, 5899, 20711, 20843, 113821, 164231, 0 };
            const std::uint32_t dim14872JoeKuoD6Init[]   =   { 1, 1, 1, 15, 21, 33, 67, 247, 55, 573, 1863, 2703, 5267, 4071, 18235, 44659, 102379, 171529, 0 };
            const std::uint32_t dim14873JoeKuoD6Init[]   =   { 1, 3, 1, 15, 5, 59, 69, 189, 313, 243, 339, 3097, 4999, 5909, 1903, 56143, 76209, 83073, 0 };
            const std::uint32_t dim14874JoeKuoD6Init[]   =   { 1, 3, 5, 15, 11, 41, 65, 207, 95, 115, 1203, 3731, 6845, 11173, 8281, 40623, 97119, 218455, 0 };
            const std::uint32_t dim14875JoeKuoD6Init[]   =   { 1, 3, 7, 13, 29, 57, 5, 31, 255, 539, 107, 953, 3707, 9233, 20295, 17459, 2005, 56193, 0 };
            const std::uint32_t dim14876JoeKuoD6Init[]   =   { 1, 1, 1, 15, 5, 31, 83, 165, 211, 433, 1411, 2949, 4817, 1645, 1693, 9877, 118493, 142923, 0 };
            const std::uint32_t dim14877JoeKuoD6Init[]   =   { 1, 3, 1, 11, 19, 61, 35, 21, 159, 159, 1717, 3227, 3351, 8641, 20575, 13721, 114649, 129201, 0 };
            const std::uint32_t dim14878JoeKuoD6Init[]   =   { 1, 3, 1, 13, 9, 41, 17, 7, 209, 501, 445, 23, 7911, 5867, 30129, 643, 36363, 52037, 0 };
            const std::uint32_t dim14879JoeKuoD6Init[]   =   { 1, 3, 5, 11, 31, 55, 27, 81, 413, 167, 599, 2231, 7055, 4013, 26729, 63927, 12075, 208123, 0 };
            const std::uint32_t dim14880JoeKuoD6Init[]   =   { 1, 1, 7, 9, 11, 39, 99, 187, 169, 999, 609, 3647, 2497, 8969, 30919, 29145, 67699, 51601, 0 };
            const std::uint32_t dim14881JoeKuoD6Init[]   =   { 1, 3, 1, 1, 11, 11, 69, 29, 197, 979, 1135, 869, 5435, 5151, 26349, 55911, 68051, 131849, 0 };
            const std::uint32_t dim14882JoeKuoD6Init[]   =   { 1, 1, 1, 5, 27, 1, 85, 145, 439, 585, 1713, 677, 1833, 14139, 5547, 31265, 82223, 47605, 0 };
            const std::uint32_t dim14883JoeKuoD6Init[]   =   { 1, 3, 5, 9, 17, 23, 31, 199, 447, 551, 683, 2977, 7839, 8681, 15923, 61057, 89875, 52945, 0 };
            const std::uint32_t dim14884JoeKuoD6Init[]   =   { 1, 1, 3, 11, 9, 17, 29, 125, 195, 123, 1259, 2729, 3099, 2229, 9683, 13121, 105399, 111833, 0 };
            const std::uint32_t dim14885JoeKuoD6Init[]   =   { 1, 3, 1, 3, 1, 47, 93, 117, 461, 633, 1641, 933, 7927, 13569, 483, 28159, 121561, 164325, 0 };
            const std::uint32_t dim14886JoeKuoD6Init[]   =   { 1, 3, 1, 5, 21, 19, 79, 183, 395, 23, 767, 519, 4857, 10385, 12425, 26207, 114623, 37125, 0 };
            const std::uint32_t dim14887JoeKuoD6Init[]   =   { 1, 1, 5, 5, 9, 47, 67, 217, 499, 843, 1539, 301, 1485, 3157, 22375, 47199, 26215, 182785, 0 };
            const std::uint32_t dim14888JoeKuoD6Init[]   =   { 1, 1, 1, 13, 9, 37, 87, 49, 445, 681, 1097, 1049, 4093, 13167, 18447, 58243, 41797, 217929, 0 };
            const std::uint32_t dim14889JoeKuoD6Init[]   =   { 1, 1, 5, 13, 13, 49, 21, 149, 79, 113, 1217, 921, 6321, 9345, 27987, 21723, 49249, 18813, 0 };
            const std::uint32_t dim14890JoeKuoD6Init[]   =   { 1, 3, 1, 3, 15, 27, 67, 69, 131, 713, 1741, 1955, 5665, 8749, 11971, 11257, 13999, 124535, 0 };
            const std::uint32_t dim14891JoeKuoD6Init[]   =   { 1, 3, 1, 3, 3, 11, 21, 167, 441, 557, 593, 3261, 3099, 2801, 21725, 23247, 106891, 129187, 0 };
            const std::uint32_t dim14892JoeKuoD6Init[]   =   { 1, 1, 1, 11, 5, 55, 33, 71, 505, 85, 1609, 521, 5459, 12777, 13007, 255, 67537, 2877, 0 };
            const std::uint32_t dim14893JoeKuoD6Init[]   =   { 1, 1, 1, 3, 31, 47, 49, 119, 351, 797, 1407, 4089, 2381, 12409, 12849, 23489, 53631, 119387, 0 };
            const std::uint32_t dim14894JoeKuoD6Init[]   =   { 1, 3, 5, 11, 25, 11, 25, 185, 85, 849, 141, 385, 3663, 13133, 8451, 61463, 35129, 149933, 0 };
            const std::uint32_t dim14895JoeKuoD6Init[]   =   { 1, 3, 7, 9, 23, 17, 21, 197, 15, 893, 939, 707, 5491, 7249, 14009, 18973, 111545, 36809, 0 };
            const std::uint32_t dim14896JoeKuoD6Init[]   =   { 1, 3, 3, 13, 23, 15, 19, 193, 223, 627, 1529, 1963, 1003, 7199, 15361, 25233, 110281, 221761, 0 };
            const std::uint32_t dim14897JoeKuoD6Init[]   =   { 1, 3, 3, 1, 17, 51, 61, 215, 311, 919, 349, 59, 2897, 12137, 5931, 37611, 124387, 83503, 0 };
            const std::uint32_t dim14898JoeKuoD6Init[]   =   { 1, 3, 7, 9, 13, 47, 53, 139, 481, 733, 389, 1209, 3281, 593, 29103, 61521, 41445, 11015, 0 };
            const std::uint32_t dim14899JoeKuoD6Init[]   =   { 1, 1, 1, 13, 3, 31, 19, 47, 151, 883, 1707, 827, 2129, 4333, 871, 42967, 79701, 192211, 0 };
            const std::uint32_t dim14900JoeKuoD6Init[]   =   { 1, 3, 3, 11, 11, 51, 121, 241, 199, 881, 1493, 2381, 5161, 13287, 8155, 52481, 120307, 206203, 0 };
            const std::uint32_t dim14901JoeKuoD6Init[]   =   { 1, 1, 1, 13, 15, 37, 27, 151, 17, 851, 1343, 1447, 43, 10267, 18267, 21347, 129277, 83987, 0 };
            const std::uint32_t dim14902JoeKuoD6Init[]   =   { 1, 1, 3, 3, 13, 17, 53, 217, 253, 853, 1461, 1953, 617, 4209, 9925, 377, 42789, 150415, 0 };
            const std::uint32_t dim14903JoeKuoD6Init[]   =   { 1, 3, 7, 11, 13, 23, 83, 235, 39, 701, 1091, 25, 1807, 15431, 2169, 5339, 123679, 117053, 0 };
            const std::uint32_t dim14904JoeKuoD6Init[]   =   { 1, 3, 7, 13, 3, 29, 43, 149, 33, 873, 1177, 1961, 7943, 11317, 30725, 55765, 50929, 12335, 0 };
            const std::uint32_t dim14905JoeKuoD6Init[]   =   { 1, 1, 3, 5, 25, 1, 91, 121, 295, 25, 1743, 2125, 2643, 11175, 15089, 44979, 28355, 543, 0 };
            const std::uint32_t dim14906JoeKuoD6Init[]   =   { 1, 1, 1, 13, 27, 27, 43, 195, 377, 821, 437, 3445, 2673, 15221, 15101, 25143, 22347, 218549, 0 };
            const std::uint32_t dim14907JoeKuoD6Init[]   =   { 1, 1, 3, 7, 9, 51, 121, 231, 91, 913, 1325, 167, 8067, 8119, 9307, 33551, 58069, 170567, 0 };
            const std::uint32_t dim14908JoeKuoD6Init[]   =   { 1, 3, 7, 7, 15, 7, 85, 51, 11, 353, 1117, 2479, 3091, 2377, 23589, 38537, 113047, 261285, 0 };
            const std::uint32_t dim14909JoeKuoD6Init[]   =   { 1, 1, 3, 5, 15, 33, 61, 145, 147, 815, 767, 9, 2059, 11463, 1883, 8565, 101043, 117565, 0 };
            const std::uint32_t dim14910JoeKuoD6Init[]   =   { 1, 3, 5, 3, 5, 49, 5, 33, 15, 13, 895, 3973, 7963, 3831, 26817, 10799, 111409, 90679, 0 };
            const std::uint32_t dim14911JoeKuoD6Init[]   =   { 1, 1, 5, 7, 5, 51, 35, 237, 217, 531, 719, 2711, 1937, 16071, 23233, 22799, 66023, 145739, 0 };
            const std::uint32_t dim14912JoeKuoD6Init[]   =   { 1, 3, 5, 1, 5, 63, 1, 163, 9, 697, 1379, 2989, 7113, 9821, 15941, 6495, 7825, 29715, 0 };
            const std::uint32_t dim14913JoeKuoD6Init[]   =   { 1, 3, 5, 7, 9, 41, 113, 173, 151, 963, 2019, 3531, 1133, 4287, 16917, 16929, 12345, 31201, 0 };
            const std::uint32_t dim14914JoeKuoD6Init[]   =   { 1, 3, 7, 1, 25, 9, 5, 195, 175, 297, 717, 3725, 33, 5155, 4405, 56171, 105597, 132407, 0 };
            const std::uint32_t dim14915JoeKuoD6Init[]   =   { 1, 1, 7, 7, 3, 59, 115, 95, 227, 951, 843, 619, 7791, 10981, 11773, 57651, 108391, 179561, 0 };
            const std::uint32_t dim14916JoeKuoD6Init[]   =   { 1, 3, 3, 1, 9, 3, 59, 161, 417, 413, 1933, 1027, 4575, 10427, 15643, 16049, 120089, 176607, 0 };
            const std::uint32_t dim14917JoeKuoD6Init[]   =   { 1, 3, 3, 3, 15, 1, 83, 195, 59, 859, 1669, 1063, 2069, 15875, 16459, 53741, 114521, 37641, 0 };
            const std::uint32_t dim14918JoeKuoD6Init[]   =   { 1, 1, 1, 11, 11, 45, 47, 143, 11, 239, 1329, 865, 2693, 899, 26265, 43255, 125679, 130099, 0 };
            const std::uint32_t dim14919JoeKuoD6Init[]   =   { 1, 3, 5, 3, 31, 51, 95, 127, 79, 167, 117, 3177, 5875, 14039, 20341, 47815, 118799, 211871, 0 };
            const std::uint32_t dim14920JoeKuoD6Init[]   =   { 1, 1, 1, 1, 3, 21, 65, 203, 11, 565, 537, 1307, 8189, 11423, 7745, 56117, 110959, 95361, 0 };
            const std::uint32_t dim14921JoeKuoD6Init[]   =   { 1, 1, 7, 7, 21, 63, 63, 231, 441, 127, 1943, 13, 4813, 10607, 23867, 43891, 15801, 173245, 0 };
            const std::uint32_t dim14922JoeKuoD6Init[]   =   { 1, 3, 3, 5, 25, 23, 123, 133, 129, 303, 1993, 1453, 1109, 4649, 30315, 62399, 121575, 60069, 0 };
            const std::uint32_t dim14923JoeKuoD6Init[]   =   { 1, 3, 5, 3, 29, 23, 69, 141, 137, 1017, 1915, 35, 3817, 6249, 22427, 7281, 88473, 230167, 0 };
            const std::uint32_t dim14924JoeKuoD6Init[]   =   { 1, 3, 7, 7, 19, 37, 93, 217, 287, 731, 583, 3377, 2879, 4873, 5549, 52949, 127285, 211173, 0 };
            const std::uint32_t dim14925JoeKuoD6Init[]   =   { 1, 1, 5, 7, 23, 41, 49, 145, 277, 571, 1225, 455, 2133, 1229, 25421, 20179, 70919, 242825, 0 };
            const std::uint32_t dim14926JoeKuoD6Init[]   =   { 1, 3, 5, 5, 29, 3, 1, 89, 413, 901, 1343, 3963, 6969, 14649, 18331, 4573, 82077, 100693, 0 };
            const std::uint32_t dim14927JoeKuoD6Init[]   =   { 1, 1, 1, 13, 31, 53, 107, 95, 151, 539, 1593, 3763, 1007, 8959, 25235, 16461, 121819, 106143, 0 };
            const std::uint32_t dim14928JoeKuoD6Init[]   =   { 1, 1, 1, 3, 11, 15, 5, 157, 347, 81, 2013, 2025, 6541, 12287, 1315, 23285, 23539, 75027, 0 };
            const std::uint32_t dim14929JoeKuoD6Init[]   =   { 1, 1, 5, 7, 17, 11, 65, 157, 93, 607, 1445, 4089, 3139, 4699, 1225, 58935, 93673, 146467, 0 };
            const std::uint32_t dim14930JoeKuoD6Init[]   =   { 1, 3, 3, 13, 29, 59, 69, 141, 257, 463, 93, 649, 8179, 15205, 6943, 45317, 31269, 70825, 0 };
            const std::uint32_t dim14931JoeKuoD6Init[]   =   { 1, 3, 5, 9, 23, 39, 113, 61, 315, 463, 1739, 149, 6007, 2789, 12021, 969, 18551, 153669, 0 };
            const std::uint32_t dim14932JoeKuoD6Init[]   =   { 1, 1, 3, 15, 19, 9, 23, 211, 265, 877, 325, 2635, 8131, 4957, 24371, 60975, 3887, 198927, 0 };
            const std::uint32_t dim14933JoeKuoD6Init[]   =   { 1, 1, 3, 11, 29, 31, 5, 105, 157, 573, 2009, 1701, 1549, 1641, 17429, 13587, 48421, 8675, 0 };
            const std::uint32_t dim14934JoeKuoD6Init[]   =   { 1, 1, 5, 13, 3, 13, 17, 55, 101, 369, 705, 3635, 5195, 10439, 12881, 21565, 1671, 75489, 0 };
            const std::uint32_t dim14935JoeKuoD6Init[]   =   { 1, 3, 3, 1, 1, 23, 85, 189, 347, 205, 5, 3465, 3269, 3347, 10163, 26921, 86555, 9387, 0 };
            const std::uint32_t dim14936JoeKuoD6Init[]   =   { 1, 3, 7, 15, 27, 21, 79, 151, 279, 627, 1093, 1929, 5549, 12141, 5245, 55747, 65939, 193759, 0 };
            const std::uint32_t dim14937JoeKuoD6Init[]   =   { 1, 1, 1, 5, 5, 23, 57, 235, 143, 129, 795, 35, 4375, 12577, 871, 20879, 82811, 52279, 0 };
            const std::uint32_t dim14938JoeKuoD6Init[]   =   { 1, 3, 1, 5, 11, 1, 125, 99, 89, 629, 857, 2631, 393, 15075, 27473, 42695, 61505, 239651, 0 };
            const std::uint32_t dim14939JoeKuoD6Init[]   =   { 1, 1, 5, 1, 9, 11, 55, 203, 453, 677, 259, 1979, 4101, 16067, 26783, 17907, 75349, 62797, 0 };
            const std::uint32_t dim14940JoeKuoD6Init[]   =   { 1, 3, 7, 5, 5, 19, 85, 165, 341, 405, 1779, 87, 889, 265, 9851, 36175, 69697, 123769, 0 };
            const std::uint32_t dim14941JoeKuoD6Init[]   =   { 1, 3, 7, 1, 7, 49, 93, 57, 85, 597, 183, 3253, 6301, 9307, 8753, 38133, 58743, 19621, 0 };
            const std::uint32_t dim14942JoeKuoD6Init[]   =   { 1, 1, 3, 9, 1, 15, 125, 215, 391, 141, 87, 37, 4333, 5033, 30549, 64281, 18577, 156093, 0 };
            const std::uint32_t dim14943JoeKuoD6Init[]   =   { 1, 3, 3, 15, 17, 25, 29, 81, 339, 865, 1619, 773, 901, 8163, 22275, 57159, 119951, 137451, 0 };
            const std::uint32_t dim14944JoeKuoD6Init[]   =   { 1, 3, 5, 15, 7, 57, 113, 221, 13, 49, 1653, 3695, 4423, 4383, 28669, 64175, 130355, 202543, 0 };
            const std::uint32_t dim14945JoeKuoD6Init[]   =   { 1, 1, 3, 9, 29, 21, 19, 119, 409, 717, 1853, 3981, 4489, 3985, 31205, 10423, 13223, 131973, 0 };
            const std::uint32_t dim14946JoeKuoD6Init[]   =   { 1, 1, 3, 15, 29, 7, 1, 85, 133, 345, 317, 2363, 7803, 4975, 19441, 10497, 42059, 131531, 0 };
            const std::uint32_t dim14947JoeKuoD6Init[]   =   { 1, 1, 7, 13, 3, 53, 49, 27, 487, 901, 801, 335, 6317, 14205, 26655, 52747, 102659, 231359, 0 };
            const std::uint32_t dim14948JoeKuoD6Init[]   =   { 1, 3, 3, 3, 13, 33, 113, 107, 407, 499, 903, 3059, 1343, 11859, 6315, 23071, 73627, 44239, 0 };
            const std::uint32_t dim14949JoeKuoD6Init[]   =   { 1, 3, 5, 15, 1, 53, 59, 247, 213, 981, 443, 3, 615, 12067, 3881, 61759, 101219, 110407, 0 };
            const std::uint32_t dim14950JoeKuoD6Init[]   =   { 1, 3, 5, 13, 7, 31, 87, 161, 61, 1023, 147, 2075, 7245, 9025, 7229, 60935, 104481, 169561, 0 };
            const std::uint32_t dim14951JoeKuoD6Init[]   =   { 1, 3, 1, 15, 25, 17, 53, 107, 311, 621, 1493, 2443, 4635, 12163, 12543, 43031, 90843, 139645, 0 };
            const std::uint32_t dim14952JoeKuoD6Init[]   =   { 1, 3, 5, 11, 7, 49, 91, 165, 91, 329, 493, 3533, 7429, 7047, 14767, 31641, 62005, 77267, 0 };
            const std::uint32_t dim14953JoeKuoD6Init[]   =   { 1, 1, 3, 9, 31, 21, 19, 167, 185, 199, 1989, 1093, 4213, 4769, 21659, 19685, 122123, 215233, 0 };
            const std::uint32_t dim14954JoeKuoD6Init[]   =   { 1, 3, 3, 7, 27, 23, 99, 205, 365, 689, 1281, 419, 4207, 5355, 20245, 25029, 123029, 61499, 0 };
            const std::uint32_t dim14955JoeKuoD6Init[]   =   { 1, 3, 3, 7, 19, 15, 29, 185, 165, 203, 1859, 2895, 6361, 6331, 13641, 42577, 33757, 41305, 0 };
            const std::uint32_t dim14956JoeKuoD6Init[]   =   { 1, 3, 5, 11, 21, 43, 15, 11, 425, 125, 1597, 1109, 3335, 7009, 20799, 41261, 127813, 181261, 0 };
            const std::uint32_t dim14957JoeKuoD6Init[]   =   { 1, 1, 5, 5, 27, 35, 35, 159, 111, 1011, 1487, 813, 4985, 2555, 23741, 44675, 97159, 250477, 0 };
            const std::uint32_t dim14958JoeKuoD6Init[]   =   { 1, 3, 3, 7, 17, 41, 81, 187, 367, 767, 1345, 205, 5797, 9129, 21973, 39911, 130131, 96891, 0 };
            const std::uint32_t dim14959JoeKuoD6Init[]   =   { 1, 3, 5, 1, 1, 47, 57, 177, 127, 791, 1427, 1895, 5995, 12569, 32711, 58599, 55641, 80405, 0 };
            const std::uint32_t dim14960JoeKuoD6Init[]   =   { 1, 3, 3, 1, 23, 13, 115, 81, 511, 677, 775, 3143, 4963, 7093, 15963, 59893, 22609, 137601, 0 };
            const std::uint32_t dim14961JoeKuoD6Init[]   =   { 1, 1, 5, 9, 17, 17, 115, 127, 397, 139, 1171, 207, 3485, 15869, 465, 26267, 29957, 205459, 0 };
            const std::uint32_t dim14962JoeKuoD6Init[]   =   { 1, 3, 7, 3, 9, 29, 23, 189, 447, 481, 753, 2415, 2669, 6007, 15201, 7317, 18861, 173759, 0 };
            const std::uint32_t dim14963JoeKuoD6Init[]   =   { 1, 3, 5, 7, 13, 43, 13, 163, 363, 683, 1869, 1237, 2523, 3661, 13887, 5593, 91513, 220177, 0 };
            const std::uint32_t dim14964JoeKuoD6Init[]   =   { 1, 1, 1, 11, 7, 11, 43, 39, 319, 793, 375, 3159, 7621, 8965, 25743, 351, 31873, 18115, 0 };
            const std::uint32_t dim14965JoeKuoD6Init[]   =   { 1, 1, 5, 5, 11, 57, 79, 147, 55, 553, 417, 1365, 3979, 9789, 22677, 58645, 104549, 9019, 0 };
            const std::uint32_t dim14966JoeKuoD6Init[]   =   { 1, 1, 3, 11, 17, 37, 127, 5, 165, 867, 79, 2259, 197, 4789, 28109, 46721, 3431, 118939, 0 };
            const std::uint32_t dim14967JoeKuoD6Init[]   =   { 1, 1, 5, 13, 19, 45, 113, 11, 125, 351, 1753, 3201, 1697, 2567, 9717, 22247, 84309, 248583, 0 };
            const std::uint32_t dim14968JoeKuoD6Init[]   =   { 1, 1, 5, 9, 5, 37, 65, 47, 261, 855, 1573, 2267, 7977, 13029, 32527, 59805, 103591, 180041, 0 };
            const std::uint32_t dim14969JoeKuoD6Init[]   =   { 1, 3, 3, 9, 31, 5, 115, 159, 111, 899, 1907, 2671, 1575, 7021, 10281, 34905, 641, 63549, 0 };
            const std::uint32_t dim14970JoeKuoD6Init[]   =   { 1, 3, 5, 1, 17, 61, 45, 9, 375, 761, 117, 1767, 4657, 12217, 12067, 42807, 118587, 72715, 0 };
            const std::uint32_t dim14971JoeKuoD6Init[]   =   { 1, 1, 1, 13, 3, 3, 93, 3, 351, 97, 119, 1743, 81, 12761, 22529, 47191, 111315, 256501, 0 };
            const std::uint32_t dim14972JoeKuoD6Init[]   =   { 1, 1, 5, 7, 29, 23, 41, 9, 231, 567, 1565, 3539, 7241, 11535, 7375, 10391, 127045, 9371, 0 };
            const std::uint32_t dim14973JoeKuoD6Init[]   =   { 1, 1, 1, 15, 23, 47, 39, 57, 73, 809, 513, 3233, 8071, 8595, 13817, 821, 89091, 107173, 0 };
            const std::uint32_t dim14974JoeKuoD6Init[]   =   { 1, 1, 1, 13, 13, 43, 75, 239, 487, 175, 1561, 3925, 3743, 14247, 15713, 55005, 116135, 199827, 0 };
            const std::uint32_t dim14975JoeKuoD6Init[]   =   { 1, 1, 3, 7, 13, 15, 67, 147, 77, 241, 1763, 651, 1107, 4943, 15651, 23259, 45931, 34717, 0 };
            const std::uint32_t dim14976JoeKuoD6Init[]   =   { 1, 1, 3, 5, 15, 15, 67, 153, 163, 179, 1567, 685, 3245, 2205, 8373, 56567, 32091, 23313, 0 };
            const std::uint32_t dim14977JoeKuoD6Init[]   =   { 1, 1, 7, 9, 1, 27, 79, 209, 263, 517, 635, 3, 103, 2173, 22659, 11319, 103757, 144449, 0 };
            const std::uint32_t dim14978JoeKuoD6Init[]   =   { 1, 1, 1, 5, 11, 63, 21, 89, 443, 775, 327, 1559, 1421, 2309, 18597, 46385, 16547, 186813, 0 };
            const std::uint32_t dim14979JoeKuoD6Init[]   =   { 1, 1, 7, 9, 27, 37, 43, 7, 305, 117, 1103, 1801, 3349, 12225, 28215, 8857, 118677, 88909, 0 };
            const std::uint32_t dim14980JoeKuoD6Init[]   =   { 1, 3, 3, 7, 15, 59, 21, 19, 371, 81, 755, 1565, 4823, 16363, 20301, 33571, 74423, 177205, 0 };
            const std::uint32_t dim14981JoeKuoD6Init[]   =   { 1, 1, 3, 9, 15, 33, 23, 31, 171, 713, 271, 2437, 3609, 4271, 24355, 46283, 121767, 188501, 0 };
            const std::uint32_t dim14982JoeKuoD6Init[]   =   { 1, 1, 1, 1, 21, 3, 3, 241, 339, 211, 443, 1577, 343, 2625, 1077, 29933, 106401, 51439, 0 };
            const std::uint32_t dim14983JoeKuoD6Init[]   =   { 1, 3, 5, 15, 13, 31, 11, 167, 15, 101, 373, 2095, 3017, 1347, 15029, 6579, 21233, 87589, 0 };
            const std::uint32_t dim14984JoeKuoD6Init[]   =   { 1, 3, 1, 3, 15, 1, 61, 239, 13, 867, 1621, 2275, 5757, 8275, 7923, 44469, 113513, 84927, 0 };
            const std::uint32_t dim14985JoeKuoD6Init[]   =   { 1, 1, 1, 13, 23, 27, 101, 25, 459, 517, 127, 1131, 669, 13209, 23671, 3379, 66091, 72919, 0 };
            const std::uint32_t dim14986JoeKuoD6Init[]   =   { 1, 3, 5, 7, 29, 53, 25, 185, 101, 707, 281, 183, 2823, 7241, 3127, 48093, 20195, 208349, 0 };
            const std::uint32_t dim14987JoeKuoD6Init[]   =   { 1, 3, 3, 15, 31, 11, 3, 165, 453, 609, 1053, 3937, 1989, 13887, 13415, 8005, 103537, 17853, 0 };
            const std::uint32_t dim14988JoeKuoD6Init[]   =   { 1, 1, 3, 7, 3, 41, 13, 67, 227, 265, 767, 391, 1835, 8827, 13131, 42605, 117089, 12475, 0 };
            const std::uint32_t dim14989JoeKuoD6Init[]   =   { 1, 1, 7, 3, 15, 31, 45, 157, 261, 207, 1109, 1587, 5389, 13239, 31697, 35969, 79839, 209633, 0 };
            const std::uint32_t dim14990JoeKuoD6Init[]   =   { 1, 1, 5, 9, 31, 3, 35, 187, 5, 945, 633, 2645, 171, 2221, 18369, 41765, 82373, 8007, 0 };
            const std::uint32_t dim14991JoeKuoD6Init[]   =   { 1, 1, 7, 7, 3, 57, 73, 103, 245, 811, 1637, 101, 6335, 9911, 663, 21779, 31681, 119141, 0 };
            const std::uint32_t dim14992JoeKuoD6Init[]   =   { 1, 1, 5, 13, 27, 25, 5, 203, 183, 251, 1803, 665, 6295, 965, 5269, 379, 78455, 7097, 0 };
            const std::uint32_t dim14993JoeKuoD6Init[]   =   { 1, 1, 5, 3, 19, 55, 45, 161, 481, 737, 1903, 1093, 3313, 4427, 7959, 6231, 94769, 123827, 0 };
            const std::uint32_t dim14994JoeKuoD6Init[]   =   { 1, 1, 7, 11, 29, 41, 77, 165, 49, 875, 137, 2003, 8093, 1941, 25979, 10765, 99241, 71275, 0 };
            const std::uint32_t dim14995JoeKuoD6Init[]   =   { 1, 3, 5, 3, 23, 1, 89, 163, 293, 701, 29, 2543, 4487, 14873, 28123, 48643, 31633, 74179, 0 };
            const std::uint32_t dim14996JoeKuoD6Init[]   =   { 1, 1, 7, 1, 13, 33, 33, 173, 111, 959, 205, 1633, 3127, 3963, 6455, 41809, 60655, 247121, 0 };
            const std::uint32_t dim14997JoeKuoD6Init[]   =   { 1, 3, 5, 13, 1, 49, 87, 217, 381, 125, 823, 837, 3967, 8157, 11097, 35721, 93591, 3939, 0 };
            const std::uint32_t dim14998JoeKuoD6Init[]   =   { 1, 3, 7, 1, 7, 27, 29, 21, 295, 127, 823, 2409, 1873, 2417, 27961, 39211, 14785, 71557, 0 };
            const std::uint32_t dim14999JoeKuoD6Init[]   =   { 1, 3, 1, 5, 31, 59, 43, 121, 217, 417, 2029, 3983, 5629, 10447, 1073, 57515, 58849, 178927, 0 };
            const std::uint32_t dim15000JoeKuoD6Init[]   =   { 1, 3, 3, 11, 5, 59, 45, 39, 269, 483, 757, 3245, 4383, 11127, 26535, 17395, 60953, 259333, 0 };
            const std::uint32_t dim15001JoeKuoD6Init[]   =   { 1, 1, 1, 5, 5, 49, 81, 241, 371, 353, 1293, 3375, 6725, 11891, 5973, 13901, 37999, 17751, 0 };
            const std::uint32_t dim15002JoeKuoD6Init[]   =   { 1, 3, 3, 7, 31, 21, 45, 107, 33, 911, 1869, 2643, 2655, 3979, 5509, 33065, 128463, 246937, 0 };
            const std::uint32_t dim15003JoeKuoD6Init[]   =   { 1, 1, 1, 1, 31, 33, 99, 29, 485, 11, 1423, 1775, 2045, 741, 30691, 53957, 13891, 57303, 0 };
            const std::uint32_t dim15004JoeKuoD6Init[]   =   { 1, 1, 7, 13, 7, 37, 117, 121, 51, 743, 887, 1769, 1049, 12859, 1663, 27763, 90969, 38935, 0 };
            const std::uint32_t dim15005JoeKuoD6Init[]   =   { 1, 3, 5, 7, 3, 41, 121, 89, 461, 979, 457, 2973, 8109, 13819, 30237, 54671, 66967, 135233, 0 };
            const std::uint32_t dim15006JoeKuoD6Init[]   =   { 1, 1, 7, 13, 13, 47, 51, 121, 295, 847, 681, 1163, 8123, 14179, 26561, 54057, 74043, 146155, 0 };
            const std::uint32_t dim15007JoeKuoD6Init[]   =   { 1, 3, 3, 11, 21, 15, 9, 85, 445, 11, 1525, 3165, 5929, 12481, 10769, 31885, 51487, 248933, 0 };
            const std::uint32_t dim15008JoeKuoD6Init[]   =   { 1, 3, 1, 9, 25, 41, 59, 139, 293, 1021, 2043, 967, 3949, 7309, 6545, 62761, 37761, 22395, 0 };
            const std::uint32_t dim15009JoeKuoD6Init[]   =   { 1, 3, 7, 15, 25, 45, 29, 75, 283, 845, 687, 3285, 7263, 10237, 5343, 58635, 85137, 2387, 0 };
            const std::uint32_t dim15010JoeKuoD6Init[]   =   { 1, 1, 3, 15, 29, 33, 111, 175, 251, 181, 709, 1373, 1661, 1155, 30479, 57823, 28809, 74117, 0 };
            const std::uint32_t dim15011JoeKuoD6Init[]   =   { 1, 3, 3, 5, 11, 37, 55, 155, 439, 173, 1861, 1713, 1675, 12119, 12531, 50995, 124657, 58321, 0 };
            const std::uint32_t dim15012JoeKuoD6Init[]   =   { 1, 1, 5, 13, 1, 23, 27, 141, 3, 985, 1439, 781, 7381, 2223, 26673, 46607, 54953, 24547, 0 };
            const std::uint32_t dim15013JoeKuoD6Init[]   =   { 1, 1, 5, 7, 5, 3, 41, 115, 503, 731, 633, 3631, 3455, 15937, 22639, 41163, 65243, 233749, 0 };
            const std::uint32_t dim15014JoeKuoD6Init[]   =   { 1, 3, 1, 1, 5, 57, 89, 35, 53, 653, 1763, 1247, 6999, 1811, 28191, 52327, 129421, 191093, 0 };
            const std::uint32_t dim15015JoeKuoD6Init[]   =   { 1, 3, 3, 9, 3, 27, 107, 13, 475, 409, 1623, 483, 3127, 12841, 4777, 36157, 24967, 89795, 0 };
            const std::uint32_t dim15016JoeKuoD6Init[]   =   { 1, 1, 3, 5, 7, 29, 15, 225, 257, 923, 251, 21, 4559, 3571, 9351, 1739, 37393, 170789, 0 };
            const std::uint32_t dim15017JoeKuoD6Init[]   =   { 1, 3, 7, 5, 11, 7, 107, 237, 343, 665, 767, 2293, 4781, 4811, 11227, 25045, 3951, 44307, 0 };
            const std::uint32_t dim15018JoeKuoD6Init[]   =   { 1, 3, 7, 7, 13, 31, 47, 9, 121, 441, 1011, 2015, 8053, 355, 13441, 23213, 60675, 259761, 0 };
            const std::uint32_t dim15019JoeKuoD6Init[]   =   { 1, 1, 5, 9, 21, 61, 85, 141, 271, 577, 17, 243, 3049, 2479, 28947, 53351, 67379, 211133, 0 };
            const std::uint32_t dim15020JoeKuoD6Init[]   =   { 1, 1, 1, 15, 23, 1, 119, 141, 311, 543, 1463, 3633, 8111, 9439, 4147, 64913, 28261, 197217, 0 };
            const std::uint32_t dim15021JoeKuoD6Init[]   =   { 1, 3, 1, 15, 15, 33, 125, 231, 225, 797, 605, 259, 3673, 10423, 7541, 26289, 61681, 136463, 0 };
            const std::uint32_t dim15022JoeKuoD6Init[]   =   { 1, 3, 1, 13, 23, 15, 15, 151, 289, 657, 1883, 2923, 6861, 1411, 17159, 9353, 79463, 135813, 0 };
            const std::uint32_t dim15023JoeKuoD6Init[]   =   { 1, 3, 7, 11, 5, 59, 101, 167, 291, 63, 753, 1105, 8173, 2389, 22097, 7207, 110377, 15797, 0 };
            const std::uint32_t dim15024JoeKuoD6Init[]   =   { 1, 3, 7, 15, 7, 9, 7, 135, 303, 675, 1803, 2827, 1711, 9543, 16567, 24075, 17065, 22193, 0 };
            const std::uint32_t dim15025JoeKuoD6Init[]   =   { 1, 3, 5, 7, 17, 7, 125, 57, 423, 733, 1813, 4031, 713, 10687, 27315, 37599, 78807, 103429, 0 };
            const std::uint32_t dim15026JoeKuoD6Init[]   =   { 1, 1, 5, 15, 21, 11, 87, 21, 415, 571, 1169, 2561, 7071, 12499, 195, 20111, 116757, 157731, 0 };
            const std::uint32_t dim15027JoeKuoD6Init[]   =   { 1, 3, 3, 15, 7, 33, 11, 241, 23, 189, 599, 2891, 2829, 13327, 21777, 57733, 38583, 162161, 0 };
            const std::uint32_t dim15028JoeKuoD6Init[]   =   { 1, 1, 1, 15, 3, 49, 7, 143, 291, 301, 1439, 793, 3447, 1167, 2815, 24875, 117437, 112561, 0 };
            const std::uint32_t dim15029JoeKuoD6Init[]   =   { 1, 3, 5, 13, 29, 11, 51, 255, 365, 741, 1919, 2091, 2865, 12721, 4329, 37281, 128703, 739, 0 };
            const std::uint32_t dim15030JoeKuoD6Init[]   =   { 1, 1, 1, 13, 19, 31, 39, 141, 81, 133, 297, 3837, 7537, 16043, 11755, 10289, 74399, 95371, 0 };
            const std::uint32_t dim15031JoeKuoD6Init[]   =   { 1, 1, 7, 5, 21, 35, 125, 109, 241, 217, 1219, 2617, 1925, 9573, 19305, 44689, 89365, 248869, 0 };
            const std::uint32_t dim15032JoeKuoD6Init[]   =   { 1, 3, 5, 5, 13, 33, 43, 221, 325, 267, 837, 809, 6025, 9847, 9267, 13465, 45937, 204339, 0 };
            const std::uint32_t dim15033JoeKuoD6Init[]   =   { 1, 3, 1, 3, 25, 53, 85, 249, 105, 619, 917, 1213, 5365, 6197, 22929, 27529, 71011, 141651, 0 };
            const std::uint32_t dim15034JoeKuoD6Init[]   =   { 1, 1, 5, 1, 29, 9, 27, 161, 269, 775, 1043, 303, 4503, 5059, 479, 17237, 51383, 152495, 0 };
            const std::uint32_t dim15035JoeKuoD6Init[]   =   { 1, 3, 1, 5, 19, 5, 127, 139, 1, 461, 943, 593, 7457, 3357, 1909, 64633, 91811, 92703, 0 };
            const std::uint32_t dim15036JoeKuoD6Init[]   =   { 1, 1, 5, 7, 1, 21, 83, 29, 123, 83, 1085, 2727, 651, 15801, 20561, 34821, 17671, 162227, 0 };
            const std::uint32_t dim15037JoeKuoD6Init[]   =   { 1, 3, 7, 1, 19, 59, 33, 195, 81, 69, 51, 1473, 3873, 4247, 3587, 4293, 30831, 245345, 0 };
            const std::uint32_t dim15038JoeKuoD6Init[]   =   { 1, 3, 1, 3, 23, 27, 19, 115, 275, 293, 705, 131, 1001, 8881, 30165, 25149, 38679, 175167, 0 };
            const std::uint32_t dim15039JoeKuoD6Init[]   =   { 1, 1, 3, 15, 11, 11, 79, 55, 323, 217, 859, 897, 6567, 12529, 3161, 13009, 100787, 3501, 0 };
            const std::uint32_t dim15040JoeKuoD6Init[]   =   { 1, 3, 1, 15, 17, 63, 51, 71, 55, 207, 1095, 2527, 611, 9281, 7375, 14553, 16021, 88537, 0 };
            const std::uint32_t dim15041JoeKuoD6Init[]   =   { 1, 1, 7, 9, 11, 23, 95, 25, 327, 873, 575, 3583, 6587, 137, 23737, 59341, 83281, 93541, 0 };
            const std::uint32_t dim15042JoeKuoD6Init[]   =   { 1, 1, 5, 7, 15, 37, 89, 105, 471, 757, 103, 3747, 3565, 4957, 23537, 16193, 84843, 256757, 0 };
            const std::uint32_t dim15043JoeKuoD6Init[]   =   { 1, 3, 5, 1, 15, 17, 119, 231, 387, 715, 797, 3807, 4985, 8335, 4885, 45541, 69597, 238599, 0 };
            const std::uint32_t dim15044JoeKuoD6Init[]   =   { 1, 1, 3, 1, 7, 21, 87, 205, 39, 503, 433, 3643, 4719, 2051, 10049, 28997, 75981, 253647, 0 };
            const std::uint32_t dim15045JoeKuoD6Init[]   =   { 1, 3, 1, 13, 9, 21, 103, 63, 27, 267, 185, 3507, 3009, 5183, 2261, 40249, 33733, 70493, 0 };
            const std::uint32_t dim15046JoeKuoD6Init[]   =   { 1, 1, 3, 13, 7, 7, 79, 13, 141, 327, 1035, 1699, 6273, 5621, 13877, 57607, 50207, 184643, 0 };
            const std::uint32_t dim15047JoeKuoD6Init[]   =   { 1, 1, 3, 1, 9, 19, 75, 99, 115, 469, 1025, 1999, 1985, 9975, 11069, 59113, 80877, 124153, 0 };
            const std::uint32_t dim15048JoeKuoD6Init[]   =   { 1, 3, 5, 7, 19, 27, 47, 3, 313, 575, 107, 991, 2575, 11001, 12323, 21443, 126245, 219649, 0 };
            const std::uint32_t dim15049JoeKuoD6Init[]   =   { 1, 1, 1, 5, 19, 33, 13, 1, 357, 225, 1355, 1827, 7127, 6387, 19299, 24935, 26847, 251433, 0 };
            const std::uint32_t dim15050JoeKuoD6Init[]   =   { 1, 1, 1, 5, 3, 3, 113, 19, 425, 209, 159, 347, 1349, 6771, 13125, 8393, 21435, 186369, 0 };
            const std::uint32_t dim15051JoeKuoD6Init[]   =   { 1, 1, 5, 11, 5, 39, 95, 3, 193, 741, 1755, 3361, 1927, 12909, 5413, 29111, 123429, 109191, 0 };
            const std::uint32_t dim15052JoeKuoD6Init[]   =   { 1, 1, 1, 13, 31, 23, 43, 163, 421, 719, 457, 3149, 7741, 1465, 15719, 42831, 99051, 164675, 0 };
            const std::uint32_t dim15053JoeKuoD6Init[]   =   { 1, 1, 1, 7, 15, 1, 29, 15, 9, 577, 269, 31, 4361, 5081, 32185, 54869, 115105, 151233, 0 };
            const std::uint32_t dim15054JoeKuoD6Init[]   =   { 1, 1, 1, 11, 19, 3, 67, 3, 377, 487, 1287, 3463, 6523, 15237, 3171, 38673, 7359, 29739, 0 };
            const std::uint32_t dim15055JoeKuoD6Init[]   =   { 1, 3, 5, 11, 9, 13, 47, 191, 97, 641, 807, 1085, 1537, 2855, 24615, 32383, 66425, 53713, 0 };
            const std::uint32_t dim15056JoeKuoD6Init[]   =   { 1, 1, 5, 7, 19, 25, 93, 1, 21, 853, 813, 2535, 4291, 9051, 3385, 507, 73889, 85397, 0 };
            const std::uint32_t dim15057JoeKuoD6Init[]   =   { 1, 1, 3, 13, 7, 15, 103, 199, 83, 585, 1859, 2089, 839, 8923, 14615, 3399, 7703, 229937, 0 };
            const std::uint32_t dim15058JoeKuoD6Init[]   =   { 1, 1, 3, 3, 11, 23, 125, 135, 475, 613, 327, 339, 3081, 13221, 4889, 41233, 36547, 195357, 0 };
            const std::uint32_t dim15059JoeKuoD6Init[]   =   { 1, 3, 7, 7, 19, 23, 85, 217, 501, 447, 1873, 2175, 6753, 2825, 5171, 47561, 13321, 59583, 0 };
            const std::uint32_t dim15060JoeKuoD6Init[]   =   { 1, 1, 5, 13, 23, 59, 109, 195, 487, 785, 21, 1595, 5641, 10103, 8115, 60647, 78425, 237379, 0 };
            const std::uint32_t dim15061JoeKuoD6Init[]   =   { 1, 1, 3, 15, 21, 17, 85, 51, 369, 475, 1021, 1129, 7233, 6593, 12467, 55399, 128157, 80539, 0 };
            const std::uint32_t dim15062JoeKuoD6Init[]   =   { 1, 3, 3, 9, 31, 27, 69, 145, 489, 251, 1997, 1157, 2027, 16109, 4085, 24859, 63561, 79591, 0 };
            const std::uint32_t dim15063JoeKuoD6Init[]   =   { 1, 3, 3, 5, 29, 49, 41, 185, 405, 471, 431, 3539, 6593, 1185, 24383, 17009, 111215, 79839, 0 };
            const std::uint32_t dim15064JoeKuoD6Init[]   =   { 1, 1, 7, 3, 3, 15, 97, 157, 301, 227, 717, 3291, 2471, 11515, 30657, 30745, 72147, 98653, 0 };
            const std::uint32_t dim15065JoeKuoD6Init[]   =   { 1, 3, 5, 1, 23, 21, 67, 223, 185, 385, 137, 2897, 2423, 6119, 28471, 52269, 95725, 9105, 0 };
            const std::uint32_t dim15066JoeKuoD6Init[]   =   { 1, 3, 3, 11, 19, 1, 111, 131, 293, 495, 1043, 631, 1375, 15347, 22029, 29163, 120025, 81631, 0 };
            const std::uint32_t dim15067JoeKuoD6Init[]   =   { 1, 1, 7, 5, 17, 55, 47, 183, 367, 81, 555, 2857, 4787, 5605, 32053, 11815, 81771, 234993, 0 };
            const std::uint32_t dim15068JoeKuoD6Init[]   =   { 1, 3, 7, 15, 15, 49, 45, 221, 49, 299, 887, 3991, 2097, 10819, 23297, 1823, 11319, 205273, 0 };
            const std::uint32_t dim15069JoeKuoD6Init[]   =   { 1, 1, 1, 1, 1, 15, 91, 253, 213, 849, 501, 1073, 5503, 1379, 28887, 51811, 109763, 226149, 0 };
            const std::uint32_t dim15070JoeKuoD6Init[]   =   { 1, 1, 1, 7, 27, 39, 17, 29, 359, 655, 1695, 1781, 1203, 1125, 8983, 3477, 13925, 218399, 0 };
            const std::uint32_t dim15071JoeKuoD6Init[]   =   { 1, 3, 7, 13, 1, 25, 33, 185, 87, 19, 151, 371, 1221, 4859, 20103, 11435, 104263, 218515, 0 };
            const std::uint32_t dim15072JoeKuoD6Init[]   =   { 1, 1, 3, 5, 17, 43, 29, 149, 207, 39, 1539, 2933, 6825, 12391, 18163, 24543, 35305, 196295, 0 };
            const std::uint32_t dim15073JoeKuoD6Init[]   =   { 1, 3, 7, 9, 21, 61, 69, 231, 401, 95, 1757, 839, 3395, 7573, 6583, 34621, 119303, 20767, 0 };
            const std::uint32_t dim15074JoeKuoD6Init[]   =   { 1, 1, 7, 1, 25, 53, 63, 105, 241, 591, 23, 3219, 2387, 13945, 3047, 30939, 63243, 60941, 0 };
            const std::uint32_t dim15075JoeKuoD6Init[]   =   { 1, 1, 5, 7, 25, 47, 7, 227, 57, 279, 81, 4017, 3117, 6229, 20029, 30031, 25049, 102291, 0 };
            const std::uint32_t dim15076JoeKuoD6Init[]   =   { 1, 3, 3, 1, 21, 15, 69, 57, 311, 9, 853, 3377, 2949, 4781, 15419, 54741, 11603, 136821, 0 };
            const std::uint32_t dim15077JoeKuoD6Init[]   =   { 1, 3, 3, 13, 13, 5, 103, 253, 27, 449, 821, 3241, 41, 6643, 15217, 61691, 58463, 46117, 0 };
            const std::uint32_t dim15078JoeKuoD6Init[]   =   { 1, 1, 7, 7, 27, 51, 1, 239, 71, 955, 145, 1059, 5645, 7025, 4839, 11459, 3051, 235989, 0 };
            const std::uint32_t dim15079JoeKuoD6Init[]   =   { 1, 1, 5, 15, 15, 13, 33, 21, 209, 681, 1163, 3109, 1441, 6895, 20829, 48769, 35373, 195171, 0 };
            const std::uint32_t dim15080JoeKuoD6Init[]   =   { 1, 1, 7, 3, 11, 7, 25, 27, 463, 77, 1293, 1977, 4931, 8089, 11079, 14793, 123049, 32259, 0 };
            const std::uint32_t dim15081JoeKuoD6Init[]   =   { 1, 3, 1, 15, 11, 49, 7, 103, 79, 773, 235, 1653, 6477, 8835, 26627, 61101, 40633, 98155, 0 };
            const std::uint32_t dim15082JoeKuoD6Init[]   =   { 1, 3, 5, 7, 3, 53, 77, 197, 49, 57, 1533, 3485, 6603, 1131, 9073, 37023, 85293, 170883, 0 };
            const std::uint32_t dim15083JoeKuoD6Init[]   =   { 1, 3, 7, 15, 23, 5, 125, 75, 413, 521, 1897, 1099, 35, 2013, 687, 51511, 21359, 19995, 0 };
            const std::uint32_t dim15084JoeKuoD6Init[]   =   { 1, 3, 1, 11, 19, 13, 91, 181, 39, 613, 1917, 3149, 669, 9927, 20967, 38313, 13537, 181873, 0 };
            const std::uint32_t dim15085JoeKuoD6Init[]   =   { 1, 3, 5, 7, 5, 23, 25, 145, 189, 679, 483, 2689, 2855, 9631, 8863, 34841, 83311, 211507, 0 };
            const std::uint32_t dim15086JoeKuoD6Init[]   =   { 1, 3, 5, 15, 15, 15, 87, 53, 309, 807, 1405, 259, 3181, 12187, 31529, 8861, 70557, 247787, 0 };
            const std::uint32_t dim15087JoeKuoD6Init[]   =   { 1, 1, 7, 13, 7, 15, 1, 205, 91, 325, 1371, 531, 4917, 10291, 30827, 32491, 34497, 250301, 0 };
            const std::uint32_t dim15088JoeKuoD6Init[]   =   { 1, 3, 1, 11, 29, 17, 97, 37, 259, 1021, 1705, 4001, 4385, 7047, 14593, 63443, 3283, 18195, 0 };
            const std::uint32_t dim15089JoeKuoD6Init[]   =   { 1, 1, 7, 9, 9, 55, 11, 113, 351, 513, 197, 873, 1595, 11331, 27711, 419, 73097, 144357, 0 };
            const std::uint32_t dim15090JoeKuoD6Init[]   =   { 1, 3, 7, 15, 29, 31, 37, 15, 233, 573, 1457, 293, 5437, 15909, 3087, 24535, 6507, 173555, 0 };
            const std::uint32_t dim15091JoeKuoD6Init[]   =   { 1, 1, 1, 7, 7, 47, 81, 241, 257, 389, 233, 3275, 919, 14911, 14473, 58457, 78195, 121421, 0 };
            const std::uint32_t dim15092JoeKuoD6Init[]   =   { 1, 3, 7, 13, 1, 63, 9, 233, 231, 771, 1851, 3829, 7089, 4573, 13297, 58963, 2065, 8365, 0 };
            const std::uint32_t dim15093JoeKuoD6Init[]   =   { 1, 1, 5, 1, 31, 45, 45, 209, 77, 977, 159, 1521, 969, 10115, 32387, 52821, 124209, 51841, 0 };
            const std::uint32_t dim15094JoeKuoD6Init[]   =   { 1, 3, 5, 5, 13, 27, 53, 171, 91, 743, 217, 3805, 7721, 15127, 20679, 57459, 53649, 16381, 0 };
            const std::uint32_t dim15095JoeKuoD6Init[]   =   { 1, 3, 1, 15, 23, 43, 105, 169, 143, 759, 463, 1237, 3311, 2919, 16675, 53049, 12403, 153651, 0 };
            const std::uint32_t dim15096JoeKuoD6Init[]   =   { 1, 3, 3, 11, 5, 27, 1, 135, 17, 683, 679, 2591, 2929, 12417, 18379, 61903, 81991, 25231, 0 };
            const std::uint32_t dim15097JoeKuoD6Init[]   =   { 1, 1, 1, 5, 13, 59, 73, 119, 369, 445, 553, 243, 7523, 1105, 20349, 8417, 87535, 148857, 0 };
            const std::uint32_t dim15098JoeKuoD6Init[]   =   { 1, 3, 7, 15, 29, 3, 49, 49, 7, 753, 1597, 1427, 7485, 9119, 17427, 24961, 114897, 62841, 0 };
            const std::uint32_t dim15099JoeKuoD6Init[]   =   { 1, 1, 7, 7, 17, 35, 49, 225, 267, 801, 1359, 2131, 6093, 3859, 11305, 6287, 106459, 31093, 0 };
            const std::uint32_t dim15100JoeKuoD6Init[]   =   { 1, 1, 5, 3, 1, 45, 19, 89, 145, 23, 1071, 3053, 3463, 6781, 8635, 1961, 54403, 183401, 0 };
            const std::uint32_t dim15101JoeKuoD6Init[]   =   { 1, 3, 1, 13, 17, 35, 105, 155, 145, 597, 1169, 3731, 725, 2185, 23365, 31849, 113717, 185413, 0 };
            const std::uint32_t dim15102JoeKuoD6Init[]   =   { 1, 3, 3, 5, 3, 5, 13, 119, 39, 383, 1595, 63, 7003, 6465, 19847, 37213, 42921, 254479, 0 };
            const std::uint32_t dim15103JoeKuoD6Init[]   =   { 1, 3, 3, 1, 3, 33, 43, 255, 227, 151, 1911, 2657, 6529, 3855, 24411, 8485, 30385, 193265, 0 };
            const std::uint32_t dim15104JoeKuoD6Init[]   =   { 1, 1, 7, 7, 21, 53, 101, 37, 193, 107, 1095, 369, 6423, 3491, 1219, 53385, 31041, 122587, 0 };
            const std::uint32_t dim15105JoeKuoD6Init[]   =   { 1, 1, 7, 3, 13, 39, 101, 109, 113, 201, 619, 2489, 4545, 5017, 25519, 44281, 128605, 128595, 0 };
            const std::uint32_t dim15106JoeKuoD6Init[]   =   { 1, 1, 3, 13, 25, 7, 99, 141, 465, 625, 667, 1633, 6719, 16195, 365, 34355, 65025, 128025, 0 };
            const std::uint32_t dim15107JoeKuoD6Init[]   =   { 1, 1, 1, 7, 15, 51, 43, 159, 223, 493, 411, 65, 5753, 10219, 21885, 33267, 116643, 76777, 0 };
            const std::uint32_t dim15108JoeKuoD6Init[]   =   { 1, 3, 5, 13, 25, 39, 97, 31, 245, 367, 685, 103, 4093, 10449, 3849, 52659, 63355, 262059, 0 };
            const std::uint32_t dim15109JoeKuoD6Init[]   =   { 1, 3, 3, 1, 9, 49, 25, 157, 107, 821, 265, 2939, 6365, 7539, 17935, 50147, 88907, 214317, 0 };
            const std::uint32_t dim15110JoeKuoD6Init[]   =   { 1, 1, 1, 13, 17, 5, 55, 217, 137, 915, 121, 3187, 3111, 7145, 30477, 20023, 71969, 179417, 0 };
            const std::uint32_t dim15111JoeKuoD6Init[]   =   { 1, 1, 1, 5, 7, 15, 47, 71, 197, 725, 523, 2207, 5729, 741, 8595, 39125, 25431, 101093, 0 };
            const std::uint32_t dim15112JoeKuoD6Init[]   =   { 1, 3, 1, 7, 19, 37, 117, 235, 353, 459, 207, 953, 4955, 14979, 22897, 53911, 7783, 203667, 0 };
            const std::uint32_t dim15113JoeKuoD6Init[]   =   { 1, 1, 5, 13, 9, 17, 21, 95, 37, 751, 1463, 2491, 791, 1569, 32055, 61415, 113885, 259285, 0 };
            const std::uint32_t dim15114JoeKuoD6Init[]   =   { 1, 1, 3, 11, 1, 23, 5, 73, 61, 719, 215, 469, 3267, 12003, 16535, 46913, 58321, 2407, 0 };
            const std::uint32_t dim15115JoeKuoD6Init[]   =   { 1, 1, 5, 11, 5, 9, 81, 1, 275, 877, 791, 1591, 2109, 9983, 29085, 15069, 44757, 17887, 0 };
            const std::uint32_t dim15116JoeKuoD6Init[]   =   { 1, 3, 7, 11, 23, 47, 121, 53, 55, 677, 1239, 2591, 579, 11321, 14231, 53701, 71947, 56793, 0 };
            const std::uint32_t dim15117JoeKuoD6Init[]   =   { 1, 1, 5, 1, 7, 31, 39, 205, 231, 843, 159, 2301, 7765, 3317, 8935, 60647, 110545, 142543, 0 };
            const std::uint32_t dim15118JoeKuoD6Init[]   =   { 1, 3, 3, 11, 25, 39, 9, 131, 145, 373, 41, 1687, 417, 9427, 8657, 18315, 18505, 144055, 0 };
            const std::uint32_t dim15119JoeKuoD6Init[]   =   { 1, 3, 7, 3, 1, 51, 61, 223, 409, 607, 1281, 1767, 4719, 10741, 21537, 17307, 5473, 76127, 0 };
            const std::uint32_t dim15120JoeKuoD6Init[]   =   { 1, 1, 1, 1, 1, 43, 35, 157, 183, 835, 1141, 3235, 1383, 11381, 4503, 20435, 73125, 196955, 0 };
            const std::uint32_t dim15121JoeKuoD6Init[]   =   { 1, 1, 5, 7, 13, 47, 9, 191, 349, 587, 1887, 3667, 619, 9443, 28781, 7759, 6023, 81595, 0 };
            const std::uint32_t dim15122JoeKuoD6Init[]   =   { 1, 3, 5, 9, 31, 27, 77, 47, 375, 229, 989, 1241, 4937, 5881, 18797, 21743, 49947, 246165, 0 };
            const std::uint32_t dim15123JoeKuoD6Init[]   =   { 1, 1, 5, 1, 29, 23, 43, 237, 293, 391, 243, 3471, 5205, 9951, 29329, 19873, 114325, 19239, 0 };
            const std::uint32_t dim15124JoeKuoD6Init[]   =   { 1, 3, 3, 5, 19, 49, 23, 149, 419, 23, 21, 515, 3321, 3157, 28559, 8521, 11119, 192881, 0 };
            const std::uint32_t dim15125JoeKuoD6Init[]   =   { 1, 3, 1, 9, 29, 17, 15, 13, 171, 57, 1849, 3815, 7361, 7723, 23657, 60883, 54953, 159861, 0 };
            const std::uint32_t dim15126JoeKuoD6Init[]   =   { 1, 1, 3, 5, 13, 57, 35, 227, 143, 725, 2023, 2583, 2277, 4721, 4395, 61479, 112487, 211861, 0 };
            const std::uint32_t dim15127JoeKuoD6Init[]   =   { 1, 1, 5, 7, 7, 25, 83, 95, 281, 931, 415, 1661, 1543, 5313, 13317, 21203, 23965, 60891, 0 };
            const std::uint32_t dim15128JoeKuoD6Init[]   =   { 1, 3, 3, 1, 25, 51, 65, 147, 7, 521, 235, 2165, 6219, 14247, 30621, 43245, 8133, 49481, 0 };
            const std::uint32_t dim15129JoeKuoD6Init[]   =   { 1, 1, 5, 11, 13, 27, 39, 51, 213, 811, 151, 1157, 7821, 6481, 32097, 12319, 52005, 33291, 0 };
            const std::uint32_t dim15130JoeKuoD6Init[]   =   { 1, 1, 1, 13, 19, 15, 39, 205, 481, 253, 1643, 2969, 3181, 13995, 29877, 1307, 101721, 119111, 0 };
            const std::uint32_t dim15131JoeKuoD6Init[]   =   { 1, 1, 1, 11, 5, 63, 57, 53, 187, 315, 1521, 847, 5955, 3179, 21459, 25937, 83215, 181599, 0 };
            const std::uint32_t dim15132JoeKuoD6Init[]   =   { 1, 1, 7, 13, 17, 35, 113, 73, 105, 497, 1183, 3397, 4443, 14697, 29201, 40737, 40943, 3529, 0 };
            const std::uint32_t dim15133JoeKuoD6Init[]   =   { 1, 3, 5, 5, 3, 53, 101, 125, 173, 137, 333, 381, 1143, 1165, 789, 50013, 23595, 50235, 0 };
            const std::uint32_t dim15134JoeKuoD6Init[]   =   { 1, 1, 3, 1, 23, 3, 21, 143, 475, 337, 1693, 2341, 6509, 4167, 21031, 13887, 83191, 85187, 0 };
            const std::uint32_t dim15135JoeKuoD6Init[]   =   { 1, 1, 3, 1, 29, 59, 39, 217, 77, 943, 1531, 383, 6535, 2593, 8601, 61865, 26629, 57313, 0 };
            const std::uint32_t dim15136JoeKuoD6Init[]   =   { 1, 3, 5, 15, 17, 15, 19, 31, 273, 507, 1193, 2501, 4677, 13355, 5287, 1155, 102959, 185219, 0 };
            const std::uint32_t dim15137JoeKuoD6Init[]   =   { 1, 1, 1, 9, 3, 3, 5, 111, 159, 913, 331, 303, 3673, 12227, 5245, 63749, 107123, 26315, 0 };
            const std::uint32_t dim15138JoeKuoD6Init[]   =   { 1, 3, 5, 11, 13, 13, 115, 237, 481, 793, 1783, 1107, 4811, 3965, 29571, 63237, 15013, 176925, 0 };
            const std::uint32_t dim15139JoeKuoD6Init[]   =   { 1, 1, 7, 1, 13, 57, 85, 15, 19, 889, 1637, 1721, 6299, 6659, 5541, 24365, 38363, 67749, 0 };
            const std::uint32_t dim15140JoeKuoD6Init[]   =   { 1, 1, 3, 1, 9, 39, 15, 183, 133, 821, 1361, 2617, 7197, 8251, 12599, 60549, 42947, 72519, 0 };
            const std::uint32_t dim15141JoeKuoD6Init[]   =   { 1, 3, 1, 5, 19, 17, 69, 189, 309, 33, 2003, 569, 6189, 7845, 22351, 14623, 35287, 160511, 0 };
            const std::uint32_t dim15142JoeKuoD6Init[]   =   { 1, 1, 7, 13, 25, 3, 1, 203, 163, 661, 513, 3513, 741, 16259, 29817, 6059, 23823, 51869, 0 };
            const std::uint32_t dim15143JoeKuoD6Init[]   =   { 1, 3, 3, 1, 9, 43, 59, 77, 465, 223, 2007, 2187, 1499, 9373, 10535, 22207, 111689, 108485, 0 };
            const std::uint32_t dim15144JoeKuoD6Init[]   =   { 1, 1, 5, 15, 1, 21, 87, 163, 177, 751, 115, 3981, 4257, 5345, 31211, 44075, 16983, 69783, 0 };
            const std::uint32_t dim15145JoeKuoD6Init[]   =   { 1, 1, 1, 3, 29, 31, 7, 41, 181, 979, 1661, 1403, 2577, 983, 545, 6205, 20183, 44735, 0 };
            const std::uint32_t dim15146JoeKuoD6Init[]   =   { 1, 3, 3, 15, 5, 1, 85, 243, 59, 161, 1053, 803, 1813, 13583, 2559, 62761, 105337, 83209, 0 };
            const std::uint32_t dim15147JoeKuoD6Init[]   =   { 1, 3, 3, 3, 5, 21, 101, 61, 379, 369, 1865, 3289, 2643, 951, 26493, 17915, 8185, 42387, 0 };
            const std::uint32_t dim15148JoeKuoD6Init[]   =   { 1, 3, 5, 15, 15, 13, 119, 103, 141, 735, 1317, 3345, 2885, 4145, 30719, 965, 10819, 90295, 0 };
            const std::uint32_t dim15149JoeKuoD6Init[]   =   { 1, 3, 7, 13, 15, 11, 19, 163, 495, 369, 1285, 609, 1559, 9965, 31123, 55101, 76743, 104435, 0 };
            const std::uint32_t dim15150JoeKuoD6Init[]   =   { 1, 1, 5, 1, 25, 5, 5, 139, 441, 447, 353, 1369, 959, 14593, 30991, 20651, 126945, 2219, 0 };
            const std::uint32_t dim15151JoeKuoD6Init[]   =   { 1, 3, 5, 9, 21, 9, 113, 83, 115, 15, 161, 1559, 3095, 1447, 10253, 51481, 114541, 248375, 0 };
            const std::uint32_t dim15152JoeKuoD6Init[]   =   { 1, 3, 3, 1, 31, 61, 111, 69, 495, 195, 1153, 2605, 5061, 15509, 8253, 41909, 126033, 51173, 0 };
            const std::uint32_t dim15153JoeKuoD6Init[]   =   { 1, 1, 7, 15, 15, 41, 121, 75, 471, 539, 341, 441, 5357, 11509, 32525, 65477, 101251, 164835, 0 };
            const std::uint32_t dim15154JoeKuoD6Init[]   =   { 1, 1, 5, 7, 3, 63, 13, 123, 285, 499, 1023, 3533, 483, 13747, 26515, 52381, 9073, 256319, 0 };
            const std::uint32_t dim15155JoeKuoD6Init[]   =   { 1, 3, 1, 13, 29, 41, 75, 43, 229, 557, 1775, 1933, 5567, 11439, 22045, 10571, 96761, 98559, 0 };
            const std::uint32_t dim15156JoeKuoD6Init[]   =   { 1, 1, 3, 11, 19, 39, 3, 93, 435, 433, 2005, 1561, 385, 15865, 19763, 44105, 48107, 163063, 0 };
            const std::uint32_t dim15157JoeKuoD6Init[]   =   { 1, 1, 7, 5, 29, 37, 53, 19, 335, 325, 133, 2055, 3029, 14573, 30395, 38599, 97637, 203443, 0 };
            const std::uint32_t dim15158JoeKuoD6Init[]   =   { 1, 1, 7, 15, 29, 51, 7, 145, 21, 955, 1013, 579, 4971, 4849, 11691, 23725, 71079, 102641, 0 };
            const std::uint32_t dim15159JoeKuoD6Init[]   =   { 1, 1, 7, 3, 9, 49, 79, 187, 237, 823, 1951, 2947, 3633, 9119, 14393, 52969, 44703, 222389, 0 };
            const std::uint32_t dim15160JoeKuoD6Init[]   =   { 1, 3, 5, 11, 13, 9, 13, 245, 499, 661, 1899, 1313, 6907, 12259, 4577, 38547, 79687, 17555, 0 };
            const std::uint32_t dim15161JoeKuoD6Init[]   =   { 1, 3, 3, 1, 5, 59, 123, 197, 293, 247, 687, 695, 7493, 3115, 28535, 44335, 31905, 81607, 0 };
            const std::uint32_t dim15162JoeKuoD6Init[]   =   { 1, 3, 1, 3, 19, 5, 45, 101, 457, 395, 565, 3155, 8081, 4863, 1199, 32133, 73087, 27025, 0 };
            const std::uint32_t dim15163JoeKuoD6Init[]   =   { 1, 3, 7, 1, 31, 35, 111, 95, 379, 663, 731, 1813, 4551, 13105, 18275, 19729, 121971, 139959, 0 };
            const std::uint32_t dim15164JoeKuoD6Init[]   =   { 1, 1, 7, 3, 23, 47, 11, 117, 323, 943, 183, 2169, 4625, 12931, 1305, 23345, 119521, 67911, 0 };
            const std::uint32_t dim15165JoeKuoD6Init[]   =   { 1, 1, 1, 13, 19, 45, 37, 77, 301, 741, 747, 241, 5865, 11141, 7961, 10609, 97833, 256555, 0 };
            const std::uint32_t dim15166JoeKuoD6Init[]   =   { 1, 1, 1, 11, 27, 21, 119, 103, 277, 761, 201, 2063, 1043, 13303, 6535, 15553, 57695, 124187, 0 };
            const std::uint32_t dim15167JoeKuoD6Init[]   =   { 1, 3, 7, 3, 1, 11, 79, 143, 345, 237, 1421, 193, 1889, 2515, 11729, 559, 35227, 9393, 0 };
            const std::uint32_t dim15168JoeKuoD6Init[]   =   { 1, 3, 1, 1, 27, 27, 117, 159, 183, 871, 47, 989, 999, 303, 30833, 8229, 116301, 199439, 0 };
            const std::uint32_t dim15169JoeKuoD6Init[]   =   { 1, 1, 1, 1, 31, 27, 41, 83, 435, 409, 999, 2275, 4489, 1985, 21455, 23275, 125039, 192979, 0 };
            const std::uint32_t dim15170JoeKuoD6Init[]   =   { 1, 3, 7, 3, 19, 49, 27, 185, 9, 385, 191, 735, 3439, 16307, 21181, 58749, 128393, 140383, 0 };
            const std::uint32_t dim15171JoeKuoD6Init[]   =   { 1, 3, 7, 3, 15, 5, 65, 89, 11, 915, 673, 947, 3847, 6833, 10095, 34261, 101645, 42131, 0 };
            const std::uint32_t dim15172JoeKuoD6Init[]   =   { 1, 3, 5, 11, 11, 25, 79, 225, 495, 951, 1033, 5, 699, 9621, 1791, 48221, 59275, 49875, 0 };
            const std::uint32_t dim15173JoeKuoD6Init[]   =   { 1, 3, 7, 13, 29, 59, 105, 101, 233, 901, 863, 413, 2087, 16209, 445, 27463, 61465, 121795, 0 };
            const std::uint32_t dim15174JoeKuoD6Init[]   =   { 1, 1, 1, 11, 5, 19, 11, 51, 503, 313, 195, 3, 7249, 4919, 11931, 15569, 118297, 115989, 0 };
            const std::uint32_t dim15175JoeKuoD6Init[]   =   { 1, 3, 3, 13, 13, 61, 63, 57, 429, 487, 2033, 847, 7539, 1469, 3197, 1307, 124557, 211999, 0 };
            const std::uint32_t dim15176JoeKuoD6Init[]   =   { 1, 3, 7, 13, 25, 27, 39, 103, 165, 39, 1587, 3103, 1745, 12593, 10779, 37105, 29059, 256739, 0 };
            const std::uint32_t dim15177JoeKuoD6Init[]   =   { 1, 3, 3, 9, 25, 51, 105, 109, 99, 267, 623, 1351, 3837, 793, 28609, 52199, 15621, 77873, 0 };
            const std::uint32_t dim15178JoeKuoD6Init[]   =   { 1, 1, 3, 7, 29, 61, 45, 237, 431, 791, 91, 1259, 8071, 11103, 27257, 10153, 18639, 248949, 0 };
            const std::uint32_t dim15179JoeKuoD6Init[]   =   { 1, 1, 1, 9, 15, 47, 113, 189, 291, 837, 1317, 2263, 7183, 6669, 17241, 35275, 9087, 241577, 0 };
            const std::uint32_t dim15180JoeKuoD6Init[]   =   { 1, 1, 3, 1, 15, 59, 85, 21, 69, 569, 1473, 2735, 713, 3817, 14677, 26897, 75291, 251255, 0 };
            const std::uint32_t dim15181JoeKuoD6Init[]   =   { 1, 1, 1, 7, 17, 21, 105, 77, 367, 905, 513, 1807, 5571, 14627, 10349, 47821, 34395, 51143, 0 };
            const std::uint32_t dim15182JoeKuoD6Init[]   =   { 1, 3, 7, 13, 27, 19, 123, 145, 371, 857, 1699, 2231, 373, 781, 28713, 21441, 64059, 10689, 0 };
            const std::uint32_t dim15183JoeKuoD6Init[]   =   { 1, 1, 1, 7, 19, 57, 81, 223, 87, 315, 1253, 421, 1371, 1547, 1411, 6809, 23889, 213385, 0 };
            const std::uint32_t dim15184JoeKuoD6Init[]   =   { 1, 3, 1, 5, 23, 57, 89, 15, 227, 965, 1247, 3861, 7723, 15621, 7151, 53961, 47167, 73679, 0 };
            const std::uint32_t dim15185JoeKuoD6Init[]   =   { 1, 3, 7, 15, 31, 21, 9, 79, 87, 561, 1001, 3395, 2095, 15381, 30725, 48111, 68031, 121687, 0 };
            const std::uint32_t dim15186JoeKuoD6Init[]   =   { 1, 3, 1, 9, 15, 29, 83, 87, 377, 331, 2035, 93, 2319, 3637, 4809, 40091, 93141, 39881, 0 };
            const std::uint32_t dim15187JoeKuoD6Init[]   =   { 1, 3, 3, 11, 21, 39, 27, 159, 161, 439, 1417, 595, 4873, 15703, 32743, 56603, 35881, 160727, 0 };
            const std::uint32_t dim15188JoeKuoD6Init[]   =   { 1, 1, 3, 5, 21, 37, 55, 159, 497, 425, 469, 1185, 5015, 7045, 7179, 65325, 97167, 75723, 0 };
            const std::uint32_t dim15189JoeKuoD6Init[]   =   { 1, 3, 1, 7, 31, 21, 125, 223, 479, 765, 1115, 33, 2765, 12781, 22923, 36051, 103749, 33703, 0 };
            const std::uint32_t dim15190JoeKuoD6Init[]   =   { 1, 1, 7, 1, 9, 3, 29, 125, 337, 973, 253, 3179, 3269, 8801, 19369, 20693, 17331, 190295, 0 };
            const std::uint32_t dim15191JoeKuoD6Init[]   =   { 1, 1, 3, 3, 13, 5, 115, 31, 481, 45, 855, 81, 3663, 10443, 13853, 29847, 99471, 249943, 0 };
            const std::uint32_t dim15192JoeKuoD6Init[]   =   { 1, 1, 3, 7, 3, 1, 47, 31, 169, 625, 201, 2257, 4617, 1633, 26681, 53793, 78257, 8955, 0 };
            const std::uint32_t dim15193JoeKuoD6Init[]   =   { 1, 1, 5, 1, 23, 3, 95, 89, 429, 559, 119, 2619, 1235, 7609, 21905, 45495, 19461, 189091, 0 };
            const std::uint32_t dim15194JoeKuoD6Init[]   =   { 1, 3, 5, 5, 11, 33, 123, 45, 89, 899, 1607, 3717, 6745, 15199, 22955, 15891, 50411, 148201, 0 };
            const std::uint32_t dim15195JoeKuoD6Init[]   =   { 1, 3, 5, 9, 19, 23, 87, 21, 39, 117, 603, 823, 3015, 14853, 4341, 49029, 97183, 218713, 0 };
            const std::uint32_t dim15196JoeKuoD6Init[]   =   { 1, 1, 3, 7, 11, 55, 31, 255, 399, 861, 745, 1013, 4583, 15871, 32453, 25357, 90645, 100835, 0 };
            const std::uint32_t dim15197JoeKuoD6Init[]   =   { 1, 1, 1, 11, 13, 27, 57, 233, 45, 339, 305, 3689, 5273, 11801, 29109, 44139, 83171, 250559, 0 };
            const std::uint32_t dim15198JoeKuoD6Init[]   =   { 1, 3, 7, 13, 19, 1, 29, 113, 207, 313, 1465, 3563, 2535, 3307, 14921, 1923, 31429, 59815, 0 };
            const std::uint32_t dim15199JoeKuoD6Init[]   =   { 1, 3, 1, 5, 29, 25, 59, 95, 177, 795, 353, 3973, 8029, 1687, 5045, 16157, 30361, 218479, 0 };
            const std::uint32_t dim15200JoeKuoD6Init[]   =   { 1, 3, 5, 3, 5, 27, 109, 239, 121, 347, 93, 1645, 3293, 13181, 23793, 42935, 98659, 85385, 0 };
            const std::uint32_t dim15201JoeKuoD6Init[]   =   { 1, 1, 7, 9, 9, 37, 127, 211, 77, 557, 177, 2465, 7895, 5523, 26665, 23463, 71715, 126673, 0 };
            const std::uint32_t dim15202JoeKuoD6Init[]   =   { 1, 3, 7, 1, 27, 55, 125, 85, 47, 739, 1513, 3763, 5335, 3135, 11913, 22405, 90785, 88845, 0 };
            const std::uint32_t dim15203JoeKuoD6Init[]   =   { 1, 3, 3, 9, 29, 21, 123, 211, 491, 83, 697, 929, 3507, 7139, 30569, 16365, 122657, 77523, 0 };
            const std::uint32_t dim15204JoeKuoD6Init[]   =   { 1, 3, 5, 5, 27, 21, 41, 129, 67, 503, 877, 1893, 6055, 12709, 24613, 43831, 124035, 62631, 0 };
            const std::uint32_t dim15205JoeKuoD6Init[]   =   { 1, 3, 3, 1, 21, 15, 59, 185, 405, 487, 627, 3737, 345, 14751, 2947, 15815, 55047, 207137, 0 };
            const std::uint32_t dim15206JoeKuoD6Init[]   =   { 1, 1, 1, 9, 15, 29, 19, 155, 101, 405, 597, 329, 2977, 4333, 5465, 43863, 6009, 229481, 0 };
            const std::uint32_t dim15207JoeKuoD6Init[]   =   { 1, 1, 1, 11, 7, 27, 93, 207, 43, 599, 1899, 3979, 4219, 10199, 2901, 34261, 19435, 58317, 0 };
            const std::uint32_t dim15208JoeKuoD6Init[]   =   { 1, 1, 7, 15, 9, 47, 33, 209, 235, 655, 253, 3507, 3355, 1685, 7045, 58907, 41791, 175835, 0 };
            const std::uint32_t dim15209JoeKuoD6Init[]   =   { 1, 3, 3, 11, 11, 43, 21, 255, 45, 831, 1051, 1271, 7945, 9793, 11125, 17709, 118267, 169981, 0 };
            const std::uint32_t dim15210JoeKuoD6Init[]   =   { 1, 3, 7, 13, 27, 37, 45, 221, 243, 37, 1493, 2773, 6655, 7451, 22609, 56559, 12063, 221143, 0 };
            const std::uint32_t dim15211JoeKuoD6Init[]   =   { 1, 3, 1, 1, 9, 15, 97, 61, 241, 825, 735, 3953, 5331, 16373, 19403, 28933, 31881, 111545, 0 };
            const std::uint32_t dim15212JoeKuoD6Init[]   =   { 1, 1, 1, 15, 29, 1, 127, 111, 329, 741, 1589, 1653, 5949, 8703, 27617, 65285, 122167, 11895, 0 };
            const std::uint32_t dim15213JoeKuoD6Init[]   =   { 1, 1, 3, 3, 17, 31, 91, 197, 421, 865, 1901, 897, 6917, 15943, 12823, 15325, 17011, 110783, 0 };
            const std::uint32_t dim15214JoeKuoD6Init[]   =   { 1, 1, 3, 15, 21, 57, 29, 179, 503, 929, 1513, 205, 6083, 4015, 32517, 26921, 54229, 147789, 0 };
            const std::uint32_t dim15215JoeKuoD6Init[]   =   { 1, 1, 7, 15, 27, 21, 95, 59, 193, 97, 1235, 819, 4435, 371, 627, 24673, 1775, 261041, 0 };
            const std::uint32_t dim15216JoeKuoD6Init[]   =   { 1, 1, 7, 15, 3, 37, 99, 85, 505, 1011, 19, 1241, 5299, 15661, 27323, 44625, 12683, 225687, 0 };
            const std::uint32_t dim15217JoeKuoD6Init[]   =   { 1, 1, 7, 3, 25, 37, 111, 121, 217, 659, 365, 2627, 5499, 12911, 951, 54317, 51927, 235327, 0 };
            const std::uint32_t dim15218JoeKuoD6Init[]   =   { 1, 1, 3, 9, 29, 31, 99, 195, 427, 735, 1817, 3675, 4269, 1579, 12593, 39285, 74909, 230613, 0 };
            const std::uint32_t dim15219JoeKuoD6Init[]   =   { 1, 3, 1, 13, 7, 21, 37, 101, 111, 931, 1581, 465, 4753, 15607, 14515, 29769, 107711, 32703, 0 };
            const std::uint32_t dim15220JoeKuoD6Init[]   =   { 1, 1, 7, 15, 25, 57, 117, 119, 309, 345, 491, 3647, 2933, 5409, 15431, 43731, 25537, 17269, 0 };
            const std::uint32_t dim15221JoeKuoD6Init[]   =   { 1, 1, 5, 3, 15, 9, 83, 221, 501, 675, 1441, 129, 213, 5587, 22361, 16739, 118845, 192835, 0 };
            const std::uint32_t dim15222JoeKuoD6Init[]   =   { 1, 3, 7, 13, 1, 31, 75, 23, 13, 447, 687, 2711, 7577, 8275, 5051, 61835, 22159, 56477, 0 };
            const std::uint32_t dim15223JoeKuoD6Init[]   =   { 1, 1, 3, 1, 23, 19, 111, 45, 395, 841, 1665, 21, 7435, 12457, 11065, 20007, 48785, 15115, 0 };
            const std::uint32_t dim15224JoeKuoD6Init[]   =   { 1, 3, 7, 7, 21, 3, 117, 35, 117, 433, 561, 3045, 2169, 3255, 18015, 41093, 99699, 3479, 0 };
            const std::uint32_t dim15225JoeKuoD6Init[]   =   { 1, 1, 3, 7, 9, 59, 65, 143, 315, 63, 29, 3817, 1259, 7119, 20847, 44407, 80015, 37851, 0 };
            const std::uint32_t dim15226JoeKuoD6Init[]   =   { 1, 3, 7, 13, 13, 33, 85, 75, 39, 163, 1759, 1197, 5971, 8815, 8745, 45625, 121873, 246197, 0 };
            const std::uint32_t dim15227JoeKuoD6Init[]   =   { 1, 1, 1, 13, 31, 41, 61, 7, 145, 113, 943, 3757, 2141, 3523, 22351, 14143, 107683, 105579, 0 };
            const std::uint32_t dim15228JoeKuoD6Init[]   =   { 1, 1, 5, 5, 23, 27, 75, 77, 25, 901, 1295, 3091, 981, 10109, 12649, 15123, 102433, 145557, 0 };
            const std::uint32_t dim15229JoeKuoD6Init[]   =   { 1, 1, 7, 5, 9, 11, 19, 229, 301, 835, 1577, 3365, 425, 2271, 15647, 11685, 57315, 131043, 0 };
            const std::uint32_t dim15230JoeKuoD6Init[]   =   { 1, 3, 1, 13, 31, 3, 113, 7, 473, 395, 1979, 61, 4205, 2031, 28007, 34789, 54463, 94741, 0 };
            const std::uint32_t dim15231JoeKuoD6Init[]   =   { 1, 1, 3, 5, 7, 13, 35, 151, 461, 621, 185, 2645, 907, 9151, 25953, 26363, 105531, 235555, 0 };
            const std::uint32_t dim15232JoeKuoD6Init[]   =   { 1, 3, 3, 13, 21, 5, 43, 183, 149, 607, 509, 777, 4089, 16365, 32201, 60431, 58773, 92719, 0 };
            const std::uint32_t dim15233JoeKuoD6Init[]   =   { 1, 3, 3, 11, 25, 53, 103, 203, 269, 1017, 77, 3537, 4839, 15991, 29223, 57397, 122735, 67299, 0 };
            const std::uint32_t dim15234JoeKuoD6Init[]   =   { 1, 3, 3, 1, 29, 45, 85, 171, 307, 455, 1399, 2367, 5991, 5751, 27957, 36649, 9251, 38581, 0 };
            const std::uint32_t dim15235JoeKuoD6Init[]   =   { 1, 1, 5, 13, 29, 15, 127, 1, 175, 921, 671, 2469, 3137, 3679, 32521, 5321, 92505, 45901, 0 };
            const std::uint32_t dim15236JoeKuoD6Init[]   =   { 1, 3, 3, 11, 23, 23, 113, 255, 443, 609, 1085, 133, 5369, 885, 17043, 20961, 36137, 260457, 0 };
            const std::uint32_t dim15237JoeKuoD6Init[]   =   { 1, 3, 3, 9, 13, 55, 117, 19, 111, 323, 275, 495, 6679, 2217, 12015, 3053, 32745, 189413, 0 };
            const std::uint32_t dim15238JoeKuoD6Init[]   =   { 1, 3, 5, 13, 31, 43, 37, 225, 67, 755, 1427, 3967, 6497, 9987, 28145, 50583, 59457, 213217, 0 };
            const std::uint32_t dim15239JoeKuoD6Init[]   =   { 1, 3, 1, 15, 1, 5, 121, 249, 293, 695, 1697, 313, 61, 4037, 11757, 53739, 5693, 106225, 0 };
            const std::uint32_t dim15240JoeKuoD6Init[]   =   { 1, 1, 7, 1, 23, 9, 111, 211, 303, 147, 1291, 3807, 1969, 4115, 7473, 50077, 60745, 41605, 0 };
            const std::uint32_t dim15241JoeKuoD6Init[]   =   { 1, 3, 3, 15, 21, 51, 63, 171, 197, 403, 1327, 1851, 6991, 9069, 19221, 45765, 55489, 34853, 0 };
            const std::uint32_t dim15242JoeKuoD6Init[]   =   { 1, 1, 5, 3, 5, 53, 87, 241, 255, 309, 1319, 3727, 3189, 10887, 13401, 32371, 24479, 170571, 0 };
            const std::uint32_t dim15243JoeKuoD6Init[]   =   { 1, 1, 7, 11, 5, 5, 59, 177, 317, 835, 527, 165, 2137, 9597, 30181, 1779, 75407, 185827, 0 };
            const std::uint32_t dim15244JoeKuoD6Init[]   =   { 1, 3, 3, 7, 25, 15, 15, 183, 235, 955, 27, 2223, 5587, 11301, 17653, 56697, 70787, 198347, 0 };
            const std::uint32_t dim15245JoeKuoD6Init[]   =   { 1, 3, 5, 5, 11, 63, 123, 41, 169, 975, 1709, 2965, 7491, 4183, 15217, 41343, 36139, 9649, 0 };
            const std::uint32_t dim15246JoeKuoD6Init[]   =   { 1, 1, 3, 7, 5, 37, 87, 247, 379, 603, 781, 463, 8063, 13681, 32005, 43485, 107401, 42303, 0 };
            const std::uint32_t dim15247JoeKuoD6Init[]   =   { 1, 3, 5, 9, 19, 53, 61, 219, 217, 361, 769, 1687, 5643, 3145, 12885, 40303, 86377, 255051, 0 };
            const std::uint32_t dim15248JoeKuoD6Init[]   =   { 1, 1, 7, 11, 15, 49, 127, 99, 127, 515, 647, 1725, 1605, 2357, 2069, 31803, 14179, 180367, 0 };
            const std::uint32_t dim15249JoeKuoD6Init[]   =   { 1, 3, 5, 15, 9, 7, 41, 3, 49, 485, 1471, 207, 6477, 4463, 12255, 53481, 110785, 909, 0 };
            const std::uint32_t dim15250JoeKuoD6Init[]   =   { 1, 1, 5, 9, 23, 51, 107, 227, 205, 987, 1525, 2739, 6761, 12343, 32311, 12523, 93351, 29663, 0 };
            const std::uint32_t dim15251JoeKuoD6Init[]   =   { 1, 3, 5, 11, 21, 19, 53, 169, 197, 21, 825, 4029, 6733, 8943, 13475, 60677, 31001, 242291, 0 };
            const std::uint32_t dim15252JoeKuoD6Init[]   =   { 1, 3, 7, 13, 9, 27, 87, 37, 265, 877, 735, 2249, 4801, 2365, 16923, 40451, 29693, 222483, 0 };
            const std::uint32_t dim15253JoeKuoD6Init[]   =   { 1, 1, 3, 9, 31, 61, 71, 103, 215, 421, 193, 3451, 6181, 4271, 30875, 59573, 80773, 100369, 0 };
            const std::uint32_t dim15254JoeKuoD6Init[]   =   { 1, 1, 3, 13, 17, 55, 73, 191, 233, 821, 961, 1637, 2393, 3453, 25959, 5069, 114585, 186001, 0 };
            const std::uint32_t dim15255JoeKuoD6Init[]   =   { 1, 1, 7, 5, 15, 27, 39, 23, 69, 811, 709, 2349, 6011, 803, 12497, 7387, 62023, 247875, 0 };
            const std::uint32_t dim15256JoeKuoD6Init[]   =   { 1, 1, 5, 13, 29, 55, 51, 41, 121, 599, 1633, 3813, 1913, 3803, 26097, 53799, 30997, 261965, 0 };
            const std::uint32_t dim15257JoeKuoD6Init[]   =   { 1, 1, 1, 11, 31, 25, 19, 195, 87, 657, 1005, 3853, 61, 6585, 24665, 38283, 5495, 257201, 0 };
            const std::uint32_t dim15258JoeKuoD6Init[]   =   { 1, 1, 1, 11, 23, 43, 91, 121, 49, 491, 1443, 1873, 7689, 15957, 30463, 64079, 100003, 325, 0 };
            const std::uint32_t dim15259JoeKuoD6Init[]   =   { 1, 1, 7, 1, 25, 51, 27, 105, 119, 233, 513, 3403, 2647, 2847, 12687, 15619, 71225, 243759, 0 };
            const std::uint32_t dim15260JoeKuoD6Init[]   =   { 1, 1, 7, 3, 17, 49, 19, 123, 307, 463, 1619, 1853, 7019, 2605, 17351, 7971, 20675, 235929, 0 };
            const std::uint32_t dim15261JoeKuoD6Init[]   =   { 1, 1, 5, 3, 17, 29, 71, 215, 365, 955, 1631, 3549, 1379, 13881, 25409, 55703, 29863, 135401, 0 };
            const std::uint32_t dim15262JoeKuoD6Init[]   =   { 1, 3, 7, 15, 3, 27, 107, 149, 65, 681, 505, 3957, 6697, 11203, 9321, 63323, 98587, 199241, 0 };
            const std::uint32_t dim15263JoeKuoD6Init[]   =   { 1, 1, 1, 13, 27, 41, 59, 223, 431, 339, 1805, 899, 639, 6559, 13233, 4773, 37415, 110477, 0 };
            const std::uint32_t dim15264JoeKuoD6Init[]   =   { 1, 3, 7, 9, 1, 59, 79, 161, 311, 905, 1755, 3915, 6259, 8955, 14187, 11331, 86185, 209805, 0 };
            const std::uint32_t dim15265JoeKuoD6Init[]   =   { 1, 1, 7, 9, 5, 27, 75, 93, 285, 89, 891, 3341, 1157, 11219, 8883, 8093, 68949, 189643, 0 };
            const std::uint32_t dim15266JoeKuoD6Init[]   =   { 1, 3, 1, 5, 1, 43, 97, 71, 67, 605, 739, 1641, 4415, 4487, 13437, 12755, 121595, 55761, 0 };
            const std::uint32_t dim15267JoeKuoD6Init[]   =   { 1, 1, 1, 3, 1, 13, 61, 77, 297, 507, 1527, 3585, 4515, 13913, 7679, 28461, 61807, 196517, 0 };
            const std::uint32_t dim15268JoeKuoD6Init[]   =   { 1, 1, 1, 3, 21, 23, 101, 135, 59, 485, 1601, 3713, 7409, 349, 16543, 18897, 97253, 149055, 0 };
            const std::uint32_t dim15269JoeKuoD6Init[]   =   { 1, 1, 1, 13, 5, 37, 15, 37, 109, 1005, 363, 1925, 2701, 13169, 17027, 58453, 27667, 234027, 0 };
            const std::uint32_t dim15270JoeKuoD6Init[]   =   { 1, 1, 7, 1, 1, 41, 67, 231, 143, 951, 2023, 3465, 1717, 645, 17353, 9037, 129127, 199467, 0 };
            const std::uint32_t dim15271JoeKuoD6Init[]   =   { 1, 1, 1, 11, 27, 29, 65, 139, 425, 947, 141, 2601, 7339, 4451, 25065, 62691, 62355, 91819, 0 };
            const std::uint32_t dim15272JoeKuoD6Init[]   =   { 1, 3, 7, 15, 29, 29, 93, 25, 139, 267, 1319, 3839, 7295, 11855, 17775, 30199, 44127, 150875, 0 };
            const std::uint32_t dim15273JoeKuoD6Init[]   =   { 1, 3, 5, 1, 3, 55, 23, 191, 199, 583, 1167, 1357, 6477, 11827, 15581, 56541, 16603, 120139, 0 };
            const std::uint32_t dim15274JoeKuoD6Init[]   =   { 1, 1, 1, 3, 5, 47, 103, 211, 443, 491, 1043, 4001, 121, 1637, 5685, 42675, 13009, 22979, 0 };
            const std::uint32_t dim15275JoeKuoD6Init[]   =   { 1, 1, 1, 9, 21, 7, 77, 17, 303, 955, 51, 2389, 3573, 8817, 28053, 40269, 35457, 211023, 0 };
            const std::uint32_t dim15276JoeKuoD6Init[]   =   { 1, 3, 5, 15, 3, 39, 17, 75, 223, 37, 1231, 2127, 3575, 9085, 10715, 41871, 103703, 154181, 0 };
            const std::uint32_t dim15277JoeKuoD6Init[]   =   { 1, 3, 3, 15, 25, 31, 31, 223, 473, 267, 1519, 3205, 7029, 10753, 24757, 28187, 117921, 26783, 0 };
            const std::uint32_t dim15278JoeKuoD6Init[]   =   { 1, 3, 7, 1, 5, 21, 105, 191, 55, 115, 1813, 3701, 1673, 4199, 2441, 19737, 46913, 208725, 0 };
            const std::uint32_t dim15279JoeKuoD6Init[]   =   { 1, 1, 5, 5, 19, 63, 89, 141, 143, 783, 545, 883, 2979, 9219, 24983, 41793, 88441, 207095, 0 };
            const std::uint32_t dim15280JoeKuoD6Init[]   =   { 1, 1, 1, 9, 21, 21, 93, 161, 93, 733, 417, 3133, 8155, 12415, 16343, 11727, 82877, 94469, 0 };
            const std::uint32_t dim15281JoeKuoD6Init[]   =   { 1, 1, 5, 15, 5, 39, 33, 203, 213, 731, 1849, 1675, 6029, 2743, 1529, 16345, 13955, 54929, 0 };
            const std::uint32_t dim15282JoeKuoD6Init[]   =   { 1, 1, 7, 7, 23, 47, 121, 211, 271, 737, 1015, 1021, 5641, 12659, 27545, 52363, 104761, 150143, 0 };
            const std::uint32_t dim15283JoeKuoD6Init[]   =   { 1, 3, 1, 11, 11, 51, 79, 141, 255, 1007, 481, 3221, 7741, 6861, 24943, 63091, 46741, 33359, 0 };
            const std::uint32_t dim15284JoeKuoD6Init[]   =   { 1, 1, 3, 3, 27, 47, 85, 27, 423, 811, 75, 3911, 1951, 10821, 7487, 18971, 83355, 197479, 0 };
            const std::uint32_t dim15285JoeKuoD6Init[]   =   { 1, 1, 5, 5, 1, 63, 125, 251, 457, 795, 557, 217, 2335, 5659, 18375, 52183, 9789, 31417, 0 };
            const std::uint32_t dim15286JoeKuoD6Init[]   =   { 1, 3, 3, 3, 19, 61, 41, 129, 345, 361, 187, 3881, 43, 7197, 7673, 25011, 115155, 16375, 0 };
            const std::uint32_t dim15287JoeKuoD6Init[]   =   { 1, 3, 3, 7, 13, 7, 55, 91, 153, 341, 2003, 2013, 6891, 2411, 14825, 39555, 50267, 61405, 0 };
            const std::uint32_t dim15288JoeKuoD6Init[]   =   { 1, 3, 5, 7, 13, 57, 21, 91, 331, 615, 1297, 2881, 2011, 1907, 16489, 43061, 75731, 76675, 0 };
            const std::uint32_t dim15289JoeKuoD6Init[]   =   { 1, 1, 5, 5, 25, 15, 77, 175, 101, 885, 835, 529, 2787, 547, 20191, 50457, 58557, 61807, 0 };
            const std::uint32_t dim15290JoeKuoD6Init[]   =   { 1, 3, 7, 1, 13, 47, 101, 117, 179, 245, 861, 611, 4377, 5257, 12807, 26667, 19889, 112485, 0 };
            const std::uint32_t dim15291JoeKuoD6Init[]   =   { 1, 3, 7, 1, 27, 3, 23, 109, 197, 187, 963, 1827, 5741, 11921, 6359, 3989, 108939, 5761, 0 };
            const std::uint32_t dim15292JoeKuoD6Init[]   =   { 1, 1, 7, 5, 27, 7, 119, 159, 53, 969, 557, 597, 7821, 7121, 17341, 11233, 10811, 23969, 0 };
            const std::uint32_t dim15293JoeKuoD6Init[]   =   { 1, 1, 3, 13, 23, 55, 75, 131, 339, 917, 317, 2645, 5973, 9939, 26375, 29261, 80883, 229897, 0 };
            const std::uint32_t dim15294JoeKuoD6Init[]   =   { 1, 1, 5, 13, 3, 63, 41, 191, 315, 191, 649, 2119, 317, 14699, 4097, 19557, 97015, 124557, 0 };
            const std::uint32_t dim15295JoeKuoD6Init[]   =   { 1, 3, 7, 15, 13, 29, 29, 43, 47, 37, 729, 185, 4477, 15091, 13991, 18701, 56785, 218823, 0 };
            const std::uint32_t dim15296JoeKuoD6Init[]   =   { 1, 3, 7, 15, 31, 39, 17, 133, 469, 509, 995, 1683, 391, 1775, 15431, 63489, 7405, 122125, 0 };
            const std::uint32_t dim15297JoeKuoD6Init[]   =   { 1, 3, 7, 5, 15, 63, 5, 235, 193, 411, 1493, 3967, 3279, 6421, 13359, 20949, 68097, 69469, 0 };
            const std::uint32_t dim15298JoeKuoD6Init[]   =   { 1, 3, 3, 13, 7, 37, 7, 207, 399, 553, 1629, 1903, 329, 7577, 5813, 17151, 40889, 174811, 0 };
            const std::uint32_t dim15299JoeKuoD6Init[]   =   { 1, 3, 1, 13, 7, 39, 119, 109, 323, 61, 749, 1377, 911, 8195, 19753, 6265, 60783, 182339, 0 };
            const std::uint32_t dim15300JoeKuoD6Init[]   =   { 1, 1, 5, 11, 3, 21, 89, 61, 243, 273, 1317, 3443, 117, 6205, 13907, 12903, 95485, 103355, 0 };
            const std::uint32_t dim15301JoeKuoD6Init[]   =   { 1, 3, 7, 13, 19, 27, 45, 251, 405, 289, 121, 1501, 2599, 8111, 5163, 17437, 75095, 165847, 0 };
            const std::uint32_t dim15302JoeKuoD6Init[]   =   { 1, 3, 3, 5, 23, 13, 29, 145, 333, 573, 1939, 2133, 5797, 5263, 18835, 11945, 42161, 103123, 0 };
            const std::uint32_t dim15303JoeKuoD6Init[]   =   { 1, 3, 5, 13, 9, 31, 45, 17, 181, 111, 219, 3451, 1591, 5823, 20307, 41207, 77047, 173401, 0 };
            const std::uint32_t dim15304JoeKuoD6Init[]   =   { 1, 3, 1, 9, 19, 63, 73, 111, 377, 875, 1749, 2887, 7035, 14209, 1805, 20527, 93839, 225185, 0 };
            const std::uint32_t dim15305JoeKuoD6Init[]   =   { 1, 3, 1, 9, 15, 45, 97, 235, 11, 803, 899, 427, 3353, 7363, 26687, 1307, 5451, 176233, 0 };
            const std::uint32_t dim15306JoeKuoD6Init[]   =   { 1, 3, 7, 5, 7, 51, 59, 53, 3, 263, 159, 1005, 6079, 7237, 17419, 56653, 61091, 182209, 0 };
            const std::uint32_t dim15307JoeKuoD6Init[]   =   { 1, 1, 3, 15, 19, 47, 17, 185, 167, 219, 233, 2921, 5755, 1277, 27281, 33671, 3191, 169477, 0 };
            const std::uint32_t dim15308JoeKuoD6Init[]   =   { 1, 3, 7, 1, 25, 27, 99, 81, 57, 969, 821, 2397, 2947, 5913, 15247, 47651, 449, 183295, 0 };
            const std::uint32_t dim15309JoeKuoD6Init[]   =   { 1, 3, 1, 15, 3, 63, 83, 75, 41, 959, 1005, 153, 97, 15381, 6901, 55141, 90215, 161321, 0 };
            const std::uint32_t dim15310JoeKuoD6Init[]   =   { 1, 3, 1, 9, 1, 1, 29, 191, 43, 241, 607, 667, 1189, 4389, 31335, 14133, 104049, 100925, 0 };
            const std::uint32_t dim15311JoeKuoD6Init[]   =   { 1, 1, 3, 1, 1, 61, 109, 23, 325, 27, 1601, 3957, 7181, 8375, 9823, 50533, 114895, 73825, 0 };
            const std::uint32_t dim15312JoeKuoD6Init[]   =   { 1, 1, 7, 7, 1, 25, 51, 19, 383, 955, 1717, 2953, 5431, 7883, 14451, 18619, 9601, 153151, 0 };
            const std::uint32_t dim15313JoeKuoD6Init[]   =   { 1, 3, 1, 5, 1, 1, 35, 3, 141, 37, 1531, 1855, 7905, 6509, 6223, 45911, 54267, 172275, 0 };
            const std::uint32_t dim15314JoeKuoD6Init[]   =   { 1, 1, 3, 15, 23, 39, 109, 145, 215, 147, 1191, 2425, 301, 5543, 997, 31071, 101697, 169677, 0 };
            const std::uint32_t dim15315JoeKuoD6Init[]   =   { 1, 1, 3, 5, 17, 23, 41, 191, 367, 967, 1625, 3669, 769, 7599, 111, 4399, 64121, 232275, 0 };
            const std::uint32_t dim15316JoeKuoD6Init[]   =   { 1, 3, 5, 1, 25, 61, 47, 247, 413, 605, 399, 1233, 2789, 9775, 7111, 42853, 2305, 87423, 0 };
            const std::uint32_t dim15317JoeKuoD6Init[]   =   { 1, 3, 7, 3, 1, 25, 73, 247, 221, 235, 169, 889, 5635, 4325, 27015, 39549, 107545, 80885, 0 };
            const std::uint32_t dim15318JoeKuoD6Init[]   =   { 1, 1, 7, 11, 15, 55, 61, 103, 179, 157, 481, 3089, 4539, 375, 25425, 14995, 60119, 31031, 0 };
            const std::uint32_t dim15319JoeKuoD6Init[]   =   { 1, 3, 3, 1, 31, 17, 87, 123, 27, 309, 1693, 3871, 7319, 15615, 20113, 18239, 86407, 172381, 0 };
            const std::uint32_t dim15320JoeKuoD6Init[]   =   { 1, 1, 1, 13, 17, 31, 83, 149, 451, 305, 847, 223, 5705, 9697, 4967, 34273, 4041, 252891, 0 };
            const std::uint32_t dim15321JoeKuoD6Init[]   =   { 1, 3, 3, 15, 7, 27, 105, 207, 443, 825, 701, 1159, 5267, 14085, 28295, 41757, 47799, 14835, 0 };
            const std::uint32_t dim15322JoeKuoD6Init[]   =   { 1, 3, 7, 3, 1, 31, 77, 219, 139, 497, 1575, 905, 4341, 4611, 27861, 59871, 45525, 21735, 0 };
            const std::uint32_t dim15323JoeKuoD6Init[]   =   { 1, 3, 3, 3, 7, 17, 65, 183, 231, 955, 1111, 1899, 1677, 13685, 29395, 10449, 62505, 125643, 0 };
            const std::uint32_t dim15324JoeKuoD6Init[]   =   { 1, 3, 5, 7, 27, 57, 81, 165, 279, 989, 1569, 573, 7593, 10067, 1343, 12039, 117175, 225125, 0 };
            const std::uint32_t dim15325JoeKuoD6Init[]   =   { 1, 3, 3, 15, 19, 37, 47, 175, 87, 153, 1137, 1985, 2473, 14767, 19587, 41751, 98937, 66667, 0 };
            const std::uint32_t dim15326JoeKuoD6Init[]   =   { 1, 3, 5, 3, 19, 51, 25, 155, 37, 597, 719, 1039, 165, 1871, 15677, 59891, 29899, 231979, 0 };
            const std::uint32_t dim15327JoeKuoD6Init[]   =   { 1, 3, 5, 13, 15, 39, 17, 21, 73, 695, 1813, 2463, 3549, 3081, 14037, 13077, 40417, 258995, 0 };
            const std::uint32_t dim15328JoeKuoD6Init[]   =   { 1, 1, 5, 9, 29, 5, 105, 75, 97, 937, 1767, 975, 637, 9419, 30673, 33537, 979, 45381, 0 };
            const std::uint32_t dim15329JoeKuoD6Init[]   =   { 1, 1, 5, 9, 3, 31, 91, 193, 171, 163, 925, 3519, 3621, 4943, 14093, 22881, 18459, 110155, 0 };
            const std::uint32_t dim15330JoeKuoD6Init[]   =   { 1, 1, 3, 7, 29, 1, 39, 107, 359, 805, 91, 2911, 4741, 3099, 16967, 45849, 95255, 63225, 0 };
            const std::uint32_t dim15331JoeKuoD6Init[]   =   { 1, 1, 5, 13, 25, 41, 49, 145, 345, 823, 1571, 341, 6323, 9679, 14855, 19965, 108367, 99833, 0 };
            const std::uint32_t dim15332JoeKuoD6Init[]   =   { 1, 3, 5, 3, 27, 35, 87, 83, 373, 425, 281, 1313, 5153, 6301, 2745, 12677, 34603, 181835, 0 };
            const std::uint32_t dim15333JoeKuoD6Init[]   =   { 1, 1, 7, 7, 13, 17, 83, 101, 141, 789, 1403, 2777, 2749, 1551, 9009, 9909, 48443, 176679, 0 };
            const std::uint32_t dim15334JoeKuoD6Init[]   =   { 1, 3, 5, 9, 7, 25, 125, 109, 155, 357, 1111, 3057, 771, 11253, 25811, 60333, 68505, 146987, 0 };
            const std::uint32_t dim15335JoeKuoD6Init[]   =   { 1, 3, 7, 7, 29, 19, 69, 115, 411, 793, 51, 715, 3035, 11577, 14237, 23963, 13915, 196771, 0 };
            const std::uint32_t dim15336JoeKuoD6Init[]   =   { 1, 1, 3, 3, 27, 37, 61, 163, 131, 749, 37, 1333, 47, 2519, 25473, 40851, 55861, 113961, 0 };
            const std::uint32_t dim15337JoeKuoD6Init[]   =   { 1, 3, 5, 1, 3, 49, 19, 251, 125, 387, 1887, 3571, 1465, 4831, 3859, 43357, 20859, 225835, 0 };
            const std::uint32_t dim15338JoeKuoD6Init[]   =   { 1, 3, 5, 9, 27, 53, 53, 143, 383, 781, 819, 2921, 3499, 11551, 18761, 14453, 58209, 181763, 0 };
            const std::uint32_t dim15339JoeKuoD6Init[]   =   { 1, 3, 7, 9, 17, 17, 79, 61, 145, 413, 541, 895, 2077, 6957, 28681, 44821, 30609, 131705, 0 };
            const std::uint32_t dim15340JoeKuoD6Init[]   =   { 1, 1, 3, 15, 1, 57, 17, 125, 11, 43, 1079, 1023, 5391, 67, 31701, 5737, 429, 75411, 0 };
            const std::uint32_t dim15341JoeKuoD6Init[]   =   { 1, 1, 7, 7, 21, 45, 65, 127, 447, 793, 161, 333, 637, 7403, 12861, 30173, 125121, 254687, 0 };
            const std::uint32_t dim15342JoeKuoD6Init[]   =   { 1, 1, 3, 9, 27, 53, 85, 223, 297, 455, 919, 2371, 7049, 7167, 18075, 22815, 10265, 14765, 0 };
            const std::uint32_t dim15343JoeKuoD6Init[]   =   { 1, 1, 3, 7, 1, 53, 91, 181, 471, 101, 771, 4043, 3039, 1215, 19289, 15941, 55187, 147355, 0 };
            const std::uint32_t dim15344JoeKuoD6Init[]   =   { 1, 3, 1, 1, 13, 19, 13, 47, 159, 965, 1383, 297, 4299, 7181, 1271, 17057, 114847, 180883, 0 };
            const std::uint32_t dim15345JoeKuoD6Init[]   =   { 1, 3, 1, 15, 29, 55, 113, 243, 215, 665, 641, 1975, 5907, 2617, 17077, 43697, 61101, 70007, 0 };
            const std::uint32_t dim15346JoeKuoD6Init[]   =   { 1, 3, 1, 11, 5, 55, 109, 145, 307, 663, 1327, 1247, 8033, 15425, 18539, 57027, 72161, 181655, 0 };
            const std::uint32_t dim15347JoeKuoD6Init[]   =   { 1, 3, 5, 9, 25, 17, 3, 57, 7, 449, 1049, 3423, 5769, 12713, 29849, 1017, 92579, 131255, 0 };
            const std::uint32_t dim15348JoeKuoD6Init[]   =   { 1, 1, 7, 13, 25, 13, 55, 217, 461, 595, 931, 1883, 2645, 9625, 20467, 45825, 72027, 163767, 0 };
            const std::uint32_t dim15349JoeKuoD6Init[]   =   { 1, 3, 5, 15, 29, 49, 23, 47, 45, 645, 973, 3837, 621, 7373, 3585, 16083, 93823, 184593, 0 };
            const std::uint32_t dim15350JoeKuoD6Init[]   =   { 1, 3, 7, 11, 27, 19, 59, 125, 447, 33, 541, 1067, 6983, 3779, 27275, 34269, 106937, 65085, 0 };
            const std::uint32_t dim15351JoeKuoD6Init[]   =   { 1, 3, 1, 9, 23, 23, 51, 43, 475, 861, 1759, 2559, 3059, 1175, 31555, 27671, 117653, 162735, 0 };
            const std::uint32_t dim15352JoeKuoD6Init[]   =   { 1, 1, 7, 13, 7, 61, 33, 49, 23, 737, 949, 1785, 2921, 873, 26631, 61941, 14467, 76225, 0 };
            const std::uint32_t dim15353JoeKuoD6Init[]   =   { 1, 3, 7, 5, 31, 11, 49, 149, 7, 85, 1929, 1001, 4185, 221, 23719, 52265, 52973, 67967, 0 };
            const std::uint32_t dim15354JoeKuoD6Init[]   =   { 1, 3, 1, 13, 17, 31, 35, 191, 65, 527, 51, 1093, 3673, 11167, 29985, 59739, 43567, 109817, 0 };
            const std::uint32_t dim15355JoeKuoD6Init[]   =   { 1, 1, 1, 11, 23, 39, 95, 121, 501, 355, 1043, 993, 7533, 15763, 18399, 31601, 49373, 243209, 0 };
            const std::uint32_t dim15356JoeKuoD6Init[]   =   { 1, 1, 3, 3, 15, 37, 57, 183, 27, 981, 153, 1481, 549, 7847, 2689, 57401, 46359, 175401, 0 };
            const std::uint32_t dim15357JoeKuoD6Init[]   =   { 1, 3, 5, 9, 31, 19, 83, 79, 413, 597, 1957, 3027, 4751, 1437, 11255, 39513, 56927, 166841, 0 };
            const std::uint32_t dim15358JoeKuoD6Init[]   =   { 1, 3, 7, 5, 27, 61, 69, 65, 143, 321, 1129, 2521, 4467, 4369, 11727, 35643, 80155, 184241, 0 };
            const std::uint32_t dim15359JoeKuoD6Init[]   =   { 1, 3, 7, 1, 25, 27, 107, 219, 481, 457, 2027, 1057, 6409, 5641, 19711, 11009, 44295, 28171, 0 };
            const std::uint32_t dim15360JoeKuoD6Init[]   =   { 1, 3, 3, 9, 3, 17, 85, 5, 341, 107, 2037, 93, 741, 5279, 20093, 28637, 80823, 210279, 0 };
            const std::uint32_t dim15361JoeKuoD6Init[]   =   { 1, 1, 7, 15, 5, 9, 33, 167, 451, 463, 1951, 2395, 3821, 2915, 15195, 34517, 113545, 22173, 0 };
            const std::uint32_t dim15362JoeKuoD6Init[]   =   { 1, 1, 3, 1, 23, 55, 113, 159, 139, 795, 69, 2021, 6769, 10807, 18605, 54161, 39501, 233797, 0 };
            const std::uint32_t dim15363JoeKuoD6Init[]   =   { 1, 1, 7, 11, 17, 53, 103, 131, 385, 909, 629, 3127, 6117, 11457, 31115, 8255, 33227, 170877, 0 };
            const std::uint32_t dim15364JoeKuoD6Init[]   =   { 1, 1, 3, 9, 23, 19, 99, 221, 141, 731, 311, 2617, 2763, 375, 26763, 56473, 6613, 60519, 0 };
            const std::uint32_t dim15365JoeKuoD6Init[]   =   { 1, 3, 1, 9, 7, 29, 15, 105, 243, 159, 1755, 3999, 5861, 12009, 30111, 48269, 70427, 187173, 0 };
            const std::uint32_t dim15366JoeKuoD6Init[]   =   { 1, 1, 3, 13, 1, 35, 39, 121, 409, 571, 1835, 1535, 4671, 12671, 4503, 4783, 48009, 216837, 0 };
            const std::uint32_t dim15367JoeKuoD6Init[]   =   { 1, 1, 1, 9, 25, 61, 87, 109, 489, 107, 1741, 859, 237, 7161, 27117, 58587, 55445, 155763, 0 };
            const std::uint32_t dim15368JoeKuoD6Init[]   =   { 1, 1, 7, 15, 9, 21, 61, 159, 301, 863, 1823, 11, 419, 6717, 28199, 24129, 58419, 22147, 0 };
            const std::uint32_t dim15369JoeKuoD6Init[]   =   { 1, 3, 1, 5, 9, 7, 13, 205, 185, 759, 777, 2877, 5991, 14555, 18793, 51485, 6373, 232105, 0 };
            const std::uint32_t dim15370JoeKuoD6Init[]   =   { 1, 1, 3, 5, 7, 25, 51, 79, 227, 447, 867, 2709, 2677, 15249, 22957, 45577, 39011, 16839, 0 };
            const std::uint32_t dim15371JoeKuoD6Init[]   =   { 1, 1, 1, 3, 5, 51, 69, 135, 395, 339, 685, 3657, 3789, 16345, 2911, 51737, 97471, 126605, 0 };
            const std::uint32_t dim15372JoeKuoD6Init[]   =   { 1, 3, 7, 15, 15, 5, 85, 153, 507, 347, 1457, 527, 1055, 7773, 4161, 10487, 92373, 256535, 0 };
            const std::uint32_t dim15373JoeKuoD6Init[]   =   { 1, 3, 3, 3, 1, 9, 25, 1, 155, 321, 1739, 555, 7719, 10501, 19075, 12529, 75975, 229905, 0 };
            const std::uint32_t dim15374JoeKuoD6Init[]   =   { 1, 1, 1, 3, 29, 31, 89, 23, 283, 875, 1653, 855, 7613, 15277, 23845, 47443, 287, 217441, 0 };
            const std::uint32_t dim15375JoeKuoD6Init[]   =   { 1, 3, 3, 1, 25, 7, 75, 119, 493, 131, 231, 3063, 7171, 5437, 16385, 50347, 87427, 53603, 0 };
            const std::uint32_t dim15376JoeKuoD6Init[]   =   { 1, 3, 7, 7, 27, 55, 103, 223, 219, 103, 733, 1233, 1931, 2119, 19333, 59839, 100421, 256811, 0 };
            const std::uint32_t dim15377JoeKuoD6Init[]   =   { 1, 3, 7, 15, 23, 63, 77, 151, 285, 701, 1403, 1267, 6975, 11421, 24943, 51647, 75651, 191675, 0 };
            const std::uint32_t dim15378JoeKuoD6Init[]   =   { 1, 1, 5, 7, 25, 23, 25, 7, 503, 759, 997, 1711, 1439, 12483, 30117, 55205, 8813, 221589, 0 };
            const std::uint32_t dim15379JoeKuoD6Init[]   =   { 1, 3, 7, 5, 21, 3, 117, 65, 461, 851, 915, 575, 3061, 1055, 11999, 8375, 128677, 98005, 0 };
            const std::uint32_t dim15380JoeKuoD6Init[]   =   { 1, 3, 7, 7, 19, 13, 123, 23, 41, 293, 79, 1435, 1175, 7399, 14907, 4671, 88029, 220627, 0 };
            const std::uint32_t dim15381JoeKuoD6Init[]   =   { 1, 3, 3, 13, 11, 17, 65, 21, 143, 257, 1001, 2423, 5659, 11681, 23605, 40649, 49797, 55497, 0 };
            const std::uint32_t dim15382JoeKuoD6Init[]   =   { 1, 3, 5, 5, 29, 15, 125, 83, 139, 381, 1435, 2129, 1699, 10725, 531, 767, 112477, 134223, 0 };
            const std::uint32_t dim15383JoeKuoD6Init[]   =   { 1, 3, 7, 9, 9, 23, 35, 1, 127, 143, 707, 1475, 4705, 8921, 14919, 50909, 64425, 33381, 0 };
            const std::uint32_t dim15384JoeKuoD6Init[]   =   { 1, 1, 1, 15, 11, 63, 87, 101, 243, 833, 707, 4095, 201, 4877, 10219, 39019, 129779, 229857, 0 };
            const std::uint32_t dim15385JoeKuoD6Init[]   =   { 1, 1, 1, 11, 5, 9, 35, 177, 303, 545, 917, 1037, 1789, 12147, 29095, 27391, 112833, 104713, 0 };
            const std::uint32_t dim15386JoeKuoD6Init[]   =   { 1, 1, 1, 5, 27, 23, 111, 219, 439, 445, 967, 3527, 6203, 1829, 19657, 48965, 85213, 58719, 0 };
            const std::uint32_t dim15387JoeKuoD6Init[]   =   { 1, 3, 7, 11, 15, 7, 95, 113, 317, 225, 1229, 3033, 5777, 4075, 24093, 3539, 19333, 212757, 0 };
            const std::uint32_t dim15388JoeKuoD6Init[]   =   { 1, 3, 7, 7, 1, 35, 35, 67, 459, 769, 1675, 3509, 7393, 10433, 12003, 7385, 4425, 188989, 0 };
            const std::uint32_t dim15389JoeKuoD6Init[]   =   { 1, 1, 7, 9, 5, 45, 35, 27, 443, 301, 533, 2803, 99, 17, 20749, 58353, 93067, 118763, 0 };
            const std::uint32_t dim15390JoeKuoD6Init[]   =   { 1, 1, 3, 3, 13, 51, 61, 181, 81, 859, 1461, 3455, 2277, 13769, 1251, 4313, 119973, 30693, 0 };
            const std::uint32_t dim15391JoeKuoD6Init[]   =   { 1, 1, 3, 7, 15, 29, 23, 207, 239, 65, 1889, 151, 7793, 2657, 13673, 29033, 74477, 215027, 0 };
            const std::uint32_t dim15392JoeKuoD6Init[]   =   { 1, 1, 5, 1, 19, 35, 19, 71, 187, 783, 543, 505, 347, 3191, 1087, 49735, 54109, 27979, 0 };
            const std::uint32_t dim15393JoeKuoD6Init[]   =   { 1, 3, 3, 3, 3, 61, 67, 59, 207, 957, 1709, 1567, 7973, 5921, 29841, 8311, 81165, 91965, 0 };
            const std::uint32_t dim15394JoeKuoD6Init[]   =   { 1, 1, 1, 7, 23, 47, 109, 189, 447, 861, 1615, 3283, 3059, 749, 28729, 8713, 38743, 211019, 0 };
            const std::uint32_t dim15395JoeKuoD6Init[]   =   { 1, 3, 5, 1, 17, 51, 127, 181, 355, 515, 603, 465, 1825, 9281, 31971, 42793, 22467, 175777, 0 };
            const std::uint32_t dim15396JoeKuoD6Init[]   =   { 1, 3, 1, 5, 3, 29, 111, 91, 99, 15, 535, 3047, 1083, 7181, 28003, 60719, 71825, 12293, 0 };
            const std::uint32_t dim15397JoeKuoD6Init[]   =   { 1, 3, 5, 7, 1, 43, 83, 117, 221, 353, 139, 647, 6017, 4655, 31823, 22097, 118537, 71803, 0 };
            const std::uint32_t dim15398JoeKuoD6Init[]   =   { 1, 1, 3, 3, 27, 11, 35, 169, 215, 883, 1195, 2983, 4651, 15893, 24051, 313, 103947, 5227, 0 };
            const std::uint32_t dim15399JoeKuoD6Init[]   =   { 1, 3, 5, 13, 3, 51, 33, 159, 499, 763, 845, 1541, 3837, 9397, 855, 4187, 112167, 243817, 0 };
            const std::uint32_t dim15400JoeKuoD6Init[]   =   { 1, 1, 7, 9, 1, 15, 19, 239, 227, 561, 1685, 2841, 53, 9753, 15105, 34277, 128859, 100085, 0 };
            const std::uint32_t dim15401JoeKuoD6Init[]   =   { 1, 3, 5, 13, 15, 7, 57, 9, 415, 1005, 583, 1347, 4349, 3603, 9125, 15019, 77735, 237011, 0 };
            const std::uint32_t dim15402JoeKuoD6Init[]   =   { 1, 1, 1, 13, 27, 21, 105, 17, 235, 605, 1417, 2053, 3233, 11617, 28651, 43161, 71663, 98373, 0 };
            const std::uint32_t dim15403JoeKuoD6Init[]   =   { 1, 3, 5, 13, 29, 17, 123, 105, 477, 359, 613, 1699, 2581, 3007, 8507, 14391, 95487, 633, 0 };
            const std::uint32_t dim15404JoeKuoD6Init[]   =   { 1, 1, 7, 7, 13, 55, 107, 211, 71, 339, 1169, 2629, 165, 16207, 25523, 7101, 47553, 261131, 0 };
            const std::uint32_t dim15405JoeKuoD6Init[]   =   { 1, 3, 5, 15, 11, 7, 45, 207, 39, 41, 781, 3347, 2529, 4475, 9665, 31499, 119837, 128755, 0 };
            const std::uint32_t dim15406JoeKuoD6Init[]   =   { 1, 3, 1, 15, 23, 59, 59, 17, 89, 823, 59, 3991, 305, 14893, 1411, 8015, 92193, 66935, 0 };
            const std::uint32_t dim15407JoeKuoD6Init[]   =   { 1, 1, 7, 15, 19, 29, 11, 207, 429, 851, 1661, 2903, 4413, 447, 29447, 39243, 70435, 160451, 0 };
            const std::uint32_t dim15408JoeKuoD6Init[]   =   { 1, 1, 3, 13, 17, 5, 93, 89, 455, 67, 33, 65, 7957, 14383, 28525, 56983, 71899, 4881, 0 };
            const std::uint32_t dim15409JoeKuoD6Init[]   =   { 1, 3, 3, 5, 11, 7, 47, 233, 433, 791, 47, 2561, 6539, 1151, 2083, 12309, 62353, 69507, 0 };
            const std::uint32_t dim15410JoeKuoD6Init[]   =   { 1, 3, 5, 11, 15, 55, 101, 251, 41, 39, 383, 3481, 1817, 3447, 6205, 38169, 98267, 157091, 0 };
            const std::uint32_t dim15411JoeKuoD6Init[]   =   { 1, 3, 5, 7, 9, 47, 113, 55, 421, 703, 849, 2251, 129, 9257, 28097, 33475, 98933, 32041, 0 };
            const std::uint32_t dim15412JoeKuoD6Init[]   =   { 1, 3, 3, 11, 9, 59, 1, 211, 277, 969, 977, 3079, 4707, 3341, 17679, 9469, 52859, 125883, 0 };
            const std::uint32_t dim15413JoeKuoD6Init[]   =   { 1, 1, 7, 13, 29, 19, 49, 149, 259, 573, 1137, 2571, 2661, 12865, 24993, 10721, 96921, 85931, 0 };
            const std::uint32_t dim15414JoeKuoD6Init[]   =   { 1, 3, 1, 9, 15, 27, 91, 127, 305, 159, 523, 2539, 1969, 4325, 595, 37077, 79919, 26889, 0 };
            const std::uint32_t dim15415JoeKuoD6Init[]   =   { 1, 3, 1, 11, 1, 5, 65, 75, 317, 909, 1601, 2713, 6891, 4927, 28427, 5791, 82285, 35209, 0 };
            const std::uint32_t dim15416JoeKuoD6Init[]   =   { 1, 3, 7, 7, 9, 5, 111, 167, 477, 437, 1133, 2715, 6189, 5051, 4765, 26267, 99819, 70419, 0 };
            const std::uint32_t dim15417JoeKuoD6Init[]   =   { 1, 1, 3, 9, 27, 57, 23, 233, 423, 191, 1159, 1539, 6397, 16041, 8803, 19787, 114447, 17029, 0 };
            const std::uint32_t dim15418JoeKuoD6Init[]   =   { 1, 1, 5, 1, 11, 3, 111, 125, 287, 487, 1663, 1953, 3771, 2011, 18167, 47471, 94041, 87569, 0 };
            const std::uint32_t dim15419JoeKuoD6Init[]   =   { 1, 3, 1, 11, 5, 9, 75, 153, 37, 803, 971, 1667, 4631, 9183, 20179, 6905, 80949, 54443, 0 };
            const std::uint32_t dim15420JoeKuoD6Init[]   =   { 1, 1, 1, 5, 13, 29, 91, 201, 49, 739, 1569, 2725, 257, 5505, 5289, 40731, 27843, 16565, 0 };
            const std::uint32_t dim15421JoeKuoD6Init[]   =   { 1, 1, 7, 13, 27, 41, 81, 199, 99, 43, 1331, 3237, 6493, 3839, 19329, 44371, 19715, 60553, 0 };
            const std::uint32_t dim15422JoeKuoD6Init[]   =   { 1, 1, 5, 7, 29, 41, 67, 163, 467, 93, 1977, 2625, 6967, 6655, 19835, 39517, 10259, 200487, 0 };
            const std::uint32_t dim15423JoeKuoD6Init[]   =   { 1, 1, 3, 15, 23, 35, 31, 171, 175, 883, 593, 245, 6209, 7381, 5555, 54507, 66159, 40771, 0 };
            const std::uint32_t dim15424JoeKuoD6Init[]   =   { 1, 3, 3, 11, 3, 63, 75, 177, 239, 77, 1543, 875, 7951, 7571, 961, 9909, 101781, 160399, 0 };
            const std::uint32_t dim15425JoeKuoD6Init[]   =   { 1, 3, 1, 3, 3, 37, 71, 231, 373, 443, 835, 1321, 2107, 2929, 7527, 47969, 15329, 94537, 0 };
            const std::uint32_t dim15426JoeKuoD6Init[]   =   { 1, 3, 3, 15, 7, 5, 127, 121, 159, 25, 399, 3009, 4401, 9649, 4311, 18045, 22557, 135177, 0 };
            const std::uint32_t dim15427JoeKuoD6Init[]   =   { 1, 1, 1, 3, 29, 57, 75, 73, 261, 493, 1417, 1351, 3407, 8553, 4893, 10325, 123149, 161435, 0 };
            const std::uint32_t dim15428JoeKuoD6Init[]   =   { 1, 3, 3, 11, 15, 5, 87, 115, 337, 213, 949, 1925, 5057, 5831, 6837, 51167, 25291, 182197, 0 };
            const std::uint32_t dim15429JoeKuoD6Init[]   =   { 1, 3, 1, 11, 25, 49, 27, 101, 403, 989, 1129, 3933, 1147, 13091, 11965, 38075, 68251, 103293, 0 };
            const std::uint32_t dim15430JoeKuoD6Init[]   =   { 1, 1, 7, 5, 7, 49, 1, 189, 275, 63, 149, 3255, 1175, 7811, 24845, 20755, 99391, 140673, 0 };
            const std::uint32_t dim15431JoeKuoD6Init[]   =   { 1, 3, 1, 13, 17, 35, 37, 37, 415, 125, 643, 443, 6215, 299, 31237, 45687, 78535, 102123, 0 };
            const std::uint32_t dim15432JoeKuoD6Init[]   =   { 1, 3, 5, 3, 27, 41, 85, 215, 47, 21, 725, 1967, 2317, 121, 7827, 48229, 82027, 60271, 0 };
            const std::uint32_t dim15433JoeKuoD6Init[]   =   { 1, 3, 5, 1, 1, 55, 37, 183, 117, 421, 383, 3883, 5519, 6161, 6823, 18423, 77747, 215969, 0 };
            const std::uint32_t dim15434JoeKuoD6Init[]   =   { 1, 3, 5, 13, 31, 3, 117, 59, 375, 797, 1129, 1283, 3245, 12775, 30353, 3837, 130273, 228899, 0 };
            const std::uint32_t dim15435JoeKuoD6Init[]   =   { 1, 3, 5, 1, 7, 33, 17, 153, 179, 255, 537, 2911, 1223, 367, 18131, 25903, 33509, 220031, 0 };
            const std::uint32_t dim15436JoeKuoD6Init[]   =   { 1, 3, 7, 5, 5, 7, 103, 233, 309, 947, 1835, 3509, 4267, 15619, 5895, 30707, 81841, 191899, 0 };
            const std::uint32_t dim15437JoeKuoD6Init[]   =   { 1, 1, 5, 11, 3, 15, 91, 83, 319, 765, 895, 2565, 6833, 1719, 2971, 37483, 21709, 23193, 0 };
            const std::uint32_t dim15438JoeKuoD6Init[]   =   { 1, 1, 3, 11, 31, 57, 83, 233, 439, 161, 1503, 749, 6347, 15379, 2317, 24671, 93399, 239585, 0 };
            const std::uint32_t dim15439JoeKuoD6Init[]   =   { 1, 1, 3, 9, 29, 45, 19, 107, 295, 153, 189, 2521, 5465, 7321, 6143, 229, 100553, 258911, 0 };
            const std::uint32_t dim15440JoeKuoD6Init[]   =   { 1, 3, 7, 11, 31, 27, 95, 21, 249, 981, 1725, 1481, 1025, 9301, 11809, 53109, 29007, 127683, 0 };
            const std::uint32_t dim15441JoeKuoD6Init[]   =   { 1, 3, 1, 3, 1, 23, 97, 137, 5, 471, 1887, 1035, 2681, 5143, 3145, 1517, 88107, 245245, 0 };
            const std::uint32_t dim15442JoeKuoD6Init[]   =   { 1, 1, 1, 1, 15, 11, 13, 9, 405, 607, 403, 1693, 4363, 9365, 6425, 48121, 78969, 87341, 0 };
            const std::uint32_t dim15443JoeKuoD6Init[]   =   { 1, 1, 7, 15, 3, 17, 7, 51, 111, 1023, 9, 465, 1909, 16283, 4763, 50939, 119029, 198257, 0 };
            const std::uint32_t dim15444JoeKuoD6Init[]   =   { 1, 3, 3, 1, 31, 11, 113, 13, 499, 433, 1941, 991, 5439, 3123, 24591, 16171, 55099, 206015, 0 };
            const std::uint32_t dim15445JoeKuoD6Init[]   =   { 1, 3, 5, 15, 25, 49, 125, 101, 251, 619, 1895, 4063, 3065, 14965, 20081, 11233, 58253, 69633, 0 };
            const std::uint32_t dim15446JoeKuoD6Init[]   =   { 1, 1, 1, 5, 21, 35, 29, 241, 359, 553, 1001, 1865, 5183, 5233, 16371, 55277, 102091, 143275, 0 };
            const std::uint32_t dim15447JoeKuoD6Init[]   =   { 1, 1, 1, 3, 29, 37, 3, 191, 239, 961, 2031, 1337, 1169, 5229, 22861, 38257, 55027, 153703, 0 };
            const std::uint32_t dim15448JoeKuoD6Init[]   =   { 1, 3, 5, 7, 7, 35, 49, 139, 509, 381, 1267, 2641, 747, 16239, 23133, 32111, 70471, 128427, 0 };
            const std::uint32_t dim15449JoeKuoD6Init[]   =   { 1, 1, 1, 9, 23, 25, 117, 125, 369, 891, 103, 2215, 3571, 1291, 9001, 35671, 67119, 198847, 0 };
            const std::uint32_t dim15450JoeKuoD6Init[]   =   { 1, 1, 5, 9, 17, 19, 27, 7, 207, 55, 1099, 2117, 7511, 14999, 7761, 32215, 103401, 68599, 0 };
            const std::uint32_t dim15451JoeKuoD6Init[]   =   { 1, 1, 7, 9, 1, 59, 41, 91, 9, 225, 457, 3241, 4713, 2923, 11973, 2867, 130583, 202007, 0 };
            const std::uint32_t dim15452JoeKuoD6Init[]   =   { 1, 3, 1, 9, 31, 47, 63, 49, 457, 757, 885, 937, 2973, 12147, 2607, 52907, 126047, 83275, 0 };
            const std::uint32_t dim15453JoeKuoD6Init[]   =   { 1, 3, 5, 11, 17, 1, 79, 123, 505, 203, 1779, 71, 4357, 2285, 31625, 15225, 86519, 2021, 0 };
            const std::uint32_t dim15454JoeKuoD6Init[]   =   { 1, 3, 1, 11, 21, 17, 41, 169, 125, 995, 351, 1235, 25, 7463, 2099, 18917, 71355, 26983, 0 };
            const std::uint32_t dim15455JoeKuoD6Init[]   =   { 1, 1, 7, 1, 21, 23, 41, 5, 415, 405, 1235, 1245, 151, 11283, 25293, 45147, 12597, 39501, 0 };
            const std::uint32_t dim15456JoeKuoD6Init[]   =   { 1, 1, 1, 5, 29, 29, 15, 165, 259, 179, 1479, 3535, 779, 6583, 885, 34331, 71193, 154417, 0 };
            const std::uint32_t dim15457JoeKuoD6Init[]   =   { 1, 1, 1, 5, 3, 1, 13, 181, 507, 339, 333, 4059, 7963, 15649, 15507, 16913, 34741, 202039, 0 };
            const std::uint32_t dim15458JoeKuoD6Init[]   =   { 1, 3, 7, 1, 1, 9, 17, 119, 77, 583, 259, 883, 4011, 4275, 9599, 58663, 73237, 202783, 0 };
            const std::uint32_t dim15459JoeKuoD6Init[]   =   { 1, 1, 5, 11, 23, 27, 19, 171, 373, 779, 661, 1701, 3363, 13095, 897, 51233, 1319, 41093, 0 };
            const std::uint32_t dim15460JoeKuoD6Init[]   =   { 1, 3, 3, 3, 29, 21, 105, 29, 429, 657, 1735, 1279, 809, 14963, 9735, 23251, 44879, 159371, 0 };
            const std::uint32_t dim15461JoeKuoD6Init[]   =   { 1, 1, 5, 11, 17, 27, 117, 65, 193, 539, 1095, 439, 1687, 11277, 513, 30611, 88885, 69145, 0 };
            const std::uint32_t dim15462JoeKuoD6Init[]   =   { 1, 3, 1, 7, 11, 1, 27, 41, 63, 501, 917, 2397, 6839, 10835, 26437, 56169, 46631, 64095, 0 };
            const std::uint32_t dim15463JoeKuoD6Init[]   =   { 1, 1, 7, 15, 29, 5, 17, 217, 333, 389, 403, 3167, 3599, 12055, 30669, 44821, 109811, 237393, 0 };
            const std::uint32_t dim15464JoeKuoD6Init[]   =   { 1, 3, 5, 13, 1, 39, 51, 233, 159, 135, 763, 2499, 7741, 13099, 8639, 8043, 39827, 5989, 0 };
            const std::uint32_t dim15465JoeKuoD6Init[]   =   { 1, 1, 7, 3, 1, 61, 41, 37, 37, 67, 867, 2631, 6265, 5551, 161, 56643, 126087, 126829, 0 };
            const std::uint32_t dim15466JoeKuoD6Init[]   =   { 1, 1, 7, 1, 21, 39, 101, 225, 489, 123, 661, 2489, 1865, 6809, 21663, 59405, 45579, 51257, 0 };
            const std::uint32_t dim15467JoeKuoD6Init[]   =   { 1, 3, 7, 9, 27, 53, 11, 97, 369, 389, 1933, 3321, 543, 12331, 11571, 10685, 49049, 244027, 0 };
            const std::uint32_t dim15468JoeKuoD6Init[]   =   { 1, 3, 5, 3, 7, 15, 21, 165, 181, 877, 1161, 1815, 2097, 449, 32411, 22843, 12467, 55397, 0 };
            const std::uint32_t dim15469JoeKuoD6Init[]   =   { 1, 3, 1, 3, 11, 45, 23, 193, 287, 137, 333, 1831, 457, 583, 23081, 4525, 4781, 249509, 0 };
            const std::uint32_t dim15470JoeKuoD6Init[]   =   { 1, 3, 5, 5, 15, 13, 27, 199, 267, 297, 923, 3861, 4949, 7945, 25291, 45407, 47529, 127287, 0 };
            const std::uint32_t dim15471JoeKuoD6Init[]   =   { 1, 1, 5, 7, 19, 29, 113, 51, 503, 487, 699, 2097, 2957, 6519, 19487, 46873, 38871, 89997, 0 };
            const std::uint32_t dim15472JoeKuoD6Init[]   =   { 1, 1, 5, 13, 17, 31, 57, 127, 335, 223, 1545, 3749, 1539, 3293, 21159, 13019, 48343, 190895, 0 };
            const std::uint32_t dim15473JoeKuoD6Init[]   =   { 1, 1, 7, 9, 25, 19, 75, 41, 511, 269, 819, 3313, 6805, 15051, 4349, 1809, 34841, 190641, 0 };
            const std::uint32_t dim15474JoeKuoD6Init[]   =   { 1, 3, 5, 9, 27, 7, 91, 187, 123, 519, 477, 2719, 211, 1225, 22689, 37043, 66291, 205441, 0 };
            const std::uint32_t dim15475JoeKuoD6Init[]   =   { 1, 1, 5, 13, 5, 41, 95, 49, 187, 239, 1213, 2363, 8075, 12423, 6361, 42471, 70047, 188063, 0 };
            const std::uint32_t dim15476JoeKuoD6Init[]   =   { 1, 3, 7, 3, 27, 23, 21, 217, 65, 143, 1171, 1441, 1603, 2235, 20923, 32611, 111903, 132771, 0 };
            const std::uint32_t dim15477JoeKuoD6Init[]   =   { 1, 1, 7, 9, 3, 29, 33, 203, 497, 179, 1253, 2083, 7407, 12551, 8371, 62167, 93875, 193017, 0 };
            const std::uint32_t dim15478JoeKuoD6Init[]   =   { 1, 1, 1, 13, 7, 61, 43, 107, 417, 757, 1701, 3187, 5489, 11359, 20469, 20249, 93581, 207969, 0 };
            const std::uint32_t dim15479JoeKuoD6Init[]   =   { 1, 1, 7, 3, 31, 51, 51, 183, 483, 885, 1627, 3605, 6687, 1271, 27013, 40409, 103807, 189805, 0 };
            const std::uint32_t dim15480JoeKuoD6Init[]   =   { 1, 1, 3, 1, 21, 21, 107, 185, 267, 981, 147, 1873, 1085, 15829, 10315, 21673, 7713, 120087, 0 };
            const std::uint32_t dim15481JoeKuoD6Init[]   =   { 1, 1, 5, 3, 7, 27, 73, 131, 287, 657, 1351, 547, 3655, 2433, 6753, 2465, 110299, 194587, 0 };
            const std::uint32_t dim15482JoeKuoD6Init[]   =   { 1, 1, 7, 7, 17, 55, 29, 223, 411, 775, 745, 3515, 4573, 4289, 7411, 55999, 22021, 110567, 0 };
            const std::uint32_t dim15483JoeKuoD6Init[]   =   { 1, 3, 1, 3, 29, 55, 7, 183, 507, 773, 1299, 3653, 7693, 3773, 29549, 4171, 123039, 137495, 0 };
            const std::uint32_t dim15484JoeKuoD6Init[]   =   { 1, 1, 1, 7, 5, 25, 53, 85, 41, 837, 587, 2997, 7281, 6821, 15609, 47855, 49017, 108557, 0 };
            const std::uint32_t dim15485JoeKuoD6Init[]   =   { 1, 1, 5, 5, 1, 17, 109, 231, 295, 825, 1909, 683, 2197, 1895, 8641, 37917, 36347, 38683, 0 };
            const std::uint32_t dim15486JoeKuoD6Init[]   =   { 1, 3, 7, 3, 23, 39, 91, 121, 223, 505, 127, 3439, 7779, 12917, 17351, 33063, 84019, 40077, 0 };
            const std::uint32_t dim15487JoeKuoD6Init[]   =   { 1, 3, 3, 1, 19, 1, 125, 99, 143, 549, 709, 3605, 2377, 761, 14369, 52191, 80811, 214877, 0 };
            const std::uint32_t dim15488JoeKuoD6Init[]   =   { 1, 1, 7, 9, 13, 57, 39, 91, 505, 299, 1241, 1697, 5821, 5327, 22439, 42321, 120941, 40009, 0 };
            const std::uint32_t dim15489JoeKuoD6Init[]   =   { 1, 1, 3, 13, 15, 59, 15, 129, 265, 841, 1255, 1915, 4645, 5991, 26801, 7839, 66961, 59045, 0 };
            const std::uint32_t dim15490JoeKuoD6Init[]   =   { 1, 3, 7, 15, 17, 57, 61, 173, 391, 1001, 1815, 2565, 1445, 13237, 2273, 61683, 62327, 180255, 0 };
            const std::uint32_t dim15491JoeKuoD6Init[]   =   { 1, 1, 3, 3, 23, 29, 115, 185, 333, 103, 1807, 3271, 4803, 9743, 3031, 25263, 30761, 1899, 0 };
            const std::uint32_t dim15492JoeKuoD6Init[]   =   { 1, 1, 1, 7, 1, 13, 63, 113, 467, 17, 1803, 3141, 7069, 8895, 25823, 40347, 11211, 88769, 0 };
            const std::uint32_t dim15493JoeKuoD6Init[]   =   { 1, 3, 5, 1, 3, 3, 29, 101, 315, 915, 341, 287, 4167, 7579, 19797, 18287, 19079, 52805, 0 };
            const std::uint32_t dim15494JoeKuoD6Init[]   =   { 1, 3, 7, 15, 31, 61, 27, 153, 387, 273, 343, 881, 2273, 6621, 19391, 41735, 123899, 117851, 0 };
            const std::uint32_t dim15495JoeKuoD6Init[]   =   { 1, 1, 7, 11, 5, 49, 83, 223, 87, 341, 1023, 2785, 3635, 2651, 5179, 25907, 115249, 74001, 0 };
            const std::uint32_t dim15496JoeKuoD6Init[]   =   { 1, 3, 3, 7, 31, 37, 123, 79, 365, 455, 639, 691, 2659, 12215, 26785, 48785, 120175, 155501, 0 };
            const std::uint32_t dim15497JoeKuoD6Init[]   =   { 1, 3, 3, 11, 19, 49, 81, 97, 429, 317, 257, 663, 5009, 2855, 22721, 51553, 32511, 188977, 0 };
            const std::uint32_t dim15498JoeKuoD6Init[]   =   { 1, 1, 7, 11, 5, 37, 1, 123, 477, 747, 839, 3975, 6347, 489, 31387, 56037, 62935, 177587, 0 };
            const std::uint32_t dim15499JoeKuoD6Init[]   =   { 1, 1, 1, 1, 29, 7, 119, 233, 255, 25, 127, 1377, 991, 12151, 31259, 64863, 34733, 86101, 0 };
            const std::uint32_t dim15500JoeKuoD6Init[]   =   { 1, 3, 7, 5, 19, 57, 67, 1, 81, 719, 891, 2485, 3817, 1055, 437, 9779, 23823, 173219, 0 };
            const std::uint32_t dim15501JoeKuoD6Init[]   =   { 1, 1, 1, 5, 1, 63, 87, 163, 135, 809, 637, 1233, 5245, 481, 11011, 23477, 114963, 96051, 0 };
            const std::uint32_t dim15502JoeKuoD6Init[]   =   { 1, 1, 7, 5, 25, 39, 57, 129, 311, 525, 1555, 179, 639, 4949, 8809, 31215, 95975, 79407, 0 };
            const std::uint32_t dim15503JoeKuoD6Init[]   =   { 1, 3, 1, 1, 15, 59, 77, 87, 479, 889, 1619, 331, 4781, 10597, 935, 28105, 83861, 134273, 0 };
            const std::uint32_t dim15504JoeKuoD6Init[]   =   { 1, 3, 5, 15, 21, 55, 61, 105, 373, 185, 1579, 3487, 2621, 8993, 6443, 31709, 57329, 128165, 0 };
            const std::uint32_t dim15505JoeKuoD6Init[]   =   { 1, 3, 3, 3, 7, 21, 117, 159, 177, 927, 1873, 1865, 3219, 1693, 1173, 34365, 107053, 113949, 0 };
            const std::uint32_t dim15506JoeKuoD6Init[]   =   { 1, 3, 7, 1, 17, 37, 35, 101, 305, 141, 1681, 1949, 47, 11351, 989, 13887, 127429, 13059, 0 };
            const std::uint32_t dim15507JoeKuoD6Init[]   =   { 1, 1, 3, 7, 13, 41, 125, 115, 65, 621, 1401, 631, 5875, 8589, 17185, 22757, 83625, 92907, 0 };
            const std::uint32_t dim15508JoeKuoD6Init[]   =   { 1, 3, 1, 5, 25, 37, 73, 39, 495, 645, 265, 2685, 5875, 5919, 23223, 44593, 26207, 49921, 0 };
            const std::uint32_t dim15509JoeKuoD6Init[]   =   { 1, 3, 1, 13, 25, 31, 39, 15, 179, 791, 1817, 3617, 2139, 1827, 21215, 21767, 15009, 239443, 0 };
            const std::uint32_t dim15510JoeKuoD6Init[]   =   { 1, 1, 3, 7, 17, 9, 33, 121, 235, 535, 1537, 3307, 2881, 4351, 4721, 34131, 129619, 137993, 0 };
            const std::uint32_t dim15511JoeKuoD6Init[]   =   { 1, 1, 3, 1, 3, 51, 79, 213, 205, 323, 1749, 2563, 2013, 6519, 18923, 25937, 74445, 252283, 0 };
            const std::uint32_t dim15512JoeKuoD6Init[]   =   { 1, 3, 5, 11, 3, 53, 17, 195, 305, 543, 1937, 2997, 4593, 7801, 15307, 46359, 39365, 59537, 0 };
            const std::uint32_t dim15513JoeKuoD6Init[]   =   { 1, 1, 1, 13, 31, 53, 111, 163, 139, 163, 999, 83, 5125, 10047, 11143, 51407, 13627, 3621, 0 };
            const std::uint32_t dim15514JoeKuoD6Init[]   =   { 1, 1, 3, 9, 5, 1, 125, 95, 281, 939, 913, 1441, 1209, 12983, 27759, 22393, 75985, 178997, 0 };
            const std::uint32_t dim15515JoeKuoD6Init[]   =   { 1, 3, 5, 3, 5, 27, 91, 41, 51, 447, 491, 3405, 497, 2873, 17865, 30651, 104197, 71751, 0 };
            const std::uint32_t dim15516JoeKuoD6Init[]   =   { 1, 3, 7, 1, 29, 61, 73, 31, 423, 933, 1327, 809, 1461, 269, 15121, 18649, 36095, 139429, 0 };
            const std::uint32_t dim15517JoeKuoD6Init[]   =   { 1, 1, 7, 7, 19, 49, 51, 173, 297, 411, 1255, 1093, 2821, 6743, 1927, 27563, 68459, 261411, 0 };
            const std::uint32_t dim15518JoeKuoD6Init[]   =   { 1, 3, 5, 1, 5, 33, 27, 119, 103, 615, 149, 2299, 6801, 15615, 7361, 31045, 87719, 9557, 0 };
            const std::uint32_t dim15519JoeKuoD6Init[]   =   { 1, 1, 3, 9, 17, 23, 89, 35, 151, 385, 319, 2065, 1897, 1987, 15159, 34855, 5395, 110751, 0 };
            const std::uint32_t dim15520JoeKuoD6Init[]   =   { 1, 3, 1, 13, 7, 47, 19, 185, 207, 787, 1179, 1073, 1463, 6277, 6129, 25031, 91969, 123235, 0 };
            const std::uint32_t dim15521JoeKuoD6Init[]   =   { 1, 1, 7, 3, 19, 63, 97, 1, 381, 71, 1169, 339, 6585, 3629, 31357, 59451, 102735, 253667, 0 };
            const std::uint32_t dim15522JoeKuoD6Init[]   =   { 1, 3, 3, 13, 9, 27, 69, 17, 509, 599, 1247, 2267, 3309, 1905, 17995, 41263, 5947, 51607, 0 };
            const std::uint32_t dim15523JoeKuoD6Init[]   =   { 1, 3, 1, 9, 31, 45, 69, 243, 171, 555, 61, 1135, 1993, 8615, 18363, 19545, 64015, 81391, 0 };
            const std::uint32_t dim15524JoeKuoD6Init[]   =   { 1, 1, 1, 1, 19, 49, 31, 65, 53, 123, 271, 3007, 4509, 9465, 3855, 12673, 19457, 14677, 0 };
            const std::uint32_t dim15525JoeKuoD6Init[]   =   { 1, 3, 5, 13, 29, 53, 91, 145, 115, 53, 839, 1911, 2887, 6053, 18437, 42273, 63093, 70937, 0 };
            const std::uint32_t dim15526JoeKuoD6Init[]   =   { 1, 1, 5, 5, 27, 13, 87, 175, 485, 699, 463, 811, 4991, 15303, 23007, 10021, 59125, 39997, 0 };
            const std::uint32_t dim15527JoeKuoD6Init[]   =   { 1, 1, 5, 5, 27, 21, 89, 61, 109, 555, 953, 2811, 3015, 3249, 16085, 64413, 84605, 177333, 0 };
            const std::uint32_t dim15528JoeKuoD6Init[]   =   { 1, 1, 7, 3, 1, 29, 83, 143, 67, 577, 971, 2339, 6521, 6341, 27141, 37149, 99813, 37579, 0 };
            const std::uint32_t dim15529JoeKuoD6Init[]   =   { 1, 3, 3, 7, 23, 29, 117, 5, 287, 559, 667, 2349, 7481, 679, 9633, 40857, 89841, 98125, 0 };
            const std::uint32_t dim15530JoeKuoD6Init[]   =   { 1, 1, 1, 3, 31, 31, 83, 117, 213, 213, 23, 3803, 5967, 7759, 19521, 13229, 62231, 150687, 0 };
            const std::uint32_t dim15531JoeKuoD6Init[]   =   { 1, 3, 7, 9, 1, 15, 37, 191, 19, 107, 1723, 3517, 3477, 3777, 4359, 45815, 58661, 33217, 0 };
            const std::uint32_t dim15532JoeKuoD6Init[]   =   { 1, 1, 5, 1, 17, 3, 3, 255, 501, 1021, 1731, 481, 6145, 3475, 3417, 11847, 92203, 75109, 0 };
            const std::uint32_t dim15533JoeKuoD6Init[]   =   { 1, 1, 5, 1, 1, 61, 89, 107, 503, 627, 931, 1355, 2067, 12487, 20665, 61543, 15501, 103843, 0 };
            const std::uint32_t dim15534JoeKuoD6Init[]   =   { 1, 1, 5, 9, 25, 17, 7, 255, 251, 939, 851, 2241, 939, 15331, 29357, 2485, 80791, 152601, 0 };
            const std::uint32_t dim15535JoeKuoD6Init[]   =   { 1, 1, 5, 3, 13, 25, 35, 113, 83, 765, 1317, 1409, 369, 2215, 5659, 3581, 13925, 108673, 0 };
            const std::uint32_t dim15536JoeKuoD6Init[]   =   { 1, 1, 1, 1, 13, 13, 83, 27, 5, 563, 723, 2733, 3155, 6567, 24595, 45569, 37587, 144401, 0 };
            const std::uint32_t dim15537JoeKuoD6Init[]   =   { 1, 1, 1, 9, 31, 51, 73, 105, 299, 857, 669, 963, 4115, 14939, 11669, 46215, 92707, 149249, 0 };
            const std::uint32_t dim15538JoeKuoD6Init[]   =   { 1, 1, 3, 5, 7, 41, 105, 213, 3, 999, 93, 1497, 6783, 1559, 20047, 40761, 88219, 64769, 0 };
            const std::uint32_t dim15539JoeKuoD6Init[]   =   { 1, 3, 1, 5, 13, 17, 79, 29, 453, 75, 1095, 623, 7401, 4225, 30467, 60795, 130045, 154767, 0 };
            const std::uint32_t dim15540JoeKuoD6Init[]   =   { 1, 1, 5, 3, 31, 59, 33, 129, 505, 277, 1623, 3531, 6841, 12903, 7231, 5801, 92405, 260195, 0 };
            const std::uint32_t dim15541JoeKuoD6Init[]   =   { 1, 1, 3, 5, 27, 23, 63, 219, 225, 547, 1163, 1899, 4191, 9725, 30077, 30157, 73395, 38195, 0 };
            const std::uint32_t dim15542JoeKuoD6Init[]   =   { 1, 1, 1, 11, 17, 27, 63, 127, 95, 205, 1753, 2023, 6803, 4355, 28169, 16691, 25105, 8969, 0 };
            const std::uint32_t dim15543JoeKuoD6Init[]   =   { 1, 1, 5, 3, 23, 23, 89, 115, 231, 647, 513, 3161, 3175, 5061, 5797, 35387, 109827, 19511, 0 };
            const std::uint32_t dim15544JoeKuoD6Init[]   =   { 1, 3, 5, 5, 11, 9, 39, 251, 367, 253, 2031, 3909, 1057, 12545, 25397, 51571, 91229, 83721, 0 };
            const std::uint32_t dim15545JoeKuoD6Init[]   =   { 1, 3, 5, 7, 5, 35, 57, 153, 111, 789, 177, 2237, 1333, 13185, 993, 22099, 62113, 211815, 0 };
            const std::uint32_t dim15546JoeKuoD6Init[]   =   { 1, 1, 5, 15, 19, 37, 123, 221, 375, 605, 791, 1663, 7537, 7193, 20149, 58077, 113129, 185493, 0 };
            const std::uint32_t dim15547JoeKuoD6Init[]   =   { 1, 1, 1, 1, 1, 53, 117, 227, 441, 851, 1171, 4031, 2313, 2847, 25533, 31767, 18197, 153101, 0 };
            const std::uint32_t dim15548JoeKuoD6Init[]   =   { 1, 1, 3, 3, 13, 9, 65, 225, 71, 763, 1507, 3795, 4321, 399, 12515, 4527, 89193, 236161, 0 };
            const std::uint32_t dim15549JoeKuoD6Init[]   =   { 1, 1, 3, 11, 21, 63, 73, 125, 369, 309, 953, 3525, 3925, 13609, 26061, 21739, 112867, 112985, 0 };
            const std::uint32_t dim15550JoeKuoD6Init[]   =   { 1, 1, 7, 1, 27, 25, 3, 129, 321, 193, 1871, 233, 837, 11163, 14861, 42721, 72849, 206739, 0 };
            const std::uint32_t dim15551JoeKuoD6Init[]   =   { 1, 3, 7, 3, 5, 51, 43, 177, 167, 11, 1297, 1805, 515, 6485, 8253, 271, 47435, 252291, 0 };
            const std::uint32_t dim15552JoeKuoD6Init[]   =   { 1, 3, 3, 3, 19, 47, 47, 47, 299, 101, 1535, 3593, 4669, 10367, 19219, 16579, 85269, 36115, 0 };
            const std::uint32_t dim15553JoeKuoD6Init[]   =   { 1, 1, 7, 15, 7, 51, 53, 181, 379, 267, 985, 3401, 2189, 10197, 14183, 413, 76797, 24751, 0 };
            const std::uint32_t dim15554JoeKuoD6Init[]   =   { 1, 1, 5, 7, 13, 27, 65, 119, 235, 131, 1921, 3411, 1511, 11221, 30315, 11799, 127563, 203533, 0 };
            const std::uint32_t dim15555JoeKuoD6Init[]   =   { 1, 3, 1, 3, 13, 55, 101, 189, 483, 261, 467, 645, 417, 6203, 9221, 19671, 102331, 259335, 0 };
            const std::uint32_t dim15556JoeKuoD6Init[]   =   { 1, 1, 5, 15, 19, 7, 81, 1, 371, 119, 1433, 1211, 303, 14393, 27107, 45295, 109211, 224661, 0 };
            const std::uint32_t dim15557JoeKuoD6Init[]   =   { 1, 3, 7, 9, 19, 53, 31, 55, 103, 351, 1511, 377, 981, 6709, 19553, 53579, 55043, 170489, 0 };
            const std::uint32_t dim15558JoeKuoD6Init[]   =   { 1, 3, 3, 15, 31, 49, 1, 251, 187, 73, 119, 3041, 5455, 5355, 22245, 7735, 14661, 258447, 0 };
            const std::uint32_t dim15559JoeKuoD6Init[]   =   { 1, 3, 7, 11, 13, 1, 61, 97, 179, 975, 1653, 3301, 4303, 2271, 30171, 63287, 51271, 21909, 0 };
            const std::uint32_t dim15560JoeKuoD6Init[]   =   { 1, 1, 5, 11, 21, 45, 101, 131, 121, 881, 1205, 1849, 4337, 5687, 31967, 22559, 98017, 202557, 0 };
            const std::uint32_t dim15561JoeKuoD6Init[]   =   { 1, 3, 3, 7, 1, 49, 11, 35, 141, 309, 651, 3319, 4313, 3675, 27699, 49429, 109805, 167089, 0 };
            const std::uint32_t dim15562JoeKuoD6Init[]   =   { 1, 1, 3, 13, 13, 15, 61, 251, 335, 365, 677, 2183, 6291, 8857, 15231, 551, 63149, 76729, 0 };
            const std::uint32_t dim15563JoeKuoD6Init[]   =   { 1, 3, 3, 13, 1, 59, 85, 127, 409, 1007, 1947, 3495, 6227, 11447, 14329, 3769, 109619, 59063, 0 };
            const std::uint32_t dim15564JoeKuoD6Init[]   =   { 1, 3, 5, 11, 11, 59, 67, 209, 491, 757, 1137, 1977, 3155, 9339, 11219, 20303, 66417, 187911, 0 };
            const std::uint32_t dim15565JoeKuoD6Init[]   =   { 1, 1, 5, 9, 27, 51, 87, 249, 327, 867, 29, 3811, 4769, 12353, 24803, 35747, 84101, 210975, 0 };
            const std::uint32_t dim15566JoeKuoD6Init[]   =   { 1, 3, 7, 7, 23, 37, 23, 55, 237, 543, 779, 1305, 1535, 13333, 1403, 10903, 113135, 195799, 0 };
            const std::uint32_t dim15567JoeKuoD6Init[]   =   { 1, 1, 3, 11, 1, 1, 3, 153, 401, 35, 981, 79, 4227, 9203, 8179, 29325, 104809, 140613, 0 };
            const std::uint32_t dim15568JoeKuoD6Init[]   =   { 1, 3, 5, 9, 13, 39, 101, 181, 507, 307, 1411, 1443, 6855, 8747, 22709, 37869, 102303, 577, 0 };
            const std::uint32_t dim15569JoeKuoD6Init[]   =   { 1, 3, 5, 1, 25, 41, 3, 239, 195, 1, 1277, 2085, 4253, 14683, 24171, 56733, 82795, 213291, 0 };
            const std::uint32_t dim15570JoeKuoD6Init[]   =   { 1, 1, 3, 5, 25, 55, 31, 55, 215, 149, 1813, 3775, 779, 6137, 10561, 41671, 96883, 177435, 0 };
            const std::uint32_t dim15571JoeKuoD6Init[]   =   { 1, 1, 5, 11, 15, 5, 1, 237, 131, 13, 229, 3203, 2431, 1829, 31983, 59535, 31381, 175455, 0 };
            const std::uint32_t dim15572JoeKuoD6Init[]   =   { 1, 3, 3, 7, 5, 19, 61, 253, 223, 609, 1395, 2495, 5501, 6571, 12989, 889, 49435, 200251, 0 };
            const std::uint32_t dim15573JoeKuoD6Init[]   =   { 1, 1, 7, 13, 25, 49, 33, 157, 457, 259, 1935, 2249, 7419, 12685, 30509, 32187, 108839, 178963, 0 };
            const std::uint32_t dim15574JoeKuoD6Init[]   =   { 1, 3, 3, 15, 19, 27, 91, 133, 369, 931, 359, 759, 2647, 13643, 14877, 14031, 115367, 201745, 0 };
            const std::uint32_t dim15575JoeKuoD6Init[]   =   { 1, 1, 5, 3, 9, 23, 87, 27, 203, 995, 1759, 999, 949, 2733, 29053, 46581, 129003, 42585, 0 };
            const std::uint32_t dim15576JoeKuoD6Init[]   =   { 1, 1, 3, 1, 1, 21, 63, 243, 257, 741, 681, 2471, 2455, 15145, 31739, 8751, 15963, 165405, 0 };
            const std::uint32_t dim15577JoeKuoD6Init[]   =   { 1, 3, 3, 1, 25, 21, 69, 213, 219, 9, 199, 487, 4103, 141, 18177, 58797, 60415, 6313, 0 };
            const std::uint32_t dim15578JoeKuoD6Init[]   =   { 1, 3, 1, 5, 23, 43, 61, 121, 123, 89, 283, 1313, 2707, 10199, 7699, 17437, 130995, 140327, 0 };
            const std::uint32_t dim15579JoeKuoD6Init[]   =   { 1, 3, 5, 13, 31, 41, 111, 39, 403, 5, 1125, 2867, 3143, 7051, 9891, 43349, 20751, 88465, 0 };
            const std::uint32_t dim15580JoeKuoD6Init[]   =   { 1, 1, 3, 1, 19, 53, 83, 207, 285, 789, 1515, 3455, 4057, 15777, 27879, 46971, 122661, 143407, 0 };
            const std::uint32_t dim15581JoeKuoD6Init[]   =   { 1, 3, 3, 11, 25, 21, 127, 191, 313, 357, 1625, 1323, 1151, 12509, 22275, 23517, 12221, 258709, 0 };
            const std::uint32_t dim15582JoeKuoD6Init[]   =   { 1, 1, 5, 7, 1, 47, 1, 107, 387, 965, 1319, 2911, 2121, 8595, 9, 21587, 81187, 2803, 0 };
            const std::uint32_t dim15583JoeKuoD6Init[]   =   { 1, 3, 3, 5, 19, 55, 37, 213, 23, 767, 1493, 635, 4289, 2503, 16835, 47851, 77335, 60565, 0 };
            const std::uint32_t dim15584JoeKuoD6Init[]   =   { 1, 1, 1, 7, 23, 9, 101, 145, 457, 691, 1895, 2145, 7527, 7687, 20781, 10957, 24859, 79137, 0 };
            const std::uint32_t dim15585JoeKuoD6Init[]   =   { 1, 3, 7, 15, 9, 9, 15, 195, 493, 859, 687, 1445, 429, 8599, 24591, 40709, 118361, 148163, 0 };
            const std::uint32_t dim15586JoeKuoD6Init[]   =   { 1, 1, 1, 3, 7, 51, 45, 143, 339, 475, 1177, 2829, 785, 10141, 4923, 29135, 22603, 119973, 0 };
            const std::uint32_t dim15587JoeKuoD6Init[]   =   { 1, 3, 5, 15, 25, 37, 1, 13, 351, 127, 143, 2637, 1215, 14577, 12465, 10575, 67997, 21877, 0 };
            const std::uint32_t dim15588JoeKuoD6Init[]   =   { 1, 3, 7, 3, 27, 19, 59, 241, 327, 307, 731, 3471, 6123, 13607, 8793, 14825, 110681, 83259, 0 };
            const std::uint32_t dim15589JoeKuoD6Init[]   =   { 1, 1, 1, 11, 25, 5, 59, 85, 335, 189, 499, 1305, 5801, 7259, 2397, 14045, 55585, 258579, 0 };
            const std::uint32_t dim15590JoeKuoD6Init[]   =   { 1, 1, 3, 5, 21, 49, 49, 63, 261, 657, 1453, 55, 1325, 15513, 14891, 60689, 15381, 252641, 0 };
            const std::uint32_t dim15591JoeKuoD6Init[]   =   { 1, 1, 7, 15, 25, 3, 85, 33, 495, 867, 903, 1813, 2871, 365, 17399, 45695, 102851, 225873, 0 };
            const std::uint32_t dim15592JoeKuoD6Init[]   =   { 1, 1, 1, 13, 13, 63, 29, 35, 325, 893, 1313, 133, 8169, 7791, 9271, 36759, 92275, 169717, 0 };
            const std::uint32_t dim15593JoeKuoD6Init[]   =   { 1, 1, 7, 3, 21, 45, 7, 151, 387, 891, 1921, 1701, 307, 5323, 16321, 51229, 79369, 21513, 0 };
            const std::uint32_t dim15594JoeKuoD6Init[]   =   { 1, 1, 1, 11, 7, 27, 17, 75, 161, 649, 337, 1731, 2905, 4589, 17387, 10455, 70673, 228373, 0 };
            const std::uint32_t dim15595JoeKuoD6Init[]   =   { 1, 1, 3, 15, 17, 35, 45, 131, 469, 629, 1771, 1965, 5065, 6249, 29041, 52791, 55619, 154531, 0 };
            const std::uint32_t dim15596JoeKuoD6Init[]   =   { 1, 1, 7, 3, 25, 53, 85, 233, 161, 163, 1155, 3159, 1551, 13099, 25647, 26777, 91647, 162755, 0 };
            const std::uint32_t dim15597JoeKuoD6Init[]   =   { 1, 1, 3, 9, 17, 11, 39, 63, 503, 927, 1621, 3425, 4835, 7083, 16449, 47913, 127905, 165567, 0 };
            const std::uint32_t dim15598JoeKuoD6Init[]   =   { 1, 1, 7, 1, 29, 9, 1, 111, 285, 1009, 1427, 3071, 205, 12269, 31337, 14501, 10923, 14277, 0 };
            const std::uint32_t dim15599JoeKuoD6Init[]   =   { 1, 1, 5, 5, 1, 3, 51, 205, 477, 661, 1555, 2113, 6487, 4755, 13633, 16391, 35775, 52623, 0 };
            const std::uint32_t dim15600JoeKuoD6Init[]   =   { 1, 3, 3, 3, 27, 23, 109, 49, 71, 19, 733, 1361, 4369, 14527, 20443, 10507, 120183, 246115, 0 };
            const std::uint32_t dim15601JoeKuoD6Init[]   =   { 1, 3, 3, 5, 7, 47, 51, 197, 97, 471, 1631, 3317, 5857, 9405, 30359, 7741, 45079, 175929, 0 };
            const std::uint32_t dim15602JoeKuoD6Init[]   =   { 1, 1, 3, 3, 13, 63, 39, 173, 511, 525, 1687, 1735, 6877, 7383, 27971, 26503, 6189, 232251, 0 };
            const std::uint32_t dim15603JoeKuoD6Init[]   =   { 1, 1, 5, 3, 5, 31, 101, 99, 51, 987, 1627, 3899, 6321, 9441, 4983, 64001, 30923, 199495, 0 };
            const std::uint32_t dim15604JoeKuoD6Init[]   =   { 1, 3, 1, 1, 11, 39, 119, 123, 33, 1017, 1477, 283, 4939, 453, 16445, 25599, 106857, 257811, 0 };
            const std::uint32_t dim15605JoeKuoD6Init[]   =   { 1, 3, 1, 11, 13, 1, 3, 101, 275, 75, 1795, 1449, 2503, 11765, 19299, 14237, 157, 244825, 0 };
            const std::uint32_t dim15606JoeKuoD6Init[]   =   { 1, 3, 7, 15, 23, 1, 85, 65, 55, 103, 1523, 1443, 1021, 5733, 3297, 10889, 22487, 82503, 0 };
            const std::uint32_t dim15607JoeKuoD6Init[]   =   { 1, 1, 7, 3, 17, 59, 109, 113, 17, 173, 1709, 273, 5327, 3243, 10751, 58361, 42303, 78391, 0 };
            const std::uint32_t dim15608JoeKuoD6Init[]   =   { 1, 1, 5, 15, 25, 11, 101, 133, 193, 131, 1671, 3045, 7111, 14331, 15665, 56407, 31561, 154555, 0 };
            const std::uint32_t dim15609JoeKuoD6Init[]   =   { 1, 3, 3, 5, 15, 41, 105, 65, 81, 293, 389, 2653, 1883, 14741, 23553, 33349, 39665, 154233, 0 };
            const std::uint32_t dim15610JoeKuoD6Init[]   =   { 1, 1, 5, 15, 31, 19, 121, 41, 261, 511, 1679, 957, 1647, 12647, 12285, 30291, 122483, 187911, 0 };
            const std::uint32_t dim15611JoeKuoD6Init[]   =   { 1, 3, 1, 5, 27, 25, 17, 45, 303, 947, 1123, 2729, 281, 12389, 27987, 42667, 16089, 17129, 0 };
            const std::uint32_t dim15612JoeKuoD6Init[]   =   { 1, 3, 7, 15, 13, 17, 25, 223, 125, 837, 159, 253, 2599, 11381, 639, 32545, 50633, 139025, 0 };
            const std::uint32_t dim15613JoeKuoD6Init[]   =   { 1, 3, 1, 13, 23, 43, 25, 83, 507, 47, 99, 697, 4453, 2139, 17151, 50709, 37099, 212957, 0 };
            const std::uint32_t dim15614JoeKuoD6Init[]   =   { 1, 1, 7, 7, 29, 7, 63, 141, 475, 853, 1073, 143, 6979, 5663, 29691, 59489, 89689, 223047, 0 };
            const std::uint32_t dim15615JoeKuoD6Init[]   =   { 1, 1, 1, 1, 13, 27, 101, 61, 27, 735, 207, 2065, 5811, 5461, 21493, 15481, 103727, 80017, 0 };
            const std::uint32_t dim15616JoeKuoD6Init[]   =   { 1, 3, 1, 11, 9, 9, 35, 251, 147, 841, 1891, 1909, 5053, 5103, 11751, 16209, 110475, 114875, 0 };
            const std::uint32_t dim15617JoeKuoD6Init[]   =   { 1, 3, 3, 11, 13, 55, 117, 205, 71, 159, 1797, 989, 2221, 16087, 18287, 8355, 96403, 146613, 0 };
            const std::uint32_t dim15618JoeKuoD6Init[]   =   { 1, 1, 5, 5, 29, 25, 73, 63, 299, 839, 1225, 3583, 5641, 1341, 29431, 7035, 99107, 13493, 0 };
            const std::uint32_t dim15619JoeKuoD6Init[]   =   { 1, 1, 3, 5, 27, 53, 9, 51, 79, 701, 667, 1469, 4455, 13761, 18607, 39429, 7687, 201115, 0 };
            const std::uint32_t dim15620JoeKuoD6Init[]   =   { 1, 3, 7, 11, 23, 35, 101, 129, 491, 369, 565, 2557, 2529, 1003, 16003, 33873, 52155, 861, 0 };
            const std::uint32_t dim15621JoeKuoD6Init[]   =   { 1, 1, 1, 15, 27, 63, 1, 55, 331, 853, 899, 1027, 7389, 8935, 12559, 27315, 101753, 255331, 0 };
            const std::uint32_t dim15622JoeKuoD6Init[]   =   { 1, 3, 3, 15, 5, 41, 93, 39, 473, 887, 1667, 847, 7619, 8407, 6539, 31989, 63807, 21861, 0 };
            const std::uint32_t dim15623JoeKuoD6Init[]   =   { 1, 1, 5, 11, 27, 57, 73, 249, 331, 653, 21, 2937, 4403, 16195, 18785, 30375, 22939, 235291, 0 };
            const std::uint32_t dim15624JoeKuoD6Init[]   =   { 1, 1, 7, 1, 7, 41, 59, 161, 295, 503, 595, 3021, 455, 3991, 8617, 65361, 107239, 83205, 0 };
            const std::uint32_t dim15625JoeKuoD6Init[]   =   { 1, 3, 3, 15, 17, 41, 61, 229, 273, 687, 657, 1969, 2817, 2367, 29183, 41199, 24123, 184081, 0 };
            const std::uint32_t dim15626JoeKuoD6Init[]   =   { 1, 3, 7, 5, 25, 63, 43, 65, 443, 423, 549, 2031, 3353, 7041, 6563, 18819, 46047, 239823, 0 };
            const std::uint32_t dim15627JoeKuoD6Init[]   =   { 1, 3, 3, 3, 3, 17, 13, 115, 377, 623, 1959, 127, 5125, 13209, 24731, 23151, 21303, 7213, 0 };
            const std::uint32_t dim15628JoeKuoD6Init[]   =   { 1, 1, 7, 1, 21, 11, 21, 41, 491, 37, 1759, 2771, 1301, 12995, 17621, 30907, 75511, 82321, 0 };
            const std::uint32_t dim15629JoeKuoD6Init[]   =   { 1, 3, 3, 13, 13, 23, 77, 211, 215, 711, 427, 2213, 8041, 1595, 26105, 39051, 105407, 242141, 0 };
            const std::uint32_t dim15630JoeKuoD6Init[]   =   { 1, 3, 3, 9, 13, 35, 117, 207, 75, 395, 723, 3321, 6643, 2429, 10043, 10585, 3529, 64067, 0 };
            const std::uint32_t dim15631JoeKuoD6Init[]   =   { 1, 1, 1, 7, 3, 1, 83, 93, 311, 157, 891, 1717, 7669, 16067, 11775, 27693, 11757, 94471, 0 };
            const std::uint32_t dim15632JoeKuoD6Init[]   =   { 1, 3, 3, 5, 17, 63, 23, 177, 289, 921, 315, 3083, 5903, 8697, 22425, 37845, 31171, 49237, 0 };
            const std::uint32_t dim15633JoeKuoD6Init[]   =   { 1, 1, 7, 9, 21, 63, 29, 227, 427, 271, 525, 2071, 7103, 8389, 29185, 51601, 110737, 16949, 0 };
            const std::uint32_t dim15634JoeKuoD6Init[]   =   { 1, 3, 3, 3, 3, 49, 25, 173, 79, 343, 509, 1939, 6389, 15501, 20135, 54365, 69931, 135269, 0 };
            const std::uint32_t dim15635JoeKuoD6Init[]   =   { 1, 1, 3, 3, 21, 23, 41, 71, 169, 947, 1027, 2345, 3397, 12181, 15409, 31725, 41223, 58837, 0 };
            const std::uint32_t dim15636JoeKuoD6Init[]   =   { 1, 3, 7, 1, 19, 23, 57, 201, 27, 449, 1479, 921, 4703, 10949, 14369, 27929, 45399, 46055, 0 };
            const std::uint32_t dim15637JoeKuoD6Init[]   =   { 1, 1, 3, 9, 13, 17, 125, 17, 393, 295, 497, 3089, 6589, 4003, 8687, 48145, 2683, 175521, 0 };
            const std::uint32_t dim15638JoeKuoD6Init[]   =   { 1, 3, 3, 15, 15, 13, 3, 31, 51, 101, 973, 101, 3709, 13437, 51, 14293, 21561, 136497, 0 };
            const std::uint32_t dim15639JoeKuoD6Init[]   =   { 1, 1, 5, 11, 17, 27, 51, 45, 77, 539, 225, 2029, 533, 153, 26085, 33611, 28153, 75671, 0 };
            const std::uint32_t dim15640JoeKuoD6Init[]   =   { 1, 1, 1, 15, 3, 59, 59, 123, 475, 225, 1613, 3121, 2865, 4647, 14553, 35449, 121657, 37457, 0 };
            const std::uint32_t dim15641JoeKuoD6Init[]   =   { 1, 1, 5, 1, 27, 33, 121, 225, 57, 619, 1293, 3813, 2121, 3525, 21995, 47253, 33095, 257451, 0 };
            const std::uint32_t dim15642JoeKuoD6Init[]   =   { 1, 3, 1, 11, 11, 43, 115, 233, 335, 185, 989, 3567, 4135, 2357, 20559, 43325, 43015, 51695, 0 };
            const std::uint32_t dim15643JoeKuoD6Init[]   =   { 1, 1, 5, 9, 11, 49, 45, 187, 93, 967, 1609, 2511, 1549, 4045, 21309, 16341, 13495, 214827, 0 };
            const std::uint32_t dim15644JoeKuoD6Init[]   =   { 1, 1, 1, 13, 21, 23, 81, 7, 259, 483, 1059, 773, 5297, 10123, 9857, 61187, 47355, 76307, 0 };
            const std::uint32_t dim15645JoeKuoD6Init[]   =   { 1, 3, 7, 9, 29, 51, 113, 255, 223, 853, 1173, 1019, 1587, 9629, 22373, 32731, 125179, 193271, 0 };
            const std::uint32_t dim15646JoeKuoD6Init[]   =   { 1, 1, 5, 11, 3, 55, 25, 145, 347, 451, 1447, 3399, 5873, 11579, 11107, 64707, 10161, 142003, 0 };
            const std::uint32_t dim15647JoeKuoD6Init[]   =   { 1, 1, 1, 7, 15, 49, 109, 93, 267, 919, 177, 2247, 8129, 8039, 15629, 63767, 98153, 143255, 0 };
            const std::uint32_t dim15648JoeKuoD6Init[]   =   { 1, 1, 5, 3, 3, 27, 47, 151, 231, 35, 155, 2745, 7349, 6543, 14117, 19549, 54927, 10819, 0 };
            const std::uint32_t dim15649JoeKuoD6Init[]   =   { 1, 3, 7, 15, 31, 29, 17, 203, 249, 169, 1071, 3069, 6269, 3455, 27177, 33761, 111003, 4527, 0 };
            const std::uint32_t dim15650JoeKuoD6Init[]   =   { 1, 3, 1, 5, 31, 15, 65, 189, 3, 917, 857, 1221, 3553, 2883, 3631, 32971, 68057, 109081, 0 };
            const std::uint32_t dim15651JoeKuoD6Init[]   =   { 1, 3, 1, 9, 3, 55, 127, 57, 125, 463, 199, 317, 3373, 967, 5569, 55997, 17167, 33585, 0 };
            const std::uint32_t dim15652JoeKuoD6Init[]   =   { 1, 3, 5, 1, 9, 57, 15, 89, 335, 119, 1445, 1931, 4177, 2495, 27507, 8209, 60003, 29657, 0 };
            const std::uint32_t dim15653JoeKuoD6Init[]   =   { 1, 3, 5, 7, 15, 43, 83, 117, 283, 131, 653, 57, 6789, 7633, 30525, 64131, 101981, 122017, 0 };
            const std::uint32_t dim15654JoeKuoD6Init[]   =   { 1, 3, 7, 11, 3, 17, 115, 217, 391, 825, 1633, 885, 7787, 5595, 12235, 30233, 53587, 62985, 0 };
            const std::uint32_t dim15655JoeKuoD6Init[]   =   { 1, 1, 5, 3, 5, 13, 99, 1, 75, 329, 1247, 107, 2337, 4201, 6217, 12273, 41585, 46563, 0 };
            const std::uint32_t dim15656JoeKuoD6Init[]   =   { 1, 3, 1, 15, 25, 53, 33, 125, 311, 955, 161, 3631, 581, 11915, 4223, 63207, 16517, 201665, 0 };
            const std::uint32_t dim15657JoeKuoD6Init[]   =   { 1, 1, 5, 1, 27, 23, 93, 211, 483, 691, 949, 1825, 391, 12111, 13639, 61009, 88503, 104823, 0 };
            const std::uint32_t dim15658JoeKuoD6Init[]   =   { 1, 3, 1, 13, 3, 9, 51, 133, 259, 977, 697, 661, 7661, 3987, 8327, 50155, 112235, 236135, 0 };
            const std::uint32_t dim15659JoeKuoD6Init[]   =   { 1, 1, 3, 13, 7, 39, 121, 37, 151, 973, 1275, 2699, 3345, 7167, 19245, 55535, 12305, 33567, 0 };
            const std::uint32_t dim15660JoeKuoD6Init[]   =   { 1, 1, 1, 1, 27, 5, 91, 63, 409, 579, 459, 2335, 4721, 3305, 11293, 15405, 74513, 157863, 0 };
            const std::uint32_t dim15661JoeKuoD6Init[]   =   { 1, 1, 5, 1, 21, 45, 55, 111, 475, 381, 659, 1131, 3575, 5165, 27221, 46757, 53587, 90741, 0 };
            const std::uint32_t dim15662JoeKuoD6Init[]   =   { 1, 1, 5, 15, 11, 31, 121, 209, 69, 389, 779, 2833, 4519, 1801, 4363, 24723, 105849, 54475, 0 };
            const std::uint32_t dim15663JoeKuoD6Init[]   =   { 1, 1, 3, 9, 7, 19, 11, 75, 275, 77, 1997, 1661, 6139, 13165, 30653, 49469, 67053, 3811, 0 };
            const std::uint32_t dim15664JoeKuoD6Init[]   =   { 1, 1, 3, 9, 5, 11, 5, 151, 395, 715, 1381, 3011, 5939, 1805, 8063, 62877, 99749, 112951, 0 };
            const std::uint32_t dim15665JoeKuoD6Init[]   =   { 1, 1, 5, 13, 19, 15, 113, 47, 455, 173, 1897, 701, 6093, 2089, 3977, 20599, 60947, 23671, 0 };
            const std::uint32_t dim15666JoeKuoD6Init[]   =   { 1, 1, 1, 13, 23, 19, 13, 117, 275, 313, 1683, 2975, 179, 3949, 4361, 60211, 91999, 211219, 0 };
            const std::uint32_t dim15667JoeKuoD6Init[]   =   { 1, 3, 5, 15, 13, 53, 83, 161, 491, 1001, 1773, 1227, 1965, 14479, 17677, 24399, 86431, 203303, 0 };
            const std::uint32_t dim15668JoeKuoD6Init[]   =   { 1, 1, 7, 15, 5, 51, 103, 131, 351, 747, 1227, 2859, 6693, 10615, 29485, 6619, 106239, 148739, 0 };
            const std::uint32_t dim15669JoeKuoD6Init[]   =   { 1, 3, 5, 1, 9, 43, 91, 173, 223, 393, 1181, 3785, 6589, 1299, 10217, 20891, 64125, 63409, 0 };
            const std::uint32_t dim15670JoeKuoD6Init[]   =   { 1, 1, 5, 7, 11, 23, 45, 57, 397, 771, 511, 1849, 343, 14139, 26271, 56241, 52581, 163187, 0 };
            const std::uint32_t dim15671JoeKuoD6Init[]   =   { 1, 3, 7, 5, 15, 59, 89, 151, 255, 247, 291, 219, 995, 10821, 1445, 35581, 88767, 16871, 0 };
            const std::uint32_t dim15672JoeKuoD6Init[]   =   { 1, 1, 7, 11, 7, 25, 3, 175, 253, 193, 1641, 1669, 7095, 11871, 10801, 42567, 120663, 109347, 0 };
            const std::uint32_t dim15673JoeKuoD6Init[]   =   { 1, 3, 5, 7, 31, 41, 119, 39, 149, 653, 153, 2783, 1377, 5223, 17915, 3127, 41869, 193477, 0 };
            const std::uint32_t dim15674JoeKuoD6Init[]   =   { 1, 3, 3, 13, 23, 19, 47, 85, 487, 103, 237, 2363, 4451, 5077, 23749, 17011, 73561, 169165, 0 };
            const std::uint32_t dim15675JoeKuoD6Init[]   =   { 1, 1, 3, 9, 21, 25, 77, 235, 53, 681, 1463, 2093, 1525, 12797, 5469, 54277, 15587, 68395, 0 };
            const std::uint32_t dim15676JoeKuoD6Init[]   =   { 1, 1, 1, 15, 23, 63, 63, 225, 239, 143, 1073, 199, 3231, 1371, 11215, 5999, 100705, 174681, 0 };
            const std::uint32_t dim15677JoeKuoD6Init[]   =   { 1, 1, 1, 3, 17, 25, 69, 179, 445, 695, 281, 379, 8115, 9443, 13221, 50669, 37369, 62151, 0 };
            const std::uint32_t dim15678JoeKuoD6Init[]   =   { 1, 3, 3, 9, 11, 29, 21, 89, 441, 353, 401, 1139, 5003, 8087, 24457, 50237, 110993, 117233, 0 };
            const std::uint32_t dim15679JoeKuoD6Init[]   =   { 1, 3, 3, 1, 13, 45, 31, 249, 295, 149, 591, 2071, 3611, 931, 16261, 8239, 82767, 195665, 0 };
            const std::uint32_t dim15680JoeKuoD6Init[]   =   { 1, 3, 3, 9, 19, 47, 69, 177, 493, 231, 431, 1359, 6867, 7641, 15661, 25285, 65477, 212643, 0 };
            const std::uint32_t dim15681JoeKuoD6Init[]   =   { 1, 3, 3, 13, 19, 63, 83, 153, 367, 407, 547, 661, 7743, 5473, 2993, 62937, 33811, 101313, 0 };
            const std::uint32_t dim15682JoeKuoD6Init[]   =   { 1, 3, 5, 3, 29, 17, 19, 203, 79, 279, 1333, 1851, 51, 9793, 12955, 17383, 73437, 121743, 0 };
            const std::uint32_t dim15683JoeKuoD6Init[]   =   { 1, 1, 1, 11, 11, 43, 31, 187, 463, 827, 1511, 225, 845, 8963, 1553, 61269, 122033, 245633, 0 };
            const std::uint32_t dim15684JoeKuoD6Init[]   =   { 1, 1, 3, 3, 31, 23, 9, 241, 377, 317, 655, 2197, 2461, 13239, 15649, 7879, 55085, 129855, 0 };
            const std::uint32_t dim15685JoeKuoD6Init[]   =   { 1, 3, 5, 7, 9, 37, 1, 191, 185, 145, 1567, 3423, 1127, 1991, 10741, 38407, 22915, 222845, 0 };
            const std::uint32_t dim15686JoeKuoD6Init[]   =   { 1, 1, 5, 3, 27, 31, 11, 227, 307, 973, 745, 1079, 7479, 10065, 31389, 19195, 114775, 246615, 0 };
            const std::uint32_t dim15687JoeKuoD6Init[]   =   { 1, 3, 1, 11, 29, 27, 11, 83, 205, 399, 1489, 739, 715, 7955, 16473, 21127, 62379, 260399, 0 };
            const std::uint32_t dim15688JoeKuoD6Init[]   =   { 1, 3, 3, 3, 25, 25, 123, 163, 399, 841, 963, 2089, 4949, 13085, 19831, 15345, 60377, 164235, 0 };
            const std::uint32_t dim15689JoeKuoD6Init[]   =   { 1, 1, 1, 9, 3, 21, 101, 105, 397, 23, 1505, 3201, 547, 295, 23247, 18823, 115243, 151073, 0 };
            const std::uint32_t dim15690JoeKuoD6Init[]   =   { 1, 3, 7, 1, 31, 27, 111, 23, 205, 709, 1625, 3921, 6225, 11039, 29549, 51239, 119003, 133663, 0 };
            const std::uint32_t dim15691JoeKuoD6Init[]   =   { 1, 3, 3, 11, 21, 49, 111, 195, 25, 833, 1991, 563, 7031, 15429, 5707, 12351, 32221, 16599, 0 };
            const std::uint32_t dim15692JoeKuoD6Init[]   =   { 1, 1, 5, 7, 5, 7, 39, 171, 39, 921, 385, 2343, 625, 15355, 4923, 36597, 56901, 148377, 0 };
            const std::uint32_t dim15693JoeKuoD6Init[]   =   { 1, 1, 3, 15, 7, 43, 89, 217, 67, 271, 853, 147, 6767, 3183, 341, 40769, 116767, 22351, 0 };
            const std::uint32_t dim15694JoeKuoD6Init[]   =   { 1, 3, 5, 7, 7, 3, 105, 27, 183, 59, 953, 4027, 1277, 10323, 29437, 56085, 32677, 198067, 0 };
            const std::uint32_t dim15695JoeKuoD6Init[]   =   { 1, 1, 1, 15, 23, 29, 51, 209, 13, 177, 1103, 1723, 2877, 9199, 25601, 15537, 8599, 230819, 0 };
            const std::uint32_t dim15696JoeKuoD6Init[]   =   { 1, 1, 7, 1, 29, 39, 41, 217, 467, 423, 431, 2707, 2017, 11865, 11989, 12045, 71349, 6311, 0 };
            const std::uint32_t dim15697JoeKuoD6Init[]   =   { 1, 1, 1, 13, 15, 25, 3, 55, 403, 833, 1843, 1159, 1703, 2221, 15379, 65027, 18327, 108881, 0 };
            const std::uint32_t dim15698JoeKuoD6Init[]   =   { 1, 3, 7, 13, 3, 27, 13, 227, 215, 873, 1073, 1117, 7941, 13607, 7571, 6957, 44991, 239761, 0 };
            const std::uint32_t dim15699JoeKuoD6Init[]   =   { 1, 3, 7, 11, 23, 1, 95, 235, 283, 977, 1443, 161, 5937, 4351, 30835, 35569, 57509, 1835, 0 };
            const std::uint32_t dim15700JoeKuoD6Init[]   =   { 1, 3, 3, 13, 11, 1, 85, 75, 261, 543, 9, 899, 5821, 5465, 9771, 53707, 101003, 219215, 0 };
            const std::uint32_t dim15701JoeKuoD6Init[]   =   { 1, 3, 1, 7, 21, 49, 35, 19, 35, 759, 1467, 1423, 6355, 8415, 563, 24157, 121029, 87309, 0 };
            const std::uint32_t dim15702JoeKuoD6Init[]   =   { 1, 1, 7, 1, 9, 13, 65, 85, 209, 583, 387, 1743, 2665, 12021, 7525, 27665, 45885, 135039, 0 };
            const std::uint32_t dim15703JoeKuoD6Init[]   =   { 1, 1, 7, 11, 29, 41, 91, 17, 291, 211, 1801, 493, 899, 14491, 1741, 28971, 35205, 131417, 0 };
            const std::uint32_t dim15704JoeKuoD6Init[]   =   { 1, 1, 5, 13, 23, 55, 119, 165, 61, 653, 1375, 3575, 5081, 7767, 19963, 61583, 107149, 240639, 0 };
            const std::uint32_t dim15705JoeKuoD6Init[]   =   { 1, 3, 5, 15, 25, 3, 51, 27, 127, 259, 55, 2221, 3951, 6243, 15825, 42881, 37009, 254401, 0 };
            const std::uint32_t dim15706JoeKuoD6Init[]   =   { 1, 3, 5, 11, 25, 63, 13, 105, 111, 677, 1545, 2399, 4419, 10853, 7213, 17183, 103411, 67459, 0 };
            const std::uint32_t dim15707JoeKuoD6Init[]   =   { 1, 1, 1, 11, 11, 31, 73, 125, 155, 545, 1857, 2749, 6389, 4083, 16239, 23651, 68881, 43455, 0 };
            const std::uint32_t dim15708JoeKuoD6Init[]   =   { 1, 3, 7, 7, 21, 3, 117, 237, 431, 17, 687, 2613, 7483, 3253, 30511, 53833, 33077, 157055, 0 };
            const std::uint32_t dim15709JoeKuoD6Init[]   =   { 1, 1, 1, 1, 1, 57, 65, 97, 415, 477, 1003, 1415, 1493, 12993, 30965, 24809, 1467, 213021, 0 };
            const std::uint32_t dim15710JoeKuoD6Init[]   =   { 1, 1, 3, 7, 25, 33, 45, 25, 511, 733, 1077, 2483, 5899, 14295, 11631, 50609, 128989, 45177, 0 };
            const std::uint32_t dim15711JoeKuoD6Init[]   =   { 1, 1, 3, 3, 25, 17, 115, 31, 115, 191, 293, 3991, 3039, 6751, 16217, 16517, 21121, 193641, 0 };
            const std::uint32_t dim15712JoeKuoD6Init[]   =   { 1, 3, 3, 13, 25, 23, 7, 51, 363, 641, 333, 2533, 605, 1105, 12941, 4195, 129571, 13253, 0 };
            const std::uint32_t dim15713JoeKuoD6Init[]   =   { 1, 3, 1, 11, 17, 21, 7, 205, 293, 159, 9, 441, 3287, 10247, 2115, 54099, 128109, 8137, 0 };
            const std::uint32_t dim15714JoeKuoD6Init[]   =   { 1, 1, 7, 5, 21, 17, 43, 87, 117, 737, 149, 3175, 343, 8509, 12147, 22041, 80037, 23277, 0 };
            const std::uint32_t dim15715JoeKuoD6Init[]   =   { 1, 3, 3, 1, 3, 7, 101, 245, 11, 1003, 175, 2323, 7807, 15611, 5161, 10277, 37009, 83231, 0 };
            const std::uint32_t dim15716JoeKuoD6Init[]   =   { 1, 3, 1, 5, 13, 17, 113, 75, 315, 237, 77, 587, 5409, 2053, 22551, 15205, 82545, 18531, 0 };
            const std::uint32_t dim15717JoeKuoD6Init[]   =   { 1, 3, 5, 11, 9, 57, 61, 117, 281, 111, 369, 2411, 1691, 3391, 5379, 8237, 87329, 4253, 0 };
            const std::uint32_t dim15718JoeKuoD6Init[]   =   { 1, 3, 3, 3, 19, 25, 101, 1, 495, 25, 1317, 2333, 6183, 12215, 27879, 56403, 37169, 71635, 0 };
            const std::uint32_t dim15719JoeKuoD6Init[]   =   { 1, 1, 3, 5, 17, 63, 49, 127, 171, 405, 1763, 3697, 405, 2233, 4137, 28787, 108319, 53133, 0 };
            const std::uint32_t dim15720JoeKuoD6Init[]   =   { 1, 1, 5, 7, 23, 43, 87, 189, 97, 239, 1459, 2115, 7517, 7799, 28957, 37105, 71835, 199195, 0 };
            const std::uint32_t dim15721JoeKuoD6Init[]   =   { 1, 3, 1, 3, 25, 25, 23, 61, 369, 717, 1711, 1103, 7535, 9871, 25, 26849, 55955, 113389, 0 };
            const std::uint32_t dim15722JoeKuoD6Init[]   =   { 1, 1, 1, 11, 25, 57, 33, 175, 127, 541, 1031, 2847, 2069, 4033, 25593, 10615, 50097, 122955, 0 };
            const std::uint32_t dim15723JoeKuoD6Init[]   =   { 1, 3, 3, 13, 11, 27, 97, 171, 245, 33, 213, 4069, 753, 3535, 11727, 34941, 100543, 220789, 0 };
            const std::uint32_t dim15724JoeKuoD6Init[]   =   { 1, 3, 3, 9, 3, 17, 13, 237, 477, 507, 1751, 3191, 3385, 13977, 23355, 57355, 64341, 37683, 0 };
            const std::uint32_t dim15725JoeKuoD6Init[]   =   { 1, 1, 7, 13, 13, 43, 7, 153, 209, 7, 63, 585, 1715, 13313, 25355, 46759, 71893, 29755, 0 };
            const std::uint32_t dim15726JoeKuoD6Init[]   =   { 1, 3, 3, 3, 11, 23, 11, 147, 135, 1011, 1105, 3931, 3861, 13589, 32183, 30727, 37685, 67123, 0 };
            const std::uint32_t dim15727JoeKuoD6Init[]   =   { 1, 3, 7, 1, 11, 13, 25, 229, 147, 843, 329, 3337, 7559, 13193, 3011, 31549, 102461, 46195, 0 };
            const std::uint32_t dim15728JoeKuoD6Init[]   =   { 1, 1, 5, 11, 5, 47, 127, 89, 53, 663, 261, 541, 7743, 13037, 9013, 23079, 81225, 239875, 0 };
            const std::uint32_t dim15729JoeKuoD6Init[]   =   { 1, 1, 7, 3, 5, 39, 15, 177, 357, 357, 1959, 1721, 6703, 11829, 1195, 42113, 88699, 244347, 0 };
            const std::uint32_t dim15730JoeKuoD6Init[]   =   { 1, 1, 5, 15, 25, 19, 7, 3, 225, 773, 1535, 99, 6555, 4105, 19137, 56155, 109141, 161015, 0 };
            const std::uint32_t dim15731JoeKuoD6Init[]   =   { 1, 1, 5, 15, 5, 59, 41, 53, 203, 459, 1063, 3015, 5397, 1559, 20835, 57773, 67687, 206189, 0 };
            const std::uint32_t dim15732JoeKuoD6Init[]   =   { 1, 3, 1, 11, 17, 25, 61, 221, 37, 809, 1461, 1961, 7697, 1777, 23179, 54761, 7787, 177737, 0 };
            const std::uint32_t dim15733JoeKuoD6Init[]   =   { 1, 3, 7, 15, 27, 21, 49, 107, 353, 677, 461, 239, 5871, 1059, 3011, 32397, 13149, 103973, 0 };
            const std::uint32_t dim15734JoeKuoD6Init[]   =   { 1, 1, 5, 3, 11, 53, 61, 239, 479, 913, 479, 3435, 4979, 7931, 16841, 60077, 26667, 212601, 0 };
            const std::uint32_t dim15735JoeKuoD6Init[]   =   { 1, 1, 3, 5, 3, 19, 43, 143, 353, 507, 871, 2547, 7321, 6163, 9425, 62911, 86153, 239011, 0 };
            const std::uint32_t dim15736JoeKuoD6Init[]   =   { 1, 1, 1, 3, 15, 7, 115, 43, 69, 299, 1235, 1511, 3111, 7465, 769, 46981, 127707, 195839, 0 };
            const std::uint32_t dim15737JoeKuoD6Init[]   =   { 1, 1, 1, 5, 23, 27, 19, 21, 273, 291, 953, 3577, 3147, 3863, 18625, 53505, 33699, 123305, 0 };
            const std::uint32_t dim15738JoeKuoD6Init[]   =   { 1, 3, 5, 9, 3, 11, 89, 27, 447, 119, 493, 2605, 8175, 8837, 27555, 2319, 99101, 79121, 0 };
            const std::uint32_t dim15739JoeKuoD6Init[]   =   { 1, 1, 7, 11, 1, 11, 77, 129, 97, 261, 1241, 3117, 1627, 5397, 6495, 52339, 52711, 206237, 0 };
            const std::uint32_t dim15740JoeKuoD6Init[]   =   { 1, 3, 7, 9, 27, 57, 77, 147, 35, 845, 1417, 1615, 6097, 12559, 10765, 19027, 91693, 204339, 0 };
            const std::uint32_t dim15741JoeKuoD6Init[]   =   { 1, 1, 3, 5, 25, 47, 17, 145, 7, 969, 1981, 733, 4303, 7785, 4241, 39733, 82569, 78061, 0 };
            const std::uint32_t dim15742JoeKuoD6Init[]   =   { 1, 1, 5, 1, 5, 47, 45, 111, 405, 943, 1911, 1613, 3817, 10483, 17729, 7201, 88033, 261701, 0 };
            const std::uint32_t dim15743JoeKuoD6Init[]   =   { 1, 3, 3, 13, 9, 3, 87, 39, 277, 769, 57, 2503, 7803, 11041, 20945, 19623, 32617, 110027, 0 };
            const std::uint32_t dim15744JoeKuoD6Init[]   =   { 1, 1, 3, 3, 27, 57, 1, 103, 427, 935, 1617, 665, 837, 8001, 13543, 44771, 64033, 65239, 0 };
            const std::uint32_t dim15745JoeKuoD6Init[]   =   { 1, 1, 5, 3, 13, 21, 31, 59, 225, 945, 1825, 1511, 3273, 3171, 30347, 21993, 40203, 143297, 0 };
            const std::uint32_t dim15746JoeKuoD6Init[]   =   { 1, 3, 5, 7, 11, 3, 3, 217, 167, 885, 975, 3249, 7909, 13621, 18697, 61021, 31497, 198033, 0 };
            const std::uint32_t dim15747JoeKuoD6Init[]   =   { 1, 3, 5, 9, 11, 5, 87, 33, 117, 471, 267, 529, 5879, 13969, 5731, 52613, 106411, 74341, 0 };
            const std::uint32_t dim15748JoeKuoD6Init[]   =   { 1, 1, 7, 11, 5, 31, 25, 55, 135, 779, 717, 1953, 7929, 11011, 6133, 14099, 106975, 178337, 0 };
            const std::uint32_t dim15749JoeKuoD6Init[]   =   { 1, 3, 1, 1, 29, 17, 125, 7, 445, 299, 1897, 3235, 8189, 14339, 14725, 63185, 126751, 88747, 0 };
            const std::uint32_t dim15750JoeKuoD6Init[]   =   { 1, 1, 5, 3, 1, 11, 65, 161, 243, 605, 1945, 3141, 6443, 9703, 13331, 2239, 6315, 247595, 0 };
            const std::uint32_t dim15751JoeKuoD6Init[]   =   { 1, 3, 1, 7, 15, 23, 83, 215, 331, 631, 453, 879, 4109, 4897, 16535, 55749, 90799, 147287, 0 };
            const std::uint32_t dim15752JoeKuoD6Init[]   =   { 1, 3, 5, 13, 25, 1, 109, 205, 49, 471, 1735, 973, 1279, 9917, 18225, 44921, 98519, 211541, 0 };
            const std::uint32_t dim15753JoeKuoD6Init[]   =   { 1, 1, 5, 11, 29, 41, 113, 187, 75, 479, 1633, 841, 6259, 8919, 27751, 25179, 115369, 166567, 0 };
            const std::uint32_t dim15754JoeKuoD6Init[]   =   { 1, 3, 5, 11, 17, 31, 107, 41, 435, 647, 811, 2937, 5819, 3483, 3835, 57033, 53543, 61973, 0 };
            const std::uint32_t dim15755JoeKuoD6Init[]   =   { 1, 3, 3, 11, 15, 45, 33, 103, 505, 67, 463, 1275, 2449, 15261, 22867, 25215, 38793, 189309, 0 };
            const std::uint32_t dim15756JoeKuoD6Init[]   =   { 1, 1, 1, 5, 19, 45, 35, 173, 365, 39, 1599, 3623, 2231, 12141, 19437, 27053, 15869, 104719, 0 };
            const std::uint32_t dim15757JoeKuoD6Init[]   =   { 1, 3, 7, 7, 9, 17, 87, 151, 249, 81, 1109, 1951, 7475, 1699, 17847, 64149, 50285, 242793, 0 };
            const std::uint32_t dim15758JoeKuoD6Init[]   =   { 1, 3, 5, 13, 15, 51, 35, 105, 479, 763, 1945, 2349, 2987, 621, 283, 20411, 65799, 86517, 0 };
            const std::uint32_t dim15759JoeKuoD6Init[]   =   { 1, 3, 3, 1, 19, 31, 49, 229, 249, 689, 737, 4027, 5405, 15211, 26785, 39143, 93163, 190421, 0 };
            const std::uint32_t dim15760JoeKuoD6Init[]   =   { 1, 3, 7, 5, 1, 21, 63, 97, 347, 73, 745, 3455, 2347, 3821, 31385, 6545, 91803, 72895, 0 };
            const std::uint32_t dim15761JoeKuoD6Init[]   =   { 1, 1, 1, 15, 23, 11, 107, 47, 183, 235, 1985, 3277, 933, 8491, 14423, 24293, 6783, 162199, 0 };
            const std::uint32_t dim15762JoeKuoD6Init[]   =   { 1, 3, 3, 9, 17, 3, 123, 59, 277, 773, 1617, 2979, 1555, 9753, 10947, 24745, 89043, 45185, 0 };
            const std::uint32_t dim15763JoeKuoD6Init[]   =   { 1, 3, 7, 3, 25, 17, 79, 43, 311, 415, 1045, 1289, 7451, 11413, 11319, 37177, 101327, 147453, 0 };
            const std::uint32_t dim15764JoeKuoD6Init[]   =   { 1, 3, 7, 7, 17, 45, 49, 33, 313, 613, 1773, 773, 161, 13579, 1207, 5681, 120597, 178639, 0 };
            const std::uint32_t dim15765JoeKuoD6Init[]   =   { 1, 3, 5, 5, 17, 43, 65, 243, 287, 223, 253, 687, 887, 14887, 1077, 53337, 62381, 43531, 0 };
            const std::uint32_t dim15766JoeKuoD6Init[]   =   { 1, 3, 5, 1, 21, 3, 39, 149, 497, 939, 1537, 437, 5345, 10321, 25151, 48785, 49879, 90945, 0 };
            const std::uint32_t dim15767JoeKuoD6Init[]   =   { 1, 1, 7, 11, 1, 61, 113, 63, 285, 615, 343, 2897, 1939, 7911, 16387, 10781, 92769, 27995, 0 };
            const std::uint32_t dim15768JoeKuoD6Init[]   =   { 1, 1, 3, 3, 19, 29, 85, 227, 355, 857, 883, 1853, 5065, 13795, 5749, 59107, 57947, 35775, 0 };
            const std::uint32_t dim15769JoeKuoD6Init[]   =   { 1, 3, 5, 9, 23, 37, 119, 161, 23, 511, 81, 973, 4769, 10821, 32607, 61731, 64907, 99055, 0 };
            const std::uint32_t dim15770JoeKuoD6Init[]   =   { 1, 3, 1, 3, 11, 17, 109, 241, 349, 887, 1651, 3865, 2045, 15893, 4597, 11557, 53313, 48489, 0 };
            const std::uint32_t dim15771JoeKuoD6Init[]   =   { 1, 1, 5, 9, 31, 43, 49, 193, 171, 477, 363, 735, 1379, 8977, 9759, 56477, 99495, 170433, 0 };
            const std::uint32_t dim15772JoeKuoD6Init[]   =   { 1, 1, 3, 7, 25, 25, 77, 31, 21, 1001, 1527, 1725, 6479, 8927, 11249, 63969, 86291, 74391, 0 };
            const std::uint32_t dim15773JoeKuoD6Init[]   =   { 1, 3, 5, 13, 1, 43, 27, 7, 507, 569, 251, 2199, 3895, 7845, 13641, 1655, 112949, 119493, 0 };
            const std::uint32_t dim15774JoeKuoD6Init[]   =   { 1, 3, 7, 15, 7, 1, 123, 27, 121, 261, 201, 1469, 4229, 2933, 25157, 1919, 127937, 21607, 0 };
            const std::uint32_t dim15775JoeKuoD6Init[]   =   { 1, 1, 3, 9, 29, 59, 47, 81, 293, 191, 401, 849, 4355, 1643, 23533, 8469, 389, 97891, 0 };
            const std::uint32_t dim15776JoeKuoD6Init[]   =   { 1, 3, 5, 5, 9, 55, 37, 175, 203, 179, 901, 3473, 1489, 1009, 24623, 54895, 8711, 190271, 0 };
            const std::uint32_t dim15777JoeKuoD6Init[]   =   { 1, 1, 7, 1, 13, 39, 49, 105, 385, 189, 1079, 2799, 5901, 2511, 23199, 58925, 111727, 131193, 0 };
            const std::uint32_t dim15778JoeKuoD6Init[]   =   { 1, 1, 1, 7, 31, 63, 37, 181, 493, 745, 1131, 223, 8055, 9507, 26667, 22163, 26495, 200945, 0 };
            const std::uint32_t dim15779JoeKuoD6Init[]   =   { 1, 3, 7, 1, 25, 15, 127, 71, 445, 935, 1439, 1167, 3751, 799, 27253, 46209, 33413, 38553, 0 };
            const std::uint32_t dim15780JoeKuoD6Init[]   =   { 1, 3, 3, 11, 29, 35, 125, 77, 129, 851, 731, 3259, 4651, 4137, 20921, 19779, 119261, 141507, 0 };
            const std::uint32_t dim15781JoeKuoD6Init[]   =   { 1, 3, 1, 9, 11, 13, 31, 211, 87, 377, 547, 113, 1071, 7167, 28377, 52943, 50669, 156915, 0 };
            const std::uint32_t dim15782JoeKuoD6Init[]   =   { 1, 1, 3, 7, 29, 55, 89, 215, 425, 513, 175, 1145, 6995, 1929, 14253, 20563, 118543, 104403, 0 };
            const std::uint32_t dim15783JoeKuoD6Init[]   =   { 1, 1, 1, 5, 23, 25, 1, 23, 175, 571, 1597, 3801, 1411, 1783, 13045, 37499, 86831, 139101, 0 };
            const std::uint32_t dim15784JoeKuoD6Init[]   =   { 1, 3, 3, 13, 15, 19, 35, 139, 483, 17, 1555, 3431, 3417, 13695, 15985, 65243, 96659, 76027, 0 };
            const std::uint32_t dim15785JoeKuoD6Init[]   =   { 1, 3, 7, 9, 23, 7, 17, 89, 33, 353, 1999, 2561, 331, 15661, 25757, 63389, 112913, 131757, 0 };
            const std::uint32_t dim15786JoeKuoD6Init[]   =   { 1, 3, 1, 11, 27, 59, 37, 75, 121, 429, 1833, 3243, 2029, 2601, 5013, 29433, 123565, 234803, 0 };
            const std::uint32_t dim15787JoeKuoD6Init[]   =   { 1, 3, 1, 7, 31, 13, 33, 25, 459, 803, 267, 1573, 5579, 4575, 8125, 7491, 72681, 239409, 0 };
            const std::uint32_t dim15788JoeKuoD6Init[]   =   { 1, 1, 3, 7, 31, 43, 93, 191, 237, 75, 1809, 3257, 4131, 1983, 29153, 23205, 38393, 197859, 0 };
            const std::uint32_t dim15789JoeKuoD6Init[]   =   { 1, 3, 5, 5, 17, 47, 17, 153, 499, 529, 1515, 1587, 2951, 12431, 12787, 13245, 54117, 82663, 0 };
            const std::uint32_t dim15790JoeKuoD6Init[]   =   { 1, 1, 1, 13, 7, 23, 23, 7, 441, 991, 641, 2713, 151, 1863, 6065, 47381, 60493, 136325, 0 };
            const std::uint32_t dim15791JoeKuoD6Init[]   =   { 1, 3, 3, 11, 11, 15, 31, 137, 285, 439, 835, 3033, 6083, 7883, 3405, 35803, 65059, 150143, 0 };
            const std::uint32_t dim15792JoeKuoD6Init[]   =   { 1, 1, 7, 3, 19, 47, 61, 163, 313, 813, 1315, 2995, 2805, 14397, 6589, 62123, 46229, 206697, 0 };
            const std::uint32_t dim15793JoeKuoD6Init[]   =   { 1, 3, 5, 5, 27, 51, 25, 99, 241, 571, 1411, 1191, 7095, 8639, 29195, 53733, 53219, 42851, 0 };
            const std::uint32_t dim15794JoeKuoD6Init[]   =   { 1, 3, 1, 5, 11, 29, 1, 49, 61, 149, 1931, 29, 7163, 3717, 525, 42375, 71451, 8345, 0 };
            const std::uint32_t dim15795JoeKuoD6Init[]   =   { 1, 3, 3, 3, 13, 19, 97, 249, 265, 509, 1347, 3081, 6535, 7941, 31565, 59897, 91909, 171789, 0 };
            const std::uint32_t dim15796JoeKuoD6Init[]   =   { 1, 3, 3, 1, 25, 17, 75, 169, 251, 607, 73, 549, 1397, 10661, 1743, 9615, 41327, 243207, 0 };
            const std::uint32_t dim15797JoeKuoD6Init[]   =   { 1, 3, 1, 11, 7, 7, 15, 181, 385, 883, 651, 2939, 5457, 15309, 9807, 22221, 72893, 146331, 0 };
            const std::uint32_t dim15798JoeKuoD6Init[]   =   { 1, 3, 3, 5, 7, 7, 53, 75, 139, 459, 1861, 917, 4101, 10379, 18555, 12633, 70023, 254761, 0 };
            const std::uint32_t dim15799JoeKuoD6Init[]   =   { 1, 3, 3, 1, 17, 51, 5, 109, 471, 3, 1555, 3731, 6711, 9791, 63, 61931, 75269, 138697, 0 };
            const std::uint32_t dim15800JoeKuoD6Init[]   =   { 1, 1, 7, 15, 11, 1, 53, 141, 423, 567, 1937, 849, 5657, 7437, 32657, 16253, 115219, 106027, 0 };
            const std::uint32_t dim15801JoeKuoD6Init[]   =   { 1, 3, 5, 1, 17, 29, 65, 213, 443, 541, 697, 3859, 1463, 16081, 23299, 7645, 19475, 77857, 0 };
            const std::uint32_t dim15802JoeKuoD6Init[]   =   { 1, 1, 7, 3, 21, 43, 99, 101, 329, 755, 1123, 1277, 1381, 7017, 21763, 28243, 109995, 178377, 0 };
            const std::uint32_t dim15803JoeKuoD6Init[]   =   { 1, 3, 5, 7, 9, 31, 103, 123, 43, 895, 1925, 3383, 3539, 13669, 873, 57361, 45281, 256517, 0 };
            const std::uint32_t dim15804JoeKuoD6Init[]   =   { 1, 1, 1, 13, 1, 37, 115, 55, 415, 703, 1217, 939, 1145, 4015, 7233, 44799, 79711, 164725, 0 };
            const std::uint32_t dim15805JoeKuoD6Init[]   =   { 1, 1, 7, 1, 29, 17, 101, 15, 205, 281, 1059, 301, 753, 11953, 10533, 31881, 67741, 12683, 0 };
            const std::uint32_t dim15806JoeKuoD6Init[]   =   { 1, 1, 7, 13, 9, 23, 31, 237, 181, 813, 1765, 2237, 4897, 9955, 2139, 13113, 123423, 227629, 0 };
            const std::uint32_t dim15807JoeKuoD6Init[]   =   { 1, 1, 7, 15, 27, 57, 37, 75, 405, 185, 1671, 2245, 7151, 10531, 13161, 15695, 107547, 47689, 0 };
            const std::uint32_t dim15808JoeKuoD6Init[]   =   { 1, 1, 5, 15, 17, 53, 75, 251, 277, 1001, 179, 589, 1401, 4937, 11601, 47113, 36677, 39263, 0 };
            const std::uint32_t dim15809JoeKuoD6Init[]   =   { 1, 3, 5, 15, 23, 47, 53, 81, 115, 547, 1363, 2457, 4407, 10861, 25649, 64013, 44747, 97949, 0 };
            const std::uint32_t dim15810JoeKuoD6Init[]   =   { 1, 1, 3, 1, 25, 29, 121, 43, 205, 591, 211, 1899, 5835, 739, 19627, 60387, 127369, 11255, 0 };
            const std::uint32_t dim15811JoeKuoD6Init[]   =   { 1, 1, 3, 15, 31, 11, 93, 227, 501, 731, 1355, 3963, 347, 83, 12595, 56431, 80049, 42103, 0 };
            const std::uint32_t dim15812JoeKuoD6Init[]   =   { 1, 3, 1, 11, 13, 17, 51, 165, 311, 67, 1873, 1493, 3815, 13209, 11637, 5809, 94219, 118077, 0 };
            const std::uint32_t dim15813JoeKuoD6Init[]   =   { 1, 1, 7, 15, 19, 17, 13, 73, 365, 413, 1215, 2265, 2173, 8725, 4725, 1373, 76733, 95379, 0 };
            const std::uint32_t dim15814JoeKuoD6Init[]   =   { 1, 3, 1, 7, 7, 61, 13, 145, 205, 113, 1579, 3851, 7515, 10659, 28665, 5277, 65925, 10141, 0 };
            const std::uint32_t dim15815JoeKuoD6Init[]   =   { 1, 3, 7, 1, 9, 63, 11, 83, 197, 797, 1065, 1521, 1751, 7423, 7473, 4371, 29533, 225167, 0 };
            const std::uint32_t dim15816JoeKuoD6Init[]   =   { 1, 3, 7, 7, 3, 63, 71, 177, 53, 279, 1837, 2609, 7819, 7285, 11059, 65247, 102869, 24429, 0 };
            const std::uint32_t dim15817JoeKuoD6Init[]   =   { 1, 3, 3, 13, 9, 21, 123, 125, 367, 85, 85, 1009, 1009, 7779, 3375, 30999, 5035, 215107, 0 };
            const std::uint32_t dim15818JoeKuoD6Init[]   =   { 1, 3, 3, 9, 31, 53, 5, 43, 483, 483, 1359, 2605, 377, 4243, 13291, 50211, 118603, 259865, 0 };
            const std::uint32_t dim15819JoeKuoD6Init[]   =   { 1, 1, 1, 5, 19, 37, 109, 139, 373, 79, 1951, 3379, 5679, 6445, 29127, 56229, 97369, 232561, 0 };
            const std::uint32_t dim15820JoeKuoD6Init[]   =   { 1, 1, 3, 5, 19, 37, 61, 225, 321, 573, 1831, 971, 6507, 10005, 6837, 16433, 70913, 170873, 0 };
            const std::uint32_t dim15821JoeKuoD6Init[]   =   { 1, 1, 5, 11, 31, 17, 21, 29, 329, 679, 869, 389, 5121, 1819, 3539, 43793, 31617, 204983, 0 };
            const std::uint32_t dim15822JoeKuoD6Init[]   =   { 1, 1, 7, 7, 21, 11, 83, 97, 297, 275, 1559, 1899, 4957, 11463, 25647, 21095, 70121, 113395, 0 };
            const std::uint32_t dim15823JoeKuoD6Init[]   =   { 1, 3, 5, 11, 19, 57, 39, 37, 441, 715, 383, 4083, 1937, 12263, 6989, 36159, 118135, 238475, 0 };
            const std::uint32_t dim15824JoeKuoD6Init[]   =   { 1, 1, 1, 3, 9, 53, 85, 201, 357, 807, 865, 1621, 1993, 7623, 3165, 1005, 93343, 227765, 0 };
            const std::uint32_t dim15825JoeKuoD6Init[]   =   { 1, 1, 7, 7, 21, 29, 123, 175, 319, 621, 303, 117, 5589, 12511, 26053, 41603, 78439, 71819, 0 };
            const std::uint32_t dim15826JoeKuoD6Init[]   =   { 1, 1, 7, 15, 31, 47, 75, 225, 295, 67, 1349, 1749, 1363, 8763, 9153, 4059, 72015, 3155, 0 };
            const std::uint32_t dim15827JoeKuoD6Init[]   =   { 1, 3, 5, 13, 19, 23, 79, 25, 319, 475, 1517, 2757, 4009, 12663, 535, 51617, 55695, 64399, 0 };
            const std::uint32_t dim15828JoeKuoD6Init[]   =   { 1, 3, 7, 13, 19, 39, 61, 235, 369, 951, 111, 2169, 353, 15371, 8611, 42477, 130981, 97419, 0 };
            const std::uint32_t dim15829JoeKuoD6Init[]   =   { 1, 1, 3, 13, 27, 31, 115, 201, 3, 291, 793, 237, 3593, 2307, 12745, 54603, 96451, 80853, 0 };
            const std::uint32_t dim15830JoeKuoD6Init[]   =   { 1, 3, 3, 11, 11, 35, 43, 1, 35, 415, 1307, 2303, 5407, 6883, 29023, 31271, 119721, 90599, 0 };
            const std::uint32_t dim15831JoeKuoD6Init[]   =   { 1, 1, 5, 9, 21, 23, 3, 1, 333, 463, 1277, 1165, 6521, 4887, 16029, 32537, 43681, 21633, 0 };
            const std::uint32_t dim15832JoeKuoD6Init[]   =   { 1, 1, 1, 13, 1, 35, 45, 57, 293, 435, 1113, 2477, 6641, 14083, 28489, 26189, 44695, 220481, 0 };
            const std::uint32_t dim15833JoeKuoD6Init[]   =   { 1, 3, 5, 5, 5, 31, 75, 149, 309, 921, 941, 1063, 7041, 12651, 29533, 46955, 88133, 89989, 0 };
            const std::uint32_t dim15834JoeKuoD6Init[]   =   { 1, 1, 3, 5, 15, 23, 127, 143, 193, 739, 281, 991, 3731, 16243, 25483, 24979, 102317, 186657, 0 };
            const std::uint32_t dim15835JoeKuoD6Init[]   =   { 1, 1, 3, 13, 3, 63, 23, 69, 181, 163, 1733, 893, 5513, 1525, 31483, 15033, 108021, 167875, 0 };
            const std::uint32_t dim15836JoeKuoD6Init[]   =   { 1, 1, 5, 15, 15, 51, 79, 59, 55, 243, 565, 159, 7925, 8393, 20059, 35011, 53779, 166241, 0 };
            const std::uint32_t dim15837JoeKuoD6Init[]   =   { 1, 1, 3, 5, 11, 57, 85, 175, 495, 999, 1577, 2377, 715, 2473, 16979, 5949, 87691, 195607, 0 };
            const std::uint32_t dim15838JoeKuoD6Init[]   =   { 1, 1, 1, 13, 17, 21, 53, 73, 187, 63, 335, 3251, 4439, 5701, 13469, 23567, 70125, 68931, 0 };
            const std::uint32_t dim15839JoeKuoD6Init[]   =   { 1, 1, 1, 13, 23, 11, 55, 75, 37, 845, 745, 2193, 7113, 5657, 29449, 41153, 115547, 87261, 0 };
            const std::uint32_t dim15840JoeKuoD6Init[]   =   { 1, 3, 3, 9, 21, 39, 47, 145, 301, 883, 625, 2479, 1089, 3393, 23265, 49577, 81027, 186485, 0 };
            const std::uint32_t dim15841JoeKuoD6Init[]   =   { 1, 1, 3, 7, 3, 11, 37, 117, 79, 905, 493, 265, 1819, 12179, 12361, 27457, 14459, 231837, 0 };
            const std::uint32_t dim15842JoeKuoD6Init[]   =   { 1, 3, 5, 11, 19, 45, 99, 5, 455, 497, 1851, 2349, 5213, 3671, 5871, 43187, 59011, 211167, 0 };
            const std::uint32_t dim15843JoeKuoD6Init[]   =   { 1, 3, 7, 5, 23, 61, 63, 97, 413, 575, 1073, 2587, 573, 1805, 32307, 58463, 84927, 15065, 0 };
            const std::uint32_t dim15844JoeKuoD6Init[]   =   { 1, 3, 1, 13, 23, 9, 39, 1, 53, 383, 1277, 3599, 7719, 16175, 4443, 53143, 24345, 111899, 0 };
            const std::uint32_t dim15845JoeKuoD6Init[]   =   { 1, 1, 7, 1, 19, 37, 103, 245, 253, 5, 1367, 3127, 4689, 5089, 30697, 45513, 111291, 26599, 0 };
            const std::uint32_t dim15846JoeKuoD6Init[]   =   { 1, 3, 3, 7, 31, 31, 107, 163, 1, 855, 163, 875, 7481, 5325, 30107, 19377, 3167, 5613, 0 };
            const std::uint32_t dim15847JoeKuoD6Init[]   =   { 1, 1, 5, 13, 21, 17, 115, 203, 233, 333, 441, 3185, 3197, 3397, 8515, 61879, 11163, 233277, 0 };
            const std::uint32_t dim15848JoeKuoD6Init[]   =   { 1, 3, 5, 3, 17, 53, 93, 233, 465, 573, 1075, 1905, 1141, 4965, 13469, 24901, 23653, 225233, 0 };
            const std::uint32_t dim15849JoeKuoD6Init[]   =   { 1, 3, 7, 11, 11, 1, 95, 47, 85, 65, 9, 2413, 7347, 2127, 305, 4673, 79281, 188081, 0 };
            const std::uint32_t dim15850JoeKuoD6Init[]   =   { 1, 1, 7, 5, 9, 5, 27, 23, 393, 201, 467, 3677, 2641, 4671, 24627, 18927, 45137, 74167, 0 };
            const std::uint32_t dim15851JoeKuoD6Init[]   =   { 1, 3, 5, 11, 11, 9, 19, 247, 423, 693, 1885, 1129, 7459, 8411, 2573, 54111, 98919, 160075, 0 };
            const std::uint32_t dim15852JoeKuoD6Init[]   =   { 1, 3, 3, 3, 1, 3, 67, 131, 317, 915, 151, 3609, 4083, 6395, 12877, 44017, 28877, 244165, 0 };
            const std::uint32_t dim15853JoeKuoD6Init[]   =   { 1, 3, 1, 3, 1, 33, 29, 23, 19, 323, 873, 115, 2439, 4699, 5449, 51637, 68889, 105197, 0 };
            const std::uint32_t dim15854JoeKuoD6Init[]   =   { 1, 1, 7, 1, 19, 55, 37, 241, 53, 695, 729, 1565, 19, 12875, 26993, 18511, 35615, 169281, 0 };
            const std::uint32_t dim15855JoeKuoD6Init[]   =   { 1, 3, 3, 1, 1, 7, 121, 49, 345, 883, 1001, 657, 2647, 15387, 30633, 18107, 13745, 217735, 0 };
            const std::uint32_t dim15856JoeKuoD6Init[]   =   { 1, 3, 5, 15, 11, 45, 73, 77, 307, 373, 1723, 335, 473, 5735, 11747, 39257, 87199, 47663, 0 };
            const std::uint32_t dim15857JoeKuoD6Init[]   =   { 1, 1, 7, 7, 27, 21, 121, 169, 427, 605, 1593, 3147, 1001, 3773, 31505, 22823, 21543, 82931, 0 };
            const std::uint32_t dim15858JoeKuoD6Init[]   =   { 1, 1, 1, 9, 11, 59, 91, 165, 249, 859, 483, 3133, 5729, 12675, 7761, 6475, 116823, 224187, 0 };
            const std::uint32_t dim15859JoeKuoD6Init[]   =   { 1, 1, 3, 3, 27, 31, 51, 1, 429, 517, 1439, 3959, 2343, 6709, 5287, 24039, 52409, 20749, 0 };
            const std::uint32_t dim15860JoeKuoD6Init[]   =   { 1, 3, 7, 7, 11, 31, 83, 111, 391, 729, 721, 1675, 5679, 14637, 22065, 49903, 113759, 40881, 0 };
            const std::uint32_t dim15861JoeKuoD6Init[]   =   { 1, 3, 7, 1, 25, 15, 91, 59, 87, 313, 155, 1439, 2419, 2099, 22709, 10289, 40655, 17351, 0 };
            const std::uint32_t dim15862JoeKuoD6Init[]   =   { 1, 3, 5, 1, 15, 5, 11, 21, 261, 227, 1563, 1177, 4731, 3487, 1607, 46599, 105599, 193425, 0 };
            const std::uint32_t dim15863JoeKuoD6Init[]   =   { 1, 1, 5, 5, 5, 45, 77, 181, 431, 27, 1985, 881, 2555, 7589, 16199, 31041, 66683, 52499, 0 };
            const std::uint32_t dim15864JoeKuoD6Init[]   =   { 1, 1, 1, 15, 5, 29, 111, 209, 335, 747, 93, 3551, 5951, 14995, 18451, 33329, 9117, 167455, 0 };
            const std::uint32_t dim15865JoeKuoD6Init[]   =   { 1, 3, 1, 7, 25, 9, 113, 123, 387, 87, 267, 2251, 3509, 10829, 32733, 48025, 58267, 143553, 0 };
            const std::uint32_t dim15866JoeKuoD6Init[]   =   { 1, 3, 5, 15, 17, 17, 65, 107, 175, 427, 733, 797, 3837, 12773, 27865, 29481, 4557, 196163, 0 };
            const std::uint32_t dim15867JoeKuoD6Init[]   =   { 1, 3, 1, 3, 1, 53, 93, 175, 509, 351, 1093, 1039, 6931, 2691, 14957, 44395, 84383, 58915, 0 };
            const std::uint32_t dim15868JoeKuoD6Init[]   =   { 1, 1, 1, 11, 1, 43, 61, 123, 377, 813, 1335, 1597, 147, 13663, 30781, 47635, 24111, 64307, 0 };
            const std::uint32_t dim15869JoeKuoD6Init[]   =   { 1, 1, 3, 11, 25, 27, 15, 215, 125, 679, 1491, 3203, 5403, 4531, 11839, 44227, 49239, 110439, 0 };
            const std::uint32_t dim15870JoeKuoD6Init[]   =   { 1, 1, 3, 13, 9, 35, 71, 127, 127, 629, 1363, 585, 6713, 10637, 6803, 20963, 47157, 157781, 0 };
            const std::uint32_t dim15871JoeKuoD6Init[]   =   { 1, 1, 3, 11, 13, 21, 117, 241, 365, 175, 1397, 1279, 4117, 5427, 24007, 50711, 465, 225003, 0 };
            const std::uint32_t dim15872JoeKuoD6Init[]   =   { 1, 1, 1, 9, 13, 63, 49, 189, 113, 61, 353, 2221, 7541, 4075, 5283, 5505, 51035, 35191, 0 };
            const std::uint32_t dim15873JoeKuoD6Init[]   =   { 1, 1, 7, 9, 11, 37, 123, 63, 331, 691, 1299, 1661, 3769, 7827, 32127, 32149, 7271, 150363, 0 };
            const std::uint32_t dim15874JoeKuoD6Init[]   =   { 1, 1, 1, 5, 25, 5, 127, 195, 413, 657, 479, 879, 6743, 8959, 791, 22425, 77119, 180721, 0 };
            const std::uint32_t dim15875JoeKuoD6Init[]   =   { 1, 1, 7, 3, 13, 57, 123, 125, 135, 69, 455, 3363, 1783, 1557, 20401, 26707, 130345, 195881, 0 };
            const std::uint32_t dim15876JoeKuoD6Init[]   =   { 1, 3, 3, 7, 27, 19, 125, 71, 201, 1017, 1285, 3955, 5255, 14375, 18163, 28537, 76157, 247193, 0 };
            const std::uint32_t dim15877JoeKuoD6Init[]   =   { 1, 1, 3, 1, 27, 33, 123, 137, 189, 655, 1891, 2419, 5195, 97, 32565, 38581, 62715, 164697, 0 };
            const std::uint32_t dim15878JoeKuoD6Init[]   =   { 1, 1, 1, 15, 9, 47, 23, 147, 197, 503, 1803, 2953, 2961, 13787, 10545, 35465, 53997, 198655, 0 };
            const std::uint32_t dim15879JoeKuoD6Init[]   =   { 1, 3, 1, 9, 9, 43, 65, 237, 119, 621, 1517, 3479, 4165, 12797, 14731, 53131, 105501, 112845, 0 };
            const std::uint32_t dim15880JoeKuoD6Init[]   =   { 1, 3, 3, 15, 3, 23, 47, 163, 469, 363, 1813, 3107, 6167, 8987, 26829, 33099, 6821, 203017, 0 };
            const std::uint32_t dim15881JoeKuoD6Init[]   =   { 1, 1, 1, 9, 1, 11, 85, 11, 251, 907, 395, 3935, 3403, 229, 16825, 48337, 103647, 91425, 0 };
            const std::uint32_t dim15882JoeKuoD6Init[]   =   { 1, 3, 1, 5, 17, 57, 21, 181, 31, 27, 235, 4041, 4927, 8319, 29765, 61603, 19081, 75879, 0 };
            const std::uint32_t dim15883JoeKuoD6Init[]   =   { 1, 1, 5, 15, 11, 3, 7, 225, 247, 221, 251, 1979, 1151, 10829, 26491, 39705, 41587, 99063, 0 };
            const std::uint32_t dim15884JoeKuoD6Init[]   =   { 1, 3, 5, 5, 19, 23, 57, 127, 467, 409, 43, 829, 3883, 10767, 24351, 31365, 115943, 209231, 0 };
            const std::uint32_t dim15885JoeKuoD6Init[]   =   { 1, 1, 7, 15, 3, 51, 17, 251, 219, 33, 1511, 2027, 4995, 12277, 7639, 59895, 85267, 87735, 0 };
            const std::uint32_t dim15886JoeKuoD6Init[]   =   { 1, 3, 7, 3, 7, 29, 93, 57, 427, 235, 1591, 3475, 1159, 2387, 851, 43307, 87081, 151543, 0 };
            const std::uint32_t dim15887JoeKuoD6Init[]   =   { 1, 3, 7, 7, 1, 9, 21, 167, 73, 439, 2035, 2091, 4563, 4819, 5591, 57123, 78739, 63235, 0 };
            const std::uint32_t dim15888JoeKuoD6Init[]   =   { 1, 1, 3, 13, 19, 35, 63, 17, 425, 277, 1669, 931, 597, 5621, 22367, 1155, 109099, 169965, 0 };
            const std::uint32_t dim15889JoeKuoD6Init[]   =   { 1, 3, 7, 5, 11, 11, 41, 71, 35, 183, 555, 2631, 5199, 16381, 16319, 1851, 121551, 141711, 0 };
            const std::uint32_t dim15890JoeKuoD6Init[]   =   { 1, 3, 5, 5, 21, 17, 3, 95, 47, 1011, 1757, 3295, 1111, 16043, 6377, 16257, 37941, 206637, 0 };
            const std::uint32_t dim15891JoeKuoD6Init[]   =   { 1, 3, 1, 5, 25, 19, 19, 69, 395, 589, 1311, 1075, 5763, 12475, 3633, 40647, 54487, 97459, 0 };
            const std::uint32_t dim15892JoeKuoD6Init[]   =   { 1, 3, 5, 7, 13, 23, 83, 91, 419, 415, 685, 1685, 2893, 12953, 30641, 43565, 11851, 187837, 0 };
            const std::uint32_t dim15893JoeKuoD6Init[]   =   { 1, 1, 5, 11, 27, 1, 61, 155, 279, 737, 215, 2909, 969, 57, 17979, 34537, 41861, 243717, 0 };
            const std::uint32_t dim15894JoeKuoD6Init[]   =   { 1, 1, 5, 1, 17, 61, 57, 199, 127, 569, 1109, 3057, 7301, 16097, 17579, 25753, 82653, 237273, 0 };
            const std::uint32_t dim15895JoeKuoD6Init[]   =   { 1, 1, 7, 15, 17, 45, 19, 53, 153, 785, 51, 291, 5261, 1317, 21163, 44393, 108131, 254373, 0 };
            const std::uint32_t dim15896JoeKuoD6Init[]   =   { 1, 1, 3, 11, 5, 19, 61, 125, 127, 961, 2019, 1725, 855, 677, 20853, 38845, 3239, 95697, 0 };
            const std::uint32_t dim15897JoeKuoD6Init[]   =   { 1, 1, 3, 15, 3, 3, 117, 17, 61, 201, 241, 1759, 4465, 3985, 6985, 47703, 58657, 52633, 0 };
            const std::uint32_t dim15898JoeKuoD6Init[]   =   { 1, 3, 3, 11, 31, 39, 107, 171, 19, 825, 1309, 807, 7787, 10761, 20215, 9287, 21553, 179599, 0 };
            const std::uint32_t dim15899JoeKuoD6Init[]   =   { 1, 3, 7, 9, 5, 7, 121, 15, 3, 199, 97, 3177, 5461, 15713, 27609, 54349, 24963, 186279, 0 };
            const std::uint32_t dim15900JoeKuoD6Init[]   =   { 1, 3, 1, 15, 11, 9, 123, 187, 363, 5, 837, 451, 1601, 6597, 10857, 46893, 83729, 20409, 0 };
            const std::uint32_t dim15901JoeKuoD6Init[]   =   { 1, 3, 1, 9, 1, 53, 71, 191, 217, 165, 1709, 1827, 1977, 10073, 11373, 35311, 26637, 134519, 0 };
            const std::uint32_t dim15902JoeKuoD6Init[]   =   { 1, 3, 5, 11, 31, 55, 101, 189, 277, 347, 629, 223, 785, 5739, 25505, 55601, 55017, 212837, 0 };
            const std::uint32_t dim15903JoeKuoD6Init[]   =   { 1, 1, 5, 11, 3, 13, 45, 235, 65, 459, 621, 587, 7105, 6181, 13193, 5683, 42935, 198585, 0 };
            const std::uint32_t dim15904JoeKuoD6Init[]   =   { 1, 1, 3, 1, 3, 17, 27, 109, 261, 979, 903, 1499, 4799, 11759, 10591, 65429, 74587, 16629, 0 };
            const std::uint32_t dim15905JoeKuoD6Init[]   =   { 1, 1, 5, 1, 13, 63, 29, 11, 441, 151, 611, 4073, 3933, 6793, 28845, 39223, 120823, 49397, 0 };
            const std::uint32_t dim15906JoeKuoD6Init[]   =   { 1, 3, 3, 5, 21, 13, 23, 53, 357, 197, 1327, 1773, 2961, 11509, 16585, 10201, 28451, 45109, 0 };
            const std::uint32_t dim15907JoeKuoD6Init[]   =   { 1, 3, 5, 7, 19, 17, 97, 63, 295, 111, 85, 2981, 6719, 9193, 15197, 12117, 2553, 59909, 0 };
            const std::uint32_t dim15908JoeKuoD6Init[]   =   { 1, 1, 5, 5, 15, 3, 9, 85, 333, 379, 1409, 1445, 4173, 3953, 833, 48089, 120249, 122703, 0 };
            const std::uint32_t dim15909JoeKuoD6Init[]   =   { 1, 3, 7, 7, 29, 13, 57, 19, 141, 979, 1991, 4011, 8125, 3915, 15753, 1371, 113771, 117273, 0 };
            const std::uint32_t dim15910JoeKuoD6Init[]   =   { 1, 3, 3, 13, 21, 53, 115, 187, 279, 29, 1355, 1843, 253, 3531, 8193, 54731, 6213, 123467, 0 };
            const std::uint32_t dim15911JoeKuoD6Init[]   =   { 1, 3, 3, 1, 25, 29, 109, 19, 37, 385, 901, 3737, 6247, 9941, 13185, 2895, 88819, 53029, 0 };
            const std::uint32_t dim15912JoeKuoD6Init[]   =   { 1, 1, 1, 1, 3, 31, 89, 157, 483, 657, 1833, 2975, 3187, 631, 28685, 7277, 4915, 115955, 0 };
            const std::uint32_t dim15913JoeKuoD6Init[]   =   { 1, 3, 3, 1, 25, 41, 13, 99, 385, 303, 297, 419, 7919, 12411, 757, 9227, 47867, 120175, 0 };
            const std::uint32_t dim15914JoeKuoD6Init[]   =   { 1, 3, 5, 11, 23, 15, 21, 157, 177, 301, 789, 2791, 5769, 7809, 2369, 26123, 116465, 22595, 0 };
            const std::uint32_t dim15915JoeKuoD6Init[]   =   { 1, 1, 5, 9, 17, 63, 45, 239, 465, 811, 1157, 1443, 8137, 12587, 26209, 62057, 59299, 167171, 0 };
            const std::uint32_t dim15916JoeKuoD6Init[]   =   { 1, 3, 3, 7, 3, 45, 41, 17, 341, 461, 571, 541, 989, 4069, 17531, 46729, 107915, 47871, 0 };
            const std::uint32_t dim15917JoeKuoD6Init[]   =   { 1, 1, 7, 1, 1, 23, 45, 213, 125, 799, 5, 3443, 2535, 12983, 2133, 63411, 93027, 89831, 0 };
            const std::uint32_t dim15918JoeKuoD6Init[]   =   { 1, 1, 1, 15, 7, 31, 49, 181, 213, 923, 281, 2059, 861, 6951, 25659, 32209, 66423, 225885, 0 };
            const std::uint32_t dim15919JoeKuoD6Init[]   =   { 1, 3, 3, 7, 9, 39, 107, 197, 383, 179, 27, 1395, 6397, 16139, 32049, 33567, 43977, 203939, 0 };
            const std::uint32_t dim15920JoeKuoD6Init[]   =   { 1, 1, 3, 5, 13, 37, 13, 31, 339, 527, 641, 181, 1413, 8145, 341, 57605, 108031, 109311, 0 };
            const std::uint32_t dim15921JoeKuoD6Init[]   =   { 1, 1, 1, 1, 21, 35, 87, 15, 279, 967, 1003, 813, 5075, 10595, 5609, 33901, 86443, 150007, 0 };
            const std::uint32_t dim15922JoeKuoD6Init[]   =   { 1, 3, 1, 5, 27, 9, 75, 199, 377, 889, 545, 1987, 6277, 361, 12563, 35699, 27105, 187995, 0 };
            const std::uint32_t dim15923JoeKuoD6Init[]   =   { 1, 3, 7, 1, 11, 3, 41, 215, 273, 61, 821, 1207, 2809, 8731, 26409, 50323, 22355, 16521, 0 };
            const std::uint32_t dim15924JoeKuoD6Init[]   =   { 1, 1, 7, 5, 29, 13, 99, 133, 15, 673, 215, 445, 4051, 2187, 9395, 62491, 58685, 224707, 0 };
            const std::uint32_t dim15925JoeKuoD6Init[]   =   { 1, 3, 3, 13, 21, 59, 17, 1, 271, 613, 939, 1881, 2379, 16325, 3275, 63707, 59961, 106937, 0 };
            const std::uint32_t dim15926JoeKuoD6Init[]   =   { 1, 3, 3, 1, 23, 53, 51, 181, 391, 375, 767, 239, 373, 4593, 25211, 37173, 70409, 252345, 0 };
            const std::uint32_t dim15927JoeKuoD6Init[]   =   { 1, 3, 3, 11, 15, 17, 37, 145, 41, 107, 151, 1351, 3457, 14727, 755, 36321, 99397, 73359, 0 };
            const std::uint32_t dim15928JoeKuoD6Init[]   =   { 1, 3, 5, 7, 25, 31, 39, 185, 341, 721, 1799, 1803, 5985, 10587, 11605, 9937, 23905, 56485, 0 };
            const std::uint32_t dim15929JoeKuoD6Init[]   =   { 1, 3, 1, 3, 19, 35, 25, 71, 109, 209, 1675, 4043, 2053, 6285, 25317, 50171, 68293, 124385, 0 };
            const std::uint32_t dim15930JoeKuoD6Init[]   =   { 1, 1, 1, 1, 21, 11, 63, 137, 361, 157, 1985, 2161, 7239, 1795, 10459, 38511, 36817, 253347, 0 };
            const std::uint32_t dim15931JoeKuoD6Init[]   =   { 1, 1, 1, 5, 31, 3, 13, 83, 185, 175, 567, 295, 459, 11453, 3765, 9841, 30333, 201377, 0 };
            const std::uint32_t dim15932JoeKuoD6Init[]   =   { 1, 1, 3, 13, 5, 57, 99, 125, 371, 903, 2001, 285, 2005, 8475, 31617, 58265, 641, 115507, 0 };
            const std::uint32_t dim15933JoeKuoD6Init[]   =   { 1, 3, 5, 9, 11, 17, 123, 67, 77, 803, 815, 3173, 4795, 11917, 1187, 32389, 102289, 248359, 0 };
            const std::uint32_t dim15934JoeKuoD6Init[]   =   { 1, 1, 5, 5, 27, 19, 59, 145, 361, 821, 33, 1465, 7643, 11101, 145, 21705, 55105, 181245, 0 };
            const std::uint32_t dim15935JoeKuoD6Init[]   =   { 1, 3, 7, 5, 15, 55, 127, 133, 157, 989, 1211, 3573, 4021, 2967, 2941, 38657, 97681, 114505, 0 };
            const std::uint32_t dim15936JoeKuoD6Init[]   =   { 1, 1, 7, 7, 23, 17, 39, 209, 117, 195, 931, 5, 7509, 9187, 6011, 10297, 13727, 258007, 0 };
            const std::uint32_t dim15937JoeKuoD6Init[]   =   { 1, 3, 1, 13, 3, 17, 105, 69, 9, 163, 1615, 241, 5207, 13173, 28521, 51417, 130645, 106787, 0 };
            const std::uint32_t dim15938JoeKuoD6Init[]   =   { 1, 1, 7, 13, 15, 3, 5, 187, 5, 239, 1799, 3083, 7801, 12781, 24817, 59341, 73867, 175273, 0 };
            const std::uint32_t dim15939JoeKuoD6Init[]   =   { 1, 1, 3, 11, 11, 1, 89, 17, 497, 217, 1565, 2933, 6449, 7687, 6561, 57903, 92751, 261371, 0 };
            const std::uint32_t dim15940JoeKuoD6Init[]   =   { 1, 1, 1, 1, 15, 39, 47, 249, 39, 765, 249, 2785, 4401, 16033, 11463, 127, 120109, 83133, 0 };
            const std::uint32_t dim15941JoeKuoD6Init[]   =   { 1, 1, 3, 3, 19, 59, 47, 153, 505, 1009, 413, 1177, 5999, 6841, 12013, 40295, 115641, 189241, 0 };
            const std::uint32_t dim15942JoeKuoD6Init[]   =   { 1, 3, 3, 11, 17, 51, 45, 101, 459, 971, 1133, 3467, 4945, 12445, 1267, 41783, 66825, 130167, 0 };
            const std::uint32_t dim15943JoeKuoD6Init[]   =   { 1, 3, 1, 7, 17, 45, 77, 211, 387, 23, 1903, 2309, 2681, 6897, 6959, 30981, 113537, 207415, 0 };
            const std::uint32_t dim15944JoeKuoD6Init[]   =   { 1, 1, 3, 1, 19, 9, 103, 89, 461, 881, 71, 2019, 6475, 13563, 18835, 2375, 34807, 1373, 0 };
            const std::uint32_t dim15945JoeKuoD6Init[]   =   { 1, 1, 7, 11, 3, 31, 125, 121, 43, 737, 1995, 3043, 811, 8883, 8169, 22131, 29295, 194963, 0 };
            const std::uint32_t dim15946JoeKuoD6Init[]   =   { 1, 3, 7, 11, 7, 45, 125, 149, 427, 187, 1361, 2405, 2815, 8877, 15255, 36867, 95517, 261969, 0 };
            const std::uint32_t dim15947JoeKuoD6Init[]   =   { 1, 1, 7, 11, 9, 29, 89, 175, 467, 997, 937, 3869, 7843, 12629, 8701, 60717, 30443, 193427, 0 };
            const std::uint32_t dim15948JoeKuoD6Init[]   =   { 1, 1, 5, 7, 3, 3, 57, 199, 315, 477, 189, 2029, 2059, 3473, 27411, 30419, 26465, 187807, 0 };
            const std::uint32_t dim15949JoeKuoD6Init[]   =   { 1, 3, 1, 15, 3, 3, 11, 55, 233, 603, 1749, 1737, 5709, 4559, 13427, 39137, 44885, 61611, 0 };
            const std::uint32_t dim15950JoeKuoD6Init[]   =   { 1, 1, 7, 1, 25, 15, 61, 199, 107, 737, 909, 3229, 1799, 5129, 27655, 45937, 919, 36161, 0 };
            const std::uint32_t dim15951JoeKuoD6Init[]   =   { 1, 1, 3, 5, 31, 27, 99, 247, 425, 689, 1335, 1661, 625, 15817, 22601, 33293, 113927, 261931, 0 };
            const std::uint32_t dim15952JoeKuoD6Init[]   =   { 1, 1, 1, 9, 5, 57, 117, 121, 465, 859, 335, 879, 665, 12787, 21313, 46387, 16437, 53769, 0 };
            const std::uint32_t dim15953JoeKuoD6Init[]   =   { 1, 1, 3, 1, 11, 11, 75, 145, 307, 621, 833, 235, 3907, 11331, 6633, 51905, 72581, 129613, 0 };
            const std::uint32_t dim15954JoeKuoD6Init[]   =   { 1, 1, 3, 13, 17, 13, 81, 125, 377, 499, 1597, 3437, 4323, 789, 23825, 46609, 105997, 159709, 0 };
            const std::uint32_t dim15955JoeKuoD6Init[]   =   { 1, 3, 3, 9, 5, 29, 113, 51, 23, 957, 1981, 3205, 2549, 9771, 2555, 44289, 103893, 170241, 0 };
            const std::uint32_t dim15956JoeKuoD6Init[]   =   { 1, 1, 5, 15, 13, 17, 101, 67, 71, 7, 185, 3775, 5399, 5213, 13095, 26045, 59467, 95547, 0 };
            const std::uint32_t dim15957JoeKuoD6Init[]   =   { 1, 1, 5, 5, 31, 11, 77, 169, 3, 1007, 1853, 2245, 509, 13489, 2807, 55227, 67541, 242835, 0 };
            const std::uint32_t dim15958JoeKuoD6Init[]   =   { 1, 3, 7, 15, 11, 63, 39, 97, 1, 219, 1827, 2343, 6009, 4909, 4327, 21853, 46079, 87719, 0 };
            const std::uint32_t dim15959JoeKuoD6Init[]   =   { 1, 3, 1, 9, 17, 51, 119, 93, 179, 607, 1051, 2381, 619, 11215, 10839, 44771, 20555, 12721, 0 };
            const std::uint32_t dim15960JoeKuoD6Init[]   =   { 1, 3, 3, 5, 21, 47, 35, 133, 61, 937, 1561, 1655, 6527, 5085, 4141, 60811, 59971, 6309, 0 };
            const std::uint32_t dim15961JoeKuoD6Init[]   =   { 1, 3, 1, 7, 5, 63, 7, 235, 489, 675, 945, 943, 7107, 6005, 32695, 27655, 113219, 132963, 0 };
            const std::uint32_t dim15962JoeKuoD6Init[]   =   { 1, 1, 1, 7, 7, 5, 81, 237, 365, 1, 811, 3075, 1771, 5223, 7337, 24601, 68383, 156975, 0 };
            const std::uint32_t dim15963JoeKuoD6Init[]   =   { 1, 3, 1, 15, 5, 35, 39, 91, 301, 387, 805, 3537, 737, 7453, 4655, 16349, 108261, 123697, 0 };
            const std::uint32_t dim15964JoeKuoD6Init[]   =   { 1, 3, 5, 3, 9, 59, 95, 187, 155, 183, 589, 2107, 967, 1095, 4875, 46131, 100699, 212797, 0 };
            const std::uint32_t dim15965JoeKuoD6Init[]   =   { 1, 3, 1, 7, 27, 29, 77, 133, 397, 445, 933, 1483, 5027, 12569, 22163, 58989, 16657, 195347, 0 };
            const std::uint32_t dim15966JoeKuoD6Init[]   =   { 1, 3, 5, 15, 21, 51, 97, 135, 165, 311, 525, 171, 4785, 7947, 14649, 40837, 58875, 222303, 0 };
            const std::uint32_t dim15967JoeKuoD6Init[]   =   { 1, 3, 3, 5, 23, 47, 41, 23, 321, 709, 1555, 1139, 3775, 11617, 13001, 18235, 51803, 197863, 0 };
            const std::uint32_t dim15968JoeKuoD6Init[]   =   { 1, 3, 5, 3, 3, 41, 91, 157, 29, 1005, 945, 3471, 2563, 8493, 24961, 44759, 103079, 50841, 0 };
            const std::uint32_t dim15969JoeKuoD6Init[]   =   { 1, 1, 5, 11, 23, 19, 91, 115, 165, 291, 1653, 1061, 1067, 6171, 18441, 26067, 3569, 117329, 0 };
            const std::uint32_t dim15970JoeKuoD6Init[]   =   { 1, 3, 7, 15, 17, 19, 89, 23, 103, 389, 623, 1071, 203, 9545, 21259, 36155, 55395, 141741, 0 };
            const std::uint32_t dim15971JoeKuoD6Init[]   =   { 1, 3, 5, 11, 27, 43, 31, 193, 55, 489, 353, 1615, 7461, 13977, 31901, 64051, 82667, 258825, 0 };
            const std::uint32_t dim15972JoeKuoD6Init[]   =   { 1, 1, 3, 7, 5, 39, 7, 245, 241, 843, 1545, 3499, 8117, 15057, 14153, 2665, 107401, 66059, 0 };
            const std::uint32_t dim15973JoeKuoD6Init[]   =   { 1, 3, 5, 11, 9, 11, 41, 171, 255, 153, 1973, 759, 51, 15601, 327, 25889, 110861, 20555, 0 };
            const std::uint32_t dim15974JoeKuoD6Init[]   =   { 1, 3, 5, 7, 5, 15, 41, 77, 87, 143, 1141, 3975, 2675, 7131, 5549, 52397, 42073, 27585, 0 };
            const std::uint32_t dim15975JoeKuoD6Init[]   =   { 1, 1, 3, 7, 29, 5, 79, 243, 359, 817, 1053, 3509, 3347, 6207, 5147, 31063, 116851, 132627, 0 };
            const std::uint32_t dim15976JoeKuoD6Init[]   =   { 1, 3, 7, 3, 27, 51, 39, 7, 95, 239, 263, 3497, 867, 1869, 16773, 46947, 59193, 37523, 0 };
            const std::uint32_t dim15977JoeKuoD6Init[]   =   { 1, 3, 1, 1, 25, 31, 113, 127, 187, 77, 675, 3307, 999, 12255, 26441, 30933, 122761, 116783, 0 };
            const std::uint32_t dim15978JoeKuoD6Init[]   =   { 1, 1, 5, 7, 7, 11, 87, 59, 437, 485, 685, 3159, 7259, 16271, 24899, 17919, 130271, 52953, 0 };
            const std::uint32_t dim15979JoeKuoD6Init[]   =   { 1, 1, 3, 11, 7, 13, 61, 157, 149, 1001, 285, 3631, 1923, 16013, 19507, 64447, 8073, 261171, 0 };
            const std::uint32_t dim15980JoeKuoD6Init[]   =   { 1, 3, 7, 9, 7, 13, 45, 7, 225, 671, 287, 1059, 5223, 2077, 7551, 58385, 92955, 162725, 0 };
            const std::uint32_t dim15981JoeKuoD6Init[]   =   { 1, 1, 5, 11, 11, 21, 17, 145, 97, 633, 475, 2639, 2069, 9663, 23633, 50949, 109941, 119865, 0 };
            const std::uint32_t dim15982JoeKuoD6Init[]   =   { 1, 1, 5, 13, 9, 49, 127, 171, 199, 413, 1315, 645, 305, 12123, 9559, 38319, 99945, 103313, 0 };
            const std::uint32_t dim15983JoeKuoD6Init[]   =   { 1, 3, 5, 3, 19, 21, 119, 17, 301, 611, 1785, 2081, 2245, 8761, 4755, 9507, 23133, 144575, 0 };
            const std::uint32_t dim15984JoeKuoD6Init[]   =   { 1, 3, 7, 11, 17, 25, 101, 59, 397, 249, 687, 715, 1151, 15941, 20525, 5171, 24073, 46257, 0 };
            const std::uint32_t dim15985JoeKuoD6Init[]   =   { 1, 1, 3, 15, 11, 45, 9, 201, 421, 867, 389, 3615, 5965, 10561, 18309, 17143, 52771, 230743, 0 };
            const std::uint32_t dim15986JoeKuoD6Init[]   =   { 1, 1, 3, 5, 9, 1, 109, 233, 431, 849, 421, 475, 1331, 9903, 20649, 34759, 118611, 38541, 0 };
            const std::uint32_t dim15987JoeKuoD6Init[]   =   { 1, 3, 5, 15, 9, 55, 113, 217, 83, 409, 1449, 2325, 4825, 11311, 14565, 65075, 124399, 3591, 0 };
            const std::uint32_t dim15988JoeKuoD6Init[]   =   { 1, 3, 3, 9, 27, 13, 101, 181, 255, 313, 693, 951, 1153, 13941, 14097, 8325, 4589, 102883, 0 };
            const std::uint32_t dim15989JoeKuoD6Init[]   =   { 1, 3, 7, 3, 3, 1, 43, 65, 321, 623, 1389, 57, 3461, 9965, 6743, 34843, 91673, 249573, 0 };
            const std::uint32_t dim15990JoeKuoD6Init[]   =   { 1, 3, 5, 5, 11, 29, 101, 79, 275, 685, 569, 59, 6921, 16065, 30625, 53339, 32283, 93401, 0 };
            const std::uint32_t dim15991JoeKuoD6Init[]   =   { 1, 3, 1, 11, 29, 33, 103, 145, 431, 289, 1845, 1915, 23, 699, 5475, 18413, 127185, 162637, 0 };
            const std::uint32_t dim15992JoeKuoD6Init[]   =   { 1, 3, 1, 11, 27, 23, 71, 63, 45, 579, 1187, 1189, 1781, 5595, 9043, 10155, 33321, 36487, 0 };
            const std::uint32_t dim15993JoeKuoD6Init[]   =   { 1, 3, 3, 15, 17, 19, 85, 233, 293, 833, 1711, 857, 7573, 393, 23141, 58713, 21399, 228381, 0 };
            const std::uint32_t dim15994JoeKuoD6Init[]   =   { 1, 3, 3, 15, 3, 35, 33, 35, 403, 123, 575, 3509, 6303, 13203, 17997, 15649, 64331, 124101, 0 };
            const std::uint32_t dim15995JoeKuoD6Init[]   =   { 1, 1, 3, 9, 23, 25, 39, 53, 119, 879, 573, 3225, 5069, 15489, 21887, 11773, 37783, 169523, 0 };
            const std::uint32_t dim15996JoeKuoD6Init[]   =   { 1, 3, 5, 5, 5, 25, 29, 189, 145, 863, 661, 3939, 1059, 11993, 1487, 3157, 118287, 69835, 0 };
            const std::uint32_t dim15997JoeKuoD6Init[]   =   { 1, 3, 7, 3, 15, 9, 85, 107, 17, 965, 1097, 2087, 1947, 14649, 4099, 50941, 64511, 209153, 0 };
            const std::uint32_t dim15998JoeKuoD6Init[]   =   { 1, 3, 5, 15, 19, 21, 127, 71, 429, 97, 1989, 835, 743, 11973, 14635, 45371, 114657, 208085, 0 };
            const std::uint32_t dim15999JoeKuoD6Init[]   =   { 1, 3, 5, 7, 23, 61, 99, 133, 235, 237, 435, 2681, 331, 7859, 20859, 3573, 102901, 775, 0 };
            const std::uint32_t dim16000JoeKuoD6Init[]   =   { 1, 3, 3, 9, 7, 57, 29, 15, 53, 569, 871, 1703, 2573, 10791, 719, 3487, 105709, 89573, 0 };
            const std::uint32_t dim16001JoeKuoD6Init[]   =   { 1, 1, 1, 9, 7, 21, 21, 207, 459, 621, 737, 635, 5101, 4343, 4961, 32067, 64017, 73675, 0 };
            const std::uint32_t dim16002JoeKuoD6Init[]   =   { 1, 1, 3, 9, 25, 27, 77, 69, 251, 327, 921, 3759, 1715, 14537, 21399, 10937, 9085, 241329, 0 };
            const std::uint32_t dim16003JoeKuoD6Init[]   =   { 1, 1, 5, 1, 23, 13, 63, 117, 81, 427, 1063, 1987, 2433, 14837, 13473, 28623, 44799, 202223, 0 };
            const std::uint32_t dim16004JoeKuoD6Init[]   =   { 1, 3, 1, 11, 17, 55, 89, 89, 455, 255, 1009, 1891, 2197, 9045, 23543, 48783, 22871, 58613, 0 };
            const std::uint32_t dim16005JoeKuoD6Init[]   =   { 1, 3, 7, 15, 25, 5, 11, 71, 399, 23, 239, 93, 6681, 11311, 23403, 58131, 59549, 38917, 0 };
            const std::uint32_t dim16006JoeKuoD6Init[]   =   { 1, 1, 1, 1, 19, 63, 73, 31, 69, 145, 921, 2475, 3505, 4797, 23805, 28621, 101153, 98895, 0 };
            const std::uint32_t dim16007JoeKuoD6Init[]   =   { 1, 3, 3, 3, 9, 1, 113, 111, 275, 851, 519, 1607, 635, 13287, 6191, 24545, 112039, 114383, 0 };
            const std::uint32_t dim16008JoeKuoD6Init[]   =   { 1, 3, 7, 9, 13, 13, 107, 97, 37, 133, 21, 1059, 4201, 6777, 2843, 43503, 23761, 13247, 0 };
            const std::uint32_t dim16009JoeKuoD6Init[]   =   { 1, 1, 7, 9, 25, 23, 101, 135, 471, 901, 539, 4083, 1765, 15553, 5879, 10787, 67543, 104543, 0 };
            const std::uint32_t dim16010JoeKuoD6Init[]   =   { 1, 3, 3, 13, 25, 63, 1, 49, 287, 357, 1701, 3689, 3895, 16313, 22619, 20203, 8195, 93127, 0 };
            const std::uint32_t dim16011JoeKuoD6Init[]   =   { 1, 1, 1, 11, 15, 37, 75, 43, 311, 443, 1639, 549, 4707, 3099, 677, 59115, 11709, 71013, 0 };
            const std::uint32_t dim16012JoeKuoD6Init[]   =   { 1, 1, 5, 11, 17, 43, 23, 21, 421, 613, 199, 1029, 5255, 271, 12911, 63431, 108889, 253379, 0 };
            const std::uint32_t dim16013JoeKuoD6Init[]   =   { 1, 3, 7, 11, 27, 45, 9, 89, 65, 25, 1183, 3497, 8123, 2389, 215, 16819, 63777, 163423, 0 };
            const std::uint32_t dim16014JoeKuoD6Init[]   =   { 1, 1, 5, 5, 29, 43, 65, 201, 391, 861, 1133, 3985, 983, 13039, 15545, 13695, 91467, 963, 0 };
            const std::uint32_t dim16015JoeKuoD6Init[]   =   { 1, 3, 7, 3, 9, 55, 73, 205, 287, 765, 941, 353, 7379, 2511, 555, 64399, 77605, 121959, 0 };
            const std::uint32_t dim16016JoeKuoD6Init[]   =   { 1, 3, 1, 11, 25, 15, 109, 35, 351, 675, 1219, 3791, 233, 15133, 30733, 24477, 86077, 85857, 0 };
            const std::uint32_t dim16017JoeKuoD6Init[]   =   { 1, 1, 1, 7, 13, 33, 63, 45, 503, 525, 781, 517, 2187, 1587, 17297, 26147, 35421, 61269, 0 };
            const std::uint32_t dim16018JoeKuoD6Init[]   =   { 1, 3, 1, 9, 9, 35, 69, 79, 447, 675, 803, 2793, 5793, 4433, 29227, 5437, 103347, 37713, 0 };
            const std::uint32_t dim16019JoeKuoD6Init[]   =   { 1, 3, 1, 9, 27, 31, 65, 167, 327, 231, 1959, 657, 3141, 8659, 11055, 23923, 73597, 187139, 0 };
            const std::uint32_t dim16020JoeKuoD6Init[]   =   { 1, 1, 5, 9, 29, 5, 37, 3, 281, 693, 133, 2139, 5867, 12073, 23669, 11427, 80627, 249003, 0 };
            const std::uint32_t dim16021JoeKuoD6Init[]   =   { 1, 1, 1, 13, 9, 35, 89, 203, 381, 281, 535, 1061, 7417, 13373, 12149, 37943, 113133, 110797, 0 };
            const std::uint32_t dim16022JoeKuoD6Init[]   =   { 1, 1, 7, 5, 7, 17, 71, 65, 385, 851, 1357, 3435, 4441, 6999, 27065, 32753, 129531, 52447, 0 };
            const std::uint32_t dim16023JoeKuoD6Init[]   =   { 1, 3, 7, 1, 3, 21, 25, 113, 361, 219, 1345, 2193, 5711, 3331, 14343, 23075, 39955, 71223, 0 };
            const std::uint32_t dim16024JoeKuoD6Init[]   =   { 1, 1, 7, 9, 15, 9, 101, 183, 59, 861, 931, 3385, 6517, 12067, 7753, 37997, 128361, 4591, 0 };
            const std::uint32_t dim16025JoeKuoD6Init[]   =   { 1, 3, 5, 3, 23, 5, 37, 217, 203, 749, 993, 2537, 2425, 13949, 17235, 15461, 21275, 141815, 0 };
            const std::uint32_t dim16026JoeKuoD6Init[]   =   { 1, 3, 5, 1, 19, 59, 63, 241, 211, 285, 2033, 1111, 2859, 14801, 9491, 14557, 12973, 223089, 0 };
            const std::uint32_t dim16027JoeKuoD6Init[]   =   { 1, 1, 1, 11, 15, 41, 57, 59, 233, 897, 1193, 381, 2237, 5309, 19237, 57607, 97941, 116573, 0 };
            const std::uint32_t dim16028JoeKuoD6Init[]   =   { 1, 1, 3, 9, 15, 17, 75, 15, 385, 129, 495, 887, 4933, 15113, 7449, 56213, 15841, 248029, 0 };
            const std::uint32_t dim16029JoeKuoD6Init[]   =   { 1, 3, 1, 1, 29, 37, 19, 221, 47, 185, 1105, 3297, 5235, 6917, 12041, 10815, 54747, 132329, 0 };
            const std::uint32_t dim16030JoeKuoD6Init[]   =   { 1, 3, 1, 5, 3, 17, 33, 35, 395, 491, 1157, 2563, 6257, 1025, 18295, 5293, 77851, 140157, 0 };
            const std::uint32_t dim16031JoeKuoD6Init[]   =   { 1, 3, 1, 13, 7, 31, 95, 21, 347, 409, 1485, 925, 327, 11497, 7305, 6503, 111175, 70989, 0 };
            const std::uint32_t dim16032JoeKuoD6Init[]   =   { 1, 3, 3, 1, 11, 41, 127, 93, 367, 649, 1585, 3379, 7269, 5537, 26077, 28541, 55379, 22989, 0 };
            const std::uint32_t dim16033JoeKuoD6Init[]   =   { 1, 1, 1, 5, 27, 11, 35, 49, 7, 113, 1477, 3615, 7567, 505, 13915, 51023, 50783, 45031, 0 };
            const std::uint32_t dim16034JoeKuoD6Init[]   =   { 1, 1, 7, 5, 25, 1, 35, 59, 269, 427, 791, 3179, 1423, 9801, 17717, 23631, 97947, 126861, 0 };
            const std::uint32_t dim16035JoeKuoD6Init[]   =   { 1, 3, 5, 7, 1, 51, 77, 97, 19, 287, 303, 791, 307, 4939, 13615, 61225, 98127, 114693, 0 };
            const std::uint32_t dim16036JoeKuoD6Init[]   =   { 1, 3, 3, 15, 5, 5, 93, 119, 429, 977, 1763, 3727, 1761, 3597, 16489, 71, 44103, 257929, 0 };
            const std::uint32_t dim16037JoeKuoD6Init[]   =   { 1, 1, 5, 1, 15, 29, 79, 33, 335, 381, 1233, 47, 6741, 4953, 29689, 11223, 129185, 182487, 0 };
            const std::uint32_t dim16038JoeKuoD6Init[]   =   { 1, 1, 1, 11, 29, 27, 27, 189, 507, 523, 1949, 2567, 4105, 1227, 16631, 34187, 28521, 265, 0 };
            const std::uint32_t dim16039JoeKuoD6Init[]   =   { 1, 3, 3, 7, 3, 7, 39, 155, 315, 439, 1953, 1227, 6135, 16291, 453, 50929, 67507, 166981, 0 };
            const std::uint32_t dim16040JoeKuoD6Init[]   =   { 1, 3, 1, 5, 7, 55, 121, 119, 87, 869, 1049, 575, 3675, 13505, 15661, 43899, 106877, 141691, 0 };
            const std::uint32_t dim16041JoeKuoD6Init[]   =   { 1, 3, 1, 11, 23, 9, 117, 243, 329, 767, 335, 2951, 2887, 13441, 27579, 15437, 31699, 165177, 0 };
            const std::uint32_t dim16042JoeKuoD6Init[]   =   { 1, 3, 7, 11, 5, 49, 47, 125, 431, 511, 299, 3215, 3287, 7029, 9737, 28317, 34355, 232365, 0 };
            const std::uint32_t dim16043JoeKuoD6Init[]   =   { 1, 3, 7, 3, 17, 9, 29, 255, 509, 393, 1583, 1979, 6735, 941, 4393, 35741, 82019, 109633, 0 };
            const std::uint32_t dim16044JoeKuoD6Init[]   =   { 1, 1, 5, 1, 13, 31, 95, 133, 117, 257, 993, 1513, 4669, 12239, 7841, 751, 79567, 23289, 0 };
            const std::uint32_t dim16045JoeKuoD6Init[]   =   { 1, 1, 7, 9, 25, 33, 127, 181, 61, 333, 1087, 1661, 2715, 2569, 30041, 4937, 36053, 3435, 0 };
            const std::uint32_t dim16046JoeKuoD6Init[]   =   { 1, 3, 1, 13, 15, 27, 123, 73, 377, 85, 435, 3435, 2079, 9271, 28685, 30089, 38799, 210247, 0 };
            const std::uint32_t dim16047JoeKuoD6Init[]   =   { 1, 1, 5, 3, 5, 17, 93, 181, 313, 837, 1115, 3099, 3603, 3483, 23185, 9933, 53127, 123245, 0 };
            const std::uint32_t dim16048JoeKuoD6Init[]   =   { 1, 1, 1, 13, 3, 57, 11, 67, 41, 273, 1005, 2313, 505, 6593, 27287, 47359, 104597, 45475, 0 };
            const std::uint32_t dim16049JoeKuoD6Init[]   =   { 1, 1, 1, 5, 13, 41, 97, 251, 317, 483, 163, 1493, 6629, 11995, 31293, 4715, 98569, 178419, 0 };
            const std::uint32_t dim16050JoeKuoD6Init[]   =   { 1, 3, 5, 5, 21, 7, 69, 169, 223, 953, 1573, 1137, 8075, 7733, 23031, 14589, 6453, 228883, 0 };
            const std::uint32_t dim16051JoeKuoD6Init[]   =   { 1, 1, 7, 9, 27, 37, 3, 183, 41, 99, 111, 1713, 1291, 8263, 6373, 39549, 3099, 156793, 0 };
            const std::uint32_t dim16052JoeKuoD6Init[]   =   { 1, 1, 3, 1, 23, 43, 15, 27, 223, 173, 1601, 2159, 3595, 15143, 31065, 35799, 77339, 141397, 0 };
            const std::uint32_t dim16053JoeKuoD6Init[]   =   { 1, 1, 5, 13, 9, 35, 27, 93, 23, 999, 593, 563, 5333, 8825, 27277, 46381, 3171, 6311, 0 };
            const std::uint32_t dim16054JoeKuoD6Init[]   =   { 1, 3, 7, 15, 25, 17, 7, 237, 379, 649, 1879, 2643, 5951, 4227, 4937, 24549, 43577, 116327, 0 };
            const std::uint32_t dim16055JoeKuoD6Init[]   =   { 1, 1, 3, 9, 29, 35, 101, 105, 19, 151, 1135, 897, 2427, 15779, 31851, 29183, 44471, 187817, 0 };
            const std::uint32_t dim16056JoeKuoD6Init[]   =   { 1, 3, 7, 11, 9, 55, 19, 115, 395, 559, 1883, 409, 2459, 201, 18975, 339, 108251, 19429, 0 };
            const std::uint32_t dim16057JoeKuoD6Init[]   =   { 1, 3, 1, 13, 1, 11, 67, 45, 407, 169, 1401, 381, 3913, 6491, 28133, 63857, 52095, 115749, 0 };
            const std::uint32_t dim16058JoeKuoD6Init[]   =   { 1, 1, 1, 11, 21, 45, 65, 253, 511, 51, 893, 3533, 2101, 4779, 23941, 22449, 82457, 44447, 0 };
            const std::uint32_t dim16059JoeKuoD6Init[]   =   { 1, 1, 7, 11, 19, 33, 101, 241, 493, 111, 1967, 469, 6575, 10445, 733, 56467, 27403, 25863, 0 };
            const std::uint32_t dim16060JoeKuoD6Init[]   =   { 1, 3, 1, 1, 5, 49, 21, 79, 53, 621, 43, 1183, 1385, 9129, 21727, 35559, 35269, 211383, 0 };
            const std::uint32_t dim16061JoeKuoD6Init[]   =   { 1, 1, 1, 13, 23, 43, 53, 145, 149, 611, 745, 899, 7095, 3243, 1993, 35807, 110783, 246199, 0 };
            const std::uint32_t dim16062JoeKuoD6Init[]   =   { 1, 1, 7, 9, 25, 37, 71, 233, 407, 1, 1749, 759, 7689, 15573, 7351, 33505, 22631, 49125, 0 };
            const std::uint32_t dim16063JoeKuoD6Init[]   =   { 1, 3, 1, 13, 31, 49, 105, 13, 257, 843, 1171, 2819, 621, 12567, 24339, 6689, 127413, 249671, 0 };
            const std::uint32_t dim16064JoeKuoD6Init[]   =   { 1, 1, 5, 11, 5, 1, 93, 21, 317, 789, 571, 2493, 7255, 6459, 14737, 13989, 47003, 246561, 0 };
            const std::uint32_t dim16065JoeKuoD6Init[]   =   { 1, 3, 5, 7, 9, 11, 69, 143, 175, 581, 825, 2219, 1165, 9061, 6073, 57169, 18135, 94943, 0 };
            const std::uint32_t dim16066JoeKuoD6Init[]   =   { 1, 1, 5, 7, 7, 55, 121, 107, 395, 939, 1291, 2497, 3757, 1361, 31823, 19375, 22551, 224653, 0 };
            const std::uint32_t dim16067JoeKuoD6Init[]   =   { 1, 1, 7, 15, 15, 1, 47, 225, 223, 589, 1539, 173, 6257, 5461, 11197, 9801, 80687, 84279, 0 };
            const std::uint32_t dim16068JoeKuoD6Init[]   =   { 1, 3, 7, 11, 23, 47, 83, 119, 367, 895, 431, 1949, 565, 1397, 24911, 29661, 67861, 74621, 0 };
            const std::uint32_t dim16069JoeKuoD6Init[]   =   { 1, 3, 3, 9, 17, 29, 15, 65, 157, 255, 303, 1467, 3279, 8873, 31279, 431, 8497, 7209, 0 };
            const std::uint32_t dim16070JoeKuoD6Init[]   =   { 1, 1, 5, 13, 9, 39, 85, 133, 427, 897, 1665, 2109, 2865, 15573, 27729, 59905, 2241, 83099, 0 };
            const std::uint32_t dim16071JoeKuoD6Init[]   =   { 1, 3, 1, 13, 1, 45, 65, 65, 249, 79, 1515, 503, 953, 9859, 13307, 27419, 102209, 107529, 0 };
            const std::uint32_t dim16072JoeKuoD6Init[]   =   { 1, 3, 7, 9, 17, 13, 79, 93, 231, 5, 1811, 557, 1837, 8077, 8109, 3497, 79985, 134375, 0 };
            const std::uint32_t dim16073JoeKuoD6Init[]   =   { 1, 1, 5, 9, 15, 3, 23, 27, 491, 9, 1657, 3877, 3783, 12645, 2599, 10673, 40035, 197681, 0 };
            const std::uint32_t dim16074JoeKuoD6Init[]   =   { 1, 1, 5, 3, 5, 13, 121, 145, 291, 621, 1731, 145, 2033, 341, 3667, 4139, 52035, 115865, 0 };
            const std::uint32_t dim16075JoeKuoD6Init[]   =   { 1, 3, 5, 5, 3, 29, 115, 227, 339, 23, 1659, 2367, 1079, 10757, 30709, 41473, 55847, 228761, 0 };
            const std::uint32_t dim16076JoeKuoD6Init[]   =   { 1, 3, 5, 7, 7, 61, 103, 57, 197, 31, 237, 2507, 5247, 10529, 13823, 47845, 129031, 47029, 0 };
            const std::uint32_t dim16077JoeKuoD6Init[]   =   { 1, 3, 7, 5, 3, 17, 91, 31, 277, 977, 1905, 3991, 3657, 12197, 14535, 43263, 109629, 31665, 0 };
            const std::uint32_t dim16078JoeKuoD6Init[]   =   { 1, 1, 5, 15, 29, 43, 121, 113, 159, 929, 669, 2067, 4999, 6847, 12369, 61795, 98525, 78051, 0 };
            const std::uint32_t dim16079JoeKuoD6Init[]   =   { 1, 1, 3, 7, 25, 61, 65, 79, 373, 683, 113, 1495, 5447, 15507, 16731, 53959, 62905, 252173, 0 };
            const std::uint32_t dim16080JoeKuoD6Init[]   =   { 1, 3, 1, 11, 1, 15, 101, 55, 477, 357, 333, 3243, 3325, 5885, 11385, 685, 90575, 23015, 0 };
            const std::uint32_t dim16081JoeKuoD6Init[]   =   { 1, 3, 1, 7, 15, 13, 91, 141, 209, 865, 2035, 2791, 367, 9953, 29547, 36731, 13649, 192911, 0 };
            const std::uint32_t dim16082JoeKuoD6Init[]   =   { 1, 1, 5, 15, 9, 59, 37, 131, 3, 299, 897, 119, 7515, 5271, 2207, 18187, 62613, 210345, 0 };
            const std::uint32_t dim16083JoeKuoD6Init[]   =   { 1, 3, 1, 7, 29, 53, 95, 185, 327, 473, 1525, 3751, 915, 5883, 4137, 46343, 104917, 182895, 0 };
            const std::uint32_t dim16084JoeKuoD6Init[]   =   { 1, 1, 7, 3, 31, 57, 53, 169, 215, 607, 541, 1081, 5265, 2509, 28379, 41767, 19435, 143693, 0 };
            const std::uint32_t dim16085JoeKuoD6Init[]   =   { 1, 1, 7, 7, 31, 57, 19, 203, 467, 57, 1305, 1513, 6069, 15595, 31717, 44687, 65335, 159315, 0 };
            const std::uint32_t dim16086JoeKuoD6Init[]   =   { 1, 1, 1, 1, 13, 1, 41, 39, 489, 465, 1645, 2847, 6193, 11025, 11297, 55945, 92085, 243061, 0 };
            const std::uint32_t dim16087JoeKuoD6Init[]   =   { 1, 3, 3, 13, 15, 47, 87, 77, 321, 903, 181, 2093, 1673, 5375, 17969, 48467, 83441, 120867, 0 };
            const std::uint32_t dim16088JoeKuoD6Init[]   =   { 1, 3, 3, 13, 13, 17, 65, 181, 283, 471, 745, 1091, 7255, 5987, 29423, 27579, 96201, 218157, 0 };
            const std::uint32_t dim16089JoeKuoD6Init[]   =   { 1, 1, 1, 7, 13, 5, 101, 131, 309, 401, 99, 2353, 55, 2377, 6059, 64777, 33401, 225605, 0 };
            const std::uint32_t dim16090JoeKuoD6Init[]   =   { 1, 3, 1, 15, 9, 35, 37, 197, 65, 593, 411, 2233, 1485, 9599, 9581, 31935, 115145, 76867, 0 };
            const std::uint32_t dim16091JoeKuoD6Init[]   =   { 1, 3, 7, 9, 3, 41, 103, 237, 453, 335, 1831, 3947, 7573, 3859, 12495, 60617, 20715, 163119, 0 };
            const std::uint32_t dim16092JoeKuoD6Init[]   =   { 1, 3, 5, 7, 9, 9, 25, 79, 421, 267, 585, 1093, 2237, 8881, 7311, 39417, 110901, 8969, 0 };
            const std::uint32_t dim16093JoeKuoD6Init[]   =   { 1, 3, 3, 15, 1, 29, 75, 159, 89, 965, 457, 1645, 1485, 729, 30547, 2275, 79633, 126089, 0 };
            const std::uint32_t dim16094JoeKuoD6Init[]   =   { 1, 3, 7, 7, 19, 47, 55, 115, 287, 477, 719, 3311, 2455, 12033, 13811, 34011, 45153, 126991, 0 };
            const std::uint32_t dim16095JoeKuoD6Init[]   =   { 1, 3, 7, 5, 9, 33, 27, 215, 7, 113, 1027, 415, 1057, 13011, 1547, 7955, 21347, 79427, 0 };
            const std::uint32_t dim16096JoeKuoD6Init[]   =   { 1, 3, 1, 11, 1, 41, 27, 29, 255, 763, 219, 897, 915, 453, 9417, 22845, 31655, 228869, 0 };
            const std::uint32_t dim16097JoeKuoD6Init[]   =   { 1, 1, 7, 13, 7, 49, 105, 111, 53, 219, 171, 841, 5027, 5311, 28171, 58719, 32241, 170921, 0 };
            const std::uint32_t dim16098JoeKuoD6Init[]   =   { 1, 3, 5, 7, 21, 53, 11, 169, 45, 429, 1727, 1953, 8119, 14955, 19997, 62665, 31345, 135715, 0 };
            const std::uint32_t dim16099JoeKuoD6Init[]   =   { 1, 1, 5, 13, 17, 13, 125, 247, 411, 663, 1725, 2515, 7995, 8963, 5797, 32871, 66603, 137997, 0 };
            const std::uint32_t dim16100JoeKuoD6Init[]   =   { 1, 1, 5, 5, 23, 37, 15, 63, 35, 817, 463, 1413, 1203, 8031, 4169, 45755, 93511, 134751, 0 };
            const std::uint32_t dim16101JoeKuoD6Init[]   =   { 1, 1, 1, 1, 31, 17, 15, 125, 199, 57, 1499, 1567, 6113, 6503, 515, 57841, 49885, 213881, 0 };
            const std::uint32_t dim16102JoeKuoD6Init[]   =   { 1, 1, 7, 7, 15, 1, 67, 213, 197, 471, 577, 27, 1533, 13009, 31861, 62435, 113139, 77057, 0 };
            const std::uint32_t dim16103JoeKuoD6Init[]   =   { 1, 3, 7, 1, 29, 21, 99, 173, 137, 19, 1727, 1157, 5215, 4367, 28803, 26031, 120195, 60111, 0 };
            const std::uint32_t dim16104JoeKuoD6Init[]   =   { 1, 1, 5, 9, 25, 55, 27, 45, 231, 693, 765, 429, 2897, 6045, 19705, 61903, 5385, 172967, 0 };
            const std::uint32_t dim16105JoeKuoD6Init[]   =   { 1, 3, 1, 5, 9, 17, 35, 151, 91, 41, 89, 3751, 27, 5721, 26117, 6105, 31609, 79569, 0 };
            const std::uint32_t dim16106JoeKuoD6Init[]   =   { 1, 3, 5, 11, 15, 3, 25, 73, 383, 765, 729, 51, 4245, 6215, 9435, 45223, 68071, 68453, 0 };
            const std::uint32_t dim16107JoeKuoD6Init[]   =   { 1, 1, 7, 5, 31, 61, 19, 153, 331, 233, 11, 3047, 3939, 11959, 897, 4437, 2941, 174493, 0 };
            const std::uint32_t dim16108JoeKuoD6Init[]   =   { 1, 1, 7, 11, 27, 11, 83, 33, 7, 761, 805, 2327, 2997, 12269, 18707, 10615, 114357, 54951, 0 };
            const std::uint32_t dim16109JoeKuoD6Init[]   =   { 1, 3, 5, 9, 3, 45, 65, 193, 347, 771, 663, 2901, 6467, 14109, 5169, 38021, 39605, 216877, 0 };
            const std::uint32_t dim16110JoeKuoD6Init[]   =   { 1, 1, 7, 1, 1, 13, 109, 179, 499, 325, 1763, 1923, 7429, 259, 20589, 48473, 49605, 124709, 0 };
            const std::uint32_t dim16111JoeKuoD6Init[]   =   { 1, 3, 1, 3, 5, 27, 25, 127, 313, 541, 589, 751, 5959, 5801, 32467, 40597, 75625, 24827, 0 };
            const std::uint32_t dim16112JoeKuoD6Init[]   =   { 1, 1, 1, 3, 13, 35, 71, 223, 281, 767, 447, 1253, 2227, 7305, 23125, 62847, 16783, 76145, 0 };
            const std::uint32_t dim16113JoeKuoD6Init[]   =   { 1, 1, 5, 5, 11, 1, 95, 215, 351, 915, 1471, 143, 4011, 3373, 19019, 31797, 85891, 33871, 0 };
            const std::uint32_t dim16114JoeKuoD6Init[]   =   { 1, 1, 3, 9, 15, 39, 125, 29, 85, 625, 1155, 753, 6679, 14239, 14597, 32715, 97313, 162291, 0 };
            const std::uint32_t dim16115JoeKuoD6Init[]   =   { 1, 1, 1, 7, 13, 47, 127, 69, 199, 145, 123, 3207, 7673, 9991, 27501, 29189, 93027, 136881, 0 };
            const std::uint32_t dim16116JoeKuoD6Init[]   =   { 1, 3, 1, 15, 9, 21, 121, 23, 457, 315, 437, 1919, 5531, 13817, 8883, 4421, 19487, 88591, 0 };
            const std::uint32_t dim16117JoeKuoD6Init[]   =   { 1, 3, 1, 9, 15, 49, 101, 27, 11, 283, 1277, 971, 7697, 5915, 12709, 38251, 88165, 261609, 0 };
            const std::uint32_t dim16118JoeKuoD6Init[]   =   { 1, 1, 3, 9, 17, 19, 53, 131, 327, 917, 603, 2451, 3597, 14731, 9223, 29719, 113507, 69875, 0 };
            const std::uint32_t dim16119JoeKuoD6Init[]   =   { 1, 1, 5, 7, 1, 3, 77, 71, 149, 901, 283, 1599, 1053, 16305, 9937, 20907, 4133, 29623, 0 };
            const std::uint32_t dim16120JoeKuoD6Init[]   =   { 1, 1, 3, 9, 25, 63, 101, 255, 397, 233, 1111, 1583, 3431, 5245, 30209, 33201, 63859, 16551, 0 };
            const std::uint32_t dim16121JoeKuoD6Init[]   =   { 1, 1, 7, 5, 19, 25, 9, 137, 105, 363, 867, 811, 5829, 12595, 18867, 61021, 19425, 99399, 0 };
            const std::uint32_t dim16122JoeKuoD6Init[]   =   { 1, 1, 3, 7, 11, 1, 119, 95, 367, 239, 1677, 67, 283, 5701, 3635, 26917, 112895, 224049, 0 };
            const std::uint32_t dim16123JoeKuoD6Init[]   =   { 1, 3, 5, 11, 13, 33, 11, 191, 305, 551, 159, 1953, 4231, 811, 8711, 41291, 110917, 176177, 0 };
            const std::uint32_t dim16124JoeKuoD6Init[]   =   { 1, 3, 5, 9, 15, 3, 27, 29, 77, 881, 849, 1113, 7151, 3433, 11199, 38409, 98173, 21373, 0 };
            const std::uint32_t dim16125JoeKuoD6Init[]   =   { 1, 1, 5, 13, 25, 57, 81, 169, 215, 379, 1707, 493, 1071, 4869, 19149, 24585, 61803, 149305, 0 };
            const std::uint32_t dim16126JoeKuoD6Init[]   =   { 1, 1, 5, 11, 13, 11, 9, 45, 207, 347, 1203, 185, 3919, 3119, 27879, 50793, 18499, 109239, 0 };
            const std::uint32_t dim16127JoeKuoD6Init[]   =   { 1, 1, 1, 5, 3, 23, 123, 175, 445, 439, 215, 1883, 6857, 14837, 29411, 33633, 96241, 68361, 0 };
            const std::uint32_t dim16128JoeKuoD6Init[]   =   { 1, 1, 5, 7, 31, 53, 19, 41, 477, 203, 1133, 1471, 5067, 3875, 30655, 9207, 24835, 22019, 0 };
            const std::uint32_t dim16129JoeKuoD6Init[]   =   { 1, 3, 1, 11, 19, 9, 91, 217, 135, 169, 489, 727, 5471, 2125, 20867, 19689, 78859, 222433, 0 };
            const std::uint32_t dim16130JoeKuoD6Init[]   =   { 1, 1, 1, 13, 5, 37, 37, 39, 397, 527, 789, 1447, 7123, 6099, 16849, 48895, 95543, 56135, 0 };
            const std::uint32_t dim16131JoeKuoD6Init[]   =   { 1, 3, 7, 7, 15, 31, 81, 165, 31, 867, 1879, 1161, 3651, 5167, 12855, 60195, 85611, 191791, 0 };
            const std::uint32_t dim16132JoeKuoD6Init[]   =   { 1, 1, 1, 9, 31, 35, 19, 123, 281, 445, 63, 2683, 7073, 1489, 9791, 40125, 43723, 103765, 0 };
            const std::uint32_t dim16133JoeKuoD6Init[]   =   { 1, 3, 3, 9, 23, 31, 113, 241, 149, 463, 1047, 3737, 8105, 16295, 4565, 8095, 16617, 87455, 0 };
            const std::uint32_t dim16134JoeKuoD6Init[]   =   { 1, 3, 5, 15, 1, 47, 29, 77, 27, 1013, 1091, 3657, 835, 563, 7139, 58839, 92697, 114523, 0 };
            const std::uint32_t dim16135JoeKuoD6Init[]   =   { 1, 3, 1, 1, 5, 49, 87, 251, 473, 583, 2033, 809, 5341, 15835, 691, 57133, 75751, 127717, 0 };
            const std::uint32_t dim16136JoeKuoD6Init[]   =   { 1, 3, 1, 11, 23, 51, 95, 167, 73, 739, 573, 1113, 7585, 5457, 25767, 5583, 29583, 48263, 0 };
            const std::uint32_t dim16137JoeKuoD6Init[]   =   { 1, 1, 3, 5, 9, 59, 1, 235, 17, 973, 1987, 3629, 1739, 6419, 29943, 44963, 63943, 18571, 0 };
            const std::uint32_t dim16138JoeKuoD6Init[]   =   { 1, 3, 7, 11, 9, 37, 25, 253, 307, 411, 891, 1977, 6979, 11287, 12619, 50327, 25831, 135673, 0 };
            const std::uint32_t dim16139JoeKuoD6Init[]   =   { 1, 1, 5, 15, 23, 27, 83, 157, 253, 559, 1989, 2431, 4821, 6617, 4295, 16143, 249, 109855, 0 };
            const std::uint32_t dim16140JoeKuoD6Init[]   =   { 1, 1, 3, 9, 31, 59, 117, 139, 379, 703, 49, 3013, 6383, 4019, 7289, 4567, 34931, 224967, 0 };
            const std::uint32_t dim16141JoeKuoD6Init[]   =   { 1, 1, 1, 3, 3, 33, 49, 127, 177, 417, 723, 3259, 1547, 3297, 19733, 59465, 122179, 13209, 0 };
            const std::uint32_t dim16142JoeKuoD6Init[]   =   { 1, 3, 3, 1, 3, 61, 23, 177, 77, 579, 1739, 2707, 5319, 13291, 10223, 45395, 62797, 124675, 0 };
            const std::uint32_t dim16143JoeKuoD6Init[]   =   { 1, 1, 3, 15, 25, 47, 79, 111, 245, 853, 1103, 3741, 5783, 2075, 26371, 28801, 117831, 111735, 0 };
            const std::uint32_t dim16144JoeKuoD6Init[]   =   { 1, 1, 5, 11, 3, 47, 43, 61, 75, 963, 1507, 3491, 6031, 14171, 32557, 23779, 44815, 168409, 0 };
            const std::uint32_t dim16145JoeKuoD6Init[]   =   { 1, 3, 3, 7, 21, 39, 61, 109, 13, 833, 373, 4021, 4035, 7987, 18957, 10423, 82823, 8763, 0 };
            const std::uint32_t dim16146JoeKuoD6Init[]   =   { 1, 1, 7, 3, 3, 33, 113, 77, 447, 127, 213, 1605, 3873, 12345, 7847, 63903, 80665, 6647, 0 };
            const std::uint32_t dim16147JoeKuoD6Init[]   =   { 1, 3, 1, 5, 25, 11, 49, 233, 377, 791, 43, 195, 393, 1403, 27567, 29673, 11327, 190513, 0 };
            const std::uint32_t dim16148JoeKuoD6Init[]   =   { 1, 3, 1, 15, 21, 3, 21, 169, 221, 495, 1045, 3715, 4923, 2437, 23203, 59905, 70285, 258455, 0 };
            const std::uint32_t dim16149JoeKuoD6Init[]   =   { 1, 1, 7, 13, 29, 33, 91, 153, 31, 359, 25, 3947, 1699, 4081, 20907, 24953, 64977, 88115, 0 };
            const std::uint32_t dim16150JoeKuoD6Init[]   =   { 1, 1, 5, 11, 17, 7, 17, 129, 91, 835, 139, 3823, 1827, 6787, 27367, 26801, 61513, 189677, 0 };
            const std::uint32_t dim16151JoeKuoD6Init[]   =   { 1, 3, 3, 9, 23, 21, 97, 103, 481, 859, 413, 893, 4021, 8111, 23703, 18791, 102735, 82735, 0 };
            const std::uint32_t dim16152JoeKuoD6Init[]   =   { 1, 1, 1, 7, 11, 53, 61, 3, 347, 633, 191, 3605, 41, 12605, 14381, 60403, 126223, 186157, 0 };
            const std::uint32_t dim16153JoeKuoD6Init[]   =   { 1, 3, 5, 1, 11, 33, 61, 235, 245, 623, 2019, 3289, 5761, 15557, 1685, 2173, 104825, 245139, 0 };
            const std::uint32_t dim16154JoeKuoD6Init[]   =   { 1, 1, 3, 7, 19, 55, 75, 219, 11, 75, 1765, 1833, 263, 6605, 26297, 24969, 17721, 109495, 0 };
            const std::uint32_t dim16155JoeKuoD6Init[]   =   { 1, 1, 7, 5, 7, 33, 23, 109, 207, 137, 385, 3233, 6765, 3517, 31389, 57049, 25645, 176257, 0 };
            const std::uint32_t dim16156JoeKuoD6Init[]   =   { 1, 1, 5, 5, 27, 63, 65, 23, 93, 721, 1665, 3805, 3611, 7543, 21119, 38565, 99921, 72773, 0 };
            const std::uint32_t dim16157JoeKuoD6Init[]   =   { 1, 1, 1, 13, 13, 19, 23, 5, 425, 727, 1469, 1261, 6597, 725, 27129, 36953, 25781, 191581, 0 };
            const std::uint32_t dim16158JoeKuoD6Init[]   =   { 1, 3, 3, 1, 3, 29, 25, 109, 237, 135, 409, 2239, 5033, 11007, 31861, 55171, 76313, 216271, 0 };
            const std::uint32_t dim16159JoeKuoD6Init[]   =   { 1, 3, 7, 13, 31, 33, 11, 31, 179, 67, 755, 2513, 37, 12863, 24053, 12315, 45009, 166643, 0 };
            const std::uint32_t dim16160JoeKuoD6Init[]   =   { 1, 1, 5, 13, 13, 37, 19, 223, 409, 387, 139, 3283, 243, 15573, 24173, 63271, 91561, 168665, 0 };
            const std::uint32_t dim16161JoeKuoD6Init[]   =   { 1, 3, 5, 7, 17, 25, 63, 231, 23, 965, 1873, 1021, 7927, 11127, 19553, 9883, 83009, 258991, 0 };
            const std::uint32_t dim16162JoeKuoD6Init[]   =   { 1, 3, 1, 7, 17, 21, 71, 65, 165, 845, 1739, 2395, 5959, 14803, 17333, 59003, 36477, 202511, 0 };
            const std::uint32_t dim16163JoeKuoD6Init[]   =   { 1, 3, 5, 13, 15, 57, 59, 205, 507, 41, 703, 195, 4373, 4023, 13399, 62061, 43645, 204899, 0 };
            const std::uint32_t dim16164JoeKuoD6Init[]   =   { 1, 3, 5, 11, 13, 13, 43, 19, 497, 599, 1345, 2001, 407, 2731, 16283, 55161, 130887, 189201, 0 };
            const std::uint32_t dim16165JoeKuoD6Init[]   =   { 1, 1, 7, 5, 13, 3, 105, 83, 235, 363, 869, 1715, 4031, 3419, 15149, 10627, 47787, 226107, 0 };
            const std::uint32_t dim16166JoeKuoD6Init[]   =   { 1, 3, 3, 3, 9, 49, 99, 161, 413, 739, 195, 2815, 1157, 9069, 15591, 4509, 30765, 184013, 0 };
            const std::uint32_t dim16167JoeKuoD6Init[]   =   { 1, 3, 7, 5, 25, 63, 23, 91, 507, 647, 1249, 2035, 4341, 8811, 8345, 49463, 69023, 195775, 0 };
            const std::uint32_t dim16168JoeKuoD6Init[]   =   { 1, 3, 5, 5, 5, 21, 117, 1, 321, 495, 251, 1961, 8043, 6593, 11017, 6167, 56607, 144009, 0 };
            const std::uint32_t dim16169JoeKuoD6Init[]   =   { 1, 1, 3, 3, 15, 63, 41, 177, 403, 375, 1771, 3, 7481, 4887, 799, 59283, 106319, 32155, 0 };
            const std::uint32_t dim16170JoeKuoD6Init[]   =   { 1, 1, 1, 7, 19, 57, 97, 91, 489, 561, 335, 3809, 3167, 8879, 1789, 22329, 58851, 84461, 0 };
            const std::uint32_t dim16171JoeKuoD6Init[]   =   { 1, 3, 3, 11, 3, 23, 79, 25, 187, 497, 1343, 543, 4495, 14599, 29365, 14795, 26341, 26923, 0 };
            const std::uint32_t dim16172JoeKuoD6Init[]   =   { 1, 3, 1, 13, 21, 35, 9, 227, 423, 761, 439, 3099, 5167, 12955, 12877, 5591, 123511, 74227, 0 };
            const std::uint32_t dim16173JoeKuoD6Init[]   =   { 1, 1, 3, 7, 1, 49, 115, 95, 481, 659, 183, 2337, 39, 235, 30869, 10223, 59673, 65293, 0 };
            const std::uint32_t dim16174JoeKuoD6Init[]   =   { 1, 1, 1, 13, 11, 29, 113, 37, 153, 993, 1195, 1695, 4741, 13671, 29097, 65023, 78281, 156235, 0 };
            const std::uint32_t dim16175JoeKuoD6Init[]   =   { 1, 3, 5, 11, 19, 17, 47, 243, 273, 679, 393, 4059, 705, 12473, 1867, 13783, 86821, 240545, 0 };
            const std::uint32_t dim16176JoeKuoD6Init[]   =   { 1, 3, 1, 11, 23, 35, 15, 31, 275, 261, 427, 909, 7925, 4737, 22825, 34859, 28593, 20071, 0 };
            const std::uint32_t dim16177JoeKuoD6Init[]   =   { 1, 3, 1, 1, 13, 1, 115, 115, 103, 63, 1023, 815, 7007, 6063, 13329, 28051, 29807, 109861, 0 };
            const std::uint32_t dim16178JoeKuoD6Init[]   =   { 1, 1, 1, 11, 19, 57, 49, 169, 33, 59, 579, 2409, 89, 9655, 18091, 57771, 34509, 175991, 0 };
            const std::uint32_t dim16179JoeKuoD6Init[]   =   { 1, 1, 5, 9, 27, 19, 41, 217, 313, 359, 1745, 3887, 589, 3103, 10087, 30615, 56793, 102515, 0 };
            const std::uint32_t dim16180JoeKuoD6Init[]   =   { 1, 3, 7, 11, 25, 43, 101, 245, 67, 1003, 1379, 2141, 8025, 15231, 20705, 45513, 82251, 147295, 0 };
            const std::uint32_t dim16181JoeKuoD6Init[]   =   { 1, 3, 5, 5, 5, 47, 19, 33, 107, 773, 627, 4077, 5829, 6483, 25791, 35079, 103073, 201657, 0 };
            const std::uint32_t dim16182JoeKuoD6Init[]   =   { 1, 1, 5, 15, 1, 37, 115, 15, 61, 987, 1029, 2125, 5357, 10233, 14907, 12077, 92143, 207301, 0 };
            const std::uint32_t dim16183JoeKuoD6Init[]   =   { 1, 1, 7, 7, 3, 15, 95, 3, 393, 535, 819, 743, 3613, 11459, 2269, 17083, 65547, 74813, 0 };
            const std::uint32_t dim16184JoeKuoD6Init[]   =   { 1, 1, 7, 5, 11, 27, 117, 65, 55, 87, 105, 3219, 1587, 383, 25349, 54561, 11935, 101203, 0 };
            const std::uint32_t dim16185JoeKuoD6Init[]   =   { 1, 1, 5, 15, 23, 53, 37, 149, 191, 963, 1407, 4091, 1647, 9537, 30247, 23501, 123745, 76301, 0 };
            const std::uint32_t dim16186JoeKuoD6Init[]   =   { 1, 3, 1, 1, 21, 31, 11, 107, 55, 823, 805, 141, 7177, 15883, 3307, 52245, 115171, 260589, 0 };
            const std::uint32_t dim16187JoeKuoD6Init[]   =   { 1, 3, 7, 13, 25, 15, 5, 221, 347, 83, 51, 1227, 4591, 851, 10173, 37777, 82441, 175219, 0 };
            const std::uint32_t dim16188JoeKuoD6Init[]   =   { 1, 1, 7, 15, 17, 41, 121, 215, 111, 999, 367, 1961, 3207, 10145, 10395, 24381, 95937, 12693, 0 };
            const std::uint32_t dim16189JoeKuoD6Init[]   =   { 1, 1, 1, 11, 23, 27, 117, 255, 87, 519, 599, 3471, 3983, 2797, 13477, 56479, 27321, 101585, 0 };
            const std::uint32_t dim16190JoeKuoD6Init[]   =   { 1, 1, 5, 9, 1, 3, 35, 15, 457, 209, 141, 1295, 1631, 9745, 30247, 44865, 78113, 13207, 0 };
            const std::uint32_t dim16191JoeKuoD6Init[]   =   { 1, 3, 3, 1, 27, 63, 29, 31, 277, 173, 1321, 3847, 4127, 8713, 10507, 8697, 97025, 105995, 0 };
            const std::uint32_t dim16192JoeKuoD6Init[]   =   { 1, 1, 5, 13, 13, 47, 33, 69, 113, 369, 539, 4075, 1013, 9733, 9291, 33377, 130567, 238331, 0 };
            const std::uint32_t dim16193JoeKuoD6Init[]   =   { 1, 3, 7, 13, 15, 15, 125, 219, 205, 763, 1233, 1911, 7733, 7623, 27305, 6067, 16169, 238805, 0 };
            const std::uint32_t dim16194JoeKuoD6Init[]   =   { 1, 3, 1, 9, 23, 17, 35, 175, 157, 627, 1045, 1791, 1675, 11699, 2151, 28293, 14529, 30523, 0 };
            const std::uint32_t dim16195JoeKuoD6Init[]   =   { 1, 1, 5, 9, 5, 1, 23, 151, 295, 949, 371, 3317, 2557, 5815, 9699, 48379, 104561, 103747, 0 };
            const std::uint32_t dim16196JoeKuoD6Init[]   =   { 1, 3, 5, 5, 11, 57, 125, 247, 29, 257, 979, 2437, 4391, 8229, 11231, 30145, 111165, 92347, 0 };
            const std::uint32_t dim16197JoeKuoD6Init[]   =   { 1, 1, 3, 3, 27, 17, 71, 71, 357, 367, 1213, 2549, 6049, 15299, 2891, 21839, 109889, 34643, 0 };
            const std::uint32_t dim16198JoeKuoD6Init[]   =   { 1, 1, 1, 11, 7, 21, 41, 77, 249, 567, 1947, 2989, 875, 12975, 23599, 49313, 67213, 98415, 0 };
            const std::uint32_t dim16199JoeKuoD6Init[]   =   { 1, 1, 7, 7, 27, 51, 103, 221, 295, 247, 1579, 2435, 67, 3087, 9421, 59573, 111143, 42363, 0 };
            const std::uint32_t dim16200JoeKuoD6Init[]   =   { 1, 1, 1, 13, 27, 27, 75, 33, 81, 841, 1295, 2823, 997, 16329, 6117, 43361, 63727, 113347, 0 };
            const std::uint32_t dim16201JoeKuoD6Init[]   =   { 1, 1, 1, 3, 19, 7, 43, 93, 397, 293, 803, 3021, 3915, 1417, 22255, 38529, 53737, 133705, 0 };
            const std::uint32_t dim16202JoeKuoD6Init[]   =   { 1, 3, 3, 13, 1, 33, 1, 235, 255, 345, 1621, 315, 2685, 6451, 7133, 239, 103075, 175033, 0 };
            const std::uint32_t dim16203JoeKuoD6Init[]   =   { 1, 3, 1, 11, 29, 47, 61, 115, 395, 633, 1913, 2983, 4581, 3729, 22511, 16479, 80607, 232859, 0 };
            const std::uint32_t dim16204JoeKuoD6Init[]   =   { 1, 3, 7, 7, 27, 25, 29, 121, 511, 533, 1791, 3349, 4915, 8213, 13913, 6595, 2353, 207495, 0 };
            const std::uint32_t dim16205JoeKuoD6Init[]   =   { 1, 3, 7, 5, 21, 25, 77, 189, 473, 1015, 1455, 1923, 3281, 15163, 2329, 58529, 55369, 195007, 0 };
            const std::uint32_t dim16206JoeKuoD6Init[]   =   { 1, 3, 1, 1, 25, 37, 117, 41, 207, 413, 143, 1707, 7463, 15399, 3013, 4141, 37669, 70953, 0 };
            const std::uint32_t dim16207JoeKuoD6Init[]   =   { 1, 3, 5, 3, 31, 61, 41, 157, 141, 387, 1705, 1661, 3607, 6905, 3305, 63235, 7977, 253707, 0 };
            const std::uint32_t dim16208JoeKuoD6Init[]   =   { 1, 1, 5, 11, 29, 15, 61, 127, 417, 795, 171, 415, 7935, 4553, 29979, 21153, 108811, 219959, 0 };
            const std::uint32_t dim16209JoeKuoD6Init[]   =   { 1, 1, 5, 11, 17, 61, 3, 9, 297, 53, 933, 341, 507, 2683, 15313, 24113, 78617, 191127, 0 };
            const std::uint32_t dim16210JoeKuoD6Init[]   =   { 1, 1, 7, 15, 5, 57, 65, 187, 15, 541, 1843, 731, 7331, 2479, 26259, 32685, 125259, 108693, 0 };
            const std::uint32_t dim16211JoeKuoD6Init[]   =   { 1, 1, 7, 7, 11, 15, 33, 183, 225, 609, 1755, 3531, 2767, 6267, 30823, 36797, 59699, 136769, 0 };
            const std::uint32_t dim16212JoeKuoD6Init[]   =   { 1, 3, 5, 13, 15, 19, 77, 239, 307, 691, 1165, 1327, 7901, 9299, 7777, 39151, 96261, 79791, 0 };
            const std::uint32_t dim16213JoeKuoD6Init[]   =   { 1, 1, 3, 5, 29, 31, 85, 109, 381, 243, 955, 193, 3461, 5163, 18607, 51143, 74457, 84685, 0 };
            const std::uint32_t dim16214JoeKuoD6Init[]   =   { 1, 1, 5, 9, 11, 23, 77, 247, 149, 759, 1153, 1781, 4107, 16315, 15513, 48545, 55607, 163947, 0 };
            const std::uint32_t dim16215JoeKuoD6Init[]   =   { 1, 3, 3, 5, 21, 27, 57, 61, 75, 943, 97, 1507, 4091, 671, 23023, 49095, 61649, 222401, 0 };
            const std::uint32_t dim16216JoeKuoD6Init[]   =   { 1, 1, 3, 13, 1, 3, 15, 105, 285, 255, 577, 1347, 2917, 10257, 21607, 63041, 79823, 6447, 0 };
            const std::uint32_t dim16217JoeKuoD6Init[]   =   { 1, 1, 3, 1, 17, 25, 109, 47, 445, 225, 1729, 2835, 4569, 8755, 21847, 25839, 43503, 173599, 0 };
            const std::uint32_t dim16218JoeKuoD6Init[]   =   { 1, 1, 5, 15, 19, 1, 121, 119, 33, 77, 1147, 359, 5747, 2785, 15567, 5409, 125979, 199183, 0 };
            const std::uint32_t dim16219JoeKuoD6Init[]   =   { 1, 3, 1, 9, 17, 45, 85, 83, 427, 223, 531, 1681, 2343, 14959, 27297, 54607, 70889, 45529, 0 };
            const std::uint32_t dim16220JoeKuoD6Init[]   =   { 1, 1, 5, 11, 31, 61, 109, 195, 505, 197, 159, 2799, 4517, 11549, 10297, 17415, 58277, 206577, 0 };
            const std::uint32_t dim16221JoeKuoD6Init[]   =   { 1, 1, 3, 5, 17, 43, 107, 207, 453, 161, 1775, 1287, 5775, 12417, 14201, 48187, 75073, 121099, 0 };
            const std::uint32_t dim16222JoeKuoD6Init[]   =   { 1, 1, 5, 7, 31, 27, 67, 251, 127, 443, 263, 895, 8081, 14053, 32023, 54743, 14723, 221285, 0 };
            const std::uint32_t dim16223JoeKuoD6Init[]   =   { 1, 3, 3, 13, 27, 45, 51, 47, 243, 15, 1283, 2291, 3613, 14733, 8777, 3959, 36769, 104789, 0 };
            const std::uint32_t dim16224JoeKuoD6Init[]   =   { 1, 3, 5, 1, 5, 31, 1, 139, 411, 79, 959, 1431, 2329, 3595, 19231, 55747, 18923, 223709, 0 };
            const std::uint32_t dim16225JoeKuoD6Init[]   =   { 1, 3, 1, 1, 7, 9, 69, 201, 305, 411, 459, 3201, 2525, 6977, 16249, 17777, 114321, 243831, 0 };
            const std::uint32_t dim16226JoeKuoD6Init[]   =   { 1, 3, 3, 5, 13, 7, 3, 27, 201, 279, 1253, 1725, 1481, 8885, 1233, 40699, 7267, 189095, 0 };
            const std::uint32_t dim16227JoeKuoD6Init[]   =   { 1, 3, 5, 5, 31, 61, 53, 231, 93, 597, 2027, 2179, 4517, 565, 27807, 5447, 130341, 10411, 0 };
            const std::uint32_t dim16228JoeKuoD6Init[]   =   { 1, 1, 7, 1, 9, 17, 63, 245, 405, 23, 1647, 285, 6625, 8935, 959, 29095, 657, 185511, 0 };
            const std::uint32_t dim16229JoeKuoD6Init[]   =   { 1, 1, 7, 7, 5, 15, 49, 69, 479, 585, 437, 1097, 5933, 1709, 26169, 36895, 16981, 147033, 0 };
            const std::uint32_t dim16230JoeKuoD6Init[]   =   { 1, 3, 7, 13, 29, 19, 89, 249, 195, 687, 379, 1291, 4791, 9039, 6381, 12965, 99995, 105107, 0 };
            const std::uint32_t dim16231JoeKuoD6Init[]   =   { 1, 1, 5, 7, 13, 49, 101, 217, 205, 635, 577, 3301, 911, 1793, 22285, 20163, 22593, 45701, 0 };
            const std::uint32_t dim16232JoeKuoD6Init[]   =   { 1, 3, 7, 9, 3, 21, 55, 123, 205, 309, 59, 3739, 1625, 839, 26733, 27443, 6699, 244287, 0 };
            const std::uint32_t dim16233JoeKuoD6Init[]   =   { 1, 1, 1, 11, 29, 3, 33, 57, 481, 691, 1401, 3595, 5435, 571, 6945, 10911, 94721, 89751, 0 };
            const std::uint32_t dim16234JoeKuoD6Init[]   =   { 1, 1, 3, 5, 21, 19, 23, 169, 263, 137, 771, 1995, 2211, 6287, 18691, 14219, 65647, 89885, 0 };
            const std::uint32_t dim16235JoeKuoD6Init[]   =   { 1, 1, 3, 7, 7, 53, 9, 155, 327, 325, 301, 3703, 1069, 15573, 14873, 15665, 71617, 5079, 0 };
            const std::uint32_t dim16236JoeKuoD6Init[]   =   { 1, 3, 1, 3, 27, 15, 1, 203, 465, 629, 71, 1093, 2071, 7743, 22441, 42997, 35249, 113329, 0 };
            const std::uint32_t dim16237JoeKuoD6Init[]   =   { 1, 3, 5, 3, 21, 35, 107, 73, 247, 575, 719, 3215, 3181, 5861, 25169, 6503, 12347, 196371, 0 };
            const std::uint32_t dim16238JoeKuoD6Init[]   =   { 1, 3, 1, 3, 7, 29, 117, 115, 221, 345, 165, 1367, 1491, 15791, 12647, 34679, 1043, 219311, 0 };
            const std::uint32_t dim16239JoeKuoD6Init[]   =   { 1, 3, 5, 7, 19, 47, 65, 65, 101, 323, 1209, 3185, 3803, 1077, 18933, 17081, 7475, 165133, 0 };
            const std::uint32_t dim16240JoeKuoD6Init[]   =   { 1, 1, 7, 1, 25, 9, 61, 245, 175, 201, 1837, 2119, 943, 14043, 14343, 46299, 81151, 5587, 0 };
            const std::uint32_t dim16241JoeKuoD6Init[]   =   { 1, 1, 1, 1, 31, 27, 49, 89, 387, 975, 1203, 2995, 2969, 1465, 925, 39611, 38101, 126043, 0 };
            const std::uint32_t dim16242JoeKuoD6Init[]   =   { 1, 3, 7, 13, 21, 17, 45, 139, 359, 11, 335, 79, 6629, 6137, 7879, 62735, 99493, 138943, 0 };
            const std::uint32_t dim16243JoeKuoD6Init[]   =   { 1, 3, 5, 5, 9, 23, 91, 195, 89, 195, 1931, 3855, 387, 3491, 29643, 59939, 32347, 171539, 0 };
            const std::uint32_t dim16244JoeKuoD6Init[]   =   { 1, 3, 3, 15, 21, 55, 5, 13, 139, 125, 1731, 3131, 1927, 16051, 8351, 18625, 32465, 255813, 0 };
            const std::uint32_t dim16245JoeKuoD6Init[]   =   { 1, 3, 7, 11, 21, 45, 53, 225, 33, 733, 115, 639, 4801, 5529, 11041, 3557, 83521, 37525, 0 };
            const std::uint32_t dim16246JoeKuoD6Init[]   =   { 1, 3, 7, 15, 3, 37, 111, 127, 463, 565, 543, 2593, 2203, 5719, 11667, 63735, 16481, 155613, 0 };
            const std::uint32_t dim16247JoeKuoD6Init[]   =   { 1, 1, 3, 13, 31, 1, 17, 53, 479, 629, 1517, 89, 3377, 4831, 9213, 55029, 69547, 52363, 0 };
            const std::uint32_t dim16248JoeKuoD6Init[]   =   { 1, 1, 7, 1, 5, 47, 115, 73, 59, 407, 1227, 2955, 5249, 7921, 4713, 28699, 41455, 1161, 0 };
            const std::uint32_t dim16249JoeKuoD6Init[]   =   { 1, 1, 7, 7, 5, 7, 39, 7, 97, 867, 247, 639, 3125, 14961, 19737, 52589, 59821, 96095, 0 };
            const std::uint32_t dim16250JoeKuoD6Init[]   =   { 1, 1, 7, 5, 11, 51, 63, 245, 385, 1003, 189, 4039, 6137, 3621, 13241, 55753, 14855, 50221, 0 };
            const std::uint32_t dim16251JoeKuoD6Init[]   =   { 1, 3, 5, 3, 9, 61, 83, 209, 301, 917, 259, 187, 6253, 1579, 28285, 16571, 100945, 158067, 0 };
            const std::uint32_t dim16252JoeKuoD6Init[]   =   { 1, 3, 5, 11, 5, 47, 123, 173, 253, 183, 1823, 459, 4719, 13639, 8455, 12217, 88779, 134863, 0 };
            const std::uint32_t dim16253JoeKuoD6Init[]   =   { 1, 1, 1, 5, 1, 45, 43, 163, 371, 427, 1791, 1073, 1615, 14473, 15895, 4971, 105269, 109201, 0 };
            const std::uint32_t dim16254JoeKuoD6Init[]   =   { 1, 3, 1, 15, 11, 9, 99, 99, 25, 21, 1499, 83, 6967, 12923, 13623, 27423, 4707, 477, 0 };
            const std::uint32_t dim16255JoeKuoD6Init[]   =   { 1, 1, 3, 5, 15, 49, 45, 27, 51, 391, 1849, 347, 6841, 2831, 4425, 40701, 61135, 116945, 0 };
            const std::uint32_t dim16256JoeKuoD6Init[]   =   { 1, 1, 3, 7, 21, 23, 15, 223, 403, 395, 1997, 3247, 6345, 11739, 6511, 44323, 86667, 213287, 0 };
            const std::uint32_t dim16257JoeKuoD6Init[]   =   { 1, 3, 7, 11, 31, 21, 75, 129, 427, 777, 1787, 4031, 1493, 2279, 10681, 36675, 25527, 123533, 0 };
            const std::uint32_t dim16258JoeKuoD6Init[]   =   { 1, 3, 5, 15, 9, 5, 117, 147, 259, 265, 1817, 583, 5341, 12115, 2369, 4023, 123479, 218877, 0 };
            const std::uint32_t dim16259JoeKuoD6Init[]   =   { 1, 1, 1, 15, 5, 21, 87, 57, 487, 529, 1129, 2989, 39, 5995, 28779, 35813, 97425, 5227, 0 };
            const std::uint32_t dim16260JoeKuoD6Init[]   =   { 1, 1, 7, 3, 7, 1, 41, 231, 195, 205, 1663, 3149, 4439, 8241, 3085, 43965, 58833, 216779, 0 };
            const std::uint32_t dim16261JoeKuoD6Init[]   =   { 1, 1, 3, 1, 23, 45, 65, 3, 55, 653, 131, 2425, 5653, 9105, 16921, 55221, 29241, 220927, 0 };
            const std::uint32_t dim16262JoeKuoD6Init[]   =   { 1, 3, 1, 3, 5, 47, 107, 49, 175, 957, 1287, 1299, 5215, 4141, 31697, 9371, 43339, 133933, 0 };
            const std::uint32_t dim16263JoeKuoD6Init[]   =   { 1, 3, 1, 7, 13, 55, 33, 163, 361, 793, 101, 2159, 3457, 12893, 11627, 27115, 95201, 2945, 0 };
            const std::uint32_t dim16264JoeKuoD6Init[]   =   { 1, 1, 7, 15, 11, 39, 79, 113, 385, 41, 1715, 3887, 1347, 8141, 6121, 18653, 50867, 55745, 0 };
            const std::uint32_t dim16265JoeKuoD6Init[]   =   { 1, 1, 7, 13, 3, 5, 23, 59, 223, 665, 1823, 2989, 1069, 15161, 8917, 5539, 47437, 240933, 0 };
            const std::uint32_t dim16266JoeKuoD6Init[]   =   { 1, 3, 7, 13, 13, 19, 73, 25, 413, 211, 439, 339, 1159, 16063, 9589, 33451, 28789, 118883, 0 };
            const std::uint32_t dim16267JoeKuoD6Init[]   =   { 1, 1, 5, 11, 13, 61, 81, 63, 197, 569, 961, 253, 2065, 8969, 24045, 52811, 26929, 111329, 0 };
            const std::uint32_t dim16268JoeKuoD6Init[]   =   { 1, 3, 7, 5, 19, 23, 27, 163, 37, 103, 1737, 175, 1853, 597, 14147, 46159, 26385, 69427, 0 };
            const std::uint32_t dim16269JoeKuoD6Init[]   =   { 1, 3, 7, 9, 27, 43, 45, 209, 61, 115, 645, 1149, 1473, 10557, 8541, 51703, 29207, 92059, 0 };
            const std::uint32_t dim16270JoeKuoD6Init[]   =   { 1, 1, 5, 5, 25, 53, 123, 243, 493, 403, 485, 1505, 6879, 1921, 13569, 28271, 24407, 73057, 0 };
            const std::uint32_t dim16271JoeKuoD6Init[]   =   { 1, 1, 3, 11, 15, 31, 99, 29, 503, 819, 55, 773, 2993, 15341, 7625, 12835, 28555, 200609, 0 };
            const std::uint32_t dim16272JoeKuoD6Init[]   =   { 1, 1, 7, 9, 21, 49, 47, 207, 13, 571, 57, 1727, 7441, 1703, 4253, 64851, 113, 180273, 0 };
            const std::uint32_t dim16273JoeKuoD6Init[]   =   { 1, 3, 3, 9, 23, 1, 1, 53, 195, 569, 925, 1969, 3031, 14371, 17673, 39163, 11819, 117573, 0 };
            const std::uint32_t dim16274JoeKuoD6Init[]   =   { 1, 1, 1, 11, 5, 3, 103, 133, 447, 1015, 1049, 3283, 7507, 233, 13721, 50721, 75511, 227561, 0 };
            const std::uint32_t dim16275JoeKuoD6Init[]   =   { 1, 3, 1, 1, 17, 59, 79, 105, 503, 173, 1575, 1563, 5807, 12841, 7983, 28209, 27527, 229919, 0 };
            const std::uint32_t dim16276JoeKuoD6Init[]   =   { 1, 1, 3, 9, 3, 41, 125, 213, 361, 939, 161, 2235, 2575, 13519, 7957, 21527, 40693, 51055, 0 };
            const std::uint32_t dim16277JoeKuoD6Init[]   =   { 1, 3, 7, 11, 11, 7, 117, 21, 7, 745, 1109, 3393, 953, 5163, 19909, 49121, 85061, 209555, 0 };
            const std::uint32_t dim16278JoeKuoD6Init[]   =   { 1, 1, 7, 5, 27, 59, 127, 199, 119, 461, 653, 497, 5867, 767, 16373, 21201, 87589, 171491, 0 };
            const std::uint32_t dim16279JoeKuoD6Init[]   =   { 1, 1, 7, 11, 7, 21, 121, 97, 17, 827, 1191, 113, 6527, 14977, 32567, 15191, 104541, 140359, 0 };
            const std::uint32_t dim16280JoeKuoD6Init[]   =   { 1, 1, 7, 13, 19, 29, 127, 207, 233, 511, 43, 3177, 7963, 5559, 24185, 13373, 37853, 150537, 0 };
            const std::uint32_t dim16281JoeKuoD6Init[]   =   { 1, 3, 3, 9, 15, 17, 119, 201, 443, 51, 17, 605, 4191, 5251, 28903, 4861, 92571, 143499, 0 };
            const std::uint32_t dim16282JoeKuoD6Init[]   =   { 1, 1, 5, 11, 21, 45, 111, 245, 115, 705, 1267, 3013, 7907, 14973, 30499, 44117, 118229, 136571, 0 };
            const std::uint32_t dim16283JoeKuoD6Init[]   =   { 1, 3, 7, 7, 31, 35, 69, 143, 269, 27, 1365, 775, 6067, 11477, 28475, 54573, 92827, 226459, 0 };
            const std::uint32_t dim16284JoeKuoD6Init[]   =   { 1, 1, 5, 1, 1, 29, 41, 189, 423, 245, 1031, 1667, 3465, 1491, 26787, 53851, 26189, 215443, 0 };
            const std::uint32_t dim16285JoeKuoD6Init[]   =   { 1, 3, 3, 5, 23, 29, 97, 141, 135, 249, 767, 3627, 7867, 9311, 25411, 38325, 118643, 128453, 0 };
            const std::uint32_t dim16286JoeKuoD6Init[]   =   { 1, 3, 7, 13, 3, 25, 61, 121, 285, 401, 1099, 2327, 5509, 16127, 2363, 52395, 114233, 216013, 0 };
            const std::uint32_t dim16287JoeKuoD6Init[]   =   { 1, 1, 1, 13, 7, 37, 83, 151, 447, 605, 289, 2941, 6273, 5945, 7493, 29805, 34935, 101177, 0 };
            const std::uint32_t dim16288JoeKuoD6Init[]   =   { 1, 1, 7, 13, 31, 51, 125, 9, 321, 293, 489, 4023, 2425, 7645, 2927, 20973, 111223, 71255, 0 };
            const std::uint32_t dim16289JoeKuoD6Init[]   =   { 1, 1, 7, 3, 27, 9, 59, 143, 307, 543, 1995, 111, 5807, 4641, 3581, 2421, 64213, 187567, 0 };
            const std::uint32_t dim16290JoeKuoD6Init[]   =   { 1, 3, 3, 9, 23, 33, 47, 81, 441, 995, 213, 3501, 1003, 9885, 24101, 58767, 49507, 30525, 0 };
            const std::uint32_t dim16291JoeKuoD6Init[]   =   { 1, 3, 1, 3, 19, 51, 117, 53, 49, 167, 1799, 1421, 2473, 3183, 14421, 58621, 130703, 48095, 0 };
            const std::uint32_t dim16292JoeKuoD6Init[]   =   { 1, 1, 7, 7, 5, 25, 33, 237, 447, 377, 517, 2047, 4357, 2747, 16491, 23935, 21655, 144151, 0 };
            const std::uint32_t dim16293JoeKuoD6Init[]   =   { 1, 1, 7, 7, 17, 5, 57, 67, 89, 897, 1163, 3517, 1651, 6745, 23449, 2853, 43829, 50707, 0 };
            const std::uint32_t dim16294JoeKuoD6Init[]   =   { 1, 1, 1, 13, 5, 45, 87, 139, 339, 1021, 649, 2957, 7887, 11957, 11235, 11063, 77329, 93121, 0 };
            const std::uint32_t dim16295JoeKuoD6Init[]   =   { 1, 1, 1, 7, 11, 35, 73, 241, 11, 287, 551, 207, 4701, 2031, 27191, 44337, 35577, 226387, 0 };
            const std::uint32_t dim16296JoeKuoD6Init[]   =   { 1, 3, 5, 11, 19, 3, 41, 211, 29, 913, 1455, 2525, 3935, 5581, 8043, 12033, 97479, 73521, 0 };
            const std::uint32_t dim16297JoeKuoD6Init[]   =   { 1, 3, 5, 7, 15, 49, 53, 185, 229, 161, 121, 3407, 903, 7257, 19535, 42197, 3983, 222077, 0 };
            const std::uint32_t dim16298JoeKuoD6Init[]   =   { 1, 1, 5, 7, 17, 33, 61, 121, 343, 111, 151, 1147, 3743, 2423, 24151, 42307, 50711, 140317, 0 };
            const std::uint32_t dim16299JoeKuoD6Init[]   =   { 1, 3, 3, 7, 27, 1, 119, 209, 243, 185, 1253, 2307, 7659, 7839, 9697, 16799, 5189, 130005, 0 };
            const std::uint32_t dim16300JoeKuoD6Init[]   =   { 1, 3, 3, 1, 27, 21, 115, 175, 157, 735, 1233, 1133, 1763, 1125, 4667, 42569, 125185, 218417, 0 };
            const std::uint32_t dim16301JoeKuoD6Init[]   =   { 1, 3, 5, 9, 5, 37, 97, 165, 87, 447, 1491, 3141, 597, 10651, 9727, 65163, 2469, 141859, 0 };
            const std::uint32_t dim16302JoeKuoD6Init[]   =   { 1, 1, 5, 13, 11, 53, 111, 123, 423, 413, 1519, 3715, 6623, 15415, 24085, 20925, 1529, 85183, 0 };
            const std::uint32_t dim16303JoeKuoD6Init[]   =   { 1, 3, 7, 1, 31, 45, 93, 45, 363, 779, 443, 3687, 6051, 11683, 31733, 57251, 55087, 240877, 0 };
            const std::uint32_t dim16304JoeKuoD6Init[]   =   { 1, 1, 1, 15, 1, 17, 53, 237, 131, 673, 1919, 1531, 7455, 5043, 1709, 23375, 75657, 194393, 0 };
            const std::uint32_t dim16305JoeKuoD6Init[]   =   { 1, 3, 5, 9, 21, 3, 101, 141, 387, 887, 1329, 2627, 2865, 2685, 20273, 18901, 43805, 181049, 0 };
            const std::uint32_t dim16306JoeKuoD6Init[]   =   { 1, 3, 5, 5, 7, 49, 55, 243, 311, 653, 959, 3157, 4891, 8777, 14381, 28105, 119323, 181129, 0 };
            const std::uint32_t dim16307JoeKuoD6Init[]   =   { 1, 1, 1, 9, 17, 33, 97, 123, 71, 5, 793, 2829, 4385, 8577, 9927, 26213, 53287, 203555, 0 };
            const std::uint32_t dim16308JoeKuoD6Init[]   =   { 1, 1, 1, 9, 15, 61, 51, 31, 195, 1003, 1915, 2349, 5319, 13411, 15265, 36321, 76157, 200437, 0 };
            const std::uint32_t dim16309JoeKuoD6Init[]   =   { 1, 3, 1, 13, 19, 41, 11, 227, 447, 395, 1885, 2953, 3537, 3855, 21611, 14547, 106573, 233205, 0 };
            const std::uint32_t dim16310JoeKuoD6Init[]   =   { 1, 3, 1, 11, 1, 1, 7, 61, 69, 631, 1687, 1131, 6901, 5801, 14431, 17807, 35777, 253941, 0 };
            const std::uint32_t dim16311JoeKuoD6Init[]   =   { 1, 3, 5, 9, 15, 47, 71, 145, 419, 401, 1781, 2031, 3157, 14483, 2393, 4061, 122053, 81701, 0 };
            const std::uint32_t dim16312JoeKuoD6Init[]   =   { 1, 3, 7, 13, 23, 21, 67, 147, 137, 277, 259, 3119, 4785, 5349, 3193, 21805, 108265, 231111, 0 };
            const std::uint32_t dim16313JoeKuoD6Init[]   =   { 1, 1, 3, 9, 23, 63, 77, 153, 75, 643, 1341, 3607, 6001, 3387, 17485, 17893, 124699, 99515, 0 };
            const std::uint32_t dim16314JoeKuoD6Init[]   =   { 1, 1, 7, 11, 9, 51, 79, 255, 255, 723, 1797, 2805, 2505, 3437, 4835, 30731, 73741, 8051, 0 };
            const std::uint32_t dim16315JoeKuoD6Init[]   =   { 1, 1, 5, 7, 5, 19, 73, 75, 19, 889, 1443, 2263, 5773, 9997, 329, 46679, 82313, 130897, 0 };
            const std::uint32_t dim16316JoeKuoD6Init[]   =   { 1, 3, 3, 9, 7, 53, 69, 11, 287, 861, 1367, 1433, 2693, 16255, 6785, 24705, 77463, 231247, 0 };
            const std::uint32_t dim16317JoeKuoD6Init[]   =   { 1, 1, 3, 7, 21, 15, 115, 131, 169, 447, 1731, 2873, 119, 643, 31719, 22193, 17959, 150567, 0 };
            const std::uint32_t dim16318JoeKuoD6Init[]   =   { 1, 3, 3, 9, 23, 21, 7, 39, 185, 837, 379, 3687, 3751, 14801, 15231, 7239, 77521, 80135, 0 };
            const std::uint32_t dim16319JoeKuoD6Init[]   =   { 1, 1, 1, 1, 7, 33, 93, 247, 487, 873, 1951, 3273, 551, 3735, 29477, 62387, 30361, 145613, 0 };
            const std::uint32_t dim16320JoeKuoD6Init[]   =   { 1, 1, 3, 7, 5, 47, 17, 31, 93, 517, 1175, 1033, 7421, 75, 541, 1967, 13059, 104751, 0 };
            const std::uint32_t dim16321JoeKuoD6Init[]   =   { 1, 3, 5, 3, 19, 23, 123, 115, 99, 747, 655, 2885, 2991, 7497, 5989, 33419, 54363, 224947, 0 };
            const std::uint32_t dim16322JoeKuoD6Init[]   =   { 1, 3, 3, 1, 15, 9, 51, 3, 307, 879, 1065, 1835, 2267, 11299, 21995, 2997, 102207, 39, 0 };
            const std::uint32_t dim16323JoeKuoD6Init[]   =   { 1, 3, 5, 3, 9, 19, 19, 79, 499, 121, 951, 1151, 379, 5299, 13727, 49061, 32605, 208683, 0 };
            const std::uint32_t dim16324JoeKuoD6Init[]   =   { 1, 3, 7, 7, 23, 41, 71, 23, 493, 969, 271, 3729, 6199, 14693, 17625, 52509, 121257, 151175, 0 };
            const std::uint32_t dim16325JoeKuoD6Init[]   =   { 1, 1, 7, 15, 9, 51, 61, 9, 147, 527, 803, 3255, 723, 3241, 23961, 17497, 122569, 50863, 0 };
            const std::uint32_t dim16326JoeKuoD6Init[]   =   { 1, 3, 5, 1, 19, 19, 31, 31, 95, 667, 377, 1193, 6759, 8583, 29801, 7989, 113899, 43481, 0 };
            const std::uint32_t dim16327JoeKuoD6Init[]   =   { 1, 3, 7, 5, 17, 47, 1, 7, 305, 489, 1035, 1335, 5901, 9635, 10433, 4235, 108577, 52661, 0 };
            const std::uint32_t dim16328JoeKuoD6Init[]   =   { 1, 1, 7, 3, 15, 7, 105, 189, 429, 287, 679, 111, 2087, 8479, 3053, 21763, 65655, 16207, 0 };
            const std::uint32_t dim16329JoeKuoD6Init[]   =   { 1, 3, 5, 13, 19, 41, 45, 115, 311, 653, 1301, 3797, 6183, 7203, 9829, 13263, 71649, 255611, 0 };
            const std::uint32_t dim16330JoeKuoD6Init[]   =   { 1, 3, 1, 9, 21, 33, 19, 233, 83, 423, 1701, 347, 3999, 11885, 19699, 61931, 63895, 59615, 0 };
            const std::uint32_t dim16331JoeKuoD6Init[]   =   { 1, 1, 7, 7, 15, 19, 61, 43, 183, 223, 1135, 3099, 3137, 16181, 31019, 20151, 30169, 13125, 0 };
            const std::uint32_t dim16332JoeKuoD6Init[]   =   { 1, 1, 1, 11, 9, 11, 3, 157, 495, 207, 603, 1919, 3565, 7639, 4281, 49179, 2465, 224033, 0 };
            const std::uint32_t dim16333JoeKuoD6Init[]   =   { 1, 3, 1, 13, 13, 19, 127, 81, 475, 659, 1053, 3153, 5223, 12567, 30945, 47109, 98253, 41571, 0 };
            const std::uint32_t dim16334JoeKuoD6Init[]   =   { 1, 1, 5, 11, 19, 1, 9, 67, 501, 149, 1695, 1265, 6467, 5285, 29865, 46777, 97581, 209395, 0 };
            const std::uint32_t dim16335JoeKuoD6Init[]   =   { 1, 1, 1, 11, 21, 23, 123, 103, 419, 787, 111, 3327, 673, 3425, 8097, 2411, 107353, 121379, 0 };
            const std::uint32_t dim16336JoeKuoD6Init[]   =   { 1, 1, 3, 3, 17, 7, 87, 35, 501, 973, 351, 751, 4813, 12245, 3053, 38633, 44995, 37151, 0 };
            const std::uint32_t dim16337JoeKuoD6Init[]   =   { 1, 3, 5, 15, 7, 57, 99, 53, 3, 355, 153, 3897, 6923, 2075, 10821, 41819, 75665, 21237, 0 };
            const std::uint32_t dim16338JoeKuoD6Init[]   =   { 1, 3, 5, 9, 3, 29, 85, 115, 191, 977, 1067, 1539, 5287, 3589, 18017, 35571, 41633, 148565, 0 };
            const std::uint32_t dim16339JoeKuoD6Init[]   =   { 1, 1, 3, 9, 9, 57, 1, 63, 333, 107, 1173, 3377, 3599, 277, 20643, 19295, 91169, 168891, 0 };
            const std::uint32_t dim16340JoeKuoD6Init[]   =   { 1, 1, 5, 13, 21, 7, 55, 15, 79, 995, 1553, 949, 6357, 8137, 9539, 861, 95635, 63021, 0 };
            const std::uint32_t dim16341JoeKuoD6Init[]   =   { 1, 1, 5, 13, 31, 59, 11, 55, 159, 449, 307, 2725, 2305, 8259, 13823, 51225, 44775, 54253, 0 };
            const std::uint32_t dim16342JoeKuoD6Init[]   =   { 1, 3, 3, 15, 19, 61, 105, 19, 211, 693, 835, 3607, 3703, 14007, 24597, 47109, 49855, 166115, 0 };
            const std::uint32_t dim16343JoeKuoD6Init[]   =   { 1, 3, 1, 9, 27, 33, 81, 229, 445, 171, 247, 2019, 5227, 8759, 30155, 1851, 26909, 47145, 0 };
            const std::uint32_t dim16344JoeKuoD6Init[]   =   { 1, 1, 3, 5, 23, 1, 57, 49, 177, 451, 1283, 3859, 4719, 13507, 29439, 9155, 129585, 94713, 0 };
            const std::uint32_t dim16345JoeKuoD6Init[]   =   { 1, 3, 3, 5, 1, 9, 37, 23, 423, 611, 113, 119, 4307, 11747, 93, 51213, 5479, 172061, 0 };
            const std::uint32_t dim16346JoeKuoD6Init[]   =   { 1, 3, 3, 15, 5, 35, 9, 43, 423, 877, 1563, 3411, 4233, 6961, 22421, 7347, 39553, 199745, 0 };
            const std::uint32_t dim16347JoeKuoD6Init[]   =   { 1, 3, 1, 9, 15, 35, 85, 57, 151, 323, 1627, 27, 3603, 11475, 6561, 6091, 72099, 185321, 0 };
            const std::uint32_t dim16348JoeKuoD6Init[]   =   { 1, 1, 3, 15, 17, 21, 3, 119, 455, 147, 1077, 3955, 1355, 3083, 28217, 50745, 114445, 46563, 0 };
            const std::uint32_t dim16349JoeKuoD6Init[]   =   { 1, 1, 5, 3, 13, 11, 35, 185, 357, 447, 649, 139, 2847, 12011, 7753, 671, 113693, 236281, 0 };
            const std::uint32_t dim16350JoeKuoD6Init[]   =   { 1, 3, 5, 1, 19, 27, 117, 195, 67, 259, 1073, 81, 5527, 6829, 26675, 60029, 8159, 13553, 0 };
            const std::uint32_t dim16351JoeKuoD6Init[]   =   { 1, 3, 3, 7, 27, 63, 115, 191, 431, 191, 1547, 2261, 6527, 13459, 12773, 37485, 114847, 61709, 0 };
            const std::uint32_t dim16352JoeKuoD6Init[]   =   { 1, 1, 3, 1, 29, 63, 47, 77, 415, 191, 325, 2487, 7457, 13721, 1573, 15037, 31941, 226651, 0 };
            const std::uint32_t dim16353JoeKuoD6Init[]   =   { 1, 1, 5, 11, 29, 59, 49, 209, 195, 901, 691, 3167, 7471, 11609, 30135, 22067, 71395, 248151, 0 };
            const std::uint32_t dim16354JoeKuoD6Init[]   =   { 1, 3, 7, 11, 7, 43, 55, 69, 289, 735, 1479, 139, 1395, 6463, 19827, 52151, 18963, 103367, 0 };
            const std::uint32_t dim16355JoeKuoD6Init[]   =   { 1, 3, 5, 5, 27, 45, 77, 79, 89, 79, 913, 1437, 3337, 8861, 5477, 46195, 105869, 242599, 0 };
            const std::uint32_t dim16356JoeKuoD6Init[]   =   { 1, 3, 5, 3, 3, 27, 103, 207, 233, 995, 1173, 1143, 3517, 3207, 8373, 45145, 79687, 150107, 0 };
            const std::uint32_t dim16357JoeKuoD6Init[]   =   { 1, 3, 7, 3, 7, 37, 1, 137, 45, 479, 861, 3863, 4249, 3075, 23639, 12531, 118473, 255805, 0 };
            const std::uint32_t dim16358JoeKuoD6Init[]   =   { 1, 1, 1, 9, 7, 23, 125, 57, 347, 215, 1749, 3029, 97, 14715, 16213, 29291, 104725, 92043, 0 };
            const std::uint32_t dim16359JoeKuoD6Init[]   =   { 1, 3, 3, 15, 31, 39, 111, 97, 369, 675, 1471, 3889, 6437, 1499, 13325, 46141, 121087, 202493, 0 };
            const std::uint32_t dim16360JoeKuoD6Init[]   =   { 1, 1, 1, 15, 15, 21, 3, 167, 251, 793, 1291, 427, 6407, 15521, 15441, 20071, 54513, 200485, 0 };
            const std::uint32_t dim16361JoeKuoD6Init[]   =   { 1, 1, 7, 11, 27, 47, 123, 195, 241, 385, 609, 2323, 1221, 815, 279, 28553, 17663, 180977, 0 };
            const std::uint32_t dim16362JoeKuoD6Init[]   =   { 1, 1, 3, 15, 23, 53, 21, 19, 329, 903, 561, 1539, 2829, 13037, 29867, 27825, 84005, 14853, 0 };
            const std::uint32_t dim16363JoeKuoD6Init[]   =   { 1, 1, 5, 1, 21, 27, 103, 99, 31, 829, 515, 3949, 3635, 935, 2127, 56659, 123477, 47003, 0 };
            const std::uint32_t dim16364JoeKuoD6Init[]   =   { 1, 3, 1, 11, 17, 63, 51, 15, 319, 539, 55, 2561, 1109, 16115, 23387, 20051, 120867, 4019, 0 };
            const std::uint32_t dim16365JoeKuoD6Init[]   =   { 1, 3, 3, 7, 31, 11, 45, 251, 209, 21, 553, 887, 393, 15183, 14735, 13163, 123681, 15013, 0 };
            const std::uint32_t dim16366JoeKuoD6Init[]   =   { 1, 3, 1, 7, 21, 41, 105, 39, 213, 477, 985, 2375, 937, 7099, 8867, 36519, 60503, 143225, 0 };
            const std::uint32_t dim16367JoeKuoD6Init[]   =   { 1, 3, 1, 1, 19, 55, 73, 171, 379, 271, 791, 2477, 5381, 1703, 3805, 37227, 55553, 34549, 0 };
            const std::uint32_t dim16368JoeKuoD6Init[]   =   { 1, 1, 5, 5, 29, 51, 127, 111, 209, 663, 975, 2293, 8155, 11263, 7891, 15463, 74889, 227403, 0 };
            const std::uint32_t dim16369JoeKuoD6Init[]   =   { 1, 3, 5, 1, 15, 1, 115, 221, 23, 247, 1597, 87, 7513, 3329, 14491, 8961, 78147, 89499, 0 };
            const std::uint32_t dim16370JoeKuoD6Init[]   =   { 1, 3, 5, 15, 25, 23, 99, 85, 189, 487, 1559, 427, 6179, 5291, 27279, 65507, 77347, 177073, 0 };
            const std::uint32_t dim16371JoeKuoD6Init[]   =   { 1, 3, 7, 1, 23, 35, 7, 89, 455, 659, 2039, 3115, 4057, 139, 1269, 62319, 13629, 201571, 0 };
            const std::uint32_t dim16372JoeKuoD6Init[]   =   { 1, 1, 1, 5, 9, 47, 55, 171, 213, 813, 135, 1545, 1421, 4055, 26697, 18889, 57653, 201369, 0 };
            const std::uint32_t dim16373JoeKuoD6Init[]   =   { 1, 3, 1, 11, 9, 45, 5, 69, 261, 907, 1229, 1371, 1867, 1771, 17309, 41759, 119129, 43521, 0 };
            const std::uint32_t dim16374JoeKuoD6Init[]   =   { 1, 1, 7, 5, 11, 27, 9, 237, 405, 53, 1359, 3665, 169, 3547, 23331, 14353, 106627, 219711, 0 };
            const std::uint32_t dim16375JoeKuoD6Init[]   =   { 1, 3, 3, 5, 17, 23, 9, 41, 81, 601, 1447, 3225, 6721, 161, 16109, 54331, 111273, 81061, 0 };
            const std::uint32_t dim16376JoeKuoD6Init[]   =   { 1, 1, 5, 7, 7, 37, 71, 13, 505, 671, 425, 2771, 1131, 1259, 13715, 45779, 114839, 217499, 0 };
            const std::uint32_t dim16377JoeKuoD6Init[]   =   { 1, 1, 1, 5, 9, 51, 85, 223, 117, 403, 1117, 723, 2465, 11947, 7495, 62991, 17825, 169147, 0 };
            const std::uint32_t dim16378JoeKuoD6Init[]   =   { 1, 1, 3, 13, 5, 57, 47, 35, 313, 901, 365, 1265, 137, 6335, 31419, 38497, 93285, 177187, 0 };
            const std::uint32_t dim16379JoeKuoD6Init[]   =   { 1, 3, 5, 5, 7, 9, 21, 109, 47, 557, 1449, 3459, 5175, 5135, 727, 55425, 60593, 86571, 0 };
            const std::uint32_t dim16380JoeKuoD6Init[]   =   { 1, 3, 7, 5, 1, 17, 119, 239, 347, 75, 1345, 2765, 1491, 16297, 25233, 60401, 85433, 59287, 0 };
            const std::uint32_t dim16381JoeKuoD6Init[]   =   { 1, 1, 5, 5, 19, 57, 41, 53, 161, 475, 1791, 3617, 1651, 15227, 30357, 63547, 69937, 246473, 0 };
            const std::uint32_t dim16382JoeKuoD6Init[]   =   { 1, 3, 7, 11, 11, 43, 79, 79, 195, 437, 39, 1259, 6041, 14989, 6615, 58747, 43583, 246979, 0 };
            const std::uint32_t dim16383JoeKuoD6Init[]   =   { 1, 1, 7, 9, 11, 13, 49, 133, 365, 931, 1089, 713, 5997, 8759, 5789, 61329, 22639, 149845, 0 };
            const std::uint32_t dim16384JoeKuoD6Init[]   =   { 1, 3, 7, 13, 9, 3, 11, 253, 339, 883, 1933, 443, 4265, 14165, 15845, 12625, 1453, 70961, 0 };
            const std::uint32_t dim16385JoeKuoD6Init[]   =   { 1, 1, 7, 13, 21, 35, 113, 83, 473, 719, 1601, 1727, 3715, 631, 28075, 17725, 11393, 116883, 0 };
            const std::uint32_t dim16386JoeKuoD6Init[]   =   { 1, 3, 7, 7, 7, 13, 117, 83, 365, 529, 1297, 3903, 2633, 9617, 15819, 38137, 49065, 189445, 0 };
            const std::uint32_t dim16387JoeKuoD6Init[]   =   { 1, 1, 1, 7, 11, 41, 107, 33, 381, 395, 1993, 2819, 3301, 7543, 6787, 27437, 113681, 132403, 0 };
            const std::uint32_t dim16388JoeKuoD6Init[]   =   { 1, 1, 1, 1, 3, 59, 91, 235, 67, 987, 1587, 1119, 5851, 13201, 1125, 49709, 381, 183295, 0 };
            const std::uint32_t dim16389JoeKuoD6Init[]   =   { 1, 3, 5, 9, 3, 33, 45, 187, 455, 151, 823, 565, 5725, 1927, 25387, 61785, 130271, 134083, 0 };
            const std::uint32_t dim16390JoeKuoD6Init[]   =   { 1, 1, 7, 5, 15, 25, 63, 231, 133, 401, 307, 2961, 4249, 2639, 10207, 8349, 8203, 72783, 0 };
            const std::uint32_t dim16391JoeKuoD6Init[]   =   { 1, 1, 5, 13, 19, 27, 43, 153, 165, 815, 1385, 3041, 853, 7683, 1035, 13255, 69779, 128765, 0 };
            const std::uint32_t dim16392JoeKuoD6Init[]   =   { 1, 1, 1, 3, 31, 61, 97, 15, 327, 717, 841, 643, 4781, 11609, 14181, 14625, 75369, 251015, 0 };
            const std::uint32_t dim16393JoeKuoD6Init[]   =   { 1, 1, 5, 11, 17, 33, 9, 45, 111, 91, 1923, 967, 5649, 13647, 30497, 2925, 18395, 255089, 0 };
            const std::uint32_t dim16394JoeKuoD6Init[]   =   { 1, 3, 3, 1, 3, 55, 33, 29, 101, 211, 1731, 2351, 7389, 14935, 29703, 60031, 122305, 174323, 0 };
            const std::uint32_t dim16395JoeKuoD6Init[]   =   { 1, 1, 1, 3, 13, 23, 79, 117, 367, 267, 143, 1537, 3159, 2303, 9653, 12029, 2841, 226971, 0 };
            const std::uint32_t dim16396JoeKuoD6Init[]   =   { 1, 1, 1, 13, 19, 57, 103, 159, 315, 895, 1879, 2153, 1901, 7635, 14145, 56495, 6203, 151203, 0 };
            const std::uint32_t dim16397JoeKuoD6Init[]   =   { 1, 3, 3, 11, 31, 11, 75, 5, 419, 963, 1809, 3751, 7291, 12697, 2841, 17965, 91707, 80361, 0 };
            const std::uint32_t dim16398JoeKuoD6Init[]   =   { 1, 1, 7, 7, 5, 23, 29, 199, 413, 501, 19, 697, 6523, 3997, 4945, 59817, 127613, 220399, 0 };
            const std::uint32_t dim16399JoeKuoD6Init[]   =   { 1, 1, 7, 5, 1, 17, 51, 9, 183, 689, 325, 2391, 2095, 1907, 10325, 51045, 20097, 33719, 0 };
            const std::uint32_t dim16400JoeKuoD6Init[]   =   { 1, 3, 5, 11, 3, 33, 45, 221, 325, 7, 253, 1323, 4959, 14067, 10035, 39463, 123171, 194581, 0 };
            const std::uint32_t dim16401JoeKuoD6Init[]   =   { 1, 1, 3, 3, 15, 45, 25, 57, 357, 907, 1249, 3279, 2631, 9209, 7857, 58233, 29049, 173859, 0 };
            const std::uint32_t dim16402JoeKuoD6Init[]   =   { 1, 3, 3, 9, 29, 39, 105, 55, 295, 583, 825, 1777, 2403, 9489, 9079, 24855, 18155, 252733, 0 };
            const std::uint32_t dim16403JoeKuoD6Init[]   =   { 1, 1, 5, 15, 5, 63, 77, 215, 287, 743, 1937, 2103, 2673, 15487, 27855, 46683, 120215, 89721, 0 };
            const std::uint32_t dim16404JoeKuoD6Init[]   =   { 1, 3, 3, 5, 27, 1, 45, 19, 309, 679, 1405, 415, 6107, 13567, 5803, 61941, 130285, 51847, 0 };
            const std::uint32_t dim16405JoeKuoD6Init[]   =   { 1, 3, 1, 15, 23, 49, 47, 113, 401, 825, 1299, 2711, 6509, 12225, 16147, 20615, 121305, 121937, 0 };
            const std::uint32_t dim16406JoeKuoD6Init[]   =   { 1, 3, 5, 5, 31, 41, 31, 57, 385, 919, 593, 1371, 6773, 12099, 23767, 17663, 128321, 188921, 0 };
            const std::uint32_t dim16407JoeKuoD6Init[]   =   { 1, 1, 3, 15, 5, 41, 17, 7, 479, 143, 549, 1827, 8107, 14775, 28817, 12297, 119893, 191297, 0 };
            const std::uint32_t dim16408JoeKuoD6Init[]   =   { 1, 3, 7, 5, 29, 61, 27, 123, 269, 223, 121, 1745, 3513, 1989, 9759, 8129, 78933, 40085, 0 };
            const std::uint32_t dim16409JoeKuoD6Init[]   =   { 1, 1, 5, 13, 23, 49, 125, 225, 479, 123, 41, 2359, 4443, 4729, 31717, 3139, 3869, 118803, 0 };
            const std::uint32_t dim16410JoeKuoD6Init[]   =   { 1, 3, 3, 3, 15, 7, 7, 87, 415, 95, 1799, 2009, 4711, 15635, 21997, 47201, 16815, 99815, 0 };
            const std::uint32_t dim16411JoeKuoD6Init[]   =   { 1, 3, 3, 1, 31, 57, 73, 31, 423, 363, 1469, 2411, 6449, 15275, 14189, 51079, 130201, 130181, 0 };
            const std::uint32_t dim16412JoeKuoD6Init[]   =   { 1, 1, 5, 3, 3, 31, 107, 11, 355, 647, 1463, 3019, 3263, 13727, 10461, 26577, 4439, 132737, 0 };
            const std::uint32_t dim16413JoeKuoD6Init[]   =   { 1, 1, 1, 7, 13, 55, 31, 227, 71, 563, 1467, 3733, 725, 3443, 19279, 4111, 35749, 62275, 0 };
            const std::uint32_t dim16414JoeKuoD6Init[]   =   { 1, 3, 3, 15, 9, 17, 61, 95, 43, 583, 1381, 1285, 2655, 9213, 27551, 16237, 29569, 216879, 0 };
            const std::uint32_t dim16415JoeKuoD6Init[]   =   { 1, 1, 1, 3, 29, 3, 87, 193, 53, 599, 1581, 907, 4381, 8697, 27299, 40259, 122653, 43559, 0 };
            const std::uint32_t dim16416JoeKuoD6Init[]   =   { 1, 3, 5, 3, 15, 49, 21, 27, 35, 353, 1281, 3253, 7339, 9333, 25253, 35035, 30379, 87387, 0 };
            const std::uint32_t dim16417JoeKuoD6Init[]   =   { 1, 1, 1, 15, 7, 27, 69, 41, 45, 729, 1005, 3495, 1445, 7421, 27443, 29609, 70105, 93883, 0 };
            const std::uint32_t dim16418JoeKuoD6Init[]   =   { 1, 1, 7, 7, 1, 41, 15, 149, 107, 121, 639, 3703, 3397, 1727, 14165, 2845, 78531, 175767, 0 };
            const std::uint32_t dim16419JoeKuoD6Init[]   =   { 1, 3, 7, 15, 27, 17, 121, 175, 399, 551, 1889, 2283, 4343, 3633, 653, 3267, 101901, 162157, 0 };
            const std::uint32_t dim16420JoeKuoD6Init[]   =   { 1, 3, 3, 15, 23, 41, 97, 251, 435, 955, 69, 509, 8001, 11783, 7397, 7587, 127089, 15391, 0 };
            const std::uint32_t dim16421JoeKuoD6Init[]   =   { 1, 3, 5, 5, 25, 25, 63, 25, 203, 655, 2039, 2545, 5405, 1377, 30543, 65531, 122825, 6853, 0 };
            const std::uint32_t dim16422JoeKuoD6Init[]   =   { 1, 1, 7, 9, 9, 43, 73, 195, 465, 497, 1085, 3821, 7115, 7513, 21913, 32499, 96467, 181905, 0 };
            const std::uint32_t dim16423JoeKuoD6Init[]   =   { 1, 1, 3, 7, 29, 29, 63, 131, 409, 423, 687, 2549, 7367, 6867, 2685, 29137, 61845, 194409, 0 };
            const std::uint32_t dim16424JoeKuoD6Init[]   =   { 1, 3, 7, 7, 3, 23, 47, 31, 121, 629, 1771, 2387, 861, 2269, 29565, 19599, 18051, 121531, 0 };
            const std::uint32_t dim16425JoeKuoD6Init[]   =   { 1, 1, 1, 3, 21, 13, 109, 105, 163, 433, 521, 3467, 6225, 3705, 30605, 3265, 119313, 2535, 0 };
            const std::uint32_t dim16426JoeKuoD6Init[]   =   { 1, 3, 5, 3, 25, 25, 89, 177, 415, 67, 361, 3317, 6411, 4857, 23249, 41959, 59931, 35797, 0 };
            const std::uint32_t dim16427JoeKuoD6Init[]   =   { 1, 3, 7, 15, 5, 37, 37, 65, 71, 13, 1621, 2217, 3723, 2113, 23755, 46521, 48091, 44307, 0 };
            const std::uint32_t dim16428JoeKuoD6Init[]   =   { 1, 1, 5, 13, 5, 5, 63, 75, 61, 443, 1663, 3239, 7717, 2623, 5723, 42673, 8519, 58773, 0 };
            const std::uint32_t dim16429JoeKuoD6Init[]   =   { 1, 1, 3, 1, 29, 13, 35, 61, 391, 517, 1007, 17, 2519, 7121, 20095, 33449, 21397, 103787, 0 };
            const std::uint32_t dim16430JoeKuoD6Init[]   =   { 1, 1, 5, 1, 9, 45, 49, 151, 39, 347, 1821, 2687, 1551, 12117, 29429, 40963, 77795, 20941, 0 };
            const std::uint32_t dim16431JoeKuoD6Init[]   =   { 1, 1, 5, 3, 13, 49, 107, 105, 201, 601, 1335, 2389, 6837, 11123, 22985, 62705, 59057, 128333, 0 };
            const std::uint32_t dim16432JoeKuoD6Init[]   =   { 1, 3, 3, 13, 5, 3, 21, 103, 481, 621, 2037, 2963, 425, 4685, 27475, 24363, 116419, 171743, 0 };
            const std::uint32_t dim16433JoeKuoD6Init[]   =   { 1, 3, 3, 5, 27, 27, 5, 91, 245, 421, 795, 1869, 6455, 4463, 23467, 24039, 69681, 262127, 0 };
            const std::uint32_t dim16434JoeKuoD6Init[]   =   { 1, 3, 1, 11, 11, 5, 31, 253, 469, 593, 877, 2041, 4615, 1541, 11823, 58525, 128689, 95985, 0 };
            const std::uint32_t dim16435JoeKuoD6Init[]   =   { 1, 3, 5, 13, 31, 35, 115, 73, 97, 213, 1499, 1371, 4239, 7897, 3987, 4833, 115043, 222743, 0 };
            const std::uint32_t dim16436JoeKuoD6Init[]   =   { 1, 3, 3, 5, 31, 15, 17, 233, 137, 521, 1721, 1913, 1881, 13457, 10733, 61527, 19825, 192601, 0 };
            const std::uint32_t dim16437JoeKuoD6Init[]   =   { 1, 3, 1, 3, 11, 21, 81, 77, 377, 915, 321, 3925, 867, 5491, 4707, 37307, 52141, 29155, 0 };
            const std::uint32_t dim16438JoeKuoD6Init[]   =   { 1, 1, 5, 1, 13, 51, 97, 161, 295, 159, 1717, 3817, 4687, 1907, 2655, 60577, 73867, 161851, 0 };
            const std::uint32_t dim16439JoeKuoD6Init[]   =   { 1, 1, 3, 13, 21, 31, 33, 145, 375, 377, 1429, 1981, 4851, 9047, 2685, 49037, 67399, 124243, 0 };
            const std::uint32_t dim16440JoeKuoD6Init[]   =   { 1, 1, 7, 13, 1, 55, 65, 147, 471, 277, 1585, 3949, 1885, 1635, 15687, 46367, 120931, 192097, 0 };
            const std::uint32_t dim16441JoeKuoD6Init[]   =   { 1, 1, 7, 9, 13, 27, 33, 41, 377, 863, 1297, 181, 2685, 11285, 3961, 63201, 59757, 70231, 0 };
            const std::uint32_t dim16442JoeKuoD6Init[]   =   { 1, 1, 3, 15, 29, 3, 79, 25, 147, 683, 1563, 805, 5891, 3355, 20113, 48261, 38195, 14589, 0 };
            const std::uint32_t dim16443JoeKuoD6Init[]   =   { 1, 1, 7, 11, 9, 15, 21, 33, 47, 923, 1291, 4001, 203, 305, 21575, 41915, 74769, 114921, 0 };
            const std::uint32_t dim16444JoeKuoD6Init[]   =   { 1, 3, 7, 11, 15, 1, 75, 173, 473, 493, 291, 811, 931, 10731, 9855, 57891, 81575, 250565, 0 };
            const std::uint32_t dim16445JoeKuoD6Init[]   =   { 1, 3, 3, 3, 31, 31, 71, 141, 389, 661, 71, 3245, 6827, 9219, 26607, 50511, 94783, 130785, 0 };
            const std::uint32_t dim16446JoeKuoD6Init[]   =   { 1, 1, 7, 3, 9, 15, 67, 141, 293, 779, 3, 3311, 7063, 13709, 29715, 55227, 11043, 150343, 0 };
            const std::uint32_t dim16447JoeKuoD6Init[]   =   { 1, 3, 3, 3, 21, 9, 45, 111, 207, 715, 345, 1345, 3079, 3851, 23709, 33919, 108213, 25353, 0 };
            const std::uint32_t dim16448JoeKuoD6Init[]   =   { 1, 3, 5, 13, 7, 3, 35, 95, 397, 397, 1159, 2759, 5233, 16237, 12469, 29543, 39133, 64429, 0 };
            const std::uint32_t dim16449JoeKuoD6Init[]   =   { 1, 1, 5, 13, 19, 35, 9, 7, 153, 843, 2025, 1379, 3361, 15889, 7411, 26399, 106295, 19851, 0 };
            const std::uint32_t dim16450JoeKuoD6Init[]   =   { 1, 3, 1, 1, 21, 15, 71, 143, 279, 431, 487, 967, 4445, 11969, 16671, 48891, 59605, 230607, 0 };
            const std::uint32_t dim16451JoeKuoD6Init[]   =   { 1, 3, 5, 1, 25, 63, 23, 143, 221, 805, 377, 1441, 1971, 1985, 10055, 35991, 115873, 223455, 0 };
            const std::uint32_t dim16452JoeKuoD6Init[]   =   { 1, 3, 1, 7, 21, 57, 1, 185, 117, 75, 1623, 3805, 2385, 10245, 29009, 59149, 130219, 114763, 0 };
            const std::uint32_t dim16453JoeKuoD6Init[]   =   { 1, 3, 1, 13, 19, 13, 105, 241, 47, 597, 1725, 2579, 3785, 1667, 12427, 62623, 60883, 189977, 0 };
            const std::uint32_t dim16454JoeKuoD6Init[]   =   { 1, 3, 5, 13, 1, 55, 59, 133, 263, 415, 1013, 139, 3037, 13661, 15303, 27279, 84095, 184807, 0 };
            const std::uint32_t dim16455JoeKuoD6Init[]   =   { 1, 3, 1, 11, 7, 45, 3, 179, 315, 639, 875, 3299, 5221, 8463, 17507, 59673, 73865, 98867, 0 };
            const std::uint32_t dim16456JoeKuoD6Init[]   =   { 1, 3, 7, 7, 3, 3, 53, 233, 219, 519, 585, 3029, 3623, 9559, 2251, 43735, 121513, 208007, 0 };
            const std::uint32_t dim16457JoeKuoD6Init[]   =   { 1, 3, 1, 3, 17, 47, 47, 145, 445, 541, 163, 2653, 165, 7213, 3311, 57335, 43967, 191841, 0 };
            const std::uint32_t dim16458JoeKuoD6Init[]   =   { 1, 3, 5, 5, 7, 47, 39, 119, 13, 727, 887, 3743, 3807, 15267, 3977, 52833, 14851, 61851, 0 };
            const std::uint32_t dim16459JoeKuoD6Init[]   =   { 1, 1, 3, 5, 9, 9, 107, 119, 501, 723, 1965, 3093, 6947, 1783, 11287, 24243, 14005, 106677, 0 };
            const std::uint32_t dim16460JoeKuoD6Init[]   =   { 1, 3, 3, 11, 11, 29, 85, 243, 359, 195, 221, 1767, 6969, 15275, 20853, 26921, 40903, 29849, 0 };
            const std::uint32_t dim16461JoeKuoD6Init[]   =   { 1, 3, 1, 5, 31, 3, 11, 247, 371, 339, 1263, 119, 791, 7425, 18879, 11333, 34359, 178929, 0 };
            const std::uint32_t dim16462JoeKuoD6Init[]   =   { 1, 1, 3, 7, 23, 15, 121, 203, 441, 499, 779, 1971, 339, 8737, 6859, 32417, 97073, 256143, 0 };
            const std::uint32_t dim16463JoeKuoD6Init[]   =   { 1, 1, 5, 11, 3, 23, 25, 51, 407, 677, 97, 281, 427, 3671, 7939, 54485, 3967, 210199, 0 };
            const std::uint32_t dim16464JoeKuoD6Init[]   =   { 1, 1, 5, 9, 5, 45, 23, 171, 255, 967, 313, 3881, 6039, 10545, 3591, 51985, 37145, 99291, 0 };
            const std::uint32_t dim16465JoeKuoD6Init[]   =   { 1, 1, 5, 7, 3, 13, 55, 147, 83, 369, 1707, 1919, 491, 11507, 29559, 29169, 65897, 80587, 0 };
            const std::uint32_t dim16466JoeKuoD6Init[]   =   { 1, 1, 3, 13, 31, 41, 41, 237, 245, 109, 969, 1797, 8169, 6351, 3657, 9655, 109201, 245117, 0 };
            const std::uint32_t dim16467JoeKuoD6Init[]   =   { 1, 3, 7, 5, 17, 23, 17, 219, 473, 1, 865, 1949, 7589, 10107, 3035, 19903, 79579, 138695, 0 };
            const std::uint32_t dim16468JoeKuoD6Init[]   =   { 1, 3, 1, 15, 13, 57, 109, 117, 277, 773, 31, 3807, 7615, 2453, 22655, 51513, 108367, 248473, 0 };
            const std::uint32_t dim16469JoeKuoD6Init[]   =   { 1, 1, 7, 11, 17, 59, 27, 167, 63, 931, 13, 3721, 1789, 7621, 31093, 27541, 37283, 35193, 0 };
            const std::uint32_t dim16470JoeKuoD6Init[]   =   { 1, 3, 3, 11, 13, 9, 7, 85, 45, 151, 1865, 4049, 4433, 9517, 231, 30733, 93701, 126585, 0 };
            const std::uint32_t dim16471JoeKuoD6Init[]   =   { 1, 3, 1, 13, 21, 33, 19, 87, 77, 425, 351, 1163, 7453, 12567, 24615, 35563, 127643, 28625, 0 };
            const std::uint32_t dim16472JoeKuoD6Init[]   =   { 1, 1, 3, 11, 7, 35, 27, 47, 465, 595, 985, 573, 2541, 7841, 14749, 43761, 26699, 135895, 0 };
            const std::uint32_t dim16473JoeKuoD6Init[]   =   { 1, 1, 1, 7, 25, 51, 93, 237, 355, 575, 1, 443, 5697, 1997, 28801, 11621, 62531, 88449, 0 };
            const std::uint32_t dim16474JoeKuoD6Init[]   =   { 1, 1, 1, 9, 23, 35, 23, 91, 161, 601, 1401, 2187, 6283, 10711, 21277, 47771, 12589, 176625, 0 };
            const std::uint32_t dim16475JoeKuoD6Init[]   =   { 1, 3, 3, 5, 13, 23, 33, 65, 213, 835, 539, 2487, 273, 6113, 18327, 52493, 17571, 160909, 0 };
            const std::uint32_t dim16476JoeKuoD6Init[]   =   { 1, 3, 1, 5, 25, 9, 117, 201, 457, 331, 1455, 439, 4891, 5515, 21701, 9343, 29085, 120299, 0 };
            const std::uint32_t dim16477JoeKuoD6Init[]   =   { 1, 1, 1, 5, 29, 7, 43, 125, 155, 43, 1949, 2901, 7293, 13683, 18289, 16873, 27899, 168631, 0 };
            const std::uint32_t dim16478JoeKuoD6Init[]   =   { 1, 1, 7, 3, 29, 33, 53, 137, 301, 27, 1101, 837, 5843, 13167, 6073, 49083, 120031, 45065, 0 };
            const std::uint32_t dim16479JoeKuoD6Init[]   =   { 1, 3, 5, 1, 31, 47, 127, 185, 279, 603, 1699, 1693, 3263, 9055, 3525, 46065, 79305, 19949, 0 };
            const std::uint32_t dim16480JoeKuoD6Init[]   =   { 1, 3, 7, 9, 17, 47, 25, 191, 369, 877, 1477, 3041, 5123, 1393, 5061, 1755, 61051, 55299, 0 };
            const std::uint32_t dim16481JoeKuoD6Init[]   =   { 1, 1, 5, 13, 13, 7, 89, 141, 251, 321, 1515, 2677, 5103, 12901, 29875, 165, 15073, 47795, 0 };
            const std::uint32_t dim16482JoeKuoD6Init[]   =   { 1, 3, 1, 7, 1, 37, 55, 173, 191, 981, 685, 4003, 6319, 3037, 30637, 11955, 81015, 89239, 0 };
            const std::uint32_t dim16483JoeKuoD6Init[]   =   { 1, 3, 5, 5, 1, 5, 55, 251, 229, 153, 425, 2793, 6779, 15797, 10087, 7573, 121789, 115479, 0 };
            const std::uint32_t dim16484JoeKuoD6Init[]   =   { 1, 3, 7, 13, 23, 39, 23, 21, 55, 543, 1539, 3055, 7825, 2865, 8967, 56719, 117219, 142137, 0 };
            const std::uint32_t dim16485JoeKuoD6Init[]   =   { 1, 1, 5, 13, 1, 29, 81, 11, 509, 61, 1681, 1911, 829, 10583, 7105, 42047, 128579, 48891, 0 };
            const std::uint32_t dim16486JoeKuoD6Init[]   =   { 1, 1, 3, 13, 7, 27, 81, 89, 129, 239, 309, 1353, 5265, 12255, 29391, 1659, 114857, 43551, 0 };
            const std::uint32_t dim16487JoeKuoD6Init[]   =   { 1, 1, 7, 13, 23, 15, 9, 93, 35, 839, 549, 1793, 4693, 13295, 10603, 18179, 33141, 239555, 0 };
            const std::uint32_t dim16488JoeKuoD6Init[]   =   { 1, 3, 1, 7, 17, 5, 11, 193, 143, 579, 1199, 1239, 4503, 15855, 23345, 34789, 59427, 235319, 0 };
            const std::uint32_t dim16489JoeKuoD6Init[]   =   { 1, 3, 5, 3, 25, 63, 11, 203, 415, 135, 261, 1843, 3409, 4605, 15213, 28537, 75787, 100007, 0 };
            const std::uint32_t dim16490JoeKuoD6Init[]   =   { 1, 1, 1, 5, 3, 37, 29, 157, 213, 235, 959, 1087, 2843, 10265, 28233, 14281, 25867, 204031, 0 };
            const std::uint32_t dim16491JoeKuoD6Init[]   =   { 1, 3, 3, 7, 19, 49, 55, 111, 253, 823, 533, 941, 2509, 5595, 9267, 28457, 84301, 165385, 0 };
            const std::uint32_t dim16492JoeKuoD6Init[]   =   { 1, 3, 5, 9, 5, 59, 13, 85, 339, 889, 597, 3517, 7001, 5525, 25451, 13855, 19033, 182677, 0 };
            const std::uint32_t dim16493JoeKuoD6Init[]   =   { 1, 3, 1, 15, 23, 29, 31, 105, 353, 825, 1977, 2013, 131, 1969, 427, 16465, 90817, 257931, 0 };
            const std::uint32_t dim16494JoeKuoD6Init[]   =   { 1, 3, 1, 3, 29, 9, 109, 243, 321, 15, 1479, 787, 4667, 13925, 7347, 7977, 105585, 143959, 0 };
            const std::uint32_t dim16495JoeKuoD6Init[]   =   { 1, 1, 7, 15, 5, 45, 11, 95, 215, 719, 827, 77, 7263, 5705, 26971, 26845, 82127, 2849, 0 };
            const std::uint32_t dim16496JoeKuoD6Init[]   =   { 1, 1, 7, 9, 5, 43, 103, 133, 203, 127, 2021, 3609, 6971, 13447, 27089, 62287, 104391, 147901, 0 };
            const std::uint32_t dim16497JoeKuoD6Init[]   =   { 1, 3, 1, 3, 3, 41, 61, 101, 381, 985, 1795, 2465, 2899, 13517, 23953, 38831, 43569, 128643, 0 };
            const std::uint32_t dim16498JoeKuoD6Init[]   =   { 1, 3, 5, 5, 9, 49, 13, 7, 215, 85, 1203, 647, 6627, 1861, 17901, 40203, 13007, 84975, 0 };
            const std::uint32_t dim16499JoeKuoD6Init[]   =   { 1, 3, 5, 15, 31, 13, 55, 89, 397, 641, 1599, 3379, 3401, 4173, 5757, 42945, 59269, 106891, 0 };
            const std::uint32_t dim16500JoeKuoD6Init[]   =   { 1, 1, 5, 13, 25, 17, 45, 27, 151, 725, 819, 581, 3675, 3983, 9499, 47511, 128039, 56825, 0 };
            const std::uint32_t dim16501JoeKuoD6Init[]   =   { 1, 1, 5, 1, 7, 11, 65, 63, 301, 927, 409, 3729, 7227, 12849, 17855, 36527, 2907, 66819, 0 };
            const std::uint32_t dim16502JoeKuoD6Init[]   =   { 1, 3, 3, 3, 29, 35, 39, 1, 349, 429, 805, 3639, 3909, 4211, 10393, 36223, 72543, 136375, 0 };
            const std::uint32_t dim16503JoeKuoD6Init[]   =   { 1, 1, 1, 9, 23, 27, 25, 213, 195, 455, 883, 3357, 7277, 9061, 14103, 6005, 35031, 72703, 0 };
            const std::uint32_t dim16504JoeKuoD6Init[]   =   { 1, 1, 3, 3, 11, 17, 19, 181, 25, 775, 897, 3809, 2031, 13017, 7505, 37469, 107335, 174309, 0 };
            const std::uint32_t dim16505JoeKuoD6Init[]   =   { 1, 1, 7, 13, 7, 1, 57, 27, 159, 465, 533, 3409, 3863, 14001, 8011, 25873, 14971, 67243, 0 };
            const std::uint32_t dim16506JoeKuoD6Init[]   =   { 1, 1, 3, 11, 19, 5, 11, 19, 75, 489, 1879, 1539, 6563, 4729, 15605, 35203, 47993, 110139, 0 };
            const std::uint32_t dim16507JoeKuoD6Init[]   =   { 1, 3, 5, 9, 23, 17, 67, 89, 379, 849, 1667, 955, 1537, 11781, 9791, 46959, 79481, 237335, 0 };
            const std::uint32_t dim16508JoeKuoD6Init[]   =   { 1, 1, 7, 9, 3, 31, 127, 145, 29, 35, 463, 4009, 4427, 16215, 12093, 50085, 51259, 45091, 0 };
            const std::uint32_t dim16509JoeKuoD6Init[]   =   { 1, 1, 5, 9, 25, 3, 1, 131, 221, 951, 117, 3227, 797, 7617, 13243, 50139, 26737, 105875, 0 };
            const std::uint32_t dim16510JoeKuoD6Init[]   =   { 1, 1, 5, 3, 11, 5, 7, 155, 211, 865, 27, 3943, 7923, 9973, 23233, 37399, 89951, 106555, 0 };
            const std::uint32_t dim16511JoeKuoD6Init[]   =   { 1, 1, 3, 13, 21, 61, 77, 121, 227, 527, 1641, 3535, 3801, 7221, 6423, 9179, 114935, 33373, 0 };
            const std::uint32_t dim16512JoeKuoD6Init[]   =   { 1, 3, 7, 5, 31, 7, 123, 159, 367, 369, 1905, 1689, 6773, 675, 30289, 54149, 71469, 232835, 0 };
            const std::uint32_t dim16513JoeKuoD6Init[]   =   { 1, 1, 1, 13, 9, 23, 83, 237, 251, 941, 781, 1489, 6037, 6001, 15909, 50527, 60143, 238499, 0 };
            const std::uint32_t dim16514JoeKuoD6Init[]   =   { 1, 3, 1, 11, 5, 7, 103, 43, 413, 247, 535, 2107, 1801, 16381, 32529, 2355, 39143, 71281, 0 };
            const std::uint32_t dim16515JoeKuoD6Init[]   =   { 1, 1, 7, 5, 5, 31, 19, 11, 191, 643, 923, 1661, 2215, 11817, 23937, 62907, 128301, 21459, 0 };
            const std::uint32_t dim16516JoeKuoD6Init[]   =   { 1, 3, 7, 15, 1, 51, 123, 61, 99, 751, 1819, 1191, 3865, 8765, 7131, 33965, 55697, 87059, 0 };
            const std::uint32_t dim16517JoeKuoD6Init[]   =   { 1, 1, 5, 13, 5, 57, 41, 103, 135, 207, 517, 3995, 2537, 15705, 9123, 26193, 30653, 190549, 0 };
            const std::uint32_t dim16518JoeKuoD6Init[]   =   { 1, 1, 3, 1, 23, 5, 109, 209, 407, 143, 943, 2325, 8087, 559, 23675, 31815, 43805, 67497, 0 };
            const std::uint32_t dim16519JoeKuoD6Init[]   =   { 1, 1, 5, 9, 25, 33, 13, 21, 93, 357, 1551, 739, 5595, 16285, 30761, 54075, 75505, 177333, 0 };
            const std::uint32_t dim16520JoeKuoD6Init[]   =   { 1, 3, 5, 11, 17, 59, 31, 249, 95, 561, 1849, 4061, 5577, 2607, 30083, 59033, 56697, 89761, 0 };
            const std::uint32_t dim16521JoeKuoD6Init[]   =   { 1, 1, 3, 13, 27, 57, 9, 17, 323, 813, 1197, 2775, 3443, 9523, 24509, 12129, 89697, 169043, 0 };
            const std::uint32_t dim16522JoeKuoD6Init[]   =   { 1, 3, 5, 13, 17, 51, 91, 1, 105, 345, 829, 1365, 2755, 7197, 26655, 1303, 52223, 133893, 0 };
            const std::uint32_t dim16523JoeKuoD6Init[]   =   { 1, 1, 7, 1, 31, 3, 51, 21, 327, 851, 153, 3329, 3393, 8489, 5879, 25035, 124403, 172657, 0 };
            const std::uint32_t dim16524JoeKuoD6Init[]   =   { 1, 1, 1, 5, 3, 21, 61, 29, 99, 343, 621, 3163, 3763, 9347, 7691, 34667, 24555, 125819, 0 };
            const std::uint32_t dim16525JoeKuoD6Init[]   =   { 1, 1, 1, 1, 3, 17, 83, 191, 83, 315, 1091, 589, 5081, 4611, 15521, 25791, 9103, 13741, 0 };
            const std::uint32_t dim16526JoeKuoD6Init[]   =   { 1, 3, 5, 3, 7, 53, 9, 227, 399, 857, 673, 3027, 5045, 5573, 7467, 4813, 99659, 142845, 0 };
            const std::uint32_t dim16527JoeKuoD6Init[]   =   { 1, 1, 5, 11, 23, 37, 71, 151, 279, 879, 601, 2391, 7091, 12669, 10203, 11747, 9613, 248261, 0 };
            const std::uint32_t dim16528JoeKuoD6Init[]   =   { 1, 1, 3, 3, 29, 25, 33, 25, 1, 683, 1475, 457, 3641, 14219, 20105, 21449, 6903, 43819, 0 };
            const std::uint32_t dim16529JoeKuoD6Init[]   =   { 1, 1, 7, 7, 5, 1, 73, 79, 357, 971, 699, 1105, 1683, 1687, 32677, 62467, 47671, 88149, 0 };
            const std::uint32_t dim16530JoeKuoD6Init[]   =   { 1, 3, 1, 15, 23, 13, 93, 75, 307, 81, 1607, 1333, 6969, 7747, 27135, 58941, 26355, 5565, 0 };
            const std::uint32_t dim16531JoeKuoD6Init[]   =   { 1, 1, 7, 3, 27, 35, 85, 195, 421, 999, 1721, 2029, 283, 13995, 21649, 7519, 73357, 193171, 0 };
            const std::uint32_t dim16532JoeKuoD6Init[]   =   { 1, 3, 7, 15, 17, 63, 21, 187, 475, 671, 1681, 2731, 8169, 3327, 19789, 53295, 43219, 6949, 0 };
            const std::uint32_t dim16533JoeKuoD6Init[]   =   { 1, 1, 7, 13, 9, 33, 47, 115, 295, 123, 1293, 1627, 4261, 4503, 15925, 16521, 81759, 247089, 0 };
            const std::uint32_t dim16534JoeKuoD6Init[]   =   { 1, 3, 1, 13, 11, 15, 83, 129, 409, 465, 873, 1333, 7939, 973, 2753, 33727, 128975, 43333, 0 };
            const std::uint32_t dim16535JoeKuoD6Init[]   =   { 1, 3, 3, 3, 27, 59, 1, 137, 145, 29, 1189, 2615, 3249, 11197, 17165, 32313, 14065, 44199, 0 };
            const std::uint32_t dim16536JoeKuoD6Init[]   =   { 1, 3, 3, 11, 17, 49, 107, 111, 45, 963, 1129, 1775, 7671, 1495, 14531, 49743, 63321, 159841, 0 };
            const std::uint32_t dim16537JoeKuoD6Init[]   =   { 1, 1, 5, 9, 5, 11, 79, 99, 155, 347, 1777, 3793, 1765, 2319, 3135, 30237, 100845, 52689, 0 };
            const std::uint32_t dim16538JoeKuoD6Init[]   =   { 1, 3, 7, 13, 21, 57, 71, 207, 149, 161, 265, 991, 6967, 8905, 21581, 13921, 79201, 95667, 0 };
            const std::uint32_t dim16539JoeKuoD6Init[]   =   { 1, 3, 5, 15, 13, 53, 95, 81, 443, 161, 1071, 2749, 6637, 837, 15015, 62397, 33295, 112005, 0 };
            const std::uint32_t dim16540JoeKuoD6Init[]   =   { 1, 3, 1, 1, 31, 25, 37, 111, 79, 293, 249, 1523, 1509, 1993, 17167, 62939, 118281, 62699, 0 };
            const std::uint32_t dim16541JoeKuoD6Init[]   =   { 1, 3, 7, 7, 5, 33, 61, 179, 265, 405, 287, 1899, 437, 1609, 19617, 41093, 36341, 176593, 0 };
            const std::uint32_t dim16542JoeKuoD6Init[]   =   { 1, 1, 5, 3, 9, 33, 97, 45, 23, 807, 1575, 627, 7465, 4805, 11191, 35439, 69433, 47275, 0 };
            const std::uint32_t dim16543JoeKuoD6Init[]   =   { 1, 1, 1, 5, 1, 51, 51, 247, 453, 449, 1487, 141, 2501, 8039, 14749, 63733, 91963, 232951, 0 };
            const std::uint32_t dim16544JoeKuoD6Init[]   =   { 1, 3, 3, 13, 15, 7, 81, 211, 445, 15, 899, 835, 5163, 3403, 7367, 29963, 80413, 87209, 0 };
            const std::uint32_t dim16545JoeKuoD6Init[]   =   { 1, 3, 1, 11, 25, 43, 113, 139, 381, 391, 485, 1503, 4195, 10109, 13771, 35865, 50909, 224887, 0 };
            const std::uint32_t dim16546JoeKuoD6Init[]   =   { 1, 1, 7, 9, 9, 51, 21, 85, 137, 765, 951, 2453, 227, 9177, 1457, 47937, 84203, 118987, 0 };
            const std::uint32_t dim16547JoeKuoD6Init[]   =   { 1, 3, 5, 9, 1, 1, 21, 41, 133, 317, 519, 2249, 3453, 2957, 2029, 54737, 42515, 176017, 0 };
            const std::uint32_t dim16548JoeKuoD6Init[]   =   { 1, 3, 1, 7, 9, 27, 79, 193, 209, 281, 267, 1267, 7013, 13667, 13331, 32863, 5289, 15077, 0 };
            const std::uint32_t dim16549JoeKuoD6Init[]   =   { 1, 1, 5, 11, 29, 3, 3, 177, 75, 485, 1735, 3955, 4349, 7893, 13075, 58735, 8629, 78143, 0 };
            const std::uint32_t dim16550JoeKuoD6Init[]   =   { 1, 1, 7, 13, 3, 15, 15, 77, 7, 843, 1561, 461, 6817, 4363, 7861, 45697, 115663, 93789, 0 };
            const std::uint32_t dim16551JoeKuoD6Init[]   =   { 1, 1, 1, 7, 5, 35, 83, 213, 229, 383, 747, 337, 2589, 683, 18575, 42415, 74889, 227331, 0 };
            const std::uint32_t dim16552JoeKuoD6Init[]   =   { 1, 3, 5, 3, 17, 35, 57, 213, 247, 273, 689, 1889, 5667, 357, 4267, 11611, 20621, 159039, 0 };
            const std::uint32_t dim16553JoeKuoD6Init[]   =   { 1, 3, 3, 15, 7, 55, 25, 83, 293, 939, 1169, 2507, 3939, 7537, 2959, 40231, 124511, 181091, 0 };
            const std::uint32_t dim16554JoeKuoD6Init[]   =   { 1, 1, 5, 9, 31, 51, 67, 149, 509, 695, 449, 2761, 6597, 4741, 4205, 49177, 45599, 167807, 0 };
            const std::uint32_t dim16555JoeKuoD6Init[]   =   { 1, 1, 7, 15, 3, 7, 113, 71, 279, 885, 251, 2831, 855, 6673, 6511, 63861, 41109, 177119, 0 };
            const std::uint32_t dim16556JoeKuoD6Init[]   =   { 1, 1, 5, 3, 7, 23, 125, 11, 217, 1023, 549, 529, 3891, 10595, 13751, 37729, 113469, 110549, 0 };
            const std::uint32_t dim16557JoeKuoD6Init[]   =   { 1, 1, 3, 15, 21, 9, 13, 63, 93, 635, 659, 2837, 6303, 10083, 10107, 27859, 33891, 181229, 0 };
            const std::uint32_t dim16558JoeKuoD6Init[]   =   { 1, 1, 7, 3, 3, 43, 5, 149, 353, 353, 565, 2441, 7113, 6493, 30355, 17887, 110787, 187199, 0 };
            const std::uint32_t dim16559JoeKuoD6Init[]   =   { 1, 1, 3, 7, 19, 43, 99, 63, 169, 743, 185, 3817, 6677, 5549, 1609, 24701, 98669, 233701, 0 };
            const std::uint32_t dim16560JoeKuoD6Init[]   =   { 1, 1, 1, 1, 21, 49, 73, 169, 223, 551, 553, 917, 4705, 14951, 14031, 19753, 96205, 131755, 0 };
            const std::uint32_t dim16561JoeKuoD6Init[]   =   { 1, 1, 3, 3, 17, 49, 51, 249, 293, 921, 435, 2915, 3125, 3487, 11417, 35043, 29543, 35933, 0 };
            const std::uint32_t dim16562JoeKuoD6Init[]   =   { 1, 1, 3, 9, 23, 43, 73, 151, 379, 911, 671, 151, 955, 11885, 28795, 23967, 117135, 137985, 0 };
            const std::uint32_t dim16563JoeKuoD6Init[]   =   { 1, 1, 3, 7, 29, 3, 51, 231, 59, 227, 443, 3533, 7785, 12535, 25725, 7451, 9391, 239281, 0 };
            const std::uint32_t dim16564JoeKuoD6Init[]   =   { 1, 3, 3, 9, 17, 37, 91, 195, 5, 843, 313, 1417, 1207, 3225, 15949, 34023, 1275, 221057, 0 };
            const std::uint32_t dim16565JoeKuoD6Init[]   =   { 1, 1, 3, 15, 3, 51, 111, 135, 63, 495, 1967, 2151, 197, 10913, 20705, 1021, 68431, 67119, 0 };
            const std::uint32_t dim16566JoeKuoD6Init[]   =   { 1, 1, 5, 3, 7, 29, 87, 219, 273, 267, 1317, 797, 6723, 947, 29867, 32571, 12337, 234715, 0 };
            const std::uint32_t dim16567JoeKuoD6Init[]   =   { 1, 3, 5, 15, 1, 9, 91, 63, 97, 107, 451, 4025, 233, 7803, 17031, 7669, 49417, 256611, 0 };
            const std::uint32_t dim16568JoeKuoD6Init[]   =   { 1, 1, 7, 3, 17, 17, 45, 197, 227, 133, 799, 411, 6739, 8037, 19553, 53009, 25201, 107625, 0 };
            const std::uint32_t dim16569JoeKuoD6Init[]   =   { 1, 3, 5, 7, 3, 39, 25, 95, 197, 127, 45, 173, 3305, 6575, 19633, 54919, 35373, 59509, 0 };
            const std::uint32_t dim16570JoeKuoD6Init[]   =   { 1, 3, 3, 3, 9, 1, 107, 211, 217, 715, 311, 3641, 8055, 1, 9017, 29329, 128467, 46911, 0 };
            const std::uint32_t dim16571JoeKuoD6Init[]   =   { 1, 1, 1, 7, 1, 13, 13, 79, 259, 533, 1761, 449, 3363, 3061, 26227, 50407, 122951, 261425, 0 };
            const std::uint32_t dim16572JoeKuoD6Init[]   =   { 1, 3, 5, 5, 29, 19, 41, 7, 25, 203, 587, 3321, 655, 15877, 10423, 41481, 70325, 165527, 0 };
            const std::uint32_t dim16573JoeKuoD6Init[]   =   { 1, 3, 5, 9, 11, 45, 91, 253, 7, 137, 795, 2379, 4527, 1677, 5081, 6523, 97245, 3691, 0 };
            const std::uint32_t dim16574JoeKuoD6Init[]   =   { 1, 3, 7, 9, 25, 43, 125, 243, 391, 785, 651, 3245, 7979, 14689, 15443, 40501, 5519, 96551, 0 };
            const std::uint32_t dim16575JoeKuoD6Init[]   =   { 1, 1, 1, 3, 25, 53, 45, 159, 47, 701, 1655, 2019, 2355, 11213, 12403, 42291, 44925, 72689, 0 };
            const std::uint32_t dim16576JoeKuoD6Init[]   =   { 1, 1, 1, 5, 21, 19, 77, 31, 3, 161, 149, 3759, 6331, 12311, 7021, 1117, 12459, 134821, 0 };
            const std::uint32_t dim16577JoeKuoD6Init[]   =   { 1, 1, 3, 9, 9, 59, 23, 255, 437, 625, 719, 3727, 7157, 1889, 31523, 59127, 114143, 174179, 0 };
            const std::uint32_t dim16578JoeKuoD6Init[]   =   { 1, 1, 1, 15, 23, 7, 47, 137, 77, 519, 1681, 1159, 6121, 14789, 21343, 43101, 44709, 179863, 0 };
            const std::uint32_t dim16579JoeKuoD6Init[]   =   { 1, 3, 1, 3, 17, 27, 103, 11, 327, 735, 1949, 3719, 811, 2267, 13187, 29747, 98433, 242021, 0 };
            const std::uint32_t dim16580JoeKuoD6Init[]   =   { 1, 1, 7, 15, 15, 63, 25, 203, 109, 585, 409, 4093, 6669, 2381, 30721, 58975, 17235, 257959, 0 };
            const std::uint32_t dim16581JoeKuoD6Init[]   =   { 1, 3, 3, 5, 5, 19, 27, 69, 69, 193, 693, 1169, 6321, 3425, 9285, 28019, 128343, 185165, 0 };
            const std::uint32_t dim16582JoeKuoD6Init[]   =   { 1, 1, 3, 9, 7, 51, 113, 93, 81, 385, 1811, 2601, 2065, 1029, 24515, 7199, 26425, 174283, 0 };
            const std::uint32_t dim16583JoeKuoD6Init[]   =   { 1, 1, 1, 5, 29, 55, 93, 219, 281, 887, 891, 2763, 6083, 9627, 18559, 21329, 73887, 83699, 0 };
            const std::uint32_t dim16584JoeKuoD6Init[]   =   { 1, 1, 1, 3, 21, 31, 49, 173, 15, 177, 1001, 3453, 5623, 14107, 8837, 10163, 26817, 41947, 0 };
            const std::uint32_t dim16585JoeKuoD6Init[]   =   { 1, 1, 3, 5, 27, 63, 117, 49, 405, 281, 981, 2363, 1525, 9685, 29089, 16739, 66509, 125823, 0 };
            const std::uint32_t dim16586JoeKuoD6Init[]   =   { 1, 3, 7, 13, 27, 29, 57, 189, 345, 135, 753, 463, 731, 4823, 14335, 33299, 105229, 54705, 0 };
            const std::uint32_t dim16587JoeKuoD6Init[]   =   { 1, 3, 1, 1, 9, 43, 51, 25, 371, 261, 1409, 3493, 2811, 12915, 16075, 62159, 125945, 108453, 0 };
            const std::uint32_t dim16588JoeKuoD6Init[]   =   { 1, 3, 7, 15, 13, 33, 47, 53, 263, 669, 1383, 3059, 4043, 4777, 14679, 2077, 11019, 5803, 0 };
            const std::uint32_t dim16589JoeKuoD6Init[]   =   { 1, 1, 3, 11, 21, 7, 39, 71, 215, 79, 1849, 1261, 45, 1273, 27591, 4653, 25119, 30445, 0 };
            const std::uint32_t dim16590JoeKuoD6Init[]   =   { 1, 3, 5, 9, 21, 3, 17, 207, 417, 777, 37, 3349, 2761, 4469, 3457, 15593, 87251, 38601, 0 };
            const std::uint32_t dim16591JoeKuoD6Init[]   =   { 1, 1, 7, 13, 29, 29, 101, 103, 487, 87, 1129, 2497, 5501, 4813, 8623, 25077, 50487, 94053, 0 };
            const std::uint32_t dim16592JoeKuoD6Init[]   =   { 1, 3, 3, 11, 7, 23, 95, 245, 127, 55, 431, 2707, 4955, 15871, 29589, 60023, 1921, 227623, 0 };
            const std::uint32_t dim16593JoeKuoD6Init[]   =   { 1, 1, 3, 11, 17, 61, 103, 59, 477, 99, 1203, 157, 203, 557, 22921, 47363, 12853, 144067, 0 };
            const std::uint32_t dim16594JoeKuoD6Init[]   =   { 1, 3, 1, 13, 15, 23, 51, 109, 499, 841, 1779, 2515, 2519, 4945, 20061, 12395, 9223, 157901, 0 };
            const std::uint32_t dim16595JoeKuoD6Init[]   =   { 1, 3, 7, 9, 9, 15, 57, 223, 223, 463, 427, 2145, 1219, 12639, 28361, 46019, 128101, 198479, 0 };
            const std::uint32_t dim16596JoeKuoD6Init[]   =   { 1, 3, 7, 7, 1, 1, 99, 101, 135, 169, 1885, 3979, 3051, 13649, 26607, 45067, 4503, 74087, 0 };
            const std::uint32_t dim16597JoeKuoD6Init[]   =   { 1, 3, 7, 5, 17, 63, 27, 45, 447, 759, 1099, 3407, 489, 2719, 31577, 10355, 126835, 203439, 0 };
            const std::uint32_t dim16598JoeKuoD6Init[]   =   { 1, 1, 5, 1, 21, 19, 1, 239, 433, 531, 1181, 2021, 423, 3235, 8457, 44459, 117401, 63545, 0 };
            const std::uint32_t dim16599JoeKuoD6Init[]   =   { 1, 3, 7, 13, 21, 39, 25, 65, 405, 785, 137, 2899, 3255, 11165, 7827, 46425, 89063, 102787, 0 };
            const std::uint32_t dim16600JoeKuoD6Init[]   =   { 1, 1, 1, 11, 25, 3, 39, 61, 395, 35, 2001, 3201, 2233, 9625, 26489, 54167, 88495, 127441, 0 };
            const std::uint32_t dim16601JoeKuoD6Init[]   =   { 1, 1, 7, 7, 3, 27, 11, 49, 117, 711, 1881, 1457, 6759, 10517, 12733, 47435, 103111, 237237, 0 };
            const std::uint32_t dim16602JoeKuoD6Init[]   =   { 1, 1, 5, 5, 1, 61, 121, 155, 223, 733, 1349, 2825, 2093, 4481, 21389, 40227, 20453, 116907, 0 };
            const std::uint32_t dim16603JoeKuoD6Init[]   =   { 1, 3, 7, 7, 5, 11, 85, 131, 345, 723, 853, 3679, 7859, 11923, 16619, 63169, 127261, 155665, 0 };
            const std::uint32_t dim16604JoeKuoD6Init[]   =   { 1, 1, 5, 1, 3, 51, 93, 225, 197, 893, 555, 2611, 6225, 7819, 31655, 12235, 24919, 31451, 0 };
            const std::uint32_t dim16605JoeKuoD6Init[]   =   { 1, 1, 3, 3, 11, 23, 95, 205, 85, 705, 545, 155, 5533, 14837, 8341, 42473, 96891, 70695, 0 };
            const std::uint32_t dim16606JoeKuoD6Init[]   =   { 1, 3, 3, 5, 17, 31, 99, 187, 219, 275, 685, 2933, 4535, 13495, 20351, 60667, 95211, 129233, 0 };
            const std::uint32_t dim16607JoeKuoD6Init[]   =   { 1, 1, 1, 11, 9, 11, 123, 231, 127, 199, 733, 2495, 2601, 10565, 3155, 45251, 128319, 187457, 0 };
            const std::uint32_t dim16608JoeKuoD6Init[]   =   { 1, 3, 1, 9, 3, 33, 41, 109, 279, 851, 1115, 3773, 2383, 1885, 6993, 59693, 69863, 88081, 0 };
            const std::uint32_t dim16609JoeKuoD6Init[]   =   { 1, 1, 7, 13, 3, 27, 27, 203, 337, 965, 959, 1125, 2897, 8653, 15827, 51187, 12121, 4665, 0 };
            const std::uint32_t dim16610JoeKuoD6Init[]   =   { 1, 3, 1, 9, 19, 7, 23, 113, 257, 671, 571, 1061, 4353, 217, 13603, 27961, 68431, 147187, 0 };
            const std::uint32_t dim16611JoeKuoD6Init[]   =   { 1, 3, 5, 9, 25, 61, 7, 139, 237, 859, 761, 2005, 5981, 153, 6553, 53005, 72653, 33571, 0 };
            const std::uint32_t dim16612JoeKuoD6Init[]   =   { 1, 3, 5, 5, 9, 35, 63, 149, 427, 65, 635, 1955, 1845, 13781, 9761, 36147, 91479, 141305, 0 };
            const std::uint32_t dim16613JoeKuoD6Init[]   =   { 1, 1, 3, 5, 13, 39, 53, 113, 481, 933, 239, 3713, 7453, 12363, 14763, 46955, 108545, 74349, 0 };
            const std::uint32_t dim16614JoeKuoD6Init[]   =   { 1, 3, 1, 7, 13, 41, 57, 225, 213, 617, 1947, 2855, 4885, 8553, 20259, 57125, 59369, 178553, 0 };
            const std::uint32_t dim16615JoeKuoD6Init[]   =   { 1, 3, 5, 15, 31, 31, 19, 87, 461, 403, 1193, 2123, 4991, 14551, 17153, 14171, 17157, 194879, 0 };
            const std::uint32_t dim16616JoeKuoD6Init[]   =   { 1, 1, 5, 11, 5, 27, 119, 65, 111, 455, 1949, 3441, 6951, 6819, 12839, 6913, 57695, 145925, 0 };
            const std::uint32_t dim16617JoeKuoD6Init[]   =   { 1, 1, 1, 15, 19, 41, 55, 45, 33, 559, 589, 3773, 745, 8515, 32389, 47797, 145, 105503, 0 };
            const std::uint32_t dim16618JoeKuoD6Init[]   =   { 1, 1, 3, 15, 13, 53, 35, 223, 247, 893, 149, 553, 829, 5129, 26417, 15769, 95411, 6595, 0 };
            const std::uint32_t dim16619JoeKuoD6Init[]   =   { 1, 1, 5, 3, 3, 59, 35, 187, 387, 3, 847, 3579, 7869, 481, 23955, 22191, 21041, 230449, 0 };
            const std::uint32_t dim16620JoeKuoD6Init[]   =   { 1, 1, 3, 15, 23, 11, 97, 199, 11, 647, 803, 2391, 5791, 2223, 22187, 49675, 87775, 196871, 0 };
            const std::uint32_t dim16621JoeKuoD6Init[]   =   { 1, 3, 7, 5, 25, 63, 107, 227, 133, 337, 1767, 2459, 2987, 10463, 25001, 17047, 79901, 222877, 0 };
            const std::uint32_t dim16622JoeKuoD6Init[]   =   { 1, 3, 1, 13, 25, 5, 47, 109, 473, 389, 1743, 3951, 4231, 827, 4189, 29903, 106909, 152835, 0 };
            const std::uint32_t dim16623JoeKuoD6Init[]   =   { 1, 1, 5, 3, 7, 61, 121, 189, 303, 21, 957, 545, 7893, 3217, 25847, 29371, 100569, 132393, 0 };
            const std::uint32_t dim16624JoeKuoD6Init[]   =   { 1, 1, 1, 15, 29, 17, 59, 37, 449, 149, 845, 555, 7603, 11911, 18477, 23279, 107167, 160339, 0 };
            const std::uint32_t dim16625JoeKuoD6Init[]   =   { 1, 1, 7, 5, 13, 27, 43, 167, 443, 445, 2011, 2179, 2785, 13663, 21957, 2455, 18217, 19303, 0 };
            const std::uint32_t dim16626JoeKuoD6Init[]   =   { 1, 1, 1, 5, 19, 45, 71, 39, 21, 791, 1467, 855, 3101, 8267, 15529, 919, 105313, 75627, 0 };
            const std::uint32_t dim16627JoeKuoD6Init[]   =   { 1, 3, 1, 11, 31, 25, 57, 177, 211, 327, 679, 771, 7725, 6123, 23931, 48223, 9063, 133319, 0 };
            const std::uint32_t dim16628JoeKuoD6Init[]   =   { 1, 3, 5, 3, 1, 11, 19, 153, 177, 563, 1919, 117, 5583, 1519, 16623, 10871, 15511, 66113, 0 };
            const std::uint32_t dim16629JoeKuoD6Init[]   =   { 1, 1, 7, 7, 9, 45, 63, 253, 415, 347, 81, 2991, 2691, 2383, 15573, 33783, 12445, 224107, 0 };
            const std::uint32_t dim16630JoeKuoD6Init[]   =   { 1, 3, 5, 5, 7, 17, 99, 231, 439, 1009, 623, 833, 685, 6419, 30313, 56197, 73239, 260007, 0 };
            const std::uint32_t dim16631JoeKuoD6Init[]   =   { 1, 1, 5, 5, 5, 51, 97, 239, 267, 629, 1211, 2175, 5681, 3107, 11381, 57047, 120175, 131285, 0 };
            const std::uint32_t dim16632JoeKuoD6Init[]   =   { 1, 1, 7, 7, 29, 11, 21, 49, 481, 279, 1795, 1295, 453, 15985, 19941, 51853, 15115, 107271, 0 };
            const std::uint32_t dim16633JoeKuoD6Init[]   =   { 1, 1, 5, 1, 23, 61, 33, 21, 409, 57, 903, 557, 1673, 2759, 23705, 4109, 58865, 233081, 0 };
            const std::uint32_t dim16634JoeKuoD6Init[]   =   { 1, 1, 1, 5, 11, 37, 79, 15, 213, 485, 1477, 3925, 3205, 9267, 22043, 54197, 57101, 66185, 0 };
            const std::uint32_t dim16635JoeKuoD6Init[]   =   { 1, 1, 7, 13, 31, 27, 95, 141, 131, 43, 2039, 2257, 17, 14427, 5699, 22263, 86851, 226283, 0 };
            const std::uint32_t dim16636JoeKuoD6Init[]   =   { 1, 3, 5, 5, 11, 5, 5, 217, 363, 163, 1241, 3683, 1409, 1731, 20973, 63849, 35041, 94859, 0 };
            const std::uint32_t dim16637JoeKuoD6Init[]   =   { 1, 1, 7, 1, 25, 61, 67, 239, 369, 319, 1157, 2435, 2147, 12057, 4451, 3005, 31787, 199653, 0 };
            const std::uint32_t dim16638JoeKuoD6Init[]   =   { 1, 3, 5, 1, 11, 57, 1, 163, 433, 11, 1299, 1711, 1601, 4677, 16481, 25175, 63893, 41853, 0 };
            const std::uint32_t dim16639JoeKuoD6Init[]   =   { 1, 1, 3, 1, 29, 49, 91, 15, 313, 533, 115, 4005, 3157, 10615, 27915, 52613, 64447, 93091, 0 };
            const std::uint32_t dim16640JoeKuoD6Init[]   =   { 1, 3, 7, 3, 7, 17, 103, 67, 237, 595, 1571, 3421, 3971, 11123, 145, 52087, 59273, 21417, 0 };
            const std::uint32_t dim16641JoeKuoD6Init[]   =   { 1, 3, 5, 11, 31, 37, 105, 205, 377, 243, 841, 3153, 6847, 14171, 19947, 61561, 35, 261753, 0 };
            const std::uint32_t dim16642JoeKuoD6Init[]   =   { 1, 3, 5, 9, 29, 21, 103, 219, 107, 427, 1841, 2015, 2919, 5721, 8631, 48841, 33281, 35835, 0 };
            const std::uint32_t dim16643JoeKuoD6Init[]   =   { 1, 1, 3, 5, 25, 27, 67, 65, 305, 677, 1975, 1049, 7277, 15279, 30181, 48941, 119087, 130265, 0 };
            const std::uint32_t dim16644JoeKuoD6Init[]   =   { 1, 1, 3, 9, 29, 27, 109, 167, 351, 463, 663, 3155, 919, 10627, 30163, 62233, 32927, 210775, 0 };
            const std::uint32_t dim16645JoeKuoD6Init[]   =   { 1, 3, 5, 5, 19, 9, 17, 93, 33, 999, 1537, 3045, 3735, 4625, 31363, 46075, 80985, 108331, 0 };
            const std::uint32_t dim16646JoeKuoD6Init[]   =   { 1, 3, 7, 7, 11, 63, 83, 157, 205, 505, 657, 1901, 1405, 8349, 16473, 29397, 130379, 167963, 0 };
            const std::uint32_t dim16647JoeKuoD6Init[]   =   { 1, 3, 1, 15, 25, 49, 65, 189, 461, 923, 1839, 2597, 2471, 14103, 2915, 48429, 74387, 243465, 0 };
            const std::uint32_t dim16648JoeKuoD6Init[]   =   { 1, 3, 7, 11, 31, 47, 109, 21, 205, 343, 1999, 315, 8119, 15937, 8761, 55257, 99983, 131641, 0 };
            const std::uint32_t dim16649JoeKuoD6Init[]   =   { 1, 1, 3, 11, 3, 23, 73, 125, 17, 967, 1811, 1413, 4783, 8303, 25301, 26859, 90583, 140721, 0 };
            const std::uint32_t dim16650JoeKuoD6Init[]   =   { 1, 1, 5, 5, 25, 41, 49, 127, 391, 381, 1575, 1697, 5205, 12805, 24365, 20275, 58819, 167845, 0 };
            const std::uint32_t dim16651JoeKuoD6Init[]   =   { 1, 1, 7, 11, 17, 53, 51, 35, 383, 931, 359, 2863, 119, 6683, 26247, 14281, 49205, 256869, 0 };
            const std::uint32_t dim16652JoeKuoD6Init[]   =   { 1, 1, 7, 9, 23, 5, 69, 97, 407, 15, 579, 2905, 47, 6227, 23997, 42459, 26569, 225467, 0 };
            const std::uint32_t dim16653JoeKuoD6Init[]   =   { 1, 3, 3, 11, 7, 3, 125, 87, 347, 79, 1571, 1513, 285, 12101, 1731, 27887, 42009, 173243, 0 };
            const std::uint32_t dim16654JoeKuoD6Init[]   =   { 1, 3, 7, 13, 3, 5, 99, 29, 77, 873, 1111, 1451, 5493, 10669, 22597, 54437, 55521, 101617, 0 };
            const std::uint32_t dim16655JoeKuoD6Init[]   =   { 1, 3, 1, 3, 3, 17, 41, 215, 207, 71, 683, 1979, 4849, 2437, 5717, 28999, 55005, 233929, 0 };
            const std::uint32_t dim16656JoeKuoD6Init[]   =   { 1, 1, 1, 1, 23, 21, 105, 223, 5, 235, 1533, 3715, 2689, 13937, 12125, 63879, 111537, 39817, 0 };
            const std::uint32_t dim16657JoeKuoD6Init[]   =   { 1, 3, 3, 15, 25, 47, 71, 229, 21, 563, 1851, 2423, 131, 4431, 31567, 8883, 1311, 227893, 0 };
            const std::uint32_t dim16658JoeKuoD6Init[]   =   { 1, 3, 5, 11, 7, 23, 19, 59, 397, 315, 1149, 3595, 5973, 11027, 5233, 55237, 102777, 137421, 0 };
            const std::uint32_t dim16659JoeKuoD6Init[]   =   { 1, 1, 7, 9, 17, 61, 45, 235, 387, 171, 1079, 3119, 6933, 3591, 751, 35495, 49969, 204611, 0 };
            const std::uint32_t dim16660JoeKuoD6Init[]   =   { 1, 1, 7, 7, 21, 7, 105, 79, 81, 245, 1229, 409, 5159, 9815, 6713, 4687, 120541, 246133, 0 };
            const std::uint32_t dim16661JoeKuoD6Init[]   =   { 1, 3, 7, 13, 23, 31, 85, 97, 481, 497, 581, 1179, 243, 1767, 11855, 11599, 3141, 104741, 0 };
            const std::uint32_t dim16662JoeKuoD6Init[]   =   { 1, 3, 7, 3, 3, 45, 15, 29, 413, 631, 273, 1007, 2979, 11307, 24535, 9305, 83591, 77121, 0 };
            const std::uint32_t dim16663JoeKuoD6Init[]   =   { 1, 3, 7, 15, 21, 55, 11, 169, 417, 631, 141, 1489, 3371, 16073, 11215, 15479, 125341, 131731, 0 };
            const std::uint32_t dim16664JoeKuoD6Init[]   =   { 1, 1, 7, 5, 13, 33, 7, 121, 295, 191, 497, 2233, 997, 13833, 14503, 38357, 79007, 53985, 0 };
            const std::uint32_t dim16665JoeKuoD6Init[]   =   { 1, 3, 3, 3, 29, 63, 97, 27, 449, 643, 317, 1989, 1481, 2873, 21247, 35989, 61295, 101829, 0 };
            const std::uint32_t dim16666JoeKuoD6Init[]   =   { 1, 3, 1, 7, 13, 49, 27, 227, 21, 983, 179, 2761, 2859, 2851, 26447, 33295, 126963, 41441, 0 };
            const std::uint32_t dim16667JoeKuoD6Init[]   =   { 1, 1, 5, 13, 27, 1, 61, 115, 185, 867, 2017, 2257, 5035, 7855, 25849, 48189, 28287, 133261, 0 };
            const std::uint32_t dim16668JoeKuoD6Init[]   =   { 1, 1, 7, 13, 27, 17, 13, 205, 379, 717, 247, 3341, 2841, 10845, 26979, 5589, 1935, 48371, 0 };
            const std::uint32_t dim16669JoeKuoD6Init[]   =   { 1, 3, 1, 11, 9, 51, 25, 185, 65, 643, 1867, 3825, 3395, 8883, 29239, 20019, 19071, 3377, 0 };
            const std::uint32_t dim16670JoeKuoD6Init[]   =   { 1, 1, 1, 1, 11, 57, 61, 113, 419, 249, 153, 2883, 87, 7919, 11941, 46725, 38701, 73715, 0 };
            const std::uint32_t dim16671JoeKuoD6Init[]   =   { 1, 3, 3, 11, 3, 15, 19, 87, 27, 839, 463, 1757, 3137, 10821, 2857, 58101, 91983, 137045, 0 };
            const std::uint32_t dim16672JoeKuoD6Init[]   =   { 1, 3, 3, 1, 25, 25, 15, 93, 359, 5, 53, 647, 6245, 1957, 4651, 14697, 12193, 231303, 0 };
            const std::uint32_t dim16673JoeKuoD6Init[]   =   { 1, 1, 5, 9, 31, 49, 69, 223, 133, 595, 777, 1281, 727, 6671, 21453, 14193, 51769, 258301, 0 };
            const std::uint32_t dim16674JoeKuoD6Init[]   =   { 1, 3, 5, 11, 29, 37, 75, 17, 229, 121, 313, 2873, 5233, 13231, 7589, 40075, 42101, 137697, 0 };
            const std::uint32_t dim16675JoeKuoD6Init[]   =   { 1, 1, 7, 1, 31, 9, 15, 63, 149, 5, 1785, 21, 2619, 15071, 3243, 58023, 20697, 205181, 0 };
            const std::uint32_t dim16676JoeKuoD6Init[]   =   { 1, 3, 7, 7, 25, 61, 59, 157, 251, 303, 1905, 2389, 1681, 319, 14155, 49089, 45381, 124447, 0 };
            const std::uint32_t dim16677JoeKuoD6Init[]   =   { 1, 3, 5, 5, 25, 27, 41, 125, 105, 867, 365, 117, 7215, 2887, 28499, 9597, 105999, 150189, 0 };
            const std::uint32_t dim16678JoeKuoD6Init[]   =   { 1, 1, 5, 13, 5, 33, 47, 221, 207, 641, 525, 3215, 5293, 16343, 16169, 44393, 26305, 194411, 0 };
            const std::uint32_t dim16679JoeKuoD6Init[]   =   { 1, 3, 5, 13, 29, 17, 31, 77, 511, 465, 1141, 597, 5111, 6629, 14557, 13057, 11643, 250925, 0 };
            const std::uint32_t dim16680JoeKuoD6Init[]   =   { 1, 1, 7, 11, 1, 5, 65, 139, 471, 265, 1145, 965, 47, 10971, 15615, 62031, 58523, 175593, 0 };
            const std::uint32_t dim16681JoeKuoD6Init[]   =   { 1, 1, 5, 1, 23, 61, 57, 139, 377, 843, 79, 2873, 1823, 7551, 26741, 63031, 124879, 115295, 0 };
            const std::uint32_t dim16682JoeKuoD6Init[]   =   { 1, 1, 5, 13, 9, 19, 1, 61, 331, 1015, 1035, 1691, 4057, 6071, 24929, 39569, 95695, 39307, 0 };
            const std::uint32_t dim16683JoeKuoD6Init[]   =   { 1, 3, 3, 5, 23, 17, 13, 65, 381, 893, 1879, 3735, 1547, 6735, 30251, 11471, 102997, 126429, 0 };
            const std::uint32_t dim16684JoeKuoD6Init[]   =   { 1, 1, 5, 13, 1, 43, 15, 1, 155, 221, 1463, 3793, 6467, 7221, 28027, 55357, 69397, 87565, 0 };
            const std::uint32_t dim16685JoeKuoD6Init[]   =   { 1, 1, 7, 3, 17, 9, 71, 75, 77, 639, 1251, 701, 473, 12337, 1893, 6349, 10837, 27797, 0 };
            const std::uint32_t dim16686JoeKuoD6Init[]   =   { 1, 3, 5, 11, 11, 11, 125, 23, 161, 937, 707, 2487, 695, 8495, 16219, 33671, 109463, 248305, 0 };
            const std::uint32_t dim16687JoeKuoD6Init[]   =   { 1, 1, 1, 11, 5, 49, 15, 47, 393, 407, 39, 1867, 7727, 12701, 7805, 119, 77401, 186421, 0 };
            const std::uint32_t dim16688JoeKuoD6Init[]   =   { 1, 1, 5, 5, 19, 21, 77, 187, 387, 51, 1497, 1225, 3101, 791, 529, 4321, 118435, 112889, 0 };
            const std::uint32_t dim16689JoeKuoD6Init[]   =   { 1, 3, 1, 13, 27, 17, 11, 63, 201, 909, 1549, 3243, 1803, 9461, 20985, 24637, 100993, 200473, 0 };
            const std::uint32_t dim16690JoeKuoD6Init[]   =   { 1, 3, 7, 13, 11, 35, 97, 213, 415, 467, 2013, 2159, 7017, 7895, 18235, 50659, 113169, 141887, 0 };
            const std::uint32_t dim16691JoeKuoD6Init[]   =   { 1, 1, 3, 7, 13, 21, 119, 109, 471, 323, 277, 1685, 2399, 14777, 2643, 5879, 113043, 45223, 0 };
            const std::uint32_t dim16692JoeKuoD6Init[]   =   { 1, 3, 1, 13, 19, 5, 1, 75, 499, 297, 1897, 591, 3223, 12939, 30593, 4053, 122207, 215171, 0 };
            const std::uint32_t dim16693JoeKuoD6Init[]   =   { 1, 3, 3, 9, 21, 11, 29, 205, 13, 381, 569, 599, 7089, 8145, 18531, 34477, 101057, 64269, 0 };
            const std::uint32_t dim16694JoeKuoD6Init[]   =   { 1, 1, 5, 15, 1, 19, 37, 131, 325, 441, 3, 4001, 6937, 9207, 27543, 30321, 37083, 241019, 0 };
            const std::uint32_t dim16695JoeKuoD6Init[]   =   { 1, 3, 7, 13, 7, 15, 9, 159, 97, 905, 557, 1913, 7325, 4057, 19461, 14277, 36873, 25619, 0 };
            const std::uint32_t dim16696JoeKuoD6Init[]   =   { 1, 3, 5, 7, 3, 51, 99, 9, 185, 227, 2041, 331, 3925, 12481, 17485, 37137, 3753, 125269, 0 };
            const std::uint32_t dim16697JoeKuoD6Init[]   =   { 1, 1, 7, 11, 31, 49, 89, 37, 49, 863, 833, 3263, 351, 6277, 23055, 49727, 25005, 161585, 0 };
            const std::uint32_t dim16698JoeKuoD6Init[]   =   { 1, 3, 5, 1, 9, 35, 89, 101, 117, 365, 1015, 1159, 4623, 4541, 6831, 28091, 10647, 221415, 0 };
            const std::uint32_t dim16699JoeKuoD6Init[]   =   { 1, 1, 5, 5, 13, 47, 125, 209, 199, 885, 927, 1411, 795, 8835, 28589, 48753, 27191, 53455, 0 };
            const std::uint32_t dim16700JoeKuoD6Init[]   =   { 1, 1, 5, 9, 7, 19, 3, 87, 157, 121, 1433, 1463, 3241, 5969, 203, 36723, 14779, 63949, 0 };
            const std::uint32_t dim16701JoeKuoD6Init[]   =   { 1, 1, 3, 9, 1, 47, 71, 113, 405, 561, 1149, 3599, 4173, 6819, 5493, 45987, 41521, 221503, 0 };
            const std::uint32_t dim16702JoeKuoD6Init[]   =   { 1, 3, 3, 1, 3, 55, 101, 103, 161, 549, 457, 2529, 2043, 8843, 5677, 7449, 45185, 178289, 0 };
            const std::uint32_t dim16703JoeKuoD6Init[]   =   { 1, 1, 1, 3, 31, 25, 1, 161, 7, 503, 641, 2221, 749, 1521, 6151, 19245, 55913, 80141, 0 };
            const std::uint32_t dim16704JoeKuoD6Init[]   =   { 1, 1, 1, 9, 3, 45, 73, 217, 249, 929, 163, 2139, 3921, 11223, 11161, 52697, 89633, 14243, 0 };
            const std::uint32_t dim16705JoeKuoD6Init[]   =   { 1, 1, 7, 15, 17, 41, 5, 119, 211, 53, 985, 2679, 679, 9349, 25577, 26947, 35141, 93999, 0 };
            const std::uint32_t dim16706JoeKuoD6Init[]   =   { 1, 3, 1, 15, 17, 43, 51, 15, 363, 615, 889, 195, 6279, 15477, 31545, 50941, 119711, 66535, 0 };
            const std::uint32_t dim16707JoeKuoD6Init[]   =   { 1, 1, 1, 13, 7, 11, 17, 127, 131, 759, 739, 161, 5937, 13611, 31757, 10681, 101357, 82873, 0 };
            const std::uint32_t dim16708JoeKuoD6Init[]   =   { 1, 3, 5, 7, 21, 63, 75, 33, 233, 981, 589, 3409, 3523, 1871, 8919, 38513, 32825, 56935, 0 };
            const std::uint32_t dim16709JoeKuoD6Init[]   =   { 1, 3, 5, 3, 9, 9, 85, 221, 203, 727, 1035, 1069, 2409, 2687, 235, 23395, 64163, 193235, 0 };
            const std::uint32_t dim16710JoeKuoD6Init[]   =   { 1, 3, 3, 7, 1, 35, 119, 175, 203, 819, 207, 2283, 4175, 3581, 11647, 43073, 104573, 86607, 0 };
            const std::uint32_t dim16711JoeKuoD6Init[]   =   { 1, 3, 3, 15, 11, 63, 59, 153, 279, 779, 261, 3317, 7671, 11727, 19381, 33227, 79331, 187227, 0 };
            const std::uint32_t dim16712JoeKuoD6Init[]   =   { 1, 1, 3, 1, 7, 1, 115, 15, 235, 9, 1877, 1911, 1089, 9939, 9537, 39563, 95327, 70323, 0 };
            const std::uint32_t dim16713JoeKuoD6Init[]   =   { 1, 1, 5, 7, 25, 61, 63, 145, 425, 617, 1813, 3255, 6797, 16019, 18849, 44191, 69877, 179933, 0 };
            const std::uint32_t dim16714JoeKuoD6Init[]   =   { 1, 1, 3, 13, 17, 45, 69, 247, 27, 367, 871, 1185, 895, 7991, 8145, 22869, 97609, 14673, 0 };
            const std::uint32_t dim16715JoeKuoD6Init[]   =   { 1, 3, 3, 11, 19, 41, 99, 213, 159, 803, 121, 1197, 2849, 15191, 15603, 52445, 105077, 128231, 0 };
            const std::uint32_t dim16716JoeKuoD6Init[]   =   { 1, 3, 1, 11, 21, 61, 117, 167, 437, 447, 419, 1673, 755, 15331, 29819, 16099, 130773, 177547, 0 };
            const std::uint32_t dim16717JoeKuoD6Init[]   =   { 1, 3, 7, 7, 1, 15, 79, 109, 351, 71, 985, 89, 7517, 4175, 30533, 52125, 100863, 186477, 0 };
            const std::uint32_t dim16718JoeKuoD6Init[]   =   { 1, 1, 3, 1, 15, 1, 103, 65, 511, 241, 1279, 3233, 7141, 255, 10925, 28271, 56151, 252121, 0 };
            const std::uint32_t dim16719JoeKuoD6Init[]   =   { 1, 1, 1, 13, 17, 49, 59, 93, 19, 343, 979, 865, 3447, 4595, 3067, 26807, 98915, 126237, 0 };
            const std::uint32_t dim16720JoeKuoD6Init[]   =   { 1, 3, 3, 5, 17, 5, 91, 199, 191, 775, 233, 919, 277, 3485, 9231, 37025, 23493, 186745, 0 };
            const std::uint32_t dim16721JoeKuoD6Init[]   =   { 1, 3, 1, 1, 11, 5, 103, 187, 85, 47, 1111, 883, 6155, 15315, 9041, 58275, 75037, 7773, 0 };
            const std::uint32_t dim16722JoeKuoD6Init[]   =   { 1, 3, 1, 3, 19, 5, 7, 211, 481, 713, 383, 1203, 6089, 15817, 31577, 7283, 25457, 101455, 0 };
            const std::uint32_t dim16723JoeKuoD6Init[]   =   { 1, 3, 5, 7, 21, 9, 59, 127, 375, 477, 721, 3931, 7089, 9079, 5015, 62019, 113747, 36055, 0 };
            const std::uint32_t dim16724JoeKuoD6Init[]   =   { 1, 3, 7, 13, 3, 17, 47, 177, 103, 535, 1787, 509, 5253, 2857, 13421, 19875, 37397, 251353, 0 };
            const std::uint32_t dim16725JoeKuoD6Init[]   =   { 1, 1, 5, 7, 19, 31, 41, 93, 301, 45, 251, 2691, 4657, 2627, 17321, 24627, 80221, 117191, 0 };
            const std::uint32_t dim16726JoeKuoD6Init[]   =   { 1, 3, 5, 7, 5, 31, 27, 3, 463, 549, 1669, 499, 815, 4091, 7049, 60957, 102849, 235617, 0 };
            const std::uint32_t dim16727JoeKuoD6Init[]   =   { 1, 3, 5, 1, 21, 31, 57, 201, 503, 977, 893, 3927, 1605, 8265, 5137, 51009, 89375, 237909, 0 };
            const std::uint32_t dim16728JoeKuoD6Init[]   =   { 1, 3, 3, 1, 27, 5, 11, 81, 445, 229, 5, 543, 3397, 12961, 31911, 36945, 59485, 305, 0 };
            const std::uint32_t dim16729JoeKuoD6Init[]   =   { 1, 1, 5, 13, 31, 63, 39, 171, 243, 39, 1147, 459, 7215, 14603, 20625, 47369, 121495, 237741, 0 };
            const std::uint32_t dim16730JoeKuoD6Init[]   =   { 1, 3, 3, 13, 15, 63, 39, 23, 305, 685, 1885, 571, 2657, 16031, 24759, 10639, 25619, 246137, 0 };
            const std::uint32_t dim16731JoeKuoD6Init[]   =   { 1, 1, 1, 5, 19, 33, 5, 187, 167, 725, 1405, 511, 701, 13283, 3513, 16495, 8755, 221751, 0 };
            const std::uint32_t dim16732JoeKuoD6Init[]   =   { 1, 1, 7, 11, 3, 27, 27, 237, 495, 637, 479, 3247, 3825, 2567, 12853, 52881, 34807, 161483, 0 };
            const std::uint32_t dim16733JoeKuoD6Init[]   =   { 1, 3, 3, 9, 23, 43, 101, 175, 19, 443, 787, 1053, 4113, 12777, 4615, 53115, 2873, 117383, 0 };
            const std::uint32_t dim16734JoeKuoD6Init[]   =   { 1, 3, 1, 13, 3, 23, 33, 93, 145, 937, 957, 2463, 827, 383, 16749, 61567, 10029, 188159, 0 };
            const std::uint32_t dim16735JoeKuoD6Init[]   =   { 1, 1, 7, 15, 21, 23, 3, 71, 323, 995, 645, 1189, 1029, 519, 3479, 13587, 95641, 215337, 0 };
            const std::uint32_t dim16736JoeKuoD6Init[]   =   { 1, 3, 7, 11, 9, 17, 101, 59, 421, 417, 797, 3089, 773, 15959, 18127, 13681, 104667, 217433, 0 };
            const std::uint32_t dim16737JoeKuoD6Init[]   =   { 1, 3, 5, 7, 31, 21, 9, 7, 377, 589, 1497, 939, 5389, 10997, 22291, 19639, 72187, 66193, 0 };
            const std::uint32_t dim16738JoeKuoD6Init[]   =   { 1, 1, 1, 13, 19, 1, 127, 185, 251, 167, 1289, 2715, 5885, 12715, 18261, 36861, 102721, 246917, 0 };
            const std::uint32_t dim16739JoeKuoD6Init[]   =   { 1, 1, 7, 1, 23, 41, 19, 151, 125, 465, 813, 1711, 7933, 13561, 29737, 59207, 62533, 124149, 0 };
            const std::uint32_t dim16740JoeKuoD6Init[]   =   { 1, 3, 5, 9, 7, 13, 17, 119, 425, 877, 1207, 2211, 2943, 13921, 28251, 44143, 112149, 152341, 0 };
            const std::uint32_t dim16741JoeKuoD6Init[]   =   { 1, 3, 5, 9, 15, 21, 87, 83, 77, 731, 91, 3091, 5687, 9647, 2037, 39031, 106583, 66533, 0 };
            const std::uint32_t dim16742JoeKuoD6Init[]   =   { 1, 1, 7, 9, 31, 49, 7, 119, 147, 599, 1191, 297, 1597, 10723, 16893, 47387, 106995, 165409, 0 };
            const std::uint32_t dim16743JoeKuoD6Init[]   =   { 1, 3, 3, 3, 3, 63, 11, 193, 241, 63, 1671, 2139, 5689, 13967, 9239, 7535, 34237, 140283, 0 };
            const std::uint32_t dim16744JoeKuoD6Init[]   =   { 1, 3, 5, 13, 9, 23, 65, 247, 473, 825, 109, 1897, 245, 10517, 8147, 25989, 96447, 118689, 0 };
            const std::uint32_t dim16745JoeKuoD6Init[]   =   { 1, 1, 3, 5, 27, 35, 65, 23, 159, 729, 189, 2661, 4245, 14377, 21043, 15551, 2717, 146949, 0 };
            const std::uint32_t dim16746JoeKuoD6Init[]   =   { 1, 1, 3, 13, 23, 5, 35, 63, 293, 347, 883, 149, 5145, 10821, 5813, 24183, 94711, 64787, 0 };
            const std::uint32_t dim16747JoeKuoD6Init[]   =   { 1, 1, 5, 3, 27, 3, 127, 141, 237, 535, 1509, 2755, 5843, 2379, 19413, 52345, 100247, 42571, 0 };
            const std::uint32_t dim16748JoeKuoD6Init[]   =   { 1, 3, 3, 9, 1, 55, 61, 105, 29, 1021, 1215, 2157, 7453, 4643, 26793, 33553, 2959, 51485, 0 };
            const std::uint32_t dim16749JoeKuoD6Init[]   =   { 1, 1, 3, 7, 31, 51, 59, 49, 321, 207, 415, 2115, 219, 5045, 31133, 17961, 130779, 28255, 0 };
            const std::uint32_t dim16750JoeKuoD6Init[]   =   { 1, 3, 7, 15, 9, 29, 31, 185, 111, 959, 7, 827, 7891, 5449, 22221, 49933, 2091, 194683, 0 };
            const std::uint32_t dim16751JoeKuoD6Init[]   =   { 1, 3, 7, 1, 11, 59, 75, 255, 387, 913, 423, 2915, 5079, 6363, 5175, 57977, 5559, 13257, 0 };
            const std::uint32_t dim16752JoeKuoD6Init[]   =   { 1, 1, 7, 1, 21, 3, 21, 13, 157, 3, 715, 3525, 7769, 5333, 25345, 53473, 44323, 203167, 0 };
            const std::uint32_t dim16753JoeKuoD6Init[]   =   { 1, 1, 7, 11, 31, 25, 55, 5, 169, 695, 1599, 2357, 1427, 14469, 15223, 34275, 42605, 23005, 0 };
            const std::uint32_t dim16754JoeKuoD6Init[]   =   { 1, 1, 1, 15, 19, 51, 117, 135, 297, 831, 329, 3793, 4673, 3795, 24185, 52971, 30423, 68771, 0 };
            const std::uint32_t dim16755JoeKuoD6Init[]   =   { 1, 1, 7, 5, 19, 33, 79, 77, 315, 29, 307, 1709, 3489, 14515, 12477, 58939, 53753, 165031, 0 };
            const std::uint32_t dim16756JoeKuoD6Init[]   =   { 1, 1, 7, 1, 27, 57, 119, 207, 355, 279, 1371, 3917, 2821, 5285, 12673, 28973, 54957, 94001, 0 };
            const std::uint32_t dim16757JoeKuoD6Init[]   =   { 1, 3, 7, 3, 19, 57, 53, 199, 485, 805, 301, 1337, 5993, 2187, 30573, 12045, 101205, 129841, 0 };
            const std::uint32_t dim16758JoeKuoD6Init[]   =   { 1, 1, 3, 9, 15, 45, 71, 119, 445, 759, 1361, 1299, 2927, 2343, 22085, 53733, 21241, 1553, 0 };
            const std::uint32_t dim16759JoeKuoD6Init[]   =   { 1, 3, 5, 3, 27, 11, 1, 239, 497, 343, 1989, 1463, 2473, 5191, 6271, 14129, 124453, 96817, 0 };
            const std::uint32_t dim16760JoeKuoD6Init[]   =   { 1, 3, 5, 7, 27, 19, 123, 27, 483, 557, 1545, 1871, 1297, 587, 1067, 51259, 119231, 173659, 0 };
            const std::uint32_t dim16761JoeKuoD6Init[]   =   { 1, 3, 1, 1, 27, 45, 41, 113, 453, 553, 2019, 2039, 1709, 13017, 5497, 34459, 60295, 229405, 0 };
            const std::uint32_t dim16762JoeKuoD6Init[]   =   { 1, 3, 1, 11, 1, 57, 51, 125, 261, 915, 1673, 25, 529, 653, 17247, 64225, 98991, 248143, 0 };
            const std::uint32_t dim16763JoeKuoD6Init[]   =   { 1, 3, 5, 15, 25, 27, 31, 1, 463, 249, 113, 1955, 2223, 5463, 12281, 20843, 26495, 256759, 0 };
            const std::uint32_t dim16764JoeKuoD6Init[]   =   { 1, 1, 3, 11, 27, 33, 57, 205, 89, 435, 1983, 1165, 3843, 127, 30179, 63971, 10211, 105403, 0 };
            const std::uint32_t dim16765JoeKuoD6Init[]   =   { 1, 3, 3, 5, 21, 49, 35, 161, 273, 205, 41, 1881, 2013, 12549, 24859, 55711, 98235, 237281, 0 };
            const std::uint32_t dim16766JoeKuoD6Init[]   =   { 1, 3, 3, 1, 15, 35, 95, 1, 221, 675, 385, 2257, 2531, 2129, 12895, 11565, 125977, 51973, 0 };
            const std::uint32_t dim16767JoeKuoD6Init[]   =   { 1, 1, 1, 15, 19, 61, 35, 55, 9, 721, 499, 2577, 3001, 14861, 22293, 56195, 72855, 166703, 0 };
            const std::uint32_t dim16768JoeKuoD6Init[]   =   { 1, 1, 1, 7, 5, 25, 59, 175, 81, 989, 935, 2579, 8183, 1109, 4645, 53753, 115795, 105091, 0 };
            const std::uint32_t dim16769JoeKuoD6Init[]   =   { 1, 3, 3, 13, 7, 55, 7, 113, 197, 763, 1747, 3291, 1109, 4391, 18257, 28563, 97413, 5847, 0 };
            const std::uint32_t dim16770JoeKuoD6Init[]   =   { 1, 1, 1, 7, 23, 55, 91, 83, 479, 305, 843, 2055, 3405, 15243, 31551, 5275, 8651, 66915, 0 };
            const std::uint32_t dim16771JoeKuoD6Init[]   =   { 1, 3, 7, 9, 3, 19, 83, 229, 235, 903, 1495, 1033, 2729, 14927, 11847, 22979, 13905, 84413, 0 };
            const std::uint32_t dim16772JoeKuoD6Init[]   =   { 1, 3, 3, 13, 27, 37, 83, 193, 475, 439, 745, 757, 7359, 6683, 5839, 50765, 6933, 117411, 0 };
            const std::uint32_t dim16773JoeKuoD6Init[]   =   { 1, 3, 5, 11, 31, 25, 33, 77, 113, 815, 123, 2721, 2133, 8995, 15237, 54565, 5155, 51235, 0 };
            const std::uint32_t dim16774JoeKuoD6Init[]   =   { 1, 3, 3, 7, 15, 31, 73, 91, 379, 39, 913, 53, 41, 1059, 25883, 11769, 63015, 48125, 0 };
            const std::uint32_t dim16775JoeKuoD6Init[]   =   { 1, 1, 5, 5, 5, 13, 81, 169, 71, 529, 1429, 2101, 4069, 5509, 30283, 40625, 103673, 183243, 0 };
            const std::uint32_t dim16776JoeKuoD6Init[]   =   { 1, 3, 3, 5, 23, 39, 39, 237, 445, 567, 343, 2521, 2287, 1851, 2315, 59979, 5015, 243349, 0 };
            const std::uint32_t dim16777JoeKuoD6Init[]   =   { 1, 1, 7, 1, 1, 51, 89, 229, 187, 207, 245, 3521, 2987, 4347, 6997, 62565, 54397, 140473, 0 };
            const std::uint32_t dim16778JoeKuoD6Init[]   =   { 1, 3, 1, 5, 7, 59, 45, 161, 457, 655, 1591, 215, 2213, 15101, 14791, 40397, 95811, 126291, 0 };
            const std::uint32_t dim16779JoeKuoD6Init[]   =   { 1, 1, 3, 1, 5, 23, 7, 199, 143, 561, 1669, 17, 8109, 11003, 4535, 8593, 112021, 223153, 0 };
            const std::uint32_t dim16780JoeKuoD6Init[]   =   { 1, 3, 5, 9, 3, 37, 111, 15, 235, 697, 385, 2197, 909, 1247, 26199, 50661, 100643, 122577, 0 };
            const std::uint32_t dim16781JoeKuoD6Init[]   =   { 1, 3, 5, 11, 23, 53, 95, 75, 463, 137, 1511, 3373, 3071, 547, 22399, 51891, 9123, 240925, 0 };
            const std::uint32_t dim16782JoeKuoD6Init[]   =   { 1, 3, 7, 3, 21, 35, 69, 197, 371, 15, 185, 3539, 29, 15071, 17069, 34669, 37023, 189385, 0 };
            const std::uint32_t dim16783JoeKuoD6Init[]   =   { 1, 1, 1, 15, 5, 21, 7, 5, 201, 881, 841, 827, 503, 3545, 17771, 64481, 65105, 209947, 0 };
            const std::uint32_t dim16784JoeKuoD6Init[]   =   { 1, 1, 1, 5, 3, 31, 83, 201, 455, 169, 1797, 1769, 1999, 8629, 14313, 16851, 64955, 180631, 0 };
            const std::uint32_t dim16785JoeKuoD6Init[]   =   { 1, 1, 5, 5, 1, 35, 49, 61, 499, 619, 1509, 3015, 237, 8979, 3471, 11513, 80193, 24135, 0 };
            const std::uint32_t dim16786JoeKuoD6Init[]   =   { 1, 3, 3, 9, 25, 29, 111, 19, 339, 739, 1751, 2671, 5399, 5965, 3943, 45577, 70605, 203117, 0 };
            const std::uint32_t dim16787JoeKuoD6Init[]   =   { 1, 3, 3, 7, 3, 9, 15, 147, 177, 545, 161, 2211, 4653, 15891, 15939, 19153, 77827, 245787, 0 };
            const std::uint32_t dim16788JoeKuoD6Init[]   =   { 1, 1, 1, 1, 25, 47, 37, 159, 273, 825, 1037, 2047, 7149, 5517, 699, 49687, 110115, 159475, 0 };
            const std::uint32_t dim16789JoeKuoD6Init[]   =   { 1, 3, 1, 7, 7, 55, 77, 231, 197, 381, 2013, 2421, 7551, 9955, 21031, 11365, 48271, 190147, 0 };
            const std::uint32_t dim16790JoeKuoD6Init[]   =   { 1, 1, 5, 9, 25, 1, 81, 145, 215, 427, 905, 2307, 6149, 12777, 131, 57091, 106137, 24625, 0 };
            const std::uint32_t dim16791JoeKuoD6Init[]   =   { 1, 3, 1, 13, 13, 63, 103, 245, 275, 745, 841, 2993, 2083, 8903, 4499, 55979, 22323, 244447, 0 };
            const std::uint32_t dim16792JoeKuoD6Init[]   =   { 1, 1, 5, 5, 15, 11, 59, 181, 191, 219, 599, 59, 1079, 4445, 16537, 31127, 103257, 233855, 0 };
            const std::uint32_t dim16793JoeKuoD6Init[]   =   { 1, 3, 7, 9, 9, 37, 109, 41, 145, 1001, 609, 551, 6843, 13791, 15103, 27851, 7693, 145207, 0 };
            const std::uint32_t dim16794JoeKuoD6Init[]   =   { 1, 3, 1, 9, 3, 35, 63, 219, 49, 567, 1537, 1327, 6487, 16039, 26019, 13851, 116929, 175121, 0 };
            const std::uint32_t dim16795JoeKuoD6Init[]   =   { 1, 3, 7, 15, 17, 31, 27, 91, 241, 229, 485, 2601, 3859, 12609, 19847, 31939, 50815, 235529, 0 };
            const std::uint32_t dim16796JoeKuoD6Init[]   =   { 1, 1, 5, 15, 27, 31, 3, 47, 69, 427, 95, 1445, 1223, 2953, 32343, 6841, 67851, 79561, 0 };
            const std::uint32_t dim16797JoeKuoD6Init[]   =   { 1, 3, 5, 13, 13, 37, 19, 127, 259, 139, 1597, 651, 4845, 6413, 18205, 56005, 32107, 140783, 0 };
            const std::uint32_t dim16798JoeKuoD6Init[]   =   { 1, 1, 7, 5, 15, 23, 81, 195, 127, 113, 499, 733, 5907, 12107, 18105, 28113, 16111, 152327, 0 };
            const std::uint32_t dim16799JoeKuoD6Init[]   =   { 1, 1, 5, 15, 9, 49, 109, 181, 187, 591, 1625, 3641, 313, 1225, 11725, 9047, 30351, 124301, 0 };
            const std::uint32_t dim16800JoeKuoD6Init[]   =   { 1, 3, 1, 1, 9, 45, 103, 219, 155, 805, 1775, 759, 1687, 11415, 21623, 37831, 18995, 21667, 0 };
            const std::uint32_t dim16801JoeKuoD6Init[]   =   { 1, 3, 3, 5, 25, 13, 11, 37, 489, 935, 373, 811, 5045, 3615, 2111, 22909, 117155, 69483, 0 };
            const std::uint32_t dim16802JoeKuoD6Init[]   =   { 1, 3, 3, 5, 9, 45, 71, 87, 265, 93, 161, 2983, 1023, 3633, 5965, 9499, 35653, 219257, 0 };
            const std::uint32_t dim16803JoeKuoD6Init[]   =   { 1, 1, 5, 13, 21, 27, 101, 231, 85, 469, 1023, 3735, 5093, 253, 22585, 61975, 81041, 4175, 0 };
            const std::uint32_t dim16804JoeKuoD6Init[]   =   { 1, 3, 1, 7, 5, 41, 105, 153, 391, 5, 1917, 331, 7679, 14359, 13177, 40755, 78669, 133527, 0 };
            const std::uint32_t dim16805JoeKuoD6Init[]   =   { 1, 3, 3, 15, 21, 61, 87, 63, 227, 195, 1095, 1629, 7787, 5887, 20855, 30203, 61973, 30627, 0 };
            const std::uint32_t dim16806JoeKuoD6Init[]   =   { 1, 3, 1, 15, 31, 41, 125, 223, 201, 717, 1309, 595, 5333, 10585, 32525, 8597, 92637, 111073, 0 };
            const std::uint32_t dim16807JoeKuoD6Init[]   =   { 1, 3, 5, 3, 21, 29, 39, 105, 275, 515, 503, 79, 6715, 14203, 14035, 20871, 122417, 243167, 0 };
            const std::uint32_t dim16808JoeKuoD6Init[]   =   { 1, 3, 7, 5, 29, 41, 3, 89, 165, 879, 773, 3989, 3945, 4771, 2809, 59105, 37177, 193887, 0 };
            const std::uint32_t dim16809JoeKuoD6Init[]   =   { 1, 3, 3, 3, 27, 1, 91, 191, 135, 257, 527, 2971, 7117, 6013, 8735, 52363, 110617, 96959, 0 };
            const std::uint32_t dim16810JoeKuoD6Init[]   =   { 1, 3, 7, 9, 3, 63, 67, 67, 231, 23, 1539, 771, 1485, 4331, 19231, 50539, 15081, 75945, 0 };
            const std::uint32_t dim16811JoeKuoD6Init[]   =   { 1, 3, 3, 11, 29, 11, 77, 67, 497, 861, 21, 2939, 2463, 14435, 27399, 19733, 118207, 60909, 0 };
            const std::uint32_t dim16812JoeKuoD6Init[]   =   { 1, 1, 5, 5, 1, 11, 117, 55, 485, 877, 1213, 2231, 2613, 14027, 18491, 45431, 113303, 28457, 0 };
            const std::uint32_t dim16813JoeKuoD6Init[]   =   { 1, 3, 7, 1, 13, 49, 77, 59, 455, 251, 1033, 3451, 7641, 389, 3987, 62361, 90125, 94569, 0 };
            const std::uint32_t dim16814JoeKuoD6Init[]   =   { 1, 1, 7, 15, 3, 5, 45, 173, 343, 445, 1871, 2505, 1385, 2641, 21299, 35139, 61781, 101195, 0 };
            const std::uint32_t dim16815JoeKuoD6Init[]   =   { 1, 3, 1, 9, 25, 27, 89, 123, 473, 901, 1513, 2585, 5641, 13123, 22653, 32985, 15763, 9161, 0 };
            const std::uint32_t dim16816JoeKuoD6Init[]   =   { 1, 3, 3, 9, 29, 41, 5, 127, 489, 715, 1981, 3953, 3557, 10081, 31913, 52191, 118727, 4443, 0 };
            const std::uint32_t dim16817JoeKuoD6Init[]   =   { 1, 1, 5, 1, 19, 57, 125, 33, 253, 297, 265, 2249, 6859, 14971, 3519, 24783, 127491, 210441, 0 };
            const std::uint32_t dim16818JoeKuoD6Init[]   =   { 1, 1, 7, 7, 31, 1, 47, 175, 305, 933, 679, 317, 7511, 13219, 9509, 61183, 58907, 72905, 0 };
            const std::uint32_t dim16819JoeKuoD6Init[]   =   { 1, 1, 1, 7, 13, 49, 75, 85, 341, 911, 1217, 3631, 1849, 9715, 23193, 947, 106647, 180455, 0 };
            const std::uint32_t dim16820JoeKuoD6Init[]   =   { 1, 1, 7, 7, 1, 49, 91, 195, 329, 771, 607, 1707, 2723, 291, 21393, 6549, 31645, 151431, 0 };
            const std::uint32_t dim16821JoeKuoD6Init[]   =   { 1, 3, 7, 5, 17, 57, 7, 231, 247, 217, 1729, 3231, 7515, 15341, 18681, 21733, 28723, 228187, 0 };
            const std::uint32_t dim16822JoeKuoD6Init[]   =   { 1, 1, 5, 9, 5, 19, 121, 251, 43, 951, 957, 173, 4863, 5027, 6781, 29421, 4877, 47749, 0 };
            const std::uint32_t dim16823JoeKuoD6Init[]   =   { 1, 3, 7, 7, 11, 33, 107, 233, 329, 589, 869, 913, 7687, 13223, 27577, 24379, 13037, 214713, 0 };
            const std::uint32_t dim16824JoeKuoD6Init[]   =   { 1, 3, 7, 13, 1, 13, 121, 103, 387, 193, 543, 3085, 4323, 9885, 24499, 34985, 45763, 13107, 0 };
            const std::uint32_t dim16825JoeKuoD6Init[]   =   { 1, 1, 3, 15, 25, 63, 85, 41, 457, 779, 1199, 2235, 309, 2549, 3341, 36265, 17873, 32361, 0 };
            const std::uint32_t dim16826JoeKuoD6Init[]   =   { 1, 3, 3, 3, 15, 31, 11, 57, 499, 415, 1625, 1195, 6863, 6073, 25083, 57705, 76203, 130993, 0 };
            const std::uint32_t dim16827JoeKuoD6Init[]   =   { 1, 3, 5, 5, 21, 13, 43, 161, 255, 31, 1901, 3325, 3209, 9809, 8227, 9005, 57263, 95095, 0 };
            const std::uint32_t dim16828JoeKuoD6Init[]   =   { 1, 1, 3, 15, 13, 33, 5, 123, 291, 579, 1747, 3319, 7351, 1679, 11365, 26909, 74445, 139017, 0 };
            const std::uint32_t dim16829JoeKuoD6Init[]   =   { 1, 1, 3, 13, 17, 39, 1, 253, 487, 935, 1711, 1397, 503, 7817, 28509, 20665, 78551, 204319, 0 };
            const std::uint32_t dim16830JoeKuoD6Init[]   =   { 1, 1, 3, 1, 5, 39, 123, 105, 305, 77, 63, 3285, 7463, 11199, 647, 37757, 91083, 108325, 0 };
            const std::uint32_t dim16831JoeKuoD6Init[]   =   { 1, 1, 7, 5, 9, 49, 121, 155, 389, 119, 1327, 3583, 7715, 2705, 20047, 19151, 101455, 205263, 0 };
            const std::uint32_t dim16832JoeKuoD6Init[]   =   { 1, 1, 5, 7, 31, 23, 13, 109, 103, 41, 433, 3609, 4973, 11481, 8381, 4725, 113633, 134651, 0 };
            const std::uint32_t dim16833JoeKuoD6Init[]   =   { 1, 3, 7, 7, 25, 25, 107, 189, 89, 625, 187, 2185, 713, 10107, 11139, 63681, 97005, 79329, 0 };
            const std::uint32_t dim16834JoeKuoD6Init[]   =   { 1, 3, 1, 11, 3, 41, 43, 161, 337, 955, 1035, 451, 5989, 3593, 18087, 22667, 110213, 128545, 0 };
            const std::uint32_t dim16835JoeKuoD6Init[]   =   { 1, 1, 5, 1, 25, 31, 95, 113, 205, 565, 557, 3885, 7163, 10703, 27159, 11395, 117459, 52439, 0 };
            const std::uint32_t dim16836JoeKuoD6Init[]   =   { 1, 1, 1, 5, 27, 31, 39, 61, 323, 983, 1361, 2387, 5401, 8287, 17855, 49783, 65327, 202861, 0 };
            const std::uint32_t dim16837JoeKuoD6Init[]   =   { 1, 3, 5, 3, 31, 39, 105, 113, 183, 311, 667, 945, 3677, 14623, 27907, 16673, 77899, 182863, 0 };
            const std::uint32_t dim16838JoeKuoD6Init[]   =   { 1, 1, 5, 3, 17, 27, 99, 93, 81, 805, 1799, 2855, 6859, 3917, 26177, 22307, 59213, 210123, 0 };
            const std::uint32_t dim16839JoeKuoD6Init[]   =   { 1, 3, 5, 1, 19, 37, 51, 65, 495, 229, 229, 1283, 2967, 5329, 24339, 58739, 23145, 7033, 0 };
            const std::uint32_t dim16840JoeKuoD6Init[]   =   { 1, 3, 3, 15, 11, 51, 121, 41, 75, 845, 1771, 3625, 6137, 3463, 11767, 45181, 70907, 42771, 0 };
            const std::uint32_t dim16841JoeKuoD6Init[]   =   { 1, 3, 7, 9, 15, 25, 55, 219, 265, 655, 167, 1247, 5409, 5623, 21045, 12333, 25799, 218601, 0 };
            const std::uint32_t dim16842JoeKuoD6Init[]   =   { 1, 3, 3, 13, 31, 39, 77, 155, 471, 969, 755, 2745, 3057, 3621, 32423, 48687, 9409, 90997, 0 };
            const std::uint32_t dim16843JoeKuoD6Init[]   =   { 1, 1, 3, 15, 27, 1, 77, 231, 147, 235, 2027, 4045, 7431, 14655, 6361, 43155, 9839, 161713, 0 };
            const std::uint32_t dim16844JoeKuoD6Init[]   =   { 1, 3, 7, 5, 25, 19, 25, 75, 415, 931, 457, 3691, 687, 4849, 15469, 42871, 37949, 74163, 0 };
            const std::uint32_t dim16845JoeKuoD6Init[]   =   { 1, 3, 5, 9, 17, 19, 29, 117, 387, 1021, 1159, 2467, 2585, 2563, 9155, 44763, 93319, 6321, 0 };
            const std::uint32_t dim16846JoeKuoD6Init[]   =   { 1, 3, 5, 7, 25, 33, 127, 175, 143, 705, 539, 2563, 945, 11369, 19971, 19019, 116195, 84121, 0 };
            const std::uint32_t dim16847JoeKuoD6Init[]   =   { 1, 3, 7, 7, 5, 55, 29, 1, 419, 715, 1275, 2983, 7853, 12245, 32109, 27371, 123547, 82723, 0 };
            const std::uint32_t dim16848JoeKuoD6Init[]   =   { 1, 1, 1, 13, 3, 29, 31, 213, 195, 609, 1465, 1711, 6747, 13309, 1131, 3151, 48779, 91571, 0 };
            const std::uint32_t dim16849JoeKuoD6Init[]   =   { 1, 1, 5, 3, 17, 7, 103, 7, 217, 87, 1641, 833, 4551, 14205, 15119, 6711, 111273, 200545, 0 };
            const std::uint32_t dim16850JoeKuoD6Init[]   =   { 1, 3, 1, 5, 3, 39, 99, 15, 433, 895, 165, 4049, 3183, 4385, 24695, 40009, 67151, 156643, 0 };
            const std::uint32_t dim16851JoeKuoD6Init[]   =   { 1, 1, 7, 3, 29, 9, 15, 27, 109, 1019, 327, 2837, 5297, 12455, 2355, 37703, 122995, 177871, 0 };
            const std::uint32_t dim16852JoeKuoD6Init[]   =   { 1, 1, 5, 15, 29, 5, 121, 117, 31, 155, 1027, 1105, 8057, 8677, 9523, 3019, 98801, 15539, 0 };
            const std::uint32_t dim16853JoeKuoD6Init[]   =   { 1, 3, 7, 3, 1, 1, 37, 67, 471, 317, 1571, 2801, 7383, 4339, 8095, 45685, 95885, 39577, 0 };
            const std::uint32_t dim16854JoeKuoD6Init[]   =   { 1, 3, 7, 13, 17, 13, 91, 79, 49, 321, 1235, 311, 129, 6537, 6643, 25813, 48251, 138823, 0 };
            const std::uint32_t dim16855JoeKuoD6Init[]   =   { 1, 1, 5, 3, 21, 19, 67, 61, 153, 611, 1819, 3755, 5959, 3419, 6117, 1159, 68925, 146199, 0 };
            const std::uint32_t dim16856JoeKuoD6Init[]   =   { 1, 1, 7, 9, 23, 3, 7, 13, 429, 463, 653, 3461, 6337, 4511, 18097, 44837, 99845, 37101, 0 };
            const std::uint32_t dim16857JoeKuoD6Init[]   =   { 1, 3, 5, 13, 9, 5, 123, 199, 83, 409, 1391, 1567, 7327, 8173, 30971, 18241, 7755, 185375, 0 };
            const std::uint32_t dim16858JoeKuoD6Init[]   =   { 1, 3, 1, 7, 19, 51, 51, 23, 85, 923, 1969, 2329, 7343, 12489, 16135, 64783, 117063, 141071, 0 };
            const std::uint32_t dim16859JoeKuoD6Init[]   =   { 1, 3, 1, 3, 23, 29, 5, 77, 207, 351, 367, 2097, 2639, 9255, 21971, 64167, 98069, 81153, 0 };
            const std::uint32_t dim16860JoeKuoD6Init[]   =   { 1, 1, 7, 15, 27, 1, 83, 255, 47, 935, 567, 3573, 3629, 5833, 483, 1001, 9337, 119847, 0 };
            const std::uint32_t dim16861JoeKuoD6Init[]   =   { 1, 3, 7, 11, 31, 53, 25, 35, 463, 51, 401, 3279, 7709, 11265, 17905, 40423, 26277, 43355, 0 };
            const std::uint32_t dim16862JoeKuoD6Init[]   =   { 1, 1, 7, 5, 9, 15, 73, 217, 239, 405, 1651, 2131, 6791, 11241, 21717, 7393, 77251, 28131, 0 };
            const std::uint32_t dim16863JoeKuoD6Init[]   =   { 1, 3, 5, 3, 13, 43, 115, 159, 215, 811, 1349, 2941, 2073, 1821, 6891, 17285, 72027, 137849, 0 };
            const std::uint32_t dim16864JoeKuoD6Init[]   =   { 1, 3, 3, 3, 15, 11, 29, 53, 307, 409, 1069, 3713, 3205, 6185, 2565, 14973, 46149, 162527, 0 };
            const std::uint32_t dim16865JoeKuoD6Init[]   =   { 1, 1, 3, 15, 21, 39, 61, 209, 211, 123, 697, 2285, 859, 2501, 5847, 56449, 106575, 261069, 0 };
            const std::uint32_t dim16866JoeKuoD6Init[]   =   { 1, 3, 3, 5, 25, 21, 39, 131, 189, 747, 1499, 1865, 3369, 9161, 12543, 63155, 70083, 69441, 0 };
            const std::uint32_t dim16867JoeKuoD6Init[]   =   { 1, 3, 1, 15, 31, 43, 127, 57, 169, 109, 979, 1399, 3065, 5865, 16891, 56003, 14319, 94109, 0 };
            const std::uint32_t dim16868JoeKuoD6Init[]   =   { 1, 1, 1, 13, 23, 57, 13, 239, 139, 41, 1959, 429, 209, 543, 21297, 15343, 16521, 52305, 0 };
            const std::uint32_t dim16869JoeKuoD6Init[]   =   { 1, 1, 7, 1, 17, 1, 115, 139, 93, 123, 867, 3257, 8135, 12089, 1503, 33287, 79283, 151419, 0 };
            const std::uint32_t dim16870JoeKuoD6Init[]   =   { 1, 3, 7, 7, 27, 17, 15, 253, 89, 959, 597, 2193, 3505, 13865, 2179, 58711, 114615, 15227, 0 };
            const std::uint32_t dim16871JoeKuoD6Init[]   =   { 1, 3, 7, 5, 1, 5, 105, 241, 361, 229, 1069, 3815, 1409, 4909, 31785, 46555, 123523, 53259, 0 };
            const std::uint32_t dim16872JoeKuoD6Init[]   =   { 1, 1, 5, 5, 15, 49, 13, 195, 467, 285, 1405, 3011, 2069, 8331, 13953, 31107, 46581, 154615, 0 };
            const std::uint32_t dim16873JoeKuoD6Init[]   =   { 1, 3, 5, 7, 21, 23, 17, 17, 345, 369, 1521, 3755, 2165, 15387, 2851, 11115, 60483, 236049, 0 };
            const std::uint32_t dim16874JoeKuoD6Init[]   =   { 1, 3, 3, 1, 5, 41, 53, 239, 127, 237, 609, 927, 3787, 5059, 1865, 52991, 56229, 102093, 0 };
            const std::uint32_t dim16875JoeKuoD6Init[]   =   { 1, 1, 7, 5, 23, 7, 15, 199, 325, 695, 1525, 3435, 3997, 11577, 22985, 57713, 94309, 218433, 0 };
            const std::uint32_t dim16876JoeKuoD6Init[]   =   { 1, 3, 3, 5, 25, 25, 61, 99, 237, 447, 1905, 783, 5239, 11415, 16833, 27815, 115539, 161111, 0 };
            const std::uint32_t dim16877JoeKuoD6Init[]   =   { 1, 1, 5, 9, 31, 49, 55, 199, 159, 751, 849, 1045, 5485, 8883, 8549, 11735, 35983, 161067, 0 };
            const std::uint32_t dim16878JoeKuoD6Init[]   =   { 1, 1, 5, 9, 23, 51, 79, 171, 87, 493, 1911, 3867, 3435, 493, 16639, 64085, 97797, 244959, 0 };
            const std::uint32_t dim16879JoeKuoD6Init[]   =   { 1, 1, 5, 11, 29, 33, 15, 107, 283, 545, 1995, 995, 7181, 3581, 8621, 42391, 117997, 397, 0 };
            const std::uint32_t dim16880JoeKuoD6Init[]   =   { 1, 3, 7, 13, 31, 25, 91, 75, 123, 451, 1023, 375, 4505, 13235, 8913, 34389, 77385, 168659, 0 };
            const std::uint32_t dim16881JoeKuoD6Init[]   =   { 1, 1, 3, 3, 3, 3, 85, 143, 173, 709, 1313, 593, 6931, 14609, 13803, 30305, 109089, 11473, 0 };
            const std::uint32_t dim16882JoeKuoD6Init[]   =   { 1, 3, 7, 5, 25, 45, 25, 223, 407, 597, 83, 2543, 3823, 13959, 9089, 28325, 29237, 57147, 0 };
            const std::uint32_t dim16883JoeKuoD6Init[]   =   { 1, 1, 1, 3, 25, 53, 57, 255, 231, 361, 109, 113, 6091, 13043, 28399, 29111, 57987, 137709, 0 };
            const std::uint32_t dim16884JoeKuoD6Init[]   =   { 1, 1, 1, 5, 11, 25, 53, 141, 275, 237, 1427, 1691, 6043, 8951, 10683, 17477, 117645, 89007, 0 };
            const std::uint32_t dim16885JoeKuoD6Init[]   =   { 1, 3, 3, 13, 7, 23, 73, 213, 285, 667, 1765, 1545, 1401, 12483, 6349, 47205, 25791, 16749, 0 };
            const std::uint32_t dim16886JoeKuoD6Init[]   =   { 1, 1, 1, 15, 31, 45, 105, 249, 385, 607, 723, 745, 7037, 15735, 3637, 29013, 127315, 165507, 0 };
            const std::uint32_t dim16887JoeKuoD6Init[]   =   { 1, 1, 7, 5, 21, 63, 95, 247, 161, 839, 939, 931, 4277, 7363, 8289, 55183, 122413, 152997, 0 };
            const std::uint32_t dim16888JoeKuoD6Init[]   =   { 1, 3, 7, 11, 15, 59, 91, 5, 209, 31, 1581, 979, 6289, 11443, 26641, 20183, 106907, 128647, 0 };
            const std::uint32_t dim16889JoeKuoD6Init[]   =   { 1, 1, 3, 15, 21, 33, 117, 89, 457, 405, 1971, 2211, 4379, 16189, 7933, 39351, 79813, 56373, 0 };
            const std::uint32_t dim16890JoeKuoD6Init[]   =   { 1, 3, 3, 9, 5, 9, 93, 75, 55, 271, 321, 3143, 3893, 2601, 26169, 35179, 43063, 156635, 0 };
            const std::uint32_t dim16891JoeKuoD6Init[]   =   { 1, 3, 3, 11, 29, 37, 95, 249, 221, 965, 423, 1637, 4663, 14839, 16757, 4261, 128453, 165593, 0 };
            const std::uint32_t dim16892JoeKuoD6Init[]   =   { 1, 3, 3, 7, 1, 55, 31, 235, 447, 839, 721, 1125, 6503, 4019, 23351, 37057, 96103, 143805, 0 };
            const std::uint32_t dim16893JoeKuoD6Init[]   =   { 1, 3, 7, 5, 31, 39, 7, 157, 469, 719, 1613, 395, 8133, 9753, 17323, 13849, 45409, 7601, 0 };
            const std::uint32_t dim16894JoeKuoD6Init[]   =   { 1, 3, 7, 7, 31, 37, 89, 215, 453, 659, 605, 3325, 987, 4611, 29667, 23229, 4201, 229675, 0 };
            const std::uint32_t dim16895JoeKuoD6Init[]   =   { 1, 1, 5, 5, 3, 3, 21, 249, 377, 343, 1751, 891, 5275, 14853, 32703, 51001, 6759, 162991, 0 };
            const std::uint32_t dim16896JoeKuoD6Init[]   =   { 1, 3, 1, 13, 11, 21, 55, 17, 495, 481, 1817, 919, 2495, 16367, 3343, 16997, 83437, 127791, 0 };
            const std::uint32_t dim16897JoeKuoD6Init[]   =   { 1, 3, 1, 1, 5, 57, 65, 223, 33, 491, 1953, 1521, 4903, 5007, 14583, 17321, 82231, 206299, 0 };
            const std::uint32_t dim16898JoeKuoD6Init[]   =   { 1, 3, 7, 11, 21, 45, 55, 141, 185, 379, 851, 885, 3385, 10311, 701, 2983, 71045, 171525, 0 };
            const std::uint32_t dim16899JoeKuoD6Init[]   =   { 1, 3, 7, 3, 29, 1, 53, 139, 7, 985, 291, 3949, 1163, 14637, 363, 59679, 121571, 121081, 0 };
            const std::uint32_t dim16900JoeKuoD6Init[]   =   { 1, 3, 7, 1, 31, 1, 111, 19, 421, 917, 1529, 1361, 4461, 12457, 9791, 19985, 77283, 117059, 0 };
            const std::uint32_t dim16901JoeKuoD6Init[]   =   { 1, 3, 1, 5, 7, 55, 93, 243, 477, 193, 1983, 489, 3735, 1391, 24035, 36395, 49101, 175861, 0 };
            const std::uint32_t dim16902JoeKuoD6Init[]   =   { 1, 1, 1, 11, 3, 25, 69, 167, 351, 193, 1299, 617, 7455, 2545, 18359, 9951, 119513, 128139, 0 };
            const std::uint32_t dim16903JoeKuoD6Init[]   =   { 1, 3, 3, 7, 5, 23, 101, 47, 385, 591, 345, 3501, 531, 3277, 28945, 18695, 58587, 87221, 0 };
            const std::uint32_t dim16904JoeKuoD6Init[]   =   { 1, 1, 3, 3, 29, 47, 5, 91, 365, 1, 2015, 323, 1601, 10615, 28975, 60263, 4813, 143351, 0 };
            const std::uint32_t dim16905JoeKuoD6Init[]   =   { 1, 3, 1, 7, 25, 43, 65, 211, 91, 759, 985, 3675, 5701, 4373, 27781, 51949, 40667, 102665, 0 };
            const std::uint32_t dim16906JoeKuoD6Init[]   =   { 1, 3, 3, 5, 3, 43, 91, 33, 247, 593, 849, 1955, 7769, 2307, 2877, 26037, 28907, 211021, 0 };
            const std::uint32_t dim16907JoeKuoD6Init[]   =   { 1, 3, 5, 15, 29, 29, 85, 97, 99, 979, 2033, 1415, 2955, 15733, 5567, 6241, 100195, 89077, 0 };
            const std::uint32_t dim16908JoeKuoD6Init[]   =   { 1, 3, 7, 13, 13, 19, 121, 211, 381, 73, 1131, 1881, 1693, 7873, 27557, 201, 24997, 202471, 0 };
            const std::uint32_t dim16909JoeKuoD6Init[]   =   { 1, 3, 1, 15, 15, 33, 11, 99, 479, 271, 1873, 1117, 3559, 6605, 15995, 44805, 12465, 71933, 0 };
            const std::uint32_t dim16910JoeKuoD6Init[]   =   { 1, 3, 5, 3, 19, 61, 15, 55, 423, 431, 1321, 3345, 1633, 4587, 24909, 54985, 31831, 181083, 0 };
            const std::uint32_t dim16911JoeKuoD6Init[]   =   { 1, 1, 3, 5, 29, 43, 49, 205, 415, 907, 1651, 57, 3043, 10763, 16255, 9567, 59453, 135637, 0 };
            const std::uint32_t dim16912JoeKuoD6Init[]   =   { 1, 3, 3, 1, 17, 11, 29, 33, 293, 203, 1687, 1565, 6131, 5435, 29023, 28425, 102151, 251913, 0 };
            const std::uint32_t dim16913JoeKuoD6Init[]   =   { 1, 1, 5, 7, 9, 9, 43, 191, 269, 681, 607, 3045, 2799, 14919, 8083, 57781, 19345, 49365, 0 };
            const std::uint32_t dim16914JoeKuoD6Init[]   =   { 1, 1, 5, 13, 11, 53, 67, 127, 117, 395, 575, 1651, 2601, 15019, 21413, 34433, 66847, 84159, 0 };
            const std::uint32_t dim16915JoeKuoD6Init[]   =   { 1, 3, 5, 5, 15, 59, 33, 41, 301, 699, 1479, 2285, 1813, 2459, 4775, 53213, 26039, 223155, 0 };
            const std::uint32_t dim16916JoeKuoD6Init[]   =   { 1, 3, 1, 15, 17, 57, 5, 211, 357, 175, 945, 3625, 3943, 12871, 26805, 29305, 8839, 107837, 0 };
            const std::uint32_t dim16917JoeKuoD6Init[]   =   { 1, 3, 5, 15, 21, 41, 105, 229, 265, 777, 2047, 767, 2901, 8873, 7631, 18545, 86697, 252965, 0 };
            const std::uint32_t dim16918JoeKuoD6Init[]   =   { 1, 1, 5, 11, 31, 63, 115, 119, 271, 921, 1221, 3341, 6083, 4293, 28581, 57323, 33889, 112577, 0 };
            const std::uint32_t dim16919JoeKuoD6Init[]   =   { 1, 1, 5, 5, 31, 21, 119, 93, 287, 139, 451, 2535, 3925, 10671, 21279, 55071, 76127, 248203, 0 };
            const std::uint32_t dim16920JoeKuoD6Init[]   =   { 1, 3, 7, 11, 19, 61, 61, 53, 203, 181, 963, 3581, 519, 14679, 7717, 31981, 128709, 197269, 0 };
            const std::uint32_t dim16921JoeKuoD6Init[]   =   { 1, 1, 1, 13, 25, 23, 89, 95, 221, 803, 1433, 3617, 3217, 2033, 7859, 14279, 107239, 5139, 0 };
            const std::uint32_t dim16922JoeKuoD6Init[]   =   { 1, 3, 7, 3, 29, 41, 87, 21, 71, 959, 1149, 2961, 7471, 11665, 16037, 5791, 110155, 35365, 0 };
            const std::uint32_t dim16923JoeKuoD6Init[]   =   { 1, 1, 1, 11, 21, 49, 101, 45, 311, 529, 1301, 1377, 983, 3937, 6967, 8413, 33511, 9617, 0 };
            const std::uint32_t dim16924JoeKuoD6Init[]   =   { 1, 3, 3, 5, 15, 41, 107, 49, 409, 537, 289, 3351, 5307, 16221, 907, 39847, 61579, 161487, 0 };
            const std::uint32_t dim16925JoeKuoD6Init[]   =   { 1, 1, 3, 11, 5, 49, 71, 107, 431, 469, 453, 1367, 7811, 10485, 3861, 62797, 82025, 253785, 0 };
            const std::uint32_t dim16926JoeKuoD6Init[]   =   { 1, 1, 3, 3, 27, 19, 89, 13, 445, 915, 1259, 1423, 3987, 3661, 18183, 18521, 18831, 191447, 0 };
            const std::uint32_t dim16927JoeKuoD6Init[]   =   { 1, 1, 7, 5, 13, 15, 9, 89, 129, 949, 1733, 245, 6815, 8477, 1273, 34737, 33027, 191415, 0 };
            const std::uint32_t dim16928JoeKuoD6Init[]   =   { 1, 1, 7, 15, 25, 63, 83, 195, 319, 987, 1395, 3559, 6287, 5139, 25967, 48711, 58467, 110983, 0 };
            const std::uint32_t dim16929JoeKuoD6Init[]   =   { 1, 1, 3, 9, 5, 3, 35, 171, 15, 883, 915, 2451, 871, 11741, 32715, 33475, 81711, 259157, 0 };
            const std::uint32_t dim16930JoeKuoD6Init[]   =   { 1, 1, 7, 13, 23, 63, 33, 11, 117, 351, 1701, 671, 6753, 5, 9477, 54701, 65507, 242621, 0 };
            const std::uint32_t dim16931JoeKuoD6Init[]   =   { 1, 3, 7, 11, 21, 37, 127, 143, 369, 819, 1369, 93, 7009, 3773, 30153, 30181, 120783, 137857, 0 };
            const std::uint32_t dim16932JoeKuoD6Init[]   =   { 1, 3, 3, 7, 27, 61, 15, 141, 67, 815, 1449, 1129, 4703, 3811, 3067, 61697, 8881, 110957, 0 };
            const std::uint32_t dim16933JoeKuoD6Init[]   =   { 1, 1, 7, 13, 31, 21, 59, 75, 335, 851, 503, 251, 4869, 11789, 30871, 14641, 19319, 156843, 0 };
            const std::uint32_t dim16934JoeKuoD6Init[]   =   { 1, 3, 5, 5, 9, 41, 11, 67, 231, 945, 37, 2925, 5723, 9053, 13477, 59735, 75181, 60335, 0 };
            const std::uint32_t dim16935JoeKuoD6Init[]   =   { 1, 1, 5, 1, 13, 39, 81, 43, 363, 611, 1661, 3833, 7387, 10531, 21319, 55579, 102705, 103009, 0 };
            const std::uint32_t dim16936JoeKuoD6Init[]   =   { 1, 3, 1, 7, 23, 25, 67, 179, 327, 401, 1693, 1453, 4773, 6363, 27169, 49747, 29055, 49145, 0 };
            const std::uint32_t dim16937JoeKuoD6Init[]   =   { 1, 3, 5, 7, 13, 47, 5, 175, 369, 921, 507, 113, 6069, 10919, 11099, 19795, 95819, 52419, 0 };
            const std::uint32_t dim16938JoeKuoD6Init[]   =   { 1, 1, 1, 5, 5, 53, 93, 47, 75, 837, 109, 3691, 6961, 10715, 14269, 63791, 1941, 136899, 0 };
            const std::uint32_t dim16939JoeKuoD6Init[]   =   { 1, 1, 1, 3, 1, 63, 57, 117, 157, 327, 879, 2411, 3987, 15393, 8503, 29829, 77795, 121307, 0 };
            const std::uint32_t dim16940JoeKuoD6Init[]   =   { 1, 3, 5, 1, 25, 5, 47, 45, 433, 121, 607, 1233, 6433, 3031, 16369, 58589, 79357, 151353, 0 };
            const std::uint32_t dim16941JoeKuoD6Init[]   =   { 1, 1, 1, 1, 9, 15, 77, 163, 225, 445, 1479, 1267, 2571, 2661, 21489, 5433, 123969, 191967, 0 };
            const std::uint32_t dim16942JoeKuoD6Init[]   =   { 1, 1, 7, 1, 9, 49, 17, 19, 449, 113, 1289, 2335, 3309, 2595, 17819, 18481, 86605, 125911, 0 };
            const std::uint32_t dim16943JoeKuoD6Init[]   =   { 1, 1, 5, 11, 11, 23, 65, 147, 257, 625, 1901, 913, 5711, 8159, 16237, 25133, 100059, 11395, 0 };
            const std::uint32_t dim16944JoeKuoD6Init[]   =   { 1, 3, 7, 13, 5, 33, 89, 189, 171, 185, 751, 2915, 5025, 15981, 14853, 12229, 52829, 59953, 0 };
            const std::uint32_t dim16945JoeKuoD6Init[]   =   { 1, 3, 1, 13, 3, 37, 15, 87, 463, 655, 1927, 2705, 1885, 14801, 3491, 52835, 81761, 90273, 0 };
            const std::uint32_t dim16946JoeKuoD6Init[]   =   { 1, 1, 7, 3, 5, 15, 29, 255, 199, 225, 647, 3215, 6795, 3821, 31763, 31059, 65495, 89981, 0 };
            const std::uint32_t dim16947JoeKuoD6Init[]   =   { 1, 1, 7, 7, 9, 25, 11, 85, 111, 283, 507, 2077, 2993, 5415, 31785, 16495, 82361, 122105, 0 };
            const std::uint32_t dim16948JoeKuoD6Init[]   =   { 1, 1, 3, 11, 27, 21, 127, 175, 397, 419, 1115, 2285, 223, 3881, 4187, 53759, 115035, 181647, 0 };
            const std::uint32_t dim16949JoeKuoD6Init[]   =   { 1, 3, 7, 11, 27, 31, 29, 233, 137, 827, 1009, 3879, 7595, 12989, 27655, 8517, 28083, 214985, 0 };
            const std::uint32_t dim16950JoeKuoD6Init[]   =   { 1, 3, 5, 9, 25, 23, 85, 191, 475, 445, 621, 1341, 4045, 4299, 24933, 32765, 20219, 86949, 0 };
            const std::uint32_t dim16951JoeKuoD6Init[]   =   { 1, 3, 1, 5, 25, 35, 121, 33, 199, 405, 163, 3487, 1087, 743, 21989, 47273, 49221, 124831, 0 };
            const std::uint32_t dim16952JoeKuoD6Init[]   =   { 1, 1, 5, 1, 7, 3, 91, 15, 335, 351, 1311, 777, 4303, 7203, 19465, 9135, 32251, 69805, 0 };
            const std::uint32_t dim16953JoeKuoD6Init[]   =   { 1, 3, 3, 7, 23, 55, 73, 77, 189, 801, 1877, 1901, 2675, 1015, 3041, 35925, 125903, 126227, 0 };
            const std::uint32_t dim16954JoeKuoD6Init[]   =   { 1, 3, 3, 1, 1, 23, 105, 75, 435, 743, 651, 1045, 579, 13637, 14821, 62683, 95229, 156475, 0 };
            const std::uint32_t dim16955JoeKuoD6Init[]   =   { 1, 3, 3, 5, 1, 53, 89, 239, 439, 195, 189, 731, 1805, 15123, 23315, 47737, 29167, 112081, 0 };
            const std::uint32_t dim16956JoeKuoD6Init[]   =   { 1, 1, 5, 7, 31, 11, 119, 191, 155, 61, 247, 915, 5813, 995, 20093, 23379, 118969, 65001, 0 };
            const std::uint32_t dim16957JoeKuoD6Init[]   =   { 1, 3, 7, 3, 1, 61, 45, 85, 295, 269, 539, 1787, 6639, 11093, 11303, 18509, 77637, 200743, 0 };
            const std::uint32_t dim16958JoeKuoD6Init[]   =   { 1, 3, 1, 1, 13, 17, 75, 51, 199, 151, 1529, 1443, 4983, 6723, 6071, 34711, 39159, 5441, 0 };
            const std::uint32_t dim16959JoeKuoD6Init[]   =   { 1, 3, 3, 3, 31, 15, 91, 125, 261, 683, 1769, 1697, 2761, 11373, 13607, 24933, 19079, 55497, 0 };
            const std::uint32_t dim16960JoeKuoD6Init[]   =   { 1, 1, 1, 15, 21, 49, 117, 99, 29, 969, 463, 3869, 1251, 8815, 16443, 46861, 82839, 233325, 0 };
            const std::uint32_t dim16961JoeKuoD6Init[]   =   { 1, 3, 5, 3, 27, 39, 89, 225, 161, 63, 61, 2875, 4037, 10413, 5067, 27893, 78825, 250207, 0 };
            const std::uint32_t dim16962JoeKuoD6Init[]   =   { 1, 1, 1, 9, 13, 49, 93, 11, 23, 25, 2003, 57, 3065, 11241, 13935, 2969, 44235, 39287, 0 };
            const std::uint32_t dim16963JoeKuoD6Init[]   =   { 1, 3, 3, 9, 21, 5, 55, 247, 193, 523, 575, 1235, 3277, 5253, 5293, 7919, 7573, 168809, 0 };
            const std::uint32_t dim16964JoeKuoD6Init[]   =   { 1, 3, 1, 13, 29, 39, 43, 21, 511, 205, 303, 703, 3861, 2467, 3909, 31597, 51081, 9863, 0 };
            const std::uint32_t dim16965JoeKuoD6Init[]   =   { 1, 3, 7, 1, 25, 55, 11, 131, 5, 49, 371, 1683, 1907, 5661, 1015, 15171, 101477, 11221, 0 };
            const std::uint32_t dim16966JoeKuoD6Init[]   =   { 1, 3, 5, 5, 9, 15, 93, 245, 357, 703, 701, 3675, 4527, 9225, 16137, 55433, 81887, 99153, 0 };
            const std::uint32_t dim16967JoeKuoD6Init[]   =   { 1, 1, 3, 3, 11, 1, 39, 251, 291, 599, 643, 231, 4031, 7055, 99, 14039, 81811, 184251, 0 };
            const std::uint32_t dim16968JoeKuoD6Init[]   =   { 1, 3, 5, 13, 29, 55, 11, 117, 325, 401, 2013, 3235, 995, 9255, 2741, 8211, 71451, 180619, 0 };
            const std::uint32_t dim16969JoeKuoD6Init[]   =   { 1, 1, 1, 5, 31, 41, 41, 175, 247, 3, 739, 1391, 3311, 5975, 16921, 4291, 75065, 161745, 0 };
            const std::uint32_t dim16970JoeKuoD6Init[]   =   { 1, 1, 7, 13, 23, 19, 13, 149, 203, 351, 2033, 1867, 3871, 14437, 3793, 17399, 99577, 171605, 0 };
            const std::uint32_t dim16971JoeKuoD6Init[]   =   { 1, 1, 5, 11, 7, 9, 1, 195, 261, 977, 315, 3771, 1179, 16281, 20747, 56309, 108609, 209205, 0 };
            const std::uint32_t dim16972JoeKuoD6Init[]   =   { 1, 3, 3, 5, 19, 15, 123, 153, 325, 601, 393, 753, 93, 4803, 24343, 42645, 128209, 45773, 0 };
            const std::uint32_t dim16973JoeKuoD6Init[]   =   { 1, 3, 1, 13, 3, 29, 97, 95, 115, 539, 155, 2789, 1277, 13127, 20383, 52807, 97295, 54589, 0 };
            const std::uint32_t dim16974JoeKuoD6Init[]   =   { 1, 1, 1, 3, 25, 59, 27, 149, 365, 317, 773, 3379, 5931, 14637, 19881, 37283, 118027, 21557, 0 };
            const std::uint32_t dim16975JoeKuoD6Init[]   =   { 1, 3, 5, 3, 25, 11, 101, 221, 199, 689, 515, 2255, 6107, 6259, 2853, 19039, 117089, 107181, 0 };
            const std::uint32_t dim16976JoeKuoD6Init[]   =   { 1, 3, 5, 7, 29, 63, 19, 113, 249, 147, 737, 3959, 209, 7001, 24263, 20443, 99923, 145709, 0 };
            const std::uint32_t dim16977JoeKuoD6Init[]   =   { 1, 1, 5, 9, 25, 37, 69, 41, 87, 369, 1913, 2255, 7581, 5301, 25751, 24981, 1183, 171969, 0 };
            const std::uint32_t dim16978JoeKuoD6Init[]   =   { 1, 3, 3, 1, 9, 25, 55, 5, 267, 295, 43, 819, 4569, 7065, 31527, 57811, 48721, 107707, 0 };
            const std::uint32_t dim16979JoeKuoD6Init[]   =   { 1, 1, 7, 9, 19, 19, 1, 199, 371, 1003, 597, 2097, 4071, 6185, 879, 13545, 30033, 120313, 0 };
            const std::uint32_t dim16980JoeKuoD6Init[]   =   { 1, 1, 1, 7, 9, 11, 51, 155, 309, 493, 899, 3121, 2085, 10541, 21979, 4725, 70381, 69643, 0 };
            const std::uint32_t dim16981JoeKuoD6Init[]   =   { 1, 1, 1, 1, 13, 45, 123, 119, 459, 295, 1005, 4093, 393, 11063, 27235, 28209, 1671, 215619, 0 };
            const std::uint32_t dim16982JoeKuoD6Init[]   =   { 1, 1, 7, 13, 19, 25, 125, 255, 509, 529, 1577, 3221, 4051, 7697, 2065, 42597, 86295, 131719, 0 };
            const std::uint32_t dim16983JoeKuoD6Init[]   =   { 1, 3, 3, 9, 19, 13, 21, 199, 97, 949, 1297, 379, 1801, 13247, 22563, 49517, 22757, 87371, 0 };
            const std::uint32_t dim16984JoeKuoD6Init[]   =   { 1, 3, 3, 1, 17, 63, 109, 175, 301, 565, 1181, 465, 3457, 7175, 21225, 33149, 122169, 148043, 0 };
            const std::uint32_t dim16985JoeKuoD6Init[]   =   { 1, 1, 1, 1, 5, 7, 21, 251, 53, 369, 955, 583, 4703, 9729, 15853, 55701, 29317, 27, 0 };
            const std::uint32_t dim16986JoeKuoD6Init[]   =   { 1, 3, 3, 1, 31, 3, 53, 57, 231, 441, 109, 149, 8107, 2303, 29729, 42279, 46909, 209877, 0 };
            const std::uint32_t dim16987JoeKuoD6Init[]   =   { 1, 1, 1, 11, 23, 57, 63, 189, 259, 657, 1653, 1155, 2885, 3317, 22559, 3145, 19151, 172507, 0 };
            const std::uint32_t dim16988JoeKuoD6Init[]   =   { 1, 3, 7, 5, 31, 63, 103, 147, 287, 685, 1197, 99, 4907, 12335, 12001, 20303, 75503, 231259, 0 };
            const std::uint32_t dim16989JoeKuoD6Init[]   =   { 1, 3, 3, 13, 15, 33, 63, 11, 99, 299, 97, 2669, 3635, 9969, 1525, 36555, 85215, 86915, 0 };
            const std::uint32_t dim16990JoeKuoD6Init[]   =   { 1, 3, 7, 5, 25, 47, 25, 61, 227, 939, 1719, 245, 2389, 14663, 30671, 22667, 38873, 245509, 0 };
            const std::uint32_t dim16991JoeKuoD6Init[]   =   { 1, 1, 3, 5, 25, 15, 105, 203, 57, 961, 1941, 1241, 3163, 6203, 19631, 10383, 19235, 57569, 0 };
            const std::uint32_t dim16992JoeKuoD6Init[]   =   { 1, 1, 3, 9, 1, 35, 41, 3, 449, 87, 641, 269, 1529, 14559, 16571, 4863, 21625, 921, 0 };
            const std::uint32_t dim16993JoeKuoD6Init[]   =   { 1, 1, 7, 11, 25, 53, 85, 209, 181, 417, 1657, 2117, 4581, 7069, 15533, 64475, 82381, 146943, 0 };
            const std::uint32_t dim16994JoeKuoD6Init[]   =   { 1, 3, 1, 7, 17, 53, 5, 199, 347, 887, 1041, 595, 1843, 10931, 30559, 42849, 73723, 220473, 0 };
            const std::uint32_t dim16995JoeKuoD6Init[]   =   { 1, 3, 7, 7, 21, 53, 105, 21, 141, 575, 1965, 2187, 7293, 13675, 2471, 1259, 42485, 62911, 0 };
            const std::uint32_t dim16996JoeKuoD6Init[]   =   { 1, 1, 3, 9, 5, 27, 21, 101, 101, 71, 1215, 3235, 2451, 14835, 27817, 30079, 124301, 253691, 0 };
            const std::uint32_t dim16997JoeKuoD6Init[]   =   { 1, 1, 7, 1, 11, 37, 105, 127, 115, 157, 279, 2425, 2139, 131, 22717, 40803, 74867, 86021, 0 };
            const std::uint32_t dim16998JoeKuoD6Init[]   =   { 1, 1, 1, 7, 11, 59, 95, 61, 255, 523, 501, 2895, 7531, 8151, 18393, 42069, 120809, 236537, 0 };
            const std::uint32_t dim16999JoeKuoD6Init[]   =   { 1, 1, 1, 7, 17, 23, 31, 59, 377, 187, 873, 1565, 3459, 2975, 11633, 13247, 13095, 193803, 0 };
            const std::uint32_t dim17000JoeKuoD6Init[]   =   { 1, 3, 7, 1, 25, 3, 85, 5, 485, 451, 1385, 1663, 4825, 14019, 29437, 33717, 105343, 161335, 0 };
            const std::uint32_t dim17001JoeKuoD6Init[]   =   { 1, 1, 1, 3, 27, 43, 71, 167, 425, 579, 1739, 3557, 7403, 2023, 6533, 61177, 119273, 85229, 0 };
            const std::uint32_t dim17002JoeKuoD6Init[]   =   { 1, 1, 7, 3, 31, 37, 19, 213, 373, 505, 97, 3669, 7005, 2205, 26519, 61999, 18395, 25967, 0 };
            const std::uint32_t dim17003JoeKuoD6Init[]   =   { 1, 3, 3, 7, 29, 17, 9, 137, 265, 875, 887, 3029, 3295, 11619, 8357, 46241, 23543, 43191, 0 };
            const std::uint32_t dim17004JoeKuoD6Init[]   =   { 1, 1, 5, 1, 25, 43, 33, 133, 65, 7, 1581, 3577, 5997, 6129, 30649, 18923, 56459, 227869, 0 };
            const std::uint32_t dim17005JoeKuoD6Init[]   =   { 1, 1, 5, 13, 27, 45, 27, 111, 429, 565, 1449, 1475, 6613, 4469, 16083, 42349, 66843, 214875, 0 };
            const std::uint32_t dim17006JoeKuoD6Init[]   =   { 1, 3, 1, 1, 21, 21, 107, 7, 15, 675, 233, 4021, 1097, 1393, 6445, 3323, 102435, 249355, 0 };
            const std::uint32_t dim17007JoeKuoD6Init[]   =   { 1, 1, 5, 15, 17, 51, 99, 249, 437, 667, 1921, 2371, 3813, 10543, 19, 39079, 116825, 242821, 0 };
            const std::uint32_t dim17008JoeKuoD6Init[]   =   { 1, 1, 1, 1, 7, 15, 27, 29, 161, 37, 1847, 287, 4379, 1399, 24547, 60361, 68131, 232883, 0 };
            const std::uint32_t dim17009JoeKuoD6Init[]   =   { 1, 1, 3, 9, 17, 21, 41, 169, 61, 771, 241, 1435, 4151, 1789, 12195, 27239, 62371, 165145, 0 };
            const std::uint32_t dim17010JoeKuoD6Init[]   =   { 1, 3, 5, 15, 31, 19, 127, 181, 463, 183, 749, 253, 2403, 1363, 3965, 7953, 124025, 226691, 0 };
            const std::uint32_t dim17011JoeKuoD6Init[]   =   { 1, 1, 3, 7, 17, 57, 85, 89, 17, 33, 819, 2191, 1525, 15651, 23483, 26027, 86379, 40191, 0 };
            const std::uint32_t dim17012JoeKuoD6Init[]   =   { 1, 1, 5, 1, 9, 45, 65, 65, 359, 5, 531, 2581, 6313, 13219, 6005, 36215, 16275, 208253, 0 };
            const std::uint32_t dim17013JoeKuoD6Init[]   =   { 1, 3, 1, 1, 23, 15, 51, 43, 85, 461, 773, 219, 2681, 3377, 9797, 54469, 112871, 231533, 0 };
            const std::uint32_t dim17014JoeKuoD6Init[]   =   { 1, 3, 7, 7, 15, 9, 97, 115, 301, 493, 1085, 2021, 2305, 15003, 11381, 9339, 63015, 179115, 0 };
            const std::uint32_t dim17015JoeKuoD6Init[]   =   { 1, 3, 5, 3, 3, 61, 111, 103, 283, 7, 143, 353, 7815, 7901, 25795, 7577, 92991, 228315, 0 };
            const std::uint32_t dim17016JoeKuoD6Init[]   =   { 1, 1, 7, 13, 29, 3, 53, 105, 83, 531, 497, 729, 1375, 7063, 18655, 35219, 9671, 102913, 0 };
            const std::uint32_t dim17017JoeKuoD6Init[]   =   { 1, 1, 5, 15, 11, 7, 65, 31, 15, 921, 743, 1469, 5669, 5437, 20019, 28123, 5717, 6181, 0 };
            const std::uint32_t dim17018JoeKuoD6Init[]   =   { 1, 3, 3, 15, 19, 1, 3, 183, 315, 595, 1033, 3259, 7815, 8281, 32103, 8699, 59149, 56657, 0 };
            const std::uint32_t dim17019JoeKuoD6Init[]   =   { 1, 1, 1, 7, 9, 1, 87, 81, 267, 637, 1617, 2113, 487, 23, 11213, 29211, 92715, 177767, 0 };
            const std::uint32_t dim17020JoeKuoD6Init[]   =   { 1, 3, 5, 13, 29, 37, 31, 55, 343, 759, 813, 2945, 7189, 4821, 30661, 38373, 2793, 98683, 0 };
            const std::uint32_t dim17021JoeKuoD6Init[]   =   { 1, 3, 5, 7, 9, 43, 113, 145, 103, 303, 1065, 3781, 3527, 9449, 17355, 38301, 74859, 30735, 0 };
            const std::uint32_t dim17022JoeKuoD6Init[]   =   { 1, 1, 1, 1, 3, 53, 53, 27, 119, 701, 1777, 3959, 5911, 8473, 24997, 17557, 11593, 201381, 0 };
            const std::uint32_t dim17023JoeKuoD6Init[]   =   { 1, 3, 3, 9, 3, 3, 107, 115, 423, 531, 735, 931, 8053, 4661, 1919, 29551, 62515, 210255, 0 };
            const std::uint32_t dim17024JoeKuoD6Init[]   =   { 1, 1, 3, 9, 21, 21, 117, 67, 301, 49, 2025, 781, 7951, 15719, 27287, 34551, 115241, 243981, 0 };
            const std::uint32_t dim17025JoeKuoD6Init[]   =   { 1, 1, 7, 9, 9, 25, 87, 229, 375, 353, 445, 3169, 1865, 7305, 11175, 47081, 28609, 107301, 0 };
            const std::uint32_t dim17026JoeKuoD6Init[]   =   { 1, 3, 3, 11, 7, 31, 19, 177, 17, 535, 1353, 2587, 7723, 8039, 13607, 5017, 104937, 207761, 0 };
            const std::uint32_t dim17027JoeKuoD6Init[]   =   { 1, 1, 5, 3, 11, 27, 29, 193, 235, 435, 1451, 3487, 5749, 4825, 9487, 53933, 92061, 223305, 0 };
            const std::uint32_t dim17028JoeKuoD6Init[]   =   { 1, 3, 3, 3, 5, 5, 99, 237, 91, 945, 1373, 3303, 3079, 5345, 6843, 34131, 62851, 259561, 0 };
            const std::uint32_t dim17029JoeKuoD6Init[]   =   { 1, 1, 3, 7, 7, 25, 11, 27, 329, 37, 307, 771, 659, 13045, 25767, 18887, 54407, 251313, 0 };
            const std::uint32_t dim17030JoeKuoD6Init[]   =   { 1, 1, 1, 11, 29, 59, 37, 121, 281, 55, 495, 159, 3925, 4447, 14825, 24831, 103147, 211951, 0 };
            const std::uint32_t dim17031JoeKuoD6Init[]   =   { 1, 3, 3, 7, 23, 31, 59, 67, 303, 383, 1179, 2347, 4001, 14797, 14579, 55365, 112239, 65309, 0 };
            const std::uint32_t dim17032JoeKuoD6Init[]   =   { 1, 3, 3, 9, 15, 17, 61, 123, 339, 319, 765, 1517, 1269, 69, 9065, 32347, 21377, 38449, 0 };
            const std::uint32_t dim17033JoeKuoD6Init[]   =   { 1, 3, 5, 3, 7, 35, 71, 63, 251, 457, 351, 385, 4041, 11489, 14511, 11875, 45307, 205041, 0 };
            const std::uint32_t dim17034JoeKuoD6Init[]   =   { 1, 1, 1, 7, 1, 25, 115, 195, 41, 1001, 835, 767, 7991, 7475, 22397, 36899, 77255, 194827, 0 };
            const std::uint32_t dim17035JoeKuoD6Init[]   =   { 1, 3, 3, 11, 7, 49, 45, 13, 373, 167, 741, 2569, 3781, 1131, 2909, 40387, 77877, 201859, 0 };
            const std::uint32_t dim17036JoeKuoD6Init[]   =   { 1, 3, 5, 3, 17, 11, 123, 137, 65, 835, 1385, 1157, 7387, 12301, 5759, 13137, 30595, 50923, 0 };
            const std::uint32_t dim17037JoeKuoD6Init[]   =   { 1, 1, 5, 7, 1, 55, 57, 97, 377, 223, 115, 2515, 2565, 14965, 10485, 23957, 108239, 160707, 0 };
            const std::uint32_t dim17038JoeKuoD6Init[]   =   { 1, 3, 1, 9, 15, 17, 81, 65, 387, 275, 997, 1485, 4129, 999, 4915, 55867, 103799, 191829, 0 };
            const std::uint32_t dim17039JoeKuoD6Init[]   =   { 1, 1, 1, 5, 15, 5, 35, 167, 249, 419, 267, 503, 469, 3163, 19939, 65501, 88573, 11621, 0 };
            const std::uint32_t dim17040JoeKuoD6Init[]   =   { 1, 3, 3, 13, 7, 9, 101, 125, 371, 97, 1855, 1755, 4103, 12283, 18655, 5965, 17743, 254779, 0 };
            const std::uint32_t dim17041JoeKuoD6Init[]   =   { 1, 1, 3, 7, 13, 15, 119, 227, 451, 863, 1005, 491, 6515, 717, 12783, 14161, 106249, 185297, 0 };
            const std::uint32_t dim17042JoeKuoD6Init[]   =   { 1, 1, 7, 13, 17, 23, 95, 143, 133, 219, 897, 2291, 7469, 923, 22323, 60583, 2457, 197231, 0 };
            const std::uint32_t dim17043JoeKuoD6Init[]   =   { 1, 1, 1, 11, 3, 25, 115, 187, 319, 999, 867, 1725, 6969, 239, 2527, 55283, 91099, 252153, 0 };
            const std::uint32_t dim17044JoeKuoD6Init[]   =   { 1, 1, 7, 9, 3, 37, 107, 25, 425, 95, 631, 2831, 1265, 11509, 18865, 39791, 22281, 220517, 0 };
            const std::uint32_t dim17045JoeKuoD6Init[]   =   { 1, 3, 5, 1, 1, 47, 121, 173, 489, 241, 3, 3707, 7081, 5341, 23143, 7321, 30605, 191665, 0 };
            const std::uint32_t dim17046JoeKuoD6Init[]   =   { 1, 1, 7, 7, 7, 27, 23, 43, 145, 11, 1155, 691, 6993, 9509, 5991, 40705, 58215, 202915, 0 };
            const std::uint32_t dim17047JoeKuoD6Init[]   =   { 1, 3, 5, 1, 31, 1, 7, 189, 379, 431, 417, 3843, 3885, 3263, 16333, 58123, 68307, 33795, 0 };
            const std::uint32_t dim17048JoeKuoD6Init[]   =   { 1, 1, 5, 5, 19, 27, 19, 217, 509, 535, 287, 1637, 4829, 2665, 15393, 35185, 125335, 10909, 0 };
            const std::uint32_t dim17049JoeKuoD6Init[]   =   { 1, 3, 5, 7, 25, 13, 67, 243, 255, 1021, 1203, 821, 7811, 149, 26731, 12913, 18171, 101385, 0 };
            const std::uint32_t dim17050JoeKuoD6Init[]   =   { 1, 1, 1, 3, 25, 61, 59, 207, 449, 789, 1831, 1731, 513, 10099, 291, 1963, 100233, 21847, 0 };
            const std::uint32_t dim17051JoeKuoD6Init[]   =   { 1, 1, 7, 1, 27, 19, 45, 81, 479, 31, 707, 2669, 3589, 15411, 12089, 38235, 60897, 135451, 0 };
            const std::uint32_t dim17052JoeKuoD6Init[]   =   { 1, 3, 5, 15, 11, 3, 113, 169, 171, 21, 1291, 2031, 2023, 5783, 6137, 54637, 50247, 233753, 0 };
            const std::uint32_t dim17053JoeKuoD6Init[]   =   { 1, 1, 5, 1, 11, 13, 73, 97, 269, 801, 1015, 1329, 1779, 15225, 24251, 35191, 8619, 130993, 0 };
            const std::uint32_t dim17054JoeKuoD6Init[]   =   { 1, 1, 7, 9, 9, 19, 35, 255, 505, 513, 547, 405, 3065, 4965, 30877, 50091, 81319, 29273, 0 };
            const std::uint32_t dim17055JoeKuoD6Init[]   =   { 1, 1, 1, 9, 7, 61, 45, 75, 343, 911, 1683, 453, 1225, 10939, 19901, 63685, 123507, 252027, 0 };
            const std::uint32_t dim17056JoeKuoD6Init[]   =   { 1, 1, 5, 11, 21, 55, 37, 161, 143, 463, 1937, 3349, 2953, 14827, 7893, 26581, 128459, 72325, 0 };
            const std::uint32_t dim17057JoeKuoD6Init[]   =   { 1, 3, 5, 9, 31, 57, 115, 77, 225, 859, 621, 731, 5677, 759, 20773, 52285, 65555, 4303, 0 };
            const std::uint32_t dim17058JoeKuoD6Init[]   =   { 1, 1, 3, 15, 23, 15, 49, 171, 137, 449, 855, 565, 5579, 5957, 13643, 8979, 90327, 116349, 0 };
            const std::uint32_t dim17059JoeKuoD6Init[]   =   { 1, 1, 3, 5, 9, 13, 27, 43, 391, 595, 731, 101, 7121, 13555, 29181, 38273, 42309, 175297, 0 };
            const std::uint32_t dim17060JoeKuoD6Init[]   =   { 1, 1, 3, 11, 3, 59, 17, 143, 251, 47, 1391, 1297, 23, 15871, 13153, 44081, 65423, 54875, 0 };
            const std::uint32_t dim17061JoeKuoD6Init[]   =   { 1, 3, 7, 11, 25, 43, 3, 163, 273, 277, 755, 2743, 5909, 10841, 31331, 64131, 13945, 91557, 0 };
            const std::uint32_t dim17062JoeKuoD6Init[]   =   { 1, 3, 1, 13, 31, 35, 5, 165, 417, 623, 1083, 1221, 1051, 8917, 6725, 11385, 76315, 119837, 0 };
            const std::uint32_t dim17063JoeKuoD6Init[]   =   { 1, 1, 5, 3, 21, 53, 47, 247, 471, 877, 709, 2425, 3, 1963, 24331, 52151, 98859, 119033, 0 };
            const std::uint32_t dim17064JoeKuoD6Init[]   =   { 1, 1, 7, 3, 29, 29, 43, 59, 503, 891, 763, 2927, 1613, 9091, 10393, 36003, 61147, 3437, 0 };
            const std::uint32_t dim17065JoeKuoD6Init[]   =   { 1, 1, 5, 15, 27, 59, 73, 163, 425, 855, 349, 3451, 5779, 10523, 9103, 46477, 129873, 39091, 0 };
            const std::uint32_t dim17066JoeKuoD6Init[]   =   { 1, 3, 7, 15, 25, 45, 77, 171, 467, 1017, 1553, 1877, 5507, 3909, 12157, 60441, 98261, 37781, 0 };
            const std::uint32_t dim17067JoeKuoD6Init[]   =   { 1, 1, 7, 13, 13, 39, 99, 51, 197, 327, 1101, 2679, 8025, 11853, 7763, 62537, 96999, 88673, 0 };
            const std::uint32_t dim17068JoeKuoD6Init[]   =   { 1, 3, 1, 11, 5, 61, 29, 219, 471, 387, 319, 433, 5383, 3933, 27603, 61171, 104711, 233295, 0 };
            const std::uint32_t dim17069JoeKuoD6Init[]   =   { 1, 3, 5, 11, 15, 23, 91, 119, 207, 717, 1333, 783, 437, 13073, 10923, 27049, 87233, 174899, 0 };
            const std::uint32_t dim17070JoeKuoD6Init[]   =   { 1, 1, 1, 1, 13, 19, 109, 139, 183, 299, 1023, 3265, 5153, 6307, 27879, 55311, 95201, 19481, 0 };
            const std::uint32_t dim17071JoeKuoD6Init[]   =   { 1, 1, 5, 11, 13, 61, 81, 115, 53, 483, 693, 3527, 5033, 8527, 31345, 46155, 12403, 126815, 0 };
            const std::uint32_t dim17072JoeKuoD6Init[]   =   { 1, 3, 7, 3, 27, 7, 73, 227, 269, 683, 719, 763, 5417, 9523, 13625, 6945, 116225, 223093, 0 };
            const std::uint32_t dim17073JoeKuoD6Init[]   =   { 1, 3, 5, 9, 21, 51, 111, 157, 451, 247, 1375, 1631, 2783, 3371, 22713, 34153, 41949, 141351, 0 };
            const std::uint32_t dim17074JoeKuoD6Init[]   =   { 1, 1, 5, 1, 21, 19, 45, 69, 41, 453, 523, 3163, 7351, 4467, 18865, 35371, 129577, 78039, 0 };
            const std::uint32_t dim17075JoeKuoD6Init[]   =   { 1, 3, 5, 1, 29, 33, 13, 19, 341, 321, 117, 1187, 7021, 5785, 5553, 58055, 113557, 46957, 0 };
            const std::uint32_t dim17076JoeKuoD6Init[]   =   { 1, 1, 5, 5, 13, 59, 47, 59, 69, 125, 1491, 2813, 5005, 5973, 3145, 27579, 7763, 129949, 0 };
            const std::uint32_t dim17077JoeKuoD6Init[]   =   { 1, 1, 7, 11, 11, 7, 117, 235, 407, 749, 1925, 1735, 4499, 13027, 19355, 1981, 105657, 242853, 0 };
            const std::uint32_t dim17078JoeKuoD6Init[]   =   { 1, 1, 7, 1, 15, 19, 5, 247, 203, 707, 809, 2085, 5801, 9947, 569, 9883, 109861, 156751, 0 };
            const std::uint32_t dim17079JoeKuoD6Init[]   =   { 1, 3, 5, 3, 13, 59, 67, 181, 261, 873, 1589, 2249, 7213, 14625, 28403, 41101, 73439, 46873, 0 };
            const std::uint32_t dim17080JoeKuoD6Init[]   =   { 1, 1, 5, 7, 3, 63, 79, 115, 123, 485, 1373, 3781, 4315, 4627, 29003, 64101, 67521, 184053, 0 };
            const std::uint32_t dim17081JoeKuoD6Init[]   =   { 1, 1, 3, 9, 11, 57, 93, 243, 505, 189, 449, 643, 5267, 7447, 32265, 44095, 63015, 36905, 0 };
            const std::uint32_t dim17082JoeKuoD6Init[]   =   { 1, 3, 7, 13, 25, 59, 31, 93, 401, 41, 183, 759, 2473, 8705, 8211, 13543, 59749, 235217, 0 };
            const std::uint32_t dim17083JoeKuoD6Init[]   =   { 1, 1, 5, 5, 29, 3, 65, 133, 325, 239, 649, 3225, 4095, 11691, 4479, 15419, 100551, 261981, 0 };
            const std::uint32_t dim17084JoeKuoD6Init[]   =   { 1, 3, 7, 1, 17, 11, 63, 97, 431, 161, 1437, 3679, 1643, 10583, 20731, 45919, 94093, 147067, 0 };
            const std::uint32_t dim17085JoeKuoD6Init[]   =   { 1, 1, 7, 1, 25, 13, 63, 155, 221, 345, 189, 1199, 5465, 14767, 26263, 54093, 23697, 71231, 0 };
            const std::uint32_t dim17086JoeKuoD6Init[]   =   { 1, 1, 7, 3, 3, 19, 23, 75, 381, 339, 1989, 1137, 6449, 1437, 32279, 17195, 117423, 259311, 0 };
            const std::uint32_t dim17087JoeKuoD6Init[]   =   { 1, 3, 5, 3, 27, 45, 117, 113, 129, 585, 2019, 807, 5573, 7407, 9957, 8741, 52333, 115607, 0 };
            const std::uint32_t dim17088JoeKuoD6Init[]   =   { 1, 1, 3, 7, 9, 5, 77, 9, 417, 725, 429, 1657, 5445, 1901, 28745, 26807, 111743, 169739, 0 };
            const std::uint32_t dim17089JoeKuoD6Init[]   =   { 1, 3, 1, 5, 7, 63, 51, 183, 117, 383, 435, 755, 7849, 5997, 32697, 5789, 5189, 80645, 0 };
            const std::uint32_t dim17090JoeKuoD6Init[]   =   { 1, 1, 3, 15, 5, 47, 105, 175, 41, 275, 1441, 3183, 3651, 9561, 5749, 20431, 45969, 59473, 0 };
            const std::uint32_t dim17091JoeKuoD6Init[]   =   { 1, 1, 1, 11, 13, 35, 19, 129, 125, 35, 339, 3099, 5337, 15605, 10213, 1171, 61869, 216681, 0 };
            const std::uint32_t dim17092JoeKuoD6Init[]   =   { 1, 3, 7, 1, 7, 25, 23, 9, 431, 73, 1803, 3969, 7853, 12845, 8075, 14553, 124825, 50561, 0 };
            const std::uint32_t dim17093JoeKuoD6Init[]   =   { 1, 1, 1, 7, 29, 21, 79, 247, 313, 143, 59, 2689, 5643, 827, 26597, 56423, 107903, 180809, 0 };
            const std::uint32_t dim17094JoeKuoD6Init[]   =   { 1, 3, 7, 1, 3, 3, 25, 39, 269, 529, 67, 3703, 2163, 12417, 6307, 29883, 40303, 171831, 0 };
            const std::uint32_t dim17095JoeKuoD6Init[]   =   { 1, 3, 7, 13, 1, 19, 71, 245, 267, 105, 749, 1203, 7953, 1881, 9273, 4629, 71793, 195393, 0 };
            const std::uint32_t dim17096JoeKuoD6Init[]   =   { 1, 1, 1, 15, 3, 49, 53, 145, 47, 959, 1107, 1361, 4517, 16055, 32119, 58433, 110123, 81487, 0 };
            const std::uint32_t dim17097JoeKuoD6Init[]   =   { 1, 3, 1, 1, 5, 3, 99, 93, 257, 659, 19, 3789, 203, 6183, 11571, 54845, 80591, 243303, 0 };
            const std::uint32_t dim17098JoeKuoD6Init[]   =   { 1, 3, 7, 1, 1, 7, 27, 11, 255, 261, 769, 2877, 6013, 8431, 25669, 43591, 122501, 208947, 0 };
            const std::uint32_t dim17099JoeKuoD6Init[]   =   { 1, 1, 7, 7, 3, 25, 117, 19, 15, 843, 401, 613, 801, 10579, 129, 12249, 107465, 95953, 0 };
            const std::uint32_t dim17100JoeKuoD6Init[]   =   { 1, 1, 3, 5, 1, 35, 95, 93, 243, 937, 1543, 3443, 175, 2199, 12521, 2521, 87225, 38631, 0 };
            const std::uint32_t dim17101JoeKuoD6Init[]   =   { 1, 3, 7, 13, 21, 29, 81, 139, 247, 937, 1835, 3887, 6917, 15709, 20947, 3341, 125521, 247195, 0 };
            const std::uint32_t dim17102JoeKuoD6Init[]   =   { 1, 1, 5, 11, 31, 19, 111, 215, 191, 347, 1215, 1757, 6751, 3099, 755, 43753, 2813, 159123, 0 };
            const std::uint32_t dim17103JoeKuoD6Init[]   =   { 1, 3, 3, 3, 31, 5, 35, 87, 293, 581, 1501, 3255, 7041, 5233, 2053, 63403, 37943, 12115, 0 };
            const std::uint32_t dim17104JoeKuoD6Init[]   =   { 1, 1, 7, 15, 11, 31, 5, 123, 225, 703, 733, 635, 2193, 3059, 30933, 43149, 79409, 106995, 0 };
            const std::uint32_t dim17105JoeKuoD6Init[]   =   { 1, 3, 1, 7, 11, 21, 45, 135, 99, 883, 85, 3861, 6617, 7169, 29887, 329, 42487, 129001, 0 };
            const std::uint32_t dim17106JoeKuoD6Init[]   =   { 1, 1, 1, 3, 11, 53, 31, 245, 141, 667, 1615, 3311, 1475, 12785, 3509, 47153, 105747, 141275, 0 };
            const std::uint32_t dim17107JoeKuoD6Init[]   =   { 1, 1, 3, 15, 7, 15, 55, 13, 465, 707, 1299, 1393, 399, 9229, 4897, 50313, 1275, 131811, 0 };
            const std::uint32_t dim17108JoeKuoD6Init[]   =   { 1, 1, 3, 15, 5, 57, 43, 19, 335, 929, 459, 327, 5715, 7173, 27643, 535, 46221, 144619, 0 };
            const std::uint32_t dim17109JoeKuoD6Init[]   =   { 1, 3, 5, 1, 9, 1, 63, 187, 71, 899, 969, 1349, 1553, 15593, 22783, 211, 41643, 163981, 0 };
            const std::uint32_t dim17110JoeKuoD6Init[]   =   { 1, 1, 1, 13, 3, 63, 35, 37, 311, 253, 1393, 629, 5299, 14837, 15053, 28041, 81541, 149037, 0 };
            const std::uint32_t dim17111JoeKuoD6Init[]   =   { 1, 3, 3, 11, 13, 45, 17, 165, 497, 751, 635, 2939, 6891, 14877, 32763, 20671, 106845, 258033, 0 };
            const std::uint32_t dim17112JoeKuoD6Init[]   =   { 1, 1, 3, 11, 21, 7, 3, 247, 243, 219, 1651, 929, 2737, 9507, 31819, 61389, 14593, 137207, 0 };
            const std::uint32_t dim17113JoeKuoD6Init[]   =   { 1, 1, 7, 5, 15, 33, 31, 29, 467, 75, 523, 1067, 7313, 11715, 26581, 47037, 106385, 199859, 0 };
            const std::uint32_t dim17114JoeKuoD6Init[]   =   { 1, 3, 1, 7, 19, 59, 35, 35, 3, 899, 799, 1379, 5113, 7653, 17977, 42197, 52397, 179705, 0 };
            const std::uint32_t dim17115JoeKuoD6Init[]   =   { 1, 1, 7, 5, 13, 13, 67, 157, 181, 633, 21, 3107, 6301, 7523, 23981, 9079, 88875, 195869, 0 };
            const std::uint32_t dim17116JoeKuoD6Init[]   =   { 1, 3, 7, 9, 7, 9, 115, 49, 293, 691, 1729, 4087, 6353, 963, 12433, 22135, 96383, 127745, 0 };
            const std::uint32_t dim17117JoeKuoD6Init[]   =   { 1, 3, 7, 7, 21, 5, 43, 247, 89, 275, 1219, 311, 5677, 7161, 13853, 38613, 84935, 223563, 0 };
            const std::uint32_t dim17118JoeKuoD6Init[]   =   { 1, 3, 1, 5, 29, 61, 17, 235, 127, 979, 973, 1463, 371, 5567, 6949, 34165, 3075, 169347, 0 };
            const std::uint32_t dim17119JoeKuoD6Init[]   =   { 1, 3, 3, 15, 25, 51, 43, 73, 7, 123, 1761, 1461, 5291, 14271, 19335, 45379, 123469, 190439, 0 };
            const std::uint32_t dim17120JoeKuoD6Init[]   =   { 1, 3, 3, 13, 19, 57, 25, 161, 351, 703, 819, 753, 3101, 9043, 19179, 22665, 118533, 45817, 0 };
            const std::uint32_t dim17121JoeKuoD6Init[]   =   { 1, 3, 5, 15, 3, 33, 15, 63, 251, 87, 611, 1187, 2639, 6001, 16135, 27505, 71077, 34101, 0 };
            const std::uint32_t dim17122JoeKuoD6Init[]   =   { 1, 1, 5, 3, 31, 5, 13, 239, 119, 803, 1881, 3479, 1933, 6421, 21411, 62923, 76851, 211029, 0 };
            const std::uint32_t dim17123JoeKuoD6Init[]   =   { 1, 3, 1, 11, 13, 59, 13, 77, 87, 343, 1733, 3493, 5937, 15733, 7763, 12839, 68639, 70965, 0 };
            const std::uint32_t dim17124JoeKuoD6Init[]   =   { 1, 1, 1, 3, 5, 19, 73, 109, 197, 1007, 1369, 623, 3249, 9263, 12463, 37105, 40599, 115323, 0 };
            const std::uint32_t dim17125JoeKuoD6Init[]   =   { 1, 1, 7, 1, 21, 23, 27, 221, 117, 27, 1811, 837, 7355, 8083, 12657, 34137, 102025, 6511, 0 };
            const std::uint32_t dim17126JoeKuoD6Init[]   =   { 1, 3, 7, 13, 13, 29, 7, 103, 511, 449, 1443, 775, 3503, 1057, 8809, 48583, 27649, 206219, 0 };
            const std::uint32_t dim17127JoeKuoD6Init[]   =   { 1, 1, 7, 1, 15, 37, 53, 205, 393, 691, 989, 3493, 7813, 12371, 18125, 62569, 57075, 100625, 0 };
            const std::uint32_t dim17128JoeKuoD6Init[]   =   { 1, 3, 5, 7, 11, 11, 55, 7, 487, 861, 1589, 1003, 607, 10031, 22481, 41905, 67791, 168167, 0 };
            const std::uint32_t dim17129JoeKuoD6Init[]   =   { 1, 3, 1, 9, 21, 31, 25, 187, 315, 379, 961, 2721, 3395, 12321, 21693, 56977, 73197, 160023, 0 };
            const std::uint32_t dim17130JoeKuoD6Init[]   =   { 1, 3, 3, 7, 9, 25, 103, 1, 13, 1021, 1777, 1015, 2269, 2131, 191, 2561, 74755, 27131, 0 };
            const std::uint32_t dim17131JoeKuoD6Init[]   =   { 1, 1, 3, 13, 21, 29, 97, 153, 499, 207, 719, 585, 8155, 2873, 22073, 45933, 92875, 19205, 0 };
            const std::uint32_t dim17132JoeKuoD6Init[]   =   { 1, 3, 7, 15, 13, 31, 43, 223, 405, 839, 1241, 2219, 6911, 9469, 24477, 63157, 95503, 128431, 0 };
            const std::uint32_t dim17133JoeKuoD6Init[]   =   { 1, 3, 5, 15, 5, 11, 79, 129, 235, 171, 289, 1791, 6061, 9107, 13859, 55923, 30197, 111025, 0 };
            const std::uint32_t dim17134JoeKuoD6Init[]   =   { 1, 1, 7, 11, 13, 23, 51, 139, 219, 467, 1923, 2847, 1977, 1503, 1939, 55579, 65357, 50047, 0 };
            const std::uint32_t dim17135JoeKuoD6Init[]   =   { 1, 3, 7, 11, 27, 25, 91, 95, 73, 189, 1537, 273, 725, 1215, 15255, 18847, 67419, 162153, 0 };
            const std::uint32_t dim17136JoeKuoD6Init[]   =   { 1, 3, 3, 11, 3, 63, 49, 131, 219, 285, 819, 2801, 2645, 2943, 15055, 15659, 130641, 82913, 0 };
            const std::uint32_t dim17137JoeKuoD6Init[]   =   { 1, 1, 3, 7, 17, 19, 37, 59, 391, 1009, 1569, 2569, 2519, 33, 18827, 23277, 94797, 103673, 0 };
            const std::uint32_t dim17138JoeKuoD6Init[]   =   { 1, 3, 5, 9, 27, 57, 69, 185, 49, 829, 29, 1247, 6129, 14935, 8005, 48343, 55789, 170099, 0 };
            const std::uint32_t dim17139JoeKuoD6Init[]   =   { 1, 3, 3, 7, 19, 55, 77, 231, 79, 787, 1597, 2701, 4999, 4247, 31849, 7797, 118993, 77871, 0 };
            const std::uint32_t dim17140JoeKuoD6Init[]   =   { 1, 1, 7, 13, 5, 45, 105, 137, 239, 923, 593, 3227, 3603, 15463, 15533, 55285, 95295, 141951, 0 };
            const std::uint32_t dim17141JoeKuoD6Init[]   =   { 1, 3, 1, 5, 29, 3, 113, 241, 255, 181, 1933, 2579, 1865, 11083, 8023, 34271, 78603, 240781, 0 };
            const std::uint32_t dim17142JoeKuoD6Init[]   =   { 1, 1, 3, 7, 17, 21, 123, 75, 305, 485, 9, 3037, 677, 8001, 16803, 25851, 121773, 77729, 0 };
            const std::uint32_t dim17143JoeKuoD6Init[]   =   { 1, 3, 1, 5, 23, 7, 39, 25, 381, 1003, 361, 995, 1751, 9599, 6399, 9627, 19303, 249899, 0 };
            const std::uint32_t dim17144JoeKuoD6Init[]   =   { 1, 3, 5, 5, 13, 39, 65, 145, 351, 135, 981, 3657, 4711, 13649, 17253, 46443, 99187, 176683, 0 };
            const std::uint32_t dim17145JoeKuoD6Init[]   =   { 1, 3, 1, 9, 9, 41, 79, 237, 445, 507, 1947, 2905, 8161, 715, 24499, 62397, 26393, 197221, 0 };
            const std::uint32_t dim17146JoeKuoD6Init[]   =   { 1, 3, 5, 3, 23, 9, 107, 121, 59, 265, 177, 3495, 391, 4537, 32099, 45217, 128285, 259285, 0 };
            const std::uint32_t dim17147JoeKuoD6Init[]   =   { 1, 3, 3, 15, 5, 61, 87, 209, 139, 461, 485, 3261, 7425, 6193, 22221, 22145, 93989, 101459, 0 };
            const std::uint32_t dim17148JoeKuoD6Init[]   =   { 1, 3, 1, 1, 15, 51, 29, 145, 385, 695, 375, 3743, 1387, 15385, 7995, 22993, 64115, 239897, 0 };
            const std::uint32_t dim17149JoeKuoD6Init[]   =   { 1, 1, 5, 15, 9, 11, 73, 219, 293, 941, 477, 3935, 2717, 9559, 20537, 6935, 39711, 13623, 0 };
            const std::uint32_t dim17150JoeKuoD6Init[]   =   { 1, 3, 3, 11, 3, 23, 127, 21, 61, 59, 1685, 507, 3883, 6587, 6355, 65407, 54311, 228555, 0 };
            const std::uint32_t dim17151JoeKuoD6Init[]   =   { 1, 3, 1, 1, 25, 47, 51, 111, 77, 871, 1045, 4017, 7683, 7729, 24155, 3481, 31749, 245155, 0 };
            const std::uint32_t dim17152JoeKuoD6Init[]   =   { 1, 3, 5, 1, 25, 29, 119, 131, 475, 763, 1639, 1937, 7387, 2307, 24081, 34797, 91785, 52055, 0 };
            const std::uint32_t dim17153JoeKuoD6Init[]   =   { 1, 1, 5, 1, 29, 19, 119, 111, 119, 751, 1079, 1911, 4085, 8909, 4351, 30037, 37691, 57175, 0 };
            const std::uint32_t dim17154JoeKuoD6Init[]   =   { 1, 1, 7, 7, 27, 33, 71, 189, 105, 821, 1543, 2939, 3829, 6485, 22235, 7097, 76987, 207121, 0 };
            const std::uint32_t dim17155JoeKuoD6Init[]   =   { 1, 1, 3, 3, 7, 7, 65, 121, 355, 405, 1019, 1779, 7301, 10609, 25927, 16501, 37287, 133383, 0 };
            const std::uint32_t dim17156JoeKuoD6Init[]   =   { 1, 1, 3, 11, 31, 57, 109, 197, 165, 711, 271, 653, 5835, 14905, 26065, 52287, 106215, 225075, 0 };
            const std::uint32_t dim17157JoeKuoD6Init[]   =   { 1, 1, 3, 3, 1, 41, 5, 169, 15, 49, 1311, 2715, 579, 1693, 28001, 17935, 18585, 123531, 0 };
            const std::uint32_t dim17158JoeKuoD6Init[]   =   { 1, 1, 7, 7, 1, 49, 59, 75, 173, 361, 1947, 2707, 1835, 12025, 24051, 24359, 121841, 215797, 0 };
            const std::uint32_t dim17159JoeKuoD6Init[]   =   { 1, 1, 5, 13, 7, 49, 15, 181, 409, 1005, 383, 3449, 2987, 13051, 7097, 34571, 55495, 65251, 0 };
            const std::uint32_t dim17160JoeKuoD6Init[]   =   { 1, 1, 3, 11, 5, 9, 67, 41, 9, 79, 401, 379, 4107, 5231, 519, 47877, 17273, 137479, 0 };
            const std::uint32_t dim17161JoeKuoD6Init[]   =   { 1, 1, 3, 13, 25, 7, 9, 165, 103, 37, 1369, 933, 1119, 1025, 19767, 25765, 55487, 249709, 0 };
            const std::uint32_t dim17162JoeKuoD6Init[]   =   { 1, 3, 5, 5, 19, 53, 105, 135, 245, 957, 185, 2901, 1741, 10429, 747, 23365, 49363, 84095, 0 };
            const std::uint32_t dim17163JoeKuoD6Init[]   =   { 1, 1, 1, 15, 29, 17, 107, 193, 17, 447, 1261, 1935, 5749, 2303, 23287, 59883, 28655, 188055, 0 };
            const std::uint32_t dim17164JoeKuoD6Init[]   =   { 1, 1, 5, 9, 13, 27, 99, 253, 299, 481, 89, 3041, 1549, 15417, 30495, 2063, 53649, 219883, 0 };
            const std::uint32_t dim17165JoeKuoD6Init[]   =   { 1, 3, 3, 15, 19, 19, 7, 149, 67, 349, 789, 129, 2783, 2887, 28631, 26001, 62407, 151767, 0 };
            const std::uint32_t dim17166JoeKuoD6Init[]   =   { 1, 3, 3, 13, 7, 29, 65, 25, 93, 627, 301, 721, 7249, 13295, 19995, 33715, 36441, 157625, 0 };
            const std::uint32_t dim17167JoeKuoD6Init[]   =   { 1, 1, 1, 3, 29, 63, 85, 27, 507, 543, 1887, 3169, 4239, 4455, 22047, 15369, 48913, 192071, 0 };
            const std::uint32_t dim17168JoeKuoD6Init[]   =   { 1, 3, 7, 5, 9, 33, 125, 41, 7, 723, 1091, 3311, 8173, 3861, 31507, 42669, 68853, 60043, 0 };
            const std::uint32_t dim17169JoeKuoD6Init[]   =   { 1, 3, 1, 13, 13, 7, 121, 41, 181, 913, 371, 163, 7061, 8779, 18345, 41915, 1785, 107113, 0 };
            const std::uint32_t dim17170JoeKuoD6Init[]   =   { 1, 1, 1, 9, 13, 41, 23, 35, 157, 247, 1243, 1101, 5193, 4027, 29917, 44099, 46211, 162059, 0 };
            const std::uint32_t dim17171JoeKuoD6Init[]   =   { 1, 3, 1, 5, 15, 51, 3, 241, 131, 741, 1885, 2397, 5673, 9097, 9319, 15381, 55655, 207569, 0 };
            const std::uint32_t dim17172JoeKuoD6Init[]   =   { 1, 1, 3, 15, 25, 15, 69, 55, 435, 727, 1007, 375, 7871, 10437, 11011, 36711, 11269, 105159, 0 };
            const std::uint32_t dim17173JoeKuoD6Init[]   =   { 1, 3, 3, 13, 17, 1, 101, 189, 295, 185, 1715, 2609, 6767, 11751, 11469, 3951, 80743, 114439, 0 };
            const std::uint32_t dim17174JoeKuoD6Init[]   =   { 1, 3, 1, 7, 21, 41, 93, 39, 433, 917, 279, 161, 267, 10201, 26583, 30363, 110187, 46501, 0 };
            const std::uint32_t dim17175JoeKuoD6Init[]   =   { 1, 1, 7, 7, 13, 15, 89, 167, 365, 925, 107, 3537, 6815, 15251, 23149, 61821, 66569, 135353, 0 };
            const std::uint32_t dim17176JoeKuoD6Init[]   =   { 1, 1, 1, 3, 13, 59, 21, 255, 111, 603, 547, 465, 3001, 16055, 26389, 64301, 112751, 219279, 0 };
            const std::uint32_t dim17177JoeKuoD6Init[]   =   { 1, 1, 1, 15, 17, 3, 21, 49, 327, 349, 489, 957, 807, 11685, 23975, 34729, 100773, 223551, 0 };
            const std::uint32_t dim17178JoeKuoD6Init[]   =   { 1, 3, 5, 15, 19, 59, 63, 71, 233, 767, 1789, 3609, 5911, 3405, 7519, 3611, 92015, 126669, 0 };
            const std::uint32_t dim17179JoeKuoD6Init[]   =   { 1, 1, 1, 11, 7, 31, 79, 57, 115, 763, 1643, 3329, 7209, 1385, 15565, 64353, 60637, 59445, 0 };
            const std::uint32_t dim17180JoeKuoD6Init[]   =   { 1, 1, 3, 1, 13, 3, 47, 89, 507, 523, 1, 1391, 6973, 7267, 32527, 52631, 20775, 234503, 0 };
            const std::uint32_t dim17181JoeKuoD6Init[]   =   { 1, 3, 1, 9, 23, 23, 95, 57, 295, 857, 213, 1211, 3503, 3043, 24843, 16149, 118719, 171585, 0 };
            const std::uint32_t dim17182JoeKuoD6Init[]   =   { 1, 3, 1, 5, 1, 13, 63, 167, 305, 711, 759, 2521, 5051, 9125, 22917, 24647, 100777, 261137, 0 };
            const std::uint32_t dim17183JoeKuoD6Init[]   =   { 1, 1, 5, 9, 25, 19, 5, 225, 511, 543, 685, 733, 7249, 10447, 11115, 25927, 104327, 92861, 0 };
            const std::uint32_t dim17184JoeKuoD6Init[]   =   { 1, 3, 1, 7, 15, 7, 15, 83, 379, 461, 943, 317, 7735, 12655, 7549, 6371, 20901, 170331, 0 };
            const std::uint32_t dim17185JoeKuoD6Init[]   =   { 1, 1, 1, 13, 7, 17, 41, 51, 47, 15, 477, 1203, 819, 1615, 13805, 40147, 3967, 192647, 0 };
            const std::uint32_t dim17186JoeKuoD6Init[]   =   { 1, 3, 7, 11, 9, 11, 111, 75, 171, 833, 1503, 2325, 7279, 2687, 16499, 11547, 99409, 186429, 0 };
            const std::uint32_t dim17187JoeKuoD6Init[]   =   { 1, 1, 5, 3, 13, 21, 75, 17, 447, 647, 1309, 2297, 7911, 12093, 16237, 50831, 96123, 134479, 0 };
            const std::uint32_t dim17188JoeKuoD6Init[]   =   { 1, 1, 5, 15, 19, 29, 35, 255, 291, 437, 85, 2143, 3281, 3629, 29339, 28169, 46561, 236595, 0 };
            const std::uint32_t dim17189JoeKuoD6Init[]   =   { 1, 3, 7, 1, 31, 57, 125, 109, 317, 461, 681, 1379, 6387, 14971, 8451, 17655, 87619, 51721, 0 };
            const std::uint32_t dim17190JoeKuoD6Init[]   =   { 1, 3, 7, 1, 23, 33, 45, 149, 43, 465, 997, 601, 693, 6273, 12867, 25885, 81353, 60437, 0 };
            const std::uint32_t dim17191JoeKuoD6Init[]   =   { 1, 1, 7, 7, 31, 25, 113, 205, 481, 141, 1757, 587, 2981, 7637, 3869, 4151, 69541, 68587, 0 };
            const std::uint32_t dim17192JoeKuoD6Init[]   =   { 1, 1, 7, 13, 17, 31, 69, 247, 137, 79, 1221, 1693, 3747, 10711, 1671, 31587, 12139, 248585, 0 };
            const std::uint32_t dim17193JoeKuoD6Init[]   =   { 1, 1, 1, 3, 1, 61, 39, 139, 37, 79, 125, 1145, 7505, 10129, 29209, 52045, 99159, 195553, 0 };
            const std::uint32_t dim17194JoeKuoD6Init[]   =   { 1, 1, 5, 3, 13, 41, 13, 11, 167, 953, 1961, 3557, 871, 1687, 28479, 10621, 27533, 243519, 0 };
            const std::uint32_t dim17195JoeKuoD6Init[]   =   { 1, 1, 7, 7, 1, 35, 107, 227, 375, 225, 483, 1239, 7591, 8549, 7351, 62001, 70245, 102795, 0 };
            const std::uint32_t dim17196JoeKuoD6Init[]   =   { 1, 1, 1, 9, 29, 35, 15, 3, 337, 1017, 1065, 2107, 2457, 9455, 7069, 55081, 57887, 149679, 0 };
            const std::uint32_t dim17197JoeKuoD6Init[]   =   { 1, 1, 7, 1, 1, 1, 13, 63, 287, 895, 593, 1253, 4717, 10313, 10275, 22143, 59149, 38865, 0 };
            const std::uint32_t dim17198JoeKuoD6Init[]   =   { 1, 1, 3, 15, 27, 39, 73, 11, 509, 391, 1901, 503, 5523, 6777, 30849, 41301, 35067, 68443, 0 };
            const std::uint32_t dim17199JoeKuoD6Init[]   =   { 1, 3, 3, 15, 17, 57, 39, 229, 273, 917, 577, 3627, 3285, 4495, 28581, 34011, 38537, 194999, 0 };
            const std::uint32_t dim17200JoeKuoD6Init[]   =   { 1, 1, 7, 3, 17, 51, 91, 203, 161, 757, 581, 1625, 477, 8839, 16515, 43101, 121497, 23603, 0 };
            const std::uint32_t dim17201JoeKuoD6Init[]   =   { 1, 3, 3, 5, 19, 29, 55, 127, 283, 999, 1227, 1937, 4471, 11305, 8813, 40509, 78521, 175573, 0 };
            const std::uint32_t dim17202JoeKuoD6Init[]   =   { 1, 3, 3, 3, 5, 29, 33, 249, 25, 213, 1315, 393, 6967, 12751, 7485, 39561, 14801, 191921, 0 };
            const std::uint32_t dim17203JoeKuoD6Init[]   =   { 1, 3, 7, 9, 23, 15, 93, 69, 23, 239, 1993, 3375, 539, 14141, 10123, 33561, 127565, 181527, 0 };
            const std::uint32_t dim17204JoeKuoD6Init[]   =   { 1, 3, 3, 15, 13, 15, 65, 241, 83, 351, 1943, 1305, 7181, 11803, 31907, 63623, 5439, 150661, 0 };
            const std::uint32_t dim17205JoeKuoD6Init[]   =   { 1, 3, 7, 11, 13, 17, 17, 37, 409, 577, 973, 797, 1761, 5333, 13803, 22991, 29743, 53051, 0 };
            const std::uint32_t dim17206JoeKuoD6Init[]   =   { 1, 3, 5, 5, 27, 25, 91, 225, 411, 23, 877, 2487, 8061, 12337, 11471, 8857, 10791, 112699, 0 };
            const std::uint32_t dim17207JoeKuoD6Init[]   =   { 1, 1, 5, 3, 15, 1, 87, 249, 205, 1011, 2045, 1879, 4137, 5877, 12709, 5231, 74283, 124315, 0 };
            const std::uint32_t dim17208JoeKuoD6Init[]   =   { 1, 1, 7, 7, 31, 37, 117, 71, 139, 391, 1085, 4033, 3087, 3063, 19991, 8787, 96899, 17279, 0 };
            const std::uint32_t dim17209JoeKuoD6Init[]   =   { 1, 1, 7, 15, 19, 47, 45, 181, 303, 151, 337, 2557, 6131, 3161, 13097, 52777, 77783, 259817, 0 };
            const std::uint32_t dim17210JoeKuoD6Init[]   =   { 1, 1, 3, 3, 1, 55, 115, 227, 83, 591, 967, 4067, 3441, 243, 13443, 4043, 129365, 161459, 0 };
            const std::uint32_t dim17211JoeKuoD6Init[]   =   { 1, 1, 3, 15, 5, 23, 71, 31, 271, 585, 931, 909, 3375, 15063, 12111, 35811, 124047, 68225, 0 };
            const std::uint32_t dim17212JoeKuoD6Init[]   =   { 1, 1, 5, 11, 1, 59, 19, 193, 323, 489, 837, 3709, 1807, 11617, 30931, 33561, 2805, 100979, 0 };
            const std::uint32_t dim17213JoeKuoD6Init[]   =   { 1, 3, 5, 7, 27, 7, 71, 67, 167, 521, 1237, 2911, 3531, 2885, 4669, 25703, 87647, 36381, 0 };
            const std::uint32_t dim17214JoeKuoD6Init[]   =   { 1, 3, 3, 13, 13, 21, 97, 225, 477, 1023, 2029, 877, 3849, 4675, 17665, 19257, 9697, 168577, 0 };
            const std::uint32_t dim17215JoeKuoD6Init[]   =   { 1, 1, 7, 15, 25, 31, 19, 255, 45, 539, 1831, 2655, 7471, 12011, 12455, 3681, 123881, 234471, 0 };
            const std::uint32_t dim17216JoeKuoD6Init[]   =   { 1, 1, 3, 9, 17, 39, 105, 73, 271, 555, 987, 873, 5371, 12381, 13469, 54961, 125701, 194063, 0 };
            const std::uint32_t dim17217JoeKuoD6Init[]   =   { 1, 1, 5, 5, 7, 27, 15, 195, 121, 175, 991, 955, 5007, 11423, 1539, 21381, 79891, 162149, 0 };
            const std::uint32_t dim17218JoeKuoD6Init[]   =   { 1, 3, 1, 7, 25, 23, 69, 69, 177, 545, 481, 3503, 3721, 1077, 8763, 6919, 64743, 172311, 0 };
            const std::uint32_t dim17219JoeKuoD6Init[]   =   { 1, 1, 3, 15, 31, 5, 33, 45, 81, 795, 435, 399, 4591, 3741, 26493, 14791, 59529, 89989, 0 };
            const std::uint32_t dim17220JoeKuoD6Init[]   =   { 1, 1, 7, 13, 21, 29, 95, 75, 213, 59, 1635, 479, 441, 14667, 16389, 9139, 30955, 169895, 0 };
            const std::uint32_t dim17221JoeKuoD6Init[]   =   { 1, 3, 3, 3, 17, 61, 103, 85, 233, 287, 447, 2687, 4755, 9489, 1669, 10405, 58489, 170429, 0 };
            const std::uint32_t dim17222JoeKuoD6Init[]   =   { 1, 1, 5, 5, 13, 9, 63, 129, 321, 531, 393, 3353, 5309, 16375, 20473, 12595, 52239, 183647, 0 };
            const std::uint32_t dim17223JoeKuoD6Init[]   =   { 1, 1, 3, 7, 7, 31, 101, 253, 119, 325, 351, 2321, 1899, 14073, 8985, 13609, 32043, 33225, 0 };
            const std::uint32_t dim17224JoeKuoD6Init[]   =   { 1, 1, 3, 13, 7, 25, 73, 191, 399, 591, 819, 2859, 6053, 815, 30417, 5709, 18277, 121991, 0 };
            const std::uint32_t dim17225JoeKuoD6Init[]   =   { 1, 3, 3, 1, 7, 47, 7, 81, 451, 463, 699, 1857, 8169, 15649, 22693, 28673, 9717, 227583, 0 };
            const std::uint32_t dim17226JoeKuoD6Init[]   =   { 1, 3, 3, 3, 31, 45, 123, 205, 23, 901, 1003, 1149, 7481, 6925, 23845, 18573, 97047, 248957, 0 };
            const std::uint32_t dim17227JoeKuoD6Init[]   =   { 1, 1, 3, 3, 21, 9, 53, 241, 125, 583, 1055, 3981, 8113, 12477, 8455, 6289, 112253, 17321, 0 };
            const std::uint32_t dim17228JoeKuoD6Init[]   =   { 1, 1, 7, 3, 19, 5, 51, 111, 443, 283, 117, 2127, 4273, 2335, 20373, 2885, 57439, 56839, 0 };
            const std::uint32_t dim17229JoeKuoD6Init[]   =   { 1, 1, 5, 15, 7, 5, 65, 163, 27, 691, 1667, 69, 2459, 7477, 21349, 52417, 42299, 75965, 0 };
            const std::uint32_t dim17230JoeKuoD6Init[]   =   { 1, 1, 1, 13, 13, 19, 87, 223, 475, 205, 1113, 887, 2213, 5533, 15875, 36173, 53933, 200173, 0 };
            const std::uint32_t dim17231JoeKuoD6Init[]   =   { 1, 3, 3, 13, 23, 17, 93, 37, 391, 127, 873, 1445, 3007, 10863, 21245, 55025, 99275, 255329, 0 };
            const std::uint32_t dim17232JoeKuoD6Init[]   =   { 1, 3, 1, 15, 1, 47, 57, 5, 207, 825, 161, 539, 6151, 12829, 14121, 51217, 25547, 234303, 0 };
            const std::uint32_t dim17233JoeKuoD6Init[]   =   { 1, 1, 5, 1, 21, 63, 15, 83, 19, 817, 591, 3131, 889, 12451, 14363, 27295, 83877, 124701, 0 };
            const std::uint32_t dim17234JoeKuoD6Init[]   =   { 1, 1, 7, 7, 11, 21, 87, 85, 13, 555, 163, 9, 5973, 14749, 19585, 57287, 43421, 66301, 0 };
            const std::uint32_t dim17235JoeKuoD6Init[]   =   { 1, 3, 5, 5, 7, 33, 19, 7, 9, 819, 533, 2105, 4275, 10611, 30517, 35863, 84687, 245157, 0 };
            const std::uint32_t dim17236JoeKuoD6Init[]   =   { 1, 3, 5, 13, 3, 55, 111, 157, 235, 405, 39, 2191, 905, 3099, 245, 37371, 365, 257385, 0 };
            const std::uint32_t dim17237JoeKuoD6Init[]   =   { 1, 3, 3, 13, 29, 39, 125, 235, 213, 879, 497, 1659, 6689, 12165, 18621, 14657, 37079, 167867, 0 };
            const std::uint32_t dim17238JoeKuoD6Init[]   =   { 1, 1, 5, 15, 5, 5, 27, 197, 77, 477, 1115, 3369, 2253, 5757, 20855, 4473, 112501, 76881, 0 };
            const std::uint32_t dim17239JoeKuoD6Init[]   =   { 1, 3, 3, 13, 13, 61, 37, 97, 229, 743, 1381, 3979, 307, 319, 16765, 56295, 109303, 21361, 0 };
            const std::uint32_t dim17240JoeKuoD6Init[]   =   { 1, 1, 7, 11, 19, 7, 63, 145, 129, 899, 93, 1851, 7901, 8767, 15553, 13913, 4897, 129483, 0 };
            const std::uint32_t dim17241JoeKuoD6Init[]   =   { 1, 3, 5, 11, 7, 23, 19, 5, 465, 365, 883, 3563, 4395, 2759, 4273, 623, 75047, 249519, 0 };
            const std::uint32_t dim17242JoeKuoD6Init[]   =   { 1, 3, 1, 5, 29, 43, 75, 7, 509, 373, 359, 2041, 5957, 1251, 32431, 37803, 120915, 45137, 0 };
            const std::uint32_t dim17243JoeKuoD6Init[]   =   { 1, 3, 1, 5, 21, 9, 43, 1, 337, 743, 1359, 1629, 5117, 2499, 16129, 22831, 38795, 32137, 0 };
            const std::uint32_t dim17244JoeKuoD6Init[]   =   { 1, 3, 3, 7, 23, 57, 9, 31, 351, 559, 1729, 1461, 3037, 12685, 8899, 14859, 108851, 170195, 0 };
            const std::uint32_t dim17245JoeKuoD6Init[]   =   { 1, 1, 1, 15, 23, 57, 39, 23, 283, 487, 1055, 1265, 6781, 7955, 195, 37745, 66115, 56413, 0 };
            const std::uint32_t dim17246JoeKuoD6Init[]   =   { 1, 1, 3, 7, 27, 35, 57, 17, 137, 17, 905, 4033, 5775, 5305, 22975, 17547, 106297, 146287, 0 };
            const std::uint32_t dim17247JoeKuoD6Init[]   =   { 1, 1, 1, 3, 5, 39, 73, 151, 469, 523, 119, 539, 2817, 7783, 22957, 59937, 21331, 172437, 0 };
            const std::uint32_t dim17248JoeKuoD6Init[]   =   { 1, 1, 3, 13, 21, 1, 23, 109, 113, 257, 817, 1671, 6729, 1571, 15009, 48539, 94025, 160379, 0 };
            const std::uint32_t dim17249JoeKuoD6Init[]   =   { 1, 1, 1, 1, 31, 23, 83, 107, 225, 715, 949, 69, 2163, 4777, 7715, 25901, 82935, 81455, 0 };
            const std::uint32_t dim17250JoeKuoD6Init[]   =   { 1, 3, 5, 13, 29, 11, 61, 169, 241, 973, 315, 3991, 1389, 3293, 31123, 59419, 7359, 170929, 0 };
            const std::uint32_t dim17251JoeKuoD6Init[]   =   { 1, 1, 7, 3, 21, 15, 111, 41, 329, 513, 1175, 4037, 2747, 11465, 17253, 54055, 29409, 230925, 0 };
            const std::uint32_t dim17252JoeKuoD6Init[]   =   { 1, 3, 5, 15, 31, 17, 105, 45, 61, 339, 1387, 1021, 4499, 13671, 25521, 52081, 49153, 31587, 0 };
            const std::uint32_t dim17253JoeKuoD6Init[]   =   { 1, 3, 3, 3, 29, 17, 51, 103, 429, 849, 1759, 1267, 6255, 4631, 32643, 44977, 40875, 239457, 0 };
            const std::uint32_t dim17254JoeKuoD6Init[]   =   { 1, 1, 7, 15, 3, 11, 123, 157, 73, 151, 777, 3855, 1913, 969, 11821, 16889, 63503, 197305, 0 };
            const std::uint32_t dim17255JoeKuoD6Init[]   =   { 1, 3, 1, 5, 13, 49, 61, 209, 105, 523, 851, 3667, 7525, 5537, 12851, 42867, 50535, 131403, 0 };
            const std::uint32_t dim17256JoeKuoD6Init[]   =   { 1, 3, 1, 7, 13, 19, 107, 71, 479, 895, 405, 89, 1345, 5543, 12709, 6093, 97581, 20483, 0 };
            const std::uint32_t dim17257JoeKuoD6Init[]   =   { 1, 3, 3, 11, 3, 47, 117, 175, 175, 321, 1257, 365, 1193, 12813, 2713, 26941, 43605, 223323, 0 };
            const std::uint32_t dim17258JoeKuoD6Init[]   =   { 1, 1, 7, 1, 19, 35, 45, 143, 395, 255, 1599, 575, 2637, 1287, 27673, 48329, 57975, 44173, 0 };
            const std::uint32_t dim17259JoeKuoD6Init[]   =   { 1, 3, 5, 1, 1, 19, 107, 233, 465, 661, 91, 4007, 6409, 3399, 8175, 54171, 111417, 124955, 0 };
            const std::uint32_t dim17260JoeKuoD6Init[]   =   { 1, 1, 5, 13, 9, 27, 121, 225, 55, 761, 779, 3015, 6333, 10779, 26531, 57103, 33463, 90219, 0 };
            const std::uint32_t dim17261JoeKuoD6Init[]   =   { 1, 3, 1, 9, 17, 3, 85, 147, 111, 133, 869, 1833, 2401, 5811, 24415, 27095, 65529, 164121, 0 };
            const std::uint32_t dim17262JoeKuoD6Init[]   =   { 1, 1, 5, 13, 11, 37, 13, 83, 391, 909, 2013, 1327, 6697, 1711, 29265, 10607, 20127, 57873, 0 };
            const std::uint32_t dim17263JoeKuoD6Init[]   =   { 1, 3, 1, 11, 17, 17, 33, 101, 383, 837, 1769, 1711, 3735, 14777, 27101, 56853, 110643, 101917, 0 };
            const std::uint32_t dim17264JoeKuoD6Init[]   =   { 1, 3, 5, 13, 25, 7, 37, 99, 473, 211, 1469, 1827, 6307, 8835, 15853, 22027, 43095, 15817, 0 };
            const std::uint32_t dim17265JoeKuoD6Init[]   =   { 1, 3, 1, 5, 19, 13, 61, 193, 57, 359, 1277, 749, 5499, 11239, 20681, 48477, 7225, 259259, 0 };
            const std::uint32_t dim17266JoeKuoD6Init[]   =   { 1, 1, 1, 7, 27, 17, 79, 213, 307, 761, 429, 1519, 7483, 6007, 11251, 13263, 24851, 7919, 0 };
            const std::uint32_t dim17267JoeKuoD6Init[]   =   { 1, 1, 3, 5, 9, 37, 101, 149, 405, 413, 1213, 157, 3811, 4485, 13099, 32697, 75677, 127815, 0 };
            const std::uint32_t dim17268JoeKuoD6Init[]   =   { 1, 3, 3, 7, 29, 29, 13, 113, 45, 885, 1471, 3433, 2289, 4375, 815, 16741, 20933, 9763, 0 };
            const std::uint32_t dim17269JoeKuoD6Init[]   =   { 1, 3, 5, 15, 5, 3, 7, 37, 347, 41, 1977, 395, 6363, 3591, 21457, 31455, 60547, 108153, 0 };
            const std::uint32_t dim17270JoeKuoD6Init[]   =   { 1, 3, 5, 7, 19, 9, 113, 1, 241, 439, 731, 1591, 3347, 1295, 6635, 25267, 13239, 214669, 0 };
            const std::uint32_t dim17271JoeKuoD6Init[]   =   { 1, 1, 3, 5, 7, 7, 69, 77, 281, 851, 1533, 1, 7351, 3429, 29237, 54597, 11171, 66613, 0 };
            const std::uint32_t dim17272JoeKuoD6Init[]   =   { 1, 1, 7, 15, 29, 7, 59, 9, 105, 129, 1397, 3841, 3945, 4755, 19877, 11109, 17497, 225473, 0 };
            const std::uint32_t dim17273JoeKuoD6Init[]   =   { 1, 3, 7, 7, 15, 61, 3, 207, 97, 229, 1251, 101, 3157, 5729, 15579, 14849, 119119, 91891, 0 };
            const std::uint32_t dim17274JoeKuoD6Init[]   =   { 1, 3, 3, 9, 27, 15, 85, 221, 231, 577, 1787, 3489, 2393, 7593, 13175, 25561, 108505, 97267, 0 };
            const std::uint32_t dim17275JoeKuoD6Init[]   =   { 1, 3, 7, 13, 23, 3, 7, 85, 307, 899, 371, 3539, 3467, 7955, 9539, 53583, 125587, 30969, 0 };
            const std::uint32_t dim17276JoeKuoD6Init[]   =   { 1, 1, 5, 7, 7, 31, 115, 245, 375, 803, 1121, 3775, 3565, 15283, 25981, 24681, 34469, 172003, 0 };
            const std::uint32_t dim17277JoeKuoD6Init[]   =   { 1, 1, 5, 1, 31, 5, 5, 161, 153, 235, 1703, 2163, 1089, 16233, 6183, 25167, 102925, 36673, 0 };
            const std::uint32_t dim17278JoeKuoD6Init[]   =   { 1, 3, 3, 5, 1, 57, 59, 5, 87, 497, 151, 1731, 2727, 4583, 28165, 63053, 76003, 29259, 0 };
            const std::uint32_t dim17279JoeKuoD6Init[]   =   { 1, 1, 5, 7, 5, 21, 79, 111, 347, 879, 827, 3947, 4421, 9589, 23971, 11681, 104555, 226535, 0 };
            const std::uint32_t dim17280JoeKuoD6Init[]   =   { 1, 1, 5, 1, 17, 35, 105, 159, 391, 495, 1709, 3731, 261, 2359, 1413, 37105, 8979, 189381, 0 };
            const std::uint32_t dim17281JoeKuoD6Init[]   =   { 1, 3, 3, 1, 11, 23, 21, 213, 261, 755, 1503, 2369, 1765, 14531, 2605, 15609, 48691, 113059, 0 };
            const std::uint32_t dim17282JoeKuoD6Init[]   =   { 1, 3, 5, 1, 1, 55, 87, 197, 89, 391, 1157, 3523, 385, 5871, 13681, 29097, 101903, 184553, 0 };
            const std::uint32_t dim17283JoeKuoD6Init[]   =   { 1, 3, 7, 5, 17, 51, 87, 191, 495, 761, 1943, 1845, 2963, 13133, 22439, 20101, 96759, 215215, 0 };
            const std::uint32_t dim17284JoeKuoD6Init[]   =   { 1, 3, 5, 11, 23, 9, 53, 41, 229, 233, 2025, 2835, 2359, 4755, 3015, 48267, 20721, 61001, 0 };
            const std::uint32_t dim17285JoeKuoD6Init[]   =   { 1, 1, 7, 9, 27, 35, 45, 201, 137, 291, 151, 733, 6199, 3127, 3073, 14491, 95051, 12469, 0 };
            const std::uint32_t dim17286JoeKuoD6Init[]   =   { 1, 1, 1, 9, 7, 49, 73, 233, 239, 881, 1991, 695, 5947, 9377, 12027, 41137, 80217, 122961, 0 };
            const std::uint32_t dim17287JoeKuoD6Init[]   =   { 1, 1, 5, 11, 3, 15, 85, 203, 305, 945, 1007, 1831, 3999, 373, 21141, 63829, 91779, 122495, 0 };
            const std::uint32_t dim17288JoeKuoD6Init[]   =   { 1, 1, 1, 11, 23, 51, 127, 215, 441, 467, 229, 3071, 2731, 8813, 30155, 60289, 54531, 196187, 0 };
            const std::uint32_t dim17289JoeKuoD6Init[]   =   { 1, 3, 5, 15, 29, 31, 11, 129, 443, 649, 773, 3035, 7915, 13831, 31979, 5577, 42869, 153591, 0 };
            const std::uint32_t dim17290JoeKuoD6Init[]   =   { 1, 1, 3, 11, 21, 37, 23, 79, 153, 7, 1801, 441, 8189, 7235, 6311, 965, 71993, 81755, 0 };
            const std::uint32_t dim17291JoeKuoD6Init[]   =   { 1, 3, 5, 5, 23, 13, 93, 39, 247, 367, 811, 1381, 6809, 16219, 8755, 41923, 79873, 105781, 0 };
            const std::uint32_t dim17292JoeKuoD6Init[]   =   { 1, 3, 5, 9, 19, 43, 21, 229, 251, 187, 1047, 2295, 5529, 2965, 1507, 16185, 121183, 30551, 0 };
            const std::uint32_t dim17293JoeKuoD6Init[]   =   { 1, 3, 7, 9, 19, 11, 33, 213, 39, 811, 231, 1527, 6093, 1507, 3541, 37585, 78785, 215419, 0 };
            const std::uint32_t dim17294JoeKuoD6Init[]   =   { 1, 3, 7, 7, 11, 13, 109, 119, 175, 311, 719, 3127, 6351, 1909, 5441, 5411, 58751, 80875, 0 };
            const std::uint32_t dim17295JoeKuoD6Init[]   =   { 1, 1, 1, 7, 17, 35, 57, 139, 289, 137, 1919, 2131, 6145, 3953, 24887, 64737, 4677, 23833, 0 };
            const std::uint32_t dim17296JoeKuoD6Init[]   =   { 1, 1, 3, 13, 1, 21, 83, 243, 27, 69, 501, 3925, 3339, 13313, 27021, 38319, 76441, 146397, 0 };
            const std::uint32_t dim17297JoeKuoD6Init[]   =   { 1, 3, 7, 9, 15, 17, 97, 117, 505, 673, 1333, 3891, 7775, 6323, 12967, 17387, 19501, 68347, 0 };
            const std::uint32_t dim17298JoeKuoD6Init[]   =   { 1, 1, 1, 5, 27, 55, 43, 47, 399, 147, 1539, 2663, 5555, 11993, 8759, 33783, 8361, 78633, 0 };
            const std::uint32_t dim17299JoeKuoD6Init[]   =   { 1, 1, 1, 15, 1, 17, 21, 85, 129, 117, 339, 1319, 1119, 6869, 12913, 56873, 30795, 76849, 0 };
            const std::uint32_t dim17300JoeKuoD6Init[]   =   { 1, 1, 5, 5, 11, 1, 11, 175, 355, 737, 1367, 3089, 5993, 4377, 10325, 3817, 61735, 187689, 0 };
            const std::uint32_t dim17301JoeKuoD6Init[]   =   { 1, 3, 5, 5, 21, 41, 85, 219, 425, 611, 1219, 1849, 349, 925, 26185, 31591, 23855, 35549, 0 };
            const std::uint32_t dim17302JoeKuoD6Init[]   =   { 1, 1, 3, 5, 21, 3, 77, 25, 265, 949, 1979, 1561, 4243, 12437, 5215, 23445, 33295, 130385, 0 };
            const std::uint32_t dim17303JoeKuoD6Init[]   =   { 1, 1, 3, 1, 13, 7, 3, 81, 143, 735, 31, 1781, 1537, 10789, 11923, 61589, 75761, 178837, 0 };
            const std::uint32_t dim17304JoeKuoD6Init[]   =   { 1, 1, 7, 7, 11, 47, 55, 37, 39, 533, 1773, 3121, 183, 7193, 19403, 45757, 20457, 158437, 0 };
            const std::uint32_t dim17305JoeKuoD6Init[]   =   { 1, 1, 5, 5, 3, 15, 53, 41, 139, 529, 601, 2967, 4683, 3869, 13449, 30155, 85833, 190053, 0 };
            const std::uint32_t dim17306JoeKuoD6Init[]   =   { 1, 1, 5, 1, 11, 39, 85, 131, 349, 175, 267, 779, 923, 5905, 32727, 22055, 63087, 247607, 0 };
            const std::uint32_t dim17307JoeKuoD6Init[]   =   { 1, 3, 5, 7, 7, 59, 11, 49, 465, 617, 557, 251, 1303, 10369, 29207, 13457, 113591, 43717, 0 };
            const std::uint32_t dim17308JoeKuoD6Init[]   =   { 1, 3, 5, 3, 27, 39, 21, 157, 39, 891, 1833, 2887, 7395, 7965, 21771, 42675, 71705, 177323, 0 };
            const std::uint32_t dim17309JoeKuoD6Init[]   =   { 1, 3, 7, 7, 21, 51, 53, 83, 433, 889, 1033, 1701, 6285, 14335, 1683, 3637, 110241, 110355, 0 };
            const std::uint32_t dim17310JoeKuoD6Init[]   =   { 1, 1, 7, 7, 11, 23, 35, 63, 71, 867, 79, 2551, 1837, 773, 21093, 60433, 67305, 70731, 0 };
            const std::uint32_t dim17311JoeKuoD6Init[]   =   { 1, 3, 5, 11, 9, 25, 67, 23, 137, 75, 707, 2229, 6237, 9871, 29063, 30433, 112897, 68037, 0 };
            const std::uint32_t dim17312JoeKuoD6Init[]   =   { 1, 3, 7, 13, 1, 45, 119, 149, 487, 667, 1177, 2927, 1875, 11963, 20771, 1177, 2331, 244039, 0 };
            const std::uint32_t dim17313JoeKuoD6Init[]   =   { 1, 3, 3, 7, 19, 61, 89, 163, 91, 409, 1109, 1947, 1017, 12385, 13487, 45645, 64175, 184221, 0 };
            const std::uint32_t dim17314JoeKuoD6Init[]   =   { 1, 1, 1, 15, 13, 47, 21, 203, 341, 845, 443, 1891, 2591, 2721, 7515, 52161, 70359, 173139, 0 };
            const std::uint32_t dim17315JoeKuoD6Init[]   =   { 1, 3, 3, 11, 5, 3, 119, 179, 509, 33, 1909, 2531, 6713, 12447, 30157, 61019, 45857, 165557, 0 };
            const std::uint32_t dim17316JoeKuoD6Init[]   =   { 1, 3, 7, 5, 3, 47, 79, 55, 321, 71, 1917, 4053, 6603, 3079, 28133, 15611, 99161, 118279, 0 };
            const std::uint32_t dim17317JoeKuoD6Init[]   =   { 1, 1, 1, 7, 19, 13, 3, 31, 213, 705, 435, 2381, 991, 4719, 24473, 8907, 122013, 228081, 0 };
            const std::uint32_t dim17318JoeKuoD6Init[]   =   { 1, 1, 7, 11, 27, 15, 5, 123, 169, 197, 361, 3803, 2001, 14547, 22967, 27575, 118325, 130651, 0 };
            const std::uint32_t dim17319JoeKuoD6Init[]   =   { 1, 3, 3, 5, 29, 43, 77, 15, 463, 753, 695, 3489, 2023, 9913, 13029, 26621, 129393, 209439, 0 };
            const std::uint32_t dim17320JoeKuoD6Init[]   =   { 1, 1, 5, 15, 1, 39, 55, 129, 247, 729, 1537, 2529, 3981, 13153, 1505, 12743, 104173, 218423, 0 };
            const std::uint32_t dim17321JoeKuoD6Init[]   =   { 1, 3, 7, 3, 21, 3, 49, 173, 445, 821, 3, 2671, 1865, 1377, 7589, 65485, 96485, 80193, 0 };
            const std::uint32_t dim17322JoeKuoD6Init[]   =   { 1, 3, 3, 11, 7, 21, 99, 143, 333, 869, 1469, 1579, 1749, 2203, 18773, 47377, 103211, 238357, 0 };
            const std::uint32_t dim17323JoeKuoD6Init[]   =   { 1, 3, 5, 11, 11, 19, 25, 253, 229, 755, 101, 269, 6703, 5603, 23201, 57163, 28431, 159653, 0 };
            const std::uint32_t dim17324JoeKuoD6Init[]   =   { 1, 3, 5, 3, 3, 15, 45, 225, 325, 997, 1061, 883, 3885, 7633, 461, 44411, 52129, 84535, 0 };
            const std::uint32_t dim17325JoeKuoD6Init[]   =   { 1, 1, 7, 1, 27, 29, 51, 23, 473, 443, 117, 3021, 55, 7413, 7911, 3063, 47533, 234941, 0 };
            const std::uint32_t dim17326JoeKuoD6Init[]   =   { 1, 3, 3, 15, 19, 43, 37, 95, 249, 805, 603, 865, 2115, 6999, 9739, 59029, 12181, 211159, 0 };
            const std::uint32_t dim17327JoeKuoD6Init[]   =   { 1, 3, 7, 3, 3, 61, 105, 113, 11, 169, 1007, 689, 2553, 14561, 17473, 38249, 41225, 80021, 0 };
            const std::uint32_t dim17328JoeKuoD6Init[]   =   { 1, 3, 7, 11, 5, 47, 69, 49, 457, 931, 435, 1423, 411, 15163, 3171, 29143, 101153, 240869, 0 };
            const std::uint32_t dim17329JoeKuoD6Init[]   =   { 1, 3, 7, 1, 17, 1, 13, 45, 155, 551, 1783, 3583, 2767, 2761, 18019, 61635, 104527, 123817, 0 };
            const std::uint32_t dim17330JoeKuoD6Init[]   =   { 1, 1, 5, 11, 9, 43, 101, 205, 233, 689, 1247, 2903, 3117, 12261, 11827, 50403, 103727, 35533, 0 };
            const std::uint32_t dim17331JoeKuoD6Init[]   =   { 1, 1, 5, 13, 23, 37, 121, 195, 133, 265, 1517, 823, 5933, 13917, 6363, 8533, 58443, 178549, 0 };
            const std::uint32_t dim17332JoeKuoD6Init[]   =   { 1, 1, 7, 9, 29, 1, 3, 195, 221, 877, 71, 473, 1173, 15285, 6057, 60005, 92401, 65357, 0 };
            const std::uint32_t dim17333JoeKuoD6Init[]   =   { 1, 3, 7, 1, 5, 25, 15, 207, 455, 447, 1125, 3731, 1289, 867, 22111, 38893, 70779, 88277, 0 };
            const std::uint32_t dim17334JoeKuoD6Init[]   =   { 1, 1, 1, 13, 31, 19, 15, 179, 183, 351, 1197, 1929, 3569, 12251, 17641, 4097, 24141, 186857, 0 };
            const std::uint32_t dim17335JoeKuoD6Init[]   =   { 1, 1, 1, 9, 19, 9, 125, 23, 431, 225, 943, 479, 2615, 443, 30977, 10889, 17107, 116819, 0 };
            const std::uint32_t dim17336JoeKuoD6Init[]   =   { 1, 3, 1, 9, 9, 13, 85, 123, 85, 857, 125, 3149, 1105, 3687, 2313, 38749, 52131, 259511, 0 };
            const std::uint32_t dim17337JoeKuoD6Init[]   =   { 1, 3, 5, 7, 27, 33, 57, 105, 511, 871, 1089, 2311, 3291, 2245, 3365, 30211, 62549, 56207, 0 };
            const std::uint32_t dim17338JoeKuoD6Init[]   =   { 1, 1, 7, 11, 1, 19, 75, 37, 139, 173, 391, 317, 2575, 11887, 4289, 32275, 43487, 487, 0 };
            const std::uint32_t dim17339JoeKuoD6Init[]   =   { 1, 1, 7, 1, 11, 3, 9, 217, 343, 35, 59, 93, 1343, 5043, 14869, 63717, 40983, 235373, 0 };
            const std::uint32_t dim17340JoeKuoD6Init[]   =   { 1, 1, 3, 5, 15, 13, 93, 247, 417, 179, 307, 3299, 4383, 5491, 21271, 37155, 32289, 75737, 0 };
            const std::uint32_t dim17341JoeKuoD6Init[]   =   { 1, 3, 3, 9, 3, 39, 63, 243, 305, 729, 9, 3317, 3301, 13165, 20437, 36505, 32977, 2761, 0 };
            const std::uint32_t dim17342JoeKuoD6Init[]   =   { 1, 3, 7, 5, 3, 37, 61, 109, 351, 641, 1699, 2517, 2637, 4995, 27365, 56971, 53609, 14373, 0 };
            const std::uint32_t dim17343JoeKuoD6Init[]   =   { 1, 3, 1, 15, 31, 53, 127, 123, 219, 1003, 1425, 1201, 5303, 10369, 21481, 26987, 42541, 37855, 0 };
            const std::uint32_t dim17344JoeKuoD6Init[]   =   { 1, 3, 3, 13, 9, 29, 35, 111, 395, 791, 1619, 2647, 713, 15955, 19145, 33883, 65215, 166267, 0 };
            const std::uint32_t dim17345JoeKuoD6Init[]   =   { 1, 1, 7, 11, 17, 5, 45, 249, 421, 273, 411, 2885, 7027, 11933, 24847, 36969, 124701, 214931, 0 };
            const std::uint32_t dim17346JoeKuoD6Init[]   =   { 1, 1, 3, 1, 27, 41, 125, 83, 327, 643, 223, 151, 6709, 15949, 125, 13275, 90405, 15759, 0 };
            const std::uint32_t dim17347JoeKuoD6Init[]   =   { 1, 1, 5, 15, 19, 45, 55, 109, 497, 1011, 1363, 1937, 3697, 7475, 10533, 65325, 29681, 76275, 0 };
            const std::uint32_t dim17348JoeKuoD6Init[]   =   { 1, 1, 1, 3, 23, 17, 59, 209, 229, 151, 1199, 279, 191, 8993, 25939, 13885, 113477, 166961, 0 };
            const std::uint32_t dim17349JoeKuoD6Init[]   =   { 1, 3, 5, 1, 19, 61, 27, 129, 103, 721, 1451, 2803, 5879, 3523, 15443, 4047, 95927, 50339, 0 };
            const std::uint32_t dim17350JoeKuoD6Init[]   =   { 1, 1, 1, 11, 27, 9, 53, 47, 331, 185, 1337, 3429, 807, 3341, 14871, 11035, 50651, 243843, 0 };
            const std::uint32_t dim17351JoeKuoD6Init[]   =   { 1, 3, 5, 11, 7, 57, 125, 15, 271, 811, 1873, 3093, 7841, 5761, 19955, 571, 123319, 149465, 0 };
            const std::uint32_t dim17352JoeKuoD6Init[]   =   { 1, 3, 1, 3, 31, 61, 71, 47, 477, 273, 167, 1069, 3513, 1463, 2667, 22097, 60367, 246045, 0 };
            const std::uint32_t dim17353JoeKuoD6Init[]   =   { 1, 1, 1, 11, 1, 55, 35, 233, 37, 659, 1517, 411, 2981, 10339, 21857, 33701, 44393, 6861, 0 };
            const std::uint32_t dim17354JoeKuoD6Init[]   =   { 1, 1, 5, 7, 11, 43, 109, 205, 103, 315, 1925, 2109, 6307, 7915, 19793, 61167, 27963, 251913, 0 };
            const std::uint32_t dim17355JoeKuoD6Init[]   =   { 1, 1, 5, 11, 5, 63, 107, 219, 53, 251, 1053, 2035, 77, 15885, 22011, 3945, 91, 204899, 0 };
            const std::uint32_t dim17356JoeKuoD6Init[]   =   { 1, 3, 7, 13, 21, 45, 51, 53, 99, 831, 1421, 3171, 4241, 14105, 26161, 45071, 2813, 54339, 0 };
            const std::uint32_t dim17357JoeKuoD6Init[]   =   { 1, 3, 5, 1, 3, 61, 43, 141, 355, 699, 11, 2203, 8055, 14815, 24597, 65201, 32689, 70167, 0 };
            const std::uint32_t dim17358JoeKuoD6Init[]   =   { 1, 3, 1, 5, 11, 27, 109, 239, 199, 23, 375, 1477, 3197, 4401, 29901, 46623, 79593, 133143, 0 };
            const std::uint32_t dim17359JoeKuoD6Init[]   =   { 1, 1, 1, 3, 23, 9, 63, 103, 41, 177, 1365, 1971, 5937, 13055, 27713, 13535, 47371, 57841, 0 };
            const std::uint32_t dim17360JoeKuoD6Init[]   =   { 1, 1, 5, 5, 19, 15, 5, 21, 307, 65, 215, 3801, 4149, 6565, 10249, 63541, 30867, 12129, 0 };
            const std::uint32_t dim17361JoeKuoD6Init[]   =   { 1, 3, 3, 9, 11, 1, 107, 99, 235, 331, 1479, 1365, 2557, 9545, 25767, 12461, 6471, 184643, 0 };
            const std::uint32_t dim17362JoeKuoD6Init[]   =   { 1, 3, 3, 5, 17, 13, 103, 223, 95, 955, 1479, 1825, 705, 5311, 28531, 22787, 118899, 181829, 0 };
            const std::uint32_t dim17363JoeKuoD6Init[]   =   { 1, 3, 7, 1, 5, 59, 65, 11, 251, 419, 659, 2559, 5445, 4221, 5871, 51845, 33925, 167037, 0 };
            const std::uint32_t dim17364JoeKuoD6Init[]   =   { 1, 3, 5, 13, 15, 45, 35, 181, 325, 293, 1897, 3321, 6081, 9919, 27641, 9407, 35263, 231009, 0 };
            const std::uint32_t dim17365JoeKuoD6Init[]   =   { 1, 3, 3, 3, 3, 35, 85, 33, 293, 777, 1945, 3771, 6967, 12353, 2737, 12501, 127359, 163591, 0 };
            const std::uint32_t dim17366JoeKuoD6Init[]   =   { 1, 3, 7, 9, 13, 7, 119, 107, 309, 811, 1113, 2465, 4867, 4295, 565, 59159, 94587, 119761, 0 };
            const std::uint32_t dim17367JoeKuoD6Init[]   =   { 1, 3, 3, 1, 1, 31, 61, 49, 461, 635, 233, 175, 6237, 10463, 17847, 54925, 115675, 260575, 0 };
            const std::uint32_t dim17368JoeKuoD6Init[]   =   { 1, 3, 5, 15, 25, 17, 61, 155, 235, 483, 1771, 2903, 3163, 2525, 17153, 54701, 49521, 11911, 0 };
            const std::uint32_t dim17369JoeKuoD6Init[]   =   { 1, 3, 3, 5, 1, 35, 51, 23, 187, 107, 177, 1381, 165, 6149, 10841, 3619, 107811, 188811, 0 };
            const std::uint32_t dim17370JoeKuoD6Init[]   =   { 1, 1, 5, 9, 7, 35, 5, 233, 43, 913, 939, 2195, 1369, 5355, 7941, 26075, 66813, 227623, 0 };
            const std::uint32_t dim17371JoeKuoD6Init[]   =   { 1, 3, 7, 11, 5, 43, 97, 211, 427, 875, 1179, 3631, 7989, 2419, 17209, 15789, 128209, 224117, 0 };
            const std::uint32_t dim17372JoeKuoD6Init[]   =   { 1, 1, 1, 7, 17, 7, 109, 255, 111, 883, 371, 3481, 6031, 14665, 5905, 28735, 113003, 327, 0 };
            const std::uint32_t dim17373JoeKuoD6Init[]   =   { 1, 3, 5, 3, 5, 61, 7, 155, 87, 861, 39, 3163, 179, 15493, 16403, 18755, 116157, 233185, 0 };
            const std::uint32_t dim17374JoeKuoD6Init[]   =   { 1, 3, 5, 5, 23, 45, 67, 205, 395, 417, 1235, 669, 5097, 6823, 31483, 61395, 36073, 24183, 0 };
            const std::uint32_t dim17375JoeKuoD6Init[]   =   { 1, 1, 3, 1, 11, 35, 123, 171, 125, 759, 197, 907, 2273, 3623, 31861, 60071, 91857, 158011, 0 };
            const std::uint32_t dim17376JoeKuoD6Init[]   =   { 1, 3, 7, 11, 19, 19, 25, 25, 167, 429, 1565, 3179, 5453, 15731, 30727, 32111, 63685, 113309, 0 };
            const std::uint32_t dim17377JoeKuoD6Init[]   =   { 1, 3, 7, 9, 15, 33, 67, 225, 495, 19, 1881, 1357, 4311, 9547, 18717, 20749, 8819, 209979, 0 };
            const std::uint32_t dim17378JoeKuoD6Init[]   =   { 1, 3, 5, 3, 13, 47, 107, 153, 461, 815, 1521, 2361, 7721, 10631, 2799, 62321, 59755, 170803, 0 };
            const std::uint32_t dim17379JoeKuoD6Init[]   =   { 1, 3, 7, 5, 25, 61, 5, 235, 71, 349, 1555, 3419, 1159, 2027, 17391, 29849, 47145, 122057, 0 };
            const std::uint32_t dim17380JoeKuoD6Init[]   =   { 1, 1, 5, 11, 19, 19, 101, 45, 333, 553, 1431, 4077, 2629, 15997, 19793, 65521, 124287, 174675, 0 };
            const std::uint32_t dim17381JoeKuoD6Init[]   =   { 1, 3, 7, 11, 25, 39, 103, 219, 375, 27, 227, 1061, 445, 14803, 18883, 49191, 33303, 114467, 0 };
            const std::uint32_t dim17382JoeKuoD6Init[]   =   { 1, 1, 5, 7, 3, 13, 117, 29, 387, 891, 371, 2199, 7023, 13671, 26291, 61563, 2733, 16093, 0 };
            const std::uint32_t dim17383JoeKuoD6Init[]   =   { 1, 3, 5, 11, 29, 5, 17, 249, 149, 777, 1817, 319, 19, 12321, 15241, 29069, 58381, 157467, 0 };
            const std::uint32_t dim17384JoeKuoD6Init[]   =   { 1, 3, 7, 9, 29, 17, 81, 141, 201, 383, 429, 3675, 69, 8155, 22821, 60707, 127015, 248279, 0 };
            const std::uint32_t dim17385JoeKuoD6Init[]   =   { 1, 3, 7, 9, 25, 5, 11, 27, 423, 987, 99, 3599, 4849, 4513, 32119, 34301, 6327, 249457, 0 };
            const std::uint32_t dim17386JoeKuoD6Init[]   =   { 1, 3, 3, 7, 13, 25, 71, 227, 307, 985, 665, 3097, 6713, 3823, 6357, 58199, 84057, 28055, 0 };
            const std::uint32_t dim17387JoeKuoD6Init[]   =   { 1, 3, 5, 7, 19, 21, 93, 45, 159, 527, 493, 59, 1111, 1415, 1949, 28525, 50343, 11039, 0 };
            const std::uint32_t dim17388JoeKuoD6Init[]   =   { 1, 3, 5, 13, 17, 35, 79, 229, 449, 533, 235, 3445, 8153, 15473, 12975, 53909, 24589, 237049, 0 };
            const std::uint32_t dim17389JoeKuoD6Init[]   =   { 1, 1, 7, 5, 3, 53, 93, 33, 339, 423, 497, 2691, 6125, 3931, 25357, 27509, 92509, 227209, 0 };
            const std::uint32_t dim17390JoeKuoD6Init[]   =   { 1, 1, 7, 3, 13, 49, 111, 179, 449, 279, 827, 1481, 2477, 6867, 18079, 6261, 30885, 205675, 0 };
            const std::uint32_t dim17391JoeKuoD6Init[]   =   { 1, 3, 7, 7, 11, 9, 13, 105, 367, 639, 1307, 1617, 4759, 8387, 8909, 13715, 56599, 113259, 0 };
            const std::uint32_t dim17392JoeKuoD6Init[]   =   { 1, 1, 3, 3, 15, 17, 103, 125, 205, 67, 999, 3965, 907, 13235, 15275, 58457, 66889, 227279, 0 };
            const std::uint32_t dim17393JoeKuoD6Init[]   =   { 1, 3, 3, 3, 11, 35, 99, 81, 421, 75, 1757, 2413, 5655, 1227, 4019, 14503, 20719, 224807, 0 };
            const std::uint32_t dim17394JoeKuoD6Init[]   =   { 1, 1, 7, 11, 17, 17, 109, 203, 331, 813, 987, 2925, 1601, 13617, 29, 8235, 95129, 117987, 0 };
            const std::uint32_t dim17395JoeKuoD6Init[]   =   { 1, 3, 7, 5, 5, 33, 105, 191, 183, 899, 1949, 2923, 2473, 3435, 8097, 35615, 10109, 62563, 0 };
            const std::uint32_t dim17396JoeKuoD6Init[]   =   { 1, 1, 7, 13, 5, 25, 21, 159, 487, 415, 1507, 2161, 649, 14425, 2605, 8357, 92441, 87323, 0 };
            const std::uint32_t dim17397JoeKuoD6Init[]   =   { 1, 3, 7, 15, 3, 23, 87, 209, 407, 765, 975, 3859, 675, 6351, 18703, 44919, 57155, 134961, 0 };
            const std::uint32_t dim17398JoeKuoD6Init[]   =   { 1, 3, 5, 15, 7, 59, 77, 37, 235, 565, 1707, 3531, 6733, 2223, 12621, 59523, 83547, 172355, 0 };
            const std::uint32_t dim17399JoeKuoD6Init[]   =   { 1, 3, 7, 5, 23, 15, 57, 217, 151, 333, 1033, 2549, 303, 1455, 5329, 20187, 55415, 166093, 0 };
            const std::uint32_t dim17400JoeKuoD6Init[]   =   { 1, 3, 1, 13, 21, 27, 1, 85, 335, 201, 135, 2603, 291, 10573, 28411, 1059, 129871, 98303, 0 };
            const std::uint32_t dim17401JoeKuoD6Init[]   =   { 1, 1, 3, 5, 23, 61, 123, 169, 503, 629, 711, 2795, 2291, 13273, 32703, 63377, 72809, 214927, 0 };
            const std::uint32_t dim17402JoeKuoD6Init[]   =   { 1, 3, 5, 13, 31, 11, 115, 133, 443, 709, 263, 3739, 2777, 11545, 19137, 61285, 64065, 214477, 0 };
            const std::uint32_t dim17403JoeKuoD6Init[]   =   { 1, 3, 1, 11, 29, 25, 3, 5, 385, 613, 1277, 1445, 1643, 15137, 28041, 47713, 122051, 62915, 0 };
            const std::uint32_t dim17404JoeKuoD6Init[]   =   { 1, 3, 5, 11, 3, 11, 1, 137, 457, 577, 783, 1745, 5, 5817, 26569, 50751, 14075, 246219, 0 };
            const std::uint32_t dim17405JoeKuoD6Init[]   =   { 1, 1, 1, 9, 7, 9, 105, 27, 167, 939, 799, 2773, 6427, 15579, 1975, 10695, 111429, 227105, 0 };
            const std::uint32_t dim17406JoeKuoD6Init[]   =   { 1, 3, 1, 11, 23, 23, 73, 103, 103, 61, 1743, 3061, 8127, 15893, 21223, 43549, 103659, 89129, 0 };
            const std::uint32_t dim17407JoeKuoD6Init[]   =   { 1, 1, 7, 13, 5, 43, 59, 235, 139, 961, 839, 3843, 1317, 4903, 21043, 15479, 115065, 112531, 0 };
            const std::uint32_t dim17408JoeKuoD6Init[]   =   { 1, 3, 1, 3, 19, 15, 57, 145, 193, 321, 1919, 385, 125, 15517, 14243, 62845, 38995, 120045, 0 };
            const std::uint32_t dim17409JoeKuoD6Init[]   =   { 1, 3, 3, 7, 17, 61, 77, 75, 267, 203, 1911, 2599, 1797, 761, 28101, 58603, 107755, 158689, 0 };
            const std::uint32_t dim17410JoeKuoD6Init[]   =   { 1, 1, 5, 11, 15, 21, 71, 227, 377, 361, 2013, 129, 6271, 1421, 6009, 52261, 113389, 74915, 0 };
            const std::uint32_t dim17411JoeKuoD6Init[]   =   { 1, 1, 5, 7, 3, 39, 27, 49, 97, 885, 651, 1633, 3445, 3415, 20167, 26667, 52997, 221391, 0 };
            const std::uint32_t dim17412JoeKuoD6Init[]   =   { 1, 1, 7, 9, 7, 59, 95, 127, 479, 871, 845, 2951, 673, 6385, 10057, 2605, 78529, 230771, 0 };
            const std::uint32_t dim17413JoeKuoD6Init[]   =   { 1, 3, 5, 7, 31, 15, 53, 125, 223, 711, 875, 429, 7237, 4005, 2153, 26865, 63205, 144125, 0 };
            const std::uint32_t dim17414JoeKuoD6Init[]   =   { 1, 1, 7, 9, 1, 57, 19, 189, 67, 423, 1937, 37, 4925, 15503, 25969, 20419, 59921, 58119, 0 };
            const std::uint32_t dim17415JoeKuoD6Init[]   =   { 1, 1, 7, 7, 31, 51, 99, 189, 21, 1011, 1551, 3529, 7617, 15805, 11365, 43123, 84785, 203703, 0 };
            const std::uint32_t dim17416JoeKuoD6Init[]   =   { 1, 1, 3, 15, 3, 63, 9, 67, 399, 151, 253, 1839, 1365, 16295, 13145, 29211, 48681, 177643, 0 };
            const std::uint32_t dim17417JoeKuoD6Init[]   =   { 1, 1, 1, 5, 13, 37, 1, 21, 435, 483, 939, 535, 1505, 10879, 7027, 5599, 63261, 158573, 0 };
            const std::uint32_t dim17418JoeKuoD6Init[]   =   { 1, 1, 7, 15, 13, 39, 113, 209, 213, 1017, 1197, 285, 4221, 6831, 13383, 2265, 34313, 160879, 0 };
            const std::uint32_t dim17419JoeKuoD6Init[]   =   { 1, 3, 7, 15, 25, 23, 95, 217, 141, 681, 451, 1275, 4957, 10197, 21375, 50905, 11087, 96135, 0 };
            const std::uint32_t dim17420JoeKuoD6Init[]   =   { 1, 3, 1, 11, 17, 35, 87, 15, 57, 777, 1429, 615, 681, 8437, 23981, 51781, 112169, 198471, 0 };
            const std::uint32_t dim17421JoeKuoD6Init[]   =   { 1, 3, 1, 5, 21, 37, 113, 105, 123, 327, 549, 1641, 7697, 2127, 5709, 8351, 56787, 260157, 0 };
            const std::uint32_t dim17422JoeKuoD6Init[]   =   { 1, 3, 7, 15, 19, 17, 51, 15, 367, 89, 1635, 353, 4855, 1551, 7197, 27403, 11259, 176029, 0 };
            const std::uint32_t dim17423JoeKuoD6Init[]   =   { 1, 3, 1, 1, 27, 9, 3, 35, 213, 31, 885, 797, 7077, 15641, 22509, 35193, 112411, 157335, 0 };
            const std::uint32_t dim17424JoeKuoD6Init[]   =   { 1, 1, 5, 1, 5, 9, 101, 149, 169, 581, 1927, 197, 5935, 6361, 3915, 15541, 69575, 102451, 0 };
            const std::uint32_t dim17425JoeKuoD6Init[]   =   { 1, 3, 3, 13, 23, 63, 45, 205, 271, 17, 707, 937, 2547, 12019, 8559, 26163, 58117, 138625, 0 };
            const std::uint32_t dim17426JoeKuoD6Init[]   =   { 1, 1, 3, 1, 19, 63, 125, 175, 253, 629, 1121, 3701, 7755, 61, 13037, 39417, 6179, 261923, 0 };
            const std::uint32_t dim17427JoeKuoD6Init[]   =   { 1, 1, 5, 1, 25, 63, 27, 245, 371, 657, 157, 3821, 3279, 8977, 9065, 35611, 27325, 205737, 0 };
            const std::uint32_t dim17428JoeKuoD6Init[]   =   { 1, 3, 7, 15, 7, 57, 19, 191, 1, 927, 1379, 2579, 4335, 7163, 4877, 51435, 17309, 100173, 0 };
            const std::uint32_t dim17429JoeKuoD6Init[]   =   { 1, 1, 1, 5, 21, 59, 107, 195, 317, 691, 541, 69, 7235, 2175, 25191, 23913, 126369, 9263, 0 };
            const std::uint32_t dim17430JoeKuoD6Init[]   =   { 1, 3, 5, 15, 17, 7, 67, 27, 263, 855, 1065, 973, 6705, 10729, 8719, 32741, 59207, 249107, 0 };
            const std::uint32_t dim17431JoeKuoD6Init[]   =   { 1, 3, 1, 1, 21, 23, 115, 119, 351, 207, 1691, 1105, 7479, 3877, 24439, 29017, 34171, 133797, 0 };
            const std::uint32_t dim17432JoeKuoD6Init[]   =   { 1, 3, 3, 3, 11, 23, 39, 165, 99, 1023, 309, 3933, 4235, 3891, 27237, 30887, 34363, 175017, 0 };
            const std::uint32_t dim17433JoeKuoD6Init[]   =   { 1, 3, 1, 5, 17, 33, 79, 105, 253, 515, 823, 1783, 1523, 2095, 10355, 8929, 51001, 112815, 0 };
            const std::uint32_t dim17434JoeKuoD6Init[]   =   { 1, 3, 7, 15, 11, 27, 123, 161, 279, 541, 1343, 1009, 6015, 8565, 27031, 233, 2153, 179243, 0 };
            const std::uint32_t dim17435JoeKuoD6Init[]   =   { 1, 1, 7, 7, 1, 53, 1, 33, 75, 57, 723, 3855, 3301, 14941, 6637, 25181, 103441, 208339, 0 };
            const std::uint32_t dim17436JoeKuoD6Init[]   =   { 1, 3, 7, 13, 3, 23, 11, 75, 55, 19, 1181, 3451, 4901, 2621, 18323, 42395, 95701, 237753, 0 };
            const std::uint32_t dim17437JoeKuoD6Init[]   =   { 1, 1, 1, 5, 1, 1, 123, 203, 367, 71, 1897, 295, 6719, 2647, 7135, 34511, 79853, 58351, 0 };
            const std::uint32_t dim17438JoeKuoD6Init[]   =   { 1, 3, 3, 7, 7, 63, 87, 91, 223, 265, 927, 3843, 1703, 11633, 8077, 26425, 46573, 181201, 0 };
            const std::uint32_t dim17439JoeKuoD6Init[]   =   { 1, 3, 3, 3, 1, 51, 3, 99, 37, 251, 1739, 2813, 3955, 8745, 4425, 42419, 124177, 173997, 0 };
            const std::uint32_t dim17440JoeKuoD6Init[]   =   { 1, 3, 5, 15, 9, 19, 11, 207, 123, 287, 1703, 2155, 2729, 4541, 4925, 4735, 77159, 97911, 0 };
            const std::uint32_t dim17441JoeKuoD6Init[]   =   { 1, 3, 3, 15, 23, 31, 35, 33, 507, 315, 1071, 3001, 7569, 11749, 3183, 6989, 68637, 177803, 0 };
            const std::uint32_t dim17442JoeKuoD6Init[]   =   { 1, 3, 5, 1, 31, 1, 113, 39, 295, 263, 1113, 619, 5523, 15385, 24115, 24233, 91943, 129299, 0 };
            const std::uint32_t dim17443JoeKuoD6Init[]   =   { 1, 1, 5, 11, 9, 57, 89, 49, 67, 601, 1277, 2275, 6349, 4141, 28397, 47061, 28143, 126291, 0 };
            const std::uint32_t dim17444JoeKuoD6Init[]   =   { 1, 3, 7, 15, 11, 63, 123, 187, 305, 1009, 1509, 2569, 2235, 8233, 27351, 53437, 34353, 105799, 0 };
            const std::uint32_t dim17445JoeKuoD6Init[]   =   { 1, 1, 3, 1, 13, 9, 11, 169, 427, 171, 1031, 633, 4275, 1173, 11233, 57997, 107753, 257337, 0 };
            const std::uint32_t dim17446JoeKuoD6Init[]   =   { 1, 3, 5, 5, 3, 39, 49, 233, 309, 999, 1275, 85, 1663, 16275, 9145, 18439, 59055, 249657, 0 };
            const std::uint32_t dim17447JoeKuoD6Init[]   =   { 1, 1, 3, 7, 11, 55, 73, 75, 115, 397, 945, 3657, 6847, 7341, 21305, 30119, 65675, 169281, 0 };
            const std::uint32_t dim17448JoeKuoD6Init[]   =   { 1, 1, 7, 7, 3, 5, 31, 179, 183, 479, 329, 217, 1077, 6893, 23425, 21903, 34293, 184819, 0 };
            const std::uint32_t dim17449JoeKuoD6Init[]   =   { 1, 1, 3, 3, 7, 63, 97, 255, 289, 917, 1881, 3829, 2433, 3473, 11045, 37739, 73349, 171899, 0 };
            const std::uint32_t dim17450JoeKuoD6Init[]   =   { 1, 3, 5, 5, 27, 23, 61, 151, 353, 667, 1889, 2323, 3261, 15999, 24225, 35265, 97301, 75743, 0 };
            const std::uint32_t dim17451JoeKuoD6Init[]   =   { 1, 3, 7, 1, 19, 41, 81, 61, 461, 275, 131, 2665, 5615, 1719, 21047, 42025, 97725, 196587, 0 };
            const std::uint32_t dim17452JoeKuoD6Init[]   =   { 1, 1, 7, 11, 3, 5, 47, 107, 397, 237, 1795, 3049, 5317, 14147, 15299, 50469, 83855, 75685, 0 };
            const std::uint32_t dim17453JoeKuoD6Init[]   =   { 1, 1, 7, 7, 19, 31, 39, 153, 225, 591, 1547, 3755, 3219, 15823, 4015, 30977, 63999, 198023, 0 };
            const std::uint32_t dim17454JoeKuoD6Init[]   =   { 1, 3, 1, 1, 17, 57, 91, 3, 425, 465, 735, 719, 2955, 3003, 6669, 14335, 32137, 82265, 0 };
            const std::uint32_t dim17455JoeKuoD6Init[]   =   { 1, 3, 1, 9, 13, 25, 93, 187, 119, 735, 447, 3387, 5111, 6525, 28241, 37643, 99023, 58551, 0 };
            const std::uint32_t dim17456JoeKuoD6Init[]   =   { 1, 1, 7, 1, 23, 15, 105, 89, 109, 743, 2007, 3131, 4839, 3285, 14681, 47097, 69531, 104647, 0 };
            const std::uint32_t dim17457JoeKuoD6Init[]   =   { 1, 1, 5, 7, 27, 33, 85, 109, 165, 569, 511, 3223, 2201, 2869, 30457, 42585, 125187, 83115, 0 };
            const std::uint32_t dim17458JoeKuoD6Init[]   =   { 1, 1, 7, 13, 1, 39, 55, 69, 279, 757, 425, 1317, 2403, 10711, 3341, 33491, 5607, 214161, 0 };
            const std::uint32_t dim17459JoeKuoD6Init[]   =   { 1, 3, 3, 9, 23, 57, 109, 9, 473, 323, 1371, 657, 5039, 1947, 12787, 29099, 81887, 44039, 0 };
            const std::uint32_t dim17460JoeKuoD6Init[]   =   { 1, 3, 1, 9, 21, 49, 39, 71, 493, 611, 1465, 3965, 7509, 5315, 4095, 21865, 123533, 148467, 0 };
            const std::uint32_t dim17461JoeKuoD6Init[]   =   { 1, 1, 7, 5, 15, 45, 67, 109, 143, 423, 205, 849, 1291, 245, 26275, 62873, 69177, 173705, 0 };
            const std::uint32_t dim17462JoeKuoD6Init[]   =   { 1, 3, 7, 13, 3, 13, 103, 45, 171, 919, 903, 2171, 5025, 14855, 895, 36937, 37643, 30311, 0 };
            const std::uint32_t dim17463JoeKuoD6Init[]   =   { 1, 3, 1, 5, 31, 35, 67, 111, 201, 183, 375, 905, 5705, 8839, 31551, 22525, 53013, 34189, 0 };
            const std::uint32_t dim17464JoeKuoD6Init[]   =   { 1, 1, 3, 7, 25, 11, 85, 231, 285, 957, 1731, 1267, 8179, 14195, 18405, 8489, 32503, 86257, 0 };
            const std::uint32_t dim17465JoeKuoD6Init[]   =   { 1, 3, 7, 5, 29, 7, 73, 15, 501, 909, 1325, 793, 4479, 12137, 30871, 36243, 109781, 7235, 0 };
            const std::uint32_t dim17466JoeKuoD6Init[]   =   { 1, 1, 3, 15, 13, 13, 75, 221, 497, 921, 1939, 2791, 5277, 6257, 11129, 109, 27549, 44901, 0 };
            const std::uint32_t dim17467JoeKuoD6Init[]   =   { 1, 1, 7, 3, 21, 9, 35, 113, 101, 15, 545, 2429, 5869, 11379, 14427, 28605, 108313, 220523, 0 };
            const std::uint32_t dim17468JoeKuoD6Init[]   =   { 1, 3, 5, 5, 21, 31, 79, 101, 11, 687, 609, 3741, 1259, 1529, 10185, 49863, 86529, 5147, 0 };
            const std::uint32_t dim17469JoeKuoD6Init[]   =   { 1, 3, 1, 5, 5, 49, 105, 213, 435, 201, 511, 525, 5219, 9503, 32023, 25407, 2493, 51165, 0 };
            const std::uint32_t dim17470JoeKuoD6Init[]   =   { 1, 1, 5, 9, 9, 61, 67, 107, 351, 519, 1373, 1261, 1069, 4325, 9579, 37117, 71759, 17601, 0 };
            const std::uint32_t dim17471JoeKuoD6Init[]   =   { 1, 1, 7, 7, 27, 63, 63, 229, 239, 291, 1813, 3831, 8091, 2553, 18445, 60707, 88855, 224325, 0 };
            const std::uint32_t dim17472JoeKuoD6Init[]   =   { 1, 1, 5, 7, 15, 23, 109, 7, 409, 447, 185, 3535, 4643, 13431, 11107, 48771, 95843, 155889, 0 };
            const std::uint32_t dim17473JoeKuoD6Init[]   =   { 1, 3, 3, 11, 9, 47, 13, 31, 83, 837, 1661, 2283, 299, 13161, 25305, 6079, 107237, 58477, 0 };
            const std::uint32_t dim17474JoeKuoD6Init[]   =   { 1, 3, 7, 15, 3, 31, 21, 245, 105, 141, 703, 71, 1887, 9345, 15719, 37737, 58431, 195997, 0 };
            const std::uint32_t dim17475JoeKuoD6Init[]   =   { 1, 1, 1, 13, 25, 21, 23, 67, 349, 581, 1585, 809, 3955, 4621, 25989, 25633, 107229, 193271, 0 };
            const std::uint32_t dim17476JoeKuoD6Init[]   =   { 1, 1, 5, 3, 15, 57, 111, 147, 243, 575, 851, 3461, 5171, 4203, 21855, 59579, 90509, 16897, 0 };
            const std::uint32_t dim17477JoeKuoD6Init[]   =   { 1, 1, 5, 13, 5, 45, 83, 59, 253, 261, 1277, 3179, 6397, 4277, 6629, 10979, 55759, 3033, 0 };
            const std::uint32_t dim17478JoeKuoD6Init[]   =   { 1, 1, 1, 9, 25, 1, 127, 159, 273, 357, 1343, 3209, 649, 6631, 1365, 40813, 98955, 181679, 0 };
            const std::uint32_t dim17479JoeKuoD6Init[]   =   { 1, 3, 1, 11, 1, 9, 67, 5, 41, 661, 863, 3769, 2737, 7261, 26829, 43093, 113025, 127975, 0 };
            const std::uint32_t dim17480JoeKuoD6Init[]   =   { 1, 1, 3, 3, 7, 5, 77, 207, 125, 625, 437, 1059, 2635, 1099, 25567, 63759, 97575, 231313, 0 };
            const std::uint32_t dim17481JoeKuoD6Init[]   =   { 1, 3, 7, 5, 21, 41, 11, 177, 489, 405, 1831, 1373, 6267, 11275, 23613, 55565, 120353, 98771, 0 };
            const std::uint32_t dim17482JoeKuoD6Init[]   =   { 1, 1, 3, 11, 15, 55, 103, 185, 493, 755, 1235, 3143, 4355, 4887, 11245, 60103, 4023, 184729, 0 };
            const std::uint32_t dim17483JoeKuoD6Init[]   =   { 1, 3, 1, 1, 23, 5, 103, 117, 269, 101, 2013, 1781, 6445, 8753, 15041, 13993, 28753, 47133, 0 };
            const std::uint32_t dim17484JoeKuoD6Init[]   =   { 1, 3, 7, 5, 9, 23, 1, 203, 19, 535, 1445, 1713, 5503, 11555, 6195, 35797, 55663, 10187, 0 };
            const std::uint32_t dim17485JoeKuoD6Init[]   =   { 1, 3, 5, 1, 15, 3, 125, 225, 447, 269, 1663, 1823, 4309, 12243, 16689, 3889, 41111, 123355, 0 };
            const std::uint32_t dim17486JoeKuoD6Init[]   =   { 1, 1, 1, 5, 21, 33, 83, 147, 243, 101, 1085, 121, 4939, 6081, 22621, 52995, 103047, 82531, 0 };
            const std::uint32_t dim17487JoeKuoD6Init[]   =   { 1, 3, 5, 3, 21, 3, 5, 81, 431, 191, 1973, 3675, 6691, 8687, 31619, 51669, 95541, 110447, 0 };
            const std::uint32_t dim17488JoeKuoD6Init[]   =   { 1, 1, 1, 15, 1, 11, 83, 145, 75, 133, 967, 2837, 5111, 6099, 9119, 53661, 128647, 40557, 0 };
            const std::uint32_t dim17489JoeKuoD6Init[]   =   { 1, 1, 1, 7, 3, 57, 101, 231, 255, 117, 1903, 2133, 3867, 11299, 647, 58853, 22153, 135959, 0 };
            const std::uint32_t dim17490JoeKuoD6Init[]   =   { 1, 3, 5, 5, 9, 19, 89, 229, 313, 421, 201, 953, 2487, 6283, 1305, 33421, 20933, 164841, 0 };
            const std::uint32_t dim17491JoeKuoD6Init[]   =   { 1, 1, 3, 3, 1, 45, 93, 165, 343, 577, 1329, 3019, 2727, 14397, 7123, 63347, 45525, 35133, 0 };
            const std::uint32_t dim17492JoeKuoD6Init[]   =   { 1, 3, 5, 5, 19, 1, 33, 55, 49, 1003, 1567, 2539, 7461, 14641, 7655, 37499, 65525, 84961, 0 };
            const std::uint32_t dim17493JoeKuoD6Init[]   =   { 1, 3, 5, 5, 29, 3, 77, 39, 251, 791, 215, 3779, 1589, 3577, 22299, 24133, 105449, 257157, 0 };
            const std::uint32_t dim17494JoeKuoD6Init[]   =   { 1, 3, 1, 5, 7, 23, 109, 209, 35, 571, 1047, 3453, 3657, 11713, 19379, 57101, 29943, 60909, 0 };
            const std::uint32_t dim17495JoeKuoD6Init[]   =   { 1, 1, 7, 11, 17, 63, 15, 175, 333, 831, 1447, 1991, 3339, 2519, 30127, 51481, 71935, 144995, 0 };
            const std::uint32_t dim17496JoeKuoD6Init[]   =   { 1, 3, 1, 11, 13, 51, 17, 67, 43, 209, 789, 1285, 5655, 5841, 10203, 32053, 15721, 211725, 0 };
            const std::uint32_t dim17497JoeKuoD6Init[]   =   { 1, 1, 5, 7, 31, 49, 69, 255, 325, 819, 1769, 1961, 7403, 1241, 2241, 40425, 14839, 178969, 0 };
            const std::uint32_t dim17498JoeKuoD6Init[]   =   { 1, 1, 3, 9, 1, 5, 9, 35, 167, 865, 337, 1079, 6195, 10139, 19215, 57607, 122437, 197147, 0 };
            const std::uint32_t dim17499JoeKuoD6Init[]   =   { 1, 1, 1, 15, 23, 7, 47, 155, 345, 547, 333, 3747, 961, 1397, 17067, 33385, 48253, 138611, 0 };
            const std::uint32_t dim17500JoeKuoD6Init[]   =   { 1, 1, 7, 9, 29, 27, 81, 183, 153, 171, 1125, 1929, 1047, 12463, 1543, 42981, 126163, 203259, 0 };
            const std::uint32_t dim17501JoeKuoD6Init[]   =   { 1, 1, 5, 3, 1, 41, 123, 213, 7, 179, 1, 3527, 1437, 3545, 2025, 5325, 27097, 187823, 0 };
            const std::uint32_t dim17502JoeKuoD6Init[]   =   { 1, 1, 7, 1, 19, 5, 111, 251, 431, 91, 1437, 1155, 335, 9587, 18287, 23937, 123331, 3939, 0 };
            const std::uint32_t dim17503JoeKuoD6Init[]   =   { 1, 1, 1, 9, 13, 59, 75, 219, 225, 313, 525, 2003, 7829, 7063, 22123, 4263, 95491, 9375, 0 };
            const std::uint32_t dim17504JoeKuoD6Init[]   =   { 1, 3, 1, 1, 27, 29, 71, 189, 169, 301, 165, 2967, 5147, 7127, 2191, 34259, 66605, 149603, 0 };
            const std::uint32_t dim17505JoeKuoD6Init[]   =   { 1, 3, 5, 13, 29, 57, 105, 31, 495, 311, 1161, 2109, 1471, 1275, 12761, 58379, 46365, 229935, 0 };
            const std::uint32_t dim17506JoeKuoD6Init[]   =   { 1, 1, 7, 3, 7, 49, 125, 189, 309, 399, 1361, 3969, 2177, 8171, 26623, 41855, 2809, 5825, 0 };
            const std::uint32_t dim17507JoeKuoD6Init[]   =   { 1, 3, 5, 7, 17, 21, 77, 101, 37, 661, 1743, 2243, 823, 12431, 26931, 7163, 108093, 191305, 0 };
            const std::uint32_t dim17508JoeKuoD6Init[]   =   { 1, 1, 7, 5, 27, 55, 109, 119, 13, 727, 421, 3469, 1137, 6125, 5107, 52733, 102891, 147425, 0 };
            const std::uint32_t dim17509JoeKuoD6Init[]   =   { 1, 1, 3, 5, 17, 45, 17, 211, 137, 21, 689, 1487, 233, 9845, 6499, 52617, 73081, 198137, 0 };
            const std::uint32_t dim17510JoeKuoD6Init[]   =   { 1, 3, 7, 1, 25, 27, 67, 7, 161, 633, 729, 807, 7371, 7301, 29499, 45939, 110565, 219491, 0 };
            const std::uint32_t dim17511JoeKuoD6Init[]   =   { 1, 3, 3, 13, 17, 7, 55, 211, 103, 981, 1809, 1913, 5705, 14011, 7405, 13893, 92053, 17997, 0 };
            const std::uint32_t dim17512JoeKuoD6Init[]   =   { 1, 1, 1, 1, 15, 9, 75, 37, 5, 443, 157, 2749, 5587, 16087, 14953, 26793, 21229, 226879, 0 };
            const std::uint32_t dim17513JoeKuoD6Init[]   =   { 1, 3, 3, 3, 9, 13, 113, 7, 255, 647, 235, 1713, 525, 8579, 20873, 49565, 43869, 145823, 0 };
            const std::uint32_t dim17514JoeKuoD6Init[]   =   { 1, 1, 5, 15, 9, 1, 119, 189, 73, 321, 1045, 467, 1565, 14381, 22683, 7939, 44337, 231901, 0 };
            const std::uint32_t dim17515JoeKuoD6Init[]   =   { 1, 1, 3, 13, 21, 61, 35, 105, 425, 395, 381, 1205, 3631, 8099, 23723, 29435, 94683, 180367, 0 };
            const std::uint32_t dim17516JoeKuoD6Init[]   =   { 1, 3, 3, 13, 19, 15, 59, 111, 355, 165, 857, 3131, 5037, 2527, 17533, 53563, 621, 89837, 0 };
            const std::uint32_t dim17517JoeKuoD6Init[]   =   { 1, 3, 3, 11, 11, 41, 3, 75, 179, 325, 897, 3141, 75, 1735, 493, 1123, 126763, 68645, 0 };
            const std::uint32_t dim17518JoeKuoD6Init[]   =   { 1, 3, 5, 7, 19, 61, 9, 99, 101, 583, 1967, 621, 1869, 10693, 2025, 62797, 85727, 212309, 0 };
            const std::uint32_t dim17519JoeKuoD6Init[]   =   { 1, 3, 1, 13, 23, 47, 15, 29, 199, 889, 423, 3995, 1655, 10753, 25301, 55551, 94829, 205833, 0 };
            const std::uint32_t dim17520JoeKuoD6Init[]   =   { 1, 1, 1, 1, 21, 1, 91, 237, 195, 721, 881, 1155, 4109, 10367, 1873, 6851, 13295, 182363, 0 };
            const std::uint32_t dim17521JoeKuoD6Init[]   =   { 1, 1, 5, 15, 19, 35, 37, 197, 137, 255, 93, 681, 949, 15183, 24785, 39357, 65547, 149013, 0 };
            const std::uint32_t dim17522JoeKuoD6Init[]   =   { 1, 3, 3, 3, 27, 27, 95, 239, 171, 513, 655, 1629, 4577, 3005, 1681, 2581, 59995, 83981, 0 };
            const std::uint32_t dim17523JoeKuoD6Init[]   =   { 1, 3, 3, 7, 29, 33, 111, 85, 437, 297, 1563, 2411, 6171, 2043, 17625, 59093, 995, 211599, 0 };
            const std::uint32_t dim17524JoeKuoD6Init[]   =   { 1, 3, 1, 13, 19, 35, 33, 9, 57, 153, 819, 2017, 5879, 13559, 23135, 25981, 41091, 50975, 0 };
            const std::uint32_t dim17525JoeKuoD6Init[]   =   { 1, 3, 5, 11, 23, 53, 11, 123, 119, 57, 1775, 3457, 7939, 4999, 10771, 23571, 30099, 17361, 0 };
            const std::uint32_t dim17526JoeKuoD6Init[]   =   { 1, 1, 7, 11, 27, 13, 7, 215, 7, 1009, 1967, 1845, 6679, 13781, 21797, 18755, 47131, 245907, 0 };
            const std::uint32_t dim17527JoeKuoD6Init[]   =   { 1, 1, 1, 3, 19, 47, 35, 13, 287, 349, 439, 3125, 2387, 12483, 3833, 29399, 27037, 30235, 0 };
            const std::uint32_t dim17528JoeKuoD6Init[]   =   { 1, 3, 1, 15, 17, 41, 15, 21, 499, 87, 1899, 2835, 1919, 925, 4525, 12935, 25021, 106657, 0 };
            const std::uint32_t dim17529JoeKuoD6Init[]   =   { 1, 1, 1, 13, 17, 59, 73, 75, 443, 199, 1871, 3447, 4517, 8395, 16661, 30655, 17871, 231337, 0 };
            const std::uint32_t dim17530JoeKuoD6Init[]   =   { 1, 1, 7, 1, 1, 53, 17, 49, 259, 77, 917, 631, 6061, 12291, 17715, 49761, 70699, 68313, 0 };
            const std::uint32_t dim17531JoeKuoD6Init[]   =   { 1, 1, 3, 9, 13, 27, 67, 149, 229, 347, 1397, 3457, 6047, 13117, 11, 18121, 70323, 36441, 0 };
            const std::uint32_t dim17532JoeKuoD6Init[]   =   { 1, 3, 5, 7, 27, 13, 69, 177, 451, 87, 647, 3797, 5433, 3137, 20213, 9809, 126877, 55243, 0 };
            const std::uint32_t dim17533JoeKuoD6Init[]   =   { 1, 3, 7, 13, 21, 57, 73, 157, 173, 631, 1527, 337, 5605, 8041, 2181, 19567, 19829, 63353, 0 };
            const std::uint32_t dim17534JoeKuoD6Init[]   =   { 1, 3, 3, 7, 11, 5, 111, 161, 247, 553, 435, 3883, 5639, 10889, 8953, 58297, 15197, 99711, 0 };
            const std::uint32_t dim17535JoeKuoD6Init[]   =   { 1, 1, 7, 13, 11, 29, 71, 251, 387, 1003, 1275, 763, 67, 10597, 5995, 53677, 4683, 2157, 0 };
            const std::uint32_t dim17536JoeKuoD6Init[]   =   { 1, 1, 3, 9, 23, 27, 93, 209, 325, 517, 297, 3215, 4359, 395, 10377, 36967, 69803, 190037, 0 };
            const std::uint32_t dim17537JoeKuoD6Init[]   =   { 1, 1, 1, 3, 27, 61, 21, 229, 469, 3, 387, 523, 4753, 2267, 9879, 32113, 60837, 76205, 0 };
            const std::uint32_t dim17538JoeKuoD6Init[]   =   { 1, 3, 1, 7, 31, 31, 67, 15, 161, 699, 713, 2973, 2007, 693, 21823, 57549, 28989, 157879, 0 };
            const std::uint32_t dim17539JoeKuoD6Init[]   =   { 1, 3, 1, 1, 3, 63, 111, 61, 311, 685, 1029, 345, 6763, 16217, 14505, 9777, 3513, 160985, 0 };
            const std::uint32_t dim17540JoeKuoD6Init[]   =   { 1, 1, 1, 11, 5, 25, 13, 79, 337, 3, 1997, 3489, 7621, 12115, 9221, 7953, 19067, 52697, 0 };
            const std::uint32_t dim17541JoeKuoD6Init[]   =   { 1, 1, 1, 3, 19, 3, 85, 127, 475, 391, 293, 2249, 1211, 1185, 17133, 6753, 65517, 98157, 0 };
            const std::uint32_t dim17542JoeKuoD6Init[]   =   { 1, 1, 5, 9, 11, 31, 57, 107, 315, 983, 1117, 2189, 4813, 9925, 26635, 30589, 32989, 44195, 0 };
            const std::uint32_t dim17543JoeKuoD6Init[]   =   { 1, 1, 7, 7, 21, 1, 1, 221, 421, 199, 539, 3981, 4627, 15655, 12621, 20427, 11619, 187185, 0 };
            const std::uint32_t dim17544JoeKuoD6Init[]   =   { 1, 1, 7, 5, 13, 19, 49, 31, 55, 35, 1847, 3173, 475, 15245, 30907, 50075, 130837, 87283, 0 };
            const std::uint32_t dim17545JoeKuoD6Init[]   =   { 1, 1, 7, 15, 13, 47, 13, 17, 169, 185, 1411, 1689, 2339, 2159, 10591, 52283, 26785, 255707, 0 };
            const std::uint32_t dim17546JoeKuoD6Init[]   =   { 1, 3, 5, 7, 3, 29, 7, 83, 329, 747, 1755, 1067, 2565, 2437, 12309, 15043, 97589, 69409, 0 };
            const std::uint32_t dim17547JoeKuoD6Init[]   =   { 1, 3, 3, 9, 19, 49, 9, 231, 427, 131, 485, 1637, 1129, 14723, 19071, 47997, 74613, 171539, 0 };
            const std::uint32_t dim17548JoeKuoD6Init[]   =   { 1, 1, 1, 1, 5, 17, 105, 39, 313, 407, 1321, 3013, 8035, 4395, 15917, 21105, 53599, 21341, 0 };
            const std::uint32_t dim17549JoeKuoD6Init[]   =   { 1, 3, 1, 15, 7, 35, 5, 153, 485, 1019, 713, 1891, 5023, 13885, 15911, 48215, 81719, 228189, 0 };
            const std::uint32_t dim17550JoeKuoD6Init[]   =   { 1, 1, 3, 3, 19, 3, 103, 55, 221, 847, 27, 1653, 4887, 3617, 30235, 42353, 67007, 21443, 0 };
            const std::uint32_t dim17551JoeKuoD6Init[]   =   { 1, 1, 7, 15, 15, 39, 65, 189, 251, 411, 1953, 1187, 141, 14919, 7763, 50879, 2569, 63467, 0 };
            const std::uint32_t dim17552JoeKuoD6Init[]   =   { 1, 1, 7, 1, 15, 3, 37, 133, 11, 745, 697, 3755, 1233, 2009, 25597, 40661, 40743, 198117, 0 };
            const std::uint32_t dim17553JoeKuoD6Init[]   =   { 1, 1, 7, 15, 5, 17, 13, 253, 197, 491, 1499, 2141, 6803, 13833, 27297, 385, 54341, 64305, 0 };
            const std::uint32_t dim17554JoeKuoD6Init[]   =   { 1, 3, 5, 7, 3, 11, 19, 193, 441, 575, 1649, 1821, 2621, 15803, 7343, 37361, 16467, 60629, 0 };
            const std::uint32_t dim17555JoeKuoD6Init[]   =   { 1, 3, 3, 11, 11, 29, 109, 1, 83, 475, 1913, 1975, 1289, 5221, 24221, 7479, 26683, 203435, 0 };
            const std::uint32_t dim17556JoeKuoD6Init[]   =   { 1, 1, 3, 13, 3, 35, 119, 131, 323, 413, 147, 4009, 3167, 11161, 30523, 65223, 109859, 239317, 0 };
            const std::uint32_t dim17557JoeKuoD6Init[]   =   { 1, 3, 1, 11, 25, 17, 103, 165, 437, 163, 1141, 105, 3655, 8105, 20859, 50727, 27915, 19309, 0 };
            const std::uint32_t dim17558JoeKuoD6Init[]   =   { 1, 3, 3, 11, 9, 59, 17, 135, 131, 781, 675, 2865, 7287, 11431, 3717, 56691, 54971, 83433, 0 };
            const std::uint32_t dim17559JoeKuoD6Init[]   =   { 1, 1, 1, 11, 3, 1, 59, 35, 299, 927, 1761, 823, 287, 13271, 30321, 32895, 45961, 23151, 0 };
            const std::uint32_t dim17560JoeKuoD6Init[]   =   { 1, 3, 3, 7, 11, 3, 11, 115, 241, 497, 1359, 1789, 6677, 2683, 21145, 58185, 46131, 17591, 0 };
            const std::uint32_t dim17561JoeKuoD6Init[]   =   { 1, 3, 1, 3, 17, 5, 65, 169, 247, 1001, 1183, 1801, 759, 2797, 28721, 7549, 112463, 127451, 0 };
            const std::uint32_t dim17562JoeKuoD6Init[]   =   { 1, 1, 1, 11, 1, 49, 5, 227, 333, 793, 759, 2845, 6261, 6325, 6581, 35853, 39737, 21457, 0 };
            const std::uint32_t dim17563JoeKuoD6Init[]   =   { 1, 1, 1, 3, 7, 17, 81, 105, 453, 207, 1113, 301, 4933, 14715, 18815, 29165, 85251, 209171, 0 };
            const std::uint32_t dim17564JoeKuoD6Init[]   =   { 1, 3, 1, 13, 3, 25, 7, 109, 249, 649, 1009, 937, 659, 14605, 13325, 26003, 45507, 166837, 0 };
            const std::uint32_t dim17565JoeKuoD6Init[]   =   { 1, 3, 7, 11, 19, 57, 55, 213, 261, 325, 761, 3167, 6823, 15039, 13329, 30195, 52103, 27877, 0 };
            const std::uint32_t dim17566JoeKuoD6Init[]   =   { 1, 3, 3, 11, 31, 45, 3, 185, 225, 143, 651, 327, 4263, 6005, 31577, 57779, 90485, 48393, 0 };
            const std::uint32_t dim17567JoeKuoD6Init[]   =   { 1, 1, 3, 13, 9, 21, 97, 63, 285, 531, 1275, 175, 693, 3735, 15137, 62193, 80533, 196545, 0 };
            const std::uint32_t dim17568JoeKuoD6Init[]   =   { 1, 1, 1, 11, 5, 25, 101, 111, 101, 17, 1999, 3709, 19, 5087, 20151, 4781, 88417, 186293, 0 };
            const std::uint32_t dim17569JoeKuoD6Init[]   =   { 1, 1, 5, 7, 31, 37, 39, 85, 451, 189, 1521, 619, 5021, 2601, 32447, 43513, 8317, 170611, 0 };
            const std::uint32_t dim17570JoeKuoD6Init[]   =   { 1, 1, 7, 1, 25, 45, 33, 111, 443, 719, 1869, 3619, 5751, 2649, 27823, 55465, 113203, 23875, 0 };
            const std::uint32_t dim17571JoeKuoD6Init[]   =   { 1, 3, 5, 15, 19, 47, 49, 241, 75, 395, 307, 1001, 137, 7029, 21661, 39159, 94129, 106693, 0 };
            const std::uint32_t dim17572JoeKuoD6Init[]   =   { 1, 3, 7, 1, 7, 35, 85, 27, 285, 975, 565, 2119, 5861, 9229, 15877, 25017, 10551, 155357, 0 };
            const std::uint32_t dim17573JoeKuoD6Init[]   =   { 1, 3, 3, 5, 29, 41, 17, 159, 211, 571, 907, 1745, 6541, 11643, 4441, 54599, 83359, 57227, 0 };
            const std::uint32_t dim17574JoeKuoD6Init[]   =   { 1, 3, 7, 5, 19, 11, 37, 191, 75, 443, 1833, 1715, 6949, 2477, 31161, 15647, 84305, 82887, 0 };
            const std::uint32_t dim17575JoeKuoD6Init[]   =   { 1, 1, 3, 9, 29, 35, 87, 11, 147, 443, 1659, 2457, 1615, 16135, 10729, 31583, 111583, 52607, 0 };
            const std::uint32_t dim17576JoeKuoD6Init[]   =   { 1, 3, 7, 1, 7, 47, 55, 133, 53, 23, 225, 2689, 3075, 12435, 8337, 37065, 58631, 247415, 0 };
            const std::uint32_t dim17577JoeKuoD6Init[]   =   { 1, 3, 3, 9, 23, 39, 5, 17, 353, 443, 627, 1609, 5277, 3899, 31111, 5935, 25445, 161043, 0 };
            const std::uint32_t dim17578JoeKuoD6Init[]   =   { 1, 3, 3, 11, 31, 11, 97, 99, 37, 169, 1361, 689, 5481, 5935, 11957, 36761, 105641, 250905, 0 };
            const std::uint32_t dim17579JoeKuoD6Init[]   =   { 1, 1, 7, 15, 31, 33, 3, 201, 125, 649, 315, 497, 7715, 2331, 9081, 16073, 88459, 70475, 0 };
            const std::uint32_t dim17580JoeKuoD6Init[]   =   { 1, 1, 7, 13, 25, 25, 39, 193, 185, 253, 495, 1143, 3745, 3459, 10935, 22029, 70213, 245827, 0 };
            const std::uint32_t dim17581JoeKuoD6Init[]   =   { 1, 3, 3, 11, 1, 47, 93, 27, 117, 755, 1837, 4045, 4839, 3413, 21395, 41905, 6505, 158029, 0 };
            const std::uint32_t dim17582JoeKuoD6Init[]   =   { 1, 3, 5, 5, 3, 41, 23, 207, 3, 409, 1635, 3511, 899, 747, 10623, 44933, 62439, 75577, 0 };
            const std::uint32_t dim17583JoeKuoD6Init[]   =   { 1, 3, 7, 15, 1, 15, 113, 175, 43, 513, 515, 1295, 1903, 9961, 20995, 57319, 40649, 22799, 0 };
            const std::uint32_t dim17584JoeKuoD6Init[]   =   { 1, 1, 5, 9, 7, 25, 99, 167, 117, 547, 777, 3819, 4409, 13465, 3963, 53355, 67895, 58007, 0 };
            const std::uint32_t dim17585JoeKuoD6Init[]   =   { 1, 1, 5, 9, 25, 9, 11, 113, 455, 563, 143, 1507, 4055, 6805, 25027, 37645, 475, 193193, 0 };
            const std::uint32_t dim17586JoeKuoD6Init[]   =   { 1, 1, 1, 11, 15, 27, 123, 199, 229, 27, 1285, 4013, 6541, 11203, 23705, 56821, 59665, 151109, 0 };
            const std::uint32_t dim17587JoeKuoD6Init[]   =   { 1, 1, 3, 1, 31, 19, 27, 129, 235, 407, 865, 2723, 5387, 7727, 2309, 45787, 118107, 199907, 0 };
            const std::uint32_t dim17588JoeKuoD6Init[]   =   { 1, 1, 5, 15, 17, 1, 21, 167, 165, 203, 745, 825, 7993, 15191, 13731, 13417, 543, 201511, 0 };
            const std::uint32_t dim17589JoeKuoD6Init[]   =   { 1, 3, 1, 1, 29, 49, 45, 81, 321, 755, 1319, 633, 4889, 7809, 6305, 58233, 20213, 144915, 0 };
            const std::uint32_t dim17590JoeKuoD6Init[]   =   { 1, 1, 3, 13, 1, 31, 73, 173, 111, 961, 1995, 3827, 879, 5567, 31103, 13227, 126611, 204507, 0 };
            const std::uint32_t dim17591JoeKuoD6Init[]   =   { 1, 1, 3, 7, 21, 3, 75, 137, 125, 981, 1991, 1167, 1249, 3821, 19503, 52855, 122329, 68717, 0 };
            const std::uint32_t dim17592JoeKuoD6Init[]   =   { 1, 1, 1, 13, 17, 17, 69, 167, 327, 635, 427, 2125, 7499, 9715, 24097, 39361, 64301, 63411, 0 };
            const std::uint32_t dim17593JoeKuoD6Init[]   =   { 1, 1, 1, 1, 31, 57, 55, 31, 289, 251, 823, 2301, 5965, 3381, 479, 39545, 93051, 68683, 0 };
            const std::uint32_t dim17594JoeKuoD6Init[]   =   { 1, 1, 3, 3, 15, 27, 117, 37, 29, 851, 1891, 3507, 6279, 323, 11451, 57961, 41487, 188359, 0 };
            const std::uint32_t dim17595JoeKuoD6Init[]   =   { 1, 1, 5, 1, 25, 55, 125, 207, 129, 849, 589, 1381, 3395, 645, 1157, 29285, 105423, 104429, 0 };
            const std::uint32_t dim17596JoeKuoD6Init[]   =   { 1, 1, 7, 7, 9, 47, 41, 103, 473, 395, 883, 1087, 2827, 9685, 6313, 15461, 39803, 254865, 0 };
            const std::uint32_t dim17597JoeKuoD6Init[]   =   { 1, 1, 7, 3, 17, 55, 71, 119, 159, 185, 1415, 3033, 3045, 1403, 18349, 2727, 123995, 45953, 0 };
            const std::uint32_t dim17598JoeKuoD6Init[]   =   { 1, 1, 3, 15, 17, 11, 19, 25, 483, 29, 1329, 1779, 2885, 6655, 28327, 42255, 87555, 211051, 0 };
            const std::uint32_t dim17599JoeKuoD6Init[]   =   { 1, 3, 5, 11, 29, 19, 43, 141, 157, 87, 1091, 3505, 3139, 11919, 12123, 31581, 116229, 167875, 0 };
            const std::uint32_t dim17600JoeKuoD6Init[]   =   { 1, 3, 1, 5, 25, 55, 113, 219, 491, 607, 1641, 3833, 3153, 1881, 16027, 39923, 38551, 204819, 0 };
            const std::uint32_t dim17601JoeKuoD6Init[]   =   { 1, 1, 5, 3, 7, 9, 73, 181, 305, 211, 1699, 983, 3051, 11643, 12445, 44827, 74613, 199699, 0 };
            const std::uint32_t dim17602JoeKuoD6Init[]   =   { 1, 1, 3, 5, 23, 21, 115, 49, 311, 205, 963, 1357, 4013, 8357, 7065, 47757, 7937, 249935, 0 };
            const std::uint32_t dim17603JoeKuoD6Init[]   =   { 1, 1, 1, 9, 23, 61, 21, 165, 9, 829, 457, 3975, 5831, 10901, 15871, 36769, 45899, 162083, 0 };
            const std::uint32_t dim17604JoeKuoD6Init[]   =   { 1, 1, 3, 3, 25, 41, 91, 45, 37, 939, 299, 3815, 6433, 3121, 10585, 62125, 51333, 171615, 0 };
            const std::uint32_t dim17605JoeKuoD6Init[]   =   { 1, 1, 5, 11, 1, 1, 39, 45, 141, 803, 1493, 1151, 6243, 8683, 30223, 53661, 7949, 197291, 0 };
            const std::uint32_t dim17606JoeKuoD6Init[]   =   { 1, 1, 3, 1, 17, 35, 29, 253, 395, 933, 1015, 3431, 139, 9095, 30745, 39747, 58837, 28517, 0 };
            const std::uint32_t dim17607JoeKuoD6Init[]   =   { 1, 1, 5, 3, 21, 17, 105, 21, 249, 387, 1985, 951, 6323, 8221, 24601, 57367, 18751, 240661, 0 };
            const std::uint32_t dim17608JoeKuoD6Init[]   =   { 1, 1, 7, 9, 5, 21, 23, 149, 243, 501, 935, 855, 1821, 15885, 2239, 39091, 93615, 31411, 0 };
            const std::uint32_t dim17609JoeKuoD6Init[]   =   { 1, 1, 1, 3, 23, 11, 43, 5, 65, 193, 1723, 3253, 7533, 12987, 571, 56073, 125061, 97117, 0 };
            const std::uint32_t dim17610JoeKuoD6Init[]   =   { 1, 1, 1, 13, 13, 21, 113, 79, 115, 867, 777, 2199, 501, 2913, 18697, 14959, 18369, 41631, 0 };
            const std::uint32_t dim17611JoeKuoD6Init[]   =   { 1, 1, 7, 13, 13, 53, 101, 165, 447, 995, 587, 201, 1701, 6429, 8647, 59265, 27321, 110841, 0 };
            const std::uint32_t dim17612JoeKuoD6Init[]   =   { 1, 3, 1, 3, 25, 35, 67, 95, 173, 877, 1133, 3027, 2321, 12517, 4313, 24469, 40313, 253095, 0 };
            const std::uint32_t dim17613JoeKuoD6Init[]   =   { 1, 1, 1, 9, 17, 33, 103, 141, 259, 963, 1975, 2979, 5017, 15689, 30659, 55145, 73737, 43539, 0 };
            const std::uint32_t dim17614JoeKuoD6Init[]   =   { 1, 3, 1, 15, 7, 7, 7, 1, 267, 415, 1591, 17, 2451, 13415, 6993, 16631, 90019, 237161, 0 };
            const std::uint32_t dim17615JoeKuoD6Init[]   =   { 1, 1, 7, 11, 11, 37, 107, 143, 263, 49, 1391, 3269, 6139, 1413, 26557, 16369, 86789, 89151, 0 };
            const std::uint32_t dim17616JoeKuoD6Init[]   =   { 1, 1, 7, 13, 27, 41, 3, 169, 453, 547, 157, 3219, 4711, 9805, 10657, 8121, 40229, 247825, 0 };
            const std::uint32_t dim17617JoeKuoD6Init[]   =   { 1, 3, 3, 3, 25, 25, 109, 253, 67, 901, 259, 1159, 6161, 6763, 19669, 42775, 74089, 69821, 0 };
            const std::uint32_t dim17618JoeKuoD6Init[]   =   { 1, 3, 7, 15, 11, 25, 91, 137, 247, 851, 511, 1847, 1179, 411, 9545, 31275, 46201, 169677, 0 };
            const std::uint32_t dim17619JoeKuoD6Init[]   =   { 1, 1, 5, 3, 3, 61, 19, 167, 491, 765, 1997, 3267, 883, 15439, 27581, 24865, 128245, 130055, 0 };
            const std::uint32_t dim17620JoeKuoD6Init[]   =   { 1, 1, 3, 9, 17, 61, 7, 109, 325, 347, 1109, 889, 2995, 4763, 21551, 60137, 91833, 126989, 0 };
            const std::uint32_t dim17621JoeKuoD6Init[]   =   { 1, 3, 3, 7, 5, 17, 61, 107, 209, 577, 885, 2611, 1471, 7549, 16199, 12319, 48865, 242229, 0 };
            const std::uint32_t dim17622JoeKuoD6Init[]   =   { 1, 3, 5, 1, 5, 49, 85, 177, 213, 583, 857, 179, 1805, 4297, 5835, 61923, 22741, 261983, 0 };
            const std::uint32_t dim17623JoeKuoD6Init[]   =   { 1, 3, 1, 13, 1, 1, 83, 227, 457, 375, 567, 1563, 2085, 8153, 12563, 44561, 115487, 188351, 0 };
            const std::uint32_t dim17624JoeKuoD6Init[]   =   { 1, 3, 1, 9, 15, 39, 127, 135, 181, 967, 1495, 3187, 7463, 9651, 26261, 57435, 42069, 48549, 0 };
            const std::uint32_t dim17625JoeKuoD6Init[]   =   { 1, 3, 1, 7, 5, 31, 111, 19, 19, 855, 273, 2089, 6001, 2799, 26013, 6625, 75623, 150185, 0 };
            const std::uint32_t dim17626JoeKuoD6Init[]   =   { 1, 1, 7, 1, 31, 19, 15, 159, 35, 791, 1005, 3947, 7031, 41, 28807, 45299, 37761, 101191, 0 };
            const std::uint32_t dim17627JoeKuoD6Init[]   =   { 1, 3, 5, 3, 15, 7, 7, 67, 329, 367, 843, 2309, 3023, 5369, 21561, 18881, 14395, 193369, 0 };
            const std::uint32_t dim17628JoeKuoD6Init[]   =   { 1, 3, 3, 11, 21, 53, 3, 251, 87, 131, 563, 847, 8049, 1639, 30103, 30461, 108427, 125197, 0 };
            const std::uint32_t dim17629JoeKuoD6Init[]   =   { 1, 1, 1, 5, 21, 45, 79, 229, 29, 133, 1873, 261, 4221, 3091, 25569, 11219, 70693, 227025, 0 };
            const std::uint32_t dim17630JoeKuoD6Init[]   =   { 1, 3, 1, 5, 17, 9, 75, 101, 155, 311, 789, 821, 7361, 3791, 18511, 57607, 97647, 42107, 0 };
            const std::uint32_t dim17631JoeKuoD6Init[]   =   { 1, 3, 1, 11, 21, 39, 33, 179, 7, 775, 55, 3779, 6163, 3575, 27535, 32363, 9169, 57133, 0 };
            const std::uint32_t dim17632JoeKuoD6Init[]   =   { 1, 3, 7, 3, 19, 33, 19, 11, 173, 175, 219, 3585, 1115, 15693, 23481, 45669, 94149, 19531, 0 };
            const std::uint32_t dim17633JoeKuoD6Init[]   =   { 1, 1, 5, 11, 11, 49, 29, 217, 229, 757, 1031, 3833, 4235, 13535, 8765, 20707, 52851, 9037, 0 };
            const std::uint32_t dim17634JoeKuoD6Init[]   =   { 1, 3, 1, 13, 25, 61, 65, 111, 95, 533, 1235, 2947, 3239, 9513, 11395, 9321, 117535, 228289, 0 };
            const std::uint32_t dim17635JoeKuoD6Init[]   =   { 1, 1, 1, 3, 19, 33, 13, 233, 331, 811, 1931, 1109, 7705, 3129, 19757, 44325, 97903, 165311, 0 };
            const std::uint32_t dim17636JoeKuoD6Init[]   =   { 1, 1, 3, 15, 13, 55, 57, 81, 257, 613, 1305, 653, 6059, 4935, 15707, 4717, 1859, 109265, 0 };
            const std::uint32_t dim17637JoeKuoD6Init[]   =   { 1, 1, 7, 15, 15, 19, 19, 91, 213, 311, 1651, 2215, 6985, 2989, 11961, 28647, 111163, 217187, 0 };
            const std::uint32_t dim17638JoeKuoD6Init[]   =   { 1, 3, 3, 5, 15, 31, 45, 193, 119, 11, 511, 3155, 5989, 813, 32655, 41531, 121007, 24733, 0 };
            const std::uint32_t dim17639JoeKuoD6Init[]   =   { 1, 3, 7, 1, 19, 63, 61, 11, 225, 677, 1323, 1655, 7607, 15691, 27083, 56743, 116167, 250413, 0 };
            const std::uint32_t dim17640JoeKuoD6Init[]   =   { 1, 1, 1, 15, 7, 25, 27, 213, 171, 1011, 1483, 119, 6849, 12527, 20601, 35701, 68377, 245669, 0 };
            const std::uint32_t dim17641JoeKuoD6Init[]   =   { 1, 3, 7, 5, 27, 5, 7, 117, 127, 871, 631, 3395, 1501, 4839, 1857, 45769, 107597, 90385, 0 };
            const std::uint32_t dim17642JoeKuoD6Init[]   =   { 1, 1, 3, 13, 1, 15, 49, 69, 479, 919, 881, 3069, 5609, 12795, 30225, 14411, 122847, 75569, 0 };
            const std::uint32_t dim17643JoeKuoD6Init[]   =   { 1, 1, 5, 9, 1, 15, 91, 207, 235, 667, 321, 2047, 841, 16049, 12499, 8799, 8245, 42199, 0 };
            const std::uint32_t dim17644JoeKuoD6Init[]   =   { 1, 3, 7, 15, 11, 19, 99, 163, 331, 953, 791, 3443, 3215, 8025, 1999, 43685, 72595, 153185, 0 };
            const std::uint32_t dim17645JoeKuoD6Init[]   =   { 1, 3, 1, 13, 25, 23, 17, 133, 59, 233, 151, 1971, 3611, 3951, 16979, 991, 73325, 158475, 0 };
            const std::uint32_t dim17646JoeKuoD6Init[]   =   { 1, 3, 5, 11, 1, 53, 123, 81, 285, 457, 1183, 489, 939, 3069, 15845, 24799, 81301, 105187, 0 };
            const std::uint32_t dim17647JoeKuoD6Init[]   =   { 1, 3, 5, 1, 11, 5, 61, 151, 5, 813, 1347, 1107, 4915, 4035, 18709, 20909, 60569, 55007, 0 };
            const std::uint32_t dim17648JoeKuoD6Init[]   =   { 1, 3, 3, 7, 27, 41, 79, 193, 471, 415, 937, 2561, 1669, 9213, 21145, 44917, 64763, 33195, 0 };
            const std::uint32_t dim17649JoeKuoD6Init[]   =   { 1, 3, 7, 13, 31, 5, 71, 237, 419, 957, 1741, 2829, 5879, 8143, 8717, 48995, 114465, 110295, 0 };
            const std::uint32_t dim17650JoeKuoD6Init[]   =   { 1, 1, 7, 3, 7, 23, 83, 161, 381, 313, 383, 2813, 333, 4647, 18321, 10437, 111645, 55509, 0 };
            const std::uint32_t dim17651JoeKuoD6Init[]   =   { 1, 1, 5, 9, 23, 1, 83, 121, 245, 37, 1097, 1437, 3891, 2727, 30775, 27649, 95571, 216245, 0 };
            const std::uint32_t dim17652JoeKuoD6Init[]   =   { 1, 1, 5, 7, 1, 43, 59, 253, 329, 421, 791, 3945, 2599, 2243, 11121, 37761, 27223, 176867, 0 };
            const std::uint32_t dim17653JoeKuoD6Init[]   =   { 1, 3, 5, 5, 25, 59, 85, 155, 367, 291, 1025, 1415, 7871, 14191, 23249, 32233, 93253, 177869, 0 };
            const std::uint32_t dim17654JoeKuoD6Init[]   =   { 1, 1, 1, 9, 21, 41, 111, 241, 177, 999, 779, 2827, 1683, 6405, 16133, 26523, 102567, 190313, 0 };
            const std::uint32_t dim17655JoeKuoD6Init[]   =   { 1, 3, 3, 15, 13, 59, 69, 239, 231, 511, 1675, 147, 4041, 3723, 29191, 24913, 15601, 198141, 0 };
            const std::uint32_t dim17656JoeKuoD6Init[]   =   { 1, 3, 3, 9, 17, 29, 1, 107, 243, 509, 1949, 205, 1693, 6339, 31591, 61527, 128043, 222497, 0 };
            const std::uint32_t dim17657JoeKuoD6Init[]   =   { 1, 3, 7, 3, 21, 7, 87, 57, 9, 209, 1831, 2189, 5523, 8509, 23687, 46221, 87469, 146815, 0 };
            const std::uint32_t dim17658JoeKuoD6Init[]   =   { 1, 3, 7, 9, 5, 45, 51, 207, 401, 681, 469, 1951, 793, 16379, 32143, 55457, 91787, 178569, 0 };
            const std::uint32_t dim17659JoeKuoD6Init[]   =   { 1, 3, 3, 9, 19, 15, 121, 143, 243, 795, 1839, 2411, 7175, 11535, 31995, 4157, 20111, 92653, 0 };
            const std::uint32_t dim17660JoeKuoD6Init[]   =   { 1, 3, 1, 1, 1, 5, 47, 107, 455, 429, 1411, 2375, 2823, 14657, 16297, 21893, 115257, 50343, 0 };
            const std::uint32_t dim17661JoeKuoD6Init[]   =   { 1, 3, 5, 9, 19, 63, 55, 197, 281, 797, 1539, 2601, 4497, 1631, 26583, 23819, 104553, 27285, 0 };
            const std::uint32_t dim17662JoeKuoD6Init[]   =   { 1, 1, 3, 9, 23, 41, 123, 37, 327, 789, 1711, 1299, 6735, 7243, 30635, 21251, 56081, 65623, 0 };
            const std::uint32_t dim17663JoeKuoD6Init[]   =   { 1, 3, 7, 15, 25, 49, 89, 231, 133, 1003, 351, 765, 7115, 16239, 1141, 44063, 31519, 233719, 0 };
            const std::uint32_t dim17664JoeKuoD6Init[]   =   { 1, 3, 7, 3, 13, 37, 93, 83, 59, 539, 1185, 525, 705, 993, 1113, 1871, 60817, 254075, 0 };
            const std::uint32_t dim17665JoeKuoD6Init[]   =   { 1, 3, 7, 11, 25, 33, 23, 21, 141, 451, 25, 1321, 5139, 8947, 10305, 30175, 43123, 113049, 0 };
            const std::uint32_t dim17666JoeKuoD6Init[]   =   { 1, 3, 5, 5, 17, 1, 125, 211, 143, 637, 1175, 1149, 6775, 11091, 12503, 5537, 35379, 30045, 0 };
            const std::uint32_t dim17667JoeKuoD6Init[]   =   { 1, 1, 1, 15, 17, 31, 123, 33, 279, 831, 1247, 2305, 1033, 3201, 231, 23173, 34453, 66617, 0 };
            const std::uint32_t dim17668JoeKuoD6Init[]   =   { 1, 3, 3, 1, 3, 1, 23, 115, 421, 553, 273, 4091, 5965, 7521, 18393, 31229, 78533, 243921, 0 };
            const std::uint32_t dim17669JoeKuoD6Init[]   =   { 1, 1, 7, 15, 15, 29, 73, 165, 391, 215, 1801, 45, 7451, 6969, 27897, 36599, 103647, 145165, 0 };
            const std::uint32_t dim17670JoeKuoD6Init[]   =   { 1, 3, 3, 13, 5, 7, 67, 81, 477, 301, 1397, 921, 3777, 12431, 14753, 50555, 24497, 52995, 0 };
            const std::uint32_t dim17671JoeKuoD6Init[]   =   { 1, 1, 5, 5, 27, 21, 91, 155, 405, 347, 1135, 3701, 2471, 577, 3927, 52605, 1725, 25803, 0 };
            const std::uint32_t dim17672JoeKuoD6Init[]   =   { 1, 3, 1, 3, 15, 57, 117, 175, 437, 13, 1821, 649, 899, 1295, 2753, 2183, 47923, 163407, 0 };
            const std::uint32_t dim17673JoeKuoD6Init[]   =   { 1, 3, 5, 9, 23, 15, 103, 179, 233, 787, 715, 3751, 3321, 2069, 8299, 43417, 96549, 180737, 0 };
            const std::uint32_t dim17674JoeKuoD6Init[]   =   { 1, 3, 7, 9, 1, 41, 81, 205, 141, 707, 397, 763, 4797, 8843, 3311, 37425, 43873, 131491, 0 };
            const std::uint32_t dim17675JoeKuoD6Init[]   =   { 1, 1, 5, 3, 9, 29, 123, 163, 15, 871, 159, 2615, 6987, 471, 25653, 11295, 94481, 195409, 0 };
            const std::uint32_t dim17676JoeKuoD6Init[]   =   { 1, 3, 7, 3, 13, 7, 9, 59, 59, 381, 2027, 2639, 59, 7977, 14505, 34327, 99113, 157439, 0 };
            const std::uint32_t dim17677JoeKuoD6Init[]   =   { 1, 1, 5, 9, 27, 13, 87, 85, 443, 531, 1069, 3479, 6547, 13943, 13711, 11007, 37395, 190293, 0 };
            const std::uint32_t dim17678JoeKuoD6Init[]   =   { 1, 3, 7, 9, 19, 47, 95, 229, 395, 979, 359, 1799, 7389, 14377, 19371, 56785, 6699, 215433, 0 };
            const std::uint32_t dim17679JoeKuoD6Init[]   =   { 1, 1, 1, 5, 21, 15, 59, 17, 281, 585, 293, 3029, 2539, 16089, 19, 34757, 115811, 235565, 0 };
            const std::uint32_t dim17680JoeKuoD6Init[]   =   { 1, 1, 7, 11, 27, 19, 55, 217, 475, 119, 1291, 1761, 6879, 4355, 30019, 17573, 14987, 204623, 0 };
            const std::uint32_t dim17681JoeKuoD6Init[]   =   { 1, 1, 7, 11, 29, 47, 5, 201, 165, 845, 385, 2903, 7735, 10855, 14171, 17881, 45001, 100725, 0 };
            const std::uint32_t dim17682JoeKuoD6Init[]   =   { 1, 1, 5, 5, 31, 57, 99, 35, 315, 363, 1135, 897, 1041, 729, 26987, 15299, 29563, 67293, 0 };
            const std::uint32_t dim17683JoeKuoD6Init[]   =   { 1, 1, 5, 7, 27, 13, 99, 81, 491, 887, 1309, 3343, 7241, 1289, 12021, 52533, 101799, 238721, 0 };
            const std::uint32_t dim17684JoeKuoD6Init[]   =   { 1, 1, 1, 11, 27, 49, 79, 235, 49, 215, 2003, 2771, 5943, 1183, 31931, 33885, 56971, 52665, 0 };
            const std::uint32_t dim17685JoeKuoD6Init[]   =   { 1, 1, 1, 13, 13, 1, 123, 1, 191, 747, 859, 2287, 5113, 3715, 2217, 61483, 195, 237163, 0 };
            const std::uint32_t dim17686JoeKuoD6Init[]   =   { 1, 3, 7, 15, 13, 13, 17, 207, 141, 821, 231, 1373, 5355, 6503, 2403, 18183, 83717, 170047, 0 };
            const std::uint32_t dim17687JoeKuoD6Init[]   =   { 1, 3, 1, 3, 13, 11, 41, 51, 443, 201, 1349, 2331, 1009, 16169, 5247, 50315, 15589, 150497, 0 };
            const std::uint32_t dim17688JoeKuoD6Init[]   =   { 1, 3, 5, 13, 29, 21, 93, 55, 27, 17, 1615, 3473, 3641, 10999, 31955, 4699, 23585, 141243, 0 };
            const std::uint32_t dim17689JoeKuoD6Init[]   =   { 1, 3, 3, 11, 11, 27, 125, 139, 53, 637, 241, 2651, 4999, 5923, 16203, 13645, 95965, 94459, 0 };
            const std::uint32_t dim17690JoeKuoD6Init[]   =   { 1, 3, 7, 3, 9, 53, 87, 171, 489, 691, 303, 3599, 6093, 841, 3527, 12953, 22907, 69823, 0 };
            const std::uint32_t dim17691JoeKuoD6Init[]   =   { 1, 1, 5, 13, 31, 11, 33, 207, 437, 683, 703, 1757, 1443, 14269, 12677, 20877, 46791, 176135, 0 };
            const std::uint32_t dim17692JoeKuoD6Init[]   =   { 1, 1, 7, 1, 13, 53, 123, 199, 173, 585, 1099, 3653, 2253, 13741, 15675, 38755, 74545, 139053, 0 };
            const std::uint32_t dim17693JoeKuoD6Init[]   =   { 1, 3, 3, 3, 17, 11, 1, 161, 383, 409, 605, 889, 827, 263, 9677, 42857, 127691, 99621, 0 };
            const std::uint32_t dim17694JoeKuoD6Init[]   =   { 1, 3, 5, 9, 21, 21, 11, 151, 199, 695, 493, 569, 881, 10533, 11255, 61997, 124921, 211139, 0 };
            const std::uint32_t dim17695JoeKuoD6Init[]   =   { 1, 3, 5, 5, 9, 47, 109, 7, 195, 287, 97, 3691, 6929, 6985, 3063, 16185, 6313, 228147, 0 };
            const std::uint32_t dim17696JoeKuoD6Init[]   =   { 1, 3, 1, 3, 3, 9, 107, 243, 391, 893, 1207, 2229, 5295, 723, 14753, 10921, 104147, 214941, 0 };
            const std::uint32_t dim17697JoeKuoD6Init[]   =   { 1, 3, 1, 9, 5, 63, 63, 247, 413, 805, 285, 4001, 6735, 3531, 25949, 44845, 66959, 194429, 0 };
            const std::uint32_t dim17698JoeKuoD6Init[]   =   { 1, 1, 3, 1, 15, 15, 43, 69, 419, 739, 1739, 1091, 1043, 3217, 1139, 44749, 74131, 165145, 0 };
            const std::uint32_t dim17699JoeKuoD6Init[]   =   { 1, 1, 3, 9, 17, 53, 119, 25, 427, 791, 1873, 481, 6793, 4767, 30449, 18079, 52105, 260371, 0 };
            const std::uint32_t dim17700JoeKuoD6Init[]   =   { 1, 1, 3, 15, 15, 41, 15, 53, 395, 571, 1727, 3081, 4531, 4215, 22359, 18165, 91843, 157273, 0 };
            const std::uint32_t dim17701JoeKuoD6Init[]   =   { 1, 3, 3, 9, 19, 15, 55, 185, 321, 285, 695, 1067, 2551, 1401, 20023, 22671, 21365, 89053, 0 };
            const std::uint32_t dim17702JoeKuoD6Init[]   =   { 1, 1, 7, 15, 23, 57, 71, 141, 57, 479, 543, 3783, 3635, 14011, 23603, 40877, 21837, 81079, 0 };
            const std::uint32_t dim17703JoeKuoD6Init[]   =   { 1, 3, 7, 11, 31, 5, 83, 177, 105, 981, 331, 2901, 1781, 8407, 30199, 19287, 116219, 78471, 0 };
            const std::uint32_t dim17704JoeKuoD6Init[]   =   { 1, 1, 1, 9, 7, 13, 61, 21, 299, 15, 1045, 475, 7141, 4827, 5921, 17323, 42909, 203623, 0 };
            const std::uint32_t dim17705JoeKuoD6Init[]   =   { 1, 3, 7, 1, 17, 59, 99, 221, 77, 37, 1263, 2137, 1567, 12473, 20029, 9231, 32739, 17021, 0 };
            const std::uint32_t dim17706JoeKuoD6Init[]   =   { 1, 1, 1, 5, 23, 61, 39, 13, 97, 191, 1479, 19, 1913, 3185, 32393, 59067, 5483, 158895, 0 };
            const std::uint32_t dim17707JoeKuoD6Init[]   =   { 1, 1, 1, 7, 5, 51, 81, 223, 435, 939, 781, 1153, 6409, 6369, 30559, 19007, 50121, 26525, 0 };
            const std::uint32_t dim17708JoeKuoD6Init[]   =   { 1, 3, 3, 5, 29, 1, 57, 127, 153, 897, 161, 683, 295, 11207, 245, 1819, 3061, 242609, 0 };
            const std::uint32_t dim17709JoeKuoD6Init[]   =   { 1, 1, 1, 7, 5, 19, 105, 57, 263, 433, 1339, 1479, 6671, 9917, 26299, 4573, 68725, 195, 0 };
            const std::uint32_t dim17710JoeKuoD6Init[]   =   { 1, 3, 5, 15, 1, 19, 45, 95, 155, 117, 367, 2051, 1053, 8847, 6399, 23641, 95355, 98415, 0 };
            const std::uint32_t dim17711JoeKuoD6Init[]   =   { 1, 3, 3, 15, 3, 1, 5, 115, 349, 747, 1865, 1669, 659, 7097, 7871, 3685, 11013, 59837, 0 };
            const std::uint32_t dim17712JoeKuoD6Init[]   =   { 1, 3, 3, 5, 9, 47, 51, 131, 327, 903, 975, 2481, 3509, 12481, 4049, 38053, 4629, 254415, 0 };
            const std::uint32_t dim17713JoeKuoD6Init[]   =   { 1, 3, 5, 9, 31, 47, 1, 29, 37, 683, 1363, 2527, 4019, 4965, 14077, 14191, 101, 1945, 0 };
            const std::uint32_t dim17714JoeKuoD6Init[]   =   { 1, 1, 7, 1, 9, 35, 41, 187, 509, 33, 385, 3907, 1461, 6827, 6931, 44723, 109495, 184641, 0 };
            const std::uint32_t dim17715JoeKuoD6Init[]   =   { 1, 3, 5, 9, 5, 49, 21, 171, 353, 927, 409, 913, 5199, 11747, 8777, 19891, 63189, 118839, 0 };
            const std::uint32_t dim17716JoeKuoD6Init[]   =   { 1, 3, 3, 1, 27, 49, 43, 157, 75, 469, 787, 3957, 4147, 13919, 17489, 57103, 62091, 135589, 0 };
            const std::uint32_t dim17717JoeKuoD6Init[]   =   { 1, 1, 3, 11, 7, 45, 29, 177, 185, 185, 1537, 127, 121, 817, 31269, 1677, 20245, 3835, 0 };
            const std::uint32_t dim17718JoeKuoD6Init[]   =   { 1, 1, 5, 3, 21, 9, 67, 79, 391, 971, 1711, 2607, 5705, 12863, 12415, 41255, 26447, 1643, 0 };
            const std::uint32_t dim17719JoeKuoD6Init[]   =   { 1, 1, 5, 5, 9, 63, 67, 245, 31, 225, 309, 1753, 1507, 817, 4275, 51843, 22331, 196875, 0 };
            const std::uint32_t dim17720JoeKuoD6Init[]   =   { 1, 3, 1, 13, 15, 39, 3, 245, 147, 485, 241, 2507, 1859, 7299, 15037, 41139, 82757, 224031, 0 };
            const std::uint32_t dim17721JoeKuoD6Init[]   =   { 1, 3, 3, 15, 7, 51, 9, 103, 37, 643, 25, 2067, 7619, 11991, 12885, 46809, 109107, 22393, 0 };
            const std::uint32_t dim17722JoeKuoD6Init[]   =   { 1, 1, 1, 9, 1, 55, 119, 85, 115, 827, 187, 2241, 2553, 577, 12115, 2391, 69705, 232101, 0 };
            const std::uint32_t dim17723JoeKuoD6Init[]   =   { 1, 1, 5, 7, 13, 61, 125, 129, 475, 703, 1723, 3233, 5713, 1941, 21375, 42119, 75199, 73163, 0 };
            const std::uint32_t dim17724JoeKuoD6Init[]   =   { 1, 1, 5, 5, 5, 21, 73, 155, 493, 81, 1627, 827, 5925, 7391, 1587, 39425, 11807, 64385, 0 };
            const std::uint32_t dim17725JoeKuoD6Init[]   =   { 1, 3, 1, 15, 27, 35, 111, 183, 283, 335, 1387, 669, 6041, 11637, 26255, 21113, 121183, 219703, 0 };
            const std::uint32_t dim17726JoeKuoD6Init[]   =   { 1, 3, 5, 15, 15, 23, 119, 91, 197, 809, 975, 3275, 6171, 11769, 8385, 5461, 4561, 29159, 0 };
            const std::uint32_t dim17727JoeKuoD6Init[]   =   { 1, 1, 5, 9, 29, 9, 107, 233, 417, 1005, 799, 1437, 2679, 15643, 32341, 54055, 27861, 115483, 0 };
            const std::uint32_t dim17728JoeKuoD6Init[]   =   { 1, 1, 5, 7, 27, 19, 95, 153, 175, 407, 215, 303, 8165, 14791, 2099, 61797, 129411, 10461, 0 };
            const std::uint32_t dim17729JoeKuoD6Init[]   =   { 1, 1, 1, 13, 25, 51, 11, 77, 97, 495, 971, 449, 2833, 7121, 24105, 34527, 123135, 129305, 0 };
            const std::uint32_t dim17730JoeKuoD6Init[]   =   { 1, 1, 7, 11, 23, 9, 111, 101, 169, 233, 267, 953, 6379, 15887, 22921, 33665, 95195, 159707, 0 };
            const std::uint32_t dim17731JoeKuoD6Init[]   =   { 1, 1, 5, 15, 21, 3, 21, 57, 173, 513, 2027, 1235, 5031, 5375, 2717, 23361, 71817, 232101, 0 };
            const std::uint32_t dim17732JoeKuoD6Init[]   =   { 1, 3, 3, 11, 7, 25, 43, 65, 19, 135, 1611, 85, 7673, 6459, 27813, 55557, 100989, 25205, 0 };
            const std::uint32_t dim17733JoeKuoD6Init[]   =   { 1, 3, 7, 1, 15, 37, 55, 141, 239, 205, 647, 3715, 1617, 13507, 9847, 64681, 108711, 231329, 0 };
            const std::uint32_t dim17734JoeKuoD6Init[]   =   { 1, 3, 5, 9, 21, 27, 79, 153, 335, 299, 493, 887, 1457, 16011, 13795, 50205, 43319, 130963, 0 };
            const std::uint32_t dim17735JoeKuoD6Init[]   =   { 1, 1, 3, 1, 23, 59, 121, 83, 463, 151, 323, 2977, 4769, 6011, 20135, 59541, 23179, 203487, 0 };
            const std::uint32_t dim17736JoeKuoD6Init[]   =   { 1, 1, 5, 7, 9, 17, 63, 149, 59, 281, 763, 619, 2551, 8179, 2963, 61283, 107727, 119817, 0 };
            const std::uint32_t dim17737JoeKuoD6Init[]   =   { 1, 3, 7, 3, 15, 39, 11, 145, 141, 965, 505, 2625, 4335, 7619, 11007, 43321, 33199, 212661, 0 };
            const std::uint32_t dim17738JoeKuoD6Init[]   =   { 1, 3, 5, 9, 9, 61, 27, 223, 5, 941, 513, 1437, 481, 9651, 6567, 57945, 52547, 21283, 0 };
            const std::uint32_t dim17739JoeKuoD6Init[]   =   { 1, 3, 1, 1, 25, 1, 87, 25, 121, 757, 529, 3857, 1321, 13479, 5357, 49341, 5797, 235895, 0 };
            const std::uint32_t dim17740JoeKuoD6Init[]   =   { 1, 3, 5, 1, 21, 35, 37, 215, 509, 165, 1423, 3067, 4779, 4693, 12523, 48099, 69283, 255111, 0 };
            const std::uint32_t dim17741JoeKuoD6Init[]   =   { 1, 1, 3, 1, 31, 15, 45, 127, 339, 331, 1249, 1075, 6169, 2941, 30471, 46789, 118039, 224651, 0 };
            const std::uint32_t dim17742JoeKuoD6Init[]   =   { 1, 1, 5, 13, 21, 37, 39, 61, 191, 17, 177, 3719, 2177, 11039, 20047, 14489, 20475, 171235, 0 };
            const std::uint32_t dim17743JoeKuoD6Init[]   =   { 1, 1, 3, 9, 19, 11, 65, 111, 121, 901, 99, 1861, 3687, 765, 24861, 46315, 63433, 171679, 0 };
            const std::uint32_t dim17744JoeKuoD6Init[]   =   { 1, 3, 1, 7, 1, 51, 87, 199, 241, 909, 353, 2471, 7163, 9547, 16351, 41129, 12217, 194099, 0 };
            const std::uint32_t dim17745JoeKuoD6Init[]   =   { 1, 1, 7, 7, 17, 17, 127, 67, 51, 217, 1189, 19, 2099, 10281, 9071, 21185, 122821, 110211, 0 };
            const std::uint32_t dim17746JoeKuoD6Init[]   =   { 1, 3, 3, 7, 15, 3, 53, 45, 77, 665, 701, 3175, 6151, 2639, 19819, 1063, 25079, 203343, 0 };
            const std::uint32_t dim17747JoeKuoD6Init[]   =   { 1, 1, 5, 11, 11, 5, 103, 11, 481, 999, 713, 499, 5069, 921, 20619, 25623, 69601, 82941, 0 };
            const std::uint32_t dim17748JoeKuoD6Init[]   =   { 1, 3, 5, 9, 15, 61, 67, 79, 371, 993, 475, 617, 1611, 12513, 14907, 55313, 39207, 112653, 0 };
            const std::uint32_t dim17749JoeKuoD6Init[]   =   { 1, 1, 5, 15, 17, 45, 91, 187, 175, 465, 907, 3371, 3743, 15657, 30511, 58191, 105683, 216759, 0 };
            const std::uint32_t dim17750JoeKuoD6Init[]   =   { 1, 1, 5, 9, 23, 1, 17, 79, 73, 717, 1785, 677, 7377, 4511, 21927, 34341, 47119, 193977, 0 };
            const std::uint32_t dim17751JoeKuoD6Init[]   =   { 1, 3, 7, 13, 21, 1, 59, 179, 121, 641, 175, 563, 961, 10549, 15779, 49875, 8109, 1039, 0 };
            const std::uint32_t dim17752JoeKuoD6Init[]   =   { 1, 1, 5, 7, 17, 9, 37, 171, 335, 135, 1403, 2541, 3845, 15311, 1905, 40853, 11013, 255669, 0 };
            const std::uint32_t dim17753JoeKuoD6Init[]   =   { 1, 1, 7, 1, 5, 23, 113, 111, 337, 755, 2037, 3067, 2821, 10549, 28467, 22615, 71585, 61871, 0 };
            const std::uint32_t dim17754JoeKuoD6Init[]   =   { 1, 1, 3, 9, 7, 3, 49, 229, 111, 871, 1711, 1793, 3089, 12571, 30883, 44773, 80827, 151709, 0 };
            const std::uint32_t dim17755JoeKuoD6Init[]   =   { 1, 1, 5, 1, 13, 41, 3, 253, 399, 881, 1107, 4081, 1849, 115, 31557, 2515, 126751, 195663, 0 };
            const std::uint32_t dim17756JoeKuoD6Init[]   =   { 1, 1, 3, 1, 13, 31, 113, 85, 57, 549, 1653, 2927, 5433, 11879, 22709, 41675, 13395, 46931, 0 };
            const std::uint32_t dim17757JoeKuoD6Init[]   =   { 1, 1, 3, 9, 21, 1, 109, 65, 377, 63, 861, 1031, 2709, 7265, 9861, 64109, 34577, 9743, 0 };
            const std::uint32_t dim17758JoeKuoD6Init[]   =   { 1, 1, 7, 7, 17, 31, 5, 177, 253, 387, 1271, 2805, 2211, 1813, 11649, 3217, 123793, 197753, 0 };
            const std::uint32_t dim17759JoeKuoD6Init[]   =   { 1, 1, 3, 9, 15, 63, 89, 59, 455, 783, 1181, 7, 2309, 15961, 11231, 37389, 101221, 119331, 0 };
            const std::uint32_t dim17760JoeKuoD6Init[]   =   { 1, 3, 3, 13, 7, 3, 15, 251, 431, 951, 639, 1585, 1247, 15927, 9695, 37469, 34945, 219723, 0 };
            const std::uint32_t dim17761JoeKuoD6Init[]   =   { 1, 1, 5, 3, 21, 29, 83, 151, 383, 227, 215, 2329, 1297, 13709, 15653, 3119, 111319, 222877, 0 };
            const std::uint32_t dim17762JoeKuoD6Init[]   =   { 1, 3, 1, 13, 1, 43, 127, 125, 243, 955, 583, 3497, 6605, 3821, 4657, 10599, 90927, 82725, 0 };
            const std::uint32_t dim17763JoeKuoD6Init[]   =   { 1, 1, 1, 1, 15, 51, 61, 167, 489, 603, 873, 907, 575, 6957, 24409, 63587, 50205, 159291, 0 };
            const std::uint32_t dim17764JoeKuoD6Init[]   =   { 1, 3, 3, 1, 19, 23, 7, 23, 239, 961, 1001, 1541, 2211, 4637, 19931, 39153, 102769, 242005, 0 };
            const std::uint32_t dim17765JoeKuoD6Init[]   =   { 1, 1, 1, 15, 19, 31, 73, 121, 119, 199, 979, 4061, 3903, 12055, 27957, 15999, 5709, 210329, 0 };
            const std::uint32_t dim17766JoeKuoD6Init[]   =   { 1, 1, 7, 13, 25, 35, 21, 25, 241, 937, 13, 947, 943, 3727, 15321, 46665, 99437, 233919, 0 };
            const std::uint32_t dim17767JoeKuoD6Init[]   =   { 1, 1, 1, 9, 3, 51, 127, 113, 105, 335, 685, 2173, 4329, 7569, 5617, 32407, 21649, 30609, 0 };
            const std::uint32_t dim17768JoeKuoD6Init[]   =   { 1, 3, 7, 9, 9, 13, 69, 191, 95, 727, 1649, 1201, 2093, 10053, 29381, 6207, 70755, 118505, 0 };
            const std::uint32_t dim17769JoeKuoD6Init[]   =   { 1, 1, 1, 11, 21, 57, 77, 139, 271, 21, 1747, 2337, 7761, 7753, 6847, 5219, 87033, 229105, 0 };
            const std::uint32_t dim17770JoeKuoD6Init[]   =   { 1, 3, 3, 1, 5, 51, 15, 235, 87, 567, 391, 3039, 2253, 11177, 11899, 25305, 14815, 51051, 0 };
            const std::uint32_t dim17771JoeKuoD6Init[]   =   { 1, 3, 5, 7, 27, 51, 69, 93, 261, 947, 31, 2751, 6685, 3655, 24125, 22161, 108421, 230865, 0 };
            const std::uint32_t dim17772JoeKuoD6Init[]   =   { 1, 1, 3, 3, 27, 17, 35, 97, 285, 855, 1767, 2545, 825, 11519, 11231, 50951, 32883, 78573, 0 };
            const std::uint32_t dim17773JoeKuoD6Init[]   =   { 1, 3, 7, 13, 1, 57, 99, 193, 371, 839, 1319, 2295, 5897, 7893, 14339, 64217, 16951, 234953, 0 };
            const std::uint32_t dim17774JoeKuoD6Init[]   =   { 1, 3, 1, 3, 11, 37, 13, 21, 299, 379, 63, 1209, 7879, 5001, 10181, 40173, 1753, 104821, 0 };
            const std::uint32_t dim17775JoeKuoD6Init[]   =   { 1, 3, 5, 9, 23, 51, 75, 103, 249, 533, 621, 15, 1883, 2109, 20859, 4635, 120615, 135515, 0 };
            const std::uint32_t dim17776JoeKuoD6Init[]   =   { 1, 1, 3, 3, 21, 45, 113, 57, 495, 457, 685, 3625, 243, 14831, 12351, 63001, 118191, 153875, 0 };
            const std::uint32_t dim17777JoeKuoD6Init[]   =   { 1, 3, 5, 5, 21, 15, 65, 251, 183, 241, 1513, 2711, 4527, 12675, 26747, 5181, 4237, 246479, 0 };
            const std::uint32_t dim17778JoeKuoD6Init[]   =   { 1, 1, 5, 3, 27, 29, 91, 93, 345, 893, 195, 3109, 2611, 12657, 10401, 15063, 95807, 244587, 0 };
            const std::uint32_t dim17779JoeKuoD6Init[]   =   { 1, 3, 5, 13, 19, 49, 85, 155, 159, 939, 1139, 1569, 1129, 8641, 18391, 55201, 108491, 77863, 0 };
            const std::uint32_t dim17780JoeKuoD6Init[]   =   { 1, 3, 5, 9, 25, 53, 75, 77, 85, 903, 1399, 2379, 2219, 14725, 21877, 24271, 40955, 61849, 0 };
            const std::uint32_t dim17781JoeKuoD6Init[]   =   { 1, 1, 5, 9, 13, 49, 53, 177, 163, 331, 533, 1469, 1397, 8187, 12379, 10185, 125541, 260271, 0 };
            const std::uint32_t dim17782JoeKuoD6Init[]   =   { 1, 1, 7, 9, 19, 31, 81, 89, 281, 397, 1917, 145, 2723, 15019, 18841, 13887, 11859, 171749, 0 };
            const std::uint32_t dim17783JoeKuoD6Init[]   =   { 1, 3, 7, 13, 25, 17, 87, 189, 29, 283, 913, 3855, 5707, 15881, 12787, 42357, 84579, 78531, 0 };
            const std::uint32_t dim17784JoeKuoD6Init[]   =   { 1, 1, 5, 15, 15, 31, 37, 249, 445, 119, 431, 4069, 5699, 10119, 31661, 9555, 6869, 1145, 0 };
            const std::uint32_t dim17785JoeKuoD6Init[]   =   { 1, 3, 7, 1, 31, 29, 57, 177, 341, 411, 1019, 1889, 383, 1461, 26695, 61777, 18367, 137233, 0 };
            const std::uint32_t dim17786JoeKuoD6Init[]   =   { 1, 3, 5, 1, 7, 53, 29, 53, 387, 675, 435, 461, 6247, 7519, 14003, 9037, 116599, 54471, 0 };
            const std::uint32_t dim17787JoeKuoD6Init[]   =   { 1, 3, 3, 7, 17, 59, 91, 77, 169, 591, 95, 113, 6135, 10479, 17153, 52953, 16183, 90775, 0 };
            const std::uint32_t dim17788JoeKuoD6Init[]   =   { 1, 3, 3, 15, 11, 11, 117, 141, 493, 163, 65, 1305, 7477, 7383, 22651, 64271, 80983, 154845, 0 };
            const std::uint32_t dim17789JoeKuoD6Init[]   =   { 1, 1, 1, 3, 9, 15, 83, 11, 113, 77, 1115, 1417, 511, 6825, 21013, 37241, 104695, 31335, 0 };
            const std::uint32_t dim17790JoeKuoD6Init[]   =   { 1, 1, 7, 3, 13, 33, 115, 121, 245, 673, 1991, 2157, 479, 9843, 5963, 4637, 8925, 27751, 0 };
            const std::uint32_t dim17791JoeKuoD6Init[]   =   { 1, 3, 3, 7, 19, 11, 67, 125, 339, 27, 1545, 2319, 5977, 11603, 23219, 48273, 119265, 20151, 0 };
            const std::uint32_t dim17792JoeKuoD6Init[]   =   { 1, 1, 5, 7, 27, 29, 31, 227, 279, 405, 1133, 689, 1133, 8957, 29629, 48849, 109995, 259749, 0 };
            const std::uint32_t dim17793JoeKuoD6Init[]   =   { 1, 3, 5, 7, 7, 61, 95, 243, 91, 741, 1591, 3169, 2287, 11015, 15601, 43043, 65319, 50671, 0 };
            const std::uint32_t dim17794JoeKuoD6Init[]   =   { 1, 1, 5, 5, 13, 47, 31, 95, 425, 715, 1603, 3485, 673, 12869, 32561, 42329, 112809, 181971, 0 };
            const std::uint32_t dim17795JoeKuoD6Init[]   =   { 1, 3, 3, 3, 17, 51, 109, 45, 397, 457, 1379, 3845, 4215, 14185, 16597, 27711, 74283, 98151, 0 };
            const std::uint32_t dim17796JoeKuoD6Init[]   =   { 1, 1, 1, 15, 7, 25, 13, 49, 441, 513, 1769, 707, 6037, 9689, 18915, 35647, 110823, 196633, 0 };
            const std::uint32_t dim17797JoeKuoD6Init[]   =   { 1, 1, 1, 1, 23, 53, 93, 61, 277, 125, 55, 2453, 3331, 14037, 10809, 33205, 43785, 248743, 0 };
            const std::uint32_t dim17798JoeKuoD6Init[]   =   { 1, 1, 3, 7, 23, 15, 93, 77, 333, 801, 1969, 31, 51, 5239, 24241, 5077, 113503, 132211, 0 };
            const std::uint32_t dim17799JoeKuoD6Init[]   =   { 1, 3, 3, 1, 7, 55, 53, 5, 311, 657, 1507, 3413, 565, 15745, 6129, 40285, 91811, 90527, 0 };
            const std::uint32_t dim17800JoeKuoD6Init[]   =   { 1, 3, 3, 13, 19, 23, 45, 25, 509, 313, 915, 2199, 5549, 8469, 32735, 37877, 11607, 37993, 0 };
            const std::uint32_t dim17801JoeKuoD6Init[]   =   { 1, 1, 5, 11, 25, 33, 55, 31, 311, 851, 159, 2103, 2641, 8957, 9375, 37179, 33667, 100513, 0 };
            const std::uint32_t dim17802JoeKuoD6Init[]   =   { 1, 3, 1, 1, 7, 7, 17, 75, 217, 171, 359, 1169, 4105, 929, 6427, 56349, 77985, 41941, 0 };
            const std::uint32_t dim17803JoeKuoD6Init[]   =   { 1, 1, 1, 15, 5, 51, 73, 63, 259, 351, 1797, 1001, 5025, 11203, 30221, 54345, 11331, 158415, 0 };
            const std::uint32_t dim17804JoeKuoD6Init[]   =   { 1, 3, 1, 5, 3, 21, 13, 3, 63, 779, 871, 2517, 6345, 4103, 16321, 30211, 120815, 83751, 0 };
            const std::uint32_t dim17805JoeKuoD6Init[]   =   { 1, 1, 3, 13, 11, 7, 41, 255, 215, 37, 279, 2485, 6511, 12855, 22857, 55695, 122717, 238151, 0 };
            const std::uint32_t dim17806JoeKuoD6Init[]   =   { 1, 3, 3, 3, 1, 55, 27, 193, 509, 677, 1861, 573, 5341, 5285, 6909, 51781, 91203, 139791, 0 };
            const std::uint32_t dim17807JoeKuoD6Init[]   =   { 1, 3, 7, 11, 5, 63, 87, 215, 305, 235, 1049, 1339, 5301, 9639, 29861, 58415, 68303, 76907, 0 };
            const std::uint32_t dim17808JoeKuoD6Init[]   =   { 1, 1, 5, 11, 13, 13, 67, 139, 19, 577, 165, 3067, 8023, 10905, 3159, 41289, 118231, 119673, 0 };
            const std::uint32_t dim17809JoeKuoD6Init[]   =   { 1, 1, 3, 1, 15, 5, 69, 119, 363, 703, 461, 2293, 3801, 14217, 10709, 9553, 100651, 186115, 0 };
            const std::uint32_t dim17810JoeKuoD6Init[]   =   { 1, 3, 7, 15, 19, 21, 59, 237, 227, 193, 827, 619, 3447, 13815, 3467, 38911, 41403, 99627, 0 };
            const std::uint32_t dim17811JoeKuoD6Init[]   =   { 1, 1, 3, 3, 27, 23, 41, 199, 161, 555, 1629, 3187, 1355, 5947, 1157, 25877, 110989, 231285, 0 };
            const std::uint32_t dim17812JoeKuoD6Init[]   =   { 1, 1, 3, 15, 3, 43, 103, 29, 179, 223, 375, 2877, 1917, 9367, 15337, 15381, 62833, 139003, 0 };
            const std::uint32_t dim17813JoeKuoD6Init[]   =   { 1, 3, 3, 11, 23, 33, 107, 189, 511, 209, 1519, 2809, 6185, 5921, 20939, 63879, 113687, 79149, 0 };
            const std::uint32_t dim17814JoeKuoD6Init[]   =   { 1, 3, 5, 15, 1, 63, 101, 227, 419, 803, 59, 2261, 6905, 10679, 5393, 54447, 58521, 59855, 0 };
            const std::uint32_t dim17815JoeKuoD6Init[]   =   { 1, 1, 7, 13, 13, 21, 121, 123, 181, 371, 1485, 3191, 2627, 6197, 11169, 44927, 34739, 10687, 0 };
            const std::uint32_t dim17816JoeKuoD6Init[]   =   { 1, 1, 3, 3, 25, 47, 13, 115, 187, 967, 1439, 1021, 4413, 3343, 31463, 3729, 13511, 162125, 0 };
            const std::uint32_t dim17817JoeKuoD6Init[]   =   { 1, 3, 3, 15, 15, 59, 29, 129, 469, 171, 2045, 2859, 1097, 11199, 12147, 37465, 14179, 197923, 0 };
            const std::uint32_t dim17818JoeKuoD6Init[]   =   { 1, 1, 7, 5, 13, 35, 41, 167, 207, 123, 1077, 3145, 2803, 15729, 767, 7321, 84375, 190855, 0 };
            const std::uint32_t dim17819JoeKuoD6Init[]   =   { 1, 3, 5, 11, 3, 5, 65, 3, 111, 725, 143, 2945, 4755, 3407, 31801, 15329, 70311, 119197, 0 };
            const std::uint32_t dim17820JoeKuoD6Init[]   =   { 1, 1, 5, 3, 17, 19, 61, 73, 261, 663, 821, 3389, 3883, 9961, 17727, 33113, 98371, 247097, 0 };
            const std::uint32_t dim17821JoeKuoD6Init[]   =   { 1, 3, 1, 9, 29, 17, 43, 43, 481, 1015, 1249, 607, 3495, 13259, 29001, 23083, 51487, 81723, 0 };
            const std::uint32_t dim17822JoeKuoD6Init[]   =   { 1, 3, 1, 3, 25, 57, 5, 33, 313, 21, 1731, 3417, 7033, 6609, 31631, 63231, 61107, 10941, 0 };
            const std::uint32_t dim17823JoeKuoD6Init[]   =   { 1, 3, 3, 11, 29, 29, 117, 131, 417, 789, 1545, 1677, 3213, 13869, 5319, 41387, 13895, 252387, 0 };
            const std::uint32_t dim17824JoeKuoD6Init[]   =   { 1, 3, 3, 13, 25, 47, 55, 213, 83, 345, 1453, 159, 1521, 14777, 24177, 7631, 81259, 135411, 0 };
            const std::uint32_t dim17825JoeKuoD6Init[]   =   { 1, 1, 3, 15, 11, 63, 49, 69, 273, 843, 1661, 1157, 1285, 12751, 5, 54909, 114375, 6395, 0 };
            const std::uint32_t dim17826JoeKuoD6Init[]   =   { 1, 3, 1, 11, 25, 1, 83, 55, 161, 125, 1547, 401, 7639, 4289, 7075, 9971, 33825, 135071, 0 };
            const std::uint32_t dim17827JoeKuoD6Init[]   =   { 1, 3, 7, 9, 17, 5, 79, 131, 373, 1023, 573, 2219, 1789, 5789, 5347, 26455, 58661, 206417, 0 };
            const std::uint32_t dim17828JoeKuoD6Init[]   =   { 1, 1, 7, 5, 1, 43, 83, 107, 125, 289, 793, 1731, 5167, 8943, 28397, 26877, 53781, 95899, 0 };
            const std::uint32_t dim17829JoeKuoD6Init[]   =   { 1, 3, 3, 13, 21, 53, 123, 103, 385, 753, 1917, 2075, 4385, 5757, 9221, 35797, 86743, 69069, 0 };
            const std::uint32_t dim17830JoeKuoD6Init[]   =   { 1, 3, 3, 3, 5, 19, 119, 221, 457, 907, 359, 3493, 2331, 5685, 11133, 29293, 27051, 213927, 0 };
            const std::uint32_t dim17831JoeKuoD6Init[]   =   { 1, 1, 3, 11, 11, 31, 29, 129, 429, 601, 1217, 3653, 5935, 14823, 21161, 33423, 98391, 214703, 0 };
            const std::uint32_t dim17832JoeKuoD6Init[]   =   { 1, 1, 3, 15, 31, 49, 109, 139, 349, 13, 205, 2483, 8083, 8391, 4789, 30355, 12165, 195263, 0 };
            const std::uint32_t dim17833JoeKuoD6Init[]   =   { 1, 1, 1, 9, 19, 63, 15, 167, 45, 185, 811, 529, 6811, 13441, 27195, 59047, 106675, 167125, 0 };
            const std::uint32_t dim17834JoeKuoD6Init[]   =   { 1, 1, 7, 1, 19, 19, 39, 1, 349, 467, 551, 4081, 4743, 11627, 607, 22005, 60893, 49101, 0 };
            const std::uint32_t dim17835JoeKuoD6Init[]   =   { 1, 3, 7, 9, 9, 25, 105, 119, 113, 825, 1429, 2019, 5209, 8491, 6017, 47783, 88455, 119083, 0 };
            const std::uint32_t dim17836JoeKuoD6Init[]   =   { 1, 3, 3, 13, 21, 39, 107, 119, 321, 251, 563, 311, 4441, 6491, 3157, 65479, 107349, 211621, 0 };
            const std::uint32_t dim17837JoeKuoD6Init[]   =   { 1, 1, 7, 13, 9, 3, 17, 117, 327, 459, 489, 7, 6883, 10047, 31935, 28069, 37903, 188281, 0 };
            const std::uint32_t dim17838JoeKuoD6Init[]   =   { 1, 1, 7, 1, 15, 53, 47, 127, 483, 595, 811, 1143, 4543, 10043, 30349, 24409, 91947, 240165, 0 };
            const std::uint32_t dim17839JoeKuoD6Init[]   =   { 1, 1, 1, 13, 25, 43, 109, 161, 147, 1009, 1071, 1533, 2781, 13439, 20507, 41387, 26943, 84675, 0 };
            const std::uint32_t dim17840JoeKuoD6Init[]   =   { 1, 3, 5, 13, 19, 21, 23, 167, 135, 257, 587, 2691, 5877, 3047, 11745, 24895, 114799, 48003, 0 };
            const std::uint32_t dim17841JoeKuoD6Init[]   =   { 1, 3, 1, 1, 9, 57, 33, 51, 137, 109, 137, 195, 1233, 11139, 16833, 27545, 35877, 126627, 0 };
            const std::uint32_t dim17842JoeKuoD6Init[]   =   { 1, 1, 1, 15, 5, 37, 7, 19, 363, 411, 1193, 767, 6209, 9115, 14699, 55515, 46023, 90693, 0 };
            const std::uint32_t dim17843JoeKuoD6Init[]   =   { 1, 3, 5, 3, 19, 55, 85, 117, 391, 757, 861, 3537, 6507, 6993, 19589, 6843, 33557, 64683, 0 };
            const std::uint32_t dim17844JoeKuoD6Init[]   =   { 1, 1, 7, 5, 5, 61, 99, 9, 311, 595, 807, 429, 63, 12359, 28289, 709, 129911, 143745, 0 };
            const std::uint32_t dim17845JoeKuoD6Init[]   =   { 1, 1, 1, 7, 17, 9, 9, 117, 19, 985, 657, 2803, 2699, 829, 31069, 13277, 106769, 109231, 0 };
            const std::uint32_t dim17846JoeKuoD6Init[]   =   { 1, 1, 5, 13, 25, 19, 63, 217, 419, 221, 1921, 215, 2631, 4659, 29855, 46549, 62257, 260113, 0 };
            const std::uint32_t dim17847JoeKuoD6Init[]   =   { 1, 3, 3, 9, 13, 45, 63, 129, 147, 489, 879, 3025, 6777, 1119, 20963, 30553, 20863, 169837, 0 };
            const std::uint32_t dim17848JoeKuoD6Init[]   =   { 1, 3, 5, 9, 25, 61, 79, 51, 495, 583, 1519, 1501, 123, 13871, 32239, 957, 31921, 255561, 0 };
            const std::uint32_t dim17849JoeKuoD6Init[]   =   { 1, 3, 7, 3, 31, 61, 89, 65, 305, 429, 785, 3871, 7711, 2745, 24131, 43055, 51167, 87743, 0 };
            const std::uint32_t dim17850JoeKuoD6Init[]   =   { 1, 3, 1, 11, 19, 23, 89, 117, 185, 121, 109, 1327, 6553, 14367, 16069, 28657, 81751, 10185, 0 };
            const std::uint32_t dim17851JoeKuoD6Init[]   =   { 1, 3, 5, 5, 17, 33, 115, 61, 101, 367, 1465, 3899, 6601, 4483, 2447, 49575, 129987, 11703, 0 };
            const std::uint32_t dim17852JoeKuoD6Init[]   =   { 1, 1, 3, 13, 13, 59, 79, 83, 253, 171, 53, 2467, 5005, 1045, 943, 62419, 98563, 78935, 0 };
            const std::uint32_t dim17853JoeKuoD6Init[]   =   { 1, 1, 7, 15, 31, 17, 77, 73, 249, 247, 119, 1655, 7079, 14593, 105, 55767, 130401, 74189, 0 };
            const std::uint32_t dim17854JoeKuoD6Init[]   =   { 1, 3, 5, 11, 19, 29, 79, 251, 75, 949, 527, 2779, 5839, 11451, 24125, 45991, 127437, 86541, 0 };
            const std::uint32_t dim17855JoeKuoD6Init[]   =   { 1, 1, 5, 7, 1, 29, 127, 27, 477, 807, 829, 1569, 205, 13319, 16149, 26003, 38985, 188587, 0 };
            const std::uint32_t dim17856JoeKuoD6Init[]   =   { 1, 1, 1, 3, 19, 29, 39, 71, 17, 51, 1169, 467, 7505, 1867, 4469, 32161, 43031, 31675, 0 };
            const std::uint32_t dim17857JoeKuoD6Init[]   =   { 1, 1, 1, 15, 27, 45, 67, 107, 127, 469, 1955, 1933, 2379, 8513, 32071, 35043, 126537, 23303, 0 };
            const std::uint32_t dim17858JoeKuoD6Init[]   =   { 1, 3, 7, 9, 23, 41, 23, 197, 97, 213, 17, 1751, 5467, 6179, 29291, 33397, 42131, 151093, 0 };
            const std::uint32_t dim17859JoeKuoD6Init[]   =   { 1, 3, 7, 15, 27, 3, 39, 87, 365, 77, 487, 293, 6405, 2239, 30455, 44723, 12399, 100013, 0 };
            const std::uint32_t dim17860JoeKuoD6Init[]   =   { 1, 3, 5, 9, 29, 21, 55, 183, 343, 263, 1643, 2027, 2255, 6259, 18277, 64661, 39391, 255839, 0 };
            const std::uint32_t dim17861JoeKuoD6Init[]   =   { 1, 1, 7, 11, 21, 55, 11, 139, 261, 11, 1721, 3779, 85, 8203, 12089, 50579, 128341, 119043, 0 };
            const std::uint32_t dim17862JoeKuoD6Init[]   =   { 1, 3, 5, 13, 27, 53, 109, 1, 313, 661, 431, 1543, 1571, 7337, 18857, 49951, 7881, 228161, 0 };
            const std::uint32_t dim17863JoeKuoD6Init[]   =   { 1, 1, 7, 5, 5, 31, 27, 149, 239, 199, 1011, 1979, 5297, 14609, 26971, 65531, 64215, 115109, 0 };
            const std::uint32_t dim17864JoeKuoD6Init[]   =   { 1, 1, 5, 13, 15, 11, 63, 225, 165, 405, 1367, 2291, 5171, 12419, 19561, 37719, 621, 137607, 0 };
            const std::uint32_t dim17865JoeKuoD6Init[]   =   { 1, 3, 1, 15, 25, 1, 125, 243, 97, 455, 1977, 3333, 801, 1343, 993, 18453, 19285, 71547, 0 };
            const std::uint32_t dim17866JoeKuoD6Init[]   =   { 1, 1, 5, 11, 9, 51, 109, 135, 73, 147, 649, 4071, 7425, 3093, 26417, 51139, 1523, 142225, 0 };
            const std::uint32_t dim17867JoeKuoD6Init[]   =   { 1, 3, 7, 11, 1, 39, 109, 119, 337, 715, 1087, 4005, 1393, 6397, 31135, 38935, 106255, 60723, 0 };
            const std::uint32_t dim17868JoeKuoD6Init[]   =   { 1, 1, 1, 9, 9, 11, 45, 11, 171, 671, 965, 109, 2261, 13775, 8539, 63669, 10507, 249113, 0 };
            const std::uint32_t dim17869JoeKuoD6Init[]   =   { 1, 3, 1, 15, 21, 33, 127, 173, 419, 31, 299, 857, 4915, 11331, 29385, 47375, 111891, 14505, 0 };
            const std::uint32_t dim17870JoeKuoD6Init[]   =   { 1, 3, 5, 13, 7, 43, 85, 183, 377, 275, 803, 1755, 8005, 15327, 31043, 18851, 122581, 229731, 0 };
            const std::uint32_t dim17871JoeKuoD6Init[]   =   { 1, 3, 5, 1, 27, 9, 41, 73, 283, 475, 671, 747, 1419, 15209, 25465, 60061, 91417, 103203, 0 };
            const std::uint32_t dim17872JoeKuoD6Init[]   =   { 1, 3, 1, 15, 15, 43, 13, 45, 217, 519, 363, 3265, 6213, 13045, 3709, 22119, 79733, 224195, 0 };
            const std::uint32_t dim17873JoeKuoD6Init[]   =   { 1, 3, 1, 15, 15, 59, 95, 71, 171, 769, 1395, 2673, 4523, 749, 13411, 60431, 124651, 11475, 0 };
            const std::uint32_t dim17874JoeKuoD6Init[]   =   { 1, 1, 7, 3, 1, 35, 13, 239, 101, 355, 1201, 3665, 5403, 11413, 11983, 52469, 63621, 155819, 0 };
            const std::uint32_t dim17875JoeKuoD6Init[]   =   { 1, 1, 1, 7, 31, 59, 87, 25, 511, 483, 569, 3337, 4027, 8347, 3031, 24351, 57963, 79425, 0 };
            const std::uint32_t dim17876JoeKuoD6Init[]   =   { 1, 3, 1, 3, 11, 17, 29, 249, 61, 923, 585, 2107, 2727, 8589, 22809, 3, 17937, 163267, 0 };
            const std::uint32_t dim17877JoeKuoD6Init[]   =   { 1, 3, 5, 11, 27, 3, 73, 187, 19, 975, 257, 2361, 935, 9071, 29991, 13619, 92169, 101031, 0 };
            const std::uint32_t dim17878JoeKuoD6Init[]   =   { 1, 1, 5, 13, 17, 53, 105, 157, 343, 673, 237, 3231, 7311, 1593, 18521, 57889, 79805, 97847, 0 };
            const std::uint32_t dim17879JoeKuoD6Init[]   =   { 1, 3, 1, 3, 31, 55, 63, 167, 489, 167, 121, 3333, 2475, 1545, 13291, 921, 101757, 62147, 0 };
            const std::uint32_t dim17880JoeKuoD6Init[]   =   { 1, 3, 3, 15, 13, 17, 9, 209, 339, 567, 2011, 1737, 1455, 9289, 6105, 49733, 74237, 93195, 0 };
            const std::uint32_t dim17881JoeKuoD6Init[]   =   { 1, 1, 7, 11, 3, 13, 77, 115, 305, 327, 1005, 3381, 4269, 4835, 27221, 16301, 75173, 244603, 0 };
            const std::uint32_t dim17882JoeKuoD6Init[]   =   { 1, 3, 5, 7, 7, 31, 47, 75, 499, 41, 281, 167, 3525, 8649, 23623, 4987, 2057, 204083, 0 };
            const std::uint32_t dim17883JoeKuoD6Init[]   =   { 1, 3, 3, 5, 9, 5, 35, 53, 269, 437, 1035, 1675, 4567, 13291, 19787, 28937, 108915, 62545, 0 };
            const std::uint32_t dim17884JoeKuoD6Init[]   =   { 1, 3, 1, 5, 15, 59, 57, 181, 321, 1, 791, 2149, 591, 6691, 8759, 62861, 10815, 257331, 0 };
            const std::uint32_t dim17885JoeKuoD6Init[]   =   { 1, 1, 7, 1, 21, 25, 93, 39, 429, 455, 669, 1725, 7087, 11805, 22405, 13083, 88411, 225967, 0 };
            const std::uint32_t dim17886JoeKuoD6Init[]   =   { 1, 1, 5, 15, 5, 45, 15, 1, 55, 281, 2027, 97, 2639, 57, 23717, 21669, 92181, 32731, 0 };
            const std::uint32_t dim17887JoeKuoD6Init[]   =   { 1, 3, 7, 3, 7, 3, 67, 201, 445, 577, 1011, 793, 7763, 10823, 30309, 41565, 37263, 218909, 0 };
            const std::uint32_t dim17888JoeKuoD6Init[]   =   { 1, 1, 7, 3, 17, 53, 51, 119, 399, 903, 1785, 1053, 4315, 2967, 17579, 64185, 55005, 12969, 0 };
            const std::uint32_t dim17889JoeKuoD6Init[]   =   { 1, 3, 3, 13, 21, 63, 13, 1, 427, 39, 71, 1811, 1237, 1623, 11401, 14371, 44355, 93089, 0 };
            const std::uint32_t dim17890JoeKuoD6Init[]   =   { 1, 1, 5, 1, 17, 39, 39, 105, 187, 691, 251, 3957, 931, 12149, 18299, 48819, 23061, 49179, 0 };
            const std::uint32_t dim17891JoeKuoD6Init[]   =   { 1, 1, 5, 11, 31, 3, 23, 211, 101, 763, 237, 3635, 417, 4935, 14997, 3859, 22343, 153541, 0 };
            const std::uint32_t dim17892JoeKuoD6Init[]   =   { 1, 3, 7, 5, 21, 37, 59, 137, 13, 179, 527, 895, 3451, 1743, 3149, 10665, 119427, 259343, 0 };
            const std::uint32_t dim17893JoeKuoD6Init[]   =   { 1, 3, 5, 3, 7, 37, 103, 173, 453, 327, 131, 2453, 7795, 12585, 13947, 59161, 41845, 29527, 0 };
            const std::uint32_t dim17894JoeKuoD6Init[]   =   { 1, 3, 3, 1, 17, 49, 57, 251, 295, 279, 1545, 3963, 589, 9211, 32371, 14963, 116927, 197321, 0 };
            const std::uint32_t dim17895JoeKuoD6Init[]   =   { 1, 1, 3, 7, 17, 59, 37, 115, 315, 591, 481, 767, 4611, 14741, 6949, 19507, 6567, 143371, 0 };
            const std::uint32_t dim17896JoeKuoD6Init[]   =   { 1, 1, 5, 3, 19, 53, 121, 229, 355, 909, 339, 1645, 2747, 7045, 9085, 5799, 50997, 17981, 0 };
            const std::uint32_t dim17897JoeKuoD6Init[]   =   { 1, 3, 3, 9, 3, 1, 109, 7, 15, 177, 789, 3911, 6427, 8453, 22583, 12039, 124587, 123887, 0 };
            const std::uint32_t dim17898JoeKuoD6Init[]   =   { 1, 1, 5, 1, 7, 23, 15, 193, 109, 685, 1147, 3921, 2329, 15153, 25045, 28389, 34759, 256611, 0 };
            const std::uint32_t dim17899JoeKuoD6Init[]   =   { 1, 1, 3, 3, 23, 27, 55, 43, 485, 541, 1617, 3761, 1051, 7525, 19941, 52699, 35421, 162939, 0 };
            const std::uint32_t dim17900JoeKuoD6Init[]   =   { 1, 3, 7, 1, 25, 9, 113, 251, 477, 1005, 9, 3321, 5817, 965, 18523, 29407, 53353, 205575, 0 };
            const std::uint32_t dim17901JoeKuoD6Init[]   =   { 1, 1, 7, 11, 9, 31, 111, 175, 227, 33, 1745, 1141, 1547, 2113, 8785, 40273, 100301, 190749, 0 };
            const std::uint32_t dim17902JoeKuoD6Init[]   =   { 1, 1, 5, 11, 19, 49, 45, 197, 457, 223, 91, 2769, 6331, 1161, 6609, 61905, 42257, 152117, 0 };
            const std::uint32_t dim17903JoeKuoD6Init[]   =   { 1, 1, 7, 11, 1, 17, 37, 153, 431, 933, 269, 1529, 1297, 15567, 149, 41701, 59867, 93631, 0 };
            const std::uint32_t dim17904JoeKuoD6Init[]   =   { 1, 1, 5, 9, 25, 33, 83, 127, 305, 667, 343, 185, 3527, 13079, 10567, 35753, 72191, 214091, 0 };
            const std::uint32_t dim17905JoeKuoD6Init[]   =   { 1, 3, 7, 1, 1, 7, 75, 241, 185, 81, 2043, 3081, 3563, 385, 3055, 59421, 27081, 32521, 0 };
            const std::uint32_t dim17906JoeKuoD6Init[]   =   { 1, 1, 3, 5, 31, 1, 101, 21, 69, 979, 917, 695, 5601, 12251, 15031, 18715, 116985, 53071, 0 };
            const std::uint32_t dim17907JoeKuoD6Init[]   =   { 1, 1, 3, 9, 23, 57, 91, 127, 327, 979, 721, 3855, 1131, 997, 32227, 33843, 128299, 15239, 0 };
            const std::uint32_t dim17908JoeKuoD6Init[]   =   { 1, 3, 7, 13, 23, 1, 87, 105, 259, 939, 1935, 1983, 6619, 1611, 31901, 14745, 96641, 211945, 0 };
            const std::uint32_t dim17909JoeKuoD6Init[]   =   { 1, 1, 3, 5, 25, 17, 39, 95, 137, 971, 377, 2493, 981, 329, 25845, 44513, 100561, 57985, 0 };
            const std::uint32_t dim17910JoeKuoD6Init[]   =   { 1, 1, 3, 9, 27, 37, 69, 103, 167, 131, 487, 2935, 7099, 15375, 4825, 12209, 117165, 84909, 0 };
            const std::uint32_t dim17911JoeKuoD6Init[]   =   { 1, 3, 1, 15, 27, 19, 115, 239, 247, 243, 83, 1535, 8095, 3953, 25721, 62983, 89045, 16783, 0 };
            const std::uint32_t dim17912JoeKuoD6Init[]   =   { 1, 1, 5, 1, 19, 13, 125, 39, 439, 411, 171, 155, 5117, 15137, 19851, 251, 37921, 97209, 0 };
            const std::uint32_t dim17913JoeKuoD6Init[]   =   { 1, 1, 1, 5, 13, 41, 17, 97, 215, 323, 1333, 775, 1155, 15269, 19943, 48489, 71741, 202501, 0 };
            const std::uint32_t dim17914JoeKuoD6Init[]   =   { 1, 3, 5, 3, 1, 31, 55, 125, 69, 437, 1649, 2791, 8027, 15509, 31575, 8491, 106953, 155215, 0 };
            const std::uint32_t dim17915JoeKuoD6Init[]   =   { 1, 3, 3, 13, 19, 45, 39, 63, 227, 67, 2021, 1243, 6525, 7211, 6275, 39719, 74513, 6713, 0 };
            const std::uint32_t dim17916JoeKuoD6Init[]   =   { 1, 1, 5, 11, 13, 45, 15, 101, 171, 613, 1561, 2939, 3849, 2917, 29765, 2027, 53617, 59939, 0 };
            const std::uint32_t dim17917JoeKuoD6Init[]   =   { 1, 1, 5, 9, 27, 21, 119, 19, 441, 759, 703, 2985, 3007, 2087, 5207, 64403, 20273, 66181, 0 };
            const std::uint32_t dim17918JoeKuoD6Init[]   =   { 1, 1, 7, 13, 21, 3, 49, 3, 485, 883, 1863, 1925, 877, 10009, 24191, 58639, 107755, 106539, 0 };
            const std::uint32_t dim17919JoeKuoD6Init[]   =   { 1, 1, 1, 5, 27, 37, 23, 185, 281, 533, 437, 555, 8151, 6489, 22343, 4573, 91577, 167919, 0 };
            const std::uint32_t dim17920JoeKuoD6Init[]   =   { 1, 1, 7, 15, 3, 61, 103, 221, 223, 703, 133, 2923, 1027, 14643, 26413, 16523, 107223, 97185, 0 };
            const std::uint32_t dim17921JoeKuoD6Init[]   =   { 1, 3, 1, 11, 13, 15, 1, 203, 363, 675, 511, 3225, 1163, 741, 16063, 8097, 95905, 148465, 0 };
            const std::uint32_t dim17922JoeKuoD6Init[]   =   { 1, 3, 1, 7, 11, 11, 11, 243, 371, 129, 209, 3533, 1279, 12181, 31973, 29165, 122089, 115117, 0 };
            const std::uint32_t dim17923JoeKuoD6Init[]   =   { 1, 3, 1, 5, 25, 17, 31, 45, 215, 809, 1443, 3245, 1005, 2903, 20783, 23041, 96577, 192063, 0 };
            const std::uint32_t dim17924JoeKuoD6Init[]   =   { 1, 3, 3, 3, 19, 17, 101, 219, 91, 805, 189, 761, 4771, 11629, 7285, 21631, 21691, 47421, 0 };
            const std::uint32_t dim17925JoeKuoD6Init[]   =   { 1, 3, 7, 1, 31, 11, 71, 149, 303, 793, 35, 3109, 2769, 11593, 31839, 2053, 4541, 202997, 0 };
            const std::uint32_t dim17926JoeKuoD6Init[]   =   { 1, 1, 1, 3, 11, 19, 113, 249, 141, 659, 1117, 2145, 2617, 1075, 25347, 12913, 27457, 222095, 0 };
            const std::uint32_t dim17927JoeKuoD6Init[]   =   { 1, 3, 1, 3, 5, 23, 41, 57, 193, 815, 1293, 1109, 7597, 999, 10773, 41065, 18555, 35617, 0 };
            const std::uint32_t dim17928JoeKuoD6Init[]   =   { 1, 1, 3, 1, 31, 11, 127, 99, 163, 293, 299, 3415, 3761, 8781, 5327, 47631, 56411, 242787, 0 };
            const std::uint32_t dim17929JoeKuoD6Init[]   =   { 1, 3, 7, 13, 3, 41, 23, 169, 419, 725, 1419, 2643, 5265, 77, 24077, 18639, 78665, 205303, 0 };
            const std::uint32_t dim17930JoeKuoD6Init[]   =   { 1, 1, 5, 1, 31, 39, 39, 205, 413, 393, 1713, 309, 707, 4153, 10461, 16053, 26963, 253993, 0 };
            const std::uint32_t dim17931JoeKuoD6Init[]   =   { 1, 3, 7, 5, 23, 37, 125, 87, 199, 631, 1935, 551, 7047, 4585, 21257, 42345, 39365, 249393, 0 };
            const std::uint32_t dim17932JoeKuoD6Init[]   =   { 1, 3, 5, 13, 17, 55, 29, 209, 151, 465, 155, 363, 3097, 4093, 9869, 23297, 33973, 115543, 0 };
            const std::uint32_t dim17933JoeKuoD6Init[]   =   { 1, 1, 1, 13, 23, 59, 83, 71, 145, 717, 127, 1299, 1701, 10885, 5343, 40793, 87819, 66621, 0 };
            const std::uint32_t dim17934JoeKuoD6Init[]   =   { 1, 3, 3, 9, 19, 37, 23, 11, 269, 603, 871, 851, 837, 15303, 7595, 56481, 57819, 185065, 0 };
            const std::uint32_t dim17935JoeKuoD6Init[]   =   { 1, 3, 1, 1, 3, 15, 11, 249, 413, 723, 1403, 3233, 2747, 10335, 7127, 63285, 29237, 191953, 0 };
            const std::uint32_t dim17936JoeKuoD6Init[]   =   { 1, 3, 1, 1, 11, 31, 67, 139, 51, 413, 521, 969, 171, 5943, 31613, 16477, 85771, 202139, 0 };
            const std::uint32_t dim17937JoeKuoD6Init[]   =   { 1, 3, 7, 5, 5, 21, 109, 25, 463, 873, 493, 2673, 6409, 11199, 17195, 40623, 76821, 72509, 0 };
            const std::uint32_t dim17938JoeKuoD6Init[]   =   { 1, 1, 7, 7, 11, 1, 95, 43, 243, 67, 1289, 3219, 2255, 4957, 17561, 40499, 48537, 108809, 0 };
            const std::uint32_t dim17939JoeKuoD6Init[]   =   { 1, 1, 7, 15, 3, 39, 45, 75, 43, 821, 533, 4043, 1503, 83, 26937, 56327, 114149, 156845, 0 };
            const std::uint32_t dim17940JoeKuoD6Init[]   =   { 1, 3, 1, 1, 31, 21, 59, 1, 77, 147, 137, 1827, 4123, 2791, 27859, 57921, 40569, 134753, 0 };
            const std::uint32_t dim17941JoeKuoD6Init[]   =   { 1, 1, 5, 13, 31, 41, 111, 11, 181, 963, 459, 2771, 6123, 4035, 1627, 2047, 109537, 33653, 0 };
            const std::uint32_t dim17942JoeKuoD6Init[]   =   { 1, 3, 5, 7, 31, 57, 17, 21, 5, 761, 1833, 1279, 1239, 10089, 22531, 32547, 82699, 28389, 0 };
            const std::uint32_t dim17943JoeKuoD6Init[]   =   { 1, 3, 5, 13, 11, 39, 11, 61, 299, 753, 1067, 1347, 5189, 12859, 681, 46309, 31873, 90333, 0 };
            const std::uint32_t dim17944JoeKuoD6Init[]   =   { 1, 3, 1, 5, 13, 27, 119, 205, 377, 457, 817, 3017, 279, 1859, 30241, 52089, 61445, 176203, 0 };
            const std::uint32_t dim17945JoeKuoD6Init[]   =   { 1, 1, 3, 5, 11, 35, 17, 163, 27, 1001, 417, 2899, 1959, 5513, 1441, 19743, 67147, 236591, 0 };
            const std::uint32_t dim17946JoeKuoD6Init[]   =   { 1, 3, 5, 13, 15, 39, 53, 179, 447, 675, 933, 1261, 4415, 9845, 28459, 33497, 107375, 156855, 0 };
            const std::uint32_t dim17947JoeKuoD6Init[]   =   { 1, 3, 3, 13, 27, 31, 11, 191, 413, 1011, 2035, 3965, 2071, 5429, 16247, 7439, 15079, 225041, 0 };
            const std::uint32_t dim17948JoeKuoD6Init[]   =   { 1, 3, 3, 11, 7, 23, 87, 215, 241, 687, 1351, 2399, 4677, 12967, 22957, 10443, 116701, 155477, 0 };
            const std::uint32_t dim17949JoeKuoD6Init[]   =   { 1, 3, 7, 5, 25, 55, 5, 197, 359, 879, 619, 1969, 1513, 12743, 10953, 28343, 63685, 39115, 0 };
            const std::uint32_t dim17950JoeKuoD6Init[]   =   { 1, 1, 3, 1, 19, 15, 63, 7, 305, 343, 1333, 3845, 377, 14031, 28383, 4271, 60063, 11827, 0 };
            const std::uint32_t dim17951JoeKuoD6Init[]   =   { 1, 3, 5, 15, 25, 21, 115, 101, 171, 735, 787, 3143, 593, 8793, 4121, 15471, 53491, 20617, 0 };
            const std::uint32_t dim17952JoeKuoD6Init[]   =   { 1, 1, 5, 15, 15, 51, 103, 17, 433, 611, 1351, 1729, 6147, 11623, 3, 6319, 6133, 19029, 0 };
            const std::uint32_t dim17953JoeKuoD6Init[]   =   { 1, 3, 1, 13, 29, 15, 115, 97, 505, 985, 745, 745, 1459, 7193, 1247, 58901, 114255, 212849, 0 };
            const std::uint32_t dim17954JoeKuoD6Init[]   =   { 1, 1, 7, 1, 1, 53, 99, 35, 377, 723, 1751, 2625, 5113, 13295, 20133, 26831, 41657, 51717, 0 };
            const std::uint32_t dim17955JoeKuoD6Init[]   =   { 1, 3, 5, 15, 15, 39, 17, 227, 351, 435, 49, 203, 6959, 11673, 15755, 29733, 51445, 64619, 0 };
            const std::uint32_t dim17956JoeKuoD6Init[]   =   { 1, 1, 1, 3, 25, 51, 57, 137, 415, 49, 355, 2149, 7607, 10781, 30363, 43889, 55543, 36637, 0 };
            const std::uint32_t dim17957JoeKuoD6Init[]   =   { 1, 1, 7, 5, 5, 15, 73, 189, 153, 949, 527, 587, 513, 12891, 16765, 41477, 75569, 80747, 0 };
            const std::uint32_t dim17958JoeKuoD6Init[]   =   { 1, 1, 5, 5, 9, 5, 3, 225, 115, 125, 821, 3551, 4833, 927, 24331, 63669, 26549, 220159, 0 };
            const std::uint32_t dim17959JoeKuoD6Init[]   =   { 1, 1, 3, 9, 21, 7, 9, 183, 391, 783, 493, 2785, 3879, 8311, 9935, 60629, 119329, 5791, 0 };
            const std::uint32_t dim17960JoeKuoD6Init[]   =   { 1, 1, 5, 15, 15, 41, 61, 97, 33, 29, 199, 3335, 1531, 6107, 757, 33797, 3001, 224507, 0 };
            const std::uint32_t dim17961JoeKuoD6Init[]   =   { 1, 1, 3, 9, 13, 39, 25, 247, 407, 1, 1129, 1453, 7091, 5557, 8657, 33961, 100763, 25099, 0 };
            const std::uint32_t dim17962JoeKuoD6Init[]   =   { 1, 3, 3, 13, 31, 21, 69, 73, 431, 827, 861, 235, 2369, 4283, 27183, 29095, 99957, 97577, 0 };
            const std::uint32_t dim17963JoeKuoD6Init[]   =   { 1, 1, 7, 13, 1, 25, 21, 173, 365, 921, 21, 3527, 2481, 8795, 25621, 41755, 127249, 221385, 0 };
            const std::uint32_t dim17964JoeKuoD6Init[]   =   { 1, 1, 1, 5, 25, 25, 65, 203, 305, 373, 527, 4033, 3483, 9403, 28669, 32083, 52273, 77037, 0 };
            const std::uint32_t dim17965JoeKuoD6Init[]   =   { 1, 3, 1, 15, 9, 23, 19, 7, 29, 83, 1163, 1147, 5315, 2381, 21203, 33915, 109511, 40669, 0 };
            const std::uint32_t dim17966JoeKuoD6Init[]   =   { 1, 3, 7, 15, 23, 19, 69, 127, 113, 937, 935, 1067, 2431, 7677, 21327, 44095, 82799, 5715, 0 };
            const std::uint32_t dim17967JoeKuoD6Init[]   =   { 1, 1, 5, 5, 7, 37, 107, 223, 433, 515, 393, 1721, 1977, 6383, 18835, 54841, 103263, 196997, 0 };
            const std::uint32_t dim17968JoeKuoD6Init[]   =   { 1, 1, 1, 3, 1, 11, 85, 173, 259, 685, 595, 1635, 6979, 4483, 8097, 42249, 56259, 105925, 0 };
            const std::uint32_t dim17969JoeKuoD6Init[]   =   { 1, 1, 7, 7, 1, 23, 11, 253, 187, 665, 313, 3745, 2423, 15835, 32085, 48643, 75625, 47511, 0 };
            const std::uint32_t dim17970JoeKuoD6Init[]   =   { 1, 1, 3, 5, 1, 59, 127, 83, 501, 387, 977, 3515, 7921, 12329, 14757, 20287, 49699, 91237, 0 };
            const std::uint32_t dim17971JoeKuoD6Init[]   =   { 1, 3, 5, 11, 31, 45, 51, 109, 319, 621, 1013, 3519, 4023, 12099, 28829, 26691, 83131, 261497, 0 };
            const std::uint32_t dim17972JoeKuoD6Init[]   =   { 1, 1, 3, 3, 5, 35, 51, 253, 253, 569, 1017, 2299, 8159, 13783, 22123, 55213, 111527, 110699, 0 };
            const std::uint32_t dim17973JoeKuoD6Init[]   =   { 1, 3, 7, 3, 9, 5, 59, 129, 41, 845, 723, 1607, 3047, 14323, 19277, 39447, 12465, 45925, 0 };
            const std::uint32_t dim17974JoeKuoD6Init[]   =   { 1, 1, 3, 1, 17, 35, 51, 79, 115, 361, 739, 2037, 6167, 14699, 28187, 65271, 67285, 48489, 0 };
            const std::uint32_t dim17975JoeKuoD6Init[]   =   { 1, 3, 1, 11, 1, 29, 95, 181, 419, 235, 745, 621, 3889, 2933, 743, 23801, 32057, 54103, 0 };
            const std::uint32_t dim17976JoeKuoD6Init[]   =   { 1, 3, 1, 11, 17, 47, 43, 55, 7, 695, 1653, 3983, 961, 3037, 8669, 10039, 86571, 6981, 0 };
            const std::uint32_t dim17977JoeKuoD6Init[]   =   { 1, 1, 5, 15, 13, 19, 67, 141, 291, 511, 1913, 397, 7423, 6541, 21845, 49821, 126047, 218587, 0 };
            const std::uint32_t dim17978JoeKuoD6Init[]   =   { 1, 1, 5, 3, 11, 13, 103, 213, 189, 115, 1495, 2695, 2127, 11979, 13609, 46615, 64775, 206417, 0 };
            const std::uint32_t dim17979JoeKuoD6Init[]   =   { 1, 3, 1, 5, 5, 9, 57, 207, 253, 251, 1155, 1319, 6699, 6613, 21757, 49703, 124879, 89987, 0 };
            const std::uint32_t dim17980JoeKuoD6Init[]   =   { 1, 3, 5, 7, 23, 25, 35, 81, 165, 789, 771, 415, 5557, 8431, 12043, 44359, 9447, 229481, 0 };
            const std::uint32_t dim17981JoeKuoD6Init[]   =   { 1, 1, 1, 13, 17, 21, 63, 251, 387, 767, 85, 3901, 3227, 10329, 5049, 56173, 58065, 78595, 0 };
            const std::uint32_t dim17982JoeKuoD6Init[]   =   { 1, 3, 1, 15, 23, 5, 45, 7, 123, 389, 1041, 1223, 5865, 5365, 2915, 24861, 106893, 170769, 0 };
            const std::uint32_t dim17983JoeKuoD6Init[]   =   { 1, 3, 7, 15, 27, 61, 27, 59, 309, 103, 279, 1829, 1501, 11277, 4461, 34817, 60973, 99805, 0 };
            const std::uint32_t dim17984JoeKuoD6Init[]   =   { 1, 1, 3, 9, 1, 25, 57, 85, 411, 699, 911, 1643, 2687, 13539, 10187, 21597, 18883, 212975, 0 };
            const std::uint32_t dim17985JoeKuoD6Init[]   =   { 1, 1, 3, 7, 5, 7, 81, 209, 225, 321, 1867, 2189, 6315, 5393, 8859, 47471, 41677, 222455, 0 };
            const std::uint32_t dim17986JoeKuoD6Init[]   =   { 1, 1, 5, 11, 27, 33, 119, 159, 273, 659, 883, 3773, 6519, 15449, 17219, 23923, 33749, 225489, 0 };
            const std::uint32_t dim17987JoeKuoD6Init[]   =   { 1, 1, 7, 13, 29, 39, 1, 161, 165, 531, 1019, 2369, 2093, 4341, 24945, 28537, 49467, 258065, 0 };
            const std::uint32_t dim17988JoeKuoD6Init[]   =   { 1, 3, 3, 3, 15, 59, 23, 143, 377, 943, 1329, 977, 7025, 2167, 17973, 65087, 115757, 75959, 0 };
            const std::uint32_t dim17989JoeKuoD6Init[]   =   { 1, 1, 1, 15, 17, 55, 33, 167, 43, 719, 51, 3873, 3317, 10763, 639, 58195, 20023, 100725, 0 };
            const std::uint32_t dim17990JoeKuoD6Init[]   =   { 1, 1, 7, 5, 17, 23, 71, 249, 23, 929, 467, 3073, 3355, 1343, 18755, 12247, 49737, 184103, 0 };
            const std::uint32_t dim17991JoeKuoD6Init[]   =   { 1, 3, 3, 15, 1, 9, 17, 193, 157, 265, 983, 1825, 4805, 2131, 22117, 32937, 57, 261867, 0 };
            const std::uint32_t dim17992JoeKuoD6Init[]   =   { 1, 3, 5, 9, 5, 1, 101, 141, 511, 489, 73, 1789, 1303, 2633, 709, 11891, 44897, 191229, 0 };
            const std::uint32_t dim17993JoeKuoD6Init[]   =   { 1, 1, 7, 15, 1, 27, 121, 7, 129, 421, 725, 1421, 3883, 13335, 7247, 8393, 85029, 127691, 0 };
            const std::uint32_t dim17994JoeKuoD6Init[]   =   { 1, 1, 3, 9, 19, 53, 121, 115, 85, 909, 1535, 3261, 7063, 16381, 1719, 19847, 19041, 215433, 0 };
            const std::uint32_t dim17995JoeKuoD6Init[]   =   { 1, 1, 7, 3, 17, 45, 91, 187, 181, 829, 609, 931, 5727, 3971, 14567, 15871, 9825, 184165, 0 };
            const std::uint32_t dim17996JoeKuoD6Init[]   =   { 1, 1, 1, 3, 5, 29, 7, 249, 361, 815, 1101, 1485, 6879, 5379, 7179, 27467, 101427, 196089, 0 };
            const std::uint32_t dim17997JoeKuoD6Init[]   =   { 1, 1, 5, 7, 23, 11, 27, 175, 237, 747, 1911, 3107, 961, 6649, 29887, 11003, 27561, 233841, 0 };
            const std::uint32_t dim17998JoeKuoD6Init[]   =   { 1, 1, 1, 5, 11, 5, 125, 227, 303, 315, 1879, 817, 7445, 1447, 9333, 54825, 118865, 216397, 0 };
            const std::uint32_t dim17999JoeKuoD6Init[]   =   { 1, 1, 3, 13, 17, 33, 27, 95, 245, 25, 1741, 2633, 1869, 14111, 24507, 61287, 46397, 220803, 0 };
            const std::uint32_t dim18000JoeKuoD6Init[]   =   { 1, 1, 7, 7, 25, 5, 41, 101, 171, 333, 497, 3417, 4921, 4553, 25487, 51529, 72873, 43525, 0 };
            const std::uint32_t dim18001JoeKuoD6Init[]   =   { 1, 1, 7, 7, 9, 19, 25, 161, 235, 929, 1663, 3237, 323, 3889, 31423, 2345, 63113, 212659, 0 };
            const std::uint32_t dim18002JoeKuoD6Init[]   =   { 1, 1, 5, 13, 29, 59, 39, 25, 393, 519, 429, 1461, 5867, 113, 28091, 36813, 47827, 163407, 0 };
            const std::uint32_t dim18003JoeKuoD6Init[]   =   { 1, 3, 5, 13, 15, 49, 85, 161, 83, 389, 765, 3349, 4659, 11007, 24749, 51121, 93511, 229885, 0 };
            const std::uint32_t dim18004JoeKuoD6Init[]   =   { 1, 3, 5, 11, 5, 27, 107, 233, 221, 425, 941, 1181, 5403, 4373, 32625, 41991, 2019, 245967, 0 };
            const std::uint32_t dim18005JoeKuoD6Init[]   =   { 1, 3, 5, 9, 9, 53, 97, 27, 221, 731, 1301, 3517, 4407, 11369, 4251, 31121, 4813, 42029, 0 };
            const std::uint32_t dim18006JoeKuoD6Init[]   =   { 1, 1, 1, 9, 17, 59, 107, 247, 231, 123, 1177, 3299, 6163, 4855, 14547, 63171, 45201, 27711, 0 };
            const std::uint32_t dim18007JoeKuoD6Init[]   =   { 1, 3, 7, 3, 25, 31, 63, 37, 123, 457, 1531, 3723, 4807, 14665, 17973, 42547, 5417, 170323, 0 };
            const std::uint32_t dim18008JoeKuoD6Init[]   =   { 1, 3, 7, 3, 17, 19, 57, 7, 359, 741, 385, 3127, 855, 10803, 30093, 24501, 53629, 40447, 0 };
            const std::uint32_t dim18009JoeKuoD6Init[]   =   { 1, 3, 7, 15, 11, 45, 49, 125, 445, 795, 113, 2425, 7085, 7337, 16297, 26447, 94369, 12371, 0 };
            const std::uint32_t dim18010JoeKuoD6Init[]   =   { 1, 3, 7, 9, 29, 59, 35, 191, 123, 619, 415, 1081, 2469, 4125, 25587, 7853, 119781, 9447, 0 };
            const std::uint32_t dim18011JoeKuoD6Init[]   =   { 1, 3, 1, 15, 13, 13, 111, 89, 381, 757, 389, 253, 6929, 33, 8263, 17385, 122129, 146679, 0 };
            const std::uint32_t dim18012JoeKuoD6Init[]   =   { 1, 1, 3, 3, 15, 35, 101, 95, 479, 577, 1645, 3781, 7533, 4665, 6561, 49897, 72413, 151383, 0 };
            const std::uint32_t dim18013JoeKuoD6Init[]   =   { 1, 1, 1, 1, 7, 49, 23, 223, 189, 763, 227, 2805, 8093, 389, 11525, 30915, 91341, 210231, 0 };
            const std::uint32_t dim18014JoeKuoD6Init[]   =   { 1, 1, 7, 3, 19, 23, 3, 137, 79, 569, 1833, 2091, 4235, 10739, 22855, 33845, 120141, 220267, 0 };
            const std::uint32_t dim18015JoeKuoD6Init[]   =   { 1, 3, 7, 3, 11, 43, 85, 63, 419, 681, 365, 3017, 3603, 6413, 13515, 16003, 107949, 241261, 0 };
            const std::uint32_t dim18016JoeKuoD6Init[]   =   { 1, 1, 5, 13, 3, 35, 41, 193, 189, 999, 1395, 2431, 2227, 7245, 23929, 16137, 14591, 54999, 0 };
            const std::uint32_t dim18017JoeKuoD6Init[]   =   { 1, 1, 7, 15, 23, 51, 47, 77, 31, 25, 589, 611, 371, 13329, 5873, 2133, 40351, 145293, 0 };
            const std::uint32_t dim18018JoeKuoD6Init[]   =   { 1, 1, 7, 15, 17, 19, 53, 155, 309, 573, 1059, 3557, 2445, 12205, 4497, 32061, 130293, 73859, 0 };
            const std::uint32_t dim18019JoeKuoD6Init[]   =   { 1, 1, 7, 13, 3, 25, 71, 157, 237, 185, 1035, 1759, 1331, 13533, 25635, 811, 54391, 91109, 0 };
            const std::uint32_t dim18020JoeKuoD6Init[]   =   { 1, 1, 1, 11, 5, 21, 99, 31, 259, 413, 2033, 2187, 755, 4591, 28641, 64031, 88499, 160789, 0 };
            const std::uint32_t dim18021JoeKuoD6Init[]   =   { 1, 3, 7, 13, 29, 33, 13, 157, 97, 981, 329, 81, 6351, 4171, 10925, 22733, 72521, 105477, 0 };
            const std::uint32_t dim18022JoeKuoD6Init[]   =   { 1, 3, 7, 9, 11, 31, 97, 35, 337, 309, 847, 3429, 2697, 3141, 19481, 43679, 11129, 205757, 0 };
            const std::uint32_t dim18023JoeKuoD6Init[]   =   { 1, 3, 1, 7, 27, 45, 123, 193, 439, 639, 633, 1375, 7307, 1599, 23379, 56811, 100877, 228687, 0 };
            const std::uint32_t dim18024JoeKuoD6Init[]   =   { 1, 3, 7, 1, 29, 43, 103, 131, 103, 933, 143, 2431, 2221, 4565, 20841, 58611, 49163, 13673, 0 };
            const std::uint32_t dim18025JoeKuoD6Init[]   =   { 1, 3, 5, 13, 25, 17, 121, 17, 455, 941, 1577, 509, 5401, 797, 29573, 38373, 50527, 17951, 0 };
            const std::uint32_t dim18026JoeKuoD6Init[]   =   { 1, 1, 1, 13, 25, 21, 77, 253, 199, 871, 935, 3919, 1687, 6653, 20345, 56969, 77989, 244767, 0 };
            const std::uint32_t dim18027JoeKuoD6Init[]   =   { 1, 1, 3, 1, 17, 5, 5, 191, 279, 33, 579, 651, 969, 6091, 11659, 1643, 17935, 85145, 0 };
            const std::uint32_t dim18028JoeKuoD6Init[]   =   { 1, 3, 3, 9, 29, 1, 103, 39, 83, 295, 1237, 207, 4837, 7899, 27879, 23195, 29549, 206885, 0 };
            const std::uint32_t dim18029JoeKuoD6Init[]   =   { 1, 3, 5, 1, 9, 55, 115, 37, 225, 447, 943, 1133, 6203, 949, 9973, 4309, 43969, 166795, 0 };
            const std::uint32_t dim18030JoeKuoD6Init[]   =   { 1, 1, 7, 7, 17, 43, 75, 251, 35, 489, 1011, 355, 4113, 2377, 13775, 34935, 84905, 252973, 0 };
            const std::uint32_t dim18031JoeKuoD6Init[]   =   { 1, 3, 3, 3, 11, 45, 3, 1, 135, 499, 81, 3265, 6657, 3875, 27565, 60931, 13117, 87931, 0 };
            const std::uint32_t dim18032JoeKuoD6Init[]   =   { 1, 1, 3, 1, 9, 1, 77, 69, 137, 241, 1613, 2607, 3307, 171, 13551, 54529, 45937, 180411, 0 };
            const std::uint32_t dim18033JoeKuoD6Init[]   =   { 1, 1, 1, 1, 19, 29, 77, 255, 95, 461, 567, 1103, 2753, 10627, 19479, 43411, 128565, 29869, 0 };
            const std::uint32_t dim18034JoeKuoD6Init[]   =   { 1, 1, 3, 5, 5, 63, 123, 159, 165, 733, 1107, 1711, 5039, 9221, 15541, 5527, 27629, 206505, 0 };
            const std::uint32_t dim18035JoeKuoD6Init[]   =   { 1, 3, 1, 3, 7, 45, 73, 63, 413, 693, 433, 2281, 3981, 7719, 31473, 56939, 70391, 67467, 0 };
            const std::uint32_t dim18036JoeKuoD6Init[]   =   { 1, 1, 1, 11, 19, 33, 113, 151, 427, 603, 1653, 2451, 5367, 12171, 14373, 33175, 62013, 209273, 0 };
            const std::uint32_t dim18037JoeKuoD6Init[]   =   { 1, 3, 5, 5, 17, 37, 109, 5, 187, 293, 617, 2663, 7381, 14217, 23561, 48999, 108717, 248289, 0 };
            const std::uint32_t dim18038JoeKuoD6Init[]   =   { 1, 1, 5, 1, 9, 27, 35, 127, 355, 479, 281, 2081, 7303, 259, 8893, 59141, 20927, 61611, 0 };
            const std::uint32_t dim18039JoeKuoD6Init[]   =   { 1, 3, 3, 15, 31, 33, 71, 209, 315, 363, 593, 1035, 8029, 12501, 2859, 54745, 39391, 153259, 0 };
            const std::uint32_t dim18040JoeKuoD6Init[]   =   { 1, 3, 3, 11, 21, 39, 35, 173, 171, 15, 987, 3737, 7415, 1827, 973, 6831, 108643, 241333, 0 };
            const std::uint32_t dim18041JoeKuoD6Init[]   =   { 1, 3, 7, 9, 17, 37, 127, 243, 153, 195, 113, 309, 5301, 13619, 7927, 35385, 9501, 99241, 0 };
            const std::uint32_t dim18042JoeKuoD6Init[]   =   { 1, 3, 5, 13, 23, 9, 81, 235, 139, 635, 443, 2235, 2613, 2389, 18431, 8409, 2885, 254811, 0 };
            const std::uint32_t dim18043JoeKuoD6Init[]   =   { 1, 3, 7, 9, 1, 5, 15, 109, 141, 173, 1059, 1961, 7945, 10381, 17337, 19591, 42173, 119831, 0 };
            const std::uint32_t dim18044JoeKuoD6Init[]   =   { 1, 3, 1, 13, 19, 7, 111, 111, 345, 327, 1147, 2293, 49, 16213, 25309, 60537, 50421, 108467, 0 };
            const std::uint32_t dim18045JoeKuoD6Init[]   =   { 1, 1, 5, 1, 3, 23, 63, 219, 69, 879, 1397, 3857, 1859, 1939, 4851, 26549, 86019, 7927, 0 };
            const std::uint32_t dim18046JoeKuoD6Init[]   =   { 1, 3, 1, 13, 23, 61, 25, 31, 301, 189, 1031, 2817, 829, 8777, 26869, 54405, 43535, 234687, 0 };
            const std::uint32_t dim18047JoeKuoD6Init[]   =   { 1, 1, 1, 9, 11, 31, 13, 139, 77, 567, 949, 3415, 6955, 14973, 9565, 37911, 18395, 94167, 0 };
            const std::uint32_t dim18048JoeKuoD6Init[]   =   { 1, 3, 5, 13, 17, 17, 21, 213, 171, 993, 1001, 979, 5085, 3909, 11797, 48669, 73541, 48979, 0 };
            const std::uint32_t dim18049JoeKuoD6Init[]   =   { 1, 1, 7, 9, 7, 37, 35, 107, 347, 239, 585, 2883, 3235, 1053, 14871, 25799, 4861, 56335, 0 };
            const std::uint32_t dim18050JoeKuoD6Init[]   =   { 1, 1, 3, 5, 19, 7, 91, 139, 325, 921, 863, 209, 845, 15943, 8281, 55103, 110193, 216091, 0 };
            const std::uint32_t dim18051JoeKuoD6Init[]   =   { 1, 3, 1, 13, 31, 33, 65, 155, 177, 103, 1991, 343, 6299, 3587, 30215, 64335, 114301, 220403, 0 };
            const std::uint32_t dim18052JoeKuoD6Init[]   =   { 1, 3, 5, 3, 31, 37, 121, 157, 443, 349, 1097, 3683, 503, 14061, 14685, 29755, 61543, 232983, 0 };
            const std::uint32_t dim18053JoeKuoD6Init[]   =   { 1, 3, 3, 11, 17, 59, 29, 161, 381, 791, 1647, 1077, 6369, 1095, 17279, 43141, 65003, 144609, 0 };
            const std::uint32_t dim18054JoeKuoD6Init[]   =   { 1, 1, 5, 1, 1, 15, 67, 77, 3, 585, 1909, 1485, 3003, 591, 4711, 10279, 75901, 226417, 0 };
            const std::uint32_t dim18055JoeKuoD6Init[]   =   { 1, 3, 7, 5, 1, 5, 5, 193, 469, 631, 1065, 607, 2751, 8163, 13633, 40563, 1417, 118169, 0 };
            const std::uint32_t dim18056JoeKuoD6Init[]   =   { 1, 1, 7, 9, 25, 25, 109, 27, 157, 495, 225, 1385, 4315, 995, 10591, 1629, 129939, 56765, 0 };
            const std::uint32_t dim18057JoeKuoD6Init[]   =   { 1, 3, 1, 7, 9, 23, 61, 63, 35, 145, 1537, 1029, 4225, 1467, 10519, 32861, 519, 53983, 0 };
            const std::uint32_t dim18058JoeKuoD6Init[]   =   { 1, 3, 3, 11, 7, 59, 25, 199, 403, 967, 1089, 1121, 1063, 6701, 16827, 55479, 72983, 36873, 0 };
            const std::uint32_t dim18059JoeKuoD6Init[]   =   { 1, 1, 1, 13, 9, 27, 19, 23, 395, 229, 1837, 1231, 1737, 10475, 16743, 42369, 130331, 47255, 0 };
            const std::uint32_t dim18060JoeKuoD6Init[]   =   { 1, 1, 5, 7, 29, 15, 95, 155, 339, 65, 751, 2399, 5615, 2987, 16769, 57381, 113021, 41417, 0 };
            const std::uint32_t dim18061JoeKuoD6Init[]   =   { 1, 3, 1, 9, 15, 17, 1, 111, 197, 7, 417, 3999, 7261, 5939, 16773, 29275, 105559, 84685, 0 };
            const std::uint32_t dim18062JoeKuoD6Init[]   =   { 1, 3, 3, 13, 19, 31, 103, 1, 37, 269, 1257, 1397, 4293, 3019, 6503, 7727, 93943, 237313, 0 };
            const std::uint32_t dim18063JoeKuoD6Init[]   =   { 1, 1, 3, 9, 13, 37, 67, 129, 43, 669, 1331, 1787, 8185, 323, 18749, 13737, 86123, 154131, 0 };
            const std::uint32_t dim18064JoeKuoD6Init[]   =   { 1, 3, 1, 11, 3, 51, 13, 35, 197, 867, 559, 1381, 1057, 13293, 20603, 18633, 50503, 169685, 0 };
            const std::uint32_t dim18065JoeKuoD6Init[]   =   { 1, 3, 1, 11, 9, 35, 7, 51, 499, 885, 353, 4095, 6491, 5917, 15053, 18363, 99593, 213089, 0 };
            const std::uint32_t dim18066JoeKuoD6Init[]   =   { 1, 1, 3, 9, 19, 23, 107, 147, 339, 331, 1349, 2855, 3721, 13317, 26457, 783, 93949, 196051, 0 };
            const std::uint32_t dim18067JoeKuoD6Init[]   =   { 1, 1, 5, 1, 9, 61, 89, 217, 315, 385, 1729, 2641, 5753, 6269, 547, 33737, 20103, 31533, 0 };
            const std::uint32_t dim18068JoeKuoD6Init[]   =   { 1, 3, 5, 13, 13, 61, 3, 191, 57, 683, 1227, 1255, 3651, 10687, 9049, 6529, 60783, 28639, 0 };
            const std::uint32_t dim18069JoeKuoD6Init[]   =   { 1, 1, 7, 11, 25, 41, 79, 19, 383, 363, 1731, 1597, 1651, 15037, 22191, 51883, 41927, 82419, 0 };
            const std::uint32_t dim18070JoeKuoD6Init[]   =   { 1, 3, 5, 9, 15, 61, 39, 149, 49, 633, 709, 1743, 621, 14659, 3309, 64129, 91897, 74235, 0 };
            const std::uint32_t dim18071JoeKuoD6Init[]   =   { 1, 3, 7, 15, 5, 59, 7, 197, 111, 885, 1737, 855, 2807, 3817, 13759, 29989, 45105, 171689, 0 };
            const std::uint32_t dim18072JoeKuoD6Init[]   =   { 1, 1, 3, 9, 21, 25, 55, 67, 483, 437, 303, 703, 6993, 1971, 4565, 56117, 6105, 254517, 0 };
            const std::uint32_t dim18073JoeKuoD6Init[]   =   { 1, 3, 3, 13, 15, 13, 19, 3, 487, 751, 1185, 2985, 1619, 7139, 26087, 21105, 9049, 236153, 0 };
            const std::uint32_t dim18074JoeKuoD6Init[]   =   { 1, 1, 5, 7, 15, 55, 51, 231, 85, 953, 713, 659, 2021, 4271, 15961, 26873, 31141, 76635, 0 };
            const std::uint32_t dim18075JoeKuoD6Init[]   =   { 1, 3, 5, 1, 11, 39, 3, 223, 367, 903, 799, 415, 7247, 9539, 14479, 37195, 59951, 181935, 0 };
            const std::uint32_t dim18076JoeKuoD6Init[]   =   { 1, 1, 5, 3, 13, 47, 17, 159, 439, 859, 1067, 3111, 5277, 13973, 21999, 28381, 115685, 231483, 0 };
            const std::uint32_t dim18077JoeKuoD6Init[]   =   { 1, 1, 7, 15, 17, 21, 69, 131, 193, 479, 1075, 3271, 2057, 1295, 31235, 35027, 94145, 65419, 0 };
            const std::uint32_t dim18078JoeKuoD6Init[]   =   { 1, 3, 3, 5, 5, 21, 5, 81, 113, 259, 837, 831, 5985, 6717, 12041, 40355, 50957, 111185, 0 };
            const std::uint32_t dim18079JoeKuoD6Init[]   =   { 1, 1, 1, 9, 15, 47, 103, 195, 465, 739, 1415, 225, 3121, 12623, 7539, 17555, 36703, 217641, 0 };
            const std::uint32_t dim18080JoeKuoD6Init[]   =   { 1, 3, 1, 3, 31, 17, 91, 153, 221, 217, 525, 981, 281, 9869, 9713, 10669, 12049, 97615, 0 };
            const std::uint32_t dim18081JoeKuoD6Init[]   =   { 1, 1, 5, 7, 29, 1, 1, 199, 415, 843, 301, 941, 4589, 13301, 5833, 41311, 74019, 78537, 0 };
            const std::uint32_t dim18082JoeKuoD6Init[]   =   { 1, 1, 5, 11, 13, 5, 41, 127, 213, 917, 1297, 2281, 3193, 3877, 9517, 40685, 14657, 185139, 0 };
            const std::uint32_t dim18083JoeKuoD6Init[]   =   { 1, 1, 1, 7, 21, 45, 87, 33, 425, 487, 643, 271, 7087, 5979, 14795, 27575, 34541, 173251, 0 };
            const std::uint32_t dim18084JoeKuoD6Init[]   =   { 1, 3, 7, 5, 21, 11, 7, 169, 325, 905, 973, 2853, 7929, 8801, 1005, 60641, 45973, 81859, 0 };
            const std::uint32_t dim18085JoeKuoD6Init[]   =   { 1, 3, 3, 1, 1, 35, 39, 81, 93, 463, 697, 2309, 7769, 5169, 17595, 41447, 28837, 52613, 0 };
            const std::uint32_t dim18086JoeKuoD6Init[]   =   { 1, 1, 7, 1, 1, 23, 37, 17, 137, 873, 1657, 681, 503, 7887, 24463, 32453, 112727, 133347, 0 };
            const std::uint32_t dim18087JoeKuoD6Init[]   =   { 1, 1, 5, 9, 19, 35, 37, 85, 11, 245, 11, 3, 6475, 5953, 247, 49447, 32813, 243841, 0 };
            const std::uint32_t dim18088JoeKuoD6Init[]   =   { 1, 3, 5, 3, 19, 53, 37, 45, 431, 259, 1831, 1443, 2237, 7651, 20701, 22857, 50041, 119667, 0 };
            const std::uint32_t dim18089JoeKuoD6Init[]   =   { 1, 1, 7, 1, 5, 37, 113, 69, 389, 369, 1251, 1989, 7613, 10669, 4233, 33379, 72465, 256861, 0 };
            const std::uint32_t dim18090JoeKuoD6Init[]   =   { 1, 1, 7, 5, 27, 55, 17, 75, 373, 325, 1981, 1743, 7341, 319, 28169, 3587, 66057, 169723, 0 };
            const std::uint32_t dim18091JoeKuoD6Init[]   =   { 1, 3, 3, 15, 27, 31, 47, 91, 367, 245, 2045, 979, 2169, 10935, 29523, 64871, 119447, 92131, 0 };
            const std::uint32_t dim18092JoeKuoD6Init[]   =   { 1, 3, 7, 15, 9, 11, 93, 61, 249, 107, 1883, 2547, 375, 4195, 6451, 14533, 62529, 93557, 0 };
            const std::uint32_t dim18093JoeKuoD6Init[]   =   { 1, 1, 1, 3, 29, 61, 65, 155, 301, 1017, 131, 1567, 3649, 3447, 27943, 52111, 9133, 88147, 0 };
            const std::uint32_t dim18094JoeKuoD6Init[]   =   { 1, 1, 1, 1, 21, 59, 107, 151, 265, 707, 767, 2325, 8095, 14027, 15355, 15465, 83143, 116199, 0 };
            const std::uint32_t dim18095JoeKuoD6Init[]   =   { 1, 3, 1, 15, 23, 51, 31, 25, 439, 357, 1563, 1091, 2135, 1327, 18427, 60965, 29215, 157351, 0 };
            const std::uint32_t dim18096JoeKuoD6Init[]   =   { 1, 3, 3, 13, 29, 37, 25, 215, 149, 487, 703, 1787, 3641, 8301, 8795, 13845, 95245, 169793, 0 };
            const std::uint32_t dim18097JoeKuoD6Init[]   =   { 1, 3, 3, 11, 27, 3, 49, 87, 69, 687, 1181, 3405, 589, 12901, 14199, 48607, 74027, 181379, 0 };
            const std::uint32_t dim18098JoeKuoD6Init[]   =   { 1, 3, 5, 13, 9, 15, 33, 229, 135, 769, 1005, 2435, 4831, 5493, 16745, 64379, 20253, 52661, 0 };
            const std::uint32_t dim18099JoeKuoD6Init[]   =   { 1, 1, 1, 13, 9, 61, 33, 127, 339, 15, 945, 219, 4291, 6995, 29127, 61853, 40741, 170541, 0 };
            const std::uint32_t dim18100JoeKuoD6Init[]   =   { 1, 3, 3, 15, 9, 33, 75, 39, 327, 133, 733, 1125, 2747, 15031, 24575, 65013, 41997, 158679, 0 };
            const std::uint32_t dim18101JoeKuoD6Init[]   =   { 1, 1, 3, 9, 3, 9, 63, 83, 493, 175, 249, 1977, 8177, 4067, 2131, 12467, 86185, 73417, 0 };
            const std::uint32_t dim18102JoeKuoD6Init[]   =   { 1, 1, 3, 13, 29, 55, 91, 109, 73, 913, 1343, 2147, 105, 8763, 7613, 55749, 4339, 61253, 0 };
            const std::uint32_t dim18103JoeKuoD6Init[]   =   { 1, 1, 5, 5, 17, 19, 45, 57, 345, 835, 341, 1365, 5187, 7485, 22685, 32321, 67279, 141119, 0 };
            const std::uint32_t dim18104JoeKuoD6Init[]   =   { 1, 1, 3, 11, 9, 47, 11, 231, 241, 681, 255, 3663, 5547, 997, 2445, 64413, 55349, 61785, 0 };
            const std::uint32_t dim18105JoeKuoD6Init[]   =   { 1, 3, 5, 5, 23, 29, 23, 249, 149, 1011, 173, 271, 485, 1239, 81, 59277, 96669, 210859, 0 };
            const std::uint32_t dim18106JoeKuoD6Init[]   =   { 1, 3, 3, 1, 17, 9, 41, 39, 309, 131, 1431, 1497, 1669, 14191, 22795, 48951, 101731, 70847, 0 };
            const std::uint32_t dim18107JoeKuoD6Init[]   =   { 1, 1, 3, 15, 1, 11, 37, 79, 23, 1023, 585, 127, 7817, 15009, 3897, 44601, 83039, 240457, 0 };
            const std::uint32_t dim18108JoeKuoD6Init[]   =   { 1, 3, 5, 9, 21, 33, 55, 31, 193, 745, 1741, 3637, 7265, 8969, 11797, 33239, 29123, 126077, 0 };
            const std::uint32_t dim18109JoeKuoD6Init[]   =   { 1, 3, 3, 13, 31, 5, 87, 215, 271, 573, 1423, 2611, 947, 14669, 23785, 60579, 127099, 55877, 0 };
            const std::uint32_t dim18110JoeKuoD6Init[]   =   { 1, 3, 1, 13, 5, 53, 103, 85, 237, 457, 739, 1201, 133, 8589, 13471, 6707, 42257, 141989, 0 };
            const std::uint32_t dim18111JoeKuoD6Init[]   =   { 1, 1, 1, 5, 23, 3, 65, 159, 445, 823, 341, 1723, 6263, 9421, 16023, 19145, 52337, 229397, 0 };
            const std::uint32_t dim18112JoeKuoD6Init[]   =   { 1, 3, 5, 3, 15, 3, 15, 251, 407, 137, 951, 1319, 1035, 7713, 29579, 19591, 77841, 84949, 0 };
            const std::uint32_t dim18113JoeKuoD6Init[]   =   { 1, 1, 7, 15, 19, 25, 63, 141, 511, 11, 1027, 1209, 6627, 8127, 14879, 12965, 109973, 144501, 0 };
            const std::uint32_t dim18114JoeKuoD6Init[]   =   { 1, 1, 1, 3, 11, 57, 65, 169, 453, 197, 1249, 2933, 3743, 1971, 19373, 32109, 73265, 46185, 0 };
            const std::uint32_t dim18115JoeKuoD6Init[]   =   { 1, 1, 3, 1, 3, 1, 21, 47, 471, 565, 1795, 1771, 3187, 7189, 18627, 22993, 112319, 158693, 0 };
            const std::uint32_t dim18116JoeKuoD6Init[]   =   { 1, 1, 5, 7, 5, 25, 127, 113, 31, 609, 1273, 2799, 5713, 16091, 22239, 43617, 126003, 218991, 0 };
            const std::uint32_t dim18117JoeKuoD6Init[]   =   { 1, 3, 3, 7, 19, 59, 19, 185, 483, 431, 335, 565, 819, 2555, 18653, 36573, 50085, 31007, 0 };
            const std::uint32_t dim18118JoeKuoD6Init[]   =   { 1, 1, 3, 13, 17, 61, 5, 219, 297, 755, 2005, 391, 4927, 1517, 11341, 9527, 51739, 182599, 0 };
            const std::uint32_t dim18119JoeKuoD6Init[]   =   { 1, 3, 7, 9, 9, 3, 39, 211, 475, 717, 189, 819, 529, 469, 28559, 7321, 60213, 79505, 0 };
            const std::uint32_t dim18120JoeKuoD6Init[]   =   { 1, 3, 1, 9, 17, 39, 53, 65, 247, 145, 9, 1669, 7221, 8359, 11021, 29775, 24693, 208655, 0 };
            const std::uint32_t dim18121JoeKuoD6Init[]   =   { 1, 1, 5, 13, 7, 7, 31, 135, 375, 439, 1419, 3579, 4313, 14057, 31505, 55249, 5345, 69537, 0 };
            const std::uint32_t dim18122JoeKuoD6Init[]   =   { 1, 3, 5, 9, 21, 3, 125, 223, 9, 73, 1693, 281, 3941, 10377, 29365, 19807, 73973, 169113, 0 };
            const std::uint32_t dim18123JoeKuoD6Init[]   =   { 1, 3, 7, 15, 29, 41, 119, 75, 241, 79, 1969, 1091, 6241, 10685, 11579, 3791, 124443, 5051, 0 };
            const std::uint32_t dim18124JoeKuoD6Init[]   =   { 1, 3, 7, 15, 23, 53, 13, 255, 205, 547, 255, 1589, 7261, 15735, 14521, 29679, 109373, 236433, 0 };
            const std::uint32_t dim18125JoeKuoD6Init[]   =   { 1, 3, 7, 3, 17, 37, 71, 163, 95, 265, 1, 3239, 1779, 9047, 31387, 32291, 86741, 55317, 0 };
            const std::uint32_t dim18126JoeKuoD6Init[]   =   { 1, 3, 1, 9, 31, 55, 117, 247, 317, 673, 749, 1155, 7743, 6427, 25273, 49701, 62345, 20913, 0 };
            const std::uint32_t dim18127JoeKuoD6Init[]   =   { 1, 3, 3, 7, 27, 55, 35, 111, 69, 799, 213, 3011, 4359, 14763, 7387, 13281, 58397, 38415, 0 };
            const std::uint32_t dim18128JoeKuoD6Init[]   =   { 1, 1, 5, 9, 5, 61, 49, 219, 419, 297, 1019, 2181, 6069, 12957, 24637, 23317, 6389, 240893, 0 };
            const std::uint32_t dim18129JoeKuoD6Init[]   =   { 1, 1, 5, 15, 13, 57, 59, 43, 373, 647, 1407, 3955, 5583, 15229, 20935, 38007, 65971, 95987, 0 };
            const std::uint32_t dim18130JoeKuoD6Init[]   =   { 1, 1, 7, 7, 23, 17, 77, 91, 449, 75, 1059, 3337, 2041, 261, 25077, 28161, 44537, 189443, 0 };
            const std::uint32_t dim18131JoeKuoD6Init[]   =   { 1, 1, 7, 11, 9, 7, 117, 225, 457, 941, 161, 1825, 1101, 193, 32619, 37245, 102633, 86707, 0 };
            const std::uint32_t dim18132JoeKuoD6Init[]   =   { 1, 1, 1, 7, 13, 43, 33, 137, 275, 691, 1387, 1265, 759, 1457, 4877, 41813, 4159, 234397, 0 };
            const std::uint32_t dim18133JoeKuoD6Init[]   =   { 1, 3, 3, 1, 9, 23, 71, 39, 205, 175, 953, 2965, 3283, 6025, 5905, 34691, 120987, 71841, 0 };
            const std::uint32_t dim18134JoeKuoD6Init[]   =   { 1, 3, 1, 13, 31, 63, 49, 73, 299, 169, 1265, 2205, 1299, 10045, 6919, 26067, 56909, 42549, 0 };
            const std::uint32_t dim18135JoeKuoD6Init[]   =   { 1, 3, 3, 1, 31, 41, 75, 219, 457, 407, 5, 1901, 6823, 531, 3155, 64375, 38523, 68217, 0 };
            const std::uint32_t dim18136JoeKuoD6Init[]   =   { 1, 1, 7, 9, 7, 35, 123, 193, 145, 1021, 757, 3775, 2313, 11885, 11649, 61071, 129363, 120467, 0 };
            const std::uint32_t dim18137JoeKuoD6Init[]   =   { 1, 3, 7, 3, 29, 21, 127, 93, 415, 641, 453, 923, 7713, 9569, 5961, 25969, 31095, 93317, 0 };
            const std::uint32_t dim18138JoeKuoD6Init[]   =   { 1, 3, 3, 1, 5, 15, 21, 235, 211, 663, 385, 2429, 319, 11571, 17539, 42975, 43179, 100105, 0 };
            const std::uint32_t dim18139JoeKuoD6Init[]   =   { 1, 3, 7, 7, 25, 57, 51, 215, 393, 167, 1569, 3235, 5555, 3391, 2389, 36485, 21919, 164479, 0 };
            const std::uint32_t dim18140JoeKuoD6Init[]   =   { 1, 3, 3, 3, 29, 21, 81, 59, 239, 671, 605, 583, 2341, 2321, 28593, 19035, 10209, 36433, 0 };
            const std::uint32_t dim18141JoeKuoD6Init[]   =   { 1, 3, 3, 11, 31, 33, 1, 147, 111, 523, 427, 3545, 111, 8009, 29101, 34549, 122745, 82117, 0 };
            const std::uint32_t dim18142JoeKuoD6Init[]   =   { 1, 3, 5, 15, 19, 37, 97, 141, 387, 523, 467, 1657, 4161, 5505, 18091, 39597, 124423, 74827, 0 };
            const std::uint32_t dim18143JoeKuoD6Init[]   =   { 1, 1, 1, 11, 21, 63, 61, 13, 169, 851, 1863, 3307, 7189, 10791, 22619, 24431, 127781, 14717, 0 };
            const std::uint32_t dim18144JoeKuoD6Init[]   =   { 1, 1, 3, 13, 27, 41, 69, 127, 497, 565, 1489, 277, 2551, 15409, 9885, 187, 101319, 194121, 0 };
            const std::uint32_t dim18145JoeKuoD6Init[]   =   { 1, 1, 7, 7, 17, 45, 1, 139, 347, 503, 1189, 1459, 6117, 14319, 22153, 2915, 91991, 246679, 0 };
            const std::uint32_t dim18146JoeKuoD6Init[]   =   { 1, 3, 3, 3, 9, 41, 25, 199, 327, 295, 945, 2765, 563, 11605, 24267, 37729, 80057, 169479, 0 };
            const std::uint32_t dim18147JoeKuoD6Init[]   =   { 1, 1, 7, 3, 23, 19, 13, 219, 235, 837, 1015, 2071, 2727, 3989, 32539, 26713, 112391, 163943, 0 };
            const std::uint32_t dim18148JoeKuoD6Init[]   =   { 1, 3, 3, 9, 21, 27, 17, 187, 315, 753, 817, 3053, 5961, 973, 23973, 37621, 105637, 247711, 0 };
            const std::uint32_t dim18149JoeKuoD6Init[]   =   { 1, 1, 7, 1, 11, 15, 45, 25, 421, 213, 663, 3829, 469, 15889, 28773, 14323, 107705, 111729, 0 };
            const std::uint32_t dim18150JoeKuoD6Init[]   =   { 1, 1, 1, 7, 7, 7, 51, 189, 457, 95, 1903, 639, 1933, 7409, 22327, 18959, 42679, 158987, 0 };
            const std::uint32_t dim18151JoeKuoD6Init[]   =   { 1, 1, 5, 9, 13, 13, 49, 159, 387, 365, 1799, 2399, 6375, 14965, 32495, 5383, 73479, 5653, 0 };
            const std::uint32_t dim18152JoeKuoD6Init[]   =   { 1, 1, 3, 1, 29, 23, 81, 73, 183, 563, 435, 133, 5731, 6663, 21219, 60007, 101215, 68775, 0 };
            const std::uint32_t dim18153JoeKuoD6Init[]   =   { 1, 1, 7, 11, 31, 47, 43, 159, 221, 745, 1317, 2405, 4563, 4073, 27675, 14225, 114231, 222553, 0 };
            const std::uint32_t dim18154JoeKuoD6Init[]   =   { 1, 1, 1, 5, 11, 63, 105, 99, 413, 81, 771, 547, 1633, 8097, 30431, 31417, 101379, 163575, 0 };
            const std::uint32_t dim18155JoeKuoD6Init[]   =   { 1, 1, 3, 9, 23, 29, 123, 149, 241, 267, 1925, 467, 7743, 4473, 12223, 10521, 86265, 89949, 0 };
            const std::uint32_t dim18156JoeKuoD6Init[]   =   { 1, 3, 5, 1, 31, 29, 111, 67, 311, 851, 1919, 2563, 3725, 4035, 7241, 13859, 105207, 200599, 0 };
            const std::uint32_t dim18157JoeKuoD6Init[]   =   { 1, 3, 7, 3, 19, 53, 113, 107, 133, 243, 2021, 2669, 4633, 14393, 24827, 1233, 81471, 20105, 0 };
            const std::uint32_t dim18158JoeKuoD6Init[]   =   { 1, 1, 1, 5, 3, 23, 43, 149, 157, 875, 1175, 963, 6189, 7343, 13913, 41375, 112857, 236047, 0 };
            const std::uint32_t dim18159JoeKuoD6Init[]   =   { 1, 3, 5, 15, 11, 31, 43, 225, 469, 229, 703, 3033, 2341, 10309, 12057, 13325, 109019, 130789, 0 };
            const std::uint32_t dim18160JoeKuoD6Init[]   =   { 1, 1, 1, 7, 27, 47, 45, 49, 371, 971, 1121, 2179, 1267, 9499, 10771, 28781, 77059, 90765, 0 };
            const std::uint32_t dim18161JoeKuoD6Init[]   =   { 1, 1, 7, 1, 17, 27, 59, 169, 269, 217, 983, 1365, 1985, 12287, 5385, 46407, 24827, 155761, 0 };
            const std::uint32_t dim18162JoeKuoD6Init[]   =   { 1, 1, 7, 11, 9, 5, 19, 205, 159, 937, 763, 3823, 3625, 14209, 32031, 58879, 118449, 50723, 0 };
            const std::uint32_t dim18163JoeKuoD6Init[]   =   { 1, 1, 5, 3, 25, 55, 27, 35, 125, 999, 1541, 3883, 539, 5691, 18071, 63199, 112089, 194825, 0 };
            const std::uint32_t dim18164JoeKuoD6Init[]   =   { 1, 3, 3, 1, 27, 43, 57, 225, 173, 673, 1339, 3433, 5743, 1375, 32429, 35071, 98035, 229973, 0 };
            const std::uint32_t dim18165JoeKuoD6Init[]   =   { 1, 3, 3, 9, 3, 51, 5, 203, 439, 41, 529, 863, 6735, 13211, 7075, 55637, 24481, 46673, 0 };
            const std::uint32_t dim18166JoeKuoD6Init[]   =   { 1, 1, 5, 11, 15, 23, 93, 7, 181, 843, 777, 1299, 1941, 7147, 26253, 10967, 5387, 84611, 0 };
            const std::uint32_t dim18167JoeKuoD6Init[]   =   { 1, 3, 1, 7, 9, 57, 127, 155, 257, 423, 1421, 261, 4477, 11169, 22997, 12371, 8705, 135883, 0 };
            const std::uint32_t dim18168JoeKuoD6Init[]   =   { 1, 3, 1, 9, 17, 9, 15, 209, 427, 889, 1939, 3623, 2587, 4037, 32233, 40391, 32529, 63851, 0 };
            const std::uint32_t dim18169JoeKuoD6Init[]   =   { 1, 3, 3, 13, 3, 19, 49, 155, 213, 239, 817, 1787, 2999, 9955, 20155, 44711, 41367, 59623, 0 };
            const std::uint32_t dim18170JoeKuoD6Init[]   =   { 1, 3, 7, 5, 5, 39, 103, 181, 405, 85, 1997, 3639, 1259, 10737, 189, 44377, 23589, 89371, 0 };
            const std::uint32_t dim18171JoeKuoD6Init[]   =   { 1, 3, 5, 11, 15, 13, 57, 81, 203, 773, 1571, 3235, 6625, 13803, 2091, 64265, 131013, 189705, 0 };
            const std::uint32_t dim18172JoeKuoD6Init[]   =   { 1, 1, 1, 13, 15, 3, 113, 159, 149, 55, 355, 2345, 5043, 4067, 23277, 32647, 43755, 5445, 0 };
            const std::uint32_t dim18173JoeKuoD6Init[]   =   { 1, 3, 3, 9, 31, 7, 67, 177, 423, 269, 1731, 3957, 4383, 13483, 14653, 8243, 57689, 37375, 0 };
            const std::uint32_t dim18174JoeKuoD6Init[]   =   { 1, 1, 3, 5, 25, 5, 77, 199, 161, 859, 497, 1679, 6809, 4877, 1107, 16443, 15505, 138155, 0 };
            const std::uint32_t dim18175JoeKuoD6Init[]   =   { 1, 3, 5, 1, 11, 57, 7, 49, 145, 569, 571, 2679, 7531, 14517, 12425, 6285, 116961, 116397, 0 };
            const std::uint32_t dim18176JoeKuoD6Init[]   =   { 1, 1, 7, 11, 1, 37, 65, 43, 151, 419, 801, 3231, 5321, 10725, 12885, 62771, 16507, 179009, 0 };
            const std::uint32_t dim18177JoeKuoD6Init[]   =   { 1, 1, 5, 11, 29, 55, 89, 81, 325, 47, 1037, 3235, 2017, 10875, 8919, 25115, 118035, 178227, 0 };
            const std::uint32_t dim18178JoeKuoD6Init[]   =   { 1, 3, 1, 7, 1, 43, 101, 25, 449, 617, 381, 3437, 6655, 1291, 18693, 53939, 99143, 195695, 0 };
            const std::uint32_t dim18179JoeKuoD6Init[]   =   { 1, 3, 1, 5, 23, 7, 47, 159, 295, 939, 173, 3087, 1497, 6353, 13893, 13465, 118973, 193737, 0 };
            const std::uint32_t dim18180JoeKuoD6Init[]   =   { 1, 1, 3, 9, 3, 41, 65, 79, 449, 345, 2039, 1193, 5915, 13689, 1257, 23273, 48515, 256793, 0 };
            const std::uint32_t dim18181JoeKuoD6Init[]   =   { 1, 3, 5, 11, 11, 55, 13, 117, 343, 899, 1853, 373, 6885, 12863, 1209, 34433, 48215, 218187, 0 };
            const std::uint32_t dim18182JoeKuoD6Init[]   =   { 1, 3, 7, 7, 3, 45, 103, 145, 55, 507, 743, 4027, 2075, 15707, 4473, 50077, 64551, 204305, 0 };
            const std::uint32_t dim18183JoeKuoD6Init[]   =   { 1, 1, 3, 5, 31, 45, 123, 233, 363, 1003, 411, 1459, 6455, 985, 29451, 17625, 44153, 137097, 0 };
            const std::uint32_t dim18184JoeKuoD6Init[]   =   { 1, 3, 3, 1, 27, 11, 53, 251, 41, 43, 495, 107, 6145, 8785, 28997, 7181, 92903, 105785, 0 };
            const std::uint32_t dim18185JoeKuoD6Init[]   =   { 1, 1, 3, 11, 13, 5, 117, 141, 463, 639, 1857, 2873, 3627, 6081, 18207, 29451, 80909, 73557, 0 };
            const std::uint32_t dim18186JoeKuoD6Init[]   =   { 1, 1, 1, 3, 29, 51, 15, 81, 85, 487, 307, 2481, 2769, 14901, 9407, 58321, 52813, 230393, 0 };
            const std::uint32_t dim18187JoeKuoD6Init[]   =   { 1, 3, 3, 11, 31, 7, 107, 43, 205, 811, 1121, 2757, 2447, 6843, 21347, 9143, 41003, 80507, 0 };
            const std::uint32_t dim18188JoeKuoD6Init[]   =   { 1, 1, 1, 1, 29, 19, 13, 203, 47, 689, 2003, 1477, 7857, 5031, 21781, 5745, 3649, 160389, 0 };
            const std::uint32_t dim18189JoeKuoD6Init[]   =   { 1, 3, 3, 7, 21, 21, 65, 3, 351, 157, 167, 3425, 2395, 9165, 26143, 57221, 127171, 54461, 0 };
            const std::uint32_t dim18190JoeKuoD6Init[]   =   { 1, 3, 1, 15, 13, 13, 65, 53, 305, 719, 181, 709, 5485, 13385, 30287, 52669, 82647, 83851, 0 };
            const std::uint32_t dim18191JoeKuoD6Init[]   =   { 1, 1, 3, 11, 11, 23, 31, 109, 205, 123, 509, 3831, 7771, 7341, 31613, 28035, 38061, 49375, 0 };
            const std::uint32_t dim18192JoeKuoD6Init[]   =   { 1, 3, 3, 3, 15, 33, 47, 159, 321, 589, 393, 3253, 3743, 6161, 445, 33129, 8181, 27793, 0 };
            const std::uint32_t dim18193JoeKuoD6Init[]   =   { 1, 1, 1, 13, 9, 57, 111, 253, 203, 539, 673, 855, 1937, 2699, 25795, 6889, 13531, 63561, 0 };
            const std::uint32_t dim18194JoeKuoD6Init[]   =   { 1, 1, 1, 13, 31, 45, 13, 101, 113, 903, 1699, 2423, 7967, 7957, 20303, 64395, 124447, 33947, 0 };
            const std::uint32_t dim18195JoeKuoD6Init[]   =   { 1, 3, 5, 11, 17, 39, 59, 181, 421, 535, 1445, 3927, 5433, 12885, 12497, 47231, 39819, 46371, 0 };
            const std::uint32_t dim18196JoeKuoD6Init[]   =   { 1, 3, 5, 7, 27, 3, 75, 49, 461, 781, 433, 1767, 6903, 11907, 2063, 55199, 82823, 229405, 0 };
            const std::uint32_t dim18197JoeKuoD6Init[]   =   { 1, 3, 3, 15, 17, 61, 17, 23, 247, 683, 33, 4027, 341, 8069, 2529, 9757, 95653, 12927, 0 };
            const std::uint32_t dim18198JoeKuoD6Init[]   =   { 1, 3, 3, 11, 17, 7, 29, 205, 353, 917, 219, 3509, 7803, 5939, 25111, 45357, 9259, 1549, 0 };
            const std::uint32_t dim18199JoeKuoD6Init[]   =   { 1, 3, 3, 15, 21, 7, 23, 25, 459, 291, 31, 2091, 1177, 9311, 12231, 16617, 33575, 252643, 0 };
            const std::uint32_t dim18200JoeKuoD6Init[]   =   { 1, 3, 5, 5, 3, 51, 113, 123, 453, 503, 1575, 2785, 5011, 1789, 819, 30857, 12955, 172421, 0 };
            const std::uint32_t dim18201JoeKuoD6Init[]   =   { 1, 1, 5, 3, 15, 15, 125, 65, 113, 281, 53, 3417, 5279, 6351, 25931, 54835, 124077, 204241, 0 };
            const std::uint32_t dim18202JoeKuoD6Init[]   =   { 1, 1, 3, 9, 29, 31, 19, 179, 275, 933, 711, 3351, 6221, 1711, 9375, 11645, 118911, 249395, 0 };
            const std::uint32_t dim18203JoeKuoD6Init[]   =   { 1, 3, 7, 13, 23, 59, 43, 61, 85, 267, 691, 3949, 2135, 3203, 21455, 61895, 71157, 136739, 0 };
            const std::uint32_t dim18204JoeKuoD6Init[]   =   { 1, 1, 7, 5, 19, 27, 69, 141, 9, 633, 95, 3789, 7823, 12635, 27661, 30285, 129469, 67163, 0 };
            const std::uint32_t dim18205JoeKuoD6Init[]   =   { 1, 3, 3, 9, 11, 25, 103, 47, 425, 809, 1279, 411, 219, 6703, 24145, 17303, 56835, 84879, 0 };
            const std::uint32_t dim18206JoeKuoD6Init[]   =   { 1, 1, 5, 13, 29, 41, 47, 133, 197, 615, 169, 2157, 1795, 4945, 31693, 57763, 39369, 83353, 0 };
            const std::uint32_t dim18207JoeKuoD6Init[]   =   { 1, 3, 1, 3, 27, 23, 23, 213, 387, 239, 977, 221, 383, 11005, 7221, 8795, 100963, 163777, 0 };
            const std::uint32_t dim18208JoeKuoD6Init[]   =   { 1, 1, 1, 1, 31, 29, 87, 93, 239, 399, 801, 3143, 6973, 16331, 16865, 1823, 1127, 41983, 0 };
            const std::uint32_t dim18209JoeKuoD6Init[]   =   { 1, 1, 3, 13, 7, 39, 25, 251, 277, 417, 119, 3033, 6785, 9783, 1641, 60169, 25047, 182263, 0 };
            const std::uint32_t dim18210JoeKuoD6Init[]   =   { 1, 1, 5, 5, 7, 35, 17, 47, 295, 861, 1671, 1971, 4583, 3925, 31013, 50039, 125191, 143019, 0 };
            const std::uint32_t dim18211JoeKuoD6Init[]   =   { 1, 1, 5, 1, 3, 57, 11, 23, 273, 209, 617, 1499, 665, 1193, 7539, 1625, 48065, 82843, 0 };
            const std::uint32_t dim18212JoeKuoD6Init[]   =   { 1, 1, 3, 15, 15, 17, 39, 145, 193, 503, 1305, 2071, 93, 11529, 14267, 14779, 49327, 51347, 0 };
            const std::uint32_t dim18213JoeKuoD6Init[]   =   { 1, 3, 5, 3, 7, 39, 63, 171, 263, 493, 383, 3209, 4277, 6259, 1345, 48013, 110571, 127865, 0 };
            const std::uint32_t dim18214JoeKuoD6Init[]   =   { 1, 3, 1, 7, 15, 29, 93, 75, 37, 235, 1095, 153, 745, 9785, 28831, 58899, 67091, 34743, 0 };
            const std::uint32_t dim18215JoeKuoD6Init[]   =   { 1, 3, 7, 9, 27, 23, 67, 85, 491, 447, 1899, 709, 555, 13979, 12529, 38383, 16091, 117301, 0 };
            const std::uint32_t dim18216JoeKuoD6Init[]   =   { 1, 1, 5, 3, 9, 55, 109, 173, 29, 19, 1265, 2391, 7761, 1953, 5643, 24079, 14187, 127017, 0 };
            const std::uint32_t dim18217JoeKuoD6Init[]   =   { 1, 3, 7, 13, 21, 57, 105, 145, 73, 421, 403, 5, 3523, 7005, 1109, 63357, 111671, 191857, 0 };
            const std::uint32_t dim18218JoeKuoD6Init[]   =   { 1, 1, 7, 13, 5, 27, 21, 5, 199, 515, 917, 365, 2775, 12453, 26989, 60593, 98977, 161759, 0 };
            const std::uint32_t dim18219JoeKuoD6Init[]   =   { 1, 3, 1, 13, 15, 37, 71, 65, 27, 533, 1311, 2981, 1945, 7183, 5337, 20659, 67355, 185633, 0 };
            const std::uint32_t dim18220JoeKuoD6Init[]   =   { 1, 1, 5, 7, 21, 39, 21, 195, 443, 979, 1033, 1823, 3045, 3023, 31783, 61803, 1023, 119291, 0 };
            const std::uint32_t dim18221JoeKuoD6Init[]   =   { 1, 1, 3, 11, 5, 15, 107, 155, 465, 249, 1845, 357, 2769, 3313, 12335, 16615, 20809, 103469, 0 };
            const std::uint32_t dim18222JoeKuoD6Init[]   =   { 1, 1, 3, 9, 13, 21, 11, 227, 173, 949, 1255, 3257, 601, 10865, 12779, 9173, 87255, 12867, 0 };
            const std::uint32_t dim18223JoeKuoD6Init[]   =   { 1, 3, 3, 15, 3, 41, 97, 141, 385, 23, 1253, 2905, 1523, 7647, 7069, 61143, 101245, 59747, 0 };
            const std::uint32_t dim18224JoeKuoD6Init[]   =   { 1, 3, 1, 3, 7, 35, 117, 93, 357, 741, 1673, 3295, 6809, 547, 22949, 42151, 91241, 16189, 0 };
            const std::uint32_t dim18225JoeKuoD6Init[]   =   { 1, 3, 5, 9, 25, 31, 27, 221, 55, 595, 1513, 3963, 3143, 1189, 19843, 6361, 19575, 231765, 0 };
            const std::uint32_t dim18226JoeKuoD6Init[]   =   { 1, 1, 5, 1, 3, 35, 91, 217, 385, 717, 57, 1471, 3529, 859, 15259, 4411, 54491, 79841, 0 };
            const std::uint32_t dim18227JoeKuoD6Init[]   =   { 1, 1, 5, 9, 29, 47, 111, 89, 469, 975, 513, 1339, 1747, 8839, 30375, 46217, 128191, 95831, 0 };
            const std::uint32_t dim18228JoeKuoD6Init[]   =   { 1, 1, 5, 13, 9, 45, 3, 221, 223, 461, 1353, 3953, 5505, 3139, 3407, 12953, 74487, 209401, 0 };
            const std::uint32_t dim18229JoeKuoD6Init[]   =   { 1, 1, 7, 7, 7, 43, 33, 143, 427, 183, 573, 2881, 7355, 10693, 12841, 14267, 61847, 47689, 0 };
            const std::uint32_t dim18230JoeKuoD6Init[]   =   { 1, 1, 3, 5, 23, 45, 53, 173, 347, 715, 173, 3385, 429, 8143, 2831, 57883, 77245, 37613, 0 };
            const std::uint32_t dim18231JoeKuoD6Init[]   =   { 1, 1, 1, 13, 21, 47, 33, 157, 171, 47, 1981, 2003, 7401, 7687, 10553, 38083, 111901, 30251, 0 };
            const std::uint32_t dim18232JoeKuoD6Init[]   =   { 1, 1, 5, 9, 23, 35, 121, 251, 7, 835, 1561, 1605, 7023, 15645, 14313, 6361, 107973, 211667, 0 };
            const std::uint32_t dim18233JoeKuoD6Init[]   =   { 1, 3, 1, 13, 25, 39, 81, 31, 145, 483, 1587, 3457, 5293, 927, 3529, 22457, 69689, 190371, 0 };
            const std::uint32_t dim18234JoeKuoD6Init[]   =   { 1, 1, 1, 3, 25, 61, 87, 111, 441, 829, 313, 2271, 205, 10187, 3003, 47237, 99899, 200553, 0 };
            const std::uint32_t dim18235JoeKuoD6Init[]   =   { 1, 1, 7, 13, 31, 51, 9, 243, 219, 139, 1703, 2001, 959, 11265, 27897, 9081, 4473, 107737, 0 };
            const std::uint32_t dim18236JoeKuoD6Init[]   =   { 1, 3, 5, 1, 25, 37, 61, 131, 487, 35, 1293, 833, 3847, 11315, 11811, 2763, 2199, 81127, 0 };
            const std::uint32_t dim18237JoeKuoD6Init[]   =   { 1, 3, 7, 7, 31, 33, 87, 111, 429, 809, 173, 1093, 7719, 14307, 5735, 61019, 21223, 26361, 0 };
            const std::uint32_t dim18238JoeKuoD6Init[]   =   { 1, 1, 3, 11, 17, 33, 31, 17, 49, 885, 1279, 2243, 3693, 61, 30909, 35807, 14027, 159225, 0 };
            const std::uint32_t dim18239JoeKuoD6Init[]   =   { 1, 3, 7, 11, 9, 35, 61, 75, 171, 117, 1285, 935, 7271, 3509, 14119, 31065, 58181, 136623, 0 };
            const std::uint32_t dim18240JoeKuoD6Init[]   =   { 1, 1, 3, 15, 3, 43, 93, 221, 239, 783, 37, 4007, 3637, 10461, 18425, 59629, 93781, 252689, 0 };
            const std::uint32_t dim18241JoeKuoD6Init[]   =   { 1, 3, 5, 7, 5, 61, 19, 107, 123, 417, 1655, 2307, 8177, 13617, 17195, 31597, 66241, 107199, 0 };
            const std::uint32_t dim18242JoeKuoD6Init[]   =   { 1, 3, 7, 7, 5, 5, 25, 69, 383, 217, 993, 2719, 3425, 8395, 1125, 10763, 80111, 70421, 0 };
            const std::uint32_t dim18243JoeKuoD6Init[]   =   { 1, 1, 3, 9, 29, 45, 123, 45, 89, 1015, 1703, 4049, 4969, 3801, 23657, 41031, 66415, 34063, 0 };
            const std::uint32_t dim18244JoeKuoD6Init[]   =   { 1, 1, 3, 3, 7, 53, 125, 63, 67, 335, 1937, 1793, 4641, 7115, 10951, 45503, 54723, 177433, 0 };
            const std::uint32_t dim18245JoeKuoD6Init[]   =   { 1, 3, 5, 1, 21, 55, 83, 199, 509, 331, 695, 2133, 1881, 14369, 21687, 2343, 85895, 99255, 0 };
            const std::uint32_t dim18246JoeKuoD6Init[]   =   { 1, 1, 5, 9, 11, 5, 111, 97, 433, 851, 1537, 411, 6629, 5185, 30749, 50017, 46177, 213347, 0 };
            const std::uint32_t dim18247JoeKuoD6Init[]   =   { 1, 3, 3, 1, 7, 21, 95, 229, 311, 605, 1277, 2435, 5053, 3051, 15447, 35479, 2835, 204149, 0 };
            const std::uint32_t dim18248JoeKuoD6Init[]   =   { 1, 3, 5, 9, 31, 27, 79, 201, 329, 735, 1933, 27, 6201, 9375, 24801, 34045, 16227, 61013, 0 };
            const std::uint32_t dim18249JoeKuoD6Init[]   =   { 1, 1, 5, 5, 31, 7, 73, 197, 455, 835, 1845, 2733, 3371, 513, 10495, 43659, 4621, 68969, 0 };
            const std::uint32_t dim18250JoeKuoD6Init[]   =   { 1, 1, 1, 15, 21, 55, 15, 83, 419, 471, 1427, 919, 7125, 7635, 25579, 19493, 37381, 191563, 0 };
            const std::uint32_t dim18251JoeKuoD6Init[]   =   { 1, 1, 7, 3, 15, 35, 25, 73, 295, 507, 719, 3307, 4253, 945, 21005, 24903, 80287, 48885, 0 };
            const std::uint32_t dim18252JoeKuoD6Init[]   =   { 1, 3, 7, 15, 27, 13, 71, 79, 189, 491, 1185, 3007, 4285, 13005, 18973, 33759, 15327, 45595, 0 };
            const std::uint32_t dim18253JoeKuoD6Init[]   =   { 1, 3, 3, 9, 9, 33, 115, 103, 31, 949, 1817, 2865, 1215, 9611, 16019, 7925, 72945, 208301, 0 };
            const std::uint32_t dim18254JoeKuoD6Init[]   =   { 1, 1, 1, 5, 19, 35, 89, 181, 409, 641, 1277, 2201, 2825, 5707, 13463, 34741, 39303, 217803, 0 };
            const std::uint32_t dim18255JoeKuoD6Init[]   =   { 1, 1, 3, 11, 13, 31, 65, 191, 11, 179, 509, 2513, 3861, 13323, 11817, 24901, 53815, 44343, 0 };
            const std::uint32_t dim18256JoeKuoD6Init[]   =   { 1, 3, 1, 5, 5, 57, 97, 25, 83, 177, 1963, 2367, 6703, 13361, 8749, 45533, 87883, 2977, 0 };
            const std::uint32_t dim18257JoeKuoD6Init[]   =   { 1, 3, 5, 3, 15, 41, 113, 145, 39, 509, 81, 1387, 2881, 1441, 75, 28409, 61417, 79393, 0 };
            const std::uint32_t dim18258JoeKuoD6Init[]   =   { 1, 3, 3, 3, 17, 1, 41, 19, 173, 133, 2033, 3637, 7415, 1841, 19497, 42643, 122885, 195301, 0 };
            const std::uint32_t dim18259JoeKuoD6Init[]   =   { 1, 3, 3, 9, 15, 37, 11, 87, 291, 881, 1471, 2469, 6877, 6813, 8273, 1455, 30957, 181887, 0 };
            const std::uint32_t dim18260JoeKuoD6Init[]   =   { 1, 3, 5, 9, 25, 41, 7, 71, 451, 831, 495, 3991, 4173, 4307, 31249, 7253, 57141, 35495, 0 };
            const std::uint32_t dim18261JoeKuoD6Init[]   =   { 1, 1, 7, 9, 15, 39, 29, 193, 327, 837, 991, 3503, 1175, 14965, 18151, 22479, 51127, 159019, 0 };
            const std::uint32_t dim18262JoeKuoD6Init[]   =   { 1, 3, 1, 9, 23, 41, 89, 211, 179, 507, 1005, 613, 8083, 15655, 1927, 23401, 51025, 21589, 0 };
            const std::uint32_t dim18263JoeKuoD6Init[]   =   { 1, 1, 5, 15, 5, 63, 105, 229, 239, 399, 591, 2233, 391, 2871, 29829, 49961, 62045, 190437, 0 };
            const std::uint32_t dim18264JoeKuoD6Init[]   =   { 1, 3, 5, 9, 7, 23, 85, 219, 163, 37, 1881, 589, 4239, 12845, 19993, 57267, 29519, 207597, 0 };
            const std::uint32_t dim18265JoeKuoD6Init[]   =   { 1, 3, 7, 15, 19, 19, 115, 141, 41, 405, 657, 2517, 4231, 10247, 21383, 11479, 52955, 121545, 0 };
            const std::uint32_t dim18266JoeKuoD6Init[]   =   { 1, 3, 1, 7, 23, 33, 65, 229, 287, 739, 1265, 1105, 487, 3801, 5211, 44731, 5359, 103685, 0 };
            const std::uint32_t dim18267JoeKuoD6Init[]   =   { 1, 3, 1, 13, 23, 29, 101, 153, 395, 335, 899, 303, 2073, 15767, 1303, 15539, 12889, 35517, 0 };
            const std::uint32_t dim18268JoeKuoD6Init[]   =   { 1, 1, 5, 11, 5, 63, 41, 53, 99, 339, 563, 2921, 4959, 13941, 13655, 10115, 56867, 42919, 0 };
            const std::uint32_t dim18269JoeKuoD6Init[]   =   { 1, 3, 5, 5, 5, 35, 127, 225, 497, 27, 139, 3269, 3929, 3369, 22697, 19421, 2921, 171927, 0 };
            const std::uint32_t dim18270JoeKuoD6Init[]   =   { 1, 1, 1, 15, 15, 21, 35, 251, 67, 447, 1045, 1173, 2951, 6589, 27261, 36597, 98721, 7205, 0 };
            const std::uint32_t dim18271JoeKuoD6Init[]   =   { 1, 3, 3, 9, 11, 63, 83, 19, 163, 381, 87, 1211, 3007, 4971, 27105, 2341, 21389, 32995, 0 };
            const std::uint32_t dim18272JoeKuoD6Init[]   =   { 1, 1, 3, 3, 21, 19, 63, 65, 505, 987, 1821, 2419, 3195, 2573, 1481, 35279, 45135, 597, 0 };
            const std::uint32_t dim18273JoeKuoD6Init[]   =   { 1, 3, 1, 15, 29, 5, 77, 65, 121, 223, 2009, 593, 7929, 10353, 22301, 25137, 40289, 95847, 0 };
            const std::uint32_t dim18274JoeKuoD6Init[]   =   { 1, 1, 3, 1, 17, 49, 9, 167, 69, 729, 1189, 1191, 1, 12603, 8281, 45193, 1427, 15887, 0 };
            const std::uint32_t dim18275JoeKuoD6Init[]   =   { 1, 1, 3, 7, 17, 5, 11, 217, 505, 317, 505, 1201, 8025, 13255, 12591, 16207, 32387, 242425, 0 };
            const std::uint32_t dim18276JoeKuoD6Init[]   =   { 1, 3, 7, 9, 25, 9, 97, 23, 91, 765, 653, 2689, 2787, 11719, 8455, 24665, 26907, 78525, 0 };
            const std::uint32_t dim18277JoeKuoD6Init[]   =   { 1, 3, 3, 15, 27, 19, 79, 157, 117, 715, 1921, 2453, 499, 13593, 14173, 1993, 110087, 151427, 0 };
            const std::uint32_t dim18278JoeKuoD6Init[]   =   { 1, 3, 1, 13, 5, 43, 59, 21, 451, 863, 533, 1723, 2059, 1611, 10403, 36479, 36999, 109553, 0 };
            const std::uint32_t dim18279JoeKuoD6Init[]   =   { 1, 3, 7, 7, 29, 63, 51, 5, 475, 549, 123, 1949, 5279, 8581, 20053, 52287, 125223, 152299, 0 };
            const std::uint32_t dim18280JoeKuoD6Init[]   =   { 1, 3, 1, 1, 7, 19, 1, 215, 273, 157, 1557, 425, 7549, 12337, 1735, 30917, 116487, 177335, 0 };
            const std::uint32_t dim18281JoeKuoD6Init[]   =   { 1, 1, 1, 1, 7, 47, 61, 191, 73, 551, 1435, 2283, 3191, 8545, 11875, 41389, 17607, 26869, 0 };
            const std::uint32_t dim18282JoeKuoD6Init[]   =   { 1, 1, 7, 9, 13, 61, 109, 121, 365, 223, 1729, 3311, 7249, 10765, 12419, 4235, 64127, 132257, 0 };
            const std::uint32_t dim18283JoeKuoD6Init[]   =   { 1, 1, 3, 13, 17, 25, 65, 49, 417, 311, 141, 1127, 53, 945, 28277, 33347, 96399, 166049, 0 };
            const std::uint32_t dim18284JoeKuoD6Init[]   =   { 1, 3, 7, 9, 5, 21, 93, 203, 467, 805, 115, 1757, 4535, 8687, 10423, 8065, 2955, 20403, 0 };
            const std::uint32_t dim18285JoeKuoD6Init[]   =   { 1, 3, 3, 15, 7, 63, 103, 137, 227, 111, 735, 2139, 4293, 5347, 4131, 63405, 42599, 173299, 0 };
            const std::uint32_t dim18286JoeKuoD6Init[]   =   { 1, 3, 7, 7, 17, 53, 127, 251, 57, 625, 843, 3045, 1319, 10085, 18591, 36115, 104193, 183891, 0 };
            const std::uint32_t dim18287JoeKuoD6Init[]   =   { 1, 3, 7, 1, 31, 57, 107, 253, 207, 739, 1703, 1377, 3807, 10289, 22969, 13087, 2805, 261279, 0 };
            const std::uint32_t dim18288JoeKuoD6Init[]   =   { 1, 1, 5, 5, 5, 59, 59, 63, 77, 663, 1109, 2159, 3725, 12355, 4805, 22433, 81851, 9419, 0 };
            const std::uint32_t dim18289JoeKuoD6Init[]   =   { 1, 1, 7, 15, 1, 1, 101, 101, 295, 311, 447, 3931, 933, 15713, 8919, 7185, 38577, 254203, 0 };
            const std::uint32_t dim18290JoeKuoD6Init[]   =   { 1, 1, 5, 15, 7, 35, 35, 141, 283, 665, 1685, 3875, 495, 1655, 8269, 23493, 1523, 248783, 0 };
            const std::uint32_t dim18291JoeKuoD6Init[]   =   { 1, 1, 5, 9, 27, 35, 25, 57, 285, 469, 1491, 1479, 3705, 11357, 5319, 11575, 116207, 215961, 0 };
            const std::uint32_t dim18292JoeKuoD6Init[]   =   { 1, 3, 5, 11, 7, 41, 67, 161, 73, 777, 247, 823, 6677, 1631, 3431, 2821, 25291, 17633, 0 };
            const std::uint32_t dim18293JoeKuoD6Init[]   =   { 1, 1, 3, 9, 19, 17, 45, 181, 139, 85, 857, 1231, 7167, 2951, 26847, 39113, 51705, 104617, 0 };
            const std::uint32_t dim18294JoeKuoD6Init[]   =   { 1, 3, 5, 1, 5, 55, 101, 209, 1, 47, 1059, 2175, 1549, 8007, 11267, 21863, 125567, 102775, 0 };
            const std::uint32_t dim18295JoeKuoD6Init[]   =   { 1, 3, 3, 15, 15, 21, 79, 85, 427, 963, 1335, 2129, 6831, 6613, 13319, 15781, 3781, 222547, 0 };
            const std::uint32_t dim18296JoeKuoD6Init[]   =   { 1, 3, 3, 13, 19, 63, 25, 123, 1, 215, 139, 1345, 5035, 3107, 14381, 6239, 18481, 202581, 0 };
            const std::uint32_t dim18297JoeKuoD6Init[]   =   { 1, 1, 5, 1, 11, 11, 11, 53, 109, 533, 1113, 177, 609, 15391, 22735, 62229, 103591, 89143, 0 };
            const std::uint32_t dim18298JoeKuoD6Init[]   =   { 1, 1, 5, 15, 3, 21, 115, 223, 167, 441, 277, 2971, 933, 2841, 26893, 48513, 74553, 250413, 0 };
            const std::uint32_t dim18299JoeKuoD6Init[]   =   { 1, 1, 1, 7, 19, 17, 43, 181, 483, 897, 819, 1657, 5539, 8847, 23483, 57605, 104703, 242559, 0 };
            const std::uint32_t dim18300JoeKuoD6Init[]   =   { 1, 3, 5, 11, 3, 63, 3, 129, 45, 981, 45, 845, 1481, 14735, 30451, 16937, 13789, 27107, 0 };
            const std::uint32_t dim18301JoeKuoD6Init[]   =   { 1, 3, 3, 15, 25, 11, 33, 49, 155, 947, 521, 3417, 3299, 1123, 9517, 32127, 117795, 223167, 0 };
            const std::uint32_t dim18302JoeKuoD6Init[]   =   { 1, 3, 5, 15, 3, 35, 27, 37, 287, 541, 727, 2779, 7033, 5189, 21579, 36895, 109645, 123353, 0 };
            const std::uint32_t dim18303JoeKuoD6Init[]   =   { 1, 3, 7, 9, 15, 53, 123, 125, 405, 841, 119, 63, 853, 8693, 1537, 25509, 49345, 54301, 0 };
            const std::uint32_t dim18304JoeKuoD6Init[]   =   { 1, 3, 7, 9, 11, 63, 65, 145, 283, 529, 1553, 883, 3319, 8601, 29379, 26991, 127343, 98701, 0 };
            const std::uint32_t dim18305JoeKuoD6Init[]   =   { 1, 1, 1, 7, 23, 59, 11, 89, 407, 869, 445, 659, 3029, 5465, 5063, 36775, 69089, 205367, 0 };
            const std::uint32_t dim18306JoeKuoD6Init[]   =   { 1, 3, 7, 5, 19, 35, 99, 49, 257, 287, 1113, 2825, 2797, 7283, 31757, 47015, 106987, 82589, 0 };
            const std::uint32_t dim18307JoeKuoD6Init[]   =   { 1, 3, 7, 11, 15, 37, 41, 101, 493, 725, 1091, 503, 2611, 13025, 11071, 39311, 5193, 92127, 0 };
            const std::uint32_t dim18308JoeKuoD6Init[]   =   { 1, 1, 3, 7, 9, 59, 69, 113, 381, 341, 1495, 3169, 5099, 69, 7911, 9721, 84609, 254171, 0 };
            const std::uint32_t dim18309JoeKuoD6Init[]   =   { 1, 3, 5, 7, 21, 19, 75, 71, 7, 617, 1185, 2787, 4147, 16045, 18859, 52347, 66551, 161563, 0 };
            const std::uint32_t dim18310JoeKuoD6Init[]   =   { 1, 3, 5, 3, 27, 39, 17, 205, 425, 3, 1443, 1947, 7645, 10125, 24577, 45373, 38015, 30407, 0 };
            const std::uint32_t dim18311JoeKuoD6Init[]   =   { 1, 3, 3, 11, 1, 57, 105, 251, 65, 389, 1993, 3933, 3093, 1425, 9483, 5953, 13147, 234121, 0 };
            const std::uint32_t dim18312JoeKuoD6Init[]   =   { 1, 3, 3, 3, 1, 27, 105, 45, 435, 393, 609, 291, 545, 4905, 22621, 62115, 78955, 84355, 0 };
            const std::uint32_t dim18313JoeKuoD6Init[]   =   { 1, 3, 7, 9, 1, 15, 91, 183, 301, 223, 1183, 1877, 2141, 5549, 371, 44147, 6771, 136777, 0 };
            const std::uint32_t dim18314JoeKuoD6Init[]   =   { 1, 1, 5, 15, 5, 49, 127, 161, 121, 979, 1247, 3681, 3805, 3363, 11643, 25735, 21193, 111657, 0 };
            const std::uint32_t dim18315JoeKuoD6Init[]   =   { 1, 3, 5, 15, 15, 33, 47, 91, 137, 323, 1577, 3723, 3609, 11533, 4415, 26467, 120947, 200919, 0 };
            const std::uint32_t dim18316JoeKuoD6Init[]   =   { 1, 3, 3, 3, 3, 33, 121, 161, 453, 205, 1815, 65, 5893, 4669, 14377, 10905, 9559, 56359, 0 };
            const std::uint32_t dim18317JoeKuoD6Init[]   =   { 1, 1, 1, 7, 1, 55, 21, 143, 411, 65, 1009, 2989, 133, 7059, 30981, 15417, 2651, 110345, 0 };
            const std::uint32_t dim18318JoeKuoD6Init[]   =   { 1, 1, 3, 7, 19, 25, 91, 241, 193, 903, 661, 665, 7681, 14111, 29197, 51299, 109519, 155827, 0 };
            const std::uint32_t dim18319JoeKuoD6Init[]   =   { 1, 1, 1, 15, 25, 3, 79, 57, 417, 73, 705, 7, 4415, 7699, 28185, 53005, 88547, 7281, 0 };
            const std::uint32_t dim18320JoeKuoD6Init[]   =   { 1, 1, 7, 13, 27, 21, 35, 197, 65, 171, 1773, 393, 3759, 8335, 5987, 20611, 91373, 80715, 0 };
            const std::uint32_t dim18321JoeKuoD6Init[]   =   { 1, 3, 7, 3, 17, 51, 85, 229, 131, 733, 281, 3157, 1283, 10751, 20203, 49955, 23861, 128517, 0 };
            const std::uint32_t dim18322JoeKuoD6Init[]   =   { 1, 1, 5, 15, 3, 27, 35, 87, 391, 509, 1627, 769, 701, 4933, 24597, 9695, 111441, 198493, 0 };
            const std::uint32_t dim18323JoeKuoD6Init[]   =   { 1, 1, 1, 15, 3, 31, 73, 235, 341, 263, 883, 2369, 4887, 4659, 9493, 6763, 130625, 15031, 0 };
            const std::uint32_t dim18324JoeKuoD6Init[]   =   { 1, 3, 1, 15, 1, 11, 63, 79, 389, 355, 619, 1361, 313, 1199, 555, 42213, 81089, 170863, 0 };
            const std::uint32_t dim18325JoeKuoD6Init[]   =   { 1, 3, 1, 15, 21, 27, 1, 179, 19, 241, 1655, 1803, 5413, 5353, 65, 31211, 3501, 27205, 0 };
            const std::uint32_t dim18326JoeKuoD6Init[]   =   { 1, 3, 3, 9, 9, 19, 63, 191, 217, 271, 1453, 2777, 2915, 13291, 31391, 37489, 86435, 22857, 0 };
            const std::uint32_t dim18327JoeKuoD6Init[]   =   { 1, 3, 5, 9, 13, 41, 85, 11, 333, 479, 363, 2591, 697, 8587, 3647, 5741, 21627, 244573, 0 };
            const std::uint32_t dim18328JoeKuoD6Init[]   =   { 1, 1, 3, 1, 5, 61, 83, 229, 193, 977, 677, 2585, 3273, 12035, 2621, 12943, 49293, 37985, 0 };
            const std::uint32_t dim18329JoeKuoD6Init[]   =   { 1, 1, 5, 7, 27, 9, 69, 189, 489, 747, 519, 719, 1493, 13337, 14933, 44359, 11471, 57245, 0 };
            const std::uint32_t dim18330JoeKuoD6Init[]   =   { 1, 3, 5, 1, 5, 17, 75, 89, 417, 367, 57, 1641, 1573, 1819, 31237, 5213, 78821, 149853, 0 };
            const std::uint32_t dim18331JoeKuoD6Init[]   =   { 1, 1, 7, 3, 7, 17, 121, 91, 211, 101, 1145, 3753, 2997, 67, 10755, 11261, 122489, 61679, 0 };
            const std::uint32_t dim18332JoeKuoD6Init[]   =   { 1, 3, 7, 7, 15, 17, 73, 133, 429, 285, 201, 1917, 5677, 1793, 21653, 49729, 68965, 5347, 0 };
            const std::uint32_t dim18333JoeKuoD6Init[]   =   { 1, 3, 3, 13, 23, 17, 49, 249, 71, 169, 619, 843, 2163, 585, 23309, 39509, 68087, 232233, 0 };
            const std::uint32_t dim18334JoeKuoD6Init[]   =   { 1, 1, 7, 15, 23, 15, 19, 227, 89, 719, 1247, 2521, 1509, 7553, 12225, 12865, 100107, 261847, 0 };
            const std::uint32_t dim18335JoeKuoD6Init[]   =   { 1, 1, 5, 3, 23, 17, 117, 5, 401, 57, 1945, 1081, 1269, 5921, 31815, 42341, 112099, 130047, 0 };
            const std::uint32_t dim18336JoeKuoD6Init[]   =   { 1, 1, 1, 1, 9, 5, 87, 203, 211, 1009, 403, 1617, 3969, 2541, 7261, 6989, 16579, 206159, 0 };
            const std::uint32_t dim18337JoeKuoD6Init[]   =   { 1, 3, 7, 9, 5, 13, 93, 191, 79, 631, 1019, 3639, 7137, 13859, 19603, 63263, 82947, 181023, 0 };
            const std::uint32_t dim18338JoeKuoD6Init[]   =   { 1, 1, 5, 11, 25, 17, 85, 51, 61, 311, 517, 2001, 6325, 6831, 10835, 20101, 115241, 15815, 0 };
            const std::uint32_t dim18339JoeKuoD6Init[]   =   { 1, 3, 7, 13, 29, 19, 33, 115, 473, 477, 471, 773, 4097, 11697, 30781, 20843, 27089, 181927, 0 };
            const std::uint32_t dim18340JoeKuoD6Init[]   =   { 1, 3, 5, 5, 21, 27, 3, 239, 45, 335, 505, 149, 3005, 3511, 18037, 31291, 6145, 2913, 0 };
            const std::uint32_t dim18341JoeKuoD6Init[]   =   { 1, 1, 3, 1, 25, 49, 21, 225, 27, 395, 415, 1813, 5727, 7211, 9887, 63533, 99185, 119269, 0 };
            const std::uint32_t dim18342JoeKuoD6Init[]   =   { 1, 3, 3, 5, 15, 53, 127, 195, 81, 895, 587, 561, 5951, 9901, 18117, 37855, 19393, 259031, 0 };
            const std::uint32_t dim18343JoeKuoD6Init[]   =   { 1, 1, 7, 13, 9, 49, 109, 127, 53, 735, 391, 1523, 3759, 10363, 11299, 3203, 89121, 122643, 0 };
            const std::uint32_t dim18344JoeKuoD6Init[]   =   { 1, 1, 5, 3, 13, 3, 21, 247, 259, 557, 977, 1465, 6889, 3879, 4627, 1439, 122809, 248941, 0 };
            const std::uint32_t dim18345JoeKuoD6Init[]   =   { 1, 3, 7, 15, 7, 19, 113, 251, 245, 63, 267, 1873, 6601, 16253, 24643, 7433, 130051, 233047, 0 };
            const std::uint32_t dim18346JoeKuoD6Init[]   =   { 1, 1, 3, 9, 29, 39, 47, 31, 493, 817, 1697, 2139, 1059, 11365, 31653, 56477, 119191, 45509, 0 };
            const std::uint32_t dim18347JoeKuoD6Init[]   =   { 1, 1, 1, 15, 9, 29, 99, 61, 109, 341, 1009, 1551, 897, 13075, 10603, 25153, 65911, 228213, 0 };
            const std::uint32_t dim18348JoeKuoD6Init[]   =   { 1, 3, 7, 7, 29, 47, 57, 85, 263, 767, 1633, 2473, 199, 49, 22287, 33345, 118877, 248435, 0 };
            const std::uint32_t dim18349JoeKuoD6Init[]   =   { 1, 3, 1, 9, 5, 45, 5, 179, 9, 129, 1231, 4075, 7497, 2159, 18101, 31039, 95213, 171913, 0 };
            const std::uint32_t dim18350JoeKuoD6Init[]   =   { 1, 1, 1, 13, 23, 1, 89, 63, 21, 983, 481, 773, 5957, 4823, 4483, 50405, 42979, 243567, 0 };
            const std::uint32_t dim18351JoeKuoD6Init[]   =   { 1, 1, 5, 13, 15, 21, 65, 133, 347, 511, 1887, 743, 7825, 1681, 4857, 49247, 21277, 212995, 0 };
            const std::uint32_t dim18352JoeKuoD6Init[]   =   { 1, 3, 7, 9, 7, 51, 3, 233, 287, 727, 815, 3609, 397, 5721, 16473, 7549, 100455, 136233, 0 };
            const std::uint32_t dim18353JoeKuoD6Init[]   =   { 1, 3, 1, 1, 31, 51, 59, 37, 79, 623, 1219, 2655, 4619, 11967, 11377, 28985, 16069, 188773, 0 };
            const std::uint32_t dim18354JoeKuoD6Init[]   =   { 1, 3, 3, 13, 13, 59, 93, 159, 197, 339, 1633, 1601, 255, 1631, 4989, 12019, 23921, 261273, 0 };
            const std::uint32_t dim18355JoeKuoD6Init[]   =   { 1, 1, 3, 13, 27, 25, 55, 43, 147, 981, 65, 725, 5753, 115, 26125, 25501, 89099, 233419, 0 };
            const std::uint32_t dim18356JoeKuoD6Init[]   =   { 1, 3, 7, 5, 25, 3, 95, 135, 191, 417, 929, 3855, 5829, 3827, 13979, 65367, 63683, 85911, 0 };
            const std::uint32_t dim18357JoeKuoD6Init[]   =   { 1, 3, 5, 1, 7, 63, 45, 187, 355, 735, 1325, 1461, 3869, 2127, 18231, 45891, 24027, 202997, 0 };
            const std::uint32_t dim18358JoeKuoD6Init[]   =   { 1, 3, 7, 13, 19, 47, 89, 229, 253, 659, 355, 3323, 4081, 8243, 32553, 46579, 46431, 53291, 0 };
            const std::uint32_t dim18359JoeKuoD6Init[]   =   { 1, 1, 5, 11, 3, 61, 33, 65, 239, 779, 665, 1337, 6427, 12787, 1495, 27105, 71455, 89715, 0 };
            const std::uint32_t dim18360JoeKuoD6Init[]   =   { 1, 3, 1, 11, 31, 33, 115, 69, 511, 187, 99, 1055, 1065, 9531, 29897, 23897, 80581, 166957, 0 };
            const std::uint32_t dim18361JoeKuoD6Init[]   =   { 1, 1, 7, 13, 19, 1, 13, 241, 89, 761, 425, 3865, 961, 14999, 24175, 19103, 39095, 38899, 0 };
            const std::uint32_t dim18362JoeKuoD6Init[]   =   { 1, 3, 7, 7, 11, 17, 25, 217, 113, 615, 1455, 1409, 5679, 2321, 28687, 8089, 74031, 230559, 0 };
            const std::uint32_t dim18363JoeKuoD6Init[]   =   { 1, 3, 7, 1, 25, 15, 77, 111, 405, 523, 961, 647, 3857, 14355, 27063, 48829, 87913, 254965, 0 };
            const std::uint32_t dim18364JoeKuoD6Init[]   =   { 1, 1, 3, 3, 5, 13, 67, 155, 393, 943, 1875, 1209, 3765, 8627, 15123, 43405, 78473, 146127, 0 };
            const std::uint32_t dim18365JoeKuoD6Init[]   =   { 1, 1, 3, 7, 29, 43, 23, 33, 35, 883, 1859, 1559, 4163, 13277, 16971, 15289, 60305, 56743, 0 };
            const std::uint32_t dim18366JoeKuoD6Init[]   =   { 1, 1, 1, 5, 19, 55, 37, 53, 123, 35, 1477, 1035, 4683, 259, 20079, 37041, 48081, 198685, 0 };
            const std::uint32_t dim18367JoeKuoD6Init[]   =   { 1, 1, 3, 3, 1, 19, 27, 129, 427, 685, 959, 2501, 2761, 9495, 23649, 18789, 54521, 219547, 0 };
            const std::uint32_t dim18368JoeKuoD6Init[]   =   { 1, 1, 7, 1, 31, 11, 65, 171, 229, 11, 1825, 1641, 2731, 11085, 2567, 30831, 20365, 242731, 0 };
            const std::uint32_t dim18369JoeKuoD6Init[]   =   { 1, 1, 1, 13, 13, 5, 21, 175, 265, 271, 133, 407, 3415, 5943, 15385, 12817, 106159, 41859, 0 };
            const std::uint32_t dim18370JoeKuoD6Init[]   =   { 1, 3, 7, 1, 11, 45, 105, 229, 395, 877, 1495, 2113, 1733, 10117, 1125, 9989, 109637, 124517, 0 };
            const std::uint32_t dim18371JoeKuoD6Init[]   =   { 1, 1, 7, 3, 27, 43, 57, 77, 63, 907, 1137, 3333, 189, 15285, 13895, 23773, 73523, 47811, 0 };
            const std::uint32_t dim18372JoeKuoD6Init[]   =   { 1, 3, 3, 11, 17, 19, 81, 197, 73, 897, 515, 3801, 5105, 6987, 10125, 7239, 32339, 124411, 0 };
            const std::uint32_t dim18373JoeKuoD6Init[]   =   { 1, 3, 1, 9, 11, 15, 99, 109, 307, 133, 249, 1463, 5479, 8565, 19489, 13773, 11443, 149799, 0 };
            const std::uint32_t dim18374JoeKuoD6Init[]   =   { 1, 3, 7, 7, 19, 53, 61, 75, 83, 545, 1449, 683, 5845, 8325, 18111, 35941, 51843, 97907, 0 };
            const std::uint32_t dim18375JoeKuoD6Init[]   =   { 1, 1, 1, 3, 31, 23, 37, 187, 207, 51, 439, 3095, 2217, 6393, 9117, 2779, 47331, 118275, 0 };
            const std::uint32_t dim18376JoeKuoD6Init[]   =   { 1, 1, 3, 9, 23, 17, 41, 37, 59, 281, 319, 1333, 6207, 2265, 4445, 50831, 115893, 120491, 0 };
            const std::uint32_t dim18377JoeKuoD6Init[]   =   { 1, 3, 1, 13, 27, 23, 25, 23, 187, 51, 1257, 379, 921, 3801, 24537, 59547, 34191, 184625, 0 };
            const std::uint32_t dim18378JoeKuoD6Init[]   =   { 1, 1, 5, 3, 23, 21, 23, 159, 163, 537, 1589, 2797, 8007, 6767, 31331, 20741, 119969, 174135, 0 };
            const std::uint32_t dim18379JoeKuoD6Init[]   =   { 1, 3, 1, 1, 13, 35, 73, 147, 491, 317, 69, 1069, 5413, 13973, 19741, 44717, 63263, 77145, 0 };
            const std::uint32_t dim18380JoeKuoD6Init[]   =   { 1, 3, 1, 15, 31, 41, 23, 79, 55, 863, 129, 2229, 3395, 1621, 6273, 44521, 100047, 42337, 0 };
            const std::uint32_t dim18381JoeKuoD6Init[]   =   { 1, 3, 7, 3, 7, 5, 79, 1, 191, 227, 1039, 2909, 1085, 3173, 29311, 13861, 124785, 212453, 0 };
            const std::uint32_t dim18382JoeKuoD6Init[]   =   { 1, 3, 1, 5, 13, 9, 99, 213, 61, 201, 889, 1171, 3981, 2091, 31679, 26643, 5611, 154339, 0 };
            const std::uint32_t dim18383JoeKuoD6Init[]   =   { 1, 3, 3, 7, 27, 49, 53, 77, 285, 441, 1669, 2157, 223, 1899, 2725, 36547, 39273, 206653, 0 };
            const std::uint32_t dim18384JoeKuoD6Init[]   =   { 1, 3, 3, 9, 29, 5, 91, 1, 13, 409, 1275, 891, 6557, 5157, 6481, 57381, 87683, 117277, 0 };
            const std::uint32_t dim18385JoeKuoD6Init[]   =   { 1, 3, 3, 1, 11, 7, 13, 69, 9, 1015, 907, 2685, 6665, 16307, 24567, 13191, 9567, 55073, 0 };
            const std::uint32_t dim18386JoeKuoD6Init[]   =   { 1, 3, 1, 5, 19, 15, 65, 13, 503, 427, 1947, 1869, 5857, 823, 20533, 25337, 83551, 128505, 0 };
            const std::uint32_t dim18387JoeKuoD6Init[]   =   { 1, 1, 5, 11, 25, 53, 83, 175, 445, 5, 841, 2773, 4381, 2829, 1927, 63689, 63643, 246629, 0 };
            const std::uint32_t dim18388JoeKuoD6Init[]   =   { 1, 3, 1, 11, 27, 63, 43, 95, 453, 235, 673, 117, 6617, 7589, 5767, 16465, 36961, 39395, 0 };
            const std::uint32_t dim18389JoeKuoD6Init[]   =   { 1, 1, 3, 13, 3, 27, 119, 87, 209, 167, 721, 1499, 1955, 9151, 11649, 29009, 25249, 26125, 0 };
            const std::uint32_t dim18390JoeKuoD6Init[]   =   { 1, 1, 5, 1, 9, 59, 47, 57, 81, 243, 485, 559, 7311, 15119, 9827, 47219, 5941, 16909, 0 };
            const std::uint32_t dim18391JoeKuoD6Init[]   =   { 1, 3, 7, 11, 29, 13, 97, 63, 289, 653, 1811, 835, 801, 13103, 9333, 7785, 111587, 10021, 0 };
            const std::uint32_t dim18392JoeKuoD6Init[]   =   { 1, 3, 3, 1, 27, 61, 73, 165, 279, 239, 865, 517, 7763, 1917, 9839, 20725, 50721, 171351, 0 };
            const std::uint32_t dim18393JoeKuoD6Init[]   =   { 1, 3, 7, 1, 27, 29, 43, 137, 353, 927, 889, 2511, 709, 3309, 967, 18119, 48099, 98139, 0 };
            const std::uint32_t dim18394JoeKuoD6Init[]   =   { 1, 3, 1, 1, 17, 5, 79, 23, 367, 231, 605, 3809, 7557, 14283, 18417, 15775, 107421, 9587, 0 };
            const std::uint32_t dim18395JoeKuoD6Init[]   =   { 1, 1, 1, 7, 25, 9, 93, 41, 165, 509, 661, 2165, 3595, 2555, 11399, 2403, 76179, 176003, 0 };
            const std::uint32_t dim18396JoeKuoD6Init[]   =   { 1, 3, 3, 7, 27, 19, 55, 213, 83, 601, 377, 2381, 6831, 5609, 31321, 26897, 105321, 144705, 0 };
            const std::uint32_t dim18397JoeKuoD6Init[]   =   { 1, 3, 7, 7, 21, 11, 45, 55, 379, 133, 653, 3593, 7481, 15789, 12723, 9697, 20073, 58211, 0 };
            const std::uint32_t dim18398JoeKuoD6Init[]   =   { 1, 3, 5, 1, 1, 57, 89, 159, 461, 719, 1251, 3899, 1063, 10753, 6509, 28391, 129377, 195279, 0 };
            const std::uint32_t dim18399JoeKuoD6Init[]   =   { 1, 3, 7, 7, 5, 39, 59, 81, 27, 169, 1541, 2213, 3631, 11601, 13153, 43221, 14587, 29719, 0 };
            const std::uint32_t dim18400JoeKuoD6Init[]   =   { 1, 1, 1, 1, 3, 29, 103, 125, 35, 455, 255, 3855, 567, 12013, 13285, 44753, 117415, 226285, 0 };
            const std::uint32_t dim18401JoeKuoD6Init[]   =   { 1, 1, 5, 1, 21, 41, 59, 69, 83, 813, 1041, 2559, 1947, 7343, 5291, 39281, 56141, 54487, 0 };
            const std::uint32_t dim18402JoeKuoD6Init[]   =   { 1, 1, 7, 15, 25, 17, 83, 115, 321, 659, 1625, 3253, 281, 6673, 26301, 45647, 92151, 150707, 0 };
            const std::uint32_t dim18403JoeKuoD6Init[]   =   { 1, 1, 5, 15, 9, 19, 83, 167, 325, 869, 501, 483, 2155, 14697, 12755, 54687, 100637, 6791, 0 };
            const std::uint32_t dim18404JoeKuoD6Init[]   =   { 1, 1, 7, 3, 3, 47, 91, 79, 347, 215, 847, 2957, 5881, 5371, 20099, 45603, 29349, 175357, 0 };
            const std::uint32_t dim18405JoeKuoD6Init[]   =   { 1, 3, 1, 3, 13, 43, 101, 235, 505, 289, 691, 673, 5579, 8721, 9639, 18569, 44797, 250887, 0 };
            const std::uint32_t dim18406JoeKuoD6Init[]   =   { 1, 1, 3, 11, 23, 27, 85, 223, 365, 767, 577, 2781, 4179, 12963, 25235, 51021, 84989, 149521, 0 };
            const std::uint32_t dim18407JoeKuoD6Init[]   =   { 1, 1, 1, 1, 9, 51, 13, 129, 393, 725, 1301, 1391, 4693, 4979, 16801, 21361, 122157, 56675, 0 };
            const std::uint32_t dim18408JoeKuoD6Init[]   =   { 1, 3, 5, 11, 7, 21, 97, 97, 17, 915, 255, 155, 3961, 7999, 7493, 52683, 49377, 131663, 0 };
            const std::uint32_t dim18409JoeKuoD6Init[]   =   { 1, 3, 5, 15, 31, 23, 41, 187, 89, 933, 309, 2519, 6595, 13785, 14339, 44393, 64439, 142105, 0 };
            const std::uint32_t dim18410JoeKuoD6Init[]   =   { 1, 1, 1, 11, 13, 57, 29, 249, 467, 863, 77, 3185, 6221, 13109, 32397, 13859, 27331, 35295, 0 };
            const std::uint32_t dim18411JoeKuoD6Init[]   =   { 1, 3, 3, 3, 23, 31, 29, 189, 405, 855, 1597, 3167, 4171, 13801, 12297, 38019, 130141, 135517, 0 };
            const std::uint32_t dim18412JoeKuoD6Init[]   =   { 1, 1, 5, 7, 13, 37, 87, 41, 503, 281, 103, 1997, 3603, 4185, 25331, 55123, 74263, 248695, 0 };
            const std::uint32_t dim18413JoeKuoD6Init[]   =   { 1, 3, 1, 15, 13, 57, 67, 135, 429, 489, 829, 2069, 7657, 15713, 3907, 5819, 114005, 187859, 0 };
            const std::uint32_t dim18414JoeKuoD6Init[]   =   { 1, 1, 3, 1, 23, 43, 93, 63, 5, 435, 1649, 1429, 2923, 9035, 28667, 13991, 74491, 236225, 0 };
            const std::uint32_t dim18415JoeKuoD6Init[]   =   { 1, 3, 3, 7, 19, 29, 37, 143, 443, 955, 1431, 3193, 6023, 2421, 28955, 29171, 126785, 124709, 0 };
            const std::uint32_t dim18416JoeKuoD6Init[]   =   { 1, 3, 7, 7, 23, 45, 59, 101, 25, 711, 1685, 851, 3101, 12273, 10775, 57633, 52739, 244681, 0 };
            const std::uint32_t dim18417JoeKuoD6Init[]   =   { 1, 1, 1, 5, 3, 13, 97, 143, 367, 139, 1535, 873, 8005, 2795, 11103, 3837, 125833, 194903, 0 };
            const std::uint32_t dim18418JoeKuoD6Init[]   =   { 1, 3, 5, 7, 23, 61, 61, 203, 443, 543, 573, 2835, 941, 12315, 18453, 34367, 94359, 132437, 0 };
            const std::uint32_t dim18419JoeKuoD6Init[]   =   { 1, 1, 7, 5, 11, 21, 87, 27, 495, 67, 1267, 2029, 5041, 4133, 18821, 50249, 52397, 101431, 0 };
            const std::uint32_t dim18420JoeKuoD6Init[]   =   { 1, 3, 3, 3, 13, 51, 89, 183, 61, 919, 1841, 373, 7091, 9413, 1227, 44515, 72869, 198769, 0 };
            const std::uint32_t dim18421JoeKuoD6Init[]   =   { 1, 3, 3, 11, 13, 63, 13, 253, 203, 571, 91, 3477, 123, 15353, 7803, 62729, 14337, 252725, 0 };
            const std::uint32_t dim18422JoeKuoD6Init[]   =   { 1, 1, 7, 1, 11, 57, 45, 251, 351, 895, 1813, 3857, 7545, 9739, 32029, 24915, 46261, 8149, 0 };
            const std::uint32_t dim18423JoeKuoD6Init[]   =   { 1, 3, 1, 15, 25, 41, 71, 47, 265, 567, 307, 4079, 1943, 10407, 2999, 6605, 97621, 194711, 0 };
            const std::uint32_t dim18424JoeKuoD6Init[]   =   { 1, 1, 3, 5, 17, 29, 97, 249, 449, 761, 1727, 1533, 7417, 16167, 421, 39075, 1029, 180923, 0 };
            const std::uint32_t dim18425JoeKuoD6Init[]   =   { 1, 1, 1, 3, 11, 27, 67, 227, 131, 453, 951, 3897, 515, 4513, 17361, 50049, 4533, 35953, 0 };
            const std::uint32_t dim18426JoeKuoD6Init[]   =   { 1, 1, 1, 13, 7, 53, 25, 163, 453, 195, 1115, 1019, 3799, 7489, 12419, 15141, 112001, 106459, 0 };
            const std::uint32_t dim18427JoeKuoD6Init[]   =   { 1, 1, 3, 9, 27, 15, 63, 109, 293, 867, 645, 1821, 2867, 9653, 32617, 39617, 125589, 249169, 0 };
            const std::uint32_t dim18428JoeKuoD6Init[]   =   { 1, 1, 7, 5, 19, 17, 15, 105, 65, 143, 961, 493, 7301, 11299, 4549, 49873, 82447, 107, 0 };
            const std::uint32_t dim18429JoeKuoD6Init[]   =   { 1, 1, 7, 1, 31, 21, 19, 61, 255, 815, 421, 3097, 4993, 9709, 11529, 53839, 32653, 137861, 0 };
            const std::uint32_t dim18430JoeKuoD6Init[]   =   { 1, 3, 1, 9, 5, 5, 59, 179, 115, 101, 407, 1143, 309, 843, 31143, 60639, 126659, 111695, 0 };
            const std::uint32_t dim18431JoeKuoD6Init[]   =   { 1, 3, 7, 13, 7, 47, 65, 127, 159, 817, 1029, 2983, 5443, 11087, 10595, 47143, 128353, 195189, 0 };
            const std::uint32_t dim18432JoeKuoD6Init[]   =   { 1, 3, 7, 1, 27, 21, 61, 235, 433, 929, 581, 1925, 8185, 6037, 28859, 16843, 43499, 217091, 0 };
            const std::uint32_t dim18433JoeKuoD6Init[]   =   { 1, 3, 7, 11, 1, 11, 81, 187, 227, 967, 25, 2285, 1251, 10743, 2321, 29029, 89739, 188023, 0 };
            const std::uint32_t dim18434JoeKuoD6Init[]   =   { 1, 3, 5, 11, 21, 25, 57, 201, 89, 965, 1593, 2879, 2469, 13675, 28789, 11407, 13109, 52749, 0 };
            const std::uint32_t dim18435JoeKuoD6Init[]   =   { 1, 3, 3, 3, 19, 25, 87, 3, 127, 881, 645, 207, 1129, 4235, 1533, 52503, 128733, 238679, 0 };
            const std::uint32_t dim18436JoeKuoD6Init[]   =   { 1, 3, 3, 1, 5, 5, 63, 181, 493, 457, 1529, 1795, 219, 10807, 26713, 49673, 47167, 103595, 0 };
            const std::uint32_t dim18437JoeKuoD6Init[]   =   { 1, 1, 3, 3, 1, 31, 65, 79, 473, 257, 1477, 387, 2843, 4031, 8459, 44849, 115157, 8417, 0 };
            const std::uint32_t dim18438JoeKuoD6Init[]   =   { 1, 3, 3, 5, 15, 1, 105, 67, 343, 333, 1961, 649, 5105, 11387, 27437, 35471, 26295, 220309, 0 };
            const std::uint32_t dim18439JoeKuoD6Init[]   =   { 1, 3, 7, 15, 1, 7, 23, 113, 67, 1019, 1793, 3237, 7223, 5691, 6279, 50231, 49393, 84393, 0 };
            const std::uint32_t dim18440JoeKuoD6Init[]   =   { 1, 1, 1, 7, 9, 29, 125, 249, 89, 813, 561, 871, 1957, 1095, 18563, 5257, 39563, 225651, 0 };
            const std::uint32_t dim18441JoeKuoD6Init[]   =   { 1, 1, 1, 15, 17, 11, 51, 191, 217, 617, 793, 3633, 4673, 15463, 10621, 47221, 51611, 155937, 0 };
            const std::uint32_t dim18442JoeKuoD6Init[]   =   { 1, 3, 7, 15, 13, 7, 63, 57, 45, 1005, 685, 2913, 3597, 9933, 14819, 26015, 80023, 60547, 0 };
            const std::uint32_t dim18443JoeKuoD6Init[]   =   { 1, 1, 5, 5, 31, 43, 69, 63, 425, 439, 143, 933, 675, 11301, 31779, 53445, 25143, 213213, 0 };
            const std::uint32_t dim18444JoeKuoD6Init[]   =   { 1, 1, 1, 5, 21, 9, 91, 89, 483, 153, 389, 7, 633, 15527, 21833, 45171, 88331, 150935, 0 };
            const std::uint32_t dim18445JoeKuoD6Init[]   =   { 1, 3, 5, 5, 11, 31, 49, 139, 295, 289, 1623, 3359, 7551, 11285, 25083, 27699, 91869, 237571, 0 };
            const std::uint32_t dim18446JoeKuoD6Init[]   =   { 1, 1, 1, 9, 9, 25, 55, 71, 51, 603, 1901, 2729, 6803, 11135, 5427, 37285, 69141, 262073, 0 };
            const std::uint32_t dim18447JoeKuoD6Init[]   =   { 1, 1, 3, 11, 3, 7, 81, 89, 49, 303, 755, 223, 603, 12525, 26037, 47867, 118871, 238677, 0 };
            const std::uint32_t dim18448JoeKuoD6Init[]   =   { 1, 3, 3, 11, 1, 53, 55, 15, 341, 151, 245, 1979, 3523, 15151, 25075, 21425, 48689, 125391, 0 };
            const std::uint32_t dim18449JoeKuoD6Init[]   =   { 1, 3, 3, 7, 15, 21, 73, 247, 215, 339, 1995, 633, 2557, 5625, 28443, 16413, 34615, 260591, 0 };
            const std::uint32_t dim18450JoeKuoD6Init[]   =   { 1, 3, 5, 1, 1, 59, 21, 247, 403, 15, 1129, 2263, 3361, 10675, 30417, 31285, 69913, 124329, 0 };
            const std::uint32_t dim18451JoeKuoD6Init[]   =   { 1, 1, 5, 1, 17, 3, 103, 107, 333, 191, 345, 3219, 3845, 5953, 26403, 51115, 71623, 52293, 0 };
            const std::uint32_t dim18452JoeKuoD6Init[]   =   { 1, 1, 7, 5, 29, 13, 59, 65, 185, 91, 717, 3179, 1237, 1187, 25485, 40119, 6069, 23567, 0 };
            const std::uint32_t dim18453JoeKuoD6Init[]   =   { 1, 1, 1, 5, 17, 57, 27, 39, 269, 627, 1239, 135, 623, 483, 19229, 51939, 114387, 146431, 0 };
            const std::uint32_t dim18454JoeKuoD6Init[]   =   { 1, 3, 7, 9, 21, 41, 119, 129, 177, 149, 1527, 3639, 4489, 11635, 23007, 59863, 85199, 87795, 0 };
            const std::uint32_t dim18455JoeKuoD6Init[]   =   { 1, 3, 5, 9, 17, 25, 57, 237, 129, 855, 199, 1929, 2793, 4277, 4509, 46301, 32905, 102015, 0 };
            const std::uint32_t dim18456JoeKuoD6Init[]   =   { 1, 1, 7, 1, 15, 23, 3, 131, 475, 347, 1301, 241, 153, 2801, 29271, 1337, 107613, 154105, 0 };
            const std::uint32_t dim18457JoeKuoD6Init[]   =   { 1, 1, 1, 13, 5, 19, 43, 47, 381, 709, 637, 2565, 7503, 10027, 16873, 23511, 101785, 47987, 0 };
            const std::uint32_t dim18458JoeKuoD6Init[]   =   { 1, 1, 5, 13, 31, 15, 125, 97, 361, 819, 121, 2723, 3395, 6943, 5279, 55977, 103559, 134177, 0 };
            const std::uint32_t dim18459JoeKuoD6Init[]   =   { 1, 1, 7, 13, 17, 27, 105, 11, 327, 203, 1355, 1437, 959, 10113, 7405, 43511, 114073, 199463, 0 };
            const std::uint32_t dim18460JoeKuoD6Init[]   =   { 1, 1, 7, 5, 29, 19, 7, 151, 107, 739, 1021, 1287, 6881, 2741, 3407, 13847, 75669, 116015, 0 };
            const std::uint32_t dim18461JoeKuoD6Init[]   =   { 1, 1, 1, 5, 5, 17, 99, 67, 179, 319, 149, 4069, 7811, 3055, 24669, 21635, 68057, 72059, 0 };
            const std::uint32_t dim18462JoeKuoD6Init[]   =   { 1, 3, 1, 11, 3, 3, 103, 45, 431, 159, 1693, 1069, 3403, 6121, 12695, 16565, 29787, 199327, 0 };
            const std::uint32_t dim18463JoeKuoD6Init[]   =   { 1, 1, 5, 5, 5, 35, 97, 9, 7, 703, 1533, 847, 7693, 16041, 13127, 26829, 68801, 205219, 0 };
            const std::uint32_t dim18464JoeKuoD6Init[]   =   { 1, 1, 5, 9, 25, 59, 3, 63, 305, 71, 1429, 1567, 2377, 12611, 9267, 62381, 32373, 187735, 0 };
            const std::uint32_t dim18465JoeKuoD6Init[]   =   { 1, 1, 3, 15, 5, 31, 21, 113, 329, 573, 1975, 1615, 947, 987, 4655, 46803, 100251, 89729, 0 };
            const std::uint32_t dim18466JoeKuoD6Init[]   =   { 1, 1, 5, 9, 15, 63, 83, 5, 71, 191, 1127, 3529, 7325, 1169, 4255, 6715, 42765, 73231, 0 };
            const std::uint32_t dim18467JoeKuoD6Init[]   =   { 1, 3, 3, 9, 11, 1, 1, 23, 97, 967, 1465, 1305, 2073, 3143, 31333, 1409, 95321, 182333, 0 };
            const std::uint32_t dim18468JoeKuoD6Init[]   =   { 1, 3, 5, 13, 21, 53, 47, 105, 75, 721, 239, 3619, 2581, 2063, 21227, 25579, 23729, 20067, 0 };
            const std::uint32_t dim18469JoeKuoD6Init[]   =   { 1, 3, 5, 13, 1, 55, 55, 115, 391, 539, 869, 3347, 189, 11087, 11533, 18747, 25387, 19205, 0 };
            const std::uint32_t dim18470JoeKuoD6Init[]   =   { 1, 3, 1, 15, 25, 57, 81, 27, 379, 635, 1697, 2805, 8071, 11407, 14843, 17593, 20819, 42891, 0 };
            const std::uint32_t dim18471JoeKuoD6Init[]   =   { 1, 3, 5, 11, 1, 59, 51, 187, 11, 211, 1425, 3829, 3193, 15743, 16479, 4205, 108205, 205367, 0 };
            const std::uint32_t dim18472JoeKuoD6Init[]   =   { 1, 1, 1, 5, 7, 7, 59, 85, 63, 509, 897, 2473, 7345, 111, 4431, 55273, 114037, 232541, 0 };
            const std::uint32_t dim18473JoeKuoD6Init[]   =   { 1, 1, 5, 9, 29, 7, 25, 41, 401, 843, 115, 163, 6835, 13943, 5223, 31033, 10813, 250471, 0 };
            const std::uint32_t dim18474JoeKuoD6Init[]   =   { 1, 1, 5, 11, 27, 45, 43, 233, 195, 151, 11, 1539, 4775, 15743, 15507, 26939, 30353, 162929, 0 };
            const std::uint32_t dim18475JoeKuoD6Init[]   =   { 1, 3, 1, 7, 7, 39, 1, 87, 85, 1019, 1711, 2707, 735, 5093, 8231, 25069, 102861, 45751, 0 };
            const std::uint32_t dim18476JoeKuoD6Init[]   =   { 1, 3, 7, 1, 19, 49, 55, 249, 255, 809, 1799, 3475, 7697, 5003, 12437, 52313, 96355, 138537, 0 };
            const std::uint32_t dim18477JoeKuoD6Init[]   =   { 1, 1, 3, 5, 5, 43, 25, 95, 349, 775, 213, 3643, 1355, 7745, 9553, 53367, 123655, 195365, 0 };
            const std::uint32_t dim18478JoeKuoD6Init[]   =   { 1, 1, 1, 1, 19, 53, 39, 105, 449, 447, 147, 2293, 7817, 1503, 31985, 37193, 51039, 209083, 0 };
            const std::uint32_t dim18479JoeKuoD6Init[]   =   { 1, 3, 3, 15, 27, 15, 59, 51, 411, 543, 421, 3595, 2091, 7171, 23595, 33509, 37283, 105719, 0 };
            const std::uint32_t dim18480JoeKuoD6Init[]   =   { 1, 3, 1, 11, 5, 37, 5, 203, 171, 853, 1875, 2735, 4003, 15163, 26193, 36149, 31389, 256631, 0 };
            const std::uint32_t dim18481JoeKuoD6Init[]   =   { 1, 3, 5, 1, 21, 1, 127, 41, 185, 929, 1757, 2711, 2947, 9709, 18401, 45037, 1371, 242397, 0 };
            const std::uint32_t dim18482JoeKuoD6Init[]   =   { 1, 1, 1, 1, 13, 43, 51, 187, 487, 759, 1579, 959, 2499, 4781, 27179, 6839, 43869, 36163, 0 };
            const std::uint32_t dim18483JoeKuoD6Init[]   =   { 1, 3, 1, 15, 5, 3, 101, 25, 181, 107, 1105, 879, 5341, 12215, 21615, 9619, 129591, 108393, 0 };
            const std::uint32_t dim18484JoeKuoD6Init[]   =   { 1, 1, 7, 1, 11, 39, 55, 101, 43, 935, 1703, 1269, 6751, 13723, 7463, 10055, 112971, 72789, 0 };
            const std::uint32_t dim18485JoeKuoD6Init[]   =   { 1, 3, 5, 13, 7, 3, 81, 41, 55, 375, 663, 801, 5051, 14583, 30793, 63897, 127255, 174179, 0 };
            const std::uint32_t dim18486JoeKuoD6Init[]   =   { 1, 3, 1, 7, 19, 31, 53, 29, 313, 57, 1411, 103, 6863, 10673, 4341, 5587, 106059, 222309, 0 };
            const std::uint32_t dim18487JoeKuoD6Init[]   =   { 1, 3, 7, 3, 1, 33, 89, 199, 91, 557, 715, 2715, 4753, 5987, 30355, 13819, 57443, 112179, 0 };
            const std::uint32_t dim18488JoeKuoD6Init[]   =   { 1, 3, 5, 7, 13, 27, 55, 11, 495, 29, 1273, 1727, 3397, 2739, 22907, 46203, 16687, 47385, 0 };
            const std::uint32_t dim18489JoeKuoD6Init[]   =   { 1, 3, 5, 9, 13, 23, 23, 107, 353, 429, 359, 2667, 6137, 7213, 7977, 35903, 118507, 209243, 0 };
            const std::uint32_t dim18490JoeKuoD6Init[]   =   { 1, 3, 1, 13, 9, 7, 37, 135, 377, 753, 1819, 113, 7379, 2795, 10373, 7131, 17845, 246101, 0 };
            const std::uint32_t dim18491JoeKuoD6Init[]   =   { 1, 1, 3, 11, 11, 45, 53, 209, 49, 385, 1573, 1129, 2939, 10949, 413, 59193, 15399, 169355, 0 };
            const std::uint32_t dim18492JoeKuoD6Init[]   =   { 1, 1, 5, 15, 29, 29, 89, 139, 403, 11, 1335, 2601, 3631, 15317, 1707, 3517, 1939, 121997, 0 };
            const std::uint32_t dim18493JoeKuoD6Init[]   =   { 1, 3, 1, 7, 17, 3, 113, 97, 435, 911, 1743, 1649, 4829, 9995, 2873, 17527, 46931, 86199, 0 };
            const std::uint32_t dim18494JoeKuoD6Init[]   =   { 1, 1, 7, 1, 13, 19, 83, 51, 49, 671, 1651, 3443, 2279, 5677, 8859, 41945, 110607, 200469, 0 };
            const std::uint32_t dim18495JoeKuoD6Init[]   =   { 1, 1, 5, 13, 19, 63, 19, 73, 205, 571, 507, 1781, 1489, 5909, 10351, 64607, 67023, 49441, 0 };
            const std::uint32_t dim18496JoeKuoD6Init[]   =   { 1, 1, 3, 5, 13, 35, 107, 63, 489, 69, 1541, 3761, 17, 9317, 20323, 35401, 61451, 116115, 0 };
            const std::uint32_t dim18497JoeKuoD6Init[]   =   { 1, 3, 1, 5, 31, 35, 39, 119, 237, 533, 107, 3235, 4929, 15839, 9309, 50131, 110945, 24739, 0 };
            const std::uint32_t dim18498JoeKuoD6Init[]   =   { 1, 3, 1, 5, 3, 25, 73, 145, 391, 481, 1927, 3071, 4347, 13415, 26723, 51629, 3003, 54575, 0 };
            const std::uint32_t dim18499JoeKuoD6Init[]   =   { 1, 3, 3, 11, 29, 63, 63, 183, 11, 269, 153, 3379, 5603, 14279, 28579, 4653, 98179, 125693, 0 };
            const std::uint32_t dim18500JoeKuoD6Init[]   =   { 1, 1, 5, 15, 1, 51, 101, 69, 177, 233, 213, 2389, 4963, 3391, 13419, 41283, 25667, 187239, 0 };
            const std::uint32_t dim18501JoeKuoD6Init[]   =   { 1, 1, 1, 11, 13, 29, 95, 231, 481, 283, 1323, 521, 4689, 5311, 21949, 31851, 115845, 50433, 0 };
            const std::uint32_t dim18502JoeKuoD6Init[]   =   { 1, 3, 7, 15, 11, 31, 67, 207, 57, 439, 1561, 2167, 673, 6467, 8189, 31783, 5051, 64097, 0 };
            const std::uint32_t dim18503JoeKuoD6Init[]   =   { 1, 1, 7, 9, 17, 57, 77, 85, 119, 149, 211, 2727, 4921, 8701, 23121, 36355, 9179, 68003, 0 };
            const std::uint32_t dim18504JoeKuoD6Init[]   =   { 1, 1, 5, 15, 1, 15, 123, 205, 79, 299, 71, 3413, 7635, 5699, 32393, 10253, 86205, 216015, 0 };
            const std::uint32_t dim18505JoeKuoD6Init[]   =   { 1, 1, 5, 11, 23, 39, 105, 187, 487, 247, 333, 2423, 5643, 8111, 23549, 50153, 122859, 100361, 0 };
            const std::uint32_t dim18506JoeKuoD6Init[]   =   { 1, 1, 1, 9, 11, 33, 65, 125, 67, 743, 1331, 1563, 6333, 11375, 15873, 18137, 52765, 224889, 0 };
            const std::uint32_t dim18507JoeKuoD6Init[]   =   { 1, 3, 5, 9, 15, 17, 81, 165, 3, 609, 635, 2093, 6635, 8647, 25883, 18907, 73333, 80835, 0 };
            const std::uint32_t dim18508JoeKuoD6Init[]   =   { 1, 1, 1, 11, 1, 1, 25, 115, 205, 941, 1917, 1295, 3659, 821, 11355, 1435, 40289, 115627, 0 };
            const std::uint32_t dim18509JoeKuoD6Init[]   =   { 1, 3, 1, 9, 13, 23, 35, 105, 441, 777, 1255, 3315, 1157, 8719, 9939, 38931, 120723, 123201, 0 };
            const std::uint32_t dim18510JoeKuoD6Init[]   =   { 1, 1, 5, 3, 1, 21, 95, 143, 23, 233, 73, 1223, 5619, 8583, 21417, 61971, 74565, 116249, 0 };
            const std::uint32_t dim18511JoeKuoD6Init[]   =   { 1, 1, 7, 7, 23, 35, 21, 201, 441, 623, 419, 2375, 1189, 15681, 29469, 29437, 124525, 241899, 0 };
            const std::uint32_t dim18512JoeKuoD6Init[]   =   { 1, 1, 3, 1, 11, 7, 23, 171, 435, 467, 1811, 63, 3705, 9395, 579, 58305, 86165, 67805, 0 };
            const std::uint32_t dim18513JoeKuoD6Init[]   =   { 1, 3, 1, 3, 13, 11, 107, 243, 163, 79, 815, 1149, 2247, 12411, 30287, 56915, 26939, 85883, 0 };
            const std::uint32_t dim18514JoeKuoD6Init[]   =   { 1, 3, 3, 1, 5, 23, 105, 63, 35, 57, 1815, 3325, 3727, 3623, 7203, 8301, 28073, 190053, 0 };
            const std::uint32_t dim18515JoeKuoD6Init[]   =   { 1, 3, 1, 11, 23, 33, 121, 55, 287, 139, 491, 907, 4237, 17, 20055, 63729, 7517, 151597, 0 };
            const std::uint32_t dim18516JoeKuoD6Init[]   =   { 1, 3, 5, 5, 21, 1, 37, 19, 159, 1013, 27, 2627, 851, 14021, 31311, 5871, 77613, 125311, 0 };
            const std::uint32_t dim18517JoeKuoD6Init[]   =   { 1, 3, 3, 1, 27, 3, 51, 133, 459, 581, 383, 1351, 6149, 15611, 2631, 20797, 65955, 113665, 0 };
            const std::uint32_t dim18518JoeKuoD6Init[]   =   { 1, 3, 1, 11, 23, 61, 75, 217, 283, 405, 767, 1151, 7501, 5553, 113, 48331, 49379, 191473, 0 };
            const std::uint32_t dim18519JoeKuoD6Init[]   =   { 1, 3, 5, 5, 15, 3, 19, 27, 497, 519, 1611, 709, 405, 13329, 27861, 14981, 47197, 173979, 0 };
            const std::uint32_t dim18520JoeKuoD6Init[]   =   { 1, 1, 7, 7, 25, 19, 99, 219, 349, 713, 1421, 3427, 153, 13319, 22415, 48617, 119637, 20835, 0 };
            const std::uint32_t dim18521JoeKuoD6Init[]   =   { 1, 1, 1, 3, 13, 37, 43, 9, 317, 961, 1255, 2975, 2775, 12283, 29941, 57495, 77413, 256695, 0 };
            const std::uint32_t dim18522JoeKuoD6Init[]   =   { 1, 1, 7, 5, 29, 37, 91, 199, 397, 739, 877, 251, 847, 2951, 19497, 57285, 76891, 258711, 0 };
            const std::uint32_t dim18523JoeKuoD6Init[]   =   { 1, 1, 7, 15, 21, 55, 107, 115, 481, 845, 2015, 481, 3823, 14071, 4037, 39687, 62867, 170891, 0 };
            const std::uint32_t dim18524JoeKuoD6Init[]   =   { 1, 3, 3, 1, 17, 51, 81, 195, 189, 455, 1343, 1493, 351, 361, 20289, 37423, 7747, 245861, 0 };
            const std::uint32_t dim18525JoeKuoD6Init[]   =   { 1, 1, 5, 15, 9, 41, 71, 155, 197, 563, 1271, 2227, 2557, 6657, 13565, 8467, 96135, 5903, 0 };
            const std::uint32_t dim18526JoeKuoD6Init[]   =   { 1, 1, 5, 13, 29, 33, 115, 131, 283, 435, 1327, 1113, 4729, 14125, 23743, 40121, 119955, 237453, 0 };
            const std::uint32_t dim18527JoeKuoD6Init[]   =   { 1, 1, 1, 1, 13, 21, 109, 91, 105, 749, 1695, 1123, 4349, 9855, 31565, 64001, 7919, 83591, 0 };
            const std::uint32_t dim18528JoeKuoD6Init[]   =   { 1, 3, 1, 1, 13, 19, 89, 83, 13, 609, 731, 2655, 1123, 13415, 5645, 10003, 69381, 187621, 0 };
            const std::uint32_t dim18529JoeKuoD6Init[]   =   { 1, 3, 1, 15, 3, 37, 1, 139, 11, 917, 1191, 1381, 6035, 13851, 4565, 5427, 117703, 109965, 0 };
            const std::uint32_t dim18530JoeKuoD6Init[]   =   { 1, 1, 5, 3, 17, 37, 15, 115, 19, 65, 1807, 3879, 2709, 9819, 11457, 53705, 14821, 156079, 0 };
            const std::uint32_t dim18531JoeKuoD6Init[]   =   { 1, 1, 7, 13, 17, 29, 105, 77, 127, 457, 1287, 1533, 6879, 4001, 4083, 29523, 81175, 226409, 0 };
            const std::uint32_t dim18532JoeKuoD6Init[]   =   { 1, 3, 1, 5, 5, 59, 21, 253, 459, 733, 409, 3359, 1913, 8893, 16113, 61063, 6511, 22441, 0 };
            const std::uint32_t dim18533JoeKuoD6Init[]   =   { 1, 3, 5, 11, 7, 1, 121, 217, 63, 83, 173, 1869, 7931, 655, 21053, 20703, 116853, 131785, 0 };
            const std::uint32_t dim18534JoeKuoD6Init[]   =   { 1, 1, 7, 7, 5, 13, 41, 57, 1, 17, 649, 233, 2867, 5577, 30553, 7635, 45305, 47979, 0 };
            const std::uint32_t dim18535JoeKuoD6Init[]   =   { 1, 1, 7, 1, 1, 29, 61, 241, 107, 891, 49, 3433, 5045, 143, 22473, 29243, 82625, 184163, 0 };
            const std::uint32_t dim18536JoeKuoD6Init[]   =   { 1, 3, 1, 11, 11, 21, 119, 43, 117, 429, 1569, 637, 67, 9475, 31779, 2237, 122037, 245361, 0 };
            const std::uint32_t dim18537JoeKuoD6Init[]   =   { 1, 1, 7, 1, 31, 61, 9, 179, 467, 153, 1913, 2839, 6255, 12715, 28229, 20189, 3617, 213539, 0 };
            const std::uint32_t dim18538JoeKuoD6Init[]   =   { 1, 1, 7, 13, 25, 61, 9, 109, 331, 577, 21, 1017, 6521, 5991, 26573, 56881, 58455, 169407, 0 };
            const std::uint32_t dim18539JoeKuoD6Init[]   =   { 1, 1, 7, 9, 31, 57, 51, 41, 327, 859, 1295, 1577, 1071, 3277, 11685, 62129, 34111, 174639, 0 };
            const std::uint32_t dim18540JoeKuoD6Init[]   =   { 1, 3, 5, 1, 7, 63, 35, 165, 43, 943, 1545, 3717, 1471, 11579, 29637, 22913, 8867, 12837, 0 };
            const std::uint32_t dim18541JoeKuoD6Init[]   =   { 1, 1, 3, 1, 23, 7, 19, 151, 359, 347, 1085, 3923, 1039, 5149, 6047, 49811, 33099, 247983, 0 };
            const std::uint32_t dim18542JoeKuoD6Init[]   =   { 1, 1, 1, 5, 29, 23, 73, 189, 59, 865, 1499, 1953, 1261, 1071, 26761, 26145, 129427, 223219, 0 };
            const std::uint32_t dim18543JoeKuoD6Init[]   =   { 1, 3, 1, 9, 1, 29, 107, 173, 387, 703, 193, 1965, 6233, 10997, 32697, 31005, 15415, 94345, 0 };
            const std::uint32_t dim18544JoeKuoD6Init[]   =   { 1, 1, 3, 9, 31, 35, 7, 15, 317, 79, 2045, 1455, 1559, 15087, 287, 46665, 37225, 149017, 0 };
            const std::uint32_t dim18545JoeKuoD6Init[]   =   { 1, 1, 5, 13, 17, 27, 11, 107, 47, 803, 1487, 3049, 1171, 6237, 9157, 10037, 122349, 236877, 0 };
            const std::uint32_t dim18546JoeKuoD6Init[]   =   { 1, 1, 7, 9, 21, 35, 53, 139, 165, 73, 1405, 2941, 3553, 11945, 2493, 5743, 63749, 140535, 0 };
            const std::uint32_t dim18547JoeKuoD6Init[]   =   { 1, 3, 7, 11, 7, 57, 41, 187, 483, 499, 687, 117, 4951, 14709, 17025, 23027, 94863, 228465, 0 };
            const std::uint32_t dim18548JoeKuoD6Init[]   =   { 1, 3, 7, 7, 27, 29, 85, 117, 201, 637, 823, 1135, 7595, 3323, 23579, 40759, 25087, 995, 0 };
            const std::uint32_t dim18549JoeKuoD6Init[]   =   { 1, 3, 1, 9, 31, 53, 101, 29, 381, 101, 1939, 1973, 8191, 8155, 13881, 32309, 92907, 239525, 0 };
            const std::uint32_t dim18550JoeKuoD6Init[]   =   { 1, 1, 5, 7, 3, 35, 15, 207, 1, 47, 325, 559, 3377, 3909, 31225, 28367, 63891, 19129, 0 };
            const std::uint32_t dim18551JoeKuoD6Init[]   =   { 1, 1, 1, 5, 31, 61, 117, 211, 127, 969, 73, 1295, 7167, 14881, 9965, 28143, 28161, 131867, 0 };
            const std::uint32_t dim18552JoeKuoD6Init[]   =   { 1, 3, 7, 5, 5, 57, 37, 207, 201, 79, 1151, 3685, 2071, 1751, 5481, 51447, 103437, 154895, 0 };
            const std::uint32_t dim18553JoeKuoD6Init[]   =   { 1, 3, 5, 13, 9, 5, 57, 27, 131, 211, 1481, 2237, 4227, 6927, 18625, 49773, 55399, 15209, 0 };
            const std::uint32_t dim18554JoeKuoD6Init[]   =   { 1, 3, 1, 7, 23, 29, 3, 179, 479, 787, 463, 2041, 2581, 6281, 1657, 51433, 93807, 160047, 0 };
            const std::uint32_t dim18555JoeKuoD6Init[]   =   { 1, 1, 3, 13, 25, 35, 33, 231, 385, 479, 335, 3837, 5517, 13603, 15623, 46737, 42507, 208355, 0 };
            const std::uint32_t dim18556JoeKuoD6Init[]   =   { 1, 1, 7, 9, 3, 25, 51, 125, 213, 175, 1575, 1755, 1843, 14361, 13155, 22445, 55435, 62793, 0 };
            const std::uint32_t dim18557JoeKuoD6Init[]   =   { 1, 1, 1, 7, 25, 3, 21, 7, 309, 547, 19, 471, 2679, 16185, 12149, 41437, 47625, 75113, 0 };
            const std::uint32_t dim18558JoeKuoD6Init[]   =   { 1, 1, 5, 1, 9, 23, 81, 95, 123, 143, 1111, 9, 3501, 11897, 26499, 10009, 48073, 182529, 0 };
            const std::uint32_t dim18559JoeKuoD6Init[]   =   { 1, 3, 1, 1, 1, 17, 15, 157, 129, 1005, 543, 3917, 3493, 6537, 26997, 33217, 7987, 251635, 0 };
            const std::uint32_t dim18560JoeKuoD6Init[]   =   { 1, 3, 1, 13, 11, 41, 9, 19, 173, 751, 491, 1645, 5205, 9907, 28503, 61137, 79727, 200851, 0 };
            const std::uint32_t dim18561JoeKuoD6Init[]   =   { 1, 1, 1, 1, 3, 5, 105, 203, 97, 903, 1507, 2719, 5275, 1023, 29595, 42507, 39893, 151495, 0 };
            const std::uint32_t dim18562JoeKuoD6Init[]   =   { 1, 1, 1, 11, 31, 53, 51, 65, 145, 671, 489, 109, 803, 8541, 4439, 33893, 98495, 114955, 0 };
            const std::uint32_t dim18563JoeKuoD6Init[]   =   { 1, 1, 7, 11, 27, 63, 117, 235, 497, 841, 1461, 3757, 1077, 6997, 9611, 47453, 20197, 176939, 0 };
            const std::uint32_t dim18564JoeKuoD6Init[]   =   { 1, 3, 3, 3, 31, 17, 85, 145, 377, 225, 1033, 3017, 735, 5811, 25503, 25457, 124623, 51713, 0 };
            const std::uint32_t dim18565JoeKuoD6Init[]   =   { 1, 3, 3, 13, 19, 33, 127, 57, 321, 687, 1651, 3321, 5051, 8511, 19609, 49927, 30499, 102613, 0 };
            const std::uint32_t dim18566JoeKuoD6Init[]   =   { 1, 1, 5, 13, 7, 17, 17, 147, 381, 137, 1007, 2607, 1071, 8921, 13955, 47223, 130359, 246265, 0 };
            const std::uint32_t dim18567JoeKuoD6Init[]   =   { 1, 3, 7, 9, 13, 35, 71, 129, 57, 233, 357, 3181, 2841, 3707, 24947, 57777, 115133, 6049, 0 };
            const std::uint32_t dim18568JoeKuoD6Init[]   =   { 1, 3, 7, 15, 23, 1, 107, 225, 57, 633, 1515, 1631, 4303, 4221, 8281, 59139, 45023, 70219, 0 };
            const std::uint32_t dim18569JoeKuoD6Init[]   =   { 1, 1, 7, 5, 9, 9, 93, 131, 41, 245, 1261, 459, 4811, 10987, 10421, 63839, 34067, 196353, 0 };
            const std::uint32_t dim18570JoeKuoD6Init[]   =   { 1, 3, 3, 13, 17, 3, 87, 255, 167, 701, 821, 1965, 1415, 4101, 549, 6347, 92421, 47193, 0 };
            const std::uint32_t dim18571JoeKuoD6Init[]   =   { 1, 3, 7, 11, 23, 17, 51, 81, 71, 345, 971, 917, 1057, 3627, 20361, 13491, 12855, 234215, 0 };
            const std::uint32_t dim18572JoeKuoD6Init[]   =   { 1, 1, 1, 13, 17, 9, 25, 155, 463, 851, 243, 3887, 2445, 7459, 19915, 21813, 86969, 85891, 0 };
            const std::uint32_t dim18573JoeKuoD6Init[]   =   { 1, 1, 7, 1, 9, 15, 57, 201, 193, 169, 351, 1355, 1089, 4705, 15153, 51359, 49907, 66007, 0 };
            const std::uint32_t dim18574JoeKuoD6Init[]   =   { 1, 3, 1, 9, 19, 13, 69, 83, 39, 667, 1549, 1503, 7167, 8657, 17269, 59357, 80091, 194007, 0 };
            const std::uint32_t dim18575JoeKuoD6Init[]   =   { 1, 3, 5, 5, 17, 37, 125, 117, 355, 685, 637, 3159, 4783, 3159, 14953, 12731, 126759, 89149, 0 };
            const std::uint32_t dim18576JoeKuoD6Init[]   =   { 1, 3, 3, 9, 15, 53, 7, 41, 473, 857, 511, 3741, 6837, 6167, 26351, 9885, 104819, 48221, 0 };
            const std::uint32_t dim18577JoeKuoD6Init[]   =   { 1, 3, 7, 15, 21, 21, 21, 101, 465, 223, 13, 1773, 2763, 8621, 23591, 12633, 82143, 134899, 0 };
            const std::uint32_t dim18578JoeKuoD6Init[]   =   { 1, 3, 1, 1, 29, 25, 67, 19, 349, 503, 655, 3567, 97, 6967, 18253, 42755, 33041, 250279, 0 };
            const std::uint32_t dim18579JoeKuoD6Init[]   =   { 1, 1, 7, 9, 17, 1, 7, 165, 255, 613, 579, 127, 7567, 13181, 6255, 1785, 21527, 113815, 0 };
            const std::uint32_t dim18580JoeKuoD6Init[]   =   { 1, 3, 1, 5, 27, 33, 61, 235, 37, 135, 1515, 3611, 1825, 9627, 18805, 37065, 126107, 23223, 0 };
            const std::uint32_t dim18581JoeKuoD6Init[]   =   { 1, 3, 7, 5, 23, 11, 29, 121, 129, 311, 429, 1653, 5789, 7693, 18775, 18189, 97203, 213501, 0 };
            const std::uint32_t dim18582JoeKuoD6Init[]   =   { 1, 3, 7, 3, 29, 61, 87, 197, 43, 509, 5, 3275, 345, 7885, 4381, 22059, 1395, 40125, 0 };
            const std::uint32_t dim18583JoeKuoD6Init[]   =   { 1, 3, 5, 1, 1, 59, 69, 125, 297, 983, 641, 2665, 7045, 8591, 16581, 58657, 119189, 256579, 0 };
            const std::uint32_t dim18584JoeKuoD6Init[]   =   { 1, 3, 7, 7, 7, 53, 65, 181, 149, 987, 1377, 4045, 971, 9827, 17727, 59357, 90975, 27395, 0 };
            const std::uint32_t dim18585JoeKuoD6Init[]   =   { 1, 1, 7, 7, 1, 51, 109, 165, 361, 515, 739, 3709, 6431, 113, 21401, 41743, 53071, 134205, 0 };
            const std::uint32_t dim18586JoeKuoD6Init[]   =   { 1, 3, 1, 13, 5, 51, 107, 99, 135, 163, 1705, 1683, 6221, 1377, 2211, 13379, 22801, 208753, 0 };
            const std::uint32_t dim18587JoeKuoD6Init[]   =   { 1, 3, 5, 11, 11, 39, 49, 45, 503, 549, 821, 4077, 885, 13721, 29673, 28435, 6235, 212071, 0 };
            const std::uint32_t dim18588JoeKuoD6Init[]   =   { 1, 3, 3, 11, 15, 25, 17, 67, 125, 7, 1163, 973, 5325, 12707, 12763, 9481, 21363, 195897, 0 };
            const std::uint32_t dim18589JoeKuoD6Init[]   =   { 1, 1, 7, 9, 17, 19, 15, 13, 107, 919, 461, 343, 1101, 8195, 29293, 61643, 64995, 230469, 0 };
            const std::uint32_t dim18590JoeKuoD6Init[]   =   { 1, 3, 5, 1, 9, 25, 39, 65, 27, 461, 669, 2841, 7973, 11565, 9531, 52235, 6741, 215513, 0 };
            const std::uint32_t dim18591JoeKuoD6Init[]   =   { 1, 3, 3, 1, 7, 57, 101, 199, 37, 79, 2033, 1723, 6877, 2733, 26445, 62625, 21671, 238431, 0 };
            const std::uint32_t dim18592JoeKuoD6Init[]   =   { 1, 1, 1, 9, 27, 31, 125, 199, 331, 611, 523, 407, 747, 9499, 4685, 17805, 43717, 253233, 0 };
            const std::uint32_t dim18593JoeKuoD6Init[]   =   { 1, 1, 3, 7, 29, 7, 7, 153, 339, 337, 701, 2639, 6311, 6375, 26023, 27693, 59733, 260405, 0 };
            const std::uint32_t dim18594JoeKuoD6Init[]   =   { 1, 1, 7, 7, 15, 27, 23, 49, 181, 433, 485, 2915, 6021, 9095, 15951, 47257, 104513, 208089, 0 };
            const std::uint32_t dim18595JoeKuoD6Init[]   =   { 1, 1, 5, 7, 19, 19, 125, 153, 109, 829, 1967, 2567, 7157, 6001, 10151, 55323, 92405, 82549, 0 };
            const std::uint32_t dim18596JoeKuoD6Init[]   =   { 1, 1, 3, 11, 13, 17, 85, 215, 265, 875, 311, 3773, 8059, 2115, 19259, 63999, 77411, 220267, 0 };
            const std::uint32_t dim18597JoeKuoD6Init[]   =   { 1, 3, 1, 15, 15, 35, 81, 213, 411, 435, 105, 1487, 1991, 14539, 8175, 2115, 47259, 45893, 0 };
            const std::uint32_t dim18598JoeKuoD6Init[]   =   { 1, 3, 1, 11, 9, 47, 27, 115, 449, 521, 321, 2463, 1355, 5785, 11269, 45337, 29049, 91675, 0 };
            const std::uint32_t dim18599JoeKuoD6Init[]   =   { 1, 3, 1, 13, 21, 53, 49, 83, 373, 519, 757, 1241, 577, 14443, 449, 44773, 116673, 155209, 0 };
            const std::uint32_t dim18600JoeKuoD6Init[]   =   { 1, 3, 3, 1, 29, 63, 97, 145, 371, 585, 1809, 3997, 249, 283, 28369, 27325, 61673, 12637, 0 };
            const std::uint32_t dim18601JoeKuoD6Init[]   =   { 1, 3, 5, 9, 11, 55, 77, 89, 285, 297, 861, 2791, 3245, 15093, 32489, 40477, 97603, 35347, 0 };
            const std::uint32_t dim18602JoeKuoD6Init[]   =   { 1, 1, 1, 3, 27, 33, 115, 209, 169, 893, 393, 1457, 6069, 12511, 20423, 11385, 86711, 197555, 0 };
            const std::uint32_t dim18603JoeKuoD6Init[]   =   { 1, 3, 5, 15, 21, 25, 87, 159, 477, 177, 991, 495, 29, 9347, 9721, 4071, 30145, 214155, 0 };
            const std::uint32_t dim18604JoeKuoD6Init[]   =   { 1, 1, 5, 3, 11, 45, 53, 251, 177, 651, 549, 3377, 3247, 8761, 20339, 27743, 103387, 159591, 0 };
            const std::uint32_t dim18605JoeKuoD6Init[]   =   { 1, 3, 7, 11, 17, 27, 43, 179, 507, 553, 261, 3939, 6133, 6347, 12987, 46071, 42551, 99225, 0 };
            const std::uint32_t dim18606JoeKuoD6Init[]   =   { 1, 3, 3, 11, 3, 33, 85, 51, 277, 117, 1295, 2435, 1467, 13787, 2209, 52673, 53515, 157625, 0 };
            const std::uint32_t dim18607JoeKuoD6Init[]   =   { 1, 3, 3, 3, 9, 15, 121, 229, 227, 795, 541, 3727, 4333, 2251, 27833, 43567, 82505, 230427, 0 };
            const std::uint32_t dim18608JoeKuoD6Init[]   =   { 1, 1, 5, 13, 29, 19, 119, 63, 207, 945, 761, 2601, 1391, 8939, 11683, 52433, 63301, 82501, 0 };
            const std::uint32_t dim18609JoeKuoD6Init[]   =   { 1, 3, 7, 1, 3, 57, 127, 115, 209, 31, 1631, 347, 3937, 4015, 13313, 49507, 15103, 237071, 0 };
            const std::uint32_t dim18610JoeKuoD6Init[]   =   { 1, 3, 1, 13, 3, 25, 85, 151, 115, 385, 303, 2453, 2417, 8051, 1447, 59517, 3711, 160345, 0 };
            const std::uint32_t dim18611JoeKuoD6Init[]   =   { 1, 3, 1, 13, 1, 23, 49, 75, 117, 295, 1737, 2091, 6229, 3157, 32737, 13751, 101667, 96261, 0 };
            const std::uint32_t dim18612JoeKuoD6Init[]   =   { 1, 3, 3, 5, 27, 19, 103, 201, 65, 757, 1847, 239, 2185, 15139, 8883, 17737, 9207, 147663, 0 };
            const std::uint32_t dim18613JoeKuoD6Init[]   =   { 1, 3, 1, 9, 3, 39, 51, 1, 419, 929, 1049, 2891, 2585, 2759, 27587, 55711, 15461, 46851, 0 };
            const std::uint32_t dim18614JoeKuoD6Init[]   =   { 1, 1, 5, 3, 23, 23, 23, 101, 249, 997, 1889, 2293, 5693, 939, 29619, 2775, 49293, 168895, 0 };
            const std::uint32_t dim18615JoeKuoD6Init[]   =   { 1, 3, 1, 15, 9, 63, 17, 97, 385, 517, 1737, 713, 157, 2597, 20889, 35209, 47525, 14389, 0 };
            const std::uint32_t dim18616JoeKuoD6Init[]   =   { 1, 3, 1, 1, 7, 27, 9, 147, 349, 493, 341, 2699, 7743, 4283, 24691, 11881, 78619, 153899, 0 };
            const std::uint32_t dim18617JoeKuoD6Init[]   =   { 1, 3, 1, 9, 15, 25, 103, 177, 485, 355, 1319, 767, 6675, 3425, 7187, 53767, 92023, 151523, 0 };
            const std::uint32_t dim18618JoeKuoD6Init[]   =   { 1, 1, 3, 3, 15, 35, 25, 177, 295, 5, 661, 3651, 2597, 16229, 1343, 54941, 72047, 169155, 0 };
            const std::uint32_t dim18619JoeKuoD6Init[]   =   { 1, 1, 1, 1, 19, 29, 63, 229, 79, 551, 1401, 2851, 6935, 12485, 9243, 21671, 54209, 105347, 0 };
            const std::uint32_t dim18620JoeKuoD6Init[]   =   { 1, 1, 3, 1, 13, 33, 53, 125, 261, 623, 65, 3863, 1899, 2453, 16483, 48655, 50771, 248555, 0 };
            const std::uint32_t dim18621JoeKuoD6Init[]   =   { 1, 3, 5, 7, 25, 15, 107, 149, 485, 247, 1977, 3125, 4663, 4925, 15749, 39429, 52315, 30545, 0 };
            const std::uint32_t dim18622JoeKuoD6Init[]   =   { 1, 1, 7, 13, 23, 13, 127, 111, 9, 17, 1887, 1341, 3017, 14333, 6003, 35113, 14935, 17593, 0 };
            const std::uint32_t dim18623JoeKuoD6Init[]   =   { 1, 1, 1, 15, 23, 17, 111, 43, 71, 549, 1369, 1711, 3903, 13605, 14573, 18973, 28157, 128421, 0 };
            const std::uint32_t dim18624JoeKuoD6Init[]   =   { 1, 1, 7, 15, 27, 23, 5, 99, 87, 865, 1979, 3287, 3977, 14989, 17439, 14593, 92711, 211259, 0 };
            const std::uint32_t dim18625JoeKuoD6Init[]   =   { 1, 3, 3, 15, 5, 19, 3, 231, 127, 863, 1537, 369, 7915, 10281, 13925, 12931, 3905, 178609, 0 };
            const std::uint32_t dim18626JoeKuoD6Init[]   =   { 1, 1, 3, 15, 13, 5, 17, 217, 383, 251, 1701, 3379, 8157, 4991, 8563, 24611, 66081, 205775, 0 };
            const std::uint32_t dim18627JoeKuoD6Init[]   =   { 1, 3, 7, 11, 9, 25, 73, 131, 217, 601, 843, 807, 4509, 16209, 29581, 50869, 56595, 14283, 0 };
            const std::uint32_t dim18628JoeKuoD6Init[]   =   { 1, 3, 5, 9, 5, 59, 57, 153, 359, 775, 859, 1897, 6415, 7389, 10851, 64247, 21627, 145017, 0 };
            const std::uint32_t dim18629JoeKuoD6Init[]   =   { 1, 3, 7, 1, 27, 11, 117, 179, 175, 343, 687, 2775, 3655, 11655, 2641, 355, 83447, 237799, 0 };
            const std::uint32_t dim18630JoeKuoD6Init[]   =   { 1, 1, 7, 11, 17, 59, 91, 21, 403, 797, 1839, 525, 3279, 6575, 30083, 12503, 83057, 109465, 0 };
            const std::uint32_t dim18631JoeKuoD6Init[]   =   { 1, 3, 7, 1, 25, 27, 41, 223, 169, 679, 699, 3287, 6305, 6459, 23145, 45519, 127487, 183563, 0 };
            const std::uint32_t dim18632JoeKuoD6Init[]   =   { 1, 3, 3, 1, 9, 45, 105, 57, 185, 97, 899, 3113, 7081, 7057, 14559, 53537, 105623, 155399, 0 };
            const std::uint32_t dim18633JoeKuoD6Init[]   =   { 1, 3, 7, 5, 17, 35, 89, 13, 87, 587, 451, 4079, 1005, 4311, 15861, 49977, 59653, 12107, 0 };
            const std::uint32_t dim18634JoeKuoD6Init[]   =   { 1, 3, 7, 3, 19, 55, 43, 77, 317, 369, 71, 937, 1905, 5005, 17715, 4005, 55445, 25159, 0 };
            const std::uint32_t dim18635JoeKuoD6Init[]   =   { 1, 1, 7, 15, 15, 51, 87, 37, 59, 755, 763, 455, 711, 13399, 30999, 61269, 66037, 202793, 0 };
            const std::uint32_t dim18636JoeKuoD6Init[]   =   { 1, 1, 3, 5, 11, 57, 111, 135, 325, 553, 273, 1533, 3431, 6427, 24771, 42143, 56711, 220873, 0 };
            const std::uint32_t dim18637JoeKuoD6Init[]   =   { 1, 1, 1, 13, 3, 49, 53, 81, 491, 177, 1543, 1847, 7907, 7817, 15417, 9897, 101597, 160195, 0 };
            const std::uint32_t dim18638JoeKuoD6Init[]   =   { 1, 3, 1, 15, 19, 15, 91, 123, 365, 113, 129, 3371, 5789, 13553, 6887, 62317, 84269, 44777, 0 };
            const std::uint32_t dim18639JoeKuoD6Init[]   =   { 1, 3, 7, 13, 15, 63, 43, 175, 449, 437, 597, 1371, 5101, 13797, 28025, 15809, 7645, 21169, 0 };
            const std::uint32_t dim18640JoeKuoD6Init[]   =   { 1, 1, 7, 13, 23, 63, 105, 69, 219, 153, 1539, 1537, 6899, 9363, 27459, 34551, 62563, 236679, 0 };
            const std::uint32_t dim18641JoeKuoD6Init[]   =   { 1, 3, 7, 3, 9, 33, 3, 101, 135, 571, 127, 3881, 7017, 13403, 13817, 55167, 8645, 471, 0 };
            const std::uint32_t dim18642JoeKuoD6Init[]   =   { 1, 3, 3, 13, 7, 53, 29, 89, 473, 135, 639, 3137, 93, 965, 4867, 58265, 114963, 175295, 0 };
            const std::uint32_t dim18643JoeKuoD6Init[]   =   { 1, 3, 1, 1, 9, 11, 45, 123, 129, 441, 1601, 39, 4657, 3701, 29581, 16045, 57173, 75195, 0 };
            const std::uint32_t dim18644JoeKuoD6Init[]   =   { 1, 1, 3, 11, 7, 21, 9, 73, 25, 891, 1625, 3019, 223, 14351, 30621, 3075, 79051, 178127, 0 };
            const std::uint32_t dim18645JoeKuoD6Init[]   =   { 1, 1, 7, 3, 7, 43, 69, 209, 9, 857, 1539, 2629, 5277, 14583, 16443, 28275, 54143, 206479, 0 };
            const std::uint32_t dim18646JoeKuoD6Init[]   =   { 1, 3, 5, 9, 27, 15, 109, 237, 323, 103, 837, 597, 3609, 6249, 795, 37191, 20997, 142079, 0 };
            const std::uint32_t dim18647JoeKuoD6Init[]   =   { 1, 1, 3, 1, 27, 33, 123, 191, 55, 531, 1707, 2633, 6717, 9645, 21377, 51593, 9017, 178185, 0 };
            const std::uint32_t dim18648JoeKuoD6Init[]   =   { 1, 1, 5, 15, 3, 3, 67, 225, 229, 161, 2039, 1499, 873, 8803, 29901, 58809, 35625, 207797, 0 };
            const std::uint32_t dim18649JoeKuoD6Init[]   =   { 1, 3, 3, 7, 3, 47, 99, 237, 221, 31, 1043, 1081, 837, 1617, 17323, 43879, 55615, 238537, 0 };
            const std::uint32_t dim18650JoeKuoD6Init[]   =   { 1, 3, 7, 1, 17, 37, 45, 211, 245, 657, 221, 1067, 1683, 16127, 585, 9067, 25935, 162469, 0 };
            const std::uint32_t dim18651JoeKuoD6Init[]   =   { 1, 1, 5, 9, 23, 27, 5, 237, 137, 227, 129, 279, 4171, 5963, 349, 12387, 40701, 177255, 0 };
            const std::uint32_t dim18652JoeKuoD6Init[]   =   { 1, 3, 7, 15, 17, 11, 95, 69, 49, 901, 509, 2541, 3001, 15501, 24235, 39863, 95381, 260793, 0 };
            const std::uint32_t dim18653JoeKuoD6Init[]   =   { 1, 3, 3, 3, 29, 3, 125, 3, 423, 609, 1401, 2337, 1093, 11419, 29735, 9033, 115977, 210201, 0 };
            const std::uint32_t dim18654JoeKuoD6Init[]   =   { 1, 1, 1, 9, 11, 21, 71, 33, 399, 1005, 1691, 1501, 2585, 7361, 21527, 7535, 87091, 192319, 0 };
            const std::uint32_t dim18655JoeKuoD6Init[]   =   { 1, 1, 1, 11, 5, 49, 65, 115, 239, 255, 381, 2803, 3447, 5775, 18243, 16545, 108901, 81355, 0 };
            const std::uint32_t dim18656JoeKuoD6Init[]   =   { 1, 3, 7, 15, 31, 5, 81, 213, 281, 903, 189, 1807, 3551, 4423, 3591, 27449, 71659, 255357, 0 };
            const std::uint32_t dim18657JoeKuoD6Init[]   =   { 1, 1, 1, 15, 11, 1, 25, 213, 259, 215, 435, 3531, 4889, 9509, 21391, 21589, 89871, 85895, 0 };
            const std::uint32_t dim18658JoeKuoD6Init[]   =   { 1, 3, 3, 9, 29, 29, 37, 127, 419, 631, 1793, 1547, 1463, 13265, 17233, 24627, 3687, 174179, 0 };
            const std::uint32_t dim18659JoeKuoD6Init[]   =   { 1, 1, 1, 7, 27, 61, 105, 135, 439, 161, 721, 2779, 6731, 14575, 4565, 25869, 38981, 191683, 0 };
            const std::uint32_t dim18660JoeKuoD6Init[]   =   { 1, 1, 7, 13, 21, 41, 43, 5, 313, 407, 505, 231, 5023, 8971, 15825, 38461, 38797, 136027, 0 };
            const std::uint32_t dim18661JoeKuoD6Init[]   =   { 1, 3, 7, 3, 7, 59, 11, 255, 327, 843, 1179, 889, 4505, 10891, 7901, 14485, 72297, 255985, 0 };
            const std::uint32_t dim18662JoeKuoD6Init[]   =   { 1, 1, 5, 3, 9, 37, 89, 59, 413, 51, 515, 4009, 6501, 8443, 14381, 60917, 43567, 234431, 0 };
            const std::uint32_t dim18663JoeKuoD6Init[]   =   { 1, 1, 3, 9, 9, 57, 65, 205, 367, 935, 1975, 2561, 225, 12529, 4721, 56659, 87901, 219641, 0 };
            const std::uint32_t dim18664JoeKuoD6Init[]   =   { 1, 3, 7, 15, 23, 55, 61, 15, 89, 267, 1245, 2703, 7471, 10499, 19, 19357, 72413, 199289, 0 };
            const std::uint32_t dim18665JoeKuoD6Init[]   =   { 1, 1, 1, 13, 1, 29, 65, 11, 353, 509, 1831, 2181, 5265, 14761, 913, 17109, 113613, 37143, 0 };
            const std::uint32_t dim18666JoeKuoD6Init[]   =   { 1, 1, 7, 5, 17, 37, 97, 249, 169, 223, 475, 2091, 3101, 8541, 325, 42359, 16121, 151739, 0 };
            const std::uint32_t dim18667JoeKuoD6Init[]   =   { 1, 1, 3, 13, 1, 45, 13, 209, 395, 215, 15, 2287, 5365, 9887, 29799, 51957, 97483, 109467, 0 };
            const std::uint32_t dim18668JoeKuoD6Init[]   =   { 1, 3, 7, 1, 9, 35, 91, 51, 387, 833, 783, 2483, 3743, 6155, 5881, 3047, 86191, 151867, 0 };
            const std::uint32_t dim18669JoeKuoD6Init[]   =   { 1, 1, 1, 7, 15, 25, 13, 3, 119, 333, 761, 3459, 2555, 15737, 12945, 15225, 45487, 78235, 0 };
            const std::uint32_t dim18670JoeKuoD6Init[]   =   { 1, 3, 1, 3, 13, 55, 111, 45, 121, 593, 633, 2705, 1653, 13275, 13533, 3559, 100573, 124363, 0 };
            const std::uint32_t dim18671JoeKuoD6Init[]   =   { 1, 1, 3, 1, 29, 49, 65, 69, 133, 667, 653, 2559, 6335, 8019, 9251, 5415, 90125, 197413, 0 };
            const std::uint32_t dim18672JoeKuoD6Init[]   =   { 1, 1, 1, 7, 23, 53, 99, 149, 39, 453, 129, 185, 1143, 12799, 23339, 41293, 94023, 105581, 0 };
            const std::uint32_t dim18673JoeKuoD6Init[]   =   { 1, 3, 3, 13, 5, 3, 5, 215, 425, 455, 421, 3815, 5983, 3851, 19569, 17363, 6411, 60037, 0 };
            const std::uint32_t dim18674JoeKuoD6Init[]   =   { 1, 3, 7, 1, 29, 7, 63, 207, 299, 17, 1915, 2041, 8129, 661, 32481, 55475, 72027, 239683, 0 };
            const std::uint32_t dim18675JoeKuoD6Init[]   =   { 1, 1, 5, 13, 29, 11, 39, 177, 177, 479, 1291, 3931, 4353, 327, 7827, 9529, 6967, 6469, 0 };
            const std::uint32_t dim18676JoeKuoD6Init[]   =   { 1, 1, 5, 3, 25, 39, 121, 15, 7, 715, 583, 3997, 1373, 7747, 1777, 7269, 105333, 201511, 0 };
            const std::uint32_t dim18677JoeKuoD6Init[]   =   { 1, 3, 3, 9, 11, 7, 81, 109, 129, 359, 1281, 1163, 4895, 10303, 17801, 43461, 120271, 173027, 0 };
            const std::uint32_t dim18678JoeKuoD6Init[]   =   { 1, 3, 5, 1, 23, 59, 123, 75, 505, 925, 637, 1713, 995, 14031, 13711, 62569, 90553, 242345, 0 };
            const std::uint32_t dim18679JoeKuoD6Init[]   =   { 1, 3, 3, 15, 19, 11, 39, 203, 229, 619, 735, 1367, 4963, 5263, 30229, 17847, 9623, 3277, 0 };
            const std::uint32_t dim18680JoeKuoD6Init[]   =   { 1, 1, 7, 13, 5, 27, 23, 223, 377, 335, 1821, 2481, 4111, 10373, 18423, 7237, 75225, 223433, 0 };
            const std::uint32_t dim18681JoeKuoD6Init[]   =   { 1, 3, 7, 1, 21, 19, 71, 107, 19, 703, 945, 3831, 1099, 6267, 17489, 27665, 8861, 127499, 0 };
            const std::uint32_t dim18682JoeKuoD6Init[]   =   { 1, 3, 5, 1, 19, 49, 117, 181, 245, 939, 1279, 3127, 4427, 3061, 23399, 64805, 43077, 100789, 0 };
            const std::uint32_t dim18683JoeKuoD6Init[]   =   { 1, 1, 3, 3, 31, 55, 53, 205, 97, 645, 215, 2617, 7419, 7159, 27373, 62341, 58121, 248677, 0 };
            const std::uint32_t dim18684JoeKuoD6Init[]   =   { 1, 1, 7, 5, 15, 41, 99, 75, 201, 187, 197, 3773, 3097, 6803, 5307, 31375, 26743, 142723, 0 };
            const std::uint32_t dim18685JoeKuoD6Init[]   =   { 1, 3, 5, 11, 23, 61, 127, 15, 89, 245, 1345, 1305, 5937, 15917, 23867, 50319, 91921, 248663, 0 };
            const std::uint32_t dim18686JoeKuoD6Init[]   =   { 1, 1, 3, 9, 27, 7, 1, 75, 181, 155, 1947, 577, 2975, 8855, 5295, 43403, 112497, 100679, 0 };
            const std::uint32_t dim18687JoeKuoD6Init[]   =   { 1, 1, 1, 11, 29, 61, 35, 241, 207, 73, 1747, 1797, 3665, 14275, 25359, 28685, 79367, 81819, 0 };
            const std::uint32_t dim18688JoeKuoD6Init[]   =   { 1, 3, 5, 9, 11, 1, 37, 79, 431, 157, 1979, 159, 3087, 1731, 26141, 31411, 56457, 94293, 0 };
            const std::uint32_t dim18689JoeKuoD6Init[]   =   { 1, 3, 7, 1, 17, 35, 107, 243, 279, 79, 227, 1275, 761, 11485, 22181, 16415, 68801, 4577, 0 };
            const std::uint32_t dim18690JoeKuoD6Init[]   =   { 1, 3, 1, 9, 21, 43, 115, 131, 129, 123, 1677, 1875, 7355, 15927, 845, 24101, 48985, 39703, 0 };
            const std::uint32_t dim18691JoeKuoD6Init[]   =   { 1, 1, 7, 3, 17, 25, 105, 189, 317, 109, 1629, 3103, 615, 1047, 621, 62743, 43631, 9811, 0 };
            const std::uint32_t dim18692JoeKuoD6Init[]   =   { 1, 3, 1, 3, 3, 45, 49, 73, 383, 761, 685, 3211, 3855, 16307, 30469, 1393, 52535, 165503, 0 };
            const std::uint32_t dim18693JoeKuoD6Init[]   =   { 1, 3, 5, 15, 1, 41, 89, 105, 213, 33, 1477, 711, 4823, 503, 12533, 56781, 42825, 223399, 0 };
            const std::uint32_t dim18694JoeKuoD6Init[]   =   { 1, 3, 5, 9, 17, 45, 63, 113, 359, 927, 1467, 2811, 4275, 5193, 6023, 32689, 87747, 234697, 0 };
            const std::uint32_t dim18695JoeKuoD6Init[]   =   { 1, 1, 3, 1, 21, 49, 73, 157, 97, 915, 1689, 3289, 7515, 10759, 32253, 63175, 66175, 125813, 0 };
            const std::uint32_t dim18696JoeKuoD6Init[]   =   { 1, 1, 1, 5, 19, 1, 127, 229, 453, 617, 511, 1515, 3815, 3125, 26851, 31635, 35389, 237483, 0 };
            const std::uint32_t dim18697JoeKuoD6Init[]   =   { 1, 1, 1, 13, 27, 61, 75, 23, 289, 133, 975, 3217, 3777, 12095, 15235, 33845, 125503, 88417, 0 };
            const std::uint32_t dim18698JoeKuoD6Init[]   =   { 1, 1, 3, 13, 27, 49, 29, 115, 221, 995, 1305, 2717, 2243, 13391, 20841, 863, 63195, 46829, 0 };
            const std::uint32_t dim18699JoeKuoD6Init[]   =   { 1, 3, 1, 11, 31, 49, 43, 163, 503, 123, 657, 1285, 3695, 8401, 17087, 48289, 3947, 41495, 0 };
            const std::uint32_t dim18700JoeKuoD6Init[]   =   { 1, 3, 7, 9, 21, 17, 125, 75, 395, 979, 781, 2501, 6511, 4619, 28943, 18295, 87547, 196289, 0 };
            const std::uint32_t dim18701JoeKuoD6Init[]   =   { 1, 3, 3, 5, 3, 39, 107, 199, 7, 331, 77, 511, 5787, 3155, 29605, 44633, 51041, 89141, 0 };
            const std::uint32_t dim18702JoeKuoD6Init[]   =   { 1, 1, 3, 7, 11, 37, 79, 69, 181, 623, 299, 2321, 4371, 7449, 3137, 25753, 116673, 30441, 0 };
            const std::uint32_t dim18703JoeKuoD6Init[]   =   { 1, 1, 5, 9, 11, 13, 49, 207, 179, 671, 1469, 1005, 6887, 12203, 9365, 62455, 36283, 42053, 0 };
            const std::uint32_t dim18704JoeKuoD6Init[]   =   { 1, 3, 1, 1, 7, 31, 115, 79, 435, 101, 1525, 3695, 3229, 11401, 23959, 62055, 37725, 219753, 0 };
            const std::uint32_t dim18705JoeKuoD6Init[]   =   { 1, 3, 3, 7, 25, 49, 123, 161, 275, 291, 255, 2247, 4271, 10771, 2449, 26343, 61169, 30691, 0 };
            const std::uint32_t dim18706JoeKuoD6Init[]   =   { 1, 1, 7, 1, 15, 3, 11, 15, 125, 1021, 1817, 417, 2721, 13985, 19039, 451, 32559, 199407, 0 };
            const std::uint32_t dim18707JoeKuoD6Init[]   =   { 1, 1, 5, 15, 11, 25, 23, 101, 427, 431, 1353, 1957, 3529, 513, 11937, 14469, 89539, 242015, 0 };
            const std::uint32_t dim18708JoeKuoD6Init[]   =   { 1, 1, 5, 13, 27, 5, 107, 29, 469, 3, 1427, 1949, 7007, 16339, 3375, 63545, 100739, 229487, 0 };
            const std::uint32_t dim18709JoeKuoD6Init[]   =   { 1, 3, 5, 13, 15, 17, 59, 213, 417, 557, 11, 811, 5041, 4133, 25735, 46807, 65669, 148081, 0 };
            const std::uint32_t dim18710JoeKuoD6Init[]   =   { 1, 1, 5, 13, 9, 47, 35, 173, 277, 805, 1249, 3707, 1079, 2833, 29383, 58995, 21005, 181567, 0 };
            const std::uint32_t dim18711JoeKuoD6Init[]   =   { 1, 3, 5, 1, 5, 25, 125, 45, 157, 291, 1329, 3317, 2311, 9919, 31001, 65127, 19451, 117621, 0 };
            const std::uint32_t dim18712JoeKuoD6Init[]   =   { 1, 1, 5, 9, 31, 21, 9, 193, 23, 879, 699, 1135, 7151, 8635, 20711, 45207, 67047, 4397, 0 };
            const std::uint32_t dim18713JoeKuoD6Init[]   =   { 1, 3, 1, 11, 11, 49, 119, 129, 409, 491, 463, 833, 3661, 607, 25961, 6061, 12747, 160337, 0 };
            const std::uint32_t dim18714JoeKuoD6Init[]   =   { 1, 3, 1, 15, 31, 35, 93, 95, 239, 695, 1113, 2371, 2625, 10371, 10781, 46209, 67051, 109923, 0 };
            const std::uint32_t dim18715JoeKuoD6Init[]   =   { 1, 3, 5, 9, 5, 61, 25, 19, 99, 159, 55, 43, 3679, 1023, 17951, 44841, 101653, 195955, 0 };
            const std::uint32_t dim18716JoeKuoD6Init[]   =   { 1, 1, 3, 11, 19, 45, 99, 47, 407, 115, 353, 3537, 7147, 5837, 27309, 44539, 30227, 93183, 0 };
            const std::uint32_t dim18717JoeKuoD6Init[]   =   { 1, 1, 7, 15, 13, 59, 83, 215, 79, 865, 269, 2999, 2415, 10631, 23655, 51583, 46105, 43965, 0 };
            const std::uint32_t dim18718JoeKuoD6Init[]   =   { 1, 3, 7, 5, 17, 1, 7, 119, 501, 25, 1097, 3639, 7017, 381, 4793, 37263, 60431, 77323, 0 };
            const std::uint32_t dim18719JoeKuoD6Init[]   =   { 1, 3, 7, 13, 1, 37, 99, 103, 459, 853, 5, 3093, 6167, 14497, 7003, 36979, 71919, 64823, 0 };
            const std::uint32_t dim18720JoeKuoD6Init[]   =   { 1, 3, 7, 5, 23, 7, 37, 255, 297, 115, 113, 579, 4561, 5245, 11173, 28645, 23989, 240777, 0 };
            const std::uint32_t dim18721JoeKuoD6Init[]   =   { 1, 3, 5, 9, 29, 47, 43, 145, 481, 251, 737, 2531, 2425, 529, 3953, 13229, 35933, 187855, 0 };
            const std::uint32_t dim18722JoeKuoD6Init[]   =   { 1, 3, 1, 15, 15, 15, 29, 73, 405, 91, 1399, 3599, 1517, 11075, 11265, 22817, 26619, 1183, 0 };
            const std::uint32_t dim18723JoeKuoD6Init[]   =   { 1, 1, 5, 15, 21, 47, 93, 33, 47, 527, 877, 3453, 3867, 4007, 32503, 11789, 68333, 187419, 0 };
            const std::uint32_t dim18724JoeKuoD6Init[]   =   { 1, 1, 3, 13, 5, 3, 99, 21, 17, 779, 541, 3919, 1339, 13507, 28965, 61145, 50421, 192319, 0 };
            const std::uint32_t dim18725JoeKuoD6Init[]   =   { 1, 1, 3, 7, 31, 63, 17, 9, 331, 681, 515, 1067, 351, 2471, 31271, 36015, 72911, 32383, 0 };
            const std::uint32_t dim18726JoeKuoD6Init[]   =   { 1, 1, 3, 7, 1, 55, 97, 211, 409, 499, 1207, 2405, 2291, 1373, 1263, 65303, 38655, 159965, 0 };
            const std::uint32_t dim18727JoeKuoD6Init[]   =   { 1, 1, 1, 5, 23, 11, 21, 23, 35, 19, 1699, 2325, 6117, 14971, 32327, 31369, 28061, 112819, 0 };
            const std::uint32_t dim18728JoeKuoD6Init[]   =   { 1, 3, 3, 13, 29, 63, 19, 201, 173, 395, 1437, 369, 7045, 14347, 5393, 11311, 28415, 161019, 0 };
            const std::uint32_t dim18729JoeKuoD6Init[]   =   { 1, 3, 1, 5, 31, 15, 101, 13, 97, 865, 1063, 2129, 811, 3337, 7585, 54803, 122099, 149531, 0 };
            const std::uint32_t dim18730JoeKuoD6Init[]   =   { 1, 3, 3, 13, 19, 5, 47, 13, 497, 683, 1197, 3509, 4375, 3353, 31847, 283, 95281, 7975, 0 };
            const std::uint32_t dim18731JoeKuoD6Init[]   =   { 1, 1, 7, 5, 25, 19, 59, 105, 167, 775, 581, 2679, 3003, 9345, 20209, 31487, 25357, 226341, 0 };
            const std::uint32_t dim18732JoeKuoD6Init[]   =   { 1, 1, 5, 5, 31, 61, 13, 77, 189, 141, 1157, 609, 7245, 15303, 32743, 50229, 67391, 173977, 0 };
            const std::uint32_t dim18733JoeKuoD6Init[]   =   { 1, 3, 7, 13, 17, 11, 49, 135, 475, 303, 1373, 1437, 6119, 1729, 21347, 31643, 86523, 41223, 0 };
            const std::uint32_t dim18734JoeKuoD6Init[]   =   { 1, 3, 7, 13, 3, 19, 103, 53, 209, 281, 77, 2009, 7911, 8549, 17655, 33165, 9685, 2289, 0 };
            const std::uint32_t dim18735JoeKuoD6Init[]   =   { 1, 3, 3, 9, 5, 31, 71, 113, 93, 255, 165, 3465, 6769, 13047, 20701, 33669, 22537, 175209, 0 };
            const std::uint32_t dim18736JoeKuoD6Init[]   =   { 1, 3, 1, 1, 15, 59, 89, 227, 275, 451, 869, 1865, 1327, 3895, 5459, 47997, 34287, 95343, 0 };
            const std::uint32_t dim18737JoeKuoD6Init[]   =   { 1, 3, 7, 13, 27, 1, 25, 99, 475, 421, 693, 1955, 4017, 16037, 29915, 52415, 99913, 59151, 0 };
            const std::uint32_t dim18738JoeKuoD6Init[]   =   { 1, 3, 5, 1, 9, 61, 107, 149, 465, 1003, 891, 2387, 407, 5851, 6287, 56401, 109693, 72035, 0 };
            const std::uint32_t dim18739JoeKuoD6Init[]   =   { 1, 1, 1, 11, 25, 53, 101, 125, 35, 949, 1019, 3087, 2785, 11271, 25623, 57313, 115683, 101923, 0 };
            const std::uint32_t dim18740JoeKuoD6Init[]   =   { 1, 3, 5, 13, 19, 13, 97, 147, 149, 483, 1727, 1771, 2089, 8661, 28223, 30437, 42565, 13261, 0 };
            const std::uint32_t dim18741JoeKuoD6Init[]   =   { 1, 3, 3, 11, 17, 9, 13, 13, 419, 531, 1617, 1459, 411, 9953, 25581, 30305, 120721, 81113, 0 };
            const std::uint32_t dim18742JoeKuoD6Init[]   =   { 1, 3, 3, 9, 9, 9, 83, 35, 367, 981, 911, 1915, 4937, 16187, 20441, 30433, 107605, 119939, 0 };
            const std::uint32_t dim18743JoeKuoD6Init[]   =   { 1, 3, 7, 11, 11, 47, 31, 7, 141, 905, 1753, 3069, 47, 7347, 10517, 19515, 126827, 68669, 0 };
            const std::uint32_t dim18744JoeKuoD6Init[]   =   { 1, 3, 3, 9, 17, 33, 121, 159, 265, 389, 261, 2479, 7705, 6453, 31963, 14123, 100201, 77235, 0 };
            const std::uint32_t dim18745JoeKuoD6Init[]   =   { 1, 1, 5, 5, 13, 63, 3, 1, 107, 383, 633, 2183, 1437, 14525, 29315, 3277, 2153, 204061, 0 };
            const std::uint32_t dim18746JoeKuoD6Init[]   =   { 1, 3, 3, 3, 17, 9, 47, 173, 17, 413, 451, 1127, 1807, 5265, 32543, 8215, 123601, 138777, 0 };
            const std::uint32_t dim18747JoeKuoD6Init[]   =   { 1, 3, 1, 1, 7, 57, 93, 29, 101, 955, 1445, 4017, 2853, 3551, 22173, 40355, 34687, 133063, 0 };
            const std::uint32_t dim18748JoeKuoD6Init[]   =   { 1, 1, 5, 11, 19, 15, 95, 177, 49, 971, 15, 2293, 2627, 7841, 2103, 64331, 60481, 182431, 0 };
            const std::uint32_t dim18749JoeKuoD6Init[]   =   { 1, 3, 1, 15, 25, 57, 47, 85, 485, 11, 1669, 995, 6939, 4125, 19513, 62397, 62645, 82213, 0 };
            const std::uint32_t dim18750JoeKuoD6Init[]   =   { 1, 1, 1, 11, 1, 37, 101, 157, 17, 261, 997, 817, 2195, 4141, 10505, 60685, 98165, 167391, 0 };
            const std::uint32_t dim18751JoeKuoD6Init[]   =   { 1, 1, 1, 1, 31, 9, 103, 97, 161, 13, 1043, 307, 7321, 671, 12417, 58661, 23031, 207833, 0 };
            const std::uint32_t dim18752JoeKuoD6Init[]   =   { 1, 1, 7, 9, 15, 49, 69, 117, 93, 95, 507, 393, 6169, 2111, 27179, 47217, 93699, 67315, 0 };
            const std::uint32_t dim18753JoeKuoD6Init[]   =   { 1, 3, 7, 1, 23, 41, 115, 125, 343, 615, 397, 1199, 3041, 11019, 1071, 51069, 75757, 245765, 0 };
            const std::uint32_t dim18754JoeKuoD6Init[]   =   { 1, 1, 1, 13, 7, 15, 111, 239, 29, 419, 203, 2395, 3995, 13, 32341, 17471, 53259, 3317, 0 };
            const std::uint32_t dim18755JoeKuoD6Init[]   =   { 1, 3, 1, 11, 29, 27, 15, 217, 17, 163, 1847, 3549, 4911, 4539, 4927, 57157, 44893, 41669, 0 };
            const std::uint32_t dim18756JoeKuoD6Init[]   =   { 1, 1, 7, 7, 25, 15, 101, 149, 433, 717, 1827, 3837, 4565, 14521, 28857, 27775, 117429, 136131, 0 };
            const std::uint32_t dim18757JoeKuoD6Init[]   =   { 1, 1, 1, 3, 25, 35, 85, 3, 381, 253, 375, 3967, 3101, 12727, 31739, 48885, 35821, 92229, 0 };
            const std::uint32_t dim18758JoeKuoD6Init[]   =   { 1, 3, 3, 7, 29, 5, 51, 157, 67, 467, 1957, 3453, 1353, 4839, 25379, 42731, 109385, 52479, 0 };
            const std::uint32_t dim18759JoeKuoD6Init[]   =   { 1, 3, 7, 13, 3, 55, 61, 73, 257, 313, 89, 2557, 7467, 2223, 2951, 49265, 126605, 72007, 0 };
            const std::uint32_t dim18760JoeKuoD6Init[]   =   { 1, 3, 7, 5, 5, 11, 83, 3, 347, 63, 479, 529, 5059, 7029, 20523, 58387, 44891, 168921, 0 };
            const std::uint32_t dim18761JoeKuoD6Init[]   =   { 1, 3, 1, 11, 3, 51, 99, 5, 161, 279, 1509, 3659, 3107, 13925, 5117, 46153, 48731, 69767, 0 };
            const std::uint32_t dim18762JoeKuoD6Init[]   =   { 1, 1, 5, 5, 3, 53, 49, 243, 383, 401, 1205, 975, 3305, 12769, 25533, 28733, 115161, 160885, 0 };
            const std::uint32_t dim18763JoeKuoD6Init[]   =   { 1, 1, 1, 7, 15, 5, 43, 143, 493, 527, 1625, 2115, 3929, 12425, 16127, 25045, 55973, 202359, 0 };
            const std::uint32_t dim18764JoeKuoD6Init[]   =   { 1, 3, 7, 7, 11, 9, 69, 79, 417, 941, 473, 1655, 5763, 9889, 22443, 12153, 103489, 74737, 0 };
            const std::uint32_t dim18765JoeKuoD6Init[]   =   { 1, 1, 7, 9, 27, 31, 97, 253, 199, 99, 1955, 1481, 2509, 11923, 6337, 15899, 122515, 244721, 0 };
            const std::uint32_t dim18766JoeKuoD6Init[]   =   { 1, 1, 5, 13, 29, 15, 35, 177, 261, 613, 1279, 2837, 2945, 4501, 22865, 36893, 51979, 245569, 0 };
            const std::uint32_t dim18767JoeKuoD6Init[]   =   { 1, 1, 5, 9, 21, 5, 85, 5, 303, 165, 681, 3965, 2575, 1493, 10367, 55845, 92139, 92539, 0 };
            const std::uint32_t dim18768JoeKuoD6Init[]   =   { 1, 3, 5, 1, 23, 49, 49, 161, 481, 181, 1991, 1845, 4541, 14187, 10893, 64931, 79943, 57907, 0 };
            const std::uint32_t dim18769JoeKuoD6Init[]   =   { 1, 3, 1, 5, 11, 27, 19, 193, 371, 463, 1573, 271, 1127, 15091, 9967, 40337, 104163, 159339, 0 };
            const std::uint32_t dim18770JoeKuoD6Init[]   =   { 1, 3, 1, 3, 13, 3, 57, 149, 465, 789, 1155, 2223, 2007, 13987, 19057, 40447, 5217, 86191, 0 };
            const std::uint32_t dim18771JoeKuoD6Init[]   =   { 1, 3, 5, 5, 9, 45, 27, 155, 95, 171, 489, 2539, 843, 16125, 7047, 58541, 84641, 212013, 0 };
            const std::uint32_t dim18772JoeKuoD6Init[]   =   { 1, 3, 5, 13, 13, 53, 101, 159, 7, 481, 143, 3869, 6629, 3527, 1555, 6019, 155, 230157, 0 };
            const std::uint32_t dim18773JoeKuoD6Init[]   =   { 1, 3, 1, 1, 19, 59, 59, 129, 107, 887, 1595, 93, 6577, 3947, 14409, 31081, 68595, 226741, 0 };
            const std::uint32_t dim18774JoeKuoD6Init[]   =   { 1, 3, 3, 11, 13, 49, 81, 253, 363, 875, 489, 2181, 3487, 1615, 31157, 32949, 44809, 119421, 0 };
            const std::uint32_t dim18775JoeKuoD6Init[]   =   { 1, 1, 3, 1, 3, 19, 71, 93, 397, 521, 2015, 3829, 3013, 3941, 29437, 1959, 70283, 254361, 0 };
            const std::uint32_t dim18776JoeKuoD6Init[]   =   { 1, 3, 1, 3, 27, 11, 95, 39, 299, 521, 389, 3451, 3047, 8637, 22537, 11279, 67407, 101511, 0 };
            const std::uint32_t dim18777JoeKuoD6Init[]   =   { 1, 3, 1, 1, 27, 43, 123, 237, 315, 503, 1059, 2185, 3963, 1593, 19157, 13909, 58025, 91649, 0 };
            const std::uint32_t dim18778JoeKuoD6Init[]   =   { 1, 1, 7, 1, 5, 19, 79, 109, 459, 541, 521, 89, 389, 13499, 9769, 1429, 117357, 153261, 0 };
            const std::uint32_t dim18779JoeKuoD6Init[]   =   { 1, 1, 5, 3, 9, 29, 21, 97, 219, 915, 2013, 1955, 1015, 549, 9777, 5005, 110953, 16915, 0 };
            const std::uint32_t dim18780JoeKuoD6Init[]   =   { 1, 1, 1, 9, 29, 11, 103, 167, 465, 515, 843, 151, 769, 12033, 9451, 14949, 110075, 113947, 0 };
            const std::uint32_t dim18781JoeKuoD6Init[]   =   { 1, 3, 5, 1, 21, 1, 105, 49, 35, 737, 231, 2761, 1519, 9997, 601, 20883, 42575, 98081, 0 };
            const std::uint32_t dim18782JoeKuoD6Init[]   =   { 1, 1, 1, 5, 13, 63, 47, 171, 187, 407, 643, 1423, 6325, 10079, 23781, 36353, 20655, 10231, 0 };
            const std::uint32_t dim18783JoeKuoD6Init[]   =   { 1, 1, 7, 13, 13, 13, 91, 31, 19, 305, 505, 1937, 2683, 10791, 7719, 54797, 9405, 195819, 0 };
            const std::uint32_t dim18784JoeKuoD6Init[]   =   { 1, 1, 1, 7, 17, 9, 21, 211, 85, 851, 211, 1533, 4035, 11, 26873, 16755, 77809, 44603, 0 };
            const std::uint32_t dim18785JoeKuoD6Init[]   =   { 1, 1, 3, 1, 29, 47, 31, 141, 9, 881, 1229, 1261, 3747, 4603, 22177, 48937, 21435, 157029, 0 };
            const std::uint32_t dim18786JoeKuoD6Init[]   =   { 1, 1, 1, 9, 11, 35, 109, 187, 319, 863, 1339, 2193, 4147, 3721, 7243, 18295, 92461, 88875, 0 };
            const std::uint32_t dim18787JoeKuoD6Init[]   =   { 1, 1, 1, 1, 25, 41, 79, 191, 47, 819, 2013, 3133, 2763, 9231, 10343, 49693, 26753, 97465, 0 };
            const std::uint32_t dim18788JoeKuoD6Init[]   =   { 1, 3, 1, 3, 17, 25, 63, 139, 179, 113, 1681, 1997, 4561, 14453, 30721, 7053, 22937, 183303, 0 };
            const std::uint32_t dim18789JoeKuoD6Init[]   =   { 1, 1, 7, 3, 29, 11, 41, 157, 427, 887, 295, 443, 5593, 8633, 9757, 37595, 121655, 135739, 0 };
            const std::uint32_t dim18790JoeKuoD6Init[]   =   { 1, 3, 1, 7, 29, 5, 23, 231, 85, 67, 103, 1395, 7821, 9551, 17019, 1825, 69963, 254583, 0 };
            const std::uint32_t dim18791JoeKuoD6Init[]   =   { 1, 1, 7, 9, 7, 23, 7, 205, 17, 111, 1219, 3101, 7485, 11579, 11791, 10203, 119835, 175985, 0 };
            const std::uint32_t dim18792JoeKuoD6Init[]   =   { 1, 3, 3, 13, 3, 57, 101, 255, 331, 911, 491, 3929, 2519, 2185, 21107, 24599, 92831, 75001, 0 };
            const std::uint32_t dim18793JoeKuoD6Init[]   =   { 1, 3, 7, 1, 23, 53, 69, 229, 295, 881, 905, 3727, 3885, 7967, 2061, 53595, 16033, 36443, 0 };
            const std::uint32_t dim18794JoeKuoD6Init[]   =   { 1, 1, 7, 15, 21, 1, 127, 115, 191, 53, 929, 1093, 5447, 1665, 4409, 22611, 38157, 139201, 0 };
            const std::uint32_t dim18795JoeKuoD6Init[]   =   { 1, 3, 3, 13, 29, 31, 113, 215, 365, 41, 1977, 2839, 4147, 8321, 1361, 45717, 80505, 176631, 0 };
            const std::uint32_t dim18796JoeKuoD6Init[]   =   { 1, 3, 5, 3, 3, 57, 25, 81, 41, 229, 669, 3371, 7505, 1197, 14921, 34365, 67571, 27355, 0 };
            const std::uint32_t dim18797JoeKuoD6Init[]   =   { 1, 3, 7, 9, 17, 35, 7, 169, 13, 163, 2007, 3697, 5635, 8003, 26105, 62917, 19349, 47029, 0 };
            const std::uint32_t dim18798JoeKuoD6Init[]   =   { 1, 1, 5, 5, 29, 27, 89, 137, 69, 189, 871, 3139, 6383, 14955, 15349, 60447, 122291, 26541, 0 };
            const std::uint32_t dim18799JoeKuoD6Init[]   =   { 1, 1, 7, 13, 27, 49, 115, 111, 441, 865, 1397, 161, 755, 14461, 8601, 45533, 105309, 149799, 0 };
            const std::uint32_t dim18800JoeKuoD6Init[]   =   { 1, 1, 7, 3, 9, 29, 91, 5, 239, 605, 491, 1705, 4099, 9111, 19821, 56903, 62815, 40615, 0 };
            const std::uint32_t dim18801JoeKuoD6Init[]   =   { 1, 1, 7, 15, 5, 45, 71, 225, 211, 539, 1881, 1201, 5675, 6061, 12121, 13289, 30455, 33131, 0 };
            const std::uint32_t dim18802JoeKuoD6Init[]   =   { 1, 1, 5, 15, 5, 59, 35, 121, 185, 143, 165, 2999, 7907, 5035, 8337, 11951, 66403, 219997, 0 };
            const std::uint32_t dim18803JoeKuoD6Init[]   =   { 1, 1, 5, 9, 3, 7, 27, 129, 245, 93, 715, 1249, 1717, 13381, 31255, 23153, 22227, 8077, 0 };
            const std::uint32_t dim18804JoeKuoD6Init[]   =   { 1, 3, 5, 11, 19, 49, 21, 163, 157, 615, 1475, 2453, 6315, 12325, 26565, 58399, 49385, 252127, 0 };
            const std::uint32_t dim18805JoeKuoD6Init[]   =   { 1, 3, 7, 11, 23, 3, 35, 61, 409, 795, 1447, 3461, 535, 6533, 25757, 31783, 9509, 217589, 0 };
            const std::uint32_t dim18806JoeKuoD6Init[]   =   { 1, 1, 5, 15, 9, 21, 67, 65, 399, 515, 777, 3183, 1155, 16071, 7339, 59985, 56659, 200701, 0 };
            const std::uint32_t dim18807JoeKuoD6Init[]   =   { 1, 3, 3, 1, 15, 33, 119, 145, 71, 517, 1775, 163, 5307, 1549, 31071, 56289, 128395, 230381, 0 };
            const std::uint32_t dim18808JoeKuoD6Init[]   =   { 1, 3, 1, 7, 7, 47, 97, 187, 193, 887, 515, 1301, 4841, 12069, 413, 41503, 36421, 45909, 0 };
            const std::uint32_t dim18809JoeKuoD6Init[]   =   { 1, 1, 5, 3, 17, 21, 53, 227, 137, 865, 715, 3601, 5027, 2983, 24113, 23349, 106391, 188193, 0 };
            const std::uint32_t dim18810JoeKuoD6Init[]   =   { 1, 3, 7, 15, 29, 37, 91, 235, 351, 15, 425, 681, 187, 1517, 30079, 41347, 49691, 66369, 0 };
            const std::uint32_t dim18811JoeKuoD6Init[]   =   { 1, 1, 5, 5, 15, 25, 93, 245, 397, 517, 1635, 2475, 5543, 9597, 27721, 21475, 79571, 259011, 0 };
            const std::uint32_t dim18812JoeKuoD6Init[]   =   { 1, 1, 1, 5, 21, 29, 5, 161, 37, 409, 1661, 3371, 5663, 4317, 9951, 23605, 7393, 90593, 0 };
            const std::uint32_t dim18813JoeKuoD6Init[]   =   { 1, 1, 3, 15, 21, 51, 79, 159, 209, 891, 1391, 2895, 5003, 6601, 17983, 42359, 104497, 162181, 0 };
            const std::uint32_t dim18814JoeKuoD6Init[]   =   { 1, 3, 7, 11, 23, 51, 99, 145, 21, 345, 1389, 1035, 5939, 8293, 22765, 23331, 7789, 115149, 0 };
            const std::uint32_t dim18815JoeKuoD6Init[]   =   { 1, 1, 5, 11, 27, 61, 115, 123, 317, 607, 463, 779, 5121, 3861, 18761, 39407, 125837, 244163, 0 };
            const std::uint32_t dim18816JoeKuoD6Init[]   =   { 1, 1, 7, 3, 15, 9, 33, 1, 437, 621, 31, 147, 8157, 3451, 18223, 61187, 125297, 211225, 0 };
            const std::uint32_t dim18817JoeKuoD6Init[]   =   { 1, 3, 1, 11, 27, 55, 21, 251, 5, 57, 1889, 71, 3745, 499, 9043, 62683, 21945, 138615, 0 };
            const std::uint32_t dim18818JoeKuoD6Init[]   =   { 1, 1, 3, 13, 25, 9, 1, 31, 277, 373, 507, 301, 2341, 1741, 11997, 47661, 44121, 183151, 0 };
            const std::uint32_t dim18819JoeKuoD6Init[]   =   { 1, 3, 3, 5, 15, 51, 5, 233, 475, 397, 1833, 1267, 7025, 2593, 15425, 47053, 16205, 208007, 0 };
            const std::uint32_t dim18820JoeKuoD6Init[]   =   { 1, 3, 3, 9, 31, 51, 123, 219, 493, 789, 659, 985, 7283, 11545, 15383, 25173, 130423, 196619, 0 };
            const std::uint32_t dim18821JoeKuoD6Init[]   =   { 1, 1, 1, 15, 9, 17, 37, 145, 297, 933, 1019, 1699, 2149, 12391, 17003, 42157, 126283, 252231, 0 };
            const std::uint32_t dim18822JoeKuoD6Init[]   =   { 1, 3, 5, 9, 17, 1, 91, 69, 335, 857, 925, 3855, 2225, 6909, 19101, 12191, 92117, 229077, 0 };
            const std::uint32_t dim18823JoeKuoD6Init[]   =   { 1, 3, 5, 13, 5, 21, 67, 17, 307, 879, 1563, 3169, 745, 6799, 27237, 39621, 1413, 146295, 0 };
            const std::uint32_t dim18824JoeKuoD6Init[]   =   { 1, 3, 7, 13, 17, 59, 23, 253, 415, 761, 451, 2773, 3523, 10985, 29853, 7275, 79521, 133447, 0 };
            const std::uint32_t dim18825JoeKuoD6Init[]   =   { 1, 1, 1, 1, 15, 43, 89, 19, 85, 837, 1335, 1641, 105, 5429, 8317, 45555, 104447, 102313, 0 };
            const std::uint32_t dim18826JoeKuoD6Init[]   =   { 1, 3, 3, 5, 17, 21, 67, 235, 367, 265, 1069, 835, 5457, 177, 26987, 39477, 6895, 123283, 0 };
            const std::uint32_t dim18827JoeKuoD6Init[]   =   { 1, 1, 5, 15, 19, 61, 5, 15, 487, 291, 661, 825, 1569, 8795, 13035, 57077, 112847, 160267, 0 };
            const std::uint32_t dim18828JoeKuoD6Init[]   =   { 1, 1, 7, 9, 27, 21, 91, 133, 361, 7, 447, 3035, 3523, 13167, 15927, 35555, 35713, 91291, 0 };
            const std::uint32_t dim18829JoeKuoD6Init[]   =   { 1, 3, 7, 11, 17, 23, 77, 255, 437, 897, 1185, 1633, 6451, 13081, 29097, 61335, 39671, 177835, 0 };
            const std::uint32_t dim18830JoeKuoD6Init[]   =   { 1, 1, 7, 5, 31, 49, 81, 221, 167, 241, 1895, 1813, 1493, 2475, 379, 5685, 116341, 121823, 0 };
            const std::uint32_t dim18831JoeKuoD6Init[]   =   { 1, 3, 5, 9, 25, 11, 117, 253, 337, 381, 743, 69, 1641, 3649, 26335, 59683, 28729, 83449, 0 };
            const std::uint32_t dim18832JoeKuoD6Init[]   =   { 1, 3, 1, 7, 15, 17, 59, 9, 129, 233, 1905, 1371, 6521, 8953, 26173, 9707, 70817, 260035, 0 };
            const std::uint32_t dim18833JoeKuoD6Init[]   =   { 1, 3, 1, 5, 19, 53, 23, 255, 305, 835, 1387, 2947, 3013, 9117, 27571, 47123, 49881, 47229, 0 };
            const std::uint32_t dim18834JoeKuoD6Init[]   =   { 1, 1, 3, 5, 23, 37, 123, 193, 365, 49, 1211, 3083, 8133, 14205, 11361, 55945, 23225, 159109, 0 };
            const std::uint32_t dim18835JoeKuoD6Init[]   =   { 1, 1, 7, 11, 5, 49, 43, 165, 97, 581, 617, 3045, 6187, 8399, 24045, 46713, 28389, 156811, 0 };
            const std::uint32_t dim18836JoeKuoD6Init[]   =   { 1, 3, 1, 5, 29, 17, 75, 231, 59, 143, 2041, 2319, 2289, 11805, 4039, 29895, 91305, 179091, 0 };
            const std::uint32_t dim18837JoeKuoD6Init[]   =   { 1, 1, 7, 7, 29, 5, 13, 43, 409, 81, 751, 2157, 2543, 13317, 28275, 60871, 119833, 36743, 0 };
            const std::uint32_t dim18838JoeKuoD6Init[]   =   { 1, 1, 5, 13, 5, 5, 21, 101, 497, 993, 157, 647, 3587, 1495, 20233, 30889, 112579, 172009, 0 };
            const std::uint32_t dim18839JoeKuoD6Init[]   =   { 1, 1, 7, 13, 7, 19, 101, 217, 305, 897, 1305, 1693, 6881, 2415, 17373, 56327, 53971, 19021, 0 };
            const std::uint32_t dim18840JoeKuoD6Init[]   =   { 1, 1, 7, 15, 31, 61, 93, 99, 459, 999, 239, 969, 2427, 12295, 23699, 4839, 73707, 110365, 0 };
            const std::uint32_t dim18841JoeKuoD6Init[]   =   { 1, 3, 5, 9, 15, 59, 29, 35, 15, 331, 93, 529, 2651, 5675, 3039, 25967, 2907, 222053, 0 };
            const std::uint32_t dim18842JoeKuoD6Init[]   =   { 1, 3, 3, 1, 1, 17, 59, 81, 495, 917, 1907, 3, 1989, 14339, 21311, 60909, 39393, 54115, 0 };
            const std::uint32_t dim18843JoeKuoD6Init[]   =   { 1, 3, 1, 9, 1, 37, 31, 201, 251, 117, 1753, 2453, 5007, 6935, 1165, 49231, 51495, 200219, 0 };
            const std::uint32_t dim18844JoeKuoD6Init[]   =   { 1, 1, 3, 3, 15, 47, 17, 175, 77, 363, 1455, 1417, 1357, 2295, 31165, 53337, 97891, 145621, 0 };
            const std::uint32_t dim18845JoeKuoD6Init[]   =   { 1, 3, 3, 3, 27, 31, 41, 179, 47, 629, 5, 2543, 6817, 8953, 7151, 20715, 52363, 251037, 0 };
            const std::uint32_t dim18846JoeKuoD6Init[]   =   { 1, 3, 1, 1, 21, 11, 103, 87, 285, 189, 1911, 2979, 7563, 13405, 2309, 25695, 106277, 179493, 0 };
            const std::uint32_t dim18847JoeKuoD6Init[]   =   { 1, 1, 1, 5, 7, 19, 1, 233, 261, 825, 1071, 3529, 5617, 11207, 24559, 47461, 79753, 41009, 0 };
            const std::uint32_t dim18848JoeKuoD6Init[]   =   { 1, 1, 3, 1, 15, 35, 65, 157, 381, 509, 1455, 3117, 31, 2251, 29729, 33687, 74999, 214765, 0 };
            const std::uint32_t dim18849JoeKuoD6Init[]   =   { 1, 1, 7, 11, 31, 43, 11, 147, 509, 891, 1929, 357, 3905, 16251, 30169, 27787, 124003, 142587, 0 };
            const std::uint32_t dim18850JoeKuoD6Init[]   =   { 1, 1, 7, 11, 3, 31, 93, 161, 311, 377, 1119, 2177, 4339, 3889, 24299, 35167, 87583, 145611, 0 };
            const std::uint32_t dim18851JoeKuoD6Init[]   =   { 1, 1, 5, 9, 23, 9, 73, 85, 233, 919, 1319, 13, 3353, 1029, 31251, 17731, 86759, 11705, 0 };
            const std::uint32_t dim18852JoeKuoD6Init[]   =   { 1, 1, 1, 7, 27, 23, 67, 235, 207, 161, 697, 2433, 833, 5305, 32695, 29327, 25285, 51289, 0 };
            const std::uint32_t dim18853JoeKuoD6Init[]   =   { 1, 3, 3, 3, 31, 55, 107, 211, 61, 993, 1443, 463, 5029, 5401, 8821, 29721, 113939, 194839, 0 };
            const std::uint32_t dim18854JoeKuoD6Init[]   =   { 1, 1, 1, 11, 11, 33, 39, 167, 17, 863, 363, 3967, 2277, 4053, 15403, 31887, 98565, 217953, 0 };
            const std::uint32_t dim18855JoeKuoD6Init[]   =   { 1, 1, 7, 1, 21, 47, 97, 147, 155, 327, 1417, 3531, 7649, 8975, 21221, 57631, 72611, 97745, 0 };
            const std::uint32_t dim18856JoeKuoD6Init[]   =   { 1, 3, 3, 1, 1, 63, 19, 91, 105, 991, 819, 673, 7845, 14947, 1633, 40517, 91525, 151041, 0 };
            const std::uint32_t dim18857JoeKuoD6Init[]   =   { 1, 1, 7, 11, 25, 43, 57, 141, 65, 415, 1045, 3947, 7099, 11653, 29321, 51591, 2591, 44803, 0 };
            const std::uint32_t dim18858JoeKuoD6Init[]   =   { 1, 3, 1, 9, 15, 19, 105, 37, 485, 3, 213, 1217, 951, 5637, 1589, 25501, 95073, 124683, 0 };
            const std::uint32_t dim18859JoeKuoD6Init[]   =   { 1, 1, 5, 7, 13, 19, 55, 143, 507, 575, 715, 1633, 5201, 10493, 26041, 18407, 8097, 152313, 0 };
            const std::uint32_t dim18860JoeKuoD6Init[]   =   { 1, 1, 3, 5, 9, 51, 5, 171, 143, 877, 1571, 2997, 4209, 13423, 9389, 23015, 6665, 254799, 0 };
            const std::uint32_t dim18861JoeKuoD6Init[]   =   { 1, 3, 5, 15, 31, 43, 87, 79, 89, 463, 1075, 1257, 1631, 13225, 13529, 53267, 73651, 89125, 0 };
            const std::uint32_t dim18862JoeKuoD6Init[]   =   { 1, 3, 7, 13, 23, 17, 93, 113, 45, 225, 1939, 3301, 6031, 9749, 16577, 12857, 68437, 169861, 0 };
            const std::uint32_t dim18863JoeKuoD6Init[]   =   { 1, 3, 3, 15, 31, 11, 91, 127, 227, 813, 105, 901, 6861, 10627, 18425, 2553, 102503, 83167, 0 };
            const std::uint32_t dim18864JoeKuoD6Init[]   =   { 1, 3, 3, 13, 17, 63, 83, 163, 451, 659, 1995, 2283, 6297, 8097, 20935, 6017, 4977, 5045, 0 };
            const std::uint32_t dim18865JoeKuoD6Init[]   =   { 1, 1, 5, 13, 27, 47, 103, 129, 259, 975, 391, 2343, 6639, 1385, 30187, 35401, 74321, 24751, 0 };
            const std::uint32_t dim18866JoeKuoD6Init[]   =   { 1, 3, 1, 13, 1, 57, 37, 65, 57, 413, 63, 3819, 5915, 3925, 20777, 48539, 3019, 54965, 0 };
            const std::uint32_t dim18867JoeKuoD6Init[]   =   { 1, 1, 7, 3, 7, 13, 91, 33, 143, 489, 657, 3127, 707, 10841, 11307, 37855, 92697, 119189, 0 };
            const std::uint32_t dim18868JoeKuoD6Init[]   =   { 1, 1, 3, 11, 25, 47, 11, 57, 463, 693, 55, 501, 3765, 15443, 12917, 61677, 97145, 213637, 0 };
            const std::uint32_t dim18869JoeKuoD6Init[]   =   { 1, 3, 1, 1, 13, 49, 13, 225, 101, 475, 627, 1447, 7587, 11335, 3599, 20795, 72915, 174663, 0 };
            const std::uint32_t dim18870JoeKuoD6Init[]   =   { 1, 3, 7, 5, 31, 15, 115, 255, 329, 365, 959, 3399, 4695, 14537, 1447, 17391, 88557, 130213, 0 };
            const std::uint32_t dim18871JoeKuoD6Init[]   =   { 1, 1, 1, 9, 25, 47, 29, 173, 29, 149, 291, 691, 7621, 7607, 20769, 7149, 27323, 57689, 0 };
            const std::uint32_t dim18872JoeKuoD6Init[]   =   { 1, 3, 5, 15, 3, 61, 119, 247, 25, 495, 1297, 1119, 8011, 16077, 21567, 30559, 88455, 68763, 0 };
            const std::uint32_t dim18873JoeKuoD6Init[]   =   { 1, 1, 7, 1, 11, 47, 109, 115, 313, 517, 1951, 3319, 337, 11793, 22345, 33457, 47383, 213893, 0 };
            const std::uint32_t dim18874JoeKuoD6Init[]   =   { 1, 1, 5, 11, 11, 53, 103, 237, 383, 927, 421, 4085, 3327, 169, 9941, 24753, 65437, 108173, 0 };
            const std::uint32_t dim18875JoeKuoD6Init[]   =   { 1, 1, 5, 11, 17, 59, 107, 53, 479, 143, 825, 2667, 5219, 6143, 11573, 33637, 124981, 98195, 0 };
            const std::uint32_t dim18876JoeKuoD6Init[]   =   { 1, 3, 3, 13, 3, 17, 61, 129, 475, 585, 1611, 1791, 7817, 4099, 20437, 51411, 130173, 220085, 0 };
            const std::uint32_t dim18877JoeKuoD6Init[]   =   { 1, 3, 3, 3, 27, 25, 33, 255, 361, 967, 1415, 3213, 3341, 15875, 32359, 53267, 27665, 178301, 0 };
            const std::uint32_t dim18878JoeKuoD6Init[]   =   { 1, 1, 5, 3, 13, 9, 91, 187, 173, 525, 1675, 2217, 4093, 2009, 16917, 18485, 104849, 163233, 0 };
            const std::uint32_t dim18879JoeKuoD6Init[]   =   { 1, 1, 1, 11, 3, 17, 125, 157, 9, 429, 1573, 2257, 7943, 9893, 5611, 64619, 4509, 200181, 0 };
            const std::uint32_t dim18880JoeKuoD6Init[]   =   { 1, 3, 1, 1, 3, 9, 83, 53, 315, 85, 1093, 2621, 663, 12369, 317, 6089, 16479, 225071, 0 };
            const std::uint32_t dim18881JoeKuoD6Init[]   =   { 1, 3, 3, 1, 25, 47, 57, 45, 219, 45, 945, 3989, 4889, 8989, 381, 52483, 57029, 253899, 0 };
            const std::uint32_t dim18882JoeKuoD6Init[]   =   { 1, 3, 3, 5, 3, 61, 75, 189, 53, 489, 553, 2381, 7485, 9941, 29733, 2611, 74119, 203647, 0 };
            const std::uint32_t dim18883JoeKuoD6Init[]   =   { 1, 3, 1, 11, 27, 63, 53, 61, 59, 613, 465, 867, 1985, 7605, 14301, 53847, 68547, 14717, 0 };
            const std::uint32_t dim18884JoeKuoD6Init[]   =   { 1, 3, 5, 11, 5, 41, 51, 11, 59, 761, 59, 267, 7273, 3061, 11223, 48825, 117869, 158551, 0 };
            const std::uint32_t dim18885JoeKuoD6Init[]   =   { 1, 3, 7, 1, 31, 47, 111, 43, 435, 997, 135, 3369, 6439, 5637, 13629, 13221, 90607, 86359, 0 };
            const std::uint32_t dim18886JoeKuoD6Init[]   =   { 1, 1, 1, 11, 23, 51, 109, 223, 495, 765, 1557, 3545, 305, 4949, 23931, 45115, 12121, 14487, 0 };
            const std::uint32_t dim18887JoeKuoD6Init[]   =   { 1, 3, 5, 9, 5, 25, 41, 249, 27, 375, 1339, 3647, 3529, 2077, 21091, 45523, 67191, 1257, 0 };
            const std::uint32_t dim18888JoeKuoD6Init[]   =   { 1, 1, 3, 7, 13, 15, 63, 45, 187, 761, 1245, 3381, 1817, 2491, 16469, 64417, 87333, 143103, 0 };
            const std::uint32_t dim18889JoeKuoD6Init[]   =   { 1, 1, 3, 13, 11, 33, 87, 11, 279, 689, 1047, 3935, 5359, 11309, 19735, 33259, 12347, 183653, 0 };
            const std::uint32_t dim18890JoeKuoD6Init[]   =   { 1, 1, 5, 7, 5, 49, 109, 221, 455, 167, 785, 1859, 4337, 14937, 209, 23435, 22923, 172985, 0 };
            const std::uint32_t dim18891JoeKuoD6Init[]   =   { 1, 3, 7, 9, 13, 7, 127, 117, 147, 741, 531, 2627, 2565, 11083, 30577, 42471, 77065, 120983, 0 };
            const std::uint32_t dim18892JoeKuoD6Init[]   =   { 1, 1, 7, 1, 5, 61, 115, 203, 15, 305, 1005, 2085, 2597, 4371, 11661, 33219, 53657, 40325, 0 };
            const std::uint32_t dim18893JoeKuoD6Init[]   =   { 1, 3, 7, 13, 13, 15, 69, 167, 369, 747, 1115, 1493, 4881, 2693, 32281, 27089, 56821, 121693, 0 };
            const std::uint32_t dim18894JoeKuoD6Init[]   =   { 1, 3, 5, 3, 19, 51, 101, 29, 411, 509, 847, 1033, 4135, 15561, 7045, 60757, 48479, 247295, 0 };
            const std::uint32_t dim18895JoeKuoD6Init[]   =   { 1, 1, 5, 3, 27, 47, 103, 123, 413, 71, 689, 2113, 4347, 1983, 25727, 20095, 3271, 133081, 0 };
            const std::uint32_t dim18896JoeKuoD6Init[]   =   { 1, 1, 3, 3, 5, 39, 87, 27, 505, 631, 689, 2591, 1955, 3205, 12681, 10821, 13343, 101505, 0 };
            const std::uint32_t dim18897JoeKuoD6Init[]   =   { 1, 3, 7, 9, 31, 23, 103, 223, 499, 721, 13, 1399, 7369, 3945, 27727, 7923, 60265, 197793, 0 };
            const std::uint32_t dim18898JoeKuoD6Init[]   =   { 1, 3, 3, 5, 27, 7, 119, 23, 371, 495, 1583, 3913, 5139, 12151, 17477, 10907, 121775, 13369, 0 };
            const std::uint32_t dim18899JoeKuoD6Init[]   =   { 1, 3, 7, 1, 19, 53, 91, 235, 161, 97, 37, 1115, 5909, 1943, 8137, 1541, 16253, 252151, 0 };
            const std::uint32_t dim18900JoeKuoD6Init[]   =   { 1, 3, 7, 5, 3, 1, 107, 241, 187, 253, 1225, 2827, 4191, 2749, 25629, 47465, 19969, 45035, 0 };
            const std::uint32_t dim18901JoeKuoD6Init[]   =   { 1, 3, 1, 5, 1, 29, 47, 233, 175, 313, 793, 2089, 6235, 6595, 27599, 20505, 63379, 8729, 0 };
            const std::uint32_t dim18902JoeKuoD6Init[]   =   { 1, 3, 7, 11, 15, 9, 87, 113, 389, 1, 1057, 3307, 3455, 1847, 1497, 28115, 92897, 2383, 0 };
            const std::uint32_t dim18903JoeKuoD6Init[]   =   { 1, 3, 7, 13, 19, 59, 45, 59, 49, 273, 1619, 1975, 5949, 9951, 7685, 52559, 42377, 29855, 0 };
            const std::uint32_t dim18904JoeKuoD6Init[]   =   { 1, 1, 3, 9, 19, 7, 119, 35, 85, 37, 269, 3443, 8015, 8061, 6001, 19123, 70643, 115513, 0 };
            const std::uint32_t dim18905JoeKuoD6Init[]   =   { 1, 1, 3, 15, 3, 19, 83, 171, 259, 207, 1495, 513, 5455, 4071, 27471, 15773, 66301, 228743, 0 };
            const std::uint32_t dim18906JoeKuoD6Init[]   =   { 1, 3, 7, 9, 3, 27, 93, 3, 471, 13, 677, 4067, 1941, 15345, 26629, 29419, 121593, 108669, 0 };
            const std::uint32_t dim18907JoeKuoD6Init[]   =   { 1, 3, 7, 15, 29, 43, 97, 41, 15, 181, 1969, 1901, 7237, 3879, 19337, 17659, 17957, 164667, 0 };
            const std::uint32_t dim18908JoeKuoD6Init[]   =   { 1, 3, 1, 1, 25, 33, 7, 41, 387, 469, 795, 781, 113, 4161, 29687, 32225, 73905, 137879, 0 };
            const std::uint32_t dim18909JoeKuoD6Init[]   =   { 1, 1, 3, 13, 9, 59, 89, 23, 393, 111, 1957, 719, 6179, 16183, 31331, 48015, 32147, 31691, 0 };
            const std::uint32_t dim18910JoeKuoD6Init[]   =   { 1, 3, 7, 5, 9, 45, 73, 219, 181, 51, 717, 1813, 2581, 1395, 17595, 23689, 89709, 201451, 0 };
            const std::uint32_t dim18911JoeKuoD6Init[]   =   { 1, 3, 7, 3, 1, 21, 15, 35, 131, 515, 803, 1429, 3855, 349, 11795, 26787, 6109, 117745, 0 };
            const std::uint32_t dim18912JoeKuoD6Init[]   =   { 1, 3, 3, 9, 7, 11, 57, 15, 491, 371, 1787, 85, 577, 11455, 27419, 20687, 2493, 209993, 0 };
            const std::uint32_t dim18913JoeKuoD6Init[]   =   { 1, 3, 7, 15, 5, 5, 87, 197, 93, 643, 247, 31, 357, 7377, 10509, 29883, 42747, 248861, 0 };
            const std::uint32_t dim18914JoeKuoD6Init[]   =   { 1, 3, 3, 3, 29, 33, 47, 253, 485, 25, 2003, 2953, 1629, 11549, 5697, 1135, 117761, 96411, 0 };
            const std::uint32_t dim18915JoeKuoD6Init[]   =   { 1, 3, 5, 1, 29, 5, 27, 187, 235, 423, 41, 1855, 4359, 15627, 28409, 49331, 37735, 68823, 0 };
            const std::uint32_t dim18916JoeKuoD6Init[]   =   { 1, 1, 5, 5, 21, 61, 67, 85, 41, 671, 1617, 3867, 7913, 1693, 18487, 1831, 100971, 168191, 0 };
            const std::uint32_t dim18917JoeKuoD6Init[]   =   { 1, 1, 7, 3, 1, 61, 111, 87, 55, 229, 217, 2801, 563, 13617, 9641, 22247, 16039, 113541, 0 };
            const std::uint32_t dim18918JoeKuoD6Init[]   =   { 1, 3, 5, 7, 5, 29, 67, 99, 91, 561, 1203, 643, 2607, 13421, 29695, 31925, 82985, 69031, 0 };
            const std::uint32_t dim18919JoeKuoD6Init[]   =   { 1, 1, 1, 1, 27, 7, 63, 107, 269, 163, 1711, 587, 5657, 15077, 24709, 10235, 95483, 94799, 0 };
            const std::uint32_t dim18920JoeKuoD6Init[]   =   { 1, 3, 3, 5, 29, 5, 127, 137, 67, 609, 1657, 1131, 959, 15773, 17295, 58575, 96525, 80529, 0 };
            const std::uint32_t dim18921JoeKuoD6Init[]   =   { 1, 3, 7, 7, 25, 15, 89, 93, 145, 695, 367, 2853, 3073, 4867, 26823, 31467, 94769, 9145, 0 };
            const std::uint32_t dim18922JoeKuoD6Init[]   =   { 1, 1, 7, 15, 15, 5, 1, 225, 57, 381, 1295, 2525, 1493, 2401, 91, 19809, 32803, 195289, 0 };
            const std::uint32_t dim18923JoeKuoD6Init[]   =   { 1, 3, 3, 7, 29, 51, 29, 63, 249, 107, 1689, 3703, 7227, 6967, 27861, 39167, 20043, 218827, 0 };
            const std::uint32_t dim18924JoeKuoD6Init[]   =   { 1, 1, 3, 13, 17, 1, 77, 143, 167, 255, 1709, 2089, 7465, 4805, 16185, 15167, 20493, 240855, 0 };
            const std::uint32_t dim18925JoeKuoD6Init[]   =   { 1, 1, 5, 1, 11, 43, 107, 175, 93, 955, 615, 2923, 3637, 7451, 18847, 53467, 12463, 127249, 0 };
            const std::uint32_t dim18926JoeKuoD6Init[]   =   { 1, 1, 3, 13, 31, 1, 61, 113, 479, 777, 1805, 3625, 6299, 12221, 29599, 60175, 31165, 122815, 0 };
            const std::uint32_t dim18927JoeKuoD6Init[]   =   { 1, 3, 3, 11, 11, 29, 89, 129, 195, 337, 1843, 2769, 1747, 7137, 9901, 18459, 25215, 70609, 0 };
            const std::uint32_t dim18928JoeKuoD6Init[]   =   { 1, 1, 3, 7, 17, 35, 55, 81, 413, 25, 1505, 2185, 3121, 11435, 17885, 12543, 36767, 64039, 0 };
            const std::uint32_t dim18929JoeKuoD6Init[]   =   { 1, 3, 1, 13, 25, 9, 83, 25, 5, 49, 1975, 3967, 4135, 13213, 26479, 63913, 14921, 96193, 0 };
            const std::uint32_t dim18930JoeKuoD6Init[]   =   { 1, 3, 7, 5, 17, 15, 101, 47, 245, 821, 1275, 3343, 5471, 5045, 31741, 3319, 8141, 95501, 0 };
            const std::uint32_t dim18931JoeKuoD6Init[]   =   { 1, 3, 1, 13, 1, 5, 105, 39, 175, 439, 1625, 249, 4859, 12449, 30529, 45669, 49071, 214037, 0 };
            const std::uint32_t dim18932JoeKuoD6Init[]   =   { 1, 1, 7, 7, 17, 21, 83, 123, 261, 559, 1967, 2933, 4417, 8331, 10119, 21793, 128729, 187247, 0 };
            const std::uint32_t dim18933JoeKuoD6Init[]   =   { 1, 1, 7, 9, 15, 43, 77, 231, 241, 419, 503, 3335, 927, 2567, 31259, 52453, 114441, 257449, 0 };
            const std::uint32_t dim18934JoeKuoD6Init[]   =   { 1, 3, 3, 1, 9, 29, 21, 89, 311, 185, 519, 271, 3595, 8951, 6105, 64593, 38209, 120491, 0 };
            const std::uint32_t dim18935JoeKuoD6Init[]   =   { 1, 1, 7, 9, 1, 57, 65, 5, 275, 615, 801, 2839, 2851, 15609, 28731, 31223, 87725, 437, 0 };
            const std::uint32_t dim18936JoeKuoD6Init[]   =   { 1, 3, 3, 5, 29, 3, 67, 53, 17, 499, 263, 651, 7963, 5371, 11593, 34761, 57427, 84979, 0 };
            const std::uint32_t dim18937JoeKuoD6Init[]   =   { 1, 3, 7, 11, 15, 9, 33, 165, 313, 659, 909, 969, 2309, 2197, 27263, 35273, 52887, 236107, 0 };
            const std::uint32_t dim18938JoeKuoD6Init[]   =   { 1, 1, 7, 1, 13, 17, 29, 3, 329, 573, 619, 1013, 6947, 7031, 30773, 41129, 116481, 184233, 0 };
            const std::uint32_t dim18939JoeKuoD6Init[]   =   { 1, 1, 5, 9, 13, 5, 87, 235, 63, 759, 1143, 1861, 3783, 2735, 26191, 64387, 3651, 119447, 0 };
            const std::uint32_t dim18940JoeKuoD6Init[]   =   { 1, 1, 3, 7, 15, 41, 117, 135, 273, 655, 251, 1859, 4363, 14725, 29385, 6269, 91505, 82679, 0 };
            const std::uint32_t dim18941JoeKuoD6Init[]   =   { 1, 3, 7, 3, 13, 21, 21, 9, 121, 899, 199, 1973, 7437, 9771, 26647, 30909, 118573, 152913, 0 };
            const std::uint32_t dim18942JoeKuoD6Init[]   =   { 1, 3, 3, 9, 31, 43, 5, 249, 109, 183, 161, 1185, 4025, 10331, 20983, 28549, 122687, 183429, 0 };
            const std::uint32_t dim18943JoeKuoD6Init[]   =   { 1, 3, 7, 7, 11, 45, 111, 99, 487, 971, 597, 1555, 273, 10403, 25289, 45483, 35845, 35791, 0 };
            const std::uint32_t dim18944JoeKuoD6Init[]   =   { 1, 1, 1, 7, 11, 49, 125, 229, 279, 289, 1945, 3575, 5683, 15659, 31123, 12517, 79303, 255797, 0 };
            const std::uint32_t dim18945JoeKuoD6Init[]   =   { 1, 3, 1, 15, 9, 23, 61, 53, 383, 855, 1743, 407, 4401, 7507, 26307, 56205, 110943, 184183, 0 };
            const std::uint32_t dim18946JoeKuoD6Init[]   =   { 1, 3, 5, 13, 23, 29, 101, 243, 417, 925, 1267, 257, 5893, 4335, 6309, 43519, 126035, 99205, 0 };
            const std::uint32_t dim18947JoeKuoD6Init[]   =   { 1, 3, 1, 5, 5, 35, 83, 25, 31, 455, 1799, 2919, 7037, 11829, 12239, 12969, 108469, 89513, 0 };
            const std::uint32_t dim18948JoeKuoD6Init[]   =   { 1, 3, 5, 9, 17, 29, 61, 217, 183, 131, 425, 4025, 7141, 5445, 21497, 10603, 53423, 5701, 0 };
            const std::uint32_t dim18949JoeKuoD6Init[]   =   { 1, 1, 1, 15, 27, 35, 9, 139, 261, 43, 587, 3835, 4627, 11689, 15739, 6031, 73547, 134271, 0 };
            const std::uint32_t dim18950JoeKuoD6Init[]   =   { 1, 1, 3, 3, 25, 15, 7, 225, 29, 785, 2047, 2219, 6083, 7973, 17053, 56167, 83915, 87597, 0 };
            const std::uint32_t dim18951JoeKuoD6Init[]   =   { 1, 3, 7, 15, 13, 43, 85, 121, 421, 867, 1895, 2437, 6003, 5269, 8625, 26877, 100023, 110229, 0 };
            const std::uint32_t dim18952JoeKuoD6Init[]   =   { 1, 3, 3, 3, 25, 49, 121, 1, 125, 353, 1811, 1575, 3925, 13897, 26087, 24977, 105995, 242817, 0 };
            const std::uint32_t dim18953JoeKuoD6Init[]   =   { 1, 1, 1, 9, 31, 55, 71, 241, 439, 927, 955, 109, 7779, 2397, 18797, 34177, 1255, 178671, 0 };
            const std::uint32_t dim18954JoeKuoD6Init[]   =   { 1, 1, 7, 7, 5, 15, 99, 225, 49, 407, 1711, 4027, 4845, 9209, 20983, 33969, 14205, 9351, 0 };
            const std::uint32_t dim18955JoeKuoD6Init[]   =   { 1, 3, 5, 1, 9, 13, 113, 143, 97, 189, 929, 1163, 2261, 9761, 30011, 32911, 117043, 169493, 0 };
            const std::uint32_t dim18956JoeKuoD6Init[]   =   { 1, 1, 3, 5, 9, 35, 95, 77, 5, 95, 1745, 2013, 7009, 5427, 18969, 2771, 5099, 52939, 0 };
            const std::uint32_t dim18957JoeKuoD6Init[]   =   { 1, 3, 7, 9, 13, 19, 31, 189, 367, 569, 95, 1665, 6231, 2169, 22589, 8427, 116097, 41077, 0 };
            const std::uint32_t dim18958JoeKuoD6Init[]   =   { 1, 3, 7, 3, 31, 61, 45, 233, 327, 541, 87, 3449, 2767, 12237, 17747, 53827, 80389, 121489, 0 };
            const std::uint32_t dim18959JoeKuoD6Init[]   =   { 1, 3, 7, 15, 31, 1, 49, 73, 157, 131, 553, 3417, 5283, 4737, 31675, 63213, 43689, 261869, 0 };
            const std::uint32_t dim18960JoeKuoD6Init[]   =   { 1, 3, 7, 1, 3, 5, 113, 43, 343, 39, 135, 1555, 7955, 9851, 30983, 21955, 34871, 147649, 0 };
            const std::uint32_t dim18961JoeKuoD6Init[]   =   { 1, 3, 5, 3, 5, 27, 15, 179, 141, 983, 265, 2651, 5907, 10501, 6275, 29629, 115965, 125745, 0 };
            const std::uint32_t dim18962JoeKuoD6Init[]   =   { 1, 3, 7, 13, 1, 1, 81, 105, 309, 457, 1817, 3435, 4615, 1181, 27835, 26075, 63447, 44701, 0 };
            const std::uint32_t dim18963JoeKuoD6Init[]   =   { 1, 1, 5, 5, 25, 19, 85, 103, 409, 323, 2001, 3719, 3403, 1301, 19615, 47829, 109905, 65777, 0 };
            const std::uint32_t dim18964JoeKuoD6Init[]   =   { 1, 3, 5, 3, 21, 15, 47, 75, 467, 273, 1885, 3929, 1877, 5209, 6881, 34431, 35663, 100205, 0 };
            const std::uint32_t dim18965JoeKuoD6Init[]   =   { 1, 1, 5, 3, 3, 9, 47, 143, 471, 653, 1011, 2263, 3673, 11921, 31207, 50365, 27177, 214377, 0 };
            const std::uint32_t dim18966JoeKuoD6Init[]   =   { 1, 3, 1, 15, 3, 43, 81, 253, 495, 139, 679, 2207, 4603, 5269, 27133, 46461, 120783, 185595, 0 };
            const std::uint32_t dim18967JoeKuoD6Init[]   =   { 1, 1, 7, 3, 13, 3, 109, 197, 477, 101, 859, 1035, 777, 10153, 15581, 22715, 17493, 120851, 0 };
            const std::uint32_t dim18968JoeKuoD6Init[]   =   { 1, 3, 1, 3, 23, 5, 121, 67, 265, 935, 741, 3311, 541, 1093, 1639, 5941, 5587, 150345, 0 };
            const std::uint32_t dim18969JoeKuoD6Init[]   =   { 1, 3, 1, 5, 3, 13, 65, 173, 493, 303, 359, 3813, 6007, 1105, 12185, 10431, 17117, 164899, 0 };
            const std::uint32_t dim18970JoeKuoD6Init[]   =   { 1, 3, 3, 1, 25, 33, 71, 181, 149, 7, 333, 1981, 2981, 14683, 10997, 63373, 22605, 119681, 0 };
            const std::uint32_t dim18971JoeKuoD6Init[]   =   { 1, 1, 1, 15, 29, 35, 89, 21, 281, 175, 587, 3117, 7221, 8239, 26399, 49133, 65895, 142175, 0 };
            const std::uint32_t dim18972JoeKuoD6Init[]   =   { 1, 3, 7, 15, 9, 9, 35, 161, 65, 749, 421, 3575, 6307, 2029, 11423, 63901, 102049, 26333, 0 };
            const std::uint32_t dim18973JoeKuoD6Init[]   =   { 1, 3, 1, 13, 1, 45, 97, 41, 231, 245, 271, 1497, 3119, 6225, 21665, 12113, 67315, 62779, 0 };
            const std::uint32_t dim18974JoeKuoD6Init[]   =   { 1, 1, 1, 7, 3, 29, 119, 193, 179, 353, 1015, 2803, 6869, 7653, 22309, 53421, 86969, 115549, 0 };
            const std::uint32_t dim18975JoeKuoD6Init[]   =   { 1, 3, 3, 5, 17, 37, 49, 129, 195, 537, 1237, 2775, 6683, 699, 19181, 61125, 27483, 175645, 0 };
            const std::uint32_t dim18976JoeKuoD6Init[]   =   { 1, 3, 7, 3, 7, 49, 107, 41, 285, 335, 1415, 4015, 1301, 6525, 32429, 9337, 87923, 176751, 0 };
            const std::uint32_t dim18977JoeKuoD6Init[]   =   { 1, 1, 5, 9, 21, 43, 91, 25, 225, 311, 417, 303, 2629, 3609, 29987, 28647, 104173, 52383, 0 };
            const std::uint32_t dim18978JoeKuoD6Init[]   =   { 1, 3, 5, 9, 13, 47, 75, 143, 109, 173, 503, 3843, 1767, 9433, 10009, 5653, 87339, 212975, 0 };
            const std::uint32_t dim18979JoeKuoD6Init[]   =   { 1, 3, 1, 13, 13, 55, 123, 95, 499, 245, 1875, 3661, 7661, 6927, 21003, 51729, 88089, 89063, 0 };
            const std::uint32_t dim18980JoeKuoD6Init[]   =   { 1, 1, 3, 1, 31, 7, 93, 35, 169, 191, 1079, 2137, 4401, 1563, 20021, 9101, 66881, 231589, 0 };
            const std::uint32_t dim18981JoeKuoD6Init[]   =   { 1, 3, 1, 15, 21, 41, 75, 231, 459, 701, 1715, 2581, 4445, 5877, 4765, 1037, 15827, 189529, 0 };
            const std::uint32_t dim18982JoeKuoD6Init[]   =   { 1, 3, 5, 13, 17, 23, 41, 133, 143, 297, 1335, 3907, 7745, 5139, 9397, 5765, 5347, 243091, 0 };
            const std::uint32_t dim18983JoeKuoD6Init[]   =   { 1, 1, 5, 13, 7, 15, 31, 183, 315, 153, 785, 2723, 97, 14361, 10509, 17717, 46615, 133289, 0 };
            const std::uint32_t dim18984JoeKuoD6Init[]   =   { 1, 3, 7, 9, 13, 3, 75, 103, 445, 409, 603, 201, 1873, 9277, 23953, 6881, 64327, 196771, 0 };
            const std::uint32_t dim18985JoeKuoD6Init[]   =   { 1, 1, 7, 13, 15, 21, 73, 183, 419, 997, 857, 1373, 3855, 417, 10175, 5253, 66509, 15731, 0 };
            const std::uint32_t dim18986JoeKuoD6Init[]   =   { 1, 3, 3, 9, 19, 7, 15, 119, 497, 25, 1165, 105, 2605, 15097, 28241, 2269, 519, 235655, 0 };
            const std::uint32_t dim18987JoeKuoD6Init[]   =   { 1, 3, 3, 9, 27, 9, 103, 205, 97, 317, 1621, 971, 931, 9099, 24583, 12695, 122399, 78021, 0 };
            const std::uint32_t dim18988JoeKuoD6Init[]   =   { 1, 1, 3, 5, 27, 45, 41, 239, 87, 603, 317, 3507, 7677, 9141, 26721, 40225, 80515, 205263, 0 };
            const std::uint32_t dim18989JoeKuoD6Init[]   =   { 1, 1, 3, 1, 25, 3, 63, 165, 41, 783, 291, 1997, 3769, 1881, 30613, 18821, 86175, 38837, 0 };
            const std::uint32_t dim18990JoeKuoD6Init[]   =   { 1, 1, 3, 5, 17, 19, 95, 17, 357, 587, 689, 3127, 6999, 6703, 23923, 55945, 97629, 210177, 0 };
            const std::uint32_t dim18991JoeKuoD6Init[]   =   { 1, 1, 3, 15, 21, 55, 63, 229, 397, 1007, 779, 2105, 681, 10659, 26679, 681, 115901, 83627, 0 };
            const std::uint32_t dim18992JoeKuoD6Init[]   =   { 1, 1, 7, 11, 25, 9, 47, 133, 109, 17, 697, 749, 5529, 9289, 29675, 2631, 15247, 13913, 0 };
            const std::uint32_t dim18993JoeKuoD6Init[]   =   { 1, 1, 7, 7, 3, 55, 29, 13, 467, 889, 675, 1187, 3301, 13721, 13783, 44559, 78177, 114219, 0 };
            const std::uint32_t dim18994JoeKuoD6Init[]   =   { 1, 3, 5, 13, 15, 11, 77, 71, 313, 427, 1385, 2007, 4003, 1529, 4797, 12289, 24897, 129513, 0 };
            const std::uint32_t dim18995JoeKuoD6Init[]   =   { 1, 1, 3, 11, 9, 47, 103, 253, 345, 659, 1109, 3493, 2515, 5669, 30551, 25077, 97393, 252689, 0 };
            const std::uint32_t dim18996JoeKuoD6Init[]   =   { 1, 3, 7, 9, 25, 19, 69, 161, 365, 51, 1365, 1045, 4319, 10035, 15529, 23251, 44359, 62163, 0 };
            const std::uint32_t dim18997JoeKuoD6Init[]   =   { 1, 3, 1, 7, 3, 25, 119, 33, 19, 561, 659, 2741, 6177, 899, 30911, 9627, 83003, 12939, 0 };
            const std::uint32_t dim18998JoeKuoD6Init[]   =   { 1, 3, 7, 1, 13, 37, 19, 161, 427, 621, 1045, 1963, 6067, 4439, 32507, 32775, 5201, 144645, 0 };
            const std::uint32_t dim18999JoeKuoD6Init[]   =   { 1, 1, 5, 7, 31, 17, 89, 239, 317, 109, 1827, 1395, 1587, 14813, 29911, 63545, 22939, 235383, 0 };
            const std::uint32_t dim19000JoeKuoD6Init[]   =   { 1, 1, 7, 15, 1, 17, 41, 123, 405, 539, 1063, 1443, 4611, 1847, 24107, 29365, 85859, 218601, 0 };
            const std::uint32_t dim19001JoeKuoD6Init[]   =   { 1, 1, 5, 13, 21, 27, 101, 223, 245, 705, 1579, 679, 5461, 8955, 15031, 7731, 31219, 165033, 0 };
            const std::uint32_t dim19002JoeKuoD6Init[]   =   { 1, 1, 7, 11, 19, 29, 13, 223, 179, 481, 761, 1543, 3195, 10695, 17147, 37577, 130901, 44699, 0 };
            const std::uint32_t dim19003JoeKuoD6Init[]   =   { 1, 1, 7, 3, 19, 53, 49, 1, 393, 583, 1183, 2817, 1293, 12949, 15491, 44467, 86261, 220439, 0 };
            const std::uint32_t dim19004JoeKuoD6Init[]   =   { 1, 3, 7, 15, 15, 47, 7, 125, 467, 511, 1207, 3787, 5575, 5359, 3859, 29933, 104627, 243073, 0 };
            const std::uint32_t dim19005JoeKuoD6Init[]   =   { 1, 1, 1, 13, 27, 25, 17, 243, 477, 457, 1835, 2859, 1023, 10107, 26829, 49853, 114569, 250471, 0 };
            const std::uint32_t dim19006JoeKuoD6Init[]   =   { 1, 3, 1, 15, 11, 43, 15, 235, 431, 671, 1935, 1143, 4121, 15403, 19313, 15919, 111961, 50455, 0 };
            const std::uint32_t dim19007JoeKuoD6Init[]   =   { 1, 3, 3, 3, 11, 45, 107, 143, 353, 671, 1259, 1599, 6075, 10645, 9131, 28133, 58679, 29883, 0 };
            const std::uint32_t dim19008JoeKuoD6Init[]   =   { 1, 3, 5, 15, 15, 43, 29, 171, 303, 71, 1751, 411, 7615, 12063, 26829, 31469, 34335, 3163, 0 };
            const std::uint32_t dim19009JoeKuoD6Init[]   =   { 1, 1, 7, 7, 25, 63, 25, 25, 27, 671, 505, 1235, 1985, 2593, 30031, 3251, 94729, 248911, 0 };
            const std::uint32_t dim19010JoeKuoD6Init[]   =   { 1, 1, 3, 1, 19, 15, 125, 133, 133, 209, 1749, 2091, 6325, 1275, 5675, 2249, 22631, 56293, 0 };
            const std::uint32_t dim19011JoeKuoD6Init[]   =   { 1, 1, 5, 1, 19, 27, 25, 99, 211, 739, 565, 3903, 7701, 7547, 12303, 5421, 24663, 22807, 0 };
            const std::uint32_t dim19012JoeKuoD6Init[]   =   { 1, 3, 5, 13, 5, 45, 99, 67, 21, 269, 851, 3333, 4555, 12483, 14645, 44757, 99047, 198521, 0 };
            const std::uint32_t dim19013JoeKuoD6Init[]   =   { 1, 1, 5, 13, 19, 1, 123, 87, 109, 799, 591, 2997, 1005, 16369, 10329, 34541, 100935, 200397, 0 };
            const std::uint32_t dim19014JoeKuoD6Init[]   =   { 1, 3, 5, 1, 13, 51, 93, 23, 19, 23, 965, 171, 6865, 3561, 23255, 44295, 87405, 222269, 0 };
            const std::uint32_t dim19015JoeKuoD6Init[]   =   { 1, 1, 3, 5, 1, 53, 25, 129, 123, 737, 271, 61, 113, 8481, 27075, 58633, 21499, 156689, 0 };
            const std::uint32_t dim19016JoeKuoD6Init[]   =   { 1, 3, 3, 11, 3, 43, 11, 123, 243, 1015, 1389, 3663, 1725, 6933, 5315, 7137, 127705, 56607, 0 };
            const std::uint32_t dim19017JoeKuoD6Init[]   =   { 1, 1, 5, 13, 7, 23, 43, 103, 503, 173, 267, 1509, 3311, 9553, 28851, 15771, 28741, 236427, 0 };
            const std::uint32_t dim19018JoeKuoD6Init[]   =   { 1, 1, 5, 15, 27, 43, 119, 3, 13, 107, 317, 3725, 6669, 4945, 30485, 10155, 96893, 154081, 0 };
            const std::uint32_t dim19019JoeKuoD6Init[]   =   { 1, 3, 7, 5, 11, 21, 61, 99, 155, 45, 569, 1325, 673, 15803, 12047, 55431, 9515, 106969, 0 };
            const std::uint32_t dim19020JoeKuoD6Init[]   =   { 1, 1, 7, 11, 27, 49, 121, 145, 105, 223, 1471, 1163, 3889, 4213, 21195, 45649, 14663, 82799, 0 };
            const std::uint32_t dim19021JoeKuoD6Init[]   =   { 1, 1, 3, 3, 31, 21, 17, 85, 31, 695, 1591, 2465, 907, 11621, 29681, 13131, 77187, 175913, 0 };
            const std::uint32_t dim19022JoeKuoD6Init[]   =   { 1, 3, 5, 5, 21, 49, 77, 229, 359, 825, 1851, 1223, 3351, 5349, 30971, 20797, 26975, 94425, 0 };
            const std::uint32_t dim19023JoeKuoD6Init[]   =   { 1, 1, 3, 1, 3, 63, 23, 219, 503, 47, 1675, 1641, 5257, 8035, 29793, 30093, 44897, 235691, 0 };
            const std::uint32_t dim19024JoeKuoD6Init[]   =   { 1, 1, 7, 9, 27, 37, 109, 33, 511, 203, 1195, 3281, 407, 15237, 28485, 21379, 106325, 231755, 0 };
            const std::uint32_t dim19025JoeKuoD6Init[]   =   { 1, 3, 1, 3, 9, 45, 19, 31, 255, 799, 909, 767, 421, 3301, 18557, 15043, 48505, 36763, 0 };
            const std::uint32_t dim19026JoeKuoD6Init[]   =   { 1, 3, 7, 13, 1, 45, 59, 233, 319, 265, 517, 1571, 4593, 12813, 30729, 19517, 70345, 142411, 0 };
            const std::uint32_t dim19027JoeKuoD6Init[]   =   { 1, 1, 1, 13, 17, 15, 79, 93, 265, 381, 285, 253, 919, 3715, 30555, 38801, 30439, 51511, 0 };
            const std::uint32_t dim19028JoeKuoD6Init[]   =   { 1, 1, 7, 15, 25, 39, 71, 57, 145, 487, 1655, 2589, 7655, 8413, 24537, 36761, 36427, 88929, 0 };
            const std::uint32_t dim19029JoeKuoD6Init[]   =   { 1, 1, 3, 3, 29, 41, 61, 191, 97, 849, 911, 3269, 5425, 13997, 7749, 537, 113705, 179765, 0 };
            const std::uint32_t dim19030JoeKuoD6Init[]   =   { 1, 1, 5, 9, 13, 55, 33, 221, 27, 521, 13, 2847, 6035, 8397, 6579, 29353, 101953, 88983, 0 };
            const std::uint32_t dim19031JoeKuoD6Init[]   =   { 1, 3, 3, 13, 31, 47, 97, 177, 373, 353, 159, 249, 4741, 7427, 8353, 38617, 13857, 122081, 0 };
            const std::uint32_t dim19032JoeKuoD6Init[]   =   { 1, 3, 5, 15, 13, 21, 1, 239, 369, 253, 1009, 1927, 5111, 2219, 28167, 32013, 51487, 210521, 0 };
            const std::uint32_t dim19033JoeKuoD6Init[]   =   { 1, 3, 5, 9, 17, 21, 37, 105, 405, 39, 321, 1515, 3759, 15469, 13643, 60157, 72127, 233505, 0 };
            const std::uint32_t dim19034JoeKuoD6Init[]   =   { 1, 3, 7, 5, 1, 3, 3, 125, 283, 757, 829, 2303, 3715, 6027, 17795, 37359, 54721, 5891, 0 };
            const std::uint32_t dim19035JoeKuoD6Init[]   =   { 1, 3, 7, 15, 27, 63, 117, 101, 341, 965, 1543, 51, 3397, 14051, 9889, 64647, 111169, 249477, 0 };
            const std::uint32_t dim19036JoeKuoD6Init[]   =   { 1, 1, 5, 13, 5, 29, 51, 61, 233, 685, 751, 163, 2319, 14691, 29881, 39029, 57093, 240147, 0 };
            const std::uint32_t dim19037JoeKuoD6Init[]   =   { 1, 3, 5, 3, 9, 21, 107, 147, 263, 471, 621, 3485, 197, 13271, 24689, 64341, 110163, 142711, 0 };
            const std::uint32_t dim19038JoeKuoD6Init[]   =   { 1, 3, 1, 7, 1, 23, 17, 31, 131, 631, 795, 3751, 5337, 9151, 2873, 31113, 65303, 244969, 0 };
            const std::uint32_t dim19039JoeKuoD6Init[]   =   { 1, 1, 5, 11, 3, 51, 93, 155, 389, 859, 1181, 2711, 1375, 6119, 229, 47767, 115521, 114129, 0 };
            const std::uint32_t dim19040JoeKuoD6Init[]   =   { 1, 3, 3, 15, 5, 7, 29, 187, 259, 911, 1537, 1885, 6139, 4549, 21655, 58771, 1003, 124609, 0 };
            const std::uint32_t dim19041JoeKuoD6Init[]   =   { 1, 1, 3, 15, 25, 45, 97, 217, 331, 305, 1105, 3465, 3651, 10171, 31601, 6947, 4545, 232627, 0 };
            const std::uint32_t dim19042JoeKuoD6Init[]   =   { 1, 1, 5, 5, 9, 53, 109, 201, 473, 201, 1113, 973, 1825, 13089, 1207, 9947, 92515, 216199, 0 };
            const std::uint32_t dim19043JoeKuoD6Init[]   =   { 1, 3, 7, 3, 1, 49, 25, 109, 249, 489, 1663, 3493, 4615, 13899, 27851, 60711, 14351, 41787, 0 };
            const std::uint32_t dim19044JoeKuoD6Init[]   =   { 1, 3, 3, 7, 3, 15, 29, 53, 61, 669, 371, 2187, 6769, 4623, 25785, 12997, 52263, 28387, 0 };
            const std::uint32_t dim19045JoeKuoD6Init[]   =   { 1, 1, 1, 3, 9, 31, 69, 3, 441, 219, 285, 183, 1971, 10903, 8271, 19389, 61913, 203537, 0 };
            const std::uint32_t dim19046JoeKuoD6Init[]   =   { 1, 1, 5, 3, 9, 63, 117, 131, 53, 525, 1349, 2701, 1317, 6047, 1661, 51785, 93199, 158645, 0 };
            const std::uint32_t dim19047JoeKuoD6Init[]   =   { 1, 3, 5, 3, 21, 61, 11, 91, 317, 635, 61, 1919, 2139, 12817, 6587, 63201, 52659, 8971, 0 };
            const std::uint32_t dim19048JoeKuoD6Init[]   =   { 1, 3, 1, 9, 11, 47, 49, 35, 115, 711, 511, 835, 3787, 837, 15737, 7467, 53263, 132047, 0 };
            const std::uint32_t dim19049JoeKuoD6Init[]   =   { 1, 1, 5, 3, 27, 47, 121, 211, 65, 363, 1067, 3813, 6353, 13701, 23943, 7573, 112721, 219587, 0 };
            const std::uint32_t dim19050JoeKuoD6Init[]   =   { 1, 1, 3, 7, 21, 39, 15, 199, 113, 517, 1429, 1399, 6007, 1389, 16425, 17709, 1231, 51803, 0 };
            const std::uint32_t dim19051JoeKuoD6Init[]   =   { 1, 3, 5, 11, 5, 37, 35, 97, 215, 281, 517, 1777, 4171, 10161, 18369, 23233, 83005, 75519, 0 };
            const std::uint32_t dim19052JoeKuoD6Init[]   =   { 1, 3, 7, 9, 3, 9, 69, 111, 135, 351, 971, 3551, 3739, 3571, 22861, 62669, 83723, 10707, 0 };
            const std::uint32_t dim19053JoeKuoD6Init[]   =   { 1, 3, 3, 5, 31, 35, 103, 205, 321, 553, 409, 363, 4085, 7735, 5513, 64249, 127883, 147839, 0 };
            const std::uint32_t dim19054JoeKuoD6Init[]   =   { 1, 1, 7, 3, 23, 35, 85, 231, 251, 237, 421, 757, 7081, 11247, 24941, 22649, 51111, 157383, 0 };
            const std::uint32_t dim19055JoeKuoD6Init[]   =   { 1, 3, 7, 5, 23, 35, 7, 101, 491, 529, 1437, 489, 5057, 12955, 27543, 60903, 104151, 42545, 0 };
            const std::uint32_t dim19056JoeKuoD6Init[]   =   { 1, 1, 3, 15, 23, 53, 85, 89, 247, 269, 1555, 3789, 467, 11145, 11751, 44343, 120117, 9975, 0 };
            const std::uint32_t dim19057JoeKuoD6Init[]   =   { 1, 1, 5, 3, 29, 49, 123, 179, 311, 45, 1839, 2725, 7307, 5525, 32075, 7979, 107751, 133677, 0 };
            const std::uint32_t dim19058JoeKuoD6Init[]   =   { 1, 1, 5, 3, 31, 21, 65, 229, 31, 597, 755, 2653, 2699, 2075, 11693, 28953, 55811, 13653, 0 };
            const std::uint32_t dim19059JoeKuoD6Init[]   =   { 1, 1, 1, 7, 25, 51, 119, 21, 245, 493, 407, 2997, 4255, 15487, 26359, 24153, 42955, 142191, 0 };
            const std::uint32_t dim19060JoeKuoD6Init[]   =   { 1, 1, 5, 3, 27, 61, 13, 209, 13, 401, 399, 2909, 3623, 8057, 21301, 32273, 112127, 210221, 0 };
            const std::uint32_t dim19061JoeKuoD6Init[]   =   { 1, 3, 5, 13, 3, 19, 121, 19, 57, 583, 947, 3591, 5283, 10831, 20429, 54097, 7559, 112465, 0 };
            const std::uint32_t dim19062JoeKuoD6Init[]   =   { 1, 3, 5, 1, 21, 1, 125, 245, 217, 165, 1319, 2119, 4641, 9481, 4147, 7079, 119015, 128401, 0 };
            const std::uint32_t dim19063JoeKuoD6Init[]   =   { 1, 1, 5, 3, 3, 31, 25, 63, 17, 191, 497, 819, 1515, 11215, 24961, 7679, 125801, 239521, 0 };
            const std::uint32_t dim19064JoeKuoD6Init[]   =   { 1, 1, 5, 1, 3, 25, 27, 43, 37, 863, 739, 2585, 773, 799, 17649, 21171, 123541, 164777, 0 };
            const std::uint32_t dim19065JoeKuoD6Init[]   =   { 1, 3, 5, 7, 7, 25, 15, 251, 305, 159, 1941, 3655, 2881, 15123, 10911, 35541, 62221, 175845, 0 };
            const std::uint32_t dim19066JoeKuoD6Init[]   =   { 1, 1, 1, 9, 19, 5, 103, 1, 417, 951, 139, 2413, 2983, 15471, 9495, 41349, 110175, 29501, 0 };
            const std::uint32_t dim19067JoeKuoD6Init[]   =   { 1, 1, 1, 5, 29, 53, 95, 173, 211, 803, 1599, 4093, 5559, 15855, 12271, 12583, 102221, 203453, 0 };
            const std::uint32_t dim19068JoeKuoD6Init[]   =   { 1, 3, 5, 5, 19, 43, 31, 175, 493, 289, 1865, 2925, 3833, 11327, 23337, 62669, 99485, 230583, 0 };
            const std::uint32_t dim19069JoeKuoD6Init[]   =   { 1, 3, 3, 11, 11, 25, 95, 215, 501, 421, 725, 1571, 2133, 2761, 8649, 45359, 88851, 55057, 0 };
            const std::uint32_t dim19070JoeKuoD6Init[]   =   { 1, 1, 7, 7, 21, 45, 69, 63, 399, 929, 1431, 3397, 3613, 14595, 10417, 62913, 106283, 120869, 0 };
            const std::uint32_t dim19071JoeKuoD6Init[]   =   { 1, 3, 7, 15, 13, 45, 11, 177, 125, 611, 1115, 2441, 2689, 12517, 8989, 34991, 23789, 51543, 0 };
            const std::uint32_t dim19072JoeKuoD6Init[]   =   { 1, 1, 3, 1, 3, 15, 5, 125, 511, 137, 1919, 2953, 5267, 3543, 5485, 7463, 130407, 255945, 0 };
            const std::uint32_t dim19073JoeKuoD6Init[]   =   { 1, 1, 3, 7, 7, 21, 95, 97, 51, 91, 813, 2819, 2839, 12041, 26197, 20143, 51403, 171337, 0 };
            const std::uint32_t dim19074JoeKuoD6Init[]   =   { 1, 1, 1, 1, 7, 27, 15, 125, 441, 387, 1869, 2157, 5863, 581, 893, 58827, 104063, 93735, 0 };
            const std::uint32_t dim19075JoeKuoD6Init[]   =   { 1, 3, 3, 7, 27, 9, 79, 97, 465, 207, 931, 2809, 2225, 13749, 18819, 30605, 9829, 130743, 0 };
            const std::uint32_t dim19076JoeKuoD6Init[]   =   { 1, 3, 5, 13, 31, 41, 19, 147, 293, 725, 297, 397, 1343, 12669, 15339, 58599, 12113, 149835, 0 };
            const std::uint32_t dim19077JoeKuoD6Init[]   =   { 1, 3, 3, 13, 27, 13, 121, 253, 349, 229, 915, 1673, 3819, 77, 20691, 53823, 78265, 138743, 0 };
            const std::uint32_t dim19078JoeKuoD6Init[]   =   { 1, 1, 5, 5, 29, 41, 65, 235, 123, 871, 1809, 3013, 3531, 1551, 8441, 23481, 58729, 117639, 0 };
            const std::uint32_t dim19079JoeKuoD6Init[]   =   { 1, 1, 7, 5, 23, 55, 89, 81, 201, 313, 1307, 2427, 2025, 8543, 26631, 58655, 122095, 247579, 0 };
            const std::uint32_t dim19080JoeKuoD6Init[]   =   { 1, 3, 1, 5, 3, 63, 89, 219, 449, 9, 1771, 2915, 5925, 13773, 26119, 61309, 65107, 33001, 0 };
            const std::uint32_t dim19081JoeKuoD6Init[]   =   { 1, 3, 7, 1, 27, 11, 25, 221, 139, 665, 1543, 2157, 7617, 9135, 567, 64985, 88749, 54223, 0 };
            const std::uint32_t dim19082JoeKuoD6Init[]   =   { 1, 1, 3, 9, 13, 41, 7, 99, 483, 115, 1499, 3343, 7207, 1805, 16031, 63707, 8555, 90959, 0 };
            const std::uint32_t dim19083JoeKuoD6Init[]   =   { 1, 3, 1, 9, 15, 53, 41, 239, 295, 47, 1645, 1095, 5163, 7739, 26635, 28245, 9315, 100629, 0 };
            const std::uint32_t dim19084JoeKuoD6Init[]   =   { 1, 3, 1, 5, 1, 19, 69, 5, 171, 669, 673, 633, 6895, 7571, 11539, 25133, 99235, 7991, 0 };
            const std::uint32_t dim19085JoeKuoD6Init[]   =   { 1, 3, 5, 11, 21, 37, 63, 77, 281, 307, 1711, 2671, 1315, 14683, 28757, 22751, 56477, 190805, 0 };
            const std::uint32_t dim19086JoeKuoD6Init[]   =   { 1, 3, 3, 5, 15, 1, 5, 21, 199, 161, 655, 1263, 3315, 16051, 2409, 773, 9075, 121265, 0 };
            const std::uint32_t dim19087JoeKuoD6Init[]   =   { 1, 3, 3, 3, 7, 23, 71, 195, 11, 263, 1845, 165, 3489, 447, 11315, 23861, 110949, 78909, 0 };
            const std::uint32_t dim19088JoeKuoD6Init[]   =   { 1, 1, 7, 5, 1, 53, 37, 9, 439, 135, 909, 457, 6993, 11401, 14065, 30795, 56149, 168013, 0 };
            const std::uint32_t dim19089JoeKuoD6Init[]   =   { 1, 1, 1, 15, 23, 37, 13, 87, 113, 251, 233, 725, 7757, 14399, 3023, 54277, 87879, 54053, 0 };
            const std::uint32_t dim19090JoeKuoD6Init[]   =   { 1, 3, 5, 11, 11, 57, 109, 171, 171, 17, 343, 2749, 6525, 9735, 11715, 23783, 54439, 82819, 0 };
            const std::uint32_t dim19091JoeKuoD6Init[]   =   { 1, 1, 1, 15, 3, 47, 73, 237, 399, 301, 947, 2055, 1909, 14105, 26893, 47805, 25, 172957, 0 };
            const std::uint32_t dim19092JoeKuoD6Init[]   =   { 1, 1, 7, 7, 11, 27, 93, 167, 117, 637, 351, 319, 4605, 12897, 31001, 39655, 53551, 246113, 0 };
            const std::uint32_t dim19093JoeKuoD6Init[]   =   { 1, 3, 5, 15, 3, 37, 25, 9, 421, 519, 257, 3251, 1649, 4069, 999, 59367, 112383, 32095, 0 };
            const std::uint32_t dim19094JoeKuoD6Init[]   =   { 1, 3, 7, 7, 25, 57, 11, 37, 271, 545, 1213, 1927, 6471, 5145, 22995, 51051, 126981, 260457, 0 };
            const std::uint32_t dim19095JoeKuoD6Init[]   =   { 1, 3, 5, 11, 1, 61, 77, 201, 395, 199, 477, 103, 4069, 7003, 26371, 49145, 103839, 195661, 0 };
            const std::uint32_t dim19096JoeKuoD6Init[]   =   { 1, 3, 3, 9, 13, 41, 25, 125, 161, 371, 179, 351, 7169, 7179, 21627, 57793, 104679, 158583, 0 };
            const std::uint32_t dim19097JoeKuoD6Init[]   =   { 1, 3, 7, 11, 5, 7, 111, 163, 201, 783, 189, 273, 2751, 13917, 28501, 18261, 12755, 15521, 0 };
            const std::uint32_t dim19098JoeKuoD6Init[]   =   { 1, 1, 5, 7, 3, 37, 121, 209, 503, 299, 1301, 3703, 2321, 99, 14953, 28087, 85059, 256911, 0 };
            const std::uint32_t dim19099JoeKuoD6Init[]   =   { 1, 3, 3, 13, 3, 29, 95, 249, 383, 971, 1291, 13, 1587, 3447, 26477, 15837, 111141, 73899, 0 };
            const std::uint32_t dim19100JoeKuoD6Init[]   =   { 1, 1, 7, 1, 17, 57, 31, 1, 219, 329, 19, 3841, 1829, 5179, 14945, 6625, 3783, 200583, 0 };
            const std::uint32_t dim19101JoeKuoD6Init[]   =   { 1, 3, 1, 3, 1, 31, 23, 17, 209, 383, 297, 3065, 4323, 7847, 30189, 56541, 57535, 24853, 0 };
            const std::uint32_t dim19102JoeKuoD6Init[]   =   { 1, 1, 3, 11, 31, 35, 125, 141, 251, 79, 161, 775, 2455, 6959, 26433, 39145, 26563, 665, 0 };
            const std::uint32_t dim19103JoeKuoD6Init[]   =   { 1, 1, 7, 1, 11, 9, 9, 211, 231, 723, 1337, 1713, 3779, 2001, 23451, 27107, 64297, 254943, 0 };
            const std::uint32_t dim19104JoeKuoD6Init[]   =   { 1, 3, 7, 15, 21, 55, 19, 159, 449, 837, 1259, 1851, 5061, 355, 21531, 63479, 114657, 139265, 0 };
            const std::uint32_t dim19105JoeKuoD6Init[]   =   { 1, 1, 1, 3, 11, 55, 103, 179, 363, 567, 421, 981, 7221, 2077, 19339, 1155, 67019, 218231, 0 };
            const std::uint32_t dim19106JoeKuoD6Init[]   =   { 1, 1, 7, 11, 3, 43, 55, 161, 347, 995, 1555, 3251, 1605, 13313, 4499, 19361, 60145, 71593, 0 };
            const std::uint32_t dim19107JoeKuoD6Init[]   =   { 1, 1, 5, 3, 9, 15, 119, 213, 455, 241, 857, 683, 1247, 13085, 23919, 20365, 16303, 73263, 0 };
            const std::uint32_t dim19108JoeKuoD6Init[]   =   { 1, 1, 3, 13, 25, 17, 45, 193, 375, 289, 1381, 3629, 3015, 15883, 20633, 7431, 108787, 233297, 0 };
            const std::uint32_t dim19109JoeKuoD6Init[]   =   { 1, 1, 1, 15, 21, 57, 105, 91, 233, 961, 1623, 3849, 711, 3857, 32657, 5935, 85113, 38287, 0 };
            const std::uint32_t dim19110JoeKuoD6Init[]   =   { 1, 3, 3, 3, 15, 31, 97, 217, 335, 385, 1661, 3927, 6849, 137, 28871, 56485, 32777, 260033, 0 };
            const std::uint32_t dim19111JoeKuoD6Init[]   =   { 1, 1, 3, 13, 5, 61, 19, 255, 123, 481, 1865, 1815, 3047, 173, 25363, 1277, 6453, 174405, 0 };
            const std::uint32_t dim19112JoeKuoD6Init[]   =   { 1, 3, 7, 13, 27, 9, 19, 21, 433, 857, 1931, 2927, 629, 7733, 13503, 48263, 67517, 26495, 0 };
            const std::uint32_t dim19113JoeKuoD6Init[]   =   { 1, 1, 1, 3, 5, 43, 61, 239, 81, 585, 187, 1123, 3319, 8699, 20925, 40815, 76575, 169383, 0 };
            const std::uint32_t dim19114JoeKuoD6Init[]   =   { 1, 3, 3, 3, 9, 49, 71, 225, 95, 365, 645, 237, 7829, 5727, 17031, 58971, 71415, 232423, 0 };
            const std::uint32_t dim19115JoeKuoD6Init[]   =   { 1, 3, 5, 9, 25, 49, 113, 47, 105, 609, 1557, 2099, 2129, 8663, 24811, 25505, 38153, 185821, 0 };
            const std::uint32_t dim19116JoeKuoD6Init[]   =   { 1, 3, 5, 13, 23, 55, 107, 17, 309, 807, 635, 1007, 6207, 3363, 7607, 25013, 4141, 171509, 0 };
            const std::uint32_t dim19117JoeKuoD6Init[]   =   { 1, 1, 1, 13, 27, 35, 31, 89, 109, 879, 1845, 3999, 5415, 8777, 9605, 29703, 28149, 36469, 0 };
            const std::uint32_t dim19118JoeKuoD6Init[]   =   { 1, 3, 1, 3, 13, 3, 51, 31, 479, 549, 1245, 2033, 961, 13893, 21829, 32791, 109497, 187425, 0 };
            const std::uint32_t dim19119JoeKuoD6Init[]   =   { 1, 1, 5, 3, 19, 5, 25, 187, 173, 869, 201, 3851, 7369, 6229, 16577, 45623, 19859, 209855, 0 };
            const std::uint32_t dim19120JoeKuoD6Init[]   =   { 1, 1, 7, 9, 1, 9, 53, 47, 289, 557, 999, 141, 3789, 3087, 30217, 24221, 81431, 157507, 0 };
            const std::uint32_t dim19121JoeKuoD6Init[]   =   { 1, 1, 3, 9, 1, 25, 11, 73, 155, 155, 621, 4047, 6759, 5641, 28147, 8523, 69439, 92613, 0 };
            const std::uint32_t dim19122JoeKuoD6Init[]   =   { 1, 3, 1, 5, 25, 23, 41, 79, 71, 793, 1381, 307, 7863, 16289, 28783, 5299, 128481, 222799, 0 };
            const std::uint32_t dim19123JoeKuoD6Init[]   =   { 1, 1, 7, 1, 17, 33, 117, 111, 15, 249, 1397, 1349, 4883, 6009, 3179, 33509, 56355, 31937, 0 };
            const std::uint32_t dim19124JoeKuoD6Init[]   =   { 1, 3, 5, 13, 29, 15, 41, 185, 91, 501, 571, 2889, 6901, 3875, 3737, 23657, 101587, 261181, 0 };
            const std::uint32_t dim19125JoeKuoD6Init[]   =   { 1, 1, 7, 9, 21, 49, 33, 143, 19, 203, 75, 1353, 585, 7719, 11311, 48989, 10803, 51743, 0 };
            const std::uint32_t dim19126JoeKuoD6Init[]   =   { 1, 1, 7, 13, 23, 31, 103, 209, 375, 817, 1461, 3657, 7931, 15893, 15065, 28721, 54299, 71147, 0 };
            const std::uint32_t dim19127JoeKuoD6Init[]   =   { 1, 3, 7, 7, 7, 25, 37, 173, 355, 499, 247, 459, 7701, 2219, 11703, 20631, 128857, 125367, 0 };
            const std::uint32_t dim19128JoeKuoD6Init[]   =   { 1, 1, 3, 5, 25, 61, 43, 135, 451, 667, 547, 443, 5071, 12671, 26975, 20131, 101545, 115281, 0 };
            const std::uint32_t dim19129JoeKuoD6Init[]   =   { 1, 3, 3, 5, 9, 19, 75, 133, 211, 585, 1283, 3397, 3181, 65, 20213, 47725, 101883, 194749, 0 };
            const std::uint32_t dim19130JoeKuoD6Init[]   =   { 1, 1, 1, 1, 19, 13, 75, 135, 111, 641, 765, 1631, 4711, 241, 15125, 38233, 95535, 177965, 0 };
            const std::uint32_t dim19131JoeKuoD6Init[]   =   { 1, 1, 7, 13, 31, 1, 91, 61, 299, 35, 1327, 3903, 6193, 5589, 6331, 6321, 105741, 89639, 0 };
            const std::uint32_t dim19132JoeKuoD6Init[]   =   { 1, 3, 3, 15, 1, 55, 11, 39, 171, 713, 973, 1827, 3487, 13057, 30775, 16881, 124989, 208193, 0 };
            const std::uint32_t dim19133JoeKuoD6Init[]   =   { 1, 3, 7, 1, 21, 29, 19, 75, 397, 755, 1601, 2907, 6861, 10377, 23127, 2443, 86545, 3841, 0 };
            const std::uint32_t dim19134JoeKuoD6Init[]   =   { 1, 3, 1, 11, 25, 33, 53, 195, 343, 425, 1523, 3051, 3115, 3205, 3457, 20521, 39187, 33307, 0 };
            const std::uint32_t dim19135JoeKuoD6Init[]   =   { 1, 3, 5, 1, 25, 23, 47, 5, 133, 511, 1549, 2691, 7861, 4987, 2877, 38693, 37491, 22481, 0 };
            const std::uint32_t dim19136JoeKuoD6Init[]   =   { 1, 1, 5, 15, 5, 55, 125, 231, 11, 451, 1443, 3865, 4115, 2379, 13675, 29953, 85721, 114859, 0 };
            const std::uint32_t dim19137JoeKuoD6Init[]   =   { 1, 3, 1, 15, 19, 37, 29, 75, 483, 785, 1933, 2435, 1811, 2787, 32653, 23159, 80993, 26867, 0 };
            const std::uint32_t dim19138JoeKuoD6Init[]   =   { 1, 1, 1, 15, 7, 27, 53, 99, 11, 693, 1085, 743, 939, 6461, 6391, 45913, 94037, 217039, 0 };
            const std::uint32_t dim19139JoeKuoD6Init[]   =   { 1, 3, 3, 9, 19, 37, 93, 77, 363, 125, 1675, 347, 5599, 7771, 23549, 39945, 106931, 127959, 0 };
            const std::uint32_t dim19140JoeKuoD6Init[]   =   { 1, 3, 1, 5, 27, 47, 107, 85, 31, 621, 1529, 2349, 7055, 889, 4663, 1705, 40011, 214775, 0 };
            const std::uint32_t dim19141JoeKuoD6Init[]   =   { 1, 3, 1, 5, 11, 47, 35, 13, 139, 783, 1009, 845, 4139, 14713, 24191, 17597, 124923, 219657, 0 };
            const std::uint32_t dim19142JoeKuoD6Init[]   =   { 1, 1, 7, 3, 3, 25, 63, 207, 361, 587, 763, 3027, 6523, 6783, 11203, 57313, 115397, 149921, 0 };
            const std::uint32_t dim19143JoeKuoD6Init[]   =   { 1, 1, 7, 1, 21, 55, 109, 183, 487, 869, 195, 83, 3675, 13103, 12383, 63519, 48379, 256443, 0 };
            const std::uint32_t dim19144JoeKuoD6Init[]   =   { 1, 3, 7, 13, 9, 21, 29, 163, 105, 871, 747, 2459, 7383, 439, 5223, 1655, 1469, 50345, 0 };
            const std::uint32_t dim19145JoeKuoD6Init[]   =   { 1, 3, 1, 1, 15, 63, 37, 159, 385, 795, 1369, 1973, 6119, 6027, 23913, 52475, 80827, 198261, 0 };
            const std::uint32_t dim19146JoeKuoD6Init[]   =   { 1, 3, 3, 11, 15, 5, 121, 231, 43, 907, 1621, 3895, 5075, 10865, 3123, 49657, 69827, 215813, 0 };
            const std::uint32_t dim19147JoeKuoD6Init[]   =   { 1, 3, 1, 15, 7, 41, 75, 105, 87, 899, 629, 1699, 5861, 9279, 30107, 37443, 7555, 64461, 0 };
            const std::uint32_t dim19148JoeKuoD6Init[]   =   { 1, 3, 1, 7, 9, 15, 119, 127, 121, 621, 1117, 1659, 605, 13705, 31181, 40063, 17257, 77645, 0 };
            const std::uint32_t dim19149JoeKuoD6Init[]   =   { 1, 1, 5, 5, 3, 37, 95, 237, 379, 375, 903, 257, 4425, 14191, 9185, 57133, 82067, 73521, 0 };
            const std::uint32_t dim19150JoeKuoD6Init[]   =   { 1, 1, 7, 15, 1, 43, 63, 45, 121, 669, 1775, 179, 7385, 3557, 17261, 379, 24759, 214831, 0 };
            const std::uint32_t dim19151JoeKuoD6Init[]   =   { 1, 1, 3, 9, 31, 5, 43, 153, 451, 573, 1623, 2831, 4483, 7219, 27657, 47111, 58165, 145799, 0 };
            const std::uint32_t dim19152JoeKuoD6Init[]   =   { 1, 1, 3, 11, 3, 11, 111, 83, 329, 807, 779, 1223, 6095, 7269, 22425, 19343, 11937, 10173, 0 };
            const std::uint32_t dim19153JoeKuoD6Init[]   =   { 1, 1, 1, 13, 27, 15, 7, 111, 37, 663, 51, 3759, 6321, 8253, 737, 59501, 109595, 177827, 0 };
            const std::uint32_t dim19154JoeKuoD6Init[]   =   { 1, 1, 3, 3, 29, 39, 79, 115, 307, 765, 331, 377, 1873, 14491, 11065, 11865, 76717, 29101, 0 };
            const std::uint32_t dim19155JoeKuoD6Init[]   =   { 1, 3, 7, 3, 21, 45, 97, 213, 309, 3, 483, 3933, 1043, 8519, 22517, 34675, 78819, 172479, 0 };
            const std::uint32_t dim19156JoeKuoD6Init[]   =   { 1, 3, 5, 3, 31, 51, 27, 137, 405, 427, 815, 43, 6551, 10971, 28589, 53077, 36639, 167661, 0 };
            const std::uint32_t dim19157JoeKuoD6Init[]   =   { 1, 3, 1, 3, 29, 5, 111, 19, 343, 21, 557, 4067, 1525, 12793, 11513, 48869, 78035, 171531, 0 };
            const std::uint32_t dim19158JoeKuoD6Init[]   =   { 1, 1, 5, 7, 25, 47, 53, 245, 135, 137, 1697, 2057, 3147, 15903, 26979, 2157, 43967, 207661, 0 };
            const std::uint32_t dim19159JoeKuoD6Init[]   =   { 1, 1, 5, 3, 25, 11, 15, 59, 511, 307, 757, 3275, 1299, 10373, 11943, 54169, 32417, 21645, 0 };
            const std::uint32_t dim19160JoeKuoD6Init[]   =   { 1, 3, 3, 11, 15, 15, 5, 137, 237, 741, 1613, 3565, 7359, 6181, 25953, 18137, 59759, 186693, 0 };
            const std::uint32_t dim19161JoeKuoD6Init[]   =   { 1, 3, 5, 3, 19, 13, 99, 167, 45, 71, 1683, 3635, 7603, 14879, 23903, 14795, 58395, 11853, 0 };
            const std::uint32_t dim19162JoeKuoD6Init[]   =   { 1, 3, 1, 7, 15, 45, 111, 111, 175, 567, 1031, 2255, 3895, 11861, 20195, 15461, 88411, 225713, 0 };
            const std::uint32_t dim19163JoeKuoD6Init[]   =   { 1, 1, 7, 3, 5, 5, 85, 65, 231, 643, 1591, 219, 2929, 4845, 29327, 14769, 46629, 131367, 0 };
            const std::uint32_t dim19164JoeKuoD6Init[]   =   { 1, 1, 5, 9, 29, 21, 47, 87, 113, 469, 1647, 2461, 3663, 5865, 6647, 41345, 39539, 220301, 0 };
            const std::uint32_t dim19165JoeKuoD6Init[]   =   { 1, 1, 5, 11, 9, 55, 5, 147, 141, 181, 283, 1695, 6537, 11095, 10385, 36013, 111653, 182273, 0 };
            const std::uint32_t dim19166JoeKuoD6Init[]   =   { 1, 1, 3, 5, 17, 45, 103, 253, 407, 151, 1585, 1585, 6661, 14579, 5723, 37641, 56813, 258819, 0 };
            const std::uint32_t dim19167JoeKuoD6Init[]   =   { 1, 3, 3, 3, 5, 63, 85, 201, 87, 419, 1993, 737, 5859, 6049, 17393, 9453, 65915, 1731, 0 };
            const std::uint32_t dim19168JoeKuoD6Init[]   =   { 1, 1, 3, 3, 3, 27, 97, 135, 137, 731, 1559, 3409, 5973, 15981, 19833, 8419, 33273, 44155, 0 };
            const std::uint32_t dim19169JoeKuoD6Init[]   =   { 1, 3, 3, 9, 31, 55, 109, 191, 119, 59, 645, 1047, 7767, 8379, 13781, 52289, 31605, 186667, 0 };
            const std::uint32_t dim19170JoeKuoD6Init[]   =   { 1, 3, 1, 15, 9, 1, 23, 31, 23, 311, 1879, 1939, 5509, 14573, 10501, 38867, 39131, 231151, 0 };
            const std::uint32_t dim19171JoeKuoD6Init[]   =   { 1, 3, 7, 1, 31, 33, 33, 19, 475, 723, 795, 1793, 6639, 14349, 16639, 31473, 110411, 95703, 0 };
            const std::uint32_t dim19172JoeKuoD6Init[]   =   { 1, 1, 5, 9, 11, 3, 39, 119, 455, 839, 513, 2423, 2219, 6059, 6125, 60995, 117701, 204057, 0 };
            const std::uint32_t dim19173JoeKuoD6Init[]   =   { 1, 1, 1, 9, 5, 23, 87, 33, 59, 241, 1427, 3867, 1091, 14683, 21651, 7091, 38011, 63809, 0 };
            const std::uint32_t dim19174JoeKuoD6Init[]   =   { 1, 1, 7, 15, 15, 23, 75, 227, 415, 1015, 2033, 1311, 6659, 5093, 14799, 65331, 96989, 170395, 0 };
            const std::uint32_t dim19175JoeKuoD6Init[]   =   { 1, 3, 5, 15, 25, 61, 33, 179, 503, 875, 1853, 257, 6727, 9117, 16777, 29585, 110901, 231617, 0 };
            const std::uint32_t dim19176JoeKuoD6Init[]   =   { 1, 1, 1, 15, 13, 53, 73, 151, 315, 887, 669, 3959, 5279, 1461, 15497, 40107, 9595, 252059, 0 };
            const std::uint32_t dim19177JoeKuoD6Init[]   =   { 1, 3, 7, 13, 17, 45, 43, 61, 99, 555, 981, 3255, 6385, 8723, 24451, 45243, 68617, 171911, 0 };
            const std::uint32_t dim19178JoeKuoD6Init[]   =   { 1, 3, 3, 11, 1, 29, 97, 219, 341, 597, 503, 773, 3777, 5431, 4581, 37169, 57269, 186377, 0 };
            const std::uint32_t dim19179JoeKuoD6Init[]   =   { 1, 3, 1, 11, 15, 49, 119, 189, 279, 821, 1541, 1343, 4379, 5833, 26537, 29769, 121125, 202553, 0 };
            const std::uint32_t dim19180JoeKuoD6Init[]   =   { 1, 3, 5, 9, 19, 23, 5, 197, 323, 101, 1155, 7, 5933, 3111, 19595, 36807, 40147, 153, 0 };
            const std::uint32_t dim19181JoeKuoD6Init[]   =   { 1, 1, 5, 11, 17, 9, 83, 51, 185, 415, 367, 1431, 7803, 8253, 16283, 54545, 99733, 57777, 0 };
            const std::uint32_t dim19182JoeKuoD6Init[]   =   { 1, 1, 5, 7, 5, 31, 41, 13, 33, 531, 1381, 781, 1699, 6321, 18125, 34567, 113253, 104181, 0 };
            const std::uint32_t dim19183JoeKuoD6Init[]   =   { 1, 3, 1, 5, 1, 59, 37, 239, 343, 395, 121, 2181, 2485, 13825, 19127, 22689, 103023, 198213, 0 };
            const std::uint32_t dim19184JoeKuoD6Init[]   =   { 1, 3, 1, 15, 29, 17, 11, 27, 413, 273, 1805, 2845, 8147, 10301, 5423, 29859, 85243, 190379, 0 };
            const std::uint32_t dim19185JoeKuoD6Init[]   =   { 1, 3, 1, 15, 7, 61, 29, 135, 273, 951, 725, 1345, 4231, 13651, 31291, 6081, 85735, 96023, 0 };
            const std::uint32_t dim19186JoeKuoD6Init[]   =   { 1, 1, 3, 11, 15, 29, 81, 129, 245, 295, 527, 3905, 4323, 5447, 21253, 51177, 105105, 48323, 0 };
            const std::uint32_t dim19187JoeKuoD6Init[]   =   { 1, 1, 3, 13, 13, 45, 71, 43, 383, 95, 1689, 639, 4631, 15113, 28053, 49247, 128303, 183999, 0 };
            const std::uint32_t dim19188JoeKuoD6Init[]   =   { 1, 1, 1, 3, 19, 31, 93, 35, 369, 765, 1201, 1625, 7683, 8719, 13843, 42723, 62323, 49431, 0 };
            const std::uint32_t dim19189JoeKuoD6Init[]   =   { 1, 3, 3, 11, 5, 39, 49, 217, 109, 63, 1753, 2489, 6017, 403, 16657, 59577, 80255, 66071, 0 };
            const std::uint32_t dim19190JoeKuoD6Init[]   =   { 1, 3, 5, 5, 11, 1, 79, 37, 261, 537, 1845, 3567, 3233, 16249, 9795, 2471, 69661, 118231, 0 };
            const std::uint32_t dim19191JoeKuoD6Init[]   =   { 1, 3, 3, 1, 19, 61, 35, 253, 31, 19, 161, 2597, 5733, 8231, 26569, 38613, 121945, 137391, 0 };
            const std::uint32_t dim19192JoeKuoD6Init[]   =   { 1, 3, 7, 3, 15, 25, 125, 231, 187, 797, 1237, 1767, 1557, 1095, 13613, 43325, 33801, 127881, 0 };
            const std::uint32_t dim19193JoeKuoD6Init[]   =   { 1, 1, 1, 9, 23, 63, 75, 107, 311, 493, 471, 2985, 1861, 4285, 27125, 14961, 122567, 152033, 0 };
            const std::uint32_t dim19194JoeKuoD6Init[]   =   { 1, 3, 5, 7, 9, 7, 43, 117, 203, 727, 101, 3831, 3201, 2327, 4675, 12085, 25131, 211835, 0 };
            const std::uint32_t dim19195JoeKuoD6Init[]   =   { 1, 1, 7, 11, 17, 1, 5, 87, 291, 1023, 1345, 3879, 7739, 9201, 19573, 20037, 128711, 187263, 0 };
            const std::uint32_t dim19196JoeKuoD6Init[]   =   { 1, 1, 3, 13, 25, 39, 71, 251, 365, 617, 1539, 2121, 3803, 8003, 23393, 56991, 56143, 223453, 0 };
            const std::uint32_t dim19197JoeKuoD6Init[]   =   { 1, 3, 5, 13, 25, 61, 71, 139, 319, 399, 903, 3063, 3667, 275, 13297, 25285, 120417, 169613, 0 };
            const std::uint32_t dim19198JoeKuoD6Init[]   =   { 1, 3, 1, 9, 9, 41, 59, 213, 195, 705, 313, 2313, 4993, 323, 24049, 30527, 27287, 80489, 0 };
            const std::uint32_t dim19199JoeKuoD6Init[]   =   { 1, 1, 5, 1, 29, 57, 107, 161, 217, 295, 721, 3857, 1935, 14981, 12243, 38541, 51177, 248889, 0 };
            const std::uint32_t dim19200JoeKuoD6Init[]   =   { 1, 1, 1, 15, 5, 25, 95, 137, 11, 215, 971, 1573, 4341, 4725, 8201, 33147, 87687, 187405, 0 };
            const std::uint32_t dim19201JoeKuoD6Init[]   =   { 1, 3, 3, 9, 9, 13, 31, 3, 175, 309, 145, 2265, 4863, 7199, 23881, 15445, 123753, 126653, 0 };
            const std::uint32_t dim19202JoeKuoD6Init[]   =   { 1, 1, 7, 3, 7, 43, 51, 191, 21, 639, 939, 691, 7823, 10529, 7757, 9291, 115045, 51539, 0 };
            const std::uint32_t dim19203JoeKuoD6Init[]   =   { 1, 1, 7, 13, 7, 45, 91, 173, 73, 779, 1647, 2059, 1373, 16027, 4611, 45787, 699, 78905, 0 };
            const std::uint32_t dim19204JoeKuoD6Init[]   =   { 1, 1, 5, 15, 5, 23, 123, 45, 265, 1009, 235, 1343, 5779, 209, 23263, 63163, 26079, 240905, 0 };
            const std::uint32_t dim19205JoeKuoD6Init[]   =   { 1, 1, 1, 11, 19, 31, 75, 105, 71, 21, 1361, 2125, 6949, 2111, 10333, 61881, 112811, 85723, 0 };
            const std::uint32_t dim19206JoeKuoD6Init[]   =   { 1, 3, 5, 7, 27, 17, 95, 35, 503, 181, 1885, 1097, 6019, 13745, 15009, 26343, 117727, 93017, 0 };
            const std::uint32_t dim19207JoeKuoD6Init[]   =   { 1, 1, 3, 11, 27, 41, 109, 23, 365, 283, 1509, 3269, 5969, 14567, 27715, 429, 65813, 169391, 0 };
            const std::uint32_t dim19208JoeKuoD6Init[]   =   { 1, 1, 5, 9, 11, 1, 23, 143, 401, 61, 993, 3029, 1901, 12947, 10439, 48661, 113863, 9353, 0 };
            const std::uint32_t dim19209JoeKuoD6Init[]   =   { 1, 3, 7, 3, 15, 27, 123, 51, 403, 569, 75, 3837, 8167, 10875, 29861, 44133, 52385, 185515, 0 };
            const std::uint32_t dim19210JoeKuoD6Init[]   =   { 1, 3, 3, 15, 15, 45, 3, 77, 439, 265, 103, 3715, 7889, 9241, 26511, 19063, 108239, 237233, 0 };
            const std::uint32_t dim19211JoeKuoD6Init[]   =   { 1, 1, 5, 13, 7, 47, 7, 185, 155, 833, 1895, 1103, 6761, 4307, 19551, 2371, 41079, 207663, 0 };
            const std::uint32_t dim19212JoeKuoD6Init[]   =   { 1, 1, 3, 7, 1, 49, 79, 127, 149, 383, 919, 3787, 6703, 8823, 15551, 28397, 11497, 144227, 0 };
            const std::uint32_t dim19213JoeKuoD6Init[]   =   { 1, 1, 7, 15, 7, 5, 9, 161, 425, 275, 1943, 3003, 3615, 1417, 587, 20949, 9651, 101257, 0 };
            const std::uint32_t dim19214JoeKuoD6Init[]   =   { 1, 3, 5, 11, 31, 11, 113, 201, 113, 889, 867, 3537, 7173, 3403, 4713, 29709, 50127, 55893, 0 };
            const std::uint32_t dim19215JoeKuoD6Init[]   =   { 1, 3, 7, 11, 11, 17, 123, 97, 3, 1009, 1567, 3261, 8053, 4639, 24493, 64085, 73975, 123965, 0 };
            const std::uint32_t dim19216JoeKuoD6Init[]   =   { 1, 1, 7, 1, 31, 7, 111, 137, 427, 615, 865, 2243, 3603, 5943, 1639, 22213, 81977, 77283, 0 };
            const std::uint32_t dim19217JoeKuoD6Init[]   =   { 1, 1, 5, 11, 25, 63, 5, 19, 67, 469, 621, 2831, 1635, 11859, 23143, 29189, 43955, 87475, 0 };
            const std::uint32_t dim19218JoeKuoD6Init[]   =   { 1, 3, 7, 15, 7, 61, 125, 207, 401, 567, 1943, 2645, 641, 15427, 24467, 41767, 122591, 48905, 0 };
            const std::uint32_t dim19219JoeKuoD6Init[]   =   { 1, 3, 3, 5, 1, 61, 65, 169, 329, 489, 435, 1719, 491, 6189, 18383, 34973, 90611, 180991, 0 };
            const std::uint32_t dim19220JoeKuoD6Init[]   =   { 1, 3, 7, 9, 25, 43, 115, 11, 289, 193, 263, 3885, 4881, 15669, 19757, 20073, 119873, 67069, 0 };
            const std::uint32_t dim19221JoeKuoD6Init[]   =   { 1, 1, 7, 11, 3, 45, 93, 115, 233, 891, 1541, 2557, 2115, 2237, 4253, 30445, 32983, 86185, 0 };
            const std::uint32_t dim19222JoeKuoD6Init[]   =   { 1, 3, 7, 3, 29, 23, 105, 51, 157, 505, 773, 2403, 1237, 5193, 32725, 53331, 66377, 25745, 0 };
            const std::uint32_t dim19223JoeKuoD6Init[]   =   { 1, 3, 5, 11, 31, 5, 111, 251, 287, 225, 913, 97, 3429, 15111, 10637, 18843, 102589, 229667, 0 };
            const std::uint32_t dim19224JoeKuoD6Init[]   =   { 1, 3, 7, 13, 21, 43, 27, 11, 265, 991, 1645, 1967, 2675, 3083, 2957, 65275, 7757, 201953, 0 };
            const std::uint32_t dim19225JoeKuoD6Init[]   =   { 1, 3, 7, 7, 23, 59, 37, 105, 113, 961, 1585, 855, 6037, 8461, 24057, 46861, 42421, 21061, 0 };
            const std::uint32_t dim19226JoeKuoD6Init[]   =   { 1, 1, 5, 1, 7, 45, 37, 147, 225, 793, 737, 753, 565, 5347, 15393, 42611, 39253, 246455, 0 };
            const std::uint32_t dim19227JoeKuoD6Init[]   =   { 1, 3, 3, 5, 29, 59, 125, 69, 283, 677, 1615, 3341, 219, 10753, 445, 43343, 117035, 137907, 0 };
            const std::uint32_t dim19228JoeKuoD6Init[]   =   { 1, 1, 5, 1, 19, 41, 93, 137, 481, 93, 703, 1211, 4051, 5591, 5913, 32831, 62027, 60519, 0 };
            const std::uint32_t dim19229JoeKuoD6Init[]   =   { 1, 1, 7, 13, 17, 63, 65, 147, 361, 83, 1383, 1761, 579, 9493, 2611, 6951, 12197, 81857, 0 };
            const std::uint32_t dim19230JoeKuoD6Init[]   =   { 1, 3, 3, 15, 11, 3, 25, 7, 221, 211, 1745, 1173, 5479, 12063, 5667, 43443, 4865, 193345, 0 };
            const std::uint32_t dim19231JoeKuoD6Init[]   =   { 1, 1, 5, 11, 31, 11, 71, 61, 57, 851, 1089, 1395, 4525, 1223, 27681, 14355, 23125, 257233, 0 };
            const std::uint32_t dim19232JoeKuoD6Init[]   =   { 1, 3, 1, 11, 25, 59, 17, 193, 229, 1005, 387, 3993, 2457, 4185, 18421, 1315, 125155, 142277, 0 };
            const std::uint32_t dim19233JoeKuoD6Init[]   =   { 1, 1, 5, 11, 13, 55, 123, 191, 5, 1023, 705, 3481, 367, 12961, 11917, 12131, 99109, 105093, 0 };
            const std::uint32_t dim19234JoeKuoD6Init[]   =   { 1, 1, 3, 11, 13, 29, 57, 57, 467, 19, 1409, 971, 3041, 13487, 24737, 3377, 97883, 248893, 0 };
            const std::uint32_t dim19235JoeKuoD6Init[]   =   { 1, 3, 7, 3, 3, 37, 109, 77, 201, 469, 39, 1747, 2027, 14781, 18821, 34647, 123865, 195097, 0 };
            const std::uint32_t dim19236JoeKuoD6Init[]   =   { 1, 3, 3, 5, 29, 27, 97, 217, 249, 141, 431, 1621, 539, 8945, 3443, 48227, 27867, 205355, 0 };
            const std::uint32_t dim19237JoeKuoD6Init[]   =   { 1, 1, 3, 13, 7, 57, 65, 167, 103, 511, 239, 325, 1793, 2811, 14223, 40999, 12589, 149759, 0 };
            const std::uint32_t dim19238JoeKuoD6Init[]   =   { 1, 3, 5, 11, 3, 1, 61, 87, 283, 29, 507, 3473, 2685, 13829, 32337, 8413, 12201, 152309, 0 };
            const std::uint32_t dim19239JoeKuoD6Init[]   =   { 1, 3, 5, 15, 1, 23, 103, 173, 423, 915, 1519, 1859, 7341, 8689, 17141, 53769, 81189, 144305, 0 };
            const std::uint32_t dim19240JoeKuoD6Init[]   =   { 1, 1, 1, 5, 31, 41, 89, 117, 329, 245, 381, 3357, 1053, 15079, 3569, 27665, 65645, 259279, 0 };
            const std::uint32_t dim19241JoeKuoD6Init[]   =   { 1, 1, 7, 5, 3, 55, 91, 35, 463, 15, 1195, 533, 6013, 10755, 1919, 61169, 81285, 82757, 0 };
            const std::uint32_t dim19242JoeKuoD6Init[]   =   { 1, 3, 5, 11, 3, 29, 85, 169, 163, 733, 939, 3401, 3709, 3307, 17329, 56873, 10721, 174235, 0 };
            const std::uint32_t dim19243JoeKuoD6Init[]   =   { 1, 1, 5, 1, 11, 45, 75, 247, 435, 21, 1985, 2261, 7013, 4935, 2457, 41077, 53121, 143269, 0 };
            const std::uint32_t dim19244JoeKuoD6Init[]   =   { 1, 3, 3, 13, 17, 59, 43, 149, 27, 1, 367, 957, 5607, 2591, 22161, 10095, 73769, 52455, 0 };
            const std::uint32_t dim19245JoeKuoD6Init[]   =   { 1, 1, 3, 13, 15, 15, 121, 83, 469, 819, 1973, 3595, 2313, 1621, 3105, 42971, 7243, 98727, 0 };
            const std::uint32_t dim19246JoeKuoD6Init[]   =   { 1, 1, 5, 7, 21, 53, 123, 9, 119, 437, 1567, 431, 3647, 10967, 22037, 8523, 81279, 126473, 0 };
            const std::uint32_t dim19247JoeKuoD6Init[]   =   { 1, 1, 5, 13, 5, 23, 125, 119, 195, 555, 341, 2037, 313, 6323, 27201, 8377, 122793, 197781, 0 };
            const std::uint32_t dim19248JoeKuoD6Init[]   =   { 1, 3, 3, 5, 17, 25, 67, 237, 349, 443, 1529, 3541, 3105, 10105, 13409, 20165, 64597, 244513, 0 };
            const std::uint32_t dim19249JoeKuoD6Init[]   =   { 1, 1, 5, 1, 11, 43, 77, 245, 359, 625, 1171, 597, 3, 591, 2457, 20275, 75995, 204685, 0 };
            const std::uint32_t dim19250JoeKuoD6Init[]   =   { 1, 3, 1, 11, 5, 13, 99, 107, 285, 617, 1687, 2959, 4439, 771, 3103, 62363, 89437, 172221, 0 };
            const std::uint32_t dim19251JoeKuoD6Init[]   =   { 1, 3, 1, 11, 1, 63, 43, 85, 23, 95, 501, 1223, 669, 16101, 1071, 53175, 102101, 419, 0 };
            const std::uint32_t dim19252JoeKuoD6Init[]   =   { 1, 3, 1, 5, 19, 23, 63, 105, 289, 419, 885, 441, 5107, 4213, 8683, 1847, 113301, 240821, 0 };
            const std::uint32_t dim19253JoeKuoD6Init[]   =   { 1, 1, 1, 9, 9, 9, 111, 63, 53, 531, 517, 3463, 8171, 2645, 13883, 52213, 40707, 24637, 0 };
            const std::uint32_t dim19254JoeKuoD6Init[]   =   { 1, 3, 1, 5, 15, 43, 71, 215, 117, 685, 1819, 1105, 5805, 8875, 31093, 31077, 93807, 65631, 0 };
            const std::uint32_t dim19255JoeKuoD6Init[]   =   { 1, 1, 7, 7, 17, 15, 31, 87, 13, 615, 2003, 3461, 7585, 1947, 6693, 26141, 95059, 52229, 0 };
            const std::uint32_t dim19256JoeKuoD6Init[]   =   { 1, 1, 3, 5, 5, 55, 7, 41, 473, 541, 545, 2901, 763, 12731, 24715, 43301, 7981, 123961, 0 };
            const std::uint32_t dim19257JoeKuoD6Init[]   =   { 1, 3, 1, 11, 13, 29, 65, 47, 511, 931, 1681, 3813, 995, 4261, 32243, 21327, 33749, 52607, 0 };
            const std::uint32_t dim19258JoeKuoD6Init[]   =   { 1, 1, 3, 1, 27, 51, 19, 119, 71, 989, 485, 1483, 4115, 11743, 5513, 32447, 62599, 163185, 0 };
            const std::uint32_t dim19259JoeKuoD6Init[]   =   { 1, 3, 7, 13, 7, 5, 127, 67, 221, 773, 1641, 3763, 2061, 2025, 29813, 64385, 109219, 70149, 0 };
            const std::uint32_t dim19260JoeKuoD6Init[]   =   { 1, 1, 5, 15, 9, 29, 105, 245, 333, 11, 803, 1877, 6735, 3797, 1913, 63837, 23649, 234721, 0 };
            const std::uint32_t dim19261JoeKuoD6Init[]   =   { 1, 3, 7, 13, 11, 21, 113, 175, 385, 885, 1259, 983, 7715, 11889, 12515, 35723, 9897, 63415, 0 };
            const std::uint32_t dim19262JoeKuoD6Init[]   =   { 1, 1, 5, 9, 31, 63, 53, 51, 375, 133, 2021, 3173, 3861, 9885, 4117, 37505, 73687, 16411, 0 };
            const std::uint32_t dim19263JoeKuoD6Init[]   =   { 1, 3, 7, 7, 11, 13, 99, 235, 285, 159, 489, 917, 3033, 7711, 6545, 52893, 28549, 68791, 0 };
            const std::uint32_t dim19264JoeKuoD6Init[]   =   { 1, 1, 5, 11, 31, 15, 89, 157, 105, 347, 455, 3391, 5341, 16035, 11819, 57679, 48057, 147673, 0 };
            const std::uint32_t dim19265JoeKuoD6Init[]   =   { 1, 3, 1, 5, 21, 5, 1, 41, 213, 677, 1745, 2591, 6237, 14265, 5963, 30017, 47293, 199411, 0 };
            const std::uint32_t dim19266JoeKuoD6Init[]   =   { 1, 3, 1, 15, 19, 9, 65, 103, 489, 977, 579, 2571, 2827, 12971, 24445, 17963, 68829, 89781, 0 };
            const std::uint32_t dim19267JoeKuoD6Init[]   =   { 1, 3, 5, 7, 3, 45, 9, 223, 137, 749, 919, 2695, 7569, 6735, 16649, 55899, 91531, 10709, 0 };
            const std::uint32_t dim19268JoeKuoD6Init[]   =   { 1, 1, 5, 11, 25, 51, 81, 243, 473, 85, 1189, 2317, 785, 9307, 25555, 36623, 66881, 150945, 0 };
            const std::uint32_t dim19269JoeKuoD6Init[]   =   { 1, 1, 3, 7, 9, 17, 99, 57, 333, 891, 71, 2359, 2067, 13265, 30077, 17935, 47343, 22673, 0 };
            const std::uint32_t dim19270JoeKuoD6Init[]   =   { 1, 1, 5, 7, 13, 17, 77, 109, 427, 667, 1367, 2383, 7505, 11239, 14229, 35431, 35473, 62447, 0 };
            const std::uint32_t dim19271JoeKuoD6Init[]   =   { 1, 1, 1, 15, 27, 5, 51, 221, 471, 877, 449, 3961, 4197, 15713, 2955, 58985, 31431, 241539, 0 };
            const std::uint32_t dim19272JoeKuoD6Init[]   =   { 1, 1, 7, 1, 13, 61, 55, 199, 87, 679, 723, 271, 1061, 8043, 13163, 8079, 81501, 60467, 0 };
            const std::uint32_t dim19273JoeKuoD6Init[]   =   { 1, 1, 3, 3, 11, 1, 85, 65, 445, 731, 2017, 3113, 8085, 7133, 14789, 2435, 38459, 234997, 0 };
            const std::uint32_t dim19274JoeKuoD6Init[]   =   { 1, 3, 3, 9, 23, 31, 49, 137, 349, 651, 1975, 3429, 7137, 7841, 28297, 58209, 36493, 259097, 0 };
            const std::uint32_t dim19275JoeKuoD6Init[]   =   { 1, 1, 7, 15, 23, 11, 87, 133, 245, 445, 151, 4075, 141, 15395, 16649, 36925, 98421, 217265, 0 };
            const std::uint32_t dim19276JoeKuoD6Init[]   =   { 1, 3, 3, 5, 25, 53, 57, 177, 481, 177, 671, 1249, 2663, 12855, 24537, 31867, 110323, 164113, 0 };
            const std::uint32_t dim19277JoeKuoD6Init[]   =   { 1, 3, 5, 7, 23, 25, 19, 91, 447, 1023, 373, 3863, 4399, 12973, 7475, 37485, 8567, 53271, 0 };
            const std::uint32_t dim19278JoeKuoD6Init[]   =   { 1, 1, 5, 7, 31, 33, 31, 75, 223, 299, 1549, 1863, 353, 4339, 8891, 10365, 3399, 185807, 0 };
            const std::uint32_t dim19279JoeKuoD6Init[]   =   { 1, 1, 7, 9, 31, 53, 23, 203, 319, 915, 1923, 205, 3119, 7243, 25251, 12907, 101921, 102695, 0 };
            const std::uint32_t dim19280JoeKuoD6Init[]   =   { 1, 1, 7, 9, 15, 1, 123, 173, 123, 215, 263, 3003, 5881, 1117, 15195, 47457, 66663, 224177, 0 };
            const std::uint32_t dim19281JoeKuoD6Init[]   =   { 1, 1, 7, 13, 11, 25, 61, 121, 173, 115, 1897, 2145, 7783, 9673, 3321, 1707, 61475, 53875, 0 };
            const std::uint32_t dim19282JoeKuoD6Init[]   =   { 1, 3, 7, 3, 31, 21, 27, 99, 421, 225, 1565, 2351, 2275, 10583, 7877, 43505, 27629, 140919, 0 };
            const std::uint32_t dim19283JoeKuoD6Init[]   =   { 1, 3, 5, 5, 11, 45, 71, 105, 487, 867, 361, 3995, 2039, 1495, 27481, 4753, 20657, 67077, 0 };
            const std::uint32_t dim19284JoeKuoD6Init[]   =   { 1, 1, 5, 1, 19, 33, 1, 77, 377, 353, 719, 1463, 7053, 7409, 32165, 15557, 117673, 69887, 0 };
            const std::uint32_t dim19285JoeKuoD6Init[]   =   { 1, 1, 5, 7, 25, 5, 15, 231, 23, 213, 1627, 1801, 7793, 651, 9903, 51745, 111611, 39679, 0 };
            const std::uint32_t dim19286JoeKuoD6Init[]   =   { 1, 3, 3, 5, 23, 43, 37, 199, 437, 19, 1853, 2119, 461, 12641, 15865, 39941, 122545, 213443, 0 };
            const std::uint32_t dim19287JoeKuoD6Init[]   =   { 1, 3, 3, 11, 31, 45, 19, 227, 507, 909, 1501, 2021, 905, 1763, 1897, 3735, 81475, 30005, 0 };
            const std::uint32_t dim19288JoeKuoD6Init[]   =   { 1, 1, 5, 5, 29, 9, 55, 25, 23, 59, 593, 2197, 6029, 8235, 8397, 27521, 96221, 168837, 0 };
            const std::uint32_t dim19289JoeKuoD6Init[]   =   { 1, 3, 1, 15, 5, 33, 75, 121, 433, 557, 1011, 3785, 2545, 953, 17295, 14407, 94871, 60445, 0 };
            const std::uint32_t dim19290JoeKuoD6Init[]   =   { 1, 3, 3, 7, 7, 53, 29, 75, 171, 587, 1701, 3815, 2761, 4403, 39, 17291, 34897, 187257, 0 };
            const std::uint32_t dim19291JoeKuoD6Init[]   =   { 1, 3, 1, 15, 17, 57, 11, 95, 335, 13, 265, 1161, 7945, 6419, 26723, 31907, 89995, 82265, 0 };
            const std::uint32_t dim19292JoeKuoD6Init[]   =   { 1, 1, 7, 5, 9, 59, 27, 153, 37, 165, 823, 3525, 621, 4777, 3485, 9109, 116567, 34691, 0 };
            const std::uint32_t dim19293JoeKuoD6Init[]   =   { 1, 1, 5, 13, 23, 27, 11, 63, 35, 39, 995, 2101, 2611, 14139, 2683, 63787, 19813, 97497, 0 };
            const std::uint32_t dim19294JoeKuoD6Init[]   =   { 1, 3, 7, 15, 31, 15, 3, 163, 167, 53, 71, 1881, 4213, 3485, 21525, 705, 122345, 203549, 0 };
            const std::uint32_t dim19295JoeKuoD6Init[]   =   { 1, 3, 5, 5, 21, 33, 85, 133, 21, 505, 1639, 3989, 771, 7171, 21953, 34503, 31247, 247459, 0 };
            const std::uint32_t dim19296JoeKuoD6Init[]   =   { 1, 1, 7, 7, 31, 1, 27, 39, 469, 243, 679, 4091, 7137, 8505, 13329, 34139, 69485, 259795, 0 };
            const std::uint32_t dim19297JoeKuoD6Init[]   =   { 1, 3, 5, 5, 31, 43, 31, 161, 413, 657, 1407, 1417, 7349, 3301, 7691, 49355, 22929, 68043, 0 };
            const std::uint32_t dim19298JoeKuoD6Init[]   =   { 1, 1, 7, 11, 15, 61, 73, 217, 163, 503, 193, 3795, 41, 16251, 1187, 65363, 113211, 100337, 0 };
            const std::uint32_t dim19299JoeKuoD6Init[]   =   { 1, 3, 1, 11, 9, 15, 109, 187, 109, 865, 845, 1579, 321, 1269, 20613, 5693, 58421, 254959, 0 };
            const std::uint32_t dim19300JoeKuoD6Init[]   =   { 1, 3, 1, 13, 11, 3, 19, 135, 93, 779, 1383, 219, 2737, 377, 1125, 35663, 130815, 103797, 0 };
            const std::uint32_t dim19301JoeKuoD6Init[]   =   { 1, 1, 5, 11, 25, 25, 71, 249, 201, 679, 1677, 1817, 7619, 10327, 14821, 47847, 33629, 250979, 0 };
            const std::uint32_t dim19302JoeKuoD6Init[]   =   { 1, 1, 7, 15, 23, 19, 69, 39, 25, 843, 99, 3499, 2457, 11681, 30009, 17609, 46653, 162427, 0 };
            const std::uint32_t dim19303JoeKuoD6Init[]   =   { 1, 3, 3, 7, 23, 25, 77, 135, 61, 501, 1381, 3977, 1957, 11255, 16053, 30297, 58835, 97589, 0 };
            const std::uint32_t dim19304JoeKuoD6Init[]   =   { 1, 3, 5, 3, 9, 31, 9, 55, 421, 109, 1823, 1921, 7349, 2661, 4503, 36691, 48843, 182631, 0 };
            const std::uint32_t dim19305JoeKuoD6Init[]   =   { 1, 1, 1, 11, 7, 23, 107, 125, 393, 105, 1407, 3461, 4539, 6121, 7881, 32407, 83749, 98831, 0 };
            const std::uint32_t dim19306JoeKuoD6Init[]   =   { 1, 3, 3, 13, 5, 59, 5, 3, 185, 959, 241, 819, 1443, 1789, 12771, 26703, 25399, 182583, 0 };
            const std::uint32_t dim19307JoeKuoD6Init[]   =   { 1, 1, 1, 3, 3, 47, 7, 45, 93, 373, 175, 87, 649, 12903, 5029, 1945, 111967, 140889, 0 };
            const std::uint32_t dim19308JoeKuoD6Init[]   =   { 1, 3, 1, 11, 9, 47, 25, 191, 215, 845, 1557, 9, 3451, 5837, 11763, 29127, 113115, 99039, 0 };
            const std::uint32_t dim19309JoeKuoD6Init[]   =   { 1, 1, 1, 5, 23, 53, 45, 1, 361, 751, 807, 1765, 685, 2109, 28437, 60489, 65739, 234511, 0 };
            const std::uint32_t dim19310JoeKuoD6Init[]   =   { 1, 3, 3, 7, 15, 57, 71, 61, 195, 123, 1745, 3249, 351, 14309, 2017, 15653, 110803, 45937, 0 };
            const std::uint32_t dim19311JoeKuoD6Init[]   =   { 1, 3, 7, 9, 25, 11, 25, 29, 467, 313, 1927, 2423, 7311, 14299, 8145, 8123, 115103, 213881, 0 };
            const std::uint32_t dim19312JoeKuoD6Init[]   =   { 1, 1, 3, 15, 1, 35, 111, 99, 507, 417, 1433, 129, 5565, 13365, 18853, 8607, 109739, 120623, 0 };
            const std::uint32_t dim19313JoeKuoD6Init[]   =   { 1, 1, 1, 7, 13, 31, 93, 3, 327, 67, 1101, 1965, 5939, 6505, 3117, 3021, 33707, 79353, 0 };
            const std::uint32_t dim19314JoeKuoD6Init[]   =   { 1, 1, 3, 7, 15, 21, 23, 117, 367, 137, 287, 903, 4685, 13943, 26779, 24607, 70853, 99743, 0 };
            const std::uint32_t dim19315JoeKuoD6Init[]   =   { 1, 1, 7, 11, 25, 43, 67, 181, 459, 737, 1567, 3491, 5085, 6487, 23115, 62341, 102943, 77301, 0 };
            const std::uint32_t dim19316JoeKuoD6Init[]   =   { 1, 1, 3, 15, 7, 35, 81, 199, 455, 851, 835, 3421, 4675, 15173, 9205, 7305, 109849, 15183, 0 };
            const std::uint32_t dim19317JoeKuoD6Init[]   =   { 1, 3, 5, 11, 9, 55, 3, 53, 235, 271, 1265, 3681, 3627, 3485, 11591, 53097, 85949, 158173, 0 };
            const std::uint32_t dim19318JoeKuoD6Init[]   =   { 1, 3, 7, 3, 15, 27, 57, 183, 487, 9, 1797, 2973, 3687, 12987, 9133, 14595, 52067, 131217, 0 };
            const std::uint32_t dim19319JoeKuoD6Init[]   =   { 1, 1, 5, 3, 7, 25, 19, 215, 291, 325, 813, 577, 4249, 10373, 17233, 29557, 72979, 70721, 0 };
            const std::uint32_t dim19320JoeKuoD6Init[]   =   { 1, 3, 1, 7, 25, 1, 107, 167, 367, 303, 883, 993, 4189, 6557, 13697, 15251, 77065, 116127, 0 };
            const std::uint32_t dim19321JoeKuoD6Init[]   =   { 1, 3, 5, 11, 13, 59, 9, 121, 489, 593, 1503, 601, 5263, 13837, 20991, 35761, 45867, 155905, 0 };
            const std::uint32_t dim19322JoeKuoD6Init[]   =   { 1, 1, 3, 3, 19, 47, 127, 115, 267, 261, 969, 961, 5919, 10085, 29363, 4935, 100485, 75561, 0 };
            const std::uint32_t dim19323JoeKuoD6Init[]   =   { 1, 3, 1, 15, 11, 53, 39, 187, 53, 11, 1951, 913, 965, 2565, 5457, 3237, 24923, 245681, 0 };
            const std::uint32_t dim19324JoeKuoD6Init[]   =   { 1, 1, 7, 3, 15, 5, 25, 45, 17, 45, 1317, 1853, 6627, 15879, 29935, 24749, 118149, 35359, 0 };
            const std::uint32_t dim19325JoeKuoD6Init[]   =   { 1, 1, 7, 1, 21, 45, 67, 71, 25, 743, 925, 3441, 3013, 1613, 6321, 12491, 119931, 164701, 0 };
            const std::uint32_t dim19326JoeKuoD6Init[]   =   { 1, 1, 7, 1, 13, 15, 35, 187, 91, 995, 401, 2443, 4183, 10823, 20589, 27413, 117095, 20359, 0 };
            const std::uint32_t dim19327JoeKuoD6Init[]   =   { 1, 3, 3, 7, 15, 51, 55, 167, 409, 859, 719, 3223, 2457, 16013, 13639, 4027, 79339, 225113, 0 };
            const std::uint32_t dim19328JoeKuoD6Init[]   =   { 1, 3, 1, 9, 3, 29, 105, 193, 279, 27, 1093, 2199, 6983, 619, 10163, 40365, 71015, 102191, 0 };
            const std::uint32_t dim19329JoeKuoD6Init[]   =   { 1, 1, 3, 9, 29, 5, 33, 247, 27, 299, 2017, 379, 6199, 15047, 18329, 3493, 47679, 76703, 0 };
            const std::uint32_t dim19330JoeKuoD6Init[]   =   { 1, 3, 5, 5, 9, 19, 51, 129, 157, 831, 1373, 653, 7489, 13125, 1815, 10915, 88679, 50269, 0 };
            const std::uint32_t dim19331JoeKuoD6Init[]   =   { 1, 3, 3, 9, 9, 49, 79, 11, 181, 679, 1697, 3707, 205, 13305, 6293, 56653, 42619, 116257, 0 };
            const std::uint32_t dim19332JoeKuoD6Init[]   =   { 1, 1, 5, 9, 23, 41, 17, 135, 145, 715, 257, 1561, 6941, 2411, 31459, 25055, 35807, 51579, 0 };
            const std::uint32_t dim19333JoeKuoD6Init[]   =   { 1, 1, 1, 7, 11, 13, 49, 155, 403, 569, 751, 2959, 425, 13949, 22047, 49829, 71925, 101647, 0 };
            const std::uint32_t dim19334JoeKuoD6Init[]   =   { 1, 1, 3, 15, 15, 15, 17, 213, 113, 395, 1999, 2039, 3623, 13255, 24435, 54487, 78773, 202637, 0 };
            const std::uint32_t dim19335JoeKuoD6Init[]   =   { 1, 3, 7, 9, 5, 21, 61, 165, 97, 349, 1131, 2677, 333, 13129, 2137, 22909, 95795, 143081, 0 };
            const std::uint32_t dim19336JoeKuoD6Init[]   =   { 1, 1, 1, 5, 31, 41, 109, 179, 295, 475, 639, 3929, 1841, 7545, 19411, 52573, 10173, 236769, 0 };
            const std::uint32_t dim19337JoeKuoD6Init[]   =   { 1, 1, 1, 5, 27, 51, 9, 217, 393, 671, 931, 433, 7303, 16295, 6727, 5703, 88241, 132665, 0 };
            const std::uint32_t dim19338JoeKuoD6Init[]   =   { 1, 1, 7, 13, 21, 33, 19, 241, 497, 519, 1413, 489, 4975, 1345, 24925, 40383, 110815, 136217, 0 };
            const std::uint32_t dim19339JoeKuoD6Init[]   =   { 1, 3, 1, 9, 7, 51, 79, 15, 15, 601, 997, 3713, 7829, 903, 12393, 60059, 42057, 175141, 0 };
            const std::uint32_t dim19340JoeKuoD6Init[]   =   { 1, 1, 5, 15, 9, 63, 107, 63, 495, 591, 207, 779, 8069, 3013, 23839, 3075, 127481, 193885, 0 };
            const std::uint32_t dim19341JoeKuoD6Init[]   =   { 1, 1, 1, 7, 13, 17, 121, 171, 99, 59, 1043, 1109, 1337, 1179, 27635, 34063, 12945, 1431, 0 };
            const std::uint32_t dim19342JoeKuoD6Init[]   =   { 1, 3, 1, 3, 5, 47, 101, 205, 157, 595, 263, 3887, 7015, 4693, 15211, 25381, 128803, 227233, 0 };
            const std::uint32_t dim19343JoeKuoD6Init[]   =   { 1, 1, 3, 11, 17, 33, 1, 19, 153, 603, 119, 2305, 4041, 4011, 19849, 761, 52807, 129811, 0 };
            const std::uint32_t dim19344JoeKuoD6Init[]   =   { 1, 3, 7, 15, 21, 7, 13, 225, 497, 459, 389, 911, 6349, 5059, 6363, 41915, 90687, 214501, 0 };
            const std::uint32_t dim19345JoeKuoD6Init[]   =   { 1, 3, 1, 15, 1, 39, 31, 83, 147, 629, 185, 1913, 3217, 959, 651, 65267, 108613, 20391, 0 };
            const std::uint32_t dim19346JoeKuoD6Init[]   =   { 1, 3, 1, 7, 9, 11, 29, 201, 245, 815, 1869, 2597, 5693, 15669, 23293, 30885, 4029, 225737, 0 };
            const std::uint32_t dim19347JoeKuoD6Init[]   =   { 1, 3, 5, 11, 7, 29, 119, 207, 499, 23, 1563, 3645, 3839, 2509, 24043, 64231, 22509, 221835, 0 };
            const std::uint32_t dim19348JoeKuoD6Init[]   =   { 1, 3, 3, 7, 11, 49, 13, 201, 353, 217, 831, 2803, 1521, 12989, 25339, 41035, 2125, 165271, 0 };
            const std::uint32_t dim19349JoeKuoD6Init[]   =   { 1, 1, 5, 11, 1, 45, 93, 29, 55, 1007, 1919, 241, 5931, 9211, 17291, 39849, 25453, 96077, 0 };
            const std::uint32_t dim19350JoeKuoD6Init[]   =   { 1, 3, 1, 1, 29, 43, 11, 105, 331, 693, 1363, 291, 8191, 7813, 14135, 38287, 15469, 256913, 0 };
            const std::uint32_t dim19351JoeKuoD6Init[]   =   { 1, 3, 5, 11, 19, 21, 23, 117, 253, 111, 733, 3785, 5835, 423, 30251, 27283, 79561, 162095, 0 };
            const std::uint32_t dim19352JoeKuoD6Init[]   =   { 1, 3, 3, 1, 9, 19, 83, 13, 37, 725, 1597, 1117, 8067, 8085, 1315, 41813, 8973, 175525, 0 };
            const std::uint32_t dim19353JoeKuoD6Init[]   =   { 1, 1, 5, 3, 13, 39, 3, 213, 335, 907, 1143, 1729, 601, 11255, 24351, 41045, 11335, 186221, 0 };
            const std::uint32_t dim19354JoeKuoD6Init[]   =   { 1, 3, 3, 9, 17, 11, 29, 33, 303, 815, 1607, 2403, 8095, 4213, 16697, 64733, 24439, 93081, 0 };
            const std::uint32_t dim19355JoeKuoD6Init[]   =   { 1, 1, 1, 3, 13, 37, 35, 181, 243, 645, 1915, 3521, 569, 3005, 7271, 32755, 64575, 119813, 0 };
            const std::uint32_t dim19356JoeKuoD6Init[]   =   { 1, 1, 5, 13, 25, 59, 77, 121, 459, 755, 385, 1893, 1227, 9957, 5069, 40063, 27261, 4703, 0 };
            const std::uint32_t dim19357JoeKuoD6Init[]   =   { 1, 3, 1, 3, 29, 41, 95, 255, 219, 21, 317, 3021, 2615, 5101, 19413, 25795, 6521, 157749, 0 };
            const std::uint32_t dim19358JoeKuoD6Init[]   =   { 1, 3, 3, 5, 7, 33, 7, 205, 415, 23, 1431, 117, 1605, 9541, 11825, 49195, 86341, 99673, 0 };
            const std::uint32_t dim19359JoeKuoD6Init[]   =   { 1, 3, 3, 5, 17, 37, 33, 209, 49, 161, 321, 3697, 6483, 12859, 895, 675, 1899, 260289, 0 };
            const std::uint32_t dim19360JoeKuoD6Init[]   =   { 1, 1, 3, 15, 1, 27, 83, 125, 309, 553, 505, 2209, 4931, 2593, 28253, 12879, 74971, 9047, 0 };
            const std::uint32_t dim19361JoeKuoD6Init[]   =   { 1, 3, 7, 3, 15, 3, 105, 19, 41, 119, 149, 3847, 6593, 875, 23777, 4547, 57717, 139387, 0 };
            const std::uint32_t dim19362JoeKuoD6Init[]   =   { 1, 1, 1, 3, 9, 43, 25, 15, 67, 609, 951, 273, 8095, 621, 24819, 17233, 53423, 192757, 0 };
            const std::uint32_t dim19363JoeKuoD6Init[]   =   { 1, 3, 5, 3, 9, 49, 107, 215, 245, 217, 545, 2285, 2075, 401, 26599, 32967, 130457, 203755, 0 };
            const std::uint32_t dim19364JoeKuoD6Init[]   =   { 1, 1, 5, 1, 7, 31, 87, 181, 135, 155, 9, 1431, 307, 13367, 31147, 10327, 2817, 63327, 0 };
            const std::uint32_t dim19365JoeKuoD6Init[]   =   { 1, 3, 3, 3, 29, 17, 55, 201, 33, 275, 2005, 3037, 3439, 1513, 7563, 46491, 103319, 5279, 0 };
            const std::uint32_t dim19366JoeKuoD6Init[]   =   { 1, 3, 7, 11, 31, 63, 105, 169, 257, 225, 711, 2041, 1519, 11801, 18543, 35173, 92125, 72729, 0 };
            const std::uint32_t dim19367JoeKuoD6Init[]   =   { 1, 1, 3, 3, 11, 13, 127, 231, 229, 809, 303, 1167, 47, 4281, 2373, 10455, 74685, 131775, 0 };
            const std::uint32_t dim19368JoeKuoD6Init[]   =   { 1, 1, 5, 15, 1, 5, 97, 139, 189, 39, 37, 3513, 2119, 1453, 11477, 45477, 75613, 169915, 0 };
            const std::uint32_t dim19369JoeKuoD6Init[]   =   { 1, 3, 5, 1, 15, 27, 31, 87, 311, 785, 489, 1331, 5259, 6963, 26441, 41675, 107187, 60723, 0 };
            const std::uint32_t dim19370JoeKuoD6Init[]   =   { 1, 1, 3, 5, 13, 9, 33, 3, 273, 357, 841, 1421, 5993, 12449, 6821, 4283, 9437, 215035, 0 };
            const std::uint32_t dim19371JoeKuoD6Init[]   =   { 1, 3, 3, 1, 15, 43, 101, 35, 23, 743, 29, 3953, 3095, 14355, 25977, 12513, 54565, 20199, 0 };
            const std::uint32_t dim19372JoeKuoD6Init[]   =   { 1, 3, 3, 1, 11, 53, 99, 95, 63, 503, 1361, 3231, 2445, 5073, 4667, 33033, 4575, 139475, 0 };
            const std::uint32_t dim19373JoeKuoD6Init[]   =   { 1, 3, 3, 5, 19, 57, 15, 115, 125, 1017, 1913, 907, 2461, 3229, 16591, 6591, 26385, 228661, 0 };
            const std::uint32_t dim19374JoeKuoD6Init[]   =   { 1, 3, 1, 11, 27, 19, 7, 121, 245, 997, 1743, 2571, 1333, 9603, 27811, 42081, 44365, 94943, 0 };
            const std::uint32_t dim19375JoeKuoD6Init[]   =   { 1, 3, 1, 1, 13, 5, 127, 217, 63, 137, 989, 1441, 1133, 8273, 18091, 22243, 122931, 28867, 0 };
            const std::uint32_t dim19376JoeKuoD6Init[]   =   { 1, 1, 7, 15, 23, 39, 57, 83, 321, 817, 819, 223, 4803, 6935, 2027, 20373, 119683, 29781, 0 };
            const std::uint32_t dim19377JoeKuoD6Init[]   =   { 1, 1, 7, 7, 9, 1, 55, 211, 455, 283, 1647, 471, 4351, 14119, 6945, 63117, 109687, 200165, 0 };
            const std::uint32_t dim19378JoeKuoD6Init[]   =   { 1, 1, 7, 7, 29, 45, 113, 253, 135, 375, 1091, 959, 1423, 1241, 31689, 33751, 73459, 91769, 0 };
            const std::uint32_t dim19379JoeKuoD6Init[]   =   { 1, 3, 5, 11, 23, 63, 55, 181, 453, 267, 995, 1309, 2847, 3791, 21683, 59809, 81891, 132635, 0 };
            const std::uint32_t dim19380JoeKuoD6Init[]   =   { 1, 1, 1, 13, 17, 37, 87, 17, 61, 689, 1895, 3877, 4717, 6447, 22329, 1619, 30069, 190887, 0 };
            const std::uint32_t dim19381JoeKuoD6Init[]   =   { 1, 3, 1, 7, 27, 61, 17, 51, 99, 909, 85, 951, 107, 1923, 35, 63389, 90273, 152643, 0 };
            const std::uint32_t dim19382JoeKuoD6Init[]   =   { 1, 1, 1, 1, 15, 39, 77, 255, 191, 613, 655, 1881, 267, 3927, 18025, 13825, 15381, 169193, 0 };
            const std::uint32_t dim19383JoeKuoD6Init[]   =   { 1, 3, 3, 1, 31, 17, 73, 69, 231, 221, 501, 3755, 1671, 2049, 22493, 16353, 1775, 181783, 0 };
            const std::uint32_t dim19384JoeKuoD6Init[]   =   { 1, 1, 7, 5, 31, 45, 125, 189, 287, 487, 1911, 3133, 3257, 8967, 21295, 1247, 72297, 68269, 0 };
            const std::uint32_t dim19385JoeKuoD6Init[]   =   { 1, 3, 3, 1, 7, 9, 123, 147, 7, 381, 1597, 1289, 7831, 14493, 21145, 15487, 70353, 147891, 0 };
            const std::uint32_t dim19386JoeKuoD6Init[]   =   { 1, 1, 5, 9, 15, 17, 43, 87, 101, 425, 1819, 163, 6741, 8255, 2591, 17719, 112871, 110793, 0 };
            const std::uint32_t dim19387JoeKuoD6Init[]   =   { 1, 1, 3, 9, 3, 27, 7, 41, 43, 743, 131, 705, 2607, 9963, 26367, 41191, 126347, 164291, 0 };
            const std::uint32_t dim19388JoeKuoD6Init[]   =   { 1, 3, 3, 15, 7, 17, 97, 153, 283, 461, 1723, 2421, 4973, 16369, 30633, 62299, 119425, 3591, 0 };
            const std::uint32_t dim19389JoeKuoD6Init[]   =   { 1, 1, 1, 13, 7, 33, 95, 255, 429, 693, 849, 3783, 5985, 8551, 23227, 1015, 109023, 42493, 0 };
            const std::uint32_t dim19390JoeKuoD6Init[]   =   { 1, 3, 1, 7, 3, 43, 53, 137, 413, 265, 2033, 1347, 335, 529, 24751, 16443, 122195, 158951, 0 };
            const std::uint32_t dim19391JoeKuoD6Init[]   =   { 1, 1, 5, 9, 27, 21, 83, 185, 325, 557, 1247, 2739, 6925, 5459, 26027, 62217, 61113, 197743, 0 };
            const std::uint32_t dim19392JoeKuoD6Init[]   =   { 1, 1, 3, 13, 9, 57, 79, 133, 137, 851, 863, 1605, 7839, 11809, 29941, 20473, 6687, 164479, 0 };
            const std::uint32_t dim19393JoeKuoD6Init[]   =   { 1, 1, 3, 9, 9, 51, 123, 29, 139, 43, 1329, 2701, 3413, 3875, 19673, 62369, 10529, 226525, 0 };
            const std::uint32_t dim19394JoeKuoD6Init[]   =   { 1, 3, 1, 5, 25, 47, 7, 201, 119, 623, 9, 25, 1713, 10817, 8201, 5847, 77477, 237883, 0 };
            const std::uint32_t dim19395JoeKuoD6Init[]   =   { 1, 1, 5, 13, 15, 53, 39, 93, 235, 619, 1695, 2389, 2571, 2389, 4619, 45769, 17245, 69973, 0 };
            const std::uint32_t dim19396JoeKuoD6Init[]   =   { 1, 1, 7, 1, 31, 9, 75, 143, 1, 67, 809, 1037, 2801, 16129, 22443, 26021, 119683, 14681, 0 };
            const std::uint32_t dim19397JoeKuoD6Init[]   =   { 1, 3, 1, 9, 23, 49, 69, 71, 139, 953, 1053, 3059, 1061, 5881, 26207, 15907, 79389, 95341, 0 };
            const std::uint32_t dim19398JoeKuoD6Init[]   =   { 1, 3, 5, 1, 19, 39, 69, 183, 95, 289, 847, 393, 1649, 1275, 21187, 34715, 67553, 123239, 0 };
            const std::uint32_t dim19399JoeKuoD6Init[]   =   { 1, 1, 1, 5, 21, 39, 119, 193, 347, 87, 731, 3327, 6089, 13781, 20389, 52303, 11869, 48975, 0 };
            const std::uint32_t dim19400JoeKuoD6Init[]   =   { 1, 3, 5, 1, 19, 17, 93, 33, 215, 457, 687, 1325, 1997, 2655, 21195, 54997, 36877, 57991, 0 };
            const std::uint32_t dim19401JoeKuoD6Init[]   =   { 1, 1, 1, 3, 17, 45, 91, 45, 231, 611, 413, 2321, 7181, 13765, 7791, 6973, 24497, 231795, 0 };
            const std::uint32_t dim19402JoeKuoD6Init[]   =   { 1, 3, 3, 15, 7, 29, 103, 31, 295, 637, 1775, 2293, 8001, 4175, 1257, 16881, 93695, 180591, 0 };
            const std::uint32_t dim19403JoeKuoD6Init[]   =   { 1, 1, 1, 13, 31, 7, 47, 51, 267, 231, 463, 939, 7977, 8593, 15329, 36871, 50449, 222341, 0 };
            const std::uint32_t dim19404JoeKuoD6Init[]   =   { 1, 3, 7, 3, 27, 31, 57, 135, 507, 177, 1455, 1963, 4473, 6449, 727, 49853, 65275, 237531, 0 };
            const std::uint32_t dim19405JoeKuoD6Init[]   =   { 1, 3, 7, 11, 31, 21, 111, 231, 269, 27, 719, 3275, 2489, 3689, 3425, 23763, 39413, 64565, 0 };
            const std::uint32_t dim19406JoeKuoD6Init[]   =   { 1, 1, 1, 11, 23, 27, 31, 153, 201, 985, 1553, 3061, 7663, 4079, 13549, 48765, 64169, 68223, 0 };
            const std::uint32_t dim19407JoeKuoD6Init[]   =   { 1, 1, 7, 15, 11, 53, 125, 23, 73, 799, 591, 665, 127, 3941, 11251, 12649, 2657, 230923, 0 };
            const std::uint32_t dim19408JoeKuoD6Init[]   =   { 1, 1, 7, 15, 29, 43, 95, 81, 337, 367, 779, 1237, 7627, 997, 3355, 1245, 70477, 159097, 0 };
            const std::uint32_t dim19409JoeKuoD6Init[]   =   { 1, 3, 1, 13, 19, 31, 11, 91, 179, 425, 1395, 1439, 2723, 401, 26779, 36723, 115743, 179653, 0 };
            const std::uint32_t dim19410JoeKuoD6Init[]   =   { 1, 1, 3, 1, 29, 35, 11, 217, 301, 421, 765, 1949, 5475, 2247, 3953, 27091, 16895, 194821, 0 };
            const std::uint32_t dim19411JoeKuoD6Init[]   =   { 1, 1, 5, 9, 11, 21, 95, 135, 127, 65, 609, 3893, 7143, 13231, 29199, 36205, 38711, 159599, 0 };
            const std::uint32_t dim19412JoeKuoD6Init[]   =   { 1, 3, 5, 13, 25, 25, 101, 221, 495, 993, 961, 2575, 907, 5277, 18415, 1797, 22043, 129889, 0 };
            const std::uint32_t dim19413JoeKuoD6Init[]   =   { 1, 1, 1, 15, 21, 21, 99, 3, 175, 735, 659, 543, 7573, 15549, 14067, 60009, 65785, 112927, 0 };
            const std::uint32_t dim19414JoeKuoD6Init[]   =   { 1, 3, 7, 7, 3, 39, 61, 203, 143, 581, 487, 2097, 3943, 6869, 14435, 46431, 101781, 233067, 0 };
            const std::uint32_t dim19415JoeKuoD6Init[]   =   { 1, 1, 3, 1, 13, 27, 21, 147, 295, 89, 1845, 1017, 4621, 10029, 3517, 25371, 104531, 225179, 0 };
            const std::uint32_t dim19416JoeKuoD6Init[]   =   { 1, 1, 3, 11, 25, 51, 45, 179, 299, 487, 2039, 85, 4643, 8211, 12051, 64819, 93481, 159511, 0 };
            const std::uint32_t dim19417JoeKuoD6Init[]   =   { 1, 1, 5, 3, 21, 7, 73, 193, 415, 7, 125, 2487, 7369, 2043, 7633, 19265, 65337, 57399, 0 };
            const std::uint32_t dim19418JoeKuoD6Init[]   =   { 1, 1, 5, 3, 3, 53, 51, 169, 313, 973, 1549, 243, 3155, 13827, 24971, 61393, 15147, 187397, 0 };
            const std::uint32_t dim19419JoeKuoD6Init[]   =   { 1, 3, 3, 3, 29, 33, 91, 41, 367, 77, 1259, 1703, 2105, 14473, 17763, 29809, 47777, 205553, 0 };
            const std::uint32_t dim19420JoeKuoD6Init[]   =   { 1, 3, 7, 3, 23, 61, 59, 235, 51, 41, 417, 691, 2953, 15577, 32283, 2793, 109557, 64729, 0 };
            const std::uint32_t dim19421JoeKuoD6Init[]   =   { 1, 1, 5, 9, 13, 17, 93, 201, 151, 323, 1481, 3645, 3039, 5131, 503, 42055, 114939, 198755, 0 };
            const std::uint32_t dim19422JoeKuoD6Init[]   =   { 1, 3, 5, 1, 21, 53, 75, 29, 283, 541, 499, 309, 1923, 995, 21479, 56183, 103743, 152113, 0 };
            const std::uint32_t dim19423JoeKuoD6Init[]   =   { 1, 3, 1, 3, 21, 51, 67, 97, 481, 509, 805, 213, 5157, 13573, 16187, 8199, 28025, 208445, 0 };
            const std::uint32_t dim19424JoeKuoD6Init[]   =   { 1, 1, 7, 7, 15, 25, 107, 127, 355, 249, 707, 1287, 6831, 5317, 15613, 12837, 48091, 27611, 0 };
            const std::uint32_t dim19425JoeKuoD6Init[]   =   { 1, 3, 3, 7, 31, 53, 127, 239, 17, 709, 979, 4023, 7149, 4239, 20015, 44365, 113245, 75873, 0 };
            const std::uint32_t dim19426JoeKuoD6Init[]   =   { 1, 3, 5, 11, 27, 37, 49, 123, 137, 967, 1857, 3961, 7429, 8355, 30733, 64587, 73903, 188581, 0 };
            const std::uint32_t dim19427JoeKuoD6Init[]   =   { 1, 3, 3, 7, 19, 51, 69, 121, 345, 637, 1987, 335, 7071, 13849, 22369, 46895, 20761, 148227, 0 };
            const std::uint32_t dim19428JoeKuoD6Init[]   =   { 1, 1, 3, 11, 9, 1, 93, 151, 487, 889, 919, 2429, 5425, 15303, 12583, 57627, 42683, 98265, 0 };
            const std::uint32_t dim19429JoeKuoD6Init[]   =   { 1, 3, 5, 3, 1, 29, 87, 189, 285, 805, 933, 1381, 2789, 107, 14215, 33171, 110573, 250983, 0 };
            const std::uint32_t dim19430JoeKuoD6Init[]   =   { 1, 3, 1, 1, 27, 43, 63, 115, 317, 401, 885, 1029, 7003, 10041, 15299, 42251, 58675, 177545, 0 };
            const std::uint32_t dim19431JoeKuoD6Init[]   =   { 1, 3, 5, 7, 11, 33, 119, 5, 185, 777, 1795, 1585, 3543, 1801, 17681, 1041, 44513, 105435, 0 };
            const std::uint32_t dim19432JoeKuoD6Init[]   =   { 1, 3, 1, 9, 19, 33, 15, 253, 299, 925, 241, 1333, 615, 12501, 499, 44449, 16595, 70357, 0 };
            const std::uint32_t dim19433JoeKuoD6Init[]   =   { 1, 1, 3, 13, 13, 31, 17, 123, 215, 805, 1177, 3683, 27, 11881, 7645, 25575, 63057, 89547, 0 };
            const std::uint32_t dim19434JoeKuoD6Init[]   =   { 1, 1, 5, 5, 17, 1, 57, 183, 267, 825, 1987, 329, 5603, 1295, 425, 61871, 27859, 157109, 0 };
            const std::uint32_t dim19435JoeKuoD6Init[]   =   { 1, 3, 3, 11, 19, 45, 37, 79, 191, 17, 17, 3379, 7941, 3159, 20351, 26341, 34687, 116281, 0 };
            const std::uint32_t dim19436JoeKuoD6Init[]   =   { 1, 1, 3, 7, 11, 7, 61, 199, 459, 993, 1729, 3751, 1067, 14965, 14669, 40281, 12579, 154601, 0 };
            const std::uint32_t dim19437JoeKuoD6Init[]   =   { 1, 3, 3, 13, 19, 53, 17, 39, 137, 219, 1645, 2899, 505, 10057, 22891, 32317, 81201, 126291, 0 };
            const std::uint32_t dim19438JoeKuoD6Init[]   =   { 1, 3, 5, 7, 21, 53, 65, 125, 69, 781, 761, 1683, 5817, 11859, 11543, 62853, 57149, 212261, 0 };
            const std::uint32_t dim19439JoeKuoD6Init[]   =   { 1, 3, 5, 9, 13, 25, 81, 119, 439, 25, 239, 2867, 421, 12631, 22705, 31039, 96105, 79023, 0 };
            const std::uint32_t dim19440JoeKuoD6Init[]   =   { 1, 3, 5, 3, 19, 9, 51, 135, 437, 393, 1711, 1205, 5195, 10927, 28583, 7513, 110227, 139295, 0 };
            const std::uint32_t dim19441JoeKuoD6Init[]   =   { 1, 3, 7, 9, 31, 15, 5, 143, 49, 13, 1143, 2325, 5437, 14289, 31555, 58777, 102675, 64559, 0 };
            const std::uint32_t dim19442JoeKuoD6Init[]   =   { 1, 1, 7, 3, 3, 21, 65, 127, 341, 109, 167, 1835, 6687, 1695, 15631, 47047, 127543, 51413, 0 };
            const std::uint32_t dim19443JoeKuoD6Init[]   =   { 1, 1, 3, 1, 31, 49, 103, 147, 59, 701, 1251, 3391, 1935, 5371, 28585, 50023, 73839, 118205, 0 };
            const std::uint32_t dim19444JoeKuoD6Init[]   =   { 1, 3, 3, 1, 5, 49, 91, 23, 91, 663, 1369, 1437, 2657, 11369, 29857, 53875, 127045, 242323, 0 };
            const std::uint32_t dim19445JoeKuoD6Init[]   =   { 1, 3, 1, 3, 23, 33, 7, 105, 353, 863, 1211, 1175, 1347, 12913, 11973, 55255, 27145, 175539, 0 };
            const std::uint32_t dim19446JoeKuoD6Init[]   =   { 1, 1, 1, 13, 9, 29, 71, 71, 509, 571, 2005, 3125, 2731, 6829, 26863, 16459, 113195, 80247, 0 };
            const std::uint32_t dim19447JoeKuoD6Init[]   =   { 1, 3, 5, 1, 7, 11, 45, 177, 281, 695, 1197, 2035, 2137, 11833, 12417, 5805, 77211, 45553, 0 };
            const std::uint32_t dim19448JoeKuoD6Init[]   =   { 1, 1, 7, 7, 27, 59, 91, 183, 267, 373, 677, 2431, 903, 4229, 31997, 19843, 125089, 242871, 0 };
            const std::uint32_t dim19449JoeKuoD6Init[]   =   { 1, 3, 3, 13, 23, 23, 53, 101, 225, 247, 2013, 853, 279, 2161, 30045, 28255, 130907, 57157, 0 };
            const std::uint32_t dim19450JoeKuoD6Init[]   =   { 1, 3, 5, 13, 5, 11, 63, 137, 219, 661, 773, 1991, 4081, 5963, 25207, 50461, 85293, 159441, 0 };
            const std::uint32_t dim19451JoeKuoD6Init[]   =   { 1, 3, 1, 15, 5, 59, 43, 87, 429, 77, 73, 1275, 2619, 16133, 20009, 26089, 38129, 157267, 0 };
            const std::uint32_t dim19452JoeKuoD6Init[]   =   { 1, 1, 5, 15, 9, 59, 37, 127, 127, 733, 1703, 1331, 4293, 3555, 22739, 49513, 34533, 143225, 0 };
            const std::uint32_t dim19453JoeKuoD6Init[]   =   { 1, 1, 7, 7, 11, 51, 121, 59, 505, 147, 1855, 1661, 5539, 3421, 28863, 14811, 39811, 228927, 0 };
            const std::uint32_t dim19454JoeKuoD6Init[]   =   { 1, 1, 5, 5, 1, 31, 57, 167, 107, 753, 1835, 2491, 3311, 8639, 8743, 17279, 77071, 8673, 0 };
            const std::uint32_t dim19455JoeKuoD6Init[]   =   { 1, 1, 3, 3, 15, 39, 1, 223, 395, 603, 1095, 435, 1225, 4045, 21721, 40767, 48971, 1583, 0 };
            const std::uint32_t dim19456JoeKuoD6Init[]   =   { 1, 1, 3, 13, 9, 17, 47, 175, 229, 827, 769, 2901, 137, 9931, 11115, 25337, 105811, 68413, 0 };
            const std::uint32_t dim19457JoeKuoD6Init[]   =   { 1, 1, 1, 5, 29, 55, 43, 39, 319, 919, 749, 931, 1973, 13147, 913, 48353, 40955, 189783, 0 };
            const std::uint32_t dim19458JoeKuoD6Init[]   =   { 1, 3, 5, 5, 13, 33, 81, 213, 79, 781, 1069, 3117, 5859, 9061, 30963, 17307, 6281, 208707, 0 };
            const std::uint32_t dim19459JoeKuoD6Init[]   =   { 1, 1, 5, 13, 27, 63, 41, 91, 123, 763, 1115, 3193, 4571, 4573, 8235, 24291, 40911, 225985, 0 };
            const std::uint32_t dim19460JoeKuoD6Init[]   =   { 1, 1, 1, 7, 13, 5, 77, 215, 67, 183, 1447, 1571, 213, 3481, 28349, 22451, 44951, 240257, 0 };
            const std::uint32_t dim19461JoeKuoD6Init[]   =   { 1, 3, 7, 7, 3, 21, 39, 233, 263, 19, 489, 1511, 2313, 1799, 25173, 17913, 70593, 2969, 0 };
            const std::uint32_t dim19462JoeKuoD6Init[]   =   { 1, 3, 7, 15, 3, 1, 93, 101, 393, 911, 1055, 953, 1279, 11947, 11963, 53443, 29105, 226057, 0 };
            const std::uint32_t dim19463JoeKuoD6Init[]   =   { 1, 1, 3, 7, 7, 53, 119, 39, 439, 629, 1845, 3411, 3633, 16345, 27501, 59565, 39581, 85373, 0 };
            const std::uint32_t dim19464JoeKuoD6Init[]   =   { 1, 1, 5, 7, 19, 39, 19, 191, 509, 239, 359, 645, 8107, 13721, 21289, 20763, 67727, 45957, 0 };
            const std::uint32_t dim19465JoeKuoD6Init[]   =   { 1, 1, 1, 13, 5, 13, 113, 41, 135, 351, 311, 1099, 2391, 16165, 15805, 54737, 102645, 224417, 0 };
            const std::uint32_t dim19466JoeKuoD6Init[]   =   { 1, 3, 3, 9, 17, 47, 95, 249, 45, 749, 313, 317, 2413, 15861, 27221, 35537, 6407, 50111, 0 };
            const std::uint32_t dim19467JoeKuoD6Init[]   =   { 1, 1, 7, 5, 29, 57, 81, 7, 233, 393, 307, 1089, 1367, 12275, 11861, 29119, 27271, 36351, 0 };
            const std::uint32_t dim19468JoeKuoD6Init[]   =   { 1, 3, 5, 15, 9, 15, 23, 241, 233, 305, 1025, 2035, 4897, 10321, 17345, 42873, 109045, 129533, 0 };
            const std::uint32_t dim19469JoeKuoD6Init[]   =   { 1, 3, 5, 9, 21, 33, 111, 81, 311, 829, 1851, 1437, 5935, 7847, 15493, 28531, 74879, 40567, 0 };
            const std::uint32_t dim19470JoeKuoD6Init[]   =   { 1, 3, 7, 7, 13, 21, 43, 119, 507, 701, 1385, 745, 799, 1567, 13271, 40267, 130843, 59951, 0 };
            const std::uint32_t dim19471JoeKuoD6Init[]   =   { 1, 3, 3, 1, 19, 43, 45, 119, 87, 263, 1475, 3897, 2811, 2711, 4949, 48043, 125237, 230897, 0 };
            const std::uint32_t dim19472JoeKuoD6Init[]   =   { 1, 1, 7, 1, 1, 53, 17, 71, 313, 373, 5, 2359, 1643, 9867, 18365, 5011, 40675, 105371, 0 };
            const std::uint32_t dim19473JoeKuoD6Init[]   =   { 1, 3, 7, 11, 23, 49, 123, 255, 33, 241, 473, 959, 1859, 6109, 5433, 27625, 46839, 90727, 0 };
            const std::uint32_t dim19474JoeKuoD6Init[]   =   { 1, 1, 1, 3, 31, 43, 33, 129, 159, 445, 1831, 1005, 587, 2091, 5749, 33271, 50909, 65057, 0 };
            const std::uint32_t dim19475JoeKuoD6Init[]   =   { 1, 1, 7, 13, 3, 21, 17, 125, 357, 97, 1255, 669, 1583, 7433, 32287, 61795, 5915, 211593, 0 };
            const std::uint32_t dim19476JoeKuoD6Init[]   =   { 1, 1, 7, 7, 31, 19, 71, 211, 213, 731, 1491, 3315, 3633, 14953, 21369, 4977, 33533, 12115, 0 };
            const std::uint32_t dim19477JoeKuoD6Init[]   =   { 1, 3, 1, 1, 31, 1, 87, 253, 211, 57, 1431, 2613, 4075, 14463, 11287, 38671, 100129, 4241, 0 };
            const std::uint32_t dim19478JoeKuoD6Init[]   =   { 1, 1, 1, 5, 21, 13, 27, 29, 31, 285, 179, 3861, 5319, 15683, 2579, 15663, 63357, 81849, 0 };
            const std::uint32_t dim19479JoeKuoD6Init[]   =   { 1, 1, 3, 7, 23, 29, 29, 79, 263, 865, 1237, 3871, 2097, 5337, 2387, 59277, 28831, 57957, 0 };
            const std::uint32_t dim19480JoeKuoD6Init[]   =   { 1, 3, 7, 15, 15, 31, 83, 195, 87, 691, 71, 1025, 3145, 675, 14619, 22399, 88885, 222969, 0 };
            const std::uint32_t dim19481JoeKuoD6Init[]   =   { 1, 1, 5, 7, 19, 3, 121, 105, 383, 675, 777, 2073, 643, 14439, 19467, 13159, 115421, 250561, 0 };
            const std::uint32_t dim19482JoeKuoD6Init[]   =   { 1, 3, 5, 9, 13, 41, 119, 23, 355, 765, 579, 849, 3313, 2443, 29521, 42965, 102559, 227707, 0 };
            const std::uint32_t dim19483JoeKuoD6Init[]   =   { 1, 3, 3, 7, 23, 55, 115, 83, 331, 873, 797, 621, 1197, 15299, 26307, 34287, 120459, 260603, 0 };
            const std::uint32_t dim19484JoeKuoD6Init[]   =   { 1, 1, 3, 5, 7, 11, 113, 119, 65, 691, 1169, 2291, 7283, 1391, 10737, 3801, 40649, 191009, 0 };
            const std::uint32_t dim19485JoeKuoD6Init[]   =   { 1, 1, 7, 9, 3, 23, 95, 109, 457, 277, 871, 3013, 2833, 4131, 21081, 43635, 19875, 162173, 0 };
            const std::uint32_t dim19486JoeKuoD6Init[]   =   { 1, 1, 3, 15, 25, 7, 45, 109, 195, 935, 1487, 1603, 1663, 15595, 10687, 4073, 34863, 45851, 0 };
            const std::uint32_t dim19487JoeKuoD6Init[]   =   { 1, 1, 1, 5, 21, 19, 37, 141, 377, 553, 1225, 2485, 1235, 13179, 2587, 43659, 1405, 52023, 0 };
            const std::uint32_t dim19488JoeKuoD6Init[]   =   { 1, 3, 1, 9, 5, 27, 1, 219, 397, 555, 533, 941, 2755, 1295, 16157, 30733, 54279, 168455, 0 };
            const std::uint32_t dim19489JoeKuoD6Init[]   =   { 1, 3, 3, 1, 27, 41, 93, 177, 119, 581, 167, 3943, 5765, 15455, 555, 17419, 33117, 160599, 0 };
            const std::uint32_t dim19490JoeKuoD6Init[]   =   { 1, 1, 3, 7, 15, 25, 29, 177, 503, 529, 229, 2535, 1493, 805, 30983, 26309, 123453, 118441, 0 };
            const std::uint32_t dim19491JoeKuoD6Init[]   =   { 1, 1, 7, 15, 13, 33, 83, 151, 183, 433, 823, 4003, 1991, 6563, 18743, 61835, 56535, 191193, 0 };
            const std::uint32_t dim19492JoeKuoD6Init[]   =   { 1, 1, 1, 13, 9, 31, 91, 63, 455, 67, 243, 1573, 3507, 9491, 4677, 13835, 121603, 241781, 0 };
            const std::uint32_t dim19493JoeKuoD6Init[]   =   { 1, 1, 5, 5, 29, 13, 45, 29, 289, 909, 1923, 3371, 3675, 13119, 24599, 58511, 109467, 126865, 0 };
            const std::uint32_t dim19494JoeKuoD6Init[]   =   { 1, 1, 5, 9, 21, 41, 41, 179, 25, 463, 949, 819, 397, 12329, 3461, 34773, 61337, 23579, 0 };
            const std::uint32_t dim19495JoeKuoD6Init[]   =   { 1, 3, 3, 11, 1, 25, 17, 165, 77, 455, 1983, 143, 2763, 8165, 14849, 1601, 30093, 54599, 0 };
            const std::uint32_t dim19496JoeKuoD6Init[]   =   { 1, 1, 7, 3, 7, 1, 117, 117, 53, 611, 1405, 3357, 1717, 8157, 247, 17501, 30201, 192485, 0 };
            const std::uint32_t dim19497JoeKuoD6Init[]   =   { 1, 1, 1, 5, 23, 47, 95, 173, 133, 603, 1627, 4039, 5599, 10575, 30275, 60287, 3313, 77551, 0 };
            const std::uint32_t dim19498JoeKuoD6Init[]   =   { 1, 1, 1, 9, 31, 49, 87, 169, 221, 561, 1045, 365, 1955, 9905, 13057, 33717, 91203, 57513, 0 };
            const std::uint32_t dim19499JoeKuoD6Init[]   =   { 1, 3, 3, 1, 19, 25, 113, 231, 415, 717, 1767, 755, 4825, 7541, 10121, 9351, 72093, 255877, 0 };
            const std::uint32_t dim19500JoeKuoD6Init[]   =   { 1, 3, 1, 7, 1, 35, 3, 231, 345, 375, 809, 2753, 849, 13915, 16127, 7575, 45259, 28917, 0 };
            const std::uint32_t dim19501JoeKuoD6Init[]   =   { 1, 3, 3, 11, 23, 43, 13, 37, 305, 765, 517, 333, 473, 14949, 11939, 35171, 63963, 181825, 0 };
            const std::uint32_t dim19502JoeKuoD6Init[]   =   { 1, 3, 3, 3, 5, 43, 35, 89, 293, 913, 1325, 2097, 603, 14365, 4005, 38935, 23837, 34271, 0 };
            const std::uint32_t dim19503JoeKuoD6Init[]   =   { 1, 1, 3, 15, 1, 47, 67, 199, 167, 909, 1167, 1513, 7087, 5017, 23469, 2621, 24961, 226679, 0 };
            const std::uint32_t dim19504JoeKuoD6Init[]   =   { 1, 3, 7, 15, 23, 37, 111, 217, 33, 423, 457, 1767, 4821, 10233, 27045, 33397, 85351, 156751, 0 };
            const std::uint32_t dim19505JoeKuoD6Init[]   =   { 1, 3, 3, 7, 31, 25, 67, 65, 291, 169, 1505, 1707, 4833, 11541, 1189, 62959, 59831, 48729, 0 };
            const std::uint32_t dim19506JoeKuoD6Init[]   =   { 1, 1, 5, 7, 27, 27, 15, 23, 189, 819, 709, 3591, 2781, 14807, 20303, 27795, 88349, 210251, 0 };
            const std::uint32_t dim19507JoeKuoD6Init[]   =   { 1, 3, 7, 15, 1, 19, 49, 103, 219, 85, 1281, 3981, 7229, 10427, 11689, 1547, 90747, 12283, 0 };
            const std::uint32_t dim19508JoeKuoD6Init[]   =   { 1, 1, 1, 13, 31, 49, 81, 121, 287, 851, 333, 353, 7373, 10165, 1157, 11713, 89445, 210709, 0 };
            const std::uint32_t dim19509JoeKuoD6Init[]   =   { 1, 3, 7, 5, 31, 35, 3, 229, 443, 973, 1971, 1861, 5695, 6725, 6405, 45927, 115313, 228667, 0 };
            const std::uint32_t dim19510JoeKuoD6Init[]   =   { 1, 3, 3, 11, 29, 17, 105, 203, 69, 945, 1239, 3213, 6005, 10095, 31233, 37421, 62911, 91371, 0 };
            const std::uint32_t dim19511JoeKuoD6Init[]   =   { 1, 1, 7, 1, 21, 59, 7, 43, 391, 299, 1225, 283, 3351, 11495, 25071, 16619, 65127, 114033, 0 };
            const std::uint32_t dim19512JoeKuoD6Init[]   =   { 1, 1, 3, 9, 17, 11, 71, 73, 377, 437, 311, 1083, 6941, 1039, 1047, 55647, 21239, 209201, 0 };
            const std::uint32_t dim19513JoeKuoD6Init[]   =   { 1, 3, 7, 5, 29, 51, 113, 163, 215, 511, 615, 2427, 2747, 14389, 1005, 27015, 31809, 30603, 0 };
            const std::uint32_t dim19514JoeKuoD6Init[]   =   { 1, 1, 1, 3, 9, 61, 9, 201, 259, 411, 175, 1003, 401, 13695, 13103, 3075, 43695, 177139, 0 };
            const std::uint32_t dim19515JoeKuoD6Init[]   =   { 1, 1, 5, 3, 17, 47, 125, 173, 277, 17, 619, 2295, 3091, 5615, 4529, 54065, 81875, 97279, 0 };
            const std::uint32_t dim19516JoeKuoD6Init[]   =   { 1, 3, 3, 9, 3, 61, 97, 151, 287, 671, 1439, 1129, 6343, 8161, 24593, 40371, 109705, 106279, 0 };
            const std::uint32_t dim19517JoeKuoD6Init[]   =   { 1, 3, 3, 1, 5, 61, 21, 31, 41, 855, 1541, 3351, 575, 3195, 17155, 46913, 1797, 146401, 0 };
            const std::uint32_t dim19518JoeKuoD6Init[]   =   { 1, 1, 7, 13, 11, 43, 27, 97, 479, 117, 1873, 3103, 1947, 9273, 29171, 35719, 10601, 209629, 0 };
            const std::uint32_t dim19519JoeKuoD6Init[]   =   { 1, 3, 1, 9, 21, 47, 53, 129, 85, 505, 165, 3437, 5687, 10289, 6615, 46719, 50731, 25271, 0 };
            const std::uint32_t dim19520JoeKuoD6Init[]   =   { 1, 1, 3, 1, 1, 33, 37, 239, 45, 565, 1907, 3831, 2177, 10967, 12689, 49395, 36289, 247507, 0 };
            const std::uint32_t dim19521JoeKuoD6Init[]   =   { 1, 1, 5, 1, 19, 57, 75, 245, 59, 967, 1319, 3971, 5267, 11713, 15417, 60503, 63431, 157267, 0 };
            const std::uint32_t dim19522JoeKuoD6Init[]   =   { 1, 1, 5, 7, 7, 15, 99, 87, 331, 261, 1973, 219, 3063, 4071, 19273, 48637, 128089, 55511, 0 };
            const std::uint32_t dim19523JoeKuoD6Init[]   =   { 1, 3, 5, 13, 23, 43, 7, 171, 173, 1023, 1145, 3551, 5127, 6365, 18013, 1613, 51997, 107265, 0 };
            const std::uint32_t dim19524JoeKuoD6Init[]   =   { 1, 3, 5, 3, 7, 7, 23, 195, 251, 387, 1889, 3645, 4221, 6025, 27291, 24831, 123749, 231403, 0 };
            const std::uint32_t dim19525JoeKuoD6Init[]   =   { 1, 3, 1, 1, 29, 49, 107, 215, 93, 211, 1349, 1925, 7149, 1015, 27465, 34139, 126149, 121349, 0 };
            const std::uint32_t dim19526JoeKuoD6Init[]   =   { 1, 1, 5, 5, 19, 15, 121, 189, 167, 801, 483, 1955, 8031, 4749, 26665, 64791, 18671, 123221, 0 };
            const std::uint32_t dim19527JoeKuoD6Init[]   =   { 1, 3, 3, 15, 23, 57, 15, 249, 197, 103, 2021, 1897, 5975, 12821, 6441, 62719, 81415, 232417, 0 };
            const std::uint32_t dim19528JoeKuoD6Init[]   =   { 1, 1, 3, 9, 17, 45, 111, 225, 103, 121, 1259, 2849, 2235, 2041, 13261, 7929, 76325, 38677, 0 };
            const std::uint32_t dim19529JoeKuoD6Init[]   =   { 1, 1, 3, 9, 25, 17, 63, 63, 369, 387, 31, 1423, 5699, 12519, 27407, 53193, 963, 123473, 0 };
            const std::uint32_t dim19530JoeKuoD6Init[]   =   { 1, 3, 3, 13, 3, 59, 59, 3, 367, 357, 1391, 1519, 2619, 2291, 1349, 28275, 21655, 8763, 0 };
            const std::uint32_t dim19531JoeKuoD6Init[]   =   { 1, 1, 7, 1, 31, 51, 121, 49, 157, 509, 1513, 3247, 3439, 8691, 20729, 17585, 49013, 228695, 0 };
            const std::uint32_t dim19532JoeKuoD6Init[]   =   { 1, 1, 5, 9, 11, 29, 103, 49, 209, 35, 673, 1409, 2483, 4561, 12435, 46139, 31019, 50929, 0 };
            const std::uint32_t dim19533JoeKuoD6Init[]   =   { 1, 1, 3, 9, 11, 45, 77, 143, 277, 769, 1151, 3705, 7901, 3735, 31155, 46135, 84061, 254357, 0 };
            const std::uint32_t dim19534JoeKuoD6Init[]   =   { 1, 3, 3, 3, 5, 51, 95, 7, 155, 121, 1899, 2261, 2915, 6637, 6557, 20535, 20937, 257275, 0 };
            const std::uint32_t dim19535JoeKuoD6Init[]   =   { 1, 1, 7, 9, 13, 49, 125, 135, 7, 535, 1171, 3501, 1701, 5791, 10121, 9845, 21645, 56451, 0 };
            const std::uint32_t dim19536JoeKuoD6Init[]   =   { 1, 1, 7, 5, 9, 1, 115, 27, 229, 813, 133, 753, 1959, 13121, 30425, 31059, 114619, 132257, 0 };
            const std::uint32_t dim19537JoeKuoD6Init[]   =   { 1, 1, 5, 3, 23, 25, 41, 165, 21, 551, 1751, 3563, 731, 15811, 14777, 22327, 82853, 116699, 0 };
            const std::uint32_t dim19538JoeKuoD6Init[]   =   { 1, 3, 1, 9, 3, 25, 95, 211, 457, 25, 349, 921, 213, 5721, 26725, 19541, 102473, 200845, 0 };
            const std::uint32_t dim19539JoeKuoD6Init[]   =   { 1, 3, 1, 13, 5, 1, 31, 49, 493, 785, 61, 2603, 5997, 12545, 9793, 32521, 99859, 256105, 0 };
            const std::uint32_t dim19540JoeKuoD6Init[]   =   { 1, 3, 3, 7, 31, 19, 31, 121, 507, 79, 685, 197, 4027, 12909, 30533, 38427, 38993, 14581, 0 };
            const std::uint32_t dim19541JoeKuoD6Init[]   =   { 1, 3, 7, 13, 13, 23, 63, 15, 223, 25, 1957, 2527, 6061, 11753, 4835, 34553, 45579, 205805, 0 };
            const std::uint32_t dim19542JoeKuoD6Init[]   =   { 1, 3, 3, 3, 5, 39, 55, 123, 275, 185, 749, 3227, 8137, 12959, 7243, 20613, 46247, 106127, 0 };
            const std::uint32_t dim19543JoeKuoD6Init[]   =   { 1, 1, 7, 13, 1, 21, 49, 145, 237, 291, 1721, 2981, 267, 1255, 21817, 39553, 21937, 115307, 0 };
            const std::uint32_t dim19544JoeKuoD6Init[]   =   { 1, 1, 1, 15, 5, 63, 3, 201, 117, 991, 1049, 1975, 5117, 5799, 28211, 37907, 46799, 240847, 0 };
            const std::uint32_t dim19545JoeKuoD6Init[]   =   { 1, 3, 3, 5, 25, 15, 29, 111, 201, 857, 319, 2695, 4251, 4303, 28495, 12481, 31979, 107503, 0 };
            const std::uint32_t dim19546JoeKuoD6Init[]   =   { 1, 1, 3, 11, 3, 27, 81, 55, 489, 983, 293, 3181, 4593, 4759, 18437, 51185, 47701, 75469, 0 };
            const std::uint32_t dim19547JoeKuoD6Init[]   =   { 1, 3, 1, 3, 11, 25, 113, 243, 365, 299, 1717, 561, 5173, 5983, 7453, 33563, 98519, 162451, 0 };
            const std::uint32_t dim19548JoeKuoD6Init[]   =   { 1, 3, 1, 5, 1, 21, 3, 87, 267, 483, 1397, 791, 4807, 4649, 13713, 19861, 110471, 51443, 0 };
            const std::uint32_t dim19549JoeKuoD6Init[]   =   { 1, 3, 7, 5, 31, 9, 13, 251, 351, 609, 841, 3267, 4201, 8771, 6673, 44867, 105221, 189399, 0 };
            const std::uint32_t dim19550JoeKuoD6Init[]   =   { 1, 1, 3, 1, 13, 43, 47, 153, 331, 1013, 705, 1867, 563, 6361, 7407, 46243, 30521, 213831, 0 };
            const std::uint32_t dim19551JoeKuoD6Init[]   =   { 1, 3, 3, 7, 29, 41, 3, 179, 319, 877, 905, 3803, 2775, 9729, 5673, 9521, 117887, 37605, 0 };
            const std::uint32_t dim19552JoeKuoD6Init[]   =   { 1, 1, 5, 5, 11, 49, 111, 195, 467, 931, 849, 2785, 7829, 2291, 29031, 52019, 86493, 213971, 0 };
            const std::uint32_t dim19553JoeKuoD6Init[]   =   { 1, 1, 3, 11, 13, 11, 81, 81, 419, 621, 181, 1203, 7305, 7857, 16885, 2531, 53127, 35553, 0 };
            const std::uint32_t dim19554JoeKuoD6Init[]   =   { 1, 1, 5, 1, 19, 35, 75, 131, 159, 211, 319, 2805, 6497, 14759, 28997, 62347, 4013, 233821, 0 };
            const std::uint32_t dim19555JoeKuoD6Init[]   =   { 1, 3, 3, 15, 1, 55, 107, 105, 35, 369, 1259, 665, 6717, 2555, 7149, 10373, 33153, 105915, 0 };
            const std::uint32_t dim19556JoeKuoD6Init[]   =   { 1, 3, 7, 5, 31, 13, 27, 207, 359, 355, 2047, 1777, 5555, 12659, 30547, 3655, 86189, 961, 0 };
            const std::uint32_t dim19557JoeKuoD6Init[]   =   { 1, 3, 7, 9, 9, 55, 7, 117, 57, 115, 745, 501, 2341, 3899, 8229, 10625, 66905, 187959, 0 };
            const std::uint32_t dim19558JoeKuoD6Init[]   =   { 1, 3, 3, 13, 25, 43, 87, 197, 303, 405, 1459, 3385, 4109, 8325, 24747, 18405, 48845, 96673, 0 };
            const std::uint32_t dim19559JoeKuoD6Init[]   =   { 1, 3, 5, 3, 21, 37, 109, 9, 183, 585, 1287, 3851, 4939, 1057, 19489, 42603, 32447, 117957, 0 };
            const std::uint32_t dim19560JoeKuoD6Init[]   =   { 1, 1, 5, 13, 3, 47, 109, 115, 73, 733, 1189, 3773, 7471, 10339, 5093, 50253, 122665, 254381, 0 };
            const std::uint32_t dim19561JoeKuoD6Init[]   =   { 1, 1, 5, 5, 21, 33, 113, 187, 51, 245, 241, 3887, 4075, 11945, 20883, 18817, 43567, 851, 0 };
            const std::uint32_t dim19562JoeKuoD6Init[]   =   { 1, 3, 7, 3, 1, 29, 87, 101, 29, 93, 643, 2659, 1753, 4797, 17477, 16087, 43453, 110383, 0 };
            const std::uint32_t dim19563JoeKuoD6Init[]   =   { 1, 1, 7, 13, 17, 51, 75, 91, 445, 171, 1369, 499, 3753, 14035, 4445, 21437, 86205, 231163, 0 };
            const std::uint32_t dim19564JoeKuoD6Init[]   =   { 1, 1, 7, 13, 17, 41, 67, 49, 225, 659, 1181, 1751, 5211, 6847, 20339, 34271, 60273, 52315, 0 };
            const std::uint32_t dim19565JoeKuoD6Init[]   =   { 1, 1, 5, 5, 5, 17, 87, 223, 25, 773, 53, 2447, 6805, 6547, 4429, 46809, 51171, 66457, 0 };
            const std::uint32_t dim19566JoeKuoD6Init[]   =   { 1, 1, 5, 3, 29, 49, 11, 205, 279, 821, 725, 2425, 443, 211, 6347, 59845, 90763, 237911, 0 };
            const std::uint32_t dim19567JoeKuoD6Init[]   =   { 1, 1, 3, 9, 31, 7, 49, 1, 229, 755, 517, 809, 2955, 3571, 2385, 33097, 19659, 55397, 0 };
            const std::uint32_t dim19568JoeKuoD6Init[]   =   { 1, 3, 5, 3, 5, 21, 67, 227, 359, 401, 1697, 2131, 4585, 2661, 3659, 22621, 51639, 245877, 0 };
            const std::uint32_t dim19569JoeKuoD6Init[]   =   { 1, 1, 7, 5, 11, 7, 57, 133, 9, 917, 427, 2777, 6009, 11393, 29473, 59311, 77095, 176215, 0 };
            const std::uint32_t dim19570JoeKuoD6Init[]   =   { 1, 1, 7, 5, 13, 29, 101, 15, 293, 7, 797, 437, 3739, 3369, 16917, 19047, 17773, 219541, 0 };
            const std::uint32_t dim19571JoeKuoD6Init[]   =   { 1, 3, 1, 9, 13, 51, 15, 19, 209, 991, 413, 787, 3797, 14029, 23699, 8591, 40429, 56115, 0 };
            const std::uint32_t dim19572JoeKuoD6Init[]   =   { 1, 3, 7, 3, 31, 9, 77, 33, 487, 155, 1903, 3023, 8163, 385, 4703, 57511, 102083, 85785, 0 };
            const std::uint32_t dim19573JoeKuoD6Init[]   =   { 1, 1, 5, 11, 17, 59, 115, 73, 89, 723, 1523, 2671, 1755, 3463, 19861, 31573, 126405, 90215, 0 };
            const std::uint32_t dim19574JoeKuoD6Init[]   =   { 1, 3, 3, 13, 17, 27, 123, 37, 71, 173, 203, 1245, 7905, 8955, 22589, 56705, 120473, 90129, 0 };
            const std::uint32_t dim19575JoeKuoD6Init[]   =   { 1, 3, 3, 1, 17, 63, 55, 225, 259, 531, 1493, 2639, 1319, 10865, 17993, 11205, 13253, 111261, 0 };
            const std::uint32_t dim19576JoeKuoD6Init[]   =   { 1, 1, 1, 11, 25, 17, 41, 45, 385, 1009, 1573, 1797, 527, 543, 14743, 35789, 63871, 112183, 0 };
            const std::uint32_t dim19577JoeKuoD6Init[]   =   { 1, 1, 7, 15, 15, 57, 109, 127, 143, 955, 1091, 2585, 3429, 11763, 5849, 53805, 116865, 68895, 0 };
            const std::uint32_t dim19578JoeKuoD6Init[]   =   { 1, 1, 7, 15, 9, 11, 1, 9, 491, 765, 1835, 3825, 5043, 13091, 4123, 19621, 17687, 241015, 0 };
            const std::uint32_t dim19579JoeKuoD6Init[]   =   { 1, 3, 5, 7, 25, 51, 117, 193, 91, 451, 1871, 3819, 1881, 8065, 25809, 36257, 107955, 37109, 0 };
            const std::uint32_t dim19580JoeKuoD6Init[]   =   { 1, 3, 1, 15, 5, 5, 101, 7, 59, 859, 977, 2673, 2825, 3291, 26283, 23467, 28383, 257775, 0 };
            const std::uint32_t dim19581JoeKuoD6Init[]   =   { 1, 3, 3, 15, 17, 43, 87, 191, 85, 829, 653, 327, 1773, 10101, 2707, 18341, 61435, 242215, 0 };
            const std::uint32_t dim19582JoeKuoD6Init[]   =   { 1, 3, 7, 13, 27, 43, 127, 253, 403, 81, 505, 2841, 1509, 4951, 23791, 18099, 46747, 192717, 0 };
            const std::uint32_t dim19583JoeKuoD6Init[]   =   { 1, 1, 1, 9, 31, 15, 127, 29, 171, 999, 1919, 4059, 2781, 2475, 8997, 15459, 37003, 217141, 0 };
            const std::uint32_t dim19584JoeKuoD6Init[]   =   { 1, 3, 3, 1, 31, 41, 67, 31, 171, 719, 789, 645, 3925, 11117, 1241, 63221, 1087, 59789, 0 };
            const std::uint32_t dim19585JoeKuoD6Init[]   =   { 1, 1, 1, 9, 17, 41, 107, 13, 405, 879, 1955, 3309, 1281, 10601, 13883, 43987, 111691, 130555, 0 };
            const std::uint32_t dim19586JoeKuoD6Init[]   =   { 1, 3, 7, 9, 21, 17, 127, 243, 51, 689, 1945, 3769, 7121, 7703, 16825, 34893, 32167, 20167, 0 };
            const std::uint32_t dim19587JoeKuoD6Init[]   =   { 1, 1, 1, 5, 7, 7, 61, 149, 75, 289, 717, 1951, 5917, 13375, 15683, 27507, 10897, 199009, 0 };
            const std::uint32_t dim19588JoeKuoD6Init[]   =   { 1, 3, 7, 9, 25, 61, 43, 167, 45, 299, 5, 125, 3289, 13685, 10843, 25535, 98383, 143401, 0 };
            const std::uint32_t dim19589JoeKuoD6Init[]   =   { 1, 1, 3, 15, 21, 27, 37, 45, 233, 179, 611, 3025, 7887, 9421, 16791, 17147, 49013, 33249, 0 };
            const std::uint32_t dim19590JoeKuoD6Init[]   =   { 1, 3, 7, 15, 19, 43, 43, 9, 255, 295, 649, 811, 1303, 1989, 5401, 53891, 42679, 66879, 0 };
            const std::uint32_t dim19591JoeKuoD6Init[]   =   { 1, 1, 7, 7, 25, 31, 89, 199, 455, 733, 295, 1157, 4375, 7341, 7823, 6025, 56311, 257579, 0 };
            const std::uint32_t dim19592JoeKuoD6Init[]   =   { 1, 1, 7, 3, 1, 51, 15, 29, 35, 917, 1839, 741, 1089, 8615, 4967, 34047, 32981, 200693, 0 };
            const std::uint32_t dim19593JoeKuoD6Init[]   =   { 1, 3, 3, 11, 21, 13, 71, 53, 315, 801, 1015, 3829, 2297, 6649, 28501, 18173, 83121, 107195, 0 };
            const std::uint32_t dim19594JoeKuoD6Init[]   =   { 1, 1, 7, 7, 1, 5, 127, 103, 435, 707, 7, 1045, 187, 10927, 32395, 24999, 58463, 94069, 0 };
            const std::uint32_t dim19595JoeKuoD6Init[]   =   { 1, 1, 7, 9, 11, 25, 73, 57, 231, 455, 1033, 2899, 2861, 8811, 21671, 16115, 97807, 221791, 0 };
            const std::uint32_t dim19596JoeKuoD6Init[]   =   { 1, 3, 5, 11, 11, 19, 105, 37, 181, 1, 1231, 2275, 4789, 13071, 24843, 25901, 123711, 145609, 0 };
            const std::uint32_t dim19597JoeKuoD6Init[]   =   { 1, 3, 7, 13, 7, 7, 21, 215, 393, 43, 1713, 2921, 1959, 14417, 17109, 55793, 36285, 81731, 0 };
            const std::uint32_t dim19598JoeKuoD6Init[]   =   { 1, 1, 5, 15, 29, 15, 5, 115, 15, 795, 1535, 2473, 3663, 10123, 20721, 32739, 21141, 217731, 0 };
            const std::uint32_t dim19599JoeKuoD6Init[]   =   { 1, 1, 3, 1, 15, 13, 21, 49, 293, 689, 985, 3949, 3329, 7167, 16925, 15069, 47345, 192749, 0 };
            const std::uint32_t dim19600JoeKuoD6Init[]   =   { 1, 3, 3, 7, 5, 27, 85, 11, 337, 651, 777, 1775, 5279, 15229, 21473, 36561, 85293, 27893, 0 };
            const std::uint32_t dim19601JoeKuoD6Init[]   =   { 1, 3, 7, 1, 15, 29, 7, 199, 71, 893, 1587, 1831, 3891, 3299, 14323, 23165, 28199, 84055, 0 };
            const std::uint32_t dim19602JoeKuoD6Init[]   =   { 1, 1, 1, 7, 9, 27, 15, 75, 497, 127, 433, 1781, 3711, 12659, 3765, 40827, 112425, 36281, 0 };
            const std::uint32_t dim19603JoeKuoD6Init[]   =   { 1, 1, 5, 1, 31, 59, 9, 91, 301, 217, 2013, 2015, 265, 3795, 14609, 13389, 5451, 260169, 0 };
            const std::uint32_t dim19604JoeKuoD6Init[]   =   { 1, 1, 1, 15, 19, 43, 85, 37, 33, 687, 1253, 2615, 4027, 3741, 13971, 21261, 106261, 204233, 0 };
            const std::uint32_t dim19605JoeKuoD6Init[]   =   { 1, 1, 7, 9, 31, 45, 105, 111, 207, 433, 633, 3949, 8057, 5049, 23657, 12227, 86251, 218077, 0 };
            const std::uint32_t dim19606JoeKuoD6Init[]   =   { 1, 3, 5, 11, 13, 33, 1, 67, 117, 595, 1835, 287, 2509, 14841, 1525, 15761, 61319, 182531, 0 };
            const std::uint32_t dim19607JoeKuoD6Init[]   =   { 1, 1, 3, 9, 7, 43, 105, 85, 17, 349, 1769, 3945, 31, 4907, 9373, 22447, 70905, 29189, 0 };
            const std::uint32_t dim19608JoeKuoD6Init[]   =   { 1, 1, 5, 5, 9, 19, 93, 179, 95, 255, 1807, 2717, 4757, 15025, 19479, 63499, 42441, 236519, 0 };
            const std::uint32_t dim19609JoeKuoD6Init[]   =   { 1, 1, 1, 1, 21, 35, 1, 101, 343, 1023, 1311, 347, 301, 8419, 23367, 31543, 51661, 148277, 0 };
            const std::uint32_t dim19610JoeKuoD6Init[]   =   { 1, 1, 7, 11, 23, 37, 113, 207, 147, 743, 1905, 1683, 3733, 5659, 22491, 62129, 111671, 227019, 0 };
            const std::uint32_t dim19611JoeKuoD6Init[]   =   { 1, 1, 3, 13, 27, 5, 21, 207, 445, 319, 1355, 2541, 2853, 583, 1261, 64477, 18337, 91611, 0 };
            const std::uint32_t dim19612JoeKuoD6Init[]   =   { 1, 3, 5, 3, 1, 31, 51, 55, 487, 735, 1599, 523, 5323, 10855, 28717, 62103, 18671, 143885, 0 };
            const std::uint32_t dim19613JoeKuoD6Init[]   =   { 1, 3, 1, 1, 15, 5, 79, 107, 173, 747, 1213, 1151, 875, 12759, 27115, 16403, 31349, 208909, 0 };
            const std::uint32_t dim19614JoeKuoD6Init[]   =   { 1, 3, 5, 9, 13, 57, 35, 121, 135, 237, 1707, 3655, 8109, 3623, 5119, 27645, 49401, 46453, 0 };
            const std::uint32_t dim19615JoeKuoD6Init[]   =   { 1, 3, 7, 11, 27, 3, 103, 231, 43, 515, 1279, 499, 1355, 2605, 11587, 33641, 81661, 29441, 0 };
            const std::uint32_t dim19616JoeKuoD6Init[]   =   { 1, 3, 5, 7, 13, 27, 55, 191, 81, 185, 527, 519, 4555, 3349, 24533, 60635, 40009, 230761, 0 };
            const std::uint32_t dim19617JoeKuoD6Init[]   =   { 1, 1, 5, 3, 13, 35, 75, 211, 67, 305, 705, 543, 3819, 16265, 9867, 64309, 35047, 24873, 0 };
            const std::uint32_t dim19618JoeKuoD6Init[]   =   { 1, 3, 1, 1, 11, 37, 75, 3, 145, 327, 1243, 3291, 7127, 5009, 7757, 59567, 90459, 98035, 0 };
            const std::uint32_t dim19619JoeKuoD6Init[]   =   { 1, 3, 5, 9, 9, 5, 71, 29, 243, 41, 447, 2597, 1243, 12899, 19681, 30523, 90799, 142279, 0 };
            const std::uint32_t dim19620JoeKuoD6Init[]   =   { 1, 3, 3, 3, 15, 21, 25, 101, 451, 651, 143, 3899, 3377, 4855, 23843, 25047, 87951, 239229, 0 };
            const std::uint32_t dim19621JoeKuoD6Init[]   =   { 1, 1, 1, 1, 23, 29, 25, 31, 227, 43, 399, 723, 693, 12379, 11343, 46123, 105435, 224997, 0 };
            const std::uint32_t dim19622JoeKuoD6Init[]   =   { 1, 1, 7, 3, 21, 47, 77, 57, 397, 689, 267, 813, 1279, 1727, 7451, 34025, 90273, 111663, 0 };
            const std::uint32_t dim19623JoeKuoD6Init[]   =   { 1, 1, 5, 3, 25, 61, 7, 137, 271, 723, 495, 2575, 3695, 4947, 31973, 47835, 107003, 221839, 0 };
            const std::uint32_t dim19624JoeKuoD6Init[]   =   { 1, 3, 1, 7, 5, 25, 21, 95, 323, 3, 613, 1721, 2551, 8803, 6803, 52765, 34543, 110945, 0 };
            const std::uint32_t dim19625JoeKuoD6Init[]   =   { 1, 3, 5, 9, 27, 23, 123, 193, 63, 161, 1395, 679, 161, 13719, 29321, 19243, 51947, 229547, 0 };
            const std::uint32_t dim19626JoeKuoD6Init[]   =   { 1, 3, 5, 15, 15, 37, 127, 103, 439, 513, 989, 1393, 3761, 9109, 20649, 18171, 69939, 117447, 0 };
            const std::uint32_t dim19627JoeKuoD6Init[]   =   { 1, 1, 7, 9, 7, 57, 87, 159, 195, 821, 57, 2469, 7693, 6759, 32595, 41109, 94785, 53381, 0 };
            const std::uint32_t dim19628JoeKuoD6Init[]   =   { 1, 3, 3, 7, 17, 63, 41, 7, 437, 469, 1453, 3741, 7591, 5563, 11819, 23861, 129777, 119731, 0 };
            const std::uint32_t dim19629JoeKuoD6Init[]   =   { 1, 1, 3, 3, 27, 55, 21, 145, 243, 991, 687, 909, 2105, 4485, 9095, 3677, 53819, 183027, 0 };
            const std::uint32_t dim19630JoeKuoD6Init[]   =   { 1, 1, 1, 15, 13, 61, 27, 81, 95, 37, 1439, 973, 7613, 5749, 16811, 26801, 105745, 8847, 0 };
            const std::uint32_t dim19631JoeKuoD6Init[]   =   { 1, 3, 1, 9, 15, 17, 111, 61, 27, 373, 89, 2729, 6397, 4899, 11297, 4403, 30657, 207379, 0 };
            const std::uint32_t dim19632JoeKuoD6Init[]   =   { 1, 3, 5, 15, 19, 9, 19, 19, 497, 667, 105, 601, 6715, 6355, 4231, 19241, 101771, 105651, 0 };
            const std::uint32_t dim19633JoeKuoD6Init[]   =   { 1, 1, 3, 9, 11, 11, 115, 109, 177, 753, 997, 2119, 5969, 13377, 13285, 25373, 105023, 158393, 0 };
            const std::uint32_t dim19634JoeKuoD6Init[]   =   { 1, 3, 5, 15, 27, 23, 19, 117, 129, 457, 1973, 2171, 8071, 2093, 13407, 9295, 82967, 184753, 0 };
            const std::uint32_t dim19635JoeKuoD6Init[]   =   { 1, 1, 7, 5, 1, 45, 9, 25, 307, 629, 1169, 2859, 3987, 11411, 13609, 44993, 26019, 107003, 0 };
            const std::uint32_t dim19636JoeKuoD6Init[]   =   { 1, 1, 1, 13, 29, 15, 13, 163, 203, 885, 281, 1605, 8001, 899, 4081, 65467, 61283, 198963, 0 };
            const std::uint32_t dim19637JoeKuoD6Init[]   =   { 1, 1, 3, 5, 27, 9, 89, 193, 375, 633, 1807, 2069, 3467, 3167, 23751, 39115, 90093, 190365, 0 };
            const std::uint32_t dim19638JoeKuoD6Init[]   =   { 1, 3, 3, 5, 1, 1, 19, 161, 21, 745, 493, 2227, 7993, 3337, 27041, 4817, 58963, 237015, 0 };
            const std::uint32_t dim19639JoeKuoD6Init[]   =   { 1, 3, 5, 15, 15, 45, 51, 145, 299, 787, 1059, 2407, 1143, 775, 17473, 22235, 18241, 103897, 0 };
            const std::uint32_t dim19640JoeKuoD6Init[]   =   { 1, 1, 1, 9, 11, 35, 75, 195, 281, 935, 113, 3009, 4797, 7221, 12475, 18563, 10315, 255541, 0 };
            const std::uint32_t dim19641JoeKuoD6Init[]   =   { 1, 1, 5, 7, 25, 9, 121, 179, 303, 511, 2041, 1485, 529, 13843, 29013, 28139, 63237, 21259, 0 };
            const std::uint32_t dim19642JoeKuoD6Init[]   =   { 1, 3, 7, 11, 9, 21, 61, 177, 63, 179, 679, 17, 4069, 8929, 14499, 53913, 27925, 48449, 0 };
            const std::uint32_t dim19643JoeKuoD6Init[]   =   { 1, 3, 5, 3, 9, 27, 111, 247, 253, 175, 1591, 3583, 3351, 9039, 597, 23859, 126585, 157367, 0 };
            const std::uint32_t dim19644JoeKuoD6Init[]   =   { 1, 1, 7, 9, 1, 9, 29, 1, 273, 89, 767, 1873, 39, 10487, 29857, 23577, 67457, 44571, 0 };
            const std::uint32_t dim19645JoeKuoD6Init[]   =   { 1, 1, 7, 5, 5, 23, 13, 181, 283, 333, 21, 1409, 5937, 8981, 7445, 61267, 21729, 32677, 0 };
            const std::uint32_t dim19646JoeKuoD6Init[]   =   { 1, 3, 1, 15, 31, 5, 45, 253, 179, 91, 341, 359, 4269, 7567, 23699, 30589, 42909, 126171, 0 };
            const std::uint32_t dim19647JoeKuoD6Init[]   =   { 1, 3, 7, 7, 23, 45, 15, 93, 115, 873, 49, 845, 827, 14357, 20163, 41565, 37105, 120331, 0 };
            const std::uint32_t dim19648JoeKuoD6Init[]   =   { 1, 1, 7, 7, 15, 25, 55, 175, 11, 457, 1537, 1937, 807, 11399, 27751, 16935, 75231, 204039, 0 };
            const std::uint32_t dim19649JoeKuoD6Init[]   =   { 1, 3, 7, 13, 1, 37, 67, 145, 471, 1013, 1273, 4093, 4449, 4433, 29063, 205, 93249, 140383, 0 };
            const std::uint32_t dim19650JoeKuoD6Init[]   =   { 1, 3, 1, 13, 1, 57, 85, 223, 349, 125, 863, 2179, 7813, 8817, 1767, 19169, 41367, 65883, 0 };
            const std::uint32_t dim19651JoeKuoD6Init[]   =   { 1, 3, 3, 15, 21, 39, 3, 31, 67, 505, 271, 505, 5495, 4183, 3631, 4567, 48061, 149565, 0 };
            const std::uint32_t dim19652JoeKuoD6Init[]   =   { 1, 1, 7, 11, 13, 39, 109, 201, 287, 1013, 1505, 3105, 3845, 1963, 4361, 61753, 29145, 146235, 0 };
            const std::uint32_t dim19653JoeKuoD6Init[]   =   { 1, 3, 5, 3, 29, 39, 71, 99, 501, 53, 835, 3295, 5335, 1017, 25913, 63637, 115353, 210509, 0 };
            const std::uint32_t dim19654JoeKuoD6Init[]   =   { 1, 3, 1, 13, 9, 53, 33, 177, 419, 63, 793, 1329, 2261, 11633, 18805, 49771, 47533, 74949, 0 };
            const std::uint32_t dim19655JoeKuoD6Init[]   =   { 1, 3, 7, 11, 7, 49, 123, 237, 195, 17, 1919, 1911, 4135, 11829, 26307, 34905, 114361, 228655, 0 };
            const std::uint32_t dim19656JoeKuoD6Init[]   =   { 1, 3, 5, 3, 5, 57, 65, 161, 195, 857, 1187, 2303, 1975, 2555, 26065, 17963, 57403, 136193, 0 };
            const std::uint32_t dim19657JoeKuoD6Init[]   =   { 1, 1, 3, 11, 1, 5, 105, 217, 229, 769, 1393, 2419, 7751, 14293, 9407, 4569, 30663, 89345, 0 };
            const std::uint32_t dim19658JoeKuoD6Init[]   =   { 1, 3, 3, 7, 23, 15, 15, 189, 67, 863, 485, 2435, 5145, 10537, 16485, 50369, 118245, 253201, 0 };
            const std::uint32_t dim19659JoeKuoD6Init[]   =   { 1, 1, 1, 5, 27, 27, 47, 129, 383, 227, 115, 3027, 1575, 15765, 10207, 4885, 125707, 184703, 0 };
            const std::uint32_t dim19660JoeKuoD6Init[]   =   { 1, 3, 5, 5, 17, 9, 45, 55, 151, 751, 415, 2139, 8071, 2309, 27641, 29743, 47183, 21437, 0 };
            const std::uint32_t dim19661JoeKuoD6Init[]   =   { 1, 3, 3, 7, 9, 47, 51, 31, 261, 237, 1695, 1065, 4503, 7167, 25791, 39659, 90145, 130481, 0 };
            const std::uint32_t dim19662JoeKuoD6Init[]   =   { 1, 1, 3, 3, 21, 27, 53, 249, 407, 779, 1315, 1005, 6953, 14959, 2265, 61645, 118623, 254067, 0 };
            const std::uint32_t dim19663JoeKuoD6Init[]   =   { 1, 3, 1, 9, 13, 25, 33, 225, 467, 325, 1513, 1237, 1569, 8749, 1587, 4699, 19893, 163597, 0 };
            const std::uint32_t dim19664JoeKuoD6Init[]   =   { 1, 3, 5, 5, 29, 29, 1, 55, 437, 575, 149, 791, 4243, 4405, 22963, 64125, 21631, 25819, 0 };
            const std::uint32_t dim19665JoeKuoD6Init[]   =   { 1, 3, 5, 3, 25, 9, 19, 27, 419, 139, 2035, 2065, 1925, 11499, 20053, 13161, 15115, 120891, 0 };
            const std::uint32_t dim19666JoeKuoD6Init[]   =   { 1, 1, 5, 9, 7, 9, 113, 3, 195, 555, 863, 595, 6569, 9819, 14727, 38285, 13737, 130903, 0 };
            const std::uint32_t dim19667JoeKuoD6Init[]   =   { 1, 1, 3, 7, 19, 17, 35, 107, 489, 285, 247, 3103, 2919, 11163, 2811, 62081, 42989, 24495, 0 };
            const std::uint32_t dim19668JoeKuoD6Init[]   =   { 1, 3, 1, 15, 17, 5, 123, 221, 117, 689, 1567, 3803, 5801, 14121, 23263, 8851, 41559, 226271, 0 };
            const std::uint32_t dim19669JoeKuoD6Init[]   =   { 1, 1, 1, 15, 21, 39, 87, 135, 485, 59, 1899, 2483, 2599, 8783, 6129, 55407, 7291, 217117, 0 };
            const std::uint32_t dim19670JoeKuoD6Init[]   =   { 1, 1, 3, 11, 27, 53, 45, 241, 51, 829, 121, 3047, 6785, 15127, 13923, 47913, 9087, 112005, 0 };
            const std::uint32_t dim19671JoeKuoD6Init[]   =   { 1, 1, 1, 13, 5, 9, 45, 37, 235, 497, 871, 1471, 2895, 247, 9085, 39611, 63445, 218391, 0 };
            const std::uint32_t dim19672JoeKuoD6Init[]   =   { 1, 1, 5, 3, 5, 29, 23, 155, 339, 293, 535, 1569, 2625, 2867, 4639, 53049, 88721, 96903, 0 };
            const std::uint32_t dim19673JoeKuoD6Init[]   =   { 1, 1, 3, 15, 5, 25, 17, 45, 47, 683, 949, 1381, 5929, 9539, 3345, 59883, 19071, 200411, 0 };
            const std::uint32_t dim19674JoeKuoD6Init[]   =   { 1, 1, 1, 11, 11, 5, 71, 15, 469, 749, 1763, 541, 7109, 11731, 8463, 35145, 121795, 219441, 0 };
            const std::uint32_t dim19675JoeKuoD6Init[]   =   { 1, 3, 7, 11, 5, 17, 63, 159, 69, 993, 1519, 1531, 6913, 3901, 22131, 42909, 41299, 261813, 0 };
            const std::uint32_t dim19676JoeKuoD6Init[]   =   { 1, 1, 3, 5, 21, 27, 27, 197, 339, 275, 2011, 2263, 855, 1939, 21561, 30577, 6515, 124417, 0 };
            const std::uint32_t dim19677JoeKuoD6Init[]   =   { 1, 3, 5, 15, 25, 35, 91, 31, 269, 857, 327, 3643, 3211, 14401, 18399, 9007, 12897, 25555, 0 };
            const std::uint32_t dim19678JoeKuoD6Init[]   =   { 1, 1, 7, 15, 19, 47, 127, 157, 407, 867, 943, 1509, 3113, 49, 32131, 46975, 130013, 66457, 0 };
            const std::uint32_t dim19679JoeKuoD6Init[]   =   { 1, 3, 3, 13, 31, 45, 59, 135, 67, 825, 157, 2441, 2851, 2355, 28115, 14075, 106317, 145945, 0 };
            const std::uint32_t dim19680JoeKuoD6Init[]   =   { 1, 1, 1, 15, 27, 27, 5, 211, 85, 749, 671, 1341, 6865, 10027, 14419, 20159, 126647, 147893, 0 };
            const std::uint32_t dim19681JoeKuoD6Init[]   =   { 1, 1, 1, 7, 25, 49, 115, 231, 65, 161, 1409, 573, 2859, 639, 12567, 58459, 73781, 136893, 0 };
            const std::uint32_t dim19682JoeKuoD6Init[]   =   { 1, 1, 1, 7, 11, 57, 97, 141, 327, 975, 1799, 3051, 365, 9331, 14583, 16723, 113153, 224127, 0 };
            const std::uint32_t dim19683JoeKuoD6Init[]   =   { 1, 3, 1, 13, 13, 17, 105, 109, 151, 41, 1903, 1685, 2285, 5697, 16559, 34133, 106045, 203217, 0 };
            const std::uint32_t dim19684JoeKuoD6Init[]   =   { 1, 1, 1, 3, 29, 61, 43, 255, 269, 277, 1847, 3781, 7991, 131, 9833, 34305, 10763, 41869, 0 };
            const std::uint32_t dim19685JoeKuoD6Init[]   =   { 1, 1, 7, 3, 11, 1, 85, 89, 247, 99, 419, 2041, 3729, 10301, 5291, 36033, 31749, 261871, 0 };
            const std::uint32_t dim19686JoeKuoD6Init[]   =   { 1, 3, 7, 9, 27, 27, 41, 3, 303, 893, 697, 1631, 5015, 4233, 22827, 3913, 22245, 121193, 0 };
            const std::uint32_t dim19687JoeKuoD6Init[]   =   { 1, 3, 3, 13, 19, 11, 15, 239, 419, 123, 1213, 185, 4465, 4909, 25421, 18363, 72537, 167939, 0 };
            const std::uint32_t dim19688JoeKuoD6Init[]   =   { 1, 1, 3, 5, 13, 49, 57, 197, 19, 877, 1465, 2933, 5909, 7147, 1039, 37035, 91209, 126013, 0 };
            const std::uint32_t dim19689JoeKuoD6Init[]   =   { 1, 1, 3, 5, 23, 7, 63, 179, 59, 47, 1501, 1863, 2949, 13959, 28131, 29705, 107975, 155251, 0 };
            const std::uint32_t dim19690JoeKuoD6Init[]   =   { 1, 1, 1, 5, 25, 51, 77, 169, 327, 585, 1531, 3367, 3075, 6313, 26725, 453, 68635, 173787, 0 };
            const std::uint32_t dim19691JoeKuoD6Init[]   =   { 1, 3, 7, 9, 5, 15, 43, 45, 311, 367, 297, 2249, 7507, 4785, 22685, 37279, 121683, 141453, 0 };
            const std::uint32_t dim19692JoeKuoD6Init[]   =   { 1, 3, 7, 15, 17, 33, 43, 251, 281, 345, 1659, 3729, 7629, 6179, 26107, 64255, 88003, 2545, 0 };
            const std::uint32_t dim19693JoeKuoD6Init[]   =   { 1, 3, 7, 9, 17, 13, 71, 49, 341, 495, 1975, 173, 5773, 3821, 6615, 50917, 53781, 75557, 0 };
            const std::uint32_t dim19694JoeKuoD6Init[]   =   { 1, 1, 5, 13, 17, 21, 121, 35, 195, 367, 1191, 1331, 6423, 8425, 7705, 59117, 44575, 225431, 0 };
            const std::uint32_t dim19695JoeKuoD6Init[]   =   { 1, 1, 1, 5, 25, 39, 89, 65, 449, 491, 211, 2949, 4493, 23, 22571, 4801, 50525, 222563, 0 };
            const std::uint32_t dim19696JoeKuoD6Init[]   =   { 1, 1, 7, 5, 7, 21, 15, 171, 443, 225, 577, 1841, 8139, 15071, 6095, 60185, 71957, 244753, 0 };
            const std::uint32_t dim19697JoeKuoD6Init[]   =   { 1, 1, 5, 9, 31, 33, 21, 195, 415, 1003, 441, 627, 2339, 8245, 11187, 55933, 59045, 177455, 0 };
            const std::uint32_t dim19698JoeKuoD6Init[]   =   { 1, 1, 3, 9, 31, 29, 7, 15, 31, 577, 1435, 1317, 2923, 3807, 29693, 45857, 61787, 213565, 0 };
            const std::uint32_t dim19699JoeKuoD6Init[]   =   { 1, 3, 7, 15, 17, 51, 65, 87, 295, 811, 753, 1113, 7695, 275, 28331, 46363, 53247, 166993, 0 };
            const std::uint32_t dim19700JoeKuoD6Init[]   =   { 1, 1, 5, 11, 15, 31, 31, 47, 273, 383, 1831, 3821, 1337, 13257, 415, 35453, 15293, 173095, 0 };
            const std::uint32_t dim19701JoeKuoD6Init[]   =   { 1, 3, 1, 13, 19, 21, 63, 199, 159, 475, 1257, 3119, 7083, 2861, 21099, 16873, 83583, 186289, 0 };
            const std::uint32_t dim19702JoeKuoD6Init[]   =   { 1, 1, 7, 13, 15, 23, 11, 103, 387, 899, 261, 2863, 3681, 5683, 5587, 64655, 7411, 148633, 0 };
            const std::uint32_t dim19703JoeKuoD6Init[]   =   { 1, 3, 1, 13, 1, 45, 5, 173, 379, 287, 1451, 2253, 3811, 10963, 20285, 59681, 81285, 48523, 0 };
            const std::uint32_t dim19704JoeKuoD6Init[]   =   { 1, 1, 5, 9, 27, 17, 57, 25, 499, 289, 1083, 3057, 793, 5251, 10519, 36647, 67751, 237487, 0 };
            const std::uint32_t dim19705JoeKuoD6Init[]   =   { 1, 1, 3, 1, 17, 13, 23, 73, 1, 951, 111, 3769, 3611, 4827, 10081, 55919, 21411, 127303, 0 };
            const std::uint32_t dim19706JoeKuoD6Init[]   =   { 1, 3, 1, 1, 29, 35, 93, 139, 179, 217, 1839, 1907, 4365, 1813, 31985, 28927, 39319, 233413, 0 };
            const std::uint32_t dim19707JoeKuoD6Init[]   =   { 1, 1, 1, 7, 7, 47, 37, 127, 449, 473, 311, 3833, 3263, 4163, 15985, 50159, 82685, 73273, 0 };
            const std::uint32_t dim19708JoeKuoD6Init[]   =   { 1, 1, 1, 3, 3, 5, 69, 95, 101, 115, 1575, 63, 1897, 13733, 22149, 8793, 82983, 192553, 0 };
            const std::uint32_t dim19709JoeKuoD6Init[]   =   { 1, 3, 1, 5, 3, 57, 121, 13, 291, 975, 505, 3105, 6929, 12737, 25869, 29173, 16757, 17733, 0 };
            const std::uint32_t dim19710JoeKuoD6Init[]   =   { 1, 1, 3, 13, 13, 23, 51, 51, 239, 795, 877, 1547, 6533, 11497, 14309, 32941, 128109, 187313, 0 };
            const std::uint32_t dim19711JoeKuoD6Init[]   =   { 1, 1, 3, 5, 19, 37, 57, 223, 509, 379, 1235, 1881, 4133, 13219, 5479, 36781, 56155, 231001, 0 };
            const std::uint32_t dim19712JoeKuoD6Init[]   =   { 1, 1, 1, 5, 25, 45, 111, 183, 37, 875, 1487, 3771, 5593, 6835, 10921, 40697, 114455, 259491, 0 };
            const std::uint32_t dim19713JoeKuoD6Init[]   =   { 1, 1, 3, 11, 13, 5, 43, 47, 7, 435, 1543, 3835, 1631, 8889, 23567, 24705, 26687, 14261, 0 };
            const std::uint32_t dim19714JoeKuoD6Init[]   =   { 1, 3, 3, 11, 1, 13, 51, 171, 433, 1011, 679, 1307, 1683, 7379, 7163, 29727, 40209, 259973, 0 };
            const std::uint32_t dim19715JoeKuoD6Init[]   =   { 1, 3, 1, 5, 25, 33, 111, 11, 303, 815, 1883, 263, 7907, 12637, 19203, 64151, 55739, 240509, 0 };
            const std::uint32_t dim19716JoeKuoD6Init[]   =   { 1, 3, 5, 7, 23, 51, 3, 183, 425, 47, 231, 807, 1891, 10943, 17873, 20209, 60871, 30269, 0 };
            const std::uint32_t dim19717JoeKuoD6Init[]   =   { 1, 1, 1, 1, 1, 23, 11, 183, 351, 5, 37, 3883, 1291, 15933, 11379, 53057, 61389, 240547, 0 };
            const std::uint32_t dim19718JoeKuoD6Init[]   =   { 1, 3, 1, 5, 7, 53, 97, 29, 239, 805, 1929, 1001, 5103, 11, 24695, 7825, 109755, 254717, 0 };
            const std::uint32_t dim19719JoeKuoD6Init[]   =   { 1, 3, 3, 11, 15, 37, 115, 117, 391, 313, 1761, 3627, 3931, 10277, 1767, 25401, 123827, 60463, 0 };
            const std::uint32_t dim19720JoeKuoD6Init[]   =   { 1, 1, 7, 9, 9, 61, 23, 65, 473, 579, 1979, 415, 629, 3613, 27409, 46909, 3281, 3883, 0 };
            const std::uint32_t dim19721JoeKuoD6Init[]   =   { 1, 3, 3, 13, 25, 17, 71, 247, 297, 451, 153, 1949, 2727, 6427, 19815, 54013, 129363, 248237, 0 };
            const std::uint32_t dim19722JoeKuoD6Init[]   =   { 1, 1, 7, 7, 29, 9, 57, 171, 159, 287, 693, 1365, 4665, 5255, 15013, 21225, 125409, 5893, 0 };
            const std::uint32_t dim19723JoeKuoD6Init[]   =   { 1, 3, 3, 1, 9, 43, 13, 139, 359, 267, 115, 2025, 693, 4789, 10353, 60459, 30835, 56575, 0 };
            const std::uint32_t dim19724JoeKuoD6Init[]   =   { 1, 1, 1, 7, 23, 35, 35, 77, 245, 705, 75, 2841, 1683, 6109, 19661, 49021, 25019, 7297, 0 };
            const std::uint32_t dim19725JoeKuoD6Init[]   =   { 1, 3, 1, 5, 1, 19, 49, 53, 19, 435, 1471, 409, 7051, 7057, 3621, 42925, 59551, 70941, 0 };
            const std::uint32_t dim19726JoeKuoD6Init[]   =   { 1, 3, 7, 5, 21, 27, 39, 221, 389, 255, 537, 597, 7729, 10473, 6657, 13261, 11303, 112409, 0 };
            const std::uint32_t dim19727JoeKuoD6Init[]   =   { 1, 3, 7, 13, 29, 29, 81, 107, 329, 25, 537, 561, 2247, 10371, 30031, 20537, 28437, 113319, 0 };
            const std::uint32_t dim19728JoeKuoD6Init[]   =   { 1, 1, 5, 9, 9, 7, 89, 155, 337, 829, 755, 3259, 3563, 11849, 31179, 43297, 79601, 187545, 0 };
            const std::uint32_t dim19729JoeKuoD6Init[]   =   { 1, 3, 3, 5, 11, 63, 101, 159, 357, 627, 587, 3233, 405, 4083, 5953, 44541, 110723, 240573, 0 };
            const std::uint32_t dim19730JoeKuoD6Init[]   =   { 1, 1, 3, 15, 5, 39, 87, 231, 455, 195, 1603, 315, 3869, 6375, 745, 28349, 56469, 119033, 0 };
            const std::uint32_t dim19731JoeKuoD6Init[]   =   { 1, 1, 7, 1, 11, 7, 79, 47, 391, 585, 1299, 3237, 7345, 15959, 4293, 43285, 111737, 215923, 0 };
            const std::uint32_t dim19732JoeKuoD6Init[]   =   { 1, 1, 3, 15, 21, 53, 113, 73, 265, 589, 299, 289, 3983, 1653, 17407, 15287, 53199, 44221, 0 };
            const std::uint32_t dim19733JoeKuoD6Init[]   =   { 1, 3, 1, 3, 1, 13, 31, 41, 509, 523, 401, 2647, 2731, 5699, 15649, 51737, 81249, 230865, 0 };
            const std::uint32_t dim19734JoeKuoD6Init[]   =   { 1, 3, 5, 3, 15, 53, 91, 209, 249, 243, 1119, 2531, 319, 9259, 26555, 59579, 28767, 235073, 0 };
            const std::uint32_t dim19735JoeKuoD6Init[]   =   { 1, 1, 1, 13, 29, 25, 57, 3, 413, 945, 841, 1151, 7167, 2545, 7283, 3947, 109375, 148677, 0 };
            const std::uint32_t dim19736JoeKuoD6Init[]   =   { 1, 3, 3, 7, 29, 27, 81, 141, 21, 771, 577, 897, 73, 13081, 30035, 49213, 90627, 7483, 0 };
            const std::uint32_t dim19737JoeKuoD6Init[]   =   { 1, 3, 1, 13, 23, 11, 19, 159, 183, 789, 683, 2071, 7107, 3025, 27333, 9571, 69621, 48529, 0 };
            const std::uint32_t dim19738JoeKuoD6Init[]   =   { 1, 3, 1, 9, 5, 43, 7, 123, 341, 75, 1709, 135, 7929, 14563, 6849, 32783, 91971, 223789, 0 };
            const std::uint32_t dim19739JoeKuoD6Init[]   =   { 1, 1, 7, 3, 19, 13, 45, 229, 7, 559, 1895, 2649, 7593, 1063, 17715, 45019, 29743, 37819, 0 };
            const std::uint32_t dim19740JoeKuoD6Init[]   =   { 1, 1, 5, 3, 11, 25, 11, 169, 249, 415, 249, 209, 2223, 5947, 23381, 12109, 37697, 131729, 0 };
            const std::uint32_t dim19741JoeKuoD6Init[]   =   { 1, 1, 1, 7, 19, 47, 125, 117, 235, 825, 801, 921, 2363, 1261, 20529, 65445, 55315, 173561, 0 };
            const std::uint32_t dim19742JoeKuoD6Init[]   =   { 1, 1, 1, 1, 5, 39, 31, 11, 239, 333, 727, 3991, 1453, 2201, 18129, 3513, 112057, 109673, 0 };
            const std::uint32_t dim19743JoeKuoD6Init[]   =   { 1, 1, 7, 5, 21, 59, 37, 255, 261, 1, 1401, 1101, 1233, 3813, 22809, 39389, 66263, 191623, 0 };
            const std::uint32_t dim19744JoeKuoD6Init[]   =   { 1, 3, 1, 7, 5, 51, 73, 85, 319, 671, 1149, 1631, 6021, 10711, 3813, 36485, 106147, 202021, 0 };
            const std::uint32_t dim19745JoeKuoD6Init[]   =   { 1, 3, 3, 13, 7, 63, 59, 253, 337, 453, 61, 209, 2809, 10429, 28069, 55971, 57985, 244779, 0 };
            const std::uint32_t dim19746JoeKuoD6Init[]   =   { 1, 1, 1, 9, 27, 59, 45, 101, 427, 713, 1667, 2965, 6161, 1235, 8793, 2387, 66031, 85151, 0 };
            const std::uint32_t dim19747JoeKuoD6Init[]   =   { 1, 1, 3, 1, 5, 25, 101, 7, 449, 149, 823, 725, 6803, 11949, 13009, 14785, 45633, 241957, 0 };
            const std::uint32_t dim19748JoeKuoD6Init[]   =   { 1, 3, 7, 15, 29, 45, 103, 151, 159, 23, 1353, 3541, 5909, 4173, 31391, 16179, 38289, 206603, 0 };
            const std::uint32_t dim19749JoeKuoD6Init[]   =   { 1, 1, 7, 7, 23, 3, 97, 29, 141, 383, 379, 3189, 4399, 4545, 30797, 55827, 126223, 97049, 0 };
            const std::uint32_t dim19750JoeKuoD6Init[]   =   { 1, 3, 3, 7, 25, 35, 61, 15, 349, 929, 65, 3697, 7637, 12239, 29051, 36001, 114513, 151069, 0 };
            const std::uint32_t dim19751JoeKuoD6Init[]   =   { 1, 3, 3, 11, 19, 1, 23, 245, 9, 689, 1251, 1043, 2393, 15817, 31561, 21059, 3435, 228091, 0 };
            const std::uint32_t dim19752JoeKuoD6Init[]   =   { 1, 3, 7, 3, 23, 17, 121, 147, 427, 47, 905, 3877, 2301, 15709, 13599, 48895, 108955, 53219, 0 };
            const std::uint32_t dim19753JoeKuoD6Init[]   =   { 1, 3, 7, 3, 25, 31, 53, 143, 1, 841, 1691, 749, 6713, 5373, 23487, 25749, 13911, 240923, 0 };
            const std::uint32_t dim19754JoeKuoD6Init[]   =   { 1, 3, 5, 3, 7, 39, 101, 83, 159, 187, 583, 721, 7745, 1119, 61, 27319, 35157, 241729, 0 };
            const std::uint32_t dim19755JoeKuoD6Init[]   =   { 1, 1, 5, 11, 27, 21, 79, 199, 179, 463, 987, 3909, 1741, 503, 12339, 15323, 4063, 180337, 0 };
            const std::uint32_t dim19756JoeKuoD6Init[]   =   { 1, 3, 7, 11, 23, 43, 7, 115, 489, 215, 209, 3213, 4057, 13221, 27061, 52037, 34921, 36385, 0 };
            const std::uint32_t dim19757JoeKuoD6Init[]   =   { 1, 1, 7, 1, 15, 13, 113, 55, 207, 839, 1939, 4095, 5629, 7647, 12753, 59739, 60779, 196589, 0 };
            const std::uint32_t dim19758JoeKuoD6Init[]   =   { 1, 1, 1, 5, 5, 13, 113, 243, 297, 513, 1615, 1513, 1247, 4025, 20901, 44775, 86987, 75437, 0 };
            const std::uint32_t dim19759JoeKuoD6Init[]   =   { 1, 1, 3, 7, 7, 35, 77, 115, 223, 929, 1683, 949, 2191, 15533, 29471, 24103, 102475, 173027, 0 };
            const std::uint32_t dim19760JoeKuoD6Init[]   =   { 1, 3, 1, 11, 23, 37, 7, 179, 287, 267, 319, 3147, 1481, 12297, 28185, 51423, 7505, 236225, 0 };
            const std::uint32_t dim19761JoeKuoD6Init[]   =   { 1, 1, 3, 5, 27, 5, 71, 95, 289, 121, 939, 3543, 365, 4903, 10091, 3903, 111155, 83517, 0 };
            const std::uint32_t dim19762JoeKuoD6Init[]   =   { 1, 1, 7, 9, 29, 3, 87, 245, 313, 973, 1181, 3389, 3697, 13237, 13703, 31557, 17269, 17329, 0 };
            const std::uint32_t dim19763JoeKuoD6Init[]   =   { 1, 1, 5, 11, 5, 41, 117, 51, 239, 907, 809, 741, 5327, 3403, 11825, 46981, 93485, 38053, 0 };
            const std::uint32_t dim19764JoeKuoD6Init[]   =   { 1, 1, 7, 1, 25, 41, 5, 169, 11, 599, 1451, 2189, 7255, 8441, 11169, 58313, 4387, 69, 0 };
            const std::uint32_t dim19765JoeKuoD6Init[]   =   { 1, 3, 1, 13, 5, 21, 75, 229, 153, 355, 1511, 175, 4793, 12111, 25321, 39983, 84205, 195003, 0 };
            const std::uint32_t dim19766JoeKuoD6Init[]   =   { 1, 1, 7, 1, 17, 61, 67, 181, 69, 149, 921, 1107, 6319, 431, 29481, 12507, 13109, 29527, 0 };
            const std::uint32_t dim19767JoeKuoD6Init[]   =   { 1, 1, 5, 5, 27, 47, 69, 119, 469, 193, 513, 1573, 7421, 2723, 20997, 59585, 49645, 261259, 0 };
            const std::uint32_t dim19768JoeKuoD6Init[]   =   { 1, 1, 3, 9, 27, 41, 41, 3, 181, 803, 1281, 2937, 6745, 5629, 8403, 18987, 98411, 128321, 0 };
            const std::uint32_t dim19769JoeKuoD6Init[]   =   { 1, 3, 3, 9, 5, 29, 55, 223, 309, 841, 1049, 1163, 3497, 8935, 8529, 51367, 90693, 77463, 0 };
            const std::uint32_t dim19770JoeKuoD6Init[]   =   { 1, 3, 5, 3, 3, 59, 23, 31, 309, 907, 107, 3471, 4365, 14463, 24093, 35435, 24587, 151163, 0 };
            const std::uint32_t dim19771JoeKuoD6Init[]   =   { 1, 3, 3, 1, 11, 37, 99, 95, 485, 601, 1797, 891, 5645, 8927, 22085, 5185, 18495, 260455, 0 };
            const std::uint32_t dim19772JoeKuoD6Init[]   =   { 1, 3, 7, 15, 31, 61, 5, 177, 159, 287, 311, 1377, 1419, 4387, 25297, 22505, 100937, 223785, 0 };
            const std::uint32_t dim19773JoeKuoD6Init[]   =   { 1, 3, 3, 3, 27, 31, 45, 171, 95, 507, 1475, 4013, 2781, 133, 6857, 3367, 103455, 69559, 0 };
            const std::uint32_t dim19774JoeKuoD6Init[]   =   { 1, 3, 3, 7, 9, 51, 47, 247, 213, 665, 1929, 2799, 5513, 9183, 20197, 14831, 75277, 187565, 0 };
            const std::uint32_t dim19775JoeKuoD6Init[]   =   { 1, 3, 1, 9, 13, 11, 15, 253, 145, 31, 847, 1579, 5513, 9, 3327, 46049, 16709, 56353, 0 };
            const std::uint32_t dim19776JoeKuoD6Init[]   =   { 1, 3, 3, 3, 9, 17, 59, 131, 3, 621, 1209, 3415, 2999, 127, 629, 7925, 6109, 59743, 0 };
            const std::uint32_t dim19777JoeKuoD6Init[]   =   { 1, 1, 5, 15, 29, 35, 87, 197, 495, 671, 51, 293, 3943, 7969, 4739, 10161, 119943, 97217, 0 };
            const std::uint32_t dim19778JoeKuoD6Init[]   =   { 1, 1, 1, 9, 25, 57, 61, 197, 139, 899, 783, 3835, 3407, 16301, 19033, 33359, 56309, 16237, 0 };
            const std::uint32_t dim19779JoeKuoD6Init[]   =   { 1, 1, 5, 11, 25, 47, 95, 121, 197, 511, 227, 2281, 5805, 10581, 14885, 19685, 28075, 25431, 0 };
            const std::uint32_t dim19780JoeKuoD6Init[]   =   { 1, 1, 3, 9, 1, 43, 59, 105, 319, 45, 1567, 905, 7641, 2199, 3979, 13717, 22829, 44777, 0 };
            const std::uint32_t dim19781JoeKuoD6Init[]   =   { 1, 3, 7, 1, 19, 49, 105, 53, 227, 293, 989, 697, 2553, 4561, 14851, 8999, 74815, 207475, 0 };
            const std::uint32_t dim19782JoeKuoD6Init[]   =   { 1, 1, 5, 11, 23, 3, 85, 29, 419, 847, 1385, 3857, 641, 14951, 25629, 18019, 2497, 24723, 0 };
            const std::uint32_t dim19783JoeKuoD6Init[]   =   { 1, 3, 5, 15, 5, 11, 51, 225, 179, 695, 787, 663, 7051, 3595, 4987, 53315, 88693, 7915, 0 };
            const std::uint32_t dim19784JoeKuoD6Init[]   =   { 1, 3, 1, 13, 17, 51, 51, 247, 431, 555, 603, 3301, 443, 629, 26509, 32047, 54433, 208297, 0 };
            const std::uint32_t dim19785JoeKuoD6Init[]   =   { 1, 3, 7, 7, 13, 41, 95, 105, 135, 443, 377, 1259, 3301, 6945, 11677, 33869, 107799, 186567, 0 };
            const std::uint32_t dim19786JoeKuoD6Init[]   =   { 1, 1, 5, 7, 31, 17, 85, 129, 409, 781, 983, 25, 6877, 83, 12625, 31919, 41989, 55195, 0 };
            const std::uint32_t dim19787JoeKuoD6Init[]   =   { 1, 1, 3, 3, 7, 45, 37, 45, 237, 967, 1371, 657, 7983, 3121, 32707, 25757, 49987, 92683, 0 };
            const std::uint32_t dim19788JoeKuoD6Init[]   =   { 1, 3, 1, 1, 19, 57, 63, 25, 355, 893, 2017, 1671, 7343, 4451, 28243, 22157, 103901, 178017, 0 };
            const std::uint32_t dim19789JoeKuoD6Init[]   =   { 1, 3, 7, 13, 17, 59, 81, 99, 329, 117, 1395, 2565, 5725, 2371, 343, 4713, 35077, 49793, 0 };
            const std::uint32_t dim19790JoeKuoD6Init[]   =   { 1, 3, 7, 15, 31, 19, 87, 243, 411, 339, 1063, 117, 1827, 1583, 12571, 23153, 3363, 81695, 0 };
            const std::uint32_t dim19791JoeKuoD6Init[]   =   { 1, 3, 7, 1, 3, 49, 95, 133, 295, 433, 1885, 843, 6679, 13673, 32277, 59085, 46957, 217037, 0 };
            const std::uint32_t dim19792JoeKuoD6Init[]   =   { 1, 1, 3, 9, 23, 53, 45, 183, 79, 55, 1267, 283, 3249, 4101, 8107, 54473, 126141, 127235, 0 };
            const std::uint32_t dim19793JoeKuoD6Init[]   =   { 1, 3, 5, 7, 19, 57, 113, 205, 37, 817, 929, 3643, 2231, 15725, 1733, 7877, 116741, 254529, 0 };
            const std::uint32_t dim19794JoeKuoD6Init[]   =   { 1, 3, 1, 9, 9, 7, 75, 45, 83, 203, 1401, 445, 1043, 239, 30865, 32189, 91081, 180681, 0 };
            const std::uint32_t dim19795JoeKuoD6Init[]   =   { 1, 1, 7, 7, 1, 3, 61, 255, 483, 599, 897, 1601, 5189, 13279, 4981, 37235, 117505, 66625, 0 };
            const std::uint32_t dim19796JoeKuoD6Init[]   =   { 1, 1, 3, 13, 29, 43, 65, 73, 213, 307, 959, 2735, 5155, 16063, 15745, 6225, 50159, 182445, 0 };
            const std::uint32_t dim19797JoeKuoD6Init[]   =   { 1, 1, 3, 9, 31, 61, 73, 185, 457, 687, 1887, 4041, 3455, 4739, 16399, 40929, 32631, 179031, 0 };
            const std::uint32_t dim19798JoeKuoD6Init[]   =   { 1, 3, 3, 15, 5, 45, 1, 241, 187, 23, 63, 2497, 7759, 9175, 11003, 40579, 45769, 107133, 0 };
            const std::uint32_t dim19799JoeKuoD6Init[]   =   { 1, 3, 3, 7, 5, 63, 7, 67, 31, 917, 1825, 2037, 2527, 9767, 2665, 18573, 14289, 21583, 0 };
            const std::uint32_t dim19800JoeKuoD6Init[]   =   { 1, 1, 5, 15, 15, 25, 51, 127, 261, 925, 1651, 769, 7779, 7327, 7239, 20437, 9947, 144697, 0 };
            const std::uint32_t dim19801JoeKuoD6Init[]   =   { 1, 1, 5, 1, 5, 13, 99, 7, 269, 135, 345, 1851, 7963, 457, 24573, 32529, 127359, 157755, 0 };
            const std::uint32_t dim19802JoeKuoD6Init[]   =   { 1, 3, 5, 15, 21, 17, 31, 115, 321, 351, 117, 1301, 2455, 3363, 14213, 62903, 75273, 261119, 0 };
            const std::uint32_t dim19803JoeKuoD6Init[]   =   { 1, 3, 7, 1, 1, 9, 53, 209, 319, 489, 827, 1365, 4709, 7419, 28213, 56095, 9611, 234877, 0 };
            const std::uint32_t dim19804JoeKuoD6Init[]   =   { 1, 1, 5, 5, 1, 7, 49, 15, 377, 309, 1701, 1775, 5571, 12437, 27521, 54753, 68977, 138549, 0 };
            const std::uint32_t dim19805JoeKuoD6Init[]   =   { 1, 1, 3, 11, 9, 29, 67, 21, 411, 647, 983, 1075, 2387, 13355, 1781, 56129, 87235, 260133, 0 };
            const std::uint32_t dim19806JoeKuoD6Init[]   =   { 1, 3, 1, 11, 5, 57, 71, 159, 345, 853, 745, 3733, 1607, 7265, 20097, 18911, 101141, 70495, 0 };
            const std::uint32_t dim19807JoeKuoD6Init[]   =   { 1, 1, 3, 9, 1, 43, 127, 127, 471, 465, 1777, 1879, 4655, 12925, 24935, 58445, 78303, 200463, 0 };
            const std::uint32_t dim19808JoeKuoD6Init[]   =   { 1, 1, 1, 15, 5, 33, 63, 17, 401, 831, 1559, 3547, 7869, 13901, 18185, 9399, 65859, 185315, 0 };
            const std::uint32_t dim19809JoeKuoD6Init[]   =   { 1, 3, 7, 1, 25, 21, 17, 175, 401, 833, 847, 3593, 1283, 14745, 11827, 1987, 89299, 187369, 0 };
            const std::uint32_t dim19810JoeKuoD6Init[]   =   { 1, 1, 7, 13, 29, 31, 45, 219, 177, 369, 1313, 3015, 5859, 1829, 8793, 49109, 97581, 233179, 0 };
            const std::uint32_t dim19811JoeKuoD6Init[]   =   { 1, 3, 3, 15, 17, 31, 61, 215, 231, 495, 1307, 3067, 3187, 8813, 22505, 14055, 30773, 177955, 0 };
            const std::uint32_t dim19812JoeKuoD6Init[]   =   { 1, 3, 7, 15, 9, 61, 57, 105, 89, 267, 233, 905, 3727, 1841, 31875, 32499, 27003, 208491, 0 };
            const std::uint32_t dim19813JoeKuoD6Init[]   =   { 1, 3, 1, 11, 31, 9, 63, 55, 213, 209, 1625, 2635, 4335, 15201, 6127, 11097, 37991, 62813, 0 };
            const std::uint32_t dim19814JoeKuoD6Init[]   =   { 1, 1, 1, 5, 13, 49, 127, 249, 339, 525, 1943, 2935, 3255, 5199, 6869, 6325, 731, 51085, 0 };
            const std::uint32_t dim19815JoeKuoD6Init[]   =   { 1, 1, 5, 7, 7, 29, 59, 187, 463, 409, 1321, 377, 7361, 8303, 20385, 39649, 81379, 235555, 0 };
            const std::uint32_t dim19816JoeKuoD6Init[]   =   { 1, 1, 5, 13, 15, 45, 99, 57, 217, 535, 1747, 4081, 4781, 1005, 25197, 23853, 90587, 189579, 0 };
            const std::uint32_t dim19817JoeKuoD6Init[]   =   { 1, 1, 7, 7, 23, 31, 1, 151, 339, 447, 523, 2609, 5917, 6965, 25815, 62797, 104083, 245917, 0 };
            const std::uint32_t dim19818JoeKuoD6Init[]   =   { 1, 3, 5, 3, 7, 37, 79, 253, 423, 511, 1477, 3121, 5557, 1413, 31075, 22249, 117639, 243543, 0 };
            const std::uint32_t dim19819JoeKuoD6Init[]   =   { 1, 1, 3, 7, 5, 31, 93, 117, 135, 235, 745, 3287, 4451, 2487, 15179, 62229, 18247, 150277, 0 };
            const std::uint32_t dim19820JoeKuoD6Init[]   =   { 1, 1, 7, 15, 31, 57, 125, 219, 433, 629, 1809, 2499, 6083, 7631, 31495, 63183, 28533, 120579, 0 };
            const std::uint32_t dim19821JoeKuoD6Init[]   =   { 1, 1, 1, 13, 31, 47, 77, 73, 343, 867, 1055, 1121, 3035, 15693, 6971, 50231, 16527, 190795, 0 };
            const std::uint32_t dim19822JoeKuoD6Init[]   =   { 1, 3, 7, 7, 11, 1, 5, 215, 87, 885, 1429, 1277, 3831, 9341, 22011, 34585, 56167, 65301, 0 };
            const std::uint32_t dim19823JoeKuoD6Init[]   =   { 1, 3, 1, 15, 13, 53, 91, 59, 277, 819, 453, 3191, 757, 4729, 20605, 4283, 110745, 233655, 0 };
            const std::uint32_t dim19824JoeKuoD6Init[]   =   { 1, 3, 3, 5, 17, 47, 69, 117, 113, 775, 935, 1879, 2239, 5877, 18337, 50895, 44891, 2759, 0 };
            const std::uint32_t dim19825JoeKuoD6Init[]   =   { 1, 3, 5, 1, 27, 31, 77, 65, 355, 405, 825, 2419, 3337, 10179, 27665, 35459, 13721, 154227, 0 };
            const std::uint32_t dim19826JoeKuoD6Init[]   =   { 1, 3, 3, 7, 23, 61, 9, 241, 239, 85, 485, 2659, 5371, 16175, 28691, 49109, 124433, 167033, 0 };
            const std::uint32_t dim19827JoeKuoD6Init[]   =   { 1, 3, 3, 3, 11, 57, 37, 155, 443, 249, 1913, 1347, 6569, 5357, 4231, 58273, 50707, 57097, 0 };
            const std::uint32_t dim19828JoeKuoD6Init[]   =   { 1, 1, 3, 3, 1, 7, 87, 115, 259, 807, 45, 2997, 63, 16313, 12507, 39925, 17699, 24411, 0 };
            const std::uint32_t dim19829JoeKuoD6Init[]   =   { 1, 3, 3, 1, 19, 59, 97, 209, 247, 395, 21, 1803, 2547, 11607, 15703, 58099, 111907, 196101, 0 };
            const std::uint32_t dim19830JoeKuoD6Init[]   =   { 1, 1, 7, 13, 27, 61, 73, 183, 493, 953, 445, 567, 7373, 15275, 30081, 539, 89365, 3455, 0 };
            const std::uint32_t dim19831JoeKuoD6Init[]   =   { 1, 3, 1, 3, 25, 35, 3, 105, 243, 781, 1937, 2781, 7849, 2159, 2221, 58005, 89313, 182183, 0 };
            const std::uint32_t dim19832JoeKuoD6Init[]   =   { 1, 1, 7, 15, 21, 7, 67, 163, 179, 453, 581, 2245, 3915, 8985, 16809, 35113, 93605, 79009, 0 };
            const std::uint32_t dim19833JoeKuoD6Init[]   =   { 1, 1, 7, 5, 29, 57, 13, 75, 387, 511, 331, 1119, 307, 6145, 3841, 49987, 67335, 120419, 0 };
            const std::uint32_t dim19834JoeKuoD6Init[]   =   { 1, 3, 1, 5, 13, 21, 119, 207, 453, 943, 137, 2245, 7771, 5737, 9541, 29209, 106867, 110513, 0 };
            const std::uint32_t dim19835JoeKuoD6Init[]   =   { 1, 3, 7, 13, 7, 3, 99, 129, 245, 687, 883, 1321, 1131, 6661, 7437, 1345, 128247, 167877, 0 };
            const std::uint32_t dim19836JoeKuoD6Init[]   =   { 1, 1, 3, 11, 7, 57, 59, 3, 217, 549, 85, 2607, 215, 2249, 3963, 42931, 33747, 226265, 0 };
            const std::uint32_t dim19837JoeKuoD6Init[]   =   { 1, 1, 5, 5, 29, 23, 115, 215, 103, 427, 1689, 831, 3293, 14055, 3735, 49521, 17703, 182887, 0 };
            const std::uint32_t dim19838JoeKuoD6Init[]   =   { 1, 1, 1, 15, 5, 43, 27, 181, 217, 955, 225, 2731, 7347, 14123, 26169, 4371, 26907, 15017, 0 };
            const std::uint32_t dim19839JoeKuoD6Init[]   =   { 1, 1, 7, 7, 31, 55, 63, 223, 61, 63, 431, 2779, 3169, 14323, 2945, 63913, 85407, 76511, 0 };
            const std::uint32_t dim19840JoeKuoD6Init[]   =   { 1, 1, 3, 11, 5, 27, 113, 75, 313, 697, 13, 1853, 7467, 5701, 16749, 17939, 13475, 39807, 0 };
            const std::uint32_t dim19841JoeKuoD6Init[]   =   { 1, 1, 7, 5, 13, 53, 55, 115, 125, 341, 321, 3291, 2675, 13659, 16819, 45397, 42917, 104361, 0 };
            const std::uint32_t dim19842JoeKuoD6Init[]   =   { 1, 3, 3, 15, 27, 47, 19, 213, 441, 605, 593, 2287, 4847, 10505, 22185, 36157, 10881, 87799, 0 };
            const std::uint32_t dim19843JoeKuoD6Init[]   =   { 1, 1, 1, 11, 15, 39, 109, 3, 469, 371, 1743, 2789, 199, 8703, 7407, 3353, 103417, 73319, 0 };
            const std::uint32_t dim19844JoeKuoD6Init[]   =   { 1, 3, 7, 5, 25, 61, 77, 111, 263, 399, 1579, 3447, 6205, 5945, 28099, 39183, 77003, 115001, 0 };
            const std::uint32_t dim19845JoeKuoD6Init[]   =   { 1, 1, 1, 3, 1, 7, 57, 193, 379, 923, 151, 2227, 7285, 2371, 24567, 34037, 80655, 125499, 0 };
            const std::uint32_t dim19846JoeKuoD6Init[]   =   { 1, 3, 5, 7, 13, 15, 5, 193, 55, 319, 1851, 2439, 8071, 5329, 3155, 64669, 18547, 238997, 0 };
            const std::uint32_t dim19847JoeKuoD6Init[]   =   { 1, 3, 3, 11, 7, 23, 1, 203, 333, 951, 153, 1249, 5093, 407, 361, 14175, 45149, 186291, 0 };
            const std::uint32_t dim19848JoeKuoD6Init[]   =   { 1, 3, 1, 11, 13, 19, 89, 229, 139, 981, 455, 907, 5109, 8513, 23823, 54933, 69985, 227679, 0 };
            const std::uint32_t dim19849JoeKuoD6Init[]   =   { 1, 3, 5, 13, 23, 47, 65, 123, 115, 759, 375, 1283, 729, 11045, 22015, 18287, 112603, 75911, 0 };
            const std::uint32_t dim19850JoeKuoD6Init[]   =   { 1, 1, 3, 1, 5, 43, 91, 123, 219, 409, 517, 3999, 1409, 5949, 15727, 62705, 73573, 198447, 0 };
            const std::uint32_t dim19851JoeKuoD6Init[]   =   { 1, 3, 3, 3, 5, 23, 95, 51, 275, 455, 1831, 2427, 3779, 10209, 30839, 23393, 25681, 8715, 0 };
            const std::uint32_t dim19852JoeKuoD6Init[]   =   { 1, 3, 5, 3, 9, 5, 61, 97, 497, 397, 695, 517, 3313, 4911, 1961, 45805, 99135, 216657, 0 };
            const std::uint32_t dim19853JoeKuoD6Init[]   =   { 1, 1, 1, 7, 13, 41, 19, 31, 103, 1005, 73, 1855, 405, 12395, 19979, 17663, 105183, 28493, 0 };
            const std::uint32_t dim19854JoeKuoD6Init[]   =   { 1, 3, 1, 11, 27, 27, 69, 149, 1, 225, 1809, 1367, 3663, 6545, 8475, 40837, 64459, 66705, 0 };
            const std::uint32_t dim19855JoeKuoD6Init[]   =   { 1, 3, 3, 1, 29, 21, 113, 149, 215, 443, 1069, 3437, 1793, 13573, 28285, 33707, 29127, 40715, 0 };
            const std::uint32_t dim19856JoeKuoD6Init[]   =   { 1, 3, 3, 5, 21, 9, 53, 181, 455, 283, 245, 3999, 875, 9799, 10963, 31603, 34907, 64977, 0 };
            const std::uint32_t dim19857JoeKuoD6Init[]   =   { 1, 3, 1, 11, 31, 51, 29, 103, 61, 529, 777, 1097, 445, 9169, 6305, 4513, 60189, 164103, 0 };
            const std::uint32_t dim19858JoeKuoD6Init[]   =   { 1, 1, 1, 3, 21, 5, 87, 11, 461, 637, 1283, 1471, 1429, 2401, 12163, 29401, 30089, 41745, 0 };
            const std::uint32_t dim19859JoeKuoD6Init[]   =   { 1, 1, 3, 3, 17, 43, 13, 153, 73, 419, 747, 279, 7195, 4383, 26345, 28365, 97753, 208989, 0 };
            const std::uint32_t dim19860JoeKuoD6Init[]   =   { 1, 3, 7, 1, 17, 55, 103, 151, 327, 575, 1923, 1533, 4699, 2171, 15447, 64047, 59007, 54523, 0 };
            const std::uint32_t dim19861JoeKuoD6Init[]   =   { 1, 3, 7, 7, 3, 51, 79, 39, 403, 599, 161, 2465, 4911, 10327, 23599, 3267, 44177, 184231, 0 };
            const std::uint32_t dim19862JoeKuoD6Init[]   =   { 1, 3, 3, 15, 5, 19, 57, 83, 507, 927, 665, 3471, 5037, 2051, 22923, 36813, 97393, 102715, 0 };
            const std::uint32_t dim19863JoeKuoD6Init[]   =   { 1, 3, 3, 13, 11, 19, 91, 179, 113, 295, 855, 2071, 3265, 4089, 8627, 7461, 23855, 53675, 0 };
            const std::uint32_t dim19864JoeKuoD6Init[]   =   { 1, 1, 3, 5, 21, 41, 11, 227, 87, 417, 209, 2013, 4849, 5291, 22073, 40235, 71283, 140785, 0 };
            const std::uint32_t dim19865JoeKuoD6Init[]   =   { 1, 3, 3, 5, 29, 57, 95, 65, 177, 177, 1973, 563, 5249, 337, 7611, 45099, 15443, 46583, 0 };
            const std::uint32_t dim19866JoeKuoD6Init[]   =   { 1, 1, 7, 3, 3, 5, 107, 75, 31, 293, 821, 1837, 2363, 13621, 8793, 29841, 127201, 131707, 0 };
            const std::uint32_t dim19867JoeKuoD6Init[]   =   { 1, 1, 1, 5, 1, 45, 69, 61, 157, 999, 183, 3431, 3487, 9461, 17545, 26973, 115527, 58419, 0 };
            const std::uint32_t dim19868JoeKuoD6Init[]   =   { 1, 1, 7, 7, 27, 5, 125, 153, 191, 745, 125, 2807, 5043, 10657, 24487, 19517, 31735, 42421, 0 };
            const std::uint32_t dim19869JoeKuoD6Init[]   =   { 1, 1, 7, 9, 25, 37, 73, 255, 141, 229, 1723, 1331, 6089, 13109, 30683, 2335, 111517, 105411, 0 };
            const std::uint32_t dim19870JoeKuoD6Init[]   =   { 1, 1, 5, 7, 3, 61, 79, 203, 423, 669, 1757, 1725, 4239, 7013, 28591, 61853, 81103, 39813, 0 };
            const std::uint32_t dim19871JoeKuoD6Init[]   =   { 1, 1, 3, 7, 21, 27, 23, 119, 441, 113, 1019, 285, 53, 8643, 31689, 2629, 126573, 60835, 0 };
            const std::uint32_t dim19872JoeKuoD6Init[]   =   { 1, 1, 5, 11, 29, 49, 23, 55, 441, 809, 1177, 1371, 5945, 6461, 11537, 12287, 85637, 232065, 0 };
            const std::uint32_t dim19873JoeKuoD6Init[]   =   { 1, 3, 1, 15, 5, 13, 19, 209, 105, 897, 565, 3209, 487, 9837, 22169, 26317, 39907, 185193, 0 };
            const std::uint32_t dim19874JoeKuoD6Init[]   =   { 1, 1, 1, 5, 23, 45, 49, 55, 501, 213, 1217, 3159, 733, 5889, 5475, 4953, 37317, 100369, 0 };
            const std::uint32_t dim19875JoeKuoD6Init[]   =   { 1, 1, 5, 1, 19, 5, 57, 137, 361, 605, 1077, 2015, 5511, 4667, 18457, 45979, 120253, 203397, 0 };
            const std::uint32_t dim19876JoeKuoD6Init[]   =   { 1, 1, 7, 9, 19, 19, 11, 187, 5, 647, 275, 1265, 7587, 16183, 369, 31885, 58347, 36829, 0 };
            const std::uint32_t dim19877JoeKuoD6Init[]   =   { 1, 3, 5, 3, 31, 31, 7, 105, 359, 839, 641, 3215, 4807, 13397, 885, 52867, 57125, 180607, 0 };
            const std::uint32_t dim19878JoeKuoD6Init[]   =   { 1, 1, 7, 9, 19, 45, 43, 211, 429, 757, 1637, 1569, 935, 8899, 24823, 18599, 111373, 190979, 0 };
            const std::uint32_t dim19879JoeKuoD6Init[]   =   { 1, 1, 7, 7, 13, 47, 3, 241, 467, 209, 323, 3467, 4397, 15395, 15373, 14499, 92443, 65931, 0 };
            const std::uint32_t dim19880JoeKuoD6Init[]   =   { 1, 3, 3, 5, 5, 9, 67, 115, 45, 279, 1753, 1575, 8127, 9651, 5169, 25643, 29671, 214383, 0 };
            const std::uint32_t dim19881JoeKuoD6Init[]   =   { 1, 3, 7, 7, 29, 7, 37, 205, 495, 445, 1771, 1439, 3577, 10423, 10865, 26851, 15251, 63373, 0 };
            const std::uint32_t dim19882JoeKuoD6Init[]   =   { 1, 3, 1, 9, 29, 13, 45, 61, 153, 193, 1407, 1075, 4023, 2367, 1147, 51277, 52975, 123061, 0 };
            const std::uint32_t dim19883JoeKuoD6Init[]   =   { 1, 3, 3, 3, 31, 25, 113, 173, 345, 565, 145, 3437, 7051, 12557, 27919, 41733, 76717, 192645, 0 };
            const std::uint32_t dim19884JoeKuoD6Init[]   =   { 1, 3, 3, 7, 3, 55, 35, 219, 55, 467, 635, 3833, 3753, 1099, 15301, 53121, 120807, 70481, 0 };
            const std::uint32_t dim19885JoeKuoD6Init[]   =   { 1, 3, 7, 7, 13, 1, 121, 191, 71, 193, 1891, 2303, 1401, 9143, 31297, 38979, 43093, 138941, 0 };
            const std::uint32_t dim19886JoeKuoD6Init[]   =   { 1, 3, 7, 5, 17, 51, 83, 201, 231, 423, 511, 1301, 6075, 475, 2603, 49327, 78565, 220827, 0 };
            const std::uint32_t dim19887JoeKuoD6Init[]   =   { 1, 3, 1, 7, 5, 61, 23, 11, 9, 711, 251, 1383, 613, 6213, 8921, 27267, 66009, 28575, 0 };
            const std::uint32_t dim19888JoeKuoD6Init[]   =   { 1, 3, 1, 3, 13, 13, 61, 211, 353, 883, 343, 1089, 2041, 7781, 25285, 9053, 76801, 153009, 0 };
            const std::uint32_t dim19889JoeKuoD6Init[]   =   { 1, 3, 7, 5, 17, 61, 67, 69, 361, 937, 949, 1483, 2825, 3753, 16533, 17277, 16539, 140521, 0 };
            const std::uint32_t dim19890JoeKuoD6Init[]   =   { 1, 3, 5, 9, 7, 19, 31, 239, 357, 561, 1583, 3059, 2023, 2213, 11283, 18603, 83487, 162415, 0 };
            const std::uint32_t dim19891JoeKuoD6Init[]   =   { 1, 1, 3, 15, 15, 59, 9, 43, 353, 203, 765, 1907, 2733, 3747, 30617, 32671, 119005, 72131, 0 };
            const std::uint32_t dim19892JoeKuoD6Init[]   =   { 1, 3, 1, 7, 17, 61, 55, 113, 439, 75, 703, 2741, 1059, 4561, 15923, 17153, 32563, 79681, 0 };
            const std::uint32_t dim19893JoeKuoD6Init[]   =   { 1, 1, 1, 15, 11, 57, 91, 245, 187, 185, 1859, 1209, 3247, 10863, 22421, 47287, 26831, 200935, 0 };
            const std::uint32_t dim19894JoeKuoD6Init[]   =   { 1, 1, 3, 13, 11, 39, 61, 211, 51, 197, 861, 2965, 4691, 9955, 2289, 28795, 61537, 235359, 0 };
            const std::uint32_t dim19895JoeKuoD6Init[]   =   { 1, 1, 7, 1, 31, 37, 121, 107, 79, 521, 371, 983, 6189, 4515, 25691, 26933, 123189, 70033, 0 };
            const std::uint32_t dim19896JoeKuoD6Init[]   =   { 1, 3, 3, 15, 19, 33, 31, 237, 35, 877, 1013, 3445, 573, 1145, 27781, 26327, 117451, 142339, 0 };
            const std::uint32_t dim19897JoeKuoD6Init[]   =   { 1, 3, 3, 15, 15, 9, 17, 185, 151, 499, 493, 1331, 1587, 12657, 22577, 7957, 126253, 57971, 0 };
            const std::uint32_t dim19898JoeKuoD6Init[]   =   { 1, 3, 7, 15, 3, 29, 43, 105, 423, 601, 793, 1011, 6657, 7287, 18561, 46993, 72945, 233051, 0 };
            const std::uint32_t dim19899JoeKuoD6Init[]   =   { 1, 1, 7, 5, 15, 17, 125, 141, 75, 877, 281, 2011, 4217, 9785, 7587, 42863, 35585, 212795, 0 };
            const std::uint32_t dim19900JoeKuoD6Init[]   =   { 1, 1, 3, 3, 3, 37, 67, 129, 433, 233, 115, 687, 6253, 12805, 10935, 49963, 91675, 241951, 0 };
            const std::uint32_t dim19901JoeKuoD6Init[]   =   { 1, 3, 1, 5, 3, 41, 3, 233, 317, 959, 1407, 1251, 743, 4165, 15561, 41165, 22393, 111633, 0 };
            const std::uint32_t dim19902JoeKuoD6Init[]   =   { 1, 3, 3, 15, 17, 15, 53, 245, 109, 413, 1149, 35, 2931, 11635, 27091, 63659, 33973, 16867, 0 };
            const std::uint32_t dim19903JoeKuoD6Init[]   =   { 1, 3, 7, 13, 3, 43, 83, 201, 367, 275, 235, 1795, 4041, 13539, 22345, 31451, 83985, 3527, 0 };
            const std::uint32_t dim19904JoeKuoD6Init[]   =   { 1, 3, 3, 9, 31, 47, 63, 117, 195, 497, 453, 1183, 3857, 14075, 28057, 13205, 54331, 54641, 0 };
            const std::uint32_t dim19905JoeKuoD6Init[]   =   { 1, 1, 7, 11, 11, 39, 37, 183, 213, 537, 1371, 901, 5255, 11791, 18993, 58785, 114113, 229815, 0 };
            const std::uint32_t dim19906JoeKuoD6Init[]   =   { 1, 3, 5, 5, 13, 45, 77, 165, 329, 439, 2011, 1845, 4577, 12457, 16959, 45943, 37715, 169775, 0 };
            const std::uint32_t dim19907JoeKuoD6Init[]   =   { 1, 1, 3, 11, 5, 7, 21, 245, 365, 371, 1291, 2569, 1791, 6003, 18619, 18661, 98551, 89645, 0 };
            const std::uint32_t dim19908JoeKuoD6Init[]   =   { 1, 3, 1, 7, 3, 51, 49, 245, 151, 919, 489, 3967, 3157, 7159, 17207, 19749, 94455, 112403, 0 };
            const std::uint32_t dim19909JoeKuoD6Init[]   =   { 1, 3, 7, 5, 9, 15, 17, 201, 273, 669, 1571, 3915, 1859, 2569, 28855, 27225, 116711, 148377, 0 };
            const std::uint32_t dim19910JoeKuoD6Init[]   =   { 1, 3, 7, 3, 19, 45, 115, 71, 201, 85, 1349, 3897, 4941, 10839, 14781, 36487, 107037, 109185, 0 };
            const std::uint32_t dim19911JoeKuoD6Init[]   =   { 1, 3, 5, 13, 11, 11, 35, 19, 213, 41, 45, 4075, 3163, 12937, 17487, 28911, 21289, 198489, 0 };
            const std::uint32_t dim19912JoeKuoD6Init[]   =   { 1, 1, 1, 11, 7, 35, 67, 23, 451, 235, 717, 181, 6697, 9359, 24561, 36187, 125179, 35119, 0 };
            const std::uint32_t dim19913JoeKuoD6Init[]   =   { 1, 1, 7, 15, 7, 47, 55, 125, 465, 251, 211, 3137, 4101, 1341, 2287, 22149, 45089, 94173, 0 };
            const std::uint32_t dim19914JoeKuoD6Init[]   =   { 1, 3, 1, 15, 19, 7, 15, 207, 7, 759, 869, 2337, 6805, 8287, 13447, 9963, 7177, 173505, 0 };
            const std::uint32_t dim19915JoeKuoD6Init[]   =   { 1, 3, 7, 13, 15, 3, 65, 143, 291, 511, 939, 669, 4095, 1931, 26015, 18253, 102461, 93837, 0 };
            const std::uint32_t dim19916JoeKuoD6Init[]   =   { 1, 3, 1, 5, 23, 3, 19, 121, 489, 583, 1425, 627, 4229, 5343, 3759, 17845, 105369, 132239, 0 };
            const std::uint32_t dim19917JoeKuoD6Init[]   =   { 1, 3, 3, 9, 29, 9, 17, 153, 111, 879, 1225, 979, 2687, 10477, 10105, 18091, 37825, 28077, 0 };
            const std::uint32_t dim19918JoeKuoD6Init[]   =   { 1, 1, 7, 9, 3, 51, 75, 101, 197, 551, 89, 1441, 607, 14025, 30411, 26887, 3435, 32977, 0 };
            const std::uint32_t dim19919JoeKuoD6Init[]   =   { 1, 1, 7, 3, 25, 29, 95, 123, 197, 767, 1513, 721, 4149, 10873, 32247, 4469, 42297, 49651, 0 };
            const std::uint32_t dim19920JoeKuoD6Init[]   =   { 1, 3, 5, 15, 11, 3, 77, 161, 309, 923, 513, 161, 6447, 9811, 9209, 21413, 8611, 237557, 0 };
            const std::uint32_t dim19921JoeKuoD6Init[]   =   { 1, 3, 1, 3, 23, 11, 61, 107, 317, 771, 1469, 3367, 6607, 11495, 12271, 59989, 52483, 194761, 0 };
            const std::uint32_t dim19922JoeKuoD6Init[]   =   { 1, 3, 7, 7, 23, 1, 37, 47, 185, 863, 1153, 3517, 6165, 3921, 19311, 37339, 112477, 204915, 0 };
            const std::uint32_t dim19923JoeKuoD6Init[]   =   { 1, 3, 7, 7, 15, 61, 9, 113, 175, 305, 1759, 2933, 2139, 3591, 15303, 54479, 126511, 255205, 0 };
            const std::uint32_t dim19924JoeKuoD6Init[]   =   { 1, 1, 1, 3, 29, 43, 19, 183, 121, 577, 1329, 1737, 4373, 5577, 24023, 40103, 22333, 123423, 0 };
            const std::uint32_t dim19925JoeKuoD6Init[]   =   { 1, 3, 5, 1, 29, 1, 5, 177, 271, 431, 139, 705, 4319, 9301, 15887, 13253, 13275, 233317, 0 };
            const std::uint32_t dim19926JoeKuoD6Init[]   =   { 1, 1, 3, 7, 21, 3, 13, 51, 459, 359, 1721, 193, 4887, 7805, 20615, 28813, 82427, 57853, 0 };
            const std::uint32_t dim19927JoeKuoD6Init[]   =   { 1, 3, 3, 13, 3, 29, 43, 95, 339, 993, 979, 2323, 7505, 10203, 9475, 16513, 21651, 104871, 0 };
            const std::uint32_t dim19928JoeKuoD6Init[]   =   { 1, 1, 3, 15, 11, 5, 97, 127, 397, 25, 507, 1839, 2313, 13399, 899, 25713, 94363, 178287, 0 };
            const std::uint32_t dim19929JoeKuoD6Init[]   =   { 1, 1, 5, 5, 9, 53, 95, 171, 107, 129, 1041, 3583, 5479, 943, 21435, 36481, 85519, 169651, 0 };
            const std::uint32_t dim19930JoeKuoD6Init[]   =   { 1, 1, 1, 1, 1, 11, 17, 249, 277, 805, 1827, 2705, 3015, 9033, 25019, 38593, 59235, 21145, 0 };
            const std::uint32_t dim19931JoeKuoD6Init[]   =   { 1, 1, 7, 3, 7, 59, 107, 213, 109, 213, 555, 3463, 953, 3173, 18947, 2863, 27889, 32493, 0 };
            const std::uint32_t dim19932JoeKuoD6Init[]   =   { 1, 3, 5, 15, 21, 11, 99, 131, 287, 513, 1393, 3327, 7347, 4343, 8805, 29571, 97151, 97313, 0 };
            const std::uint32_t dim19933JoeKuoD6Init[]   =   { 1, 3, 5, 3, 17, 53, 23, 21, 227, 291, 111, 1951, 6593, 16325, 31725, 31997, 116907, 181027, 0 };
            const std::uint32_t dim19934JoeKuoD6Init[]   =   { 1, 1, 5, 3, 15, 57, 93, 153, 345, 257, 169, 795, 3907, 5669, 25447, 28775, 1489, 216417, 0 };
            const std::uint32_t dim19935JoeKuoD6Init[]   =   { 1, 1, 1, 5, 19, 19, 113, 55, 431, 685, 1839, 711, 4909, 10211, 25765, 37, 72657, 79769, 0 };
            const std::uint32_t dim19936JoeKuoD6Init[]   =   { 1, 3, 5, 7, 19, 17, 93, 145, 99, 799, 1615, 1583, 7705, 1069, 30259, 37951, 78965, 16203, 0 };
            const std::uint32_t dim19937JoeKuoD6Init[]   =   { 1, 3, 7, 13, 23, 61, 119, 49, 413, 1021, 415, 465, 7395, 31, 16415, 1009, 9843, 86531, 0 };
            const std::uint32_t dim19938JoeKuoD6Init[]   =   { 1, 1, 3, 15, 17, 21, 83, 69, 411, 1, 269, 1391, 295, 13649, 21649, 62453, 11457, 215375, 0 };
            const std::uint32_t dim19939JoeKuoD6Init[]   =   { 1, 3, 3, 7, 25, 53, 95, 99, 447, 323, 27, 1595, 3771, 16099, 31523, 14405, 66999, 65733, 0 };
            const std::uint32_t dim19940JoeKuoD6Init[]   =   { 1, 1, 3, 11, 25, 29, 19, 95, 101, 661, 537, 641, 1455, 16151, 29087, 54009, 89395, 2223, 0 };
            const std::uint32_t dim19941JoeKuoD6Init[]   =   { 1, 1, 1, 11, 11, 33, 91, 227, 449, 661, 1621, 1743, 2859, 9797, 32397, 41767, 116325, 6839, 0 };
            const std::uint32_t dim19942JoeKuoD6Init[]   =   { 1, 3, 3, 7, 31, 41, 15, 139, 53, 789, 25, 67, 1131, 5987, 14091, 37259, 70313, 6633, 0 };
            const std::uint32_t dim19943JoeKuoD6Init[]   =   { 1, 3, 7, 13, 21, 29, 71, 245, 497, 493, 207, 3221, 3695, 3045, 1497, 29235, 65113, 82015, 0 };
            const std::uint32_t dim19944JoeKuoD6Init[]   =   { 1, 1, 7, 5, 29, 29, 87, 197, 123, 323, 773, 157, 2925, 9235, 31625, 58187, 121457, 25561, 0 };
            const std::uint32_t dim19945JoeKuoD6Init[]   =   { 1, 1, 1, 9, 3, 15, 99, 55, 133, 757, 1405, 997, 5201, 8971, 6095, 33309, 35587, 254545, 0 };
            const std::uint32_t dim19946JoeKuoD6Init[]   =   { 1, 3, 5, 9, 19, 57, 85, 45, 429, 823, 1369, 933, 1971, 13753, 11351, 45805, 16527, 129907, 0 };
            const std::uint32_t dim19947JoeKuoD6Init[]   =   { 1, 3, 3, 15, 23, 15, 35, 89, 477, 875, 1087, 2837, 1093, 617, 18687, 53269, 63447, 226393, 0 };
            const std::uint32_t dim19948JoeKuoD6Init[]   =   { 1, 1, 7, 9, 27, 37, 23, 107, 265, 485, 1975, 3159, 4065, 10089, 26975, 45067, 4241, 49051, 0 };
            const std::uint32_t dim19949JoeKuoD6Init[]   =   { 1, 3, 3, 1, 29, 53, 89, 129, 149, 717, 749, 1481, 7829, 15887, 23185, 30667, 11749, 188963, 0 };
            const std::uint32_t dim19950JoeKuoD6Init[]   =   { 1, 3, 5, 9, 13, 47, 119, 135, 407, 99, 1773, 2307, 7885, 4013, 25723, 53519, 37487, 205671, 0 };
            const std::uint32_t dim19951JoeKuoD6Init[]   =   { 1, 1, 5, 1, 11, 27, 121, 213, 147, 669, 799, 485, 4275, 15909, 30583, 45925, 90365, 226901, 0 };
            const std::uint32_t dim19952JoeKuoD6Init[]   =   { 1, 1, 3, 5, 1, 19, 81, 109, 217, 949, 1637, 3413, 5957, 7293, 17337, 63857, 103815, 80805, 0 };
            const std::uint32_t dim19953JoeKuoD6Init[]   =   { 1, 3, 7, 3, 9, 43, 119, 251, 345, 3, 203, 829, 3391, 2575, 6859, 50849, 22221, 227581, 0 };
            const std::uint32_t dim19954JoeKuoD6Init[]   =   { 1, 1, 7, 15, 13, 43, 7, 23, 101, 89, 1747, 1231, 1883, 13363, 10981, 59179, 59555, 242021, 0 };
            const std::uint32_t dim19955JoeKuoD6Init[]   =   { 1, 1, 5, 5, 23, 15, 93, 183, 231, 891, 1745, 2665, 1689, 8515, 11717, 35643, 113067, 233757, 0 };
            const std::uint32_t dim19956JoeKuoD6Init[]   =   { 1, 3, 7, 11, 29, 21, 13, 59, 103, 105, 483, 863, 2711, 7917, 29279, 53931, 7011, 60075, 0 };
            const std::uint32_t dim19957JoeKuoD6Init[]   =   { 1, 1, 3, 15, 5, 37, 101, 163, 31, 575, 2029, 1625, 4545, 12579, 15175, 32667, 59497, 63653, 0 };
            const std::uint32_t dim19958JoeKuoD6Init[]   =   { 1, 3, 5, 7, 23, 37, 61, 101, 273, 49, 1943, 3381, 491, 4079, 20341, 26463, 122261, 77965, 0 };
            const std::uint32_t dim19959JoeKuoD6Init[]   =   { 1, 1, 3, 15, 9, 51, 53, 89, 175, 487, 1583, 1797, 4353, 1339, 19613, 26913, 78955, 166523, 0 };
            const std::uint32_t dim19960JoeKuoD6Init[]   =   { 1, 3, 3, 9, 27, 57, 25, 207, 233, 675, 661, 2629, 6971, 8723, 31199, 47215, 36931, 28347, 0 };
            const std::uint32_t dim19961JoeKuoD6Init[]   =   { 1, 3, 1, 3, 31, 15, 123, 17, 211, 883, 1861, 2747, 8075, 5373, 23521, 46217, 86629, 171777, 0 };
            const std::uint32_t dim19962JoeKuoD6Init[]   =   { 1, 3, 5, 9, 11, 43, 45, 171, 465, 835, 603, 2121, 409, 1643, 20327, 63211, 129479, 223113, 0 };
            const std::uint32_t dim19963JoeKuoD6Init[]   =   { 1, 1, 5, 7, 13, 57, 83, 233, 307, 489, 941, 1723, 6149, 5557, 2053, 17377, 31597, 176051, 0 };
            const std::uint32_t dim19964JoeKuoD6Init[]   =   { 1, 1, 7, 3, 11, 11, 85, 163, 169, 989, 1289, 2749, 7681, 4679, 645, 36589, 85907, 194713, 0 };
            const std::uint32_t dim19965JoeKuoD6Init[]   =   { 1, 1, 1, 7, 3, 57, 39, 149, 463, 947, 481, 1163, 7171, 8539, 28991, 61235, 74487, 107051, 0 };
            const std::uint32_t dim19966JoeKuoD6Init[]   =   { 1, 1, 3, 7, 9, 57, 89, 101, 231, 163, 1355, 1393, 5823, 7565, 26285, 13523, 130329, 26099, 0 };
            const std::uint32_t dim19967JoeKuoD6Init[]   =   { 1, 1, 7, 15, 13, 59, 111, 35, 265, 927, 125, 1881, 5397, 757, 23845, 9677, 76077, 163361, 0 };
            const std::uint32_t dim19968JoeKuoD6Init[]   =   { 1, 1, 7, 9, 1, 63, 61, 157, 389, 143, 1445, 881, 3609, 9955, 11159, 59677, 45831, 138345, 0 };
            const std::uint32_t dim19969JoeKuoD6Init[]   =   { 1, 3, 5, 7, 5, 45, 65, 23, 257, 589, 905, 3651, 743, 117, 30307, 7415, 103331, 252889, 0 };
            const std::uint32_t dim19970JoeKuoD6Init[]   =   { 1, 1, 7, 13, 3, 57, 113, 91, 217, 967, 481, 989, 4795, 3549, 23717, 60793, 80281, 19977, 0 };
            const std::uint32_t dim19971JoeKuoD6Init[]   =   { 1, 3, 3, 1, 15, 37, 113, 245, 239, 575, 197, 2803, 7743, 13447, 3601, 56981, 76381, 13321, 0 };
            const std::uint32_t dim19972JoeKuoD6Init[]   =   { 1, 3, 1, 11, 27, 33, 99, 151, 43, 835, 1951, 1957, 2983, 6781, 9319, 2119, 40533, 118325, 0 };
            const std::uint32_t dim19973JoeKuoD6Init[]   =   { 1, 3, 3, 7, 27, 19, 23, 243, 347, 477, 1661, 1891, 2439, 2485, 31743, 1427, 20317, 90803, 0 };
            const std::uint32_t dim19974JoeKuoD6Init[]   =   { 1, 3, 1, 1, 3, 59, 71, 129, 21, 3, 449, 629, 3657, 4045, 8305, 40461, 60927, 38529, 0 };
            const std::uint32_t dim19975JoeKuoD6Init[]   =   { 1, 3, 3, 7, 9, 11, 85, 185, 369, 451, 887, 3709, 6931, 111, 1379, 8741, 58777, 188045, 0 };
            const std::uint32_t dim19976JoeKuoD6Init[]   =   { 1, 3, 7, 11, 23, 13, 77, 141, 99, 543, 725, 2439, 6825, 1361, 2785, 5345, 5941, 234751, 0 };
            const std::uint32_t dim19977JoeKuoD6Init[]   =   { 1, 1, 5, 5, 17, 55, 69, 9, 431, 585, 1049, 165, 1705, 14907, 8655, 12485, 22783, 91195, 0 };
            const std::uint32_t dim19978JoeKuoD6Init[]   =   { 1, 1, 7, 11, 29, 41, 91, 137, 17, 785, 1151, 2033, 7031, 15077, 2241, 21453, 117947, 128891, 0 };
            const std::uint32_t dim19979JoeKuoD6Init[]   =   { 1, 1, 1, 11, 17, 53, 113, 195, 409, 275, 1757, 245, 6263, 14785, 29159, 43827, 65027, 248403, 0 };
            const std::uint32_t dim19980JoeKuoD6Init[]   =   { 1, 3, 3, 3, 5, 15, 23, 41, 261, 891, 1021, 1999, 4883, 9233, 10385, 21953, 50711, 4247, 0 };
            const std::uint32_t dim19981JoeKuoD6Init[]   =   { 1, 1, 1, 13, 23, 47, 33, 77, 317, 251, 617, 2265, 7549, 327, 2317, 41209, 41063, 120863, 0 };
            const std::uint32_t dim19982JoeKuoD6Init[]   =   { 1, 1, 7, 11, 15, 17, 25, 105, 253, 713, 1147, 415, 5777, 2215, 4207, 33857, 17001, 260533, 0 };
            const std::uint32_t dim19983JoeKuoD6Init[]   =   { 1, 1, 1, 11, 31, 45, 3, 25, 329, 45, 1563, 121, 1413, 16229, 32485, 54477, 101025, 64847, 0 };
            const std::uint32_t dim19984JoeKuoD6Init[]   =   { 1, 3, 5, 1, 15, 59, 113, 203, 481, 545, 371, 1357, 5549, 3043, 397, 61483, 59779, 58159, 0 };
            const std::uint32_t dim19985JoeKuoD6Init[]   =   { 1, 3, 3, 3, 25, 39, 29, 193, 379, 293, 1173, 3389, 4231, 11519, 6681, 28813, 63609, 13029, 0 };
            const std::uint32_t dim19986JoeKuoD6Init[]   =   { 1, 3, 1, 1, 27, 57, 37, 249, 441, 905, 463, 3543, 7203, 10075, 5373, 46103, 6685, 146943, 0 };
            const std::uint32_t dim19987JoeKuoD6Init[]   =   { 1, 3, 5, 7, 31, 51, 21, 139, 209, 219, 1663, 837, 3351, 6291, 735, 8715, 33751, 199485, 0 };
            const std::uint32_t dim19988JoeKuoD6Init[]   =   { 1, 3, 5, 11, 19, 57, 41, 163, 287, 327, 243, 2891, 1095, 3959, 5067, 2867, 16207, 213089, 0 };
            const std::uint32_t dim19989JoeKuoD6Init[]   =   { 1, 1, 5, 11, 21, 59, 97, 239, 309, 371, 797, 453, 2595, 4277, 3771, 5665, 10075, 56101, 0 };
            const std::uint32_t dim19990JoeKuoD6Init[]   =   { 1, 1, 3, 15, 17, 29, 103, 33, 449, 525, 961, 3551, 3611, 14057, 15971, 26981, 35169, 130213, 0 };
            const std::uint32_t dim19991JoeKuoD6Init[]   =   { 1, 1, 3, 1, 5, 13, 39, 211, 387, 797, 1051, 3287, 3737, 12953, 3387, 35107, 78809, 162907, 0 };
            const std::uint32_t dim19992JoeKuoD6Init[]   =   { 1, 1, 7, 9, 7, 63, 127, 115, 173, 981, 623, 737, 7625, 12245, 4195, 61873, 104301, 250333, 0 };
            const std::uint32_t dim19993JoeKuoD6Init[]   =   { 1, 1, 1, 5, 19, 5, 123, 43, 209, 741, 747, 1057, 2683, 15359, 24121, 38413, 5823, 62213, 0 };
            const std::uint32_t dim19994JoeKuoD6Init[]   =   { 1, 1, 7, 1, 23, 13, 63, 165, 309, 323, 247, 3827, 5451, 4823, 23925, 56957, 69765, 259923, 0 };
            const std::uint32_t dim19995JoeKuoD6Init[]   =   { 1, 1, 5, 1, 5, 49, 51, 65, 31, 257, 1363, 3031, 5765, 3645, 16383, 6347, 30429, 130557, 0 };
            const std::uint32_t dim19996JoeKuoD6Init[]   =   { 1, 3, 5, 13, 9, 63, 31, 3, 317, 379, 1345, 2161, 7787, 2055, 21507, 20347, 97021, 183377, 0 };
            const std::uint32_t dim19997JoeKuoD6Init[]   =   { 1, 3, 5, 11, 15, 59, 13, 139, 415, 821, 639, 1249, 6349, 15861, 21377, 22813, 42839, 76595, 0 };
            const std::uint32_t dim19998JoeKuoD6Init[]   =   { 1, 1, 7, 9, 23, 11, 25, 115, 393, 153, 1269, 871, 1323, 1891, 11619, 3103, 79813, 39811, 0 };
            const std::uint32_t dim19999JoeKuoD6Init[]   =   { 1, 3, 1, 15, 27, 37, 63, 253, 1, 855, 1651, 3111, 6693, 1825, 22549, 64189, 18347, 253425, 0 };
            const std::uint32_t dim20000JoeKuoD6Init[]   =   { 1, 3, 1, 11, 23, 27, 119, 59, 421, 343, 831, 2679, 5899, 12087, 15953, 18601, 109551, 33895, 0 };
            const std::uint32_t dim20001JoeKuoD6Init[]   =   { 1, 3, 1, 13, 29, 3, 91, 227, 301, 491, 1045, 2105, 5189, 13717, 1095, 6039, 16229, 215687, 0 };
            const std::uint32_t dim20002JoeKuoD6Init[]   =   { 1, 1, 7, 3, 11, 53, 85, 25, 23, 293, 841, 3569, 5335, 8949, 28665, 15139, 100807, 155587, 0 };
            const std::uint32_t dim20003JoeKuoD6Init[]   =   { 1, 1, 1, 9, 31, 1, 77, 149, 181, 5, 915, 1155, 4717, 2837, 17545, 3235, 26811, 124901, 0 };
            const std::uint32_t dim20004JoeKuoD6Init[]   =   { 1, 1, 3, 5, 25, 27, 47, 215, 425, 195, 1575, 3961, 3521, 4197, 9565, 32523, 125091, 165543, 0 };
            const std::uint32_t dim20005JoeKuoD6Init[]   =   { 1, 3, 7, 3, 17, 57, 7, 137, 507, 303, 1123, 1511, 2465, 4277, 19959, 31951, 83157, 62843, 0 };
            const std::uint32_t dim20006JoeKuoD6Init[]   =   { 1, 3, 3, 1, 27, 43, 79, 191, 265, 167, 665, 4017, 6613, 1175, 5427, 47139, 91517, 32071, 0 };
            const std::uint32_t dim20007JoeKuoD6Init[]   =   { 1, 1, 1, 11, 29, 63, 9, 39, 303, 1021, 415, 2157, 5227, 13557, 4931, 12541, 74101, 13189, 0 };
            const std::uint32_t dim20008JoeKuoD6Init[]   =   { 1, 1, 3, 9, 15, 41, 45, 163, 301, 315, 1433, 1449, 3589, 15783, 16069, 16155, 10527, 69335, 0 };
            const std::uint32_t dim20009JoeKuoD6Init[]   =   { 1, 3, 1, 1, 1, 5, 75, 169, 215, 115, 939, 1285, 43, 1941, 27847, 5245, 51211, 244817, 0 };
            const std::uint32_t dim20010JoeKuoD6Init[]   =   { 1, 1, 1, 15, 7, 33, 31, 23, 397, 537, 1415, 329, 6705, 15015, 18883, 62895, 21435, 233075, 0 };
            const std::uint32_t dim20011JoeKuoD6Init[]   =   { 1, 3, 3, 5, 11, 49, 73, 147, 183, 317, 11, 1997, 1045, 6015, 29159, 55195, 105711, 134727, 0 };
            const std::uint32_t dim20012JoeKuoD6Init[]   =   { 1, 3, 3, 9, 21, 41, 5, 213, 421, 539, 1269, 1929, 3701, 2165, 14997, 21933, 58167, 239719, 0 };
            const std::uint32_t dim20013JoeKuoD6Init[]   =   { 1, 3, 1, 5, 23, 63, 37, 27, 21, 547, 1499, 1621, 141, 5309, 32257, 47241, 123617, 243853, 0 };
            const std::uint32_t dim20014JoeKuoD6Init[]   =   { 1, 1, 1, 13, 31, 45, 47, 91, 165, 1007, 1295, 4035, 1461, 10423, 7747, 7329, 114599, 169375, 0 };
            const std::uint32_t dim20015JoeKuoD6Init[]   =   { 1, 1, 5, 3, 21, 9, 75, 61, 35, 745, 31, 4085, 3645, 16239, 14979, 15725, 108859, 56745, 0 };
            const std::uint32_t dim20016JoeKuoD6Init[]   =   { 1, 1, 5, 15, 11, 31, 13, 229, 417, 147, 1993, 4043, 7757, 13507, 15297, 56119, 2223, 142275, 0 };
            const std::uint32_t dim20017JoeKuoD6Init[]   =   { 1, 3, 5, 13, 3, 57, 45, 109, 135, 829, 159, 769, 865, 2583, 15755, 44343, 84561, 98621, 0 };
            const std::uint32_t dim20018JoeKuoD6Init[]   =   { 1, 1, 7, 11, 17, 11, 115, 45, 371, 411, 863, 2139, 3897, 13981, 16771, 4587, 25195, 66077, 0 };
            const std::uint32_t dim20019JoeKuoD6Init[]   =   { 1, 3, 7, 15, 17, 47, 51, 133, 133, 475, 1363, 3325, 4287, 4837, 22077, 60225, 3097, 246805, 0 };
            const std::uint32_t dim20020JoeKuoD6Init[]   =   { 1, 3, 5, 9, 29, 51, 127, 125, 353, 519, 129, 1409, 1497, 3167, 14163, 24921, 81343, 129835, 0 };
            const std::uint32_t dim20021JoeKuoD6Init[]   =   { 1, 3, 5, 5, 19, 39, 95, 109, 229, 1015, 367, 2373, 709, 6169, 4089, 13533, 22399, 118977, 0 };
            const std::uint32_t dim20022JoeKuoD6Init[]   =   { 1, 1, 5, 5, 17, 21, 91, 131, 309, 739, 1373, 3723, 6659, 1119, 27521, 55589, 34967, 70831, 0 };
            const std::uint32_t dim20023JoeKuoD6Init[]   =   { 1, 3, 1, 11, 5, 7, 85, 215, 425, 947, 589, 375, 5943, 13399, 18307, 27007, 18919, 200617, 0 };
            const std::uint32_t dim20024JoeKuoD6Init[]   =   { 1, 1, 3, 15, 11, 37, 111, 179, 259, 517, 1679, 225, 3493, 15025, 21751, 40687, 73001, 214477, 0 };
            const std::uint32_t dim20025JoeKuoD6Init[]   =   { 1, 1, 7, 15, 17, 41, 109, 129, 427, 847, 1965, 3269, 5871, 12331, 26899, 49791, 103471, 213789, 0 };
            const std::uint32_t dim20026JoeKuoD6Init[]   =   { 1, 3, 3, 3, 9, 41, 25, 115, 95, 737, 717, 1545, 841, 14923, 7409, 45365, 100139, 77787, 0 };
            const std::uint32_t dim20027JoeKuoD6Init[]   =   { 1, 1, 3, 15, 11, 3, 63, 23, 425, 433, 537, 1599, 2691, 11271, 1695, 40579, 53507, 73033, 0 };
            const std::uint32_t dim20028JoeKuoD6Init[]   =   { 1, 3, 7, 13, 9, 21, 85, 31, 337, 583, 1883, 3877, 7197, 7715, 21525, 53273, 11263, 41907, 0 };
            const std::uint32_t dim20029JoeKuoD6Init[]   =   { 1, 3, 7, 1, 7, 53, 61, 45, 299, 885, 1391, 3109, 6851, 6079, 18857, 44537, 95713, 146125, 0 };
            const std::uint32_t dim20030JoeKuoD6Init[]   =   { 1, 1, 1, 3, 21, 49, 95, 105, 419, 315, 365, 3035, 4169, 5723, 26921, 62809, 27019, 243965, 0 };
            const std::uint32_t dim20031JoeKuoD6Init[]   =   { 1, 1, 3, 5, 11, 39, 71, 89, 249, 11, 1395, 105, 6637, 4577, 22979, 32405, 93163, 58785, 0 };
            const std::uint32_t dim20032JoeKuoD6Init[]   =   { 1, 1, 1, 1, 27, 25, 125, 85, 495, 697, 1793, 301, 7665, 12671, 25359, 38803, 58723, 189837, 0 };
            const std::uint32_t dim20033JoeKuoD6Init[]   =   { 1, 3, 5, 11, 17, 11, 61, 211, 19, 901, 1701, 223, 2195, 15571, 3529, 34699, 94607, 196519, 0 };
            const std::uint32_t dim20034JoeKuoD6Init[]   =   { 1, 3, 7, 11, 15, 1, 111, 1, 381, 145, 293, 3639, 6931, 13195, 19985, 58491, 53067, 184411, 0 };
            const std::uint32_t dim20035JoeKuoD6Init[]   =   { 1, 3, 1, 15, 31, 39, 39, 101, 17, 431, 1151, 2465, 727, 12709, 5377, 5857, 49707, 76439, 0 };
            const std::uint32_t dim20036JoeKuoD6Init[]   =   { 1, 3, 3, 5, 7, 1, 3, 39, 357, 339, 415, 567, 7245, 13943, 7495, 54133, 119705, 160615, 0 };
            const std::uint32_t dim20037JoeKuoD6Init[]   =   { 1, 3, 5, 15, 9, 17, 13, 253, 337, 673, 1745, 2613, 4635, 14025, 11159, 50001, 40753, 172983, 0 };
            const std::uint32_t dim20038JoeKuoD6Init[]   =   { 1, 3, 7, 11, 3, 15, 19, 107, 393, 1015, 1441, 181, 5721, 9987, 15557, 37263, 90053, 205685, 0 };
            const std::uint32_t dim20039JoeKuoD6Init[]   =   { 1, 1, 5, 1, 9, 3, 69, 123, 245, 111, 283, 1581, 259, 275, 813, 12213, 19639, 7335, 0 };
            const std::uint32_t dim20040JoeKuoD6Init[]   =   { 1, 3, 7, 7, 1, 55, 101, 63, 259, 705, 653, 3821, 2081, 6447, 25471, 15523, 38827, 68055, 0 };
            const std::uint32_t dim20041JoeKuoD6Init[]   =   { 1, 1, 5, 7, 27, 9, 97, 149, 445, 341, 167, 3695, 375, 853, 8143, 36027, 62729, 197357, 0 };
            const std::uint32_t dim20042JoeKuoD6Init[]   =   { 1, 3, 7, 1, 1, 37, 97, 103, 493, 319, 1287, 3787, 4079, 13049, 14305, 6665, 4631, 96225, 0 };
            const std::uint32_t dim20043JoeKuoD6Init[]   =   { 1, 1, 5, 7, 1, 5, 127, 143, 251, 725, 1759, 2381, 181, 15741, 9395, 64441, 44347, 221697, 0 };
            const std::uint32_t dim20044JoeKuoD6Init[]   =   { 1, 3, 1, 3, 25, 47, 29, 167, 397, 827, 1255, 3271, 6307, 13915, 3131, 19123, 88619, 62847, 0 };
            const std::uint32_t dim20045JoeKuoD6Init[]   =   { 1, 3, 5, 1, 29, 11, 59, 203, 245, 553, 617, 1287, 205, 2291, 3613, 39933, 116981, 43595, 0 };
            const std::uint32_t dim20046JoeKuoD6Init[]   =   { 1, 1, 3, 9, 27, 33, 35, 77, 437, 1003, 119, 253, 6643, 113, 10587, 41073, 55371, 233307, 0 };
            const std::uint32_t dim20047JoeKuoD6Init[]   =   { 1, 3, 7, 1, 29, 63, 1, 231, 373, 995, 1063, 1385, 273, 14115, 6899, 62991, 112003, 80527, 0 };
            const std::uint32_t dim20048JoeKuoD6Init[]   =   { 1, 3, 3, 1, 31, 21, 55, 115, 393, 685, 245, 1587, 5617, 267, 19639, 15169, 14073, 173091, 0 };
            const std::uint32_t dim20049JoeKuoD6Init[]   =   { 1, 3, 1, 11, 29, 45, 53, 21, 433, 979, 1067, 2999, 6279, 4739, 30835, 61653, 112893, 75839, 0 };
            const std::uint32_t dim20050JoeKuoD6Init[]   =   { 1, 1, 5, 11, 23, 25, 15, 107, 325, 981, 1057, 1181, 4465, 16291, 1523, 64497, 129437, 45067, 0 };
            const std::uint32_t dim20051JoeKuoD6Init[]   =   { 1, 1, 1, 5, 1, 21, 79, 135, 419, 997, 1967, 747, 2097, 15397, 4415, 15807, 79583, 259561, 0 };
            const std::uint32_t dim20052JoeKuoD6Init[]   =   { 1, 3, 1, 7, 5, 49, 105, 109, 243, 371, 13, 2297, 2845, 12569, 13165, 13551, 75471, 168579, 0 };
            const std::uint32_t dim20053JoeKuoD6Init[]   =   { 1, 1, 1, 1, 9, 33, 7, 233, 43, 773, 1121, 3763, 4047, 15039, 8165, 25407, 82561, 215045, 0 };
            const std::uint32_t dim20054JoeKuoD6Init[]   =   { 1, 3, 7, 1, 17, 41, 105, 129, 333, 687, 1357, 1197, 1271, 3835, 15823, 36777, 94311, 192321, 0 };
            const std::uint32_t dim20055JoeKuoD6Init[]   =   { 1, 1, 5, 15, 13, 31, 93, 249, 81, 167, 1681, 1587, 179, 5755, 27741, 29437, 100407, 63287, 0 };
            const std::uint32_t dim20056JoeKuoD6Init[]   =   { 1, 3, 3, 13, 11, 39, 85, 23, 37, 183, 547, 1255, 1167, 15961, 23281, 59989, 99393, 34983, 0 };
            const std::uint32_t dim20057JoeKuoD6Init[]   =   { 1, 3, 7, 5, 13, 33, 17, 243, 321, 845, 447, 1997, 4639, 11175, 24651, 18281, 82677, 244543, 0 };
            const std::uint32_t dim20058JoeKuoD6Init[]   =   { 1, 3, 5, 13, 3, 63, 75, 35, 493, 207, 1707, 1401, 3687, 11353, 5461, 23433, 71259, 93483, 0 };
            const std::uint32_t dim20059JoeKuoD6Init[]   =   { 1, 1, 3, 1, 19, 61, 81, 133, 115, 957, 669, 647, 347, 8739, 18451, 39641, 118677, 136601, 0 };
            const std::uint32_t dim20060JoeKuoD6Init[]   =   { 1, 1, 7, 13, 3, 13, 119, 187, 111, 181, 1865, 1613, 201, 3633, 17805, 46553, 8899, 100407, 0 };
            const std::uint32_t dim20061JoeKuoD6Init[]   =   { 1, 3, 3, 9, 19, 33, 35, 215, 235, 893, 877, 3099, 7597, 13521, 22473, 65435, 3205, 44897, 0 };
            const std::uint32_t dim20062JoeKuoD6Init[]   =   { 1, 3, 3, 11, 27, 3, 101, 201, 215, 373, 859, 1435, 2637, 6795, 21157, 3333, 27797, 199427, 0 };
            const std::uint32_t dim20063JoeKuoD6Init[]   =   { 1, 1, 7, 13, 31, 33, 85, 205, 273, 565, 2033, 3451, 7581, 16223, 1383, 16297, 1263, 49065, 0 };
            const std::uint32_t dim20064JoeKuoD6Init[]   =   { 1, 1, 1, 13, 11, 29, 65, 71, 395, 179, 1193, 3859, 3075, 10133, 6463, 34617, 20173, 203471, 0 };
            const std::uint32_t dim20065JoeKuoD6Init[]   =   { 1, 1, 7, 3, 7, 29, 11, 115, 465, 695, 1759, 3137, 6337, 977, 43, 62501, 13297, 59319, 0 };
            const std::uint32_t dim20066JoeKuoD6Init[]   =   { 1, 3, 5, 9, 31, 59, 11, 107, 109, 797, 177, 2891, 2535, 4305, 19255, 9591, 84417, 87381, 0 };
            const std::uint32_t dim20067JoeKuoD6Init[]   =   { 1, 3, 3, 3, 1, 9, 45, 219, 73, 573, 1477, 3699, 8145, 835, 7123, 37167, 53411, 45397, 0 };
            const std::uint32_t dim20068JoeKuoD6Init[]   =   { 1, 3, 5, 15, 15, 41, 37, 63, 233, 971, 1497, 1223, 3909, 11721, 9217, 41055, 9779, 199339, 0 };
            const std::uint32_t dim20069JoeKuoD6Init[]   =   { 1, 3, 3, 7, 17, 61, 91, 237, 313, 841, 7, 3283, 4049, 10403, 22157, 4889, 31903, 188043, 0 };
            const std::uint32_t dim20070JoeKuoD6Init[]   =   { 1, 3, 7, 1, 25, 3, 59, 87, 191, 725, 1615, 4057, 3037, 14597, 17371, 42221, 73919, 58009, 0 };
            const std::uint32_t dim20071JoeKuoD6Init[]   =   { 1, 3, 5, 11, 27, 7, 45, 231, 315, 727, 843, 2191, 7909, 53, 23309, 55189, 96193, 174017, 0 };
            const std::uint32_t dim20072JoeKuoD6Init[]   =   { 1, 3, 5, 11, 27, 51, 127, 187, 209, 883, 429, 137, 4585, 15195, 16527, 32571, 30905, 8137, 0 };
            const std::uint32_t dim20073JoeKuoD6Init[]   =   { 1, 1, 1, 11, 15, 55, 13, 161, 183, 671, 659, 3669, 4461, 13691, 17119, 26877, 52041, 110103, 0 };
            const std::uint32_t dim20074JoeKuoD6Init[]   =   { 1, 3, 5, 9, 5, 45, 29, 19, 415, 931, 683, 2987, 3839, 4529, 3091, 54457, 115537, 102671, 0 };
            const std::uint32_t dim20075JoeKuoD6Init[]   =   { 1, 1, 7, 13, 23, 31, 61, 17, 327, 951, 1333, 713, 4309, 1955, 22797, 27007, 106673, 47177, 0 };
            const std::uint32_t dim20076JoeKuoD6Init[]   =   { 1, 3, 3, 9, 31, 49, 19, 115, 413, 257, 1799, 3641, 2075, 15613, 14293, 16123, 45131, 209389, 0 };
            const std::uint32_t dim20077JoeKuoD6Init[]   =   { 1, 1, 7, 15, 1, 15, 27, 63, 463, 825, 1081, 991, 2641, 5999, 8551, 41119, 80251, 189263, 0 };
            const std::uint32_t dim20078JoeKuoD6Init[]   =   { 1, 1, 5, 9, 7, 55, 125, 97, 245, 997, 457, 1087, 1297, 3433, 14887, 24117, 30689, 184809, 0 };
            const std::uint32_t dim20079JoeKuoD6Init[]   =   { 1, 3, 1, 9, 23, 59, 81, 233, 341, 943, 1335, 2819, 2625, 4957, 14925, 7917, 107383, 204493, 0 };
            const std::uint32_t dim20080JoeKuoD6Init[]   =   { 1, 3, 5, 5, 5, 25, 79, 29, 191, 541, 1295, 269, 613, 5201, 28639, 52839, 52865, 75181, 0 };
            const std::uint32_t dim20081JoeKuoD6Init[]   =   { 1, 3, 3, 7, 19, 45, 35, 201, 391, 317, 1323, 2733, 3407, 10273, 32689, 52153, 108751, 242493, 0 };
            const std::uint32_t dim20082JoeKuoD6Init[]   =   { 1, 3, 1, 7, 15, 27, 45, 21, 383, 483, 1857, 3443, 2263, 11471, 3697, 63929, 116399, 229733, 0 };
            const std::uint32_t dim20083JoeKuoD6Init[]   =   { 1, 1, 3, 9, 13, 27, 19, 37, 181, 811, 1833, 177, 7689, 10073, 20229, 31397, 65415, 68461, 0 };
            const std::uint32_t dim20084JoeKuoD6Init[]   =   { 1, 1, 1, 15, 19, 53, 65, 209, 433, 783, 1647, 4075, 3155, 733, 25603, 39033, 43109, 151257, 0 };
            const std::uint32_t dim20085JoeKuoD6Init[]   =   { 1, 3, 3, 5, 9, 37, 61, 75, 497, 825, 1785, 3709, 1731, 889, 19325, 57453, 39095, 190855, 0 };
            const std::uint32_t dim20086JoeKuoD6Init[]   =   { 1, 3, 3, 13, 3, 53, 21, 39, 483, 833, 1191, 2829, 1323, 1877, 17257, 36077, 47997, 25349, 0 };
            const std::uint32_t dim20087JoeKuoD6Init[]   =   { 1, 1, 7, 9, 29, 25, 7, 91, 87, 723, 777, 1865, 7763, 10995, 15953, 36111, 21313, 214417, 0 };
            const std::uint32_t dim20088JoeKuoD6Init[]   =   { 1, 3, 5, 3, 17, 15, 85, 133, 245, 317, 879, 3237, 7049, 6501, 13359, 34063, 124703, 118289, 0 };
            const std::uint32_t dim20089JoeKuoD6Init[]   =   { 1, 1, 1, 7, 11, 25, 111, 143, 369, 593, 237, 2787, 1015, 13059, 23275, 38453, 90809, 25803, 0 };
            const std::uint32_t dim20090JoeKuoD6Init[]   =   { 1, 1, 7, 5, 13, 21, 39, 235, 381, 381, 949, 773, 1123, 9911, 18115, 47657, 47849, 197633, 0 };
            const std::uint32_t dim20091JoeKuoD6Init[]   =   { 1, 1, 3, 13, 15, 57, 47, 203, 483, 341, 137, 1283, 2847, 5051, 22593, 60915, 45123, 258733, 0 };
            const std::uint32_t dim20092JoeKuoD6Init[]   =   { 1, 1, 3, 5, 29, 7, 23, 127, 493, 543, 747, 3547, 4433, 5847, 28999, 18079, 81205, 231557, 0 };
            const std::uint32_t dim20093JoeKuoD6Init[]   =   { 1, 1, 3, 15, 9, 63, 17, 197, 75, 387, 1679, 2631, 1033, 2757, 18365, 11957, 98915, 24223, 0 };
            const std::uint32_t dim20094JoeKuoD6Init[]   =   { 1, 1, 3, 9, 27, 55, 67, 97, 345, 995, 1151, 1747, 4889, 13847, 13237, 9035, 13461, 10377, 0 };
            const std::uint32_t dim20095JoeKuoD6Init[]   =   { 1, 1, 5, 9, 27, 13, 7, 77, 399, 191, 137, 2801, 6379, 15969, 1727, 27503, 97385, 147625, 0 };
            const std::uint32_t dim20096JoeKuoD6Init[]   =   { 1, 3, 1, 7, 5, 9, 103, 163, 489, 615, 1359, 2635, 3115, 13795, 18853, 65225, 26545, 212065, 0 };
            const std::uint32_t dim20097JoeKuoD6Init[]   =   { 1, 3, 7, 3, 13, 25, 125, 133, 359, 423, 751, 4045, 1209, 7521, 6653, 39171, 125083, 229399, 0 };
            const std::uint32_t dim20098JoeKuoD6Init[]   =   { 1, 3, 1, 9, 15, 21, 121, 223, 283, 313, 1807, 3829, 5279, 10609, 20113, 7851, 23731, 245327, 0 };
            const std::uint32_t dim20099JoeKuoD6Init[]   =   { 1, 1, 1, 11, 15, 13, 63, 253, 311, 369, 1549, 2803, 2029, 14967, 14217, 1387, 104669, 63375, 0 };
            const std::uint32_t dim20100JoeKuoD6Init[]   =   { 1, 1, 3, 3, 31, 49, 59, 189, 249, 779, 275, 3761, 3465, 2205, 11543, 16973, 126249, 104769, 0 };
            const std::uint32_t dim20101JoeKuoD6Init[]   =   { 1, 3, 1, 5, 11, 39, 59, 33, 121, 151, 467, 1011, 1379, 13955, 20117, 52537, 51049, 50663, 0 };
            const std::uint32_t dim20102JoeKuoD6Init[]   =   { 1, 1, 1, 7, 5, 41, 121, 29, 357, 33, 849, 2441, 2127, 1337, 21147, 63869, 80215, 31211, 0 };
            const std::uint32_t dim20103JoeKuoD6Init[]   =   { 1, 3, 3, 3, 25, 41, 17, 101, 173, 915, 463, 2391, 1671, 8789, 13357, 42127, 17599, 61087, 0 };
            const std::uint32_t dim20104JoeKuoD6Init[]   =   { 1, 1, 3, 9, 29, 23, 47, 211, 435, 223, 1421, 2463, 4543, 8569, 30209, 46621, 14367, 13263, 0 };
            const std::uint32_t dim20105JoeKuoD6Init[]   =   { 1, 3, 7, 7, 5, 9, 75, 209, 299, 81, 1705, 2335, 6703, 6309, 5859, 57889, 43219, 7667, 0 };
            const std::uint32_t dim20106JoeKuoD6Init[]   =   { 1, 3, 3, 3, 19, 31, 107, 87, 413, 111, 215, 2711, 7053, 5223, 25241, 26675, 16067, 122719, 0 };
            const std::uint32_t dim20107JoeKuoD6Init[]   =   { 1, 1, 1, 15, 21, 3, 15, 13, 281, 63, 725, 2025, 4813, 14177, 18577, 875, 118623, 192005, 0 };
            const std::uint32_t dim20108JoeKuoD6Init[]   =   { 1, 3, 5, 9, 17, 21, 85, 173, 59, 153, 763, 3899, 1985, 2071, 10439, 44911, 60915, 122419, 0 };
            const std::uint32_t dim20109JoeKuoD6Init[]   =   { 1, 3, 7, 13, 11, 63, 59, 95, 53, 927, 555, 1897, 5195, 13469, 16973, 3463, 125173, 256021, 0 };
            const std::uint32_t dim20110JoeKuoD6Init[]   =   { 1, 1, 3, 7, 9, 63, 33, 193, 61, 445, 1247, 1379, 4701, 5311, 30709, 16795, 69871, 161113, 0 };
            const std::uint32_t dim20111JoeKuoD6Init[]   =   { 1, 3, 1, 3, 21, 25, 125, 111, 109, 75, 455, 861, 6483, 4501, 19095, 45601, 78415, 30995, 0 };
            const std::uint32_t dim20112JoeKuoD6Init[]   =   { 1, 1, 3, 5, 1, 25, 15, 25, 223, 961, 537, 1453, 4951, 5085, 19801, 9863, 108819, 7319, 0 };
            const std::uint32_t dim20113JoeKuoD6Init[]   =   { 1, 3, 1, 5, 29, 21, 79, 113, 177, 691, 219, 3159, 3493, 25, 30655, 46257, 23707, 243377, 0 };
            const std::uint32_t dim20114JoeKuoD6Init[]   =   { 1, 1, 3, 3, 27, 21, 11, 95, 43, 161, 2029, 4091, 6695, 7179, 9955, 45195, 32017, 128605, 0 };
            const std::uint32_t dim20115JoeKuoD6Init[]   =   { 1, 1, 7, 5, 19, 37, 47, 83, 169, 143, 773, 2127, 347, 1887, 2861, 8155, 21437, 175641, 0 };
            const std::uint32_t dim20116JoeKuoD6Init[]   =   { 1, 3, 1, 1, 27, 63, 119, 57, 77, 931, 629, 1807, 4469, 2315, 3767, 19207, 114581, 125135, 0 };
            const std::uint32_t dim20117JoeKuoD6Init[]   =   { 1, 1, 5, 11, 13, 51, 51, 239, 333, 369, 1035, 3017, 103, 1809, 14579, 34425, 123915, 258397, 0 };
            const std::uint32_t dim20118JoeKuoD6Init[]   =   { 1, 1, 1, 3, 3, 19, 63, 237, 141, 929, 943, 2597, 3983, 1043, 24269, 12325, 39013, 216689, 0 };
            const std::uint32_t dim20119JoeKuoD6Init[]   =   { 1, 1, 3, 7, 9, 61, 73, 31, 287, 303, 1415, 3453, 2667, 8625, 14347, 51953, 9181, 251937, 0 };
            const std::uint32_t dim20120JoeKuoD6Init[]   =   { 1, 1, 7, 1, 15, 41, 1, 197, 87, 311, 1147, 3799, 2585, 14027, 491, 54203, 124861, 227637, 0 };
            const std::uint32_t dim20121JoeKuoD6Init[]   =   { 1, 3, 7, 3, 15, 35, 97, 89, 65, 493, 1897, 3345, 3807, 5911, 12461, 21393, 116975, 212801, 0 };
            const std::uint32_t dim20122JoeKuoD6Init[]   =   { 1, 1, 7, 11, 29, 47, 61, 171, 399, 929, 93, 2815, 4933, 9209, 15053, 21911, 117217, 52539, 0 };
            const std::uint32_t dim20123JoeKuoD6Init[]   =   { 1, 3, 1, 1, 19, 25, 11, 41, 73, 317, 215, 923, 5153, 8025, 18703, 11513, 107981, 2027, 0 };
            const std::uint32_t dim20124JoeKuoD6Init[]   =   { 1, 1, 5, 7, 27, 33, 47, 99, 171, 259, 2017, 2055, 909, 4185, 26689, 23155, 109857, 213957, 0 };
            const std::uint32_t dim20125JoeKuoD6Init[]   =   { 1, 3, 7, 3, 31, 17, 39, 203, 255, 345, 1461, 1561, 4349, 6451, 14763, 32993, 74475, 140557, 0 };
            const std::uint32_t dim20126JoeKuoD6Init[]   =   { 1, 1, 5, 3, 21, 57, 75, 201, 371, 529, 1471, 243, 3751, 581, 18405, 40933, 106311, 745, 0 };
            const std::uint32_t dim20127JoeKuoD6Init[]   =   { 1, 1, 3, 13, 7, 53, 125, 15, 55, 267, 1865, 3297, 4331, 2913, 21675, 58911, 28419, 105585, 0 };
            const std::uint32_t dim20128JoeKuoD6Init[]   =   { 1, 3, 5, 13, 7, 13, 37, 37, 207, 127, 785, 1129, 8123, 7655, 16003, 18907, 48883, 2001, 0 };
            const std::uint32_t dim20129JoeKuoD6Init[]   =   { 1, 1, 5, 3, 11, 3, 127, 149, 503, 1019, 887, 3429, 7775, 7113, 19571, 34461, 38889, 66981, 0 };
            const std::uint32_t dim20130JoeKuoD6Init[]   =   { 1, 3, 7, 7, 1, 55, 87, 217, 465, 485, 411, 2955, 4899, 1741, 7051, 42885, 1837, 68175, 0 };
            const std::uint32_t dim20131JoeKuoD6Init[]   =   { 1, 1, 7, 1, 7, 39, 25, 1, 185, 523, 273, 2409, 1867, 3101, 29823, 4509, 81621, 11815, 0 };
            const std::uint32_t dim20132JoeKuoD6Init[]   =   { 1, 1, 1, 11, 13, 11, 89, 237, 355, 347, 91, 1791, 5745, 4181, 29207, 39495, 5275, 199395, 0 };
            const std::uint32_t dim20133JoeKuoD6Init[]   =   { 1, 1, 7, 3, 17, 37, 109, 169, 191, 295, 1001, 2631, 1981, 11821, 8315, 40675, 1293, 220247, 0 };
            const std::uint32_t dim20134JoeKuoD6Init[]   =   { 1, 3, 1, 7, 31, 25, 5, 55, 1, 795, 1663, 3177, 6821, 2073, 25789, 23691, 25015, 75203, 0 };
            const std::uint32_t dim20135JoeKuoD6Init[]   =   { 1, 3, 5, 9, 19, 9, 97, 129, 351, 735, 1897, 3555, 1731, 5413, 32051, 12869, 111973, 100157, 0 };
            const std::uint32_t dim20136JoeKuoD6Init[]   =   { 1, 3, 3, 15, 27, 1, 3, 167, 7, 851, 805, 713, 6389, 1455, 32371, 7617, 107157, 131299, 0 };
            const std::uint32_t dim20137JoeKuoD6Init[]   =   { 1, 3, 1, 13, 31, 29, 91, 123, 387, 939, 223, 3583, 2889, 5307, 16561, 6055, 4437, 123229, 0 };
            const std::uint32_t dim20138JoeKuoD6Init[]   =   { 1, 3, 5, 11, 27, 17, 5, 145, 369, 449, 1677, 1039, 3553, 3057, 11667, 51879, 20519, 41573, 0 };
            const std::uint32_t dim20139JoeKuoD6Init[]   =   { 1, 3, 1, 9, 9, 1, 91, 33, 379, 35, 691, 375, 5937, 15019, 16177, 53457, 52015, 232257, 0 };
            const std::uint32_t dim20140JoeKuoD6Init[]   =   { 1, 1, 3, 11, 23, 17, 75, 217, 377, 571, 1725, 2719, 3911, 12277, 27799, 55573, 21981, 112529, 0 };
            const std::uint32_t dim20141JoeKuoD6Init[]   =   { 1, 3, 1, 11, 9, 37, 81, 95, 501, 615, 327, 3751, 7333, 15407, 7785, 29113, 116335, 221853, 0 };
            const std::uint32_t dim20142JoeKuoD6Init[]   =   { 1, 1, 1, 3, 17, 1, 125, 157, 461, 845, 93, 107, 4429, 2271, 14445, 32919, 81175, 244557, 0 };
            const std::uint32_t dim20143JoeKuoD6Init[]   =   { 1, 3, 3, 1, 27, 23, 33, 15, 29, 361, 409, 981, 7819, 10259, 21971, 23317, 66641, 54591, 0 };
            const std::uint32_t dim20144JoeKuoD6Init[]   =   { 1, 3, 7, 13, 31, 63, 11, 167, 511, 81, 1165, 3973, 4275, 3315, 10227, 34973, 58505, 2333, 0 };
            const std::uint32_t dim20145JoeKuoD6Init[]   =   { 1, 3, 1, 9, 3, 49, 111, 101, 41, 775, 449, 1349, 4411, 8691, 535, 60137, 3269, 204895, 0 };
            const std::uint32_t dim20146JoeKuoD6Init[]   =   { 1, 3, 7, 15, 7, 43, 39, 147, 309, 185, 733, 1473, 5467, 6183, 17971, 56805, 111931, 163515, 0 };
            const std::uint32_t dim20147JoeKuoD6Init[]   =   { 1, 3, 1, 3, 21, 31, 17, 129, 317, 587, 801, 2517, 2569, 765, 20869, 16461, 34425, 101123, 0 };
            const std::uint32_t dim20148JoeKuoD6Init[]   =   { 1, 3, 1, 7, 13, 63, 117, 31, 25, 741, 365, 687, 6195, 2093, 14679, 16861, 123381, 25263, 0 };
            const std::uint32_t dim20149JoeKuoD6Init[]   =   { 1, 1, 1, 3, 13, 59, 65, 131, 41, 39, 1659, 1491, 225, 10277, 12445, 4161, 92119, 146705, 0 };
            const std::uint32_t dim20150JoeKuoD6Init[]   =   { 1, 3, 5, 1, 31, 11, 21, 203, 345, 473, 1643, 1377, 555, 11675, 15383, 30855, 41249, 231059, 0 };
            const std::uint32_t dim20151JoeKuoD6Init[]   =   { 1, 1, 7, 15, 3, 23, 33, 133, 433, 407, 1217, 3345, 7455, 11489, 21463, 41621, 95755, 86971, 0 };
            const std::uint32_t dim20152JoeKuoD6Init[]   =   { 1, 1, 1, 3, 13, 47, 45, 181, 489, 89, 427, 1915, 3993, 10133, 20437, 31811, 48421, 150009, 0 };
            const std::uint32_t dim20153JoeKuoD6Init[]   =   { 1, 3, 1, 9, 9, 25, 89, 195, 503, 755, 59, 1869, 6645, 13841, 22973, 17761, 46759, 68717, 0 };
            const std::uint32_t dim20154JoeKuoD6Init[]   =   { 1, 3, 1, 1, 19, 21, 119, 123, 481, 289, 1009, 3769, 3909, 1123, 17875, 17383, 71533, 45455, 0 };
            const std::uint32_t dim20155JoeKuoD6Init[]   =   { 1, 1, 1, 3, 31, 33, 127, 43, 467, 749, 377, 3025, 511, 13335, 23987, 63627, 50211, 197253, 0 };
            const std::uint32_t dim20156JoeKuoD6Init[]   =   { 1, 1, 5, 13, 29, 7, 101, 43, 299, 769, 1637, 3731, 1945, 9933, 22263, 1523, 127557, 116867, 0 };
            const std::uint32_t dim20157JoeKuoD6Init[]   =   { 1, 1, 3, 11, 1, 59, 25, 45, 275, 535, 1349, 3625, 8125, 727, 1215, 15487, 86229, 124817, 0 };
            const std::uint32_t dim20158JoeKuoD6Init[]   =   { 1, 3, 3, 13, 3, 11, 25, 237, 213, 331, 395, 1775, 1225, 6859, 16577, 39105, 118081, 74727, 0 };
            const std::uint32_t dim20159JoeKuoD6Init[]   =   { 1, 1, 1, 9, 5, 27, 117, 75, 479, 757, 1299, 2273, 3221, 5297, 249, 60327, 48739, 107023, 0 };
            const std::uint32_t dim20160JoeKuoD6Init[]   =   { 1, 1, 5, 9, 27, 9, 123, 49, 63, 763, 121, 3955, 2069, 5999, 25973, 64661, 6321, 1179, 0 };
            const std::uint32_t dim20161JoeKuoD6Init[]   =   { 1, 3, 7, 11, 9, 51, 65, 93, 51, 51, 829, 3239, 7431, 3489, 7691, 38777, 28151, 96635, 0 };
            const std::uint32_t dim20162JoeKuoD6Init[]   =   { 1, 3, 3, 13, 15, 51, 13, 203, 49, 73, 363, 2173, 7771, 11527, 27683, 39333, 2083, 178623, 0 };
            const std::uint32_t dim20163JoeKuoD6Init[]   =   { 1, 1, 5, 5, 15, 27, 27, 127, 503, 955, 427, 3061, 6213, 917, 889, 12601, 72445, 105383, 0 };
            const std::uint32_t dim20164JoeKuoD6Init[]   =   { 1, 3, 5, 3, 27, 43, 105, 187, 309, 747, 1843, 723, 539, 8829, 19171, 46009, 26129, 173145, 0 };
            const std::uint32_t dim20165JoeKuoD6Init[]   =   { 1, 3, 7, 7, 9, 51, 121, 139, 107, 453, 1103, 2957, 633, 1435, 27275, 53231, 51393, 16847, 0 };
            const std::uint32_t dim20166JoeKuoD6Init[]   =   { 1, 3, 7, 5, 25, 31, 71, 191, 169, 69, 1477, 1413, 7659, 11737, 12365, 25067, 21787, 16225, 0 };
            const std::uint32_t dim20167JoeKuoD6Init[]   =   { 1, 1, 7, 1, 9, 33, 37, 123, 391, 341, 829, 1543, 7323, 14695, 16431, 20009, 95821, 182791, 0 };
            const std::uint32_t dim20168JoeKuoD6Init[]   =   { 1, 3, 1, 5, 9, 59, 109, 39, 301, 977, 1963, 177, 8107, 16193, 5691, 14157, 71605, 250839, 0 };
            const std::uint32_t dim20169JoeKuoD6Init[]   =   { 1, 3, 5, 9, 29, 33, 33, 153, 7, 217, 201, 563, 6577, 9605, 16671, 63949, 97937, 234309, 0 };
            const std::uint32_t dim20170JoeKuoD6Init[]   =   { 1, 3, 7, 3, 25, 11, 81, 89, 275, 801, 477, 1921, 2279, 1651, 13333, 9127, 99693, 83141, 0 };
            const std::uint32_t dim20171JoeKuoD6Init[]   =   { 1, 3, 7, 5, 23, 51, 23, 51, 447, 689, 387, 1845, 6033, 2037, 20139, 33165, 56111, 243353, 0 };
            const std::uint32_t dim20172JoeKuoD6Init[]   =   { 1, 3, 5, 7, 5, 7, 105, 121, 439, 471, 721, 85, 1627, 3735, 29611, 15537, 36131, 30225, 0 };
            const std::uint32_t dim20173JoeKuoD6Init[]   =   { 1, 1, 5, 5, 7, 29, 31, 209, 183, 217, 467, 1287, 6145, 14737, 16249, 8857, 101405, 103355, 0 };
            const std::uint32_t dim20174JoeKuoD6Init[]   =   { 1, 3, 3, 5, 19, 1, 43, 15, 239, 63, 617, 2189, 3841, 1223, 12217, 4121, 88047, 14069, 0 };
            const std::uint32_t dim20175JoeKuoD6Init[]   =   { 1, 3, 7, 1, 9, 49, 11, 65, 297, 943, 1739, 3797, 6169, 2057, 5031, 2149, 21439, 141039, 0 };
            const std::uint32_t dim20176JoeKuoD6Init[]   =   { 1, 1, 1, 7, 15, 59, 35, 203, 347, 529, 1741, 1003, 6143, 4979, 15495, 48447, 2139, 187025, 0 };
            const std::uint32_t dim20177JoeKuoD6Init[]   =   { 1, 1, 7, 13, 15, 17, 77, 225, 461, 691, 1067, 1133, 6555, 511, 25845, 39835, 11755, 142743, 0 };
            const std::uint32_t dim20178JoeKuoD6Init[]   =   { 1, 3, 3, 11, 27, 25, 49, 51, 335, 1, 381, 2703, 7023, 14739, 19335, 39625, 82255, 76277, 0 };
            const std::uint32_t dim20179JoeKuoD6Init[]   =   { 1, 3, 3, 7, 19, 3, 35, 95, 203, 991, 515, 2245, 6085, 4129, 9581, 38309, 114203, 136021, 0 };
            const std::uint32_t dim20180JoeKuoD6Init[]   =   { 1, 1, 7, 7, 21, 61, 31, 57, 459, 119, 523, 1293, 3647, 735, 28849, 15581, 123943, 210069, 0 };
            const std::uint32_t dim20181JoeKuoD6Init[]   =   { 1, 1, 7, 3, 9, 55, 103, 23, 401, 109, 23, 4083, 6179, 12817, 2787, 43337, 53647, 241507, 0 };
            const std::uint32_t dim20182JoeKuoD6Init[]   =   { 1, 1, 5, 7, 9, 51, 37, 133, 97, 933, 1509, 2229, 1769, 12901, 15439, 25687, 128823, 72451, 0 };
            const std::uint32_t dim20183JoeKuoD6Init[]   =   { 1, 3, 1, 13, 17, 19, 7, 109, 299, 799, 621, 3393, 3645, 283, 29889, 63215, 97805, 45795, 0 };
            const std::uint32_t dim20184JoeKuoD6Init[]   =   { 1, 3, 1, 15, 21, 7, 65, 237, 221, 433, 1611, 2591, 3639, 3231, 6025, 53465, 88091, 17657, 0 };
            const std::uint32_t dim20185JoeKuoD6Init[]   =   { 1, 1, 7, 9, 27, 13, 11, 185, 381, 43, 961, 2743, 2691, 10531, 3713, 61757, 124011, 209323, 0 };
            const std::uint32_t dim20186JoeKuoD6Init[]   =   { 1, 3, 5, 1, 13, 7, 109, 65, 359, 577, 2001, 3085, 3519, 8577, 19299, 40145, 37159, 82421, 0 };
            const std::uint32_t dim20187JoeKuoD6Init[]   =   { 1, 1, 3, 11, 7, 5, 21, 215, 391, 317, 879, 1835, 611, 7189, 3887, 45383, 41025, 175701, 0 };
            const std::uint32_t dim20188JoeKuoD6Init[]   =   { 1, 1, 1, 1, 5, 17, 69, 115, 481, 477, 2017, 583, 8033, 11349, 16625, 213, 88033, 31707, 0 };
            const std::uint32_t dim20189JoeKuoD6Init[]   =   { 1, 1, 7, 15, 19, 55, 121, 35, 1, 71, 1011, 3247, 4133, 1681, 29943, 30149, 96797, 177707, 0 };
            const std::uint32_t dim20190JoeKuoD6Init[]   =   { 1, 3, 5, 13, 11, 45, 83, 153, 455, 223, 787, 2025, 5271, 229, 17549, 5775, 75311, 134523, 0 };
            const std::uint32_t dim20191JoeKuoD6Init[]   =   { 1, 3, 5, 7, 21, 43, 3, 253, 395, 651, 1111, 1685, 539, 6555, 25761, 39477, 15823, 261825, 0 };
            const std::uint32_t dim20192JoeKuoD6Init[]   =   { 1, 3, 7, 15, 27, 35, 43, 191, 269, 247, 883, 887, 1505, 7433, 6239, 5421, 49583, 17765, 0 };
            const std::uint32_t dim20193JoeKuoD6Init[]   =   { 1, 1, 5, 15, 7, 19, 113, 177, 63, 119, 517, 3987, 971, 12071, 13107, 28913, 85675, 204921, 0 };
            const std::uint32_t dim20194JoeKuoD6Init[]   =   { 1, 3, 7, 15, 31, 47, 21, 129, 31, 505, 661, 855, 6135, 13063, 27971, 63801, 27469, 75373, 0 };
            const std::uint32_t dim20195JoeKuoD6Init[]   =   { 1, 1, 7, 5, 13, 23, 111, 85, 279, 969, 483, 831, 483, 9065, 10997, 59031, 5083, 150939, 0 };
            const std::uint32_t dim20196JoeKuoD6Init[]   =   { 1, 3, 5, 7, 17, 55, 11, 223, 189, 209, 139, 577, 5443, 913, 19085, 53113, 8427, 11251, 0 };
            const std::uint32_t dim20197JoeKuoD6Init[]   =   { 1, 1, 1, 7, 23, 61, 95, 213, 443, 803, 1545, 3625, 2195, 2649, 10913, 14339, 23001, 16735, 0 };
            const std::uint32_t dim20198JoeKuoD6Init[]   =   { 1, 3, 3, 3, 13, 45, 15, 225, 419, 445, 527, 635, 2279, 5097, 25267, 199, 66187, 156717, 0 };
            const std::uint32_t dim20199JoeKuoD6Init[]   =   { 1, 1, 1, 7, 23, 17, 113, 245, 99, 159, 919, 2961, 1731, 6241, 12749, 8925, 44153, 243249, 0 };
            const std::uint32_t dim20200JoeKuoD6Init[]   =   { 1, 3, 1, 3, 29, 57, 43, 245, 389, 233, 135, 45, 3771, 14061, 10173, 51939, 128985, 81605, 0 };
            const std::uint32_t dim20201JoeKuoD6Init[]   =   { 1, 1, 1, 15, 1, 19, 25, 111, 91, 193, 1185, 3679, 7155, 7077, 13743, 35631, 128975, 196979, 0 };
            const std::uint32_t dim20202JoeKuoD6Init[]   =   { 1, 3, 3, 13, 31, 57, 25, 53, 149, 331, 643, 915, 1607, 14429, 29803, 23459, 72915, 39253, 0 };
            const std::uint32_t dim20203JoeKuoD6Init[]   =   { 1, 3, 3, 9, 23, 45, 9, 29, 383, 277, 981, 1647, 5217, 4449, 26759, 63849, 98081, 37565, 0 };
            const std::uint32_t dim20204JoeKuoD6Init[]   =   { 1, 1, 1, 15, 3, 23, 9, 121, 231, 27, 1961, 2389, 1689, 7041, 8069, 37973, 74601, 15553, 0 };
            const std::uint32_t dim20205JoeKuoD6Init[]   =   { 1, 1, 5, 15, 15, 29, 11, 177, 355, 47, 1821, 393, 3383, 10439, 6357, 41119, 60323, 206253, 0 };
            const std::uint32_t dim20206JoeKuoD6Init[]   =   { 1, 1, 1, 1, 21, 29, 87, 149, 157, 979, 1867, 729, 1949, 4409, 27495, 6841, 89033, 214957, 0 };
            const std::uint32_t dim20207JoeKuoD6Init[]   =   { 1, 1, 3, 3, 9, 7, 115, 129, 141, 157, 881, 109, 5537, 303, 32549, 1953, 9903, 82401, 0 };
            const std::uint32_t dim20208JoeKuoD6Init[]   =   { 1, 1, 5, 15, 9, 19, 93, 53, 319, 913, 1341, 705, 4639, 16189, 11375, 39155, 81393, 115843, 0 };
            const std::uint32_t dim20209JoeKuoD6Init[]   =   { 1, 1, 5, 7, 31, 21, 3, 47, 437, 799, 359, 3291, 3917, 12983, 19283, 23769, 34033, 226041, 0 };
            const std::uint32_t dim20210JoeKuoD6Init[]   =   { 1, 3, 7, 7, 27, 13, 65, 31, 181, 511, 1373, 3871, 1537, 6015, 12103, 42187, 121043, 95715, 0 };
            const std::uint32_t dim20211JoeKuoD6Init[]   =   { 1, 1, 5, 11, 1, 55, 91, 11, 105, 137, 1787, 81, 5163, 5793, 17403, 59433, 113439, 65751, 0 };
            const std::uint32_t dim20212JoeKuoD6Init[]   =   { 1, 1, 3, 13, 21, 57, 87, 157, 379, 5, 285, 3217, 4557, 3359, 28953, 63397, 110537, 230571, 0 };
            const std::uint32_t dim20213JoeKuoD6Init[]   =   { 1, 3, 7, 7, 7, 27, 25, 109, 125, 337, 719, 561, 5903, 12913, 6987, 17157, 50655, 195109, 0 };
            const std::uint32_t dim20214JoeKuoD6Init[]   =   { 1, 3, 3, 15, 3, 11, 97, 93, 441, 19, 1435, 515, 6129, 5177, 28075, 53495, 107817, 78399, 0 };
            const std::uint32_t dim20215JoeKuoD6Init[]   =   { 1, 3, 1, 9, 13, 7, 89, 171, 165, 479, 223, 4001, 691, 4033, 13577, 33363, 63447, 46609, 0 };
            const std::uint32_t dim20216JoeKuoD6Init[]   =   { 1, 3, 7, 1, 15, 47, 103, 45, 209, 639, 1465, 2795, 6025, 7981, 29491, 47743, 12861, 222445, 0 };
            const std::uint32_t dim20217JoeKuoD6Init[]   =   { 1, 3, 3, 3, 1, 25, 121, 91, 253, 969, 1259, 1409, 1329, 15995, 17733, 24081, 101747, 120619, 0 };
            const std::uint32_t dim20218JoeKuoD6Init[]   =   { 1, 3, 7, 11, 11, 5, 7, 241, 469, 411, 1733, 1385, 7005, 10977, 23369, 10675, 90341, 93077, 0 };
            const std::uint32_t dim20219JoeKuoD6Init[]   =   { 1, 3, 3, 13, 17, 35, 107, 189, 437, 801, 1761, 3133, 3847, 14079, 22465, 45957, 38449, 54273, 0 };
            const std::uint32_t dim20220JoeKuoD6Init[]   =   { 1, 1, 7, 9, 9, 47, 55, 107, 491, 281, 777, 2187, 6179, 6607, 2151, 9093, 42873, 104677, 0 };
            const std::uint32_t dim20221JoeKuoD6Init[]   =   { 1, 1, 5, 3, 25, 3, 37, 55, 339, 619, 1227, 3859, 5593, 9639, 31199, 48155, 80779, 6497, 0 };
            const std::uint32_t dim20222JoeKuoD6Init[]   =   { 1, 1, 7, 1, 21, 49, 105, 45, 119, 635, 163, 3821, 3689, 11395, 19265, 14289, 89259, 167433, 0 };
            const std::uint32_t dim20223JoeKuoD6Init[]   =   { 1, 3, 3, 15, 29, 23, 11, 255, 425, 443, 1659, 3965, 4791, 10223, 11113, 48751, 7987, 166605, 0 };
            const std::uint32_t dim20224JoeKuoD6Init[]   =   { 1, 1, 7, 3, 7, 1, 113, 153, 233, 803, 539, 297, 4847, 11203, 29393, 54319, 94373, 173471, 0 };
            const std::uint32_t dim20225JoeKuoD6Init[]   =   { 1, 3, 3, 5, 27, 57, 23, 147, 423, 617, 103, 3369, 4825, 13613, 23635, 61977, 5331, 115243, 0 };
            const std::uint32_t dim20226JoeKuoD6Init[]   =   { 1, 3, 3, 9, 11, 47, 41, 27, 345, 657, 1873, 365, 1685, 11181, 31977, 60489, 98741, 215357, 0 };
            const std::uint32_t dim20227JoeKuoD6Init[]   =   { 1, 3, 1, 11, 19, 33, 39, 223, 151, 921, 309, 3413, 6735, 11971, 25583, 6927, 54821, 125203, 0 };
            const std::uint32_t dim20228JoeKuoD6Init[]   =   { 1, 1, 5, 1, 27, 31, 61, 247, 207, 895, 1453, 3613, 7097, 6537, 29407, 9903, 39937, 98285, 0 };
            const std::uint32_t dim20229JoeKuoD6Init[]   =   { 1, 3, 1, 5, 7, 11, 119, 7, 323, 27, 1069, 2033, 7387, 3381, 19007, 49039, 39453, 115411, 0 };
            const std::uint32_t dim20230JoeKuoD6Init[]   =   { 1, 1, 7, 3, 9, 15, 51, 139, 353, 857, 1829, 3955, 7669, 3961, 22805, 39879, 26677, 66865, 0 };
            const std::uint32_t dim20231JoeKuoD6Init[]   =   { 1, 3, 5, 7, 1, 11, 59, 95, 181, 645, 829, 3119, 3607, 5973, 12381, 41577, 79443, 226945, 0 };
            const std::uint32_t dim20232JoeKuoD6Init[]   =   { 1, 3, 3, 5, 3, 13, 91, 119, 103, 889, 703, 3005, 541, 7529, 12613, 14267, 70445, 217543, 0 };
            const std::uint32_t dim20233JoeKuoD6Init[]   =   { 1, 1, 5, 7, 17, 41, 5, 225, 85, 759, 1071, 2055, 1655, 14811, 25635, 50803, 58545, 105687, 0 };
            const std::uint32_t dim20234JoeKuoD6Init[]   =   { 1, 3, 5, 13, 3, 7, 77, 209, 139, 717, 985, 1085, 831, 11011, 27313, 46423, 29435, 207359, 0 };
            const std::uint32_t dim20235JoeKuoD6Init[]   =   { 1, 3, 1, 7, 27, 45, 39, 75, 311, 937, 1593, 1357, 4815, 1997, 1045, 48681, 49301, 155607, 0 };
            const std::uint32_t dim20236JoeKuoD6Init[]   =   { 1, 3, 5, 11, 21, 9, 111, 39, 447, 241, 1613, 1799, 4817, 1861, 1263, 63641, 92081, 252051, 0 };
            const std::uint32_t dim20237JoeKuoD6Init[]   =   { 1, 1, 1, 13, 31, 13, 39, 29, 349, 25, 1227, 2457, 3831, 7965, 16903, 25825, 62381, 101765, 0 };
            const std::uint32_t dim20238JoeKuoD6Init[]   =   { 1, 1, 3, 7, 15, 17, 5, 29, 83, 607, 931, 261, 1087, 16247, 10129, 7813, 5445, 167723, 0 };
            const std::uint32_t dim20239JoeKuoD6Init[]   =   { 1, 3, 5, 9, 15, 31, 69, 191, 139, 467, 1681, 1951, 7813, 4295, 18191, 11411, 15601, 13025, 0 };
            const std::uint32_t dim20240JoeKuoD6Init[]   =   { 1, 1, 1, 11, 29, 53, 97, 205, 281, 917, 1009, 913, 1003, 16085, 30339, 55753, 53099, 30697, 0 };
            const std::uint32_t dim20241JoeKuoD6Init[]   =   { 1, 1, 3, 15, 25, 35, 7, 227, 63, 251, 845, 843, 7117, 6021, 26917, 43611, 108643, 215471, 0 };
            const std::uint32_t dim20242JoeKuoD6Init[]   =   { 1, 1, 3, 11, 19, 29, 75, 5, 131, 37, 1185, 2387, 8161, 1621, 19887, 20525, 33067, 30869, 0 };
            const std::uint32_t dim20243JoeKuoD6Init[]   =   { 1, 1, 3, 3, 7, 37, 75, 159, 313, 17, 479, 2477, 7779, 309, 26095, 35693, 92561, 143151, 0 };
            const std::uint32_t dim20244JoeKuoD6Init[]   =   { 1, 1, 5, 9, 5, 29, 65, 223, 331, 1013, 37, 1813, 1379, 9277, 14681, 61687, 24763, 124669, 0 };
            const std::uint32_t dim20245JoeKuoD6Init[]   =   { 1, 3, 1, 1, 17, 47, 7, 219, 11, 13, 1517, 2583, 7483, 5399, 6883, 51387, 17901, 108659, 0 };
            const std::uint32_t dim20246JoeKuoD6Init[]   =   { 1, 3, 7, 11, 9, 63, 81, 91, 411, 535, 255, 3683, 5285, 1787, 27205, 43651, 15647, 230651, 0 };
            const std::uint32_t dim20247JoeKuoD6Init[]   =   { 1, 3, 1, 11, 7, 47, 35, 255, 341, 379, 421, 753, 7821, 13271, 13021, 463, 48457, 132521, 0 };
            const std::uint32_t dim20248JoeKuoD6Init[]   =   { 1, 1, 5, 7, 21, 23, 53, 229, 393, 509, 1641, 2245, 6941, 10447, 3231, 5451, 18883, 47401, 0 };
            const std::uint32_t dim20249JoeKuoD6Init[]   =   { 1, 3, 1, 7, 13, 61, 71, 49, 147, 625, 299, 3843, 4851, 3483, 27005, 23871, 18855, 124893, 0 };
            const std::uint32_t dim20250JoeKuoD6Init[]   =   { 1, 3, 1, 7, 31, 13, 127, 177, 259, 179, 531, 1775, 5481, 13157, 23821, 31773, 93941, 237697, 0 };
            const std::uint32_t dim20251JoeKuoD6Init[]   =   { 1, 1, 7, 1, 23, 21, 111, 219, 401, 455, 1603, 2077, 1537, 2063, 17821, 52087, 20707, 29535, 0 };
            const std::uint32_t dim20252JoeKuoD6Init[]   =   { 1, 1, 3, 11, 17, 17, 13, 79, 49, 353, 1691, 361, 2805, 7121, 27013, 50631, 108235, 70513, 0 };
            const std::uint32_t dim20253JoeKuoD6Init[]   =   { 1, 1, 5, 3, 15, 25, 103, 73, 377, 253, 1303, 501, 555, 15789, 16647, 9019, 60581, 157337, 0 };
            const std::uint32_t dim20254JoeKuoD6Init[]   =   { 1, 3, 5, 9, 23, 45, 3, 251, 25, 559, 429, 1091, 5657, 15387, 5113, 64533, 131049, 127587, 0 };
            const std::uint32_t dim20255JoeKuoD6Init[]   =   { 1, 1, 3, 15, 1, 53, 71, 141, 413, 849, 737, 3045, 7119, 8049, 18295, 31447, 70735, 117457, 0 };
            const std::uint32_t dim20256JoeKuoD6Init[]   =   { 1, 1, 1, 11, 17, 11, 69, 155, 211, 249, 1869, 1575, 6859, 7045, 7015, 20135, 84157, 232621, 0 };
            const std::uint32_t dim20257JoeKuoD6Init[]   =   { 1, 3, 7, 5, 19, 55, 15, 163, 457, 371, 1665, 1935, 601, 3629, 21975, 1191, 45133, 111649, 0 };
            const std::uint32_t dim20258JoeKuoD6Init[]   =   { 1, 3, 7, 11, 23, 33, 5, 253, 355, 379, 933, 1781, 3989, 6191, 19081, 7651, 74671, 258799, 0 };
            const std::uint32_t dim20259JoeKuoD6Init[]   =   { 1, 1, 3, 3, 23, 3, 63, 123, 273, 861, 369, 2409, 1505, 9059, 10727, 189, 122911, 44037, 0 };
            const std::uint32_t dim20260JoeKuoD6Init[]   =   { 1, 1, 7, 13, 13, 23, 19, 87, 191, 397, 2027, 1689, 1143, 10919, 27073, 15013, 118429, 119165, 0 };
            const std::uint32_t dim20261JoeKuoD6Init[]   =   { 1, 1, 5, 9, 15, 13, 29, 81, 409, 955, 1827, 1341, 3473, 16005, 29041, 57527, 7329, 167093, 0 };
            const std::uint32_t dim20262JoeKuoD6Init[]   =   { 1, 1, 5, 3, 11, 31, 47, 13, 171, 995, 961, 3885, 3259, 2745, 12405, 49281, 2901, 207591, 0 };
            const std::uint32_t dim20263JoeKuoD6Init[]   =   { 1, 3, 5, 13, 31, 3, 1, 215, 465, 279, 1697, 2449, 3829, 2053, 9877, 52911, 126077, 210515, 0 };
            const std::uint32_t dim20264JoeKuoD6Init[]   =   { 1, 1, 3, 7, 11, 27, 55, 115, 249, 353, 407, 2567, 8105, 7747, 18111, 3383, 101875, 2185, 0 };
            const std::uint32_t dim20265JoeKuoD6Init[]   =   { 1, 1, 3, 9, 25, 5, 35, 137, 405, 667, 1671, 2965, 5975, 4999, 18421, 43623, 64621, 129797, 0 };
            const std::uint32_t dim20266JoeKuoD6Init[]   =   { 1, 3, 7, 13, 3, 17, 33, 191, 463, 787, 1795, 3037, 1679, 63, 12389, 3983, 22385, 84235, 0 };
            const std::uint32_t dim20267JoeKuoD6Init[]   =   { 1, 1, 5, 9, 11, 25, 85, 215, 355, 553, 317, 1637, 3461, 15943, 2619, 14545, 125507, 18659, 0 };
            const std::uint32_t dim20268JoeKuoD6Init[]   =   { 1, 1, 7, 5, 3, 41, 105, 179, 125, 557, 1345, 3631, 481, 10621, 11213, 40223, 46581, 113137, 0 };
            const std::uint32_t dim20269JoeKuoD6Init[]   =   { 1, 3, 3, 15, 1, 63, 95, 213, 89, 21, 1249, 3063, 413, 4307, 26723, 10225, 115143, 144817, 0 };
            const std::uint32_t dim20270JoeKuoD6Init[]   =   { 1, 3, 5, 15, 9, 43, 41, 117, 419, 143, 1651, 377, 4775, 8761, 23793, 8719, 76499, 208119, 0 };
            const std::uint32_t dim20271JoeKuoD6Init[]   =   { 1, 3, 3, 1, 21, 29, 47, 117, 23, 333, 1153, 1067, 5859, 9375, 29997, 58991, 55895, 204933, 0 };
            const std::uint32_t dim20272JoeKuoD6Init[]   =   { 1, 1, 3, 11, 11, 21, 115, 85, 223, 281, 701, 1331, 1341, 1149, 5993, 10885, 77353, 113553, 0 };
            const std::uint32_t dim20273JoeKuoD6Init[]   =   { 1, 1, 5, 1, 25, 1, 1, 153, 449, 231, 593, 3061, 4157, 6661, 21735, 11361, 57751, 129569, 0 };
            const std::uint32_t dim20274JoeKuoD6Init[]   =   { 1, 1, 3, 7, 27, 63, 81, 251, 125, 197, 1525, 1637, 4643, 4743, 17127, 51217, 95781, 973, 0 };
            const std::uint32_t dim20275JoeKuoD6Init[]   =   { 1, 1, 3, 7, 11, 51, 13, 139, 83, 341, 543, 3061, 7777, 6705, 9609, 28933, 24669, 225275, 0 };
            const std::uint32_t dim20276JoeKuoD6Init[]   =   { 1, 3, 1, 9, 25, 39, 99, 139, 5, 725, 1759, 1577, 1751, 3197, 3169, 39051, 1743, 108813, 0 };
            const std::uint32_t dim20277JoeKuoD6Init[]   =   { 1, 1, 7, 5, 31, 15, 115, 229, 499, 291, 501, 3119, 2293, 14137, 625, 16379, 111057, 101643, 0 };
            const std::uint32_t dim20278JoeKuoD6Init[]   =   { 1, 3, 7, 15, 31, 1, 51, 73, 455, 51, 1983, 3687, 6049, 3495, 26247, 6567, 28479, 158909, 0 };
            const std::uint32_t dim20279JoeKuoD6Init[]   =   { 1, 3, 5, 5, 9, 11, 77, 181, 165, 773, 1611, 3945, 6787, 3827, 28597, 53269, 34003, 237291, 0 };
            const std::uint32_t dim20280JoeKuoD6Init[]   =   { 1, 1, 5, 3, 31, 57, 15, 9, 163, 363, 1021, 2193, 8175, 3851, 26059, 63915, 114293, 163637, 0 };
            const std::uint32_t dim20281JoeKuoD6Init[]   =   { 1, 1, 3, 7, 27, 49, 35, 121, 469, 833, 879, 1601, 6991, 13271, 8085, 45343, 5189, 109413, 0 };
            const std::uint32_t dim20282JoeKuoD6Init[]   =   { 1, 3, 1, 15, 7, 11, 111, 153, 129, 769, 565, 2693, 333, 7343, 28535, 56937, 85641, 19871, 0 };
            const std::uint32_t dim20283JoeKuoD6Init[]   =   { 1, 1, 5, 13, 7, 49, 121, 223, 55, 33, 19, 2291, 1847, 10173, 23337, 23431, 18181, 155663, 0 };
            const std::uint32_t dim20284JoeKuoD6Init[]   =   { 1, 3, 1, 11, 25, 9, 3, 255, 425, 861, 1025, 3719, 6995, 14687, 31083, 60609, 115375, 17813, 0 };
            const std::uint32_t dim20285JoeKuoD6Init[]   =   { 1, 1, 5, 13, 1, 55, 109, 239, 13, 939, 1077, 669, 1643, 10949, 25399, 55055, 125829, 253077, 0 };
            const std::uint32_t dim20286JoeKuoD6Init[]   =   { 1, 1, 5, 3, 15, 51, 13, 133, 257, 387, 2017, 2223, 1479, 9377, 12867, 9833, 32323, 6255, 0 };
            const std::uint32_t dim20287JoeKuoD6Init[]   =   { 1, 3, 1, 9, 1, 53, 121, 163, 349, 491, 1867, 3403, 6859, 459, 1483, 23893, 66851, 150843, 0 };
            const std::uint32_t dim20288JoeKuoD6Init[]   =   { 1, 1, 1, 1, 1, 33, 51, 33, 177, 633, 449, 2705, 663, 3701, 8331, 43895, 87223, 48587, 0 };
            const std::uint32_t dim20289JoeKuoD6Init[]   =   { 1, 3, 5, 7, 23, 7, 99, 43, 217, 31, 749, 2831, 1557, 3295, 6797, 45229, 46831, 62183, 0 };
            const std::uint32_t dim20290JoeKuoD6Init[]   =   { 1, 1, 7, 7, 1, 45, 35, 51, 415, 693, 479, 1017, 6703, 241, 30887, 8953, 26901, 2951, 0 };
            const std::uint32_t dim20291JoeKuoD6Init[]   =   { 1, 3, 3, 7, 29, 3, 25, 217, 67, 769, 653, 3983, 5513, 15481, 21399, 17525, 81747, 109843, 0 };
            const std::uint32_t dim20292JoeKuoD6Init[]   =   { 1, 3, 5, 5, 29, 17, 97, 187, 157, 189, 1531, 1123, 4291, 14831, 15493, 62753, 53563, 153679, 0 };
            const std::uint32_t dim20293JoeKuoD6Init[]   =   { 1, 3, 7, 13, 15, 63, 47, 5, 351, 275, 1177, 3947, 6755, 1319, 17053, 14267, 98215, 228795, 0 };
            const std::uint32_t dim20294JoeKuoD6Init[]   =   { 1, 3, 7, 5, 19, 45, 43, 223, 213, 903, 539, 267, 83, 6951, 2979, 56929, 58405, 198373, 0 };
            const std::uint32_t dim20295JoeKuoD6Init[]   =   { 1, 1, 5, 11, 21, 37, 109, 103, 29, 49, 17, 3987, 5679, 2559, 17391, 46157, 38743, 82245, 0 };
            const std::uint32_t dim20296JoeKuoD6Init[]   =   { 1, 1, 3, 7, 7, 35, 57, 187, 113, 361, 721, 1821, 6473, 10233, 22549, 37725, 8445, 220669, 0 };
            const std::uint32_t dim20297JoeKuoD6Init[]   =   { 1, 3, 3, 9, 21, 41, 73, 29, 163, 701, 1277, 3869, 1529, 4889, 10091, 65507, 53829, 191347, 0 };
            const std::uint32_t dim20298JoeKuoD6Init[]   =   { 1, 1, 5, 15, 5, 21, 39, 39, 341, 271, 1543, 3161, 3935, 8319, 24921, 19575, 95009, 256221, 0 };
            const std::uint32_t dim20299JoeKuoD6Init[]   =   { 1, 1, 1, 3, 11, 33, 63, 189, 21, 773, 1261, 3947, 183, 6769, 31337, 22179, 57255, 8323, 0 };
            const std::uint32_t dim20300JoeKuoD6Init[]   =   { 1, 1, 3, 15, 29, 59, 103, 251, 107, 499, 915, 387, 3127, 5597, 3345, 15657, 979, 91685, 0 };
            const std::uint32_t dim20301JoeKuoD6Init[]   =   { 1, 3, 3, 11, 13, 27, 9, 137, 177, 75, 567, 1511, 7355, 3087, 15309, 51733, 87329, 217125, 0 };
            const std::uint32_t dim20302JoeKuoD6Init[]   =   { 1, 1, 1, 15, 9, 43, 113, 177, 507, 379, 765, 75, 6895, 7523, 24611, 7315, 49653, 59263, 0 };
            const std::uint32_t dim20303JoeKuoD6Init[]   =   { 1, 3, 1, 5, 29, 23, 59, 215, 267, 161, 1957, 341, 4081, 9635, 3345, 12323, 128751, 144577, 0 };
            const std::uint32_t dim20304JoeKuoD6Init[]   =   { 1, 3, 3, 13, 17, 55, 59, 73, 65, 697, 1209, 3345, 5629, 4545, 23043, 37649, 55015, 10263, 0 };
            const std::uint32_t dim20305JoeKuoD6Init[]   =   { 1, 1, 7, 1, 21, 3, 7, 19, 445, 417, 1677, 799, 1241, 15463, 19815, 52845, 81309, 256713, 0 };
            const std::uint32_t dim20306JoeKuoD6Init[]   =   { 1, 1, 3, 13, 13, 57, 17, 199, 3, 377, 1799, 2713, 3937, 12511, 7439, 33605, 56697, 168195, 0 };
            const std::uint32_t dim20307JoeKuoD6Init[]   =   { 1, 3, 1, 7, 21, 53, 115, 97, 389, 83, 961, 813, 1499, 3411, 22377, 33323, 118405, 115947, 0 };
            const std::uint32_t dim20308JoeKuoD6Init[]   =   { 1, 3, 7, 11, 23, 43, 85, 249, 151, 893, 833, 901, 7731, 13467, 14721, 38613, 104033, 136097, 0 };
            const std::uint32_t dim20309JoeKuoD6Init[]   =   { 1, 3, 1, 11, 23, 23, 119, 129, 175, 159, 1031, 2379, 2753, 6755, 10979, 18225, 52375, 257003, 0 };
            const std::uint32_t dim20310JoeKuoD6Init[]   =   { 1, 3, 1, 13, 1, 9, 61, 255, 433, 621, 1469, 705, 5841, 7421, 23873, 30487, 55823, 119705, 0 };
            const std::uint32_t dim20311JoeKuoD6Init[]   =   { 1, 3, 1, 15, 19, 31, 29, 163, 87, 793, 885, 2495, 4609, 2757, 5333, 52937, 79187, 228777, 0 };
            const std::uint32_t dim20312JoeKuoD6Init[]   =   { 1, 1, 1, 3, 17, 43, 69, 241, 143, 173, 327, 2747, 5617, 16347, 16155, 47775, 25917, 163663, 0 };
            const std::uint32_t dim20313JoeKuoD6Init[]   =   { 1, 1, 1, 1, 19, 19, 15, 27, 25, 139, 691, 4019, 3055, 10301, 11281, 10957, 59117, 178149, 0 };
            const std::uint32_t dim20314JoeKuoD6Init[]   =   { 1, 1, 1, 3, 15, 15, 37, 89, 103, 7, 527, 2823, 7205, 6831, 25179, 22249, 103323, 31251, 0 };
            const std::uint32_t dim20315JoeKuoD6Init[]   =   { 1, 1, 3, 3, 7, 49, 7, 241, 37, 11, 577, 1987, 1935, 14787, 16411, 36305, 65185, 221253, 0 };
            const std::uint32_t dim20316JoeKuoD6Init[]   =   { 1, 1, 1, 5, 31, 51, 123, 169, 441, 13, 721, 2359, 5687, 2641, 16339, 8441, 55967, 98775, 0 };
            const std::uint32_t dim20317JoeKuoD6Init[]   =   { 1, 1, 7, 5, 21, 23, 91, 229, 23, 105, 339, 2371, 7803, 14913, 12651, 40573, 117399, 134865, 0 };
            const std::uint32_t dim20318JoeKuoD6Init[]   =   { 1, 3, 1, 15, 19, 27, 127, 77, 469, 343, 451, 2251, 6705, 7765, 8623, 10367, 100379, 140899, 0 };
            const std::uint32_t dim20319JoeKuoD6Init[]   =   { 1, 3, 1, 5, 1, 11, 93, 231, 33, 133, 1545, 1015, 7577, 8871, 29975, 12141, 130833, 103123, 0 };
            const std::uint32_t dim20320JoeKuoD6Init[]   =   { 1, 3, 3, 5, 7, 25, 95, 93, 293, 543, 1785, 2097, 6045, 4225, 607, 443, 72055, 32269, 0 };
            const std::uint32_t dim20321JoeKuoD6Init[]   =   { 1, 1, 1, 1, 5, 55, 47, 105, 189, 359, 1589, 765, 2303, 11963, 25565, 40669, 98977, 242089, 0 };
            const std::uint32_t dim20322JoeKuoD6Init[]   =   { 1, 1, 1, 15, 13, 45, 121, 235, 125, 181, 1891, 3265, 2097, 3207, 31647, 13407, 22515, 15155, 0 };
            const std::uint32_t dim20323JoeKuoD6Init[]   =   { 1, 1, 5, 15, 13, 11, 81, 233, 307, 505, 221, 813, 6483, 741, 9819, 19405, 74235, 144761, 0 };
            const std::uint32_t dim20324JoeKuoD6Init[]   =   { 1, 3, 5, 7, 9, 25, 31, 209, 337, 473, 1831, 2711, 5551, 13531, 28747, 1875, 6401, 159995, 0 };
            const std::uint32_t dim20325JoeKuoD6Init[]   =   { 1, 1, 7, 7, 29, 3, 127, 207, 387, 849, 1449, 2741, 2105, 885, 18115, 5433, 122119, 16969, 0 };
            const std::uint32_t dim20326JoeKuoD6Init[]   =   { 1, 3, 7, 9, 25, 17, 43, 209, 41, 927, 409, 1567, 1609, 12487, 16305, 41365, 10991, 172127, 0 };
            const std::uint32_t dim20327JoeKuoD6Init[]   =   { 1, 1, 3, 7, 27, 29, 63, 127, 81, 283, 1459, 143, 5993, 14027, 8055, 28065, 128389, 255307, 0 };
            const std::uint32_t dim20328JoeKuoD6Init[]   =   { 1, 3, 7, 11, 13, 41, 63, 223, 215, 901, 1853, 2881, 5149, 7439, 4519, 33279, 127765, 139431, 0 };
            const std::uint32_t dim20329JoeKuoD6Init[]   =   { 1, 3, 7, 7, 15, 61, 61, 173, 221, 711, 191, 3863, 2695, 9663, 6277, 8791, 128019, 256755, 0 };
            const std::uint32_t dim20330JoeKuoD6Init[]   =   { 1, 3, 1, 9, 29, 45, 83, 43, 297, 605, 1887, 2421, 2307, 5199, 17275, 39225, 127215, 253687, 0 };
            const std::uint32_t dim20331JoeKuoD6Init[]   =   { 1, 1, 5, 3, 21, 23, 121, 125, 497, 945, 1367, 2757, 3481, 8607, 32447, 62373, 32171, 226621, 0 };
            const std::uint32_t dim20332JoeKuoD6Init[]   =   { 1, 3, 1, 5, 7, 1, 71, 255, 465, 951, 129, 1989, 6053, 3737, 6511, 54519, 16947, 124491, 0 };
            const std::uint32_t dim20333JoeKuoD6Init[]   =   { 1, 3, 5, 1, 9, 21, 127, 49, 85, 615, 1897, 1715, 7923, 10309, 16919, 24131, 18015, 140195, 0 };
            const std::uint32_t dim20334JoeKuoD6Init[]   =   { 1, 1, 1, 1, 5, 27, 3, 205, 29, 319, 485, 3941, 7829, 789, 4207, 39939, 67761, 152459, 0 };
            const std::uint32_t dim20335JoeKuoD6Init[]   =   { 1, 3, 7, 11, 9, 41, 1, 129, 511, 831, 1007, 2011, 6211, 9179, 20877, 62121, 21879, 23661, 0 };
            const std::uint32_t dim20336JoeKuoD6Init[]   =   { 1, 1, 7, 1, 19, 53, 75, 123, 181, 735, 925, 1065, 3317, 3201, 27473, 19379, 78223, 45725, 0 };
            const std::uint32_t dim20337JoeKuoD6Init[]   =   { 1, 1, 5, 9, 9, 61, 3, 193, 441, 815, 583, 3235, 247, 14091, 19877, 33505, 3477, 20111, 0 };
            const std::uint32_t dim20338JoeKuoD6Init[]   =   { 1, 1, 5, 13, 29, 53, 55, 165, 359, 889, 1833, 1543, 7913, 307, 22853, 37839, 15569, 140127, 0 };
            const std::uint32_t dim20339JoeKuoD6Init[]   =   { 1, 1, 1, 15, 21, 53, 63, 195, 299, 1019, 1371, 1311, 5401, 8015, 30335, 56281, 61011, 59279, 0 };
            const std::uint32_t dim20340JoeKuoD6Init[]   =   { 1, 1, 3, 13, 3, 57, 45, 239, 445, 419, 581, 3971, 4621, 9327, 27255, 53069, 126415, 250313, 0 };
            const std::uint32_t dim20341JoeKuoD6Init[]   =   { 1, 3, 1, 9, 5, 63, 21, 25, 447, 961, 1857, 3123, 3029, 9743, 26069, 38251, 58475, 108737, 0 };
            const std::uint32_t dim20342JoeKuoD6Init[]   =   { 1, 3, 1, 15, 13, 59, 5, 21, 171, 107, 1631, 2407, 6695, 8079, 2805, 50995, 53173, 104757, 0 };
            const std::uint32_t dim20343JoeKuoD6Init[]   =   { 1, 3, 7, 7, 1, 55, 103, 67, 369, 533, 515, 2363, 5147, 11633, 20435, 24591, 68155, 140029, 0 };
            const std::uint32_t dim20344JoeKuoD6Init[]   =   { 1, 3, 7, 13, 19, 51, 13, 149, 159, 915, 1029, 2825, 5259, 5139, 31325, 42825, 119923, 227811, 0 };
            const std::uint32_t dim20345JoeKuoD6Init[]   =   { 1, 3, 3, 3, 23, 17, 121, 25, 403, 333, 491, 2869, 881, 12997, 5101, 48351, 90831, 143009, 0 };
            const std::uint32_t dim20346JoeKuoD6Init[]   =   { 1, 1, 3, 15, 23, 63, 93, 43, 107, 393, 419, 3509, 1543, 10295, 11019, 8389, 73753, 42681, 0 };
            const std::uint32_t dim20347JoeKuoD6Init[]   =   { 1, 1, 7, 1, 29, 49, 41, 189, 303, 955, 1241, 1623, 2269, 3413, 6261, 2155, 90945, 95117, 0 };
            const std::uint32_t dim20348JoeKuoD6Init[]   =   { 1, 1, 3, 15, 31, 13, 103, 241, 189, 283, 1303, 1693, 1587, 16313, 205, 43421, 121799, 200151, 0 };
            const std::uint32_t dim20349JoeKuoD6Init[]   =   { 1, 3, 5, 1, 29, 27, 105, 83, 345, 411, 1197, 3489, 5891, 1137, 7311, 681, 127991, 69533, 0 };
            const std::uint32_t dim20350JoeKuoD6Init[]   =   { 1, 3, 5, 15, 31, 11, 105, 221, 57, 39, 145, 3233, 1431, 16271, 21225, 47989, 72583, 191327, 0 };
            const std::uint32_t dim20351JoeKuoD6Init[]   =   { 1, 3, 7, 9, 25, 47, 109, 61, 257, 949, 981, 1383, 8003, 4661, 19555, 20191, 114641, 84817, 0 };
            const std::uint32_t dim20352JoeKuoD6Init[]   =   { 1, 1, 5, 9, 17, 9, 19, 209, 73, 573, 1039, 2741, 1495, 1615, 6299, 20507, 84729, 166977, 0 };
            const std::uint32_t dim20353JoeKuoD6Init[]   =   { 1, 3, 5, 13, 27, 51, 39, 203, 437, 725, 1479, 3071, 621, 15563, 28473, 58403, 25943, 116683, 0 };
            const std::uint32_t dim20354JoeKuoD6Init[]   =   { 1, 1, 3, 9, 5, 29, 63, 61, 329, 305, 523, 2243, 6689, 11773, 19319, 57783, 24265, 218153, 0 };
            const std::uint32_t dim20355JoeKuoD6Init[]   =   { 1, 3, 7, 5, 17, 27, 115, 9, 243, 613, 679, 1915, 7265, 2989, 13663, 15115, 50779, 235761, 0 };
            const std::uint32_t dim20356JoeKuoD6Init[]   =   { 1, 1, 5, 5, 13, 35, 111, 151, 255, 569, 1209, 3277, 4503, 3797, 22601, 19523, 126339, 141289, 0 };
            const std::uint32_t dim20357JoeKuoD6Init[]   =   { 1, 1, 3, 9, 15, 51, 85, 125, 233, 1011, 231, 2949, 1091, 8605, 14855, 62401, 14143, 212557, 0 };
            const std::uint32_t dim20358JoeKuoD6Init[]   =   { 1, 3, 5, 11, 29, 53, 83, 31, 201, 219, 1083, 967, 6913, 10325, 1971, 55841, 7733, 208883, 0 };
            const std::uint32_t dim20359JoeKuoD6Init[]   =   { 1, 3, 3, 1, 23, 33, 51, 103, 265, 285, 1363, 2813, 3327, 7921, 13537, 31483, 43405, 189641, 0 };
            const std::uint32_t dim20360JoeKuoD6Init[]   =   { 1, 1, 7, 15, 27, 3, 5, 87, 117, 437, 1251, 189, 3271, 15579, 25025, 23203, 39421, 133581, 0 };
            const std::uint32_t dim20361JoeKuoD6Init[]   =   { 1, 1, 5, 1, 9, 3, 91, 45, 71, 557, 2019, 2355, 5539, 2843, 13025, 61017, 3475, 179891, 0 };
            const std::uint32_t dim20362JoeKuoD6Init[]   =   { 1, 1, 7, 5, 17, 11, 127, 241, 9, 971, 1699, 2719, 1947, 109, 19817, 13949, 120247, 60775, 0 };
            const std::uint32_t dim20363JoeKuoD6Init[]   =   { 1, 1, 5, 9, 9, 39, 117, 221, 197, 767, 1691, 4075, 3665, 1271, 16119, 64129, 2681, 105325, 0 };
            const std::uint32_t dim20364JoeKuoD6Init[]   =   { 1, 3, 3, 11, 31, 51, 5, 23, 419, 715, 1985, 4095, 7255, 10491, 25575, 6177, 35917, 178345, 0 };
            const std::uint32_t dim20365JoeKuoD6Init[]   =   { 1, 3, 5, 7, 15, 23, 99, 203, 461, 509, 1501, 1965, 1105, 1341, 21713, 21901, 129905, 67937, 0 };
            const std::uint32_t dim20366JoeKuoD6Init[]   =   { 1, 3, 3, 15, 25, 5, 55, 167, 477, 125, 163, 2379, 2433, 12975, 26259, 55825, 19913, 202873, 0 };
            const std::uint32_t dim20367JoeKuoD6Init[]   =   { 1, 3, 3, 7, 15, 15, 67, 227, 413, 905, 1609, 2083, 4011, 10477, 22809, 61873, 96423, 119253, 0 };
            const std::uint32_t dim20368JoeKuoD6Init[]   =   { 1, 3, 1, 11, 13, 17, 37, 147, 355, 445, 619, 3181, 5939, 6953, 15859, 37979, 24723, 133037, 0 };
            const std::uint32_t dim20369JoeKuoD6Init[]   =   { 1, 1, 5, 15, 5, 25, 89, 3, 279, 569, 343, 2453, 5739, 2901, 6709, 43957, 75791, 20791, 0 };
            const std::uint32_t dim20370JoeKuoD6Init[]   =   { 1, 1, 3, 5, 13, 39, 53, 203, 75, 945, 635, 349, 2339, 2549, 23827, 7903, 128005, 14949, 0 };
            const std::uint32_t dim20371JoeKuoD6Init[]   =   { 1, 1, 7, 3, 7, 59, 59, 77, 143, 99, 1313, 3957, 3807, 15731, 20919, 60829, 105967, 226767, 0 };
            const std::uint32_t dim20372JoeKuoD6Init[]   =   { 1, 1, 3, 7, 17, 49, 27, 245, 129, 583, 1055, 741, 5607, 689, 20075, 54837, 113257, 222677, 0 };
            const std::uint32_t dim20373JoeKuoD6Init[]   =   { 1, 1, 7, 13, 17, 5, 19, 141, 205, 749, 1769, 2981, 5787, 4511, 135, 19475, 113735, 116859, 0 };
            const std::uint32_t dim20374JoeKuoD6Init[]   =   { 1, 3, 7, 1, 9, 33, 111, 139, 77, 117, 363, 1171, 2587, 1539, 30791, 10697, 6879, 104827, 0 };
            const std::uint32_t dim20375JoeKuoD6Init[]   =   { 1, 3, 3, 5, 27, 47, 49, 215, 65, 435, 1601, 231, 2047, 10405, 28409, 17013, 103909, 232051, 0 };
            const std::uint32_t dim20376JoeKuoD6Init[]   =   { 1, 3, 3, 3, 13, 19, 3, 159, 293, 675, 247, 2829, 6703, 6085, 1935, 18209, 15709, 186669, 0 };
            const std::uint32_t dim20377JoeKuoD6Init[]   =   { 1, 3, 3, 5, 21, 55, 17, 237, 121, 603, 953, 947, 6973, 15979, 11029, 12381, 12807, 131603, 0 };
            const std::uint32_t dim20378JoeKuoD6Init[]   =   { 1, 3, 5, 3, 3, 41, 121, 203, 283, 349, 1841, 115, 6567, 2131, 883, 50515, 78381, 168189, 0 };
            const std::uint32_t dim20379JoeKuoD6Init[]   =   { 1, 3, 7, 15, 5, 55, 85, 13, 77, 443, 1711, 1043, 1265, 3701, 5121, 41435, 40637, 69125, 0 };
            const std::uint32_t dim20380JoeKuoD6Init[]   =   { 1, 1, 5, 15, 15, 33, 67, 235, 3, 95, 1685, 731, 2187, 11857, 7197, 62113, 12565, 127455, 0 };
            const std::uint32_t dim20381JoeKuoD6Init[]   =   { 1, 3, 7, 7, 11, 45, 125, 231, 263, 611, 221, 195, 6347, 14029, 7823, 52295, 78879, 211441, 0 };
            const std::uint32_t dim20382JoeKuoD6Init[]   =   { 1, 3, 7, 15, 9, 63, 75, 189, 187, 449, 27, 3647, 4705, 13037, 3773, 36441, 35445, 181793, 0 };
            const std::uint32_t dim20383JoeKuoD6Init[]   =   { 1, 1, 5, 3, 31, 19, 123, 39, 297, 1017, 1191, 2227, 6085, 5117, 16569, 64743, 29329, 157279, 0 };
            const std::uint32_t dim20384JoeKuoD6Init[]   =   { 1, 1, 5, 5, 15, 47, 111, 61, 435, 657, 141, 3445, 6921, 7759, 30141, 37631, 85969, 227563, 0 };
            const std::uint32_t dim20385JoeKuoD6Init[]   =   { 1, 3, 1, 13, 27, 39, 15, 167, 151, 185, 1513, 211, 951, 12705, 25703, 29289, 120993, 156741, 0 };
            const std::uint32_t dim20386JoeKuoD6Init[]   =   { 1, 3, 7, 7, 7, 39, 19, 221, 351, 951, 1231, 1915, 3043, 189, 18977, 50149, 56583, 122147, 0 };
            const std::uint32_t dim20387JoeKuoD6Init[]   =   { 1, 1, 5, 15, 29, 37, 77, 207, 291, 851, 131, 1041, 1657, 4393, 5023, 12745, 32253, 204431, 0 };
            const std::uint32_t dim20388JoeKuoD6Init[]   =   { 1, 1, 7, 15, 11, 59, 85, 255, 67, 23, 1321, 2153, 7043, 417, 15719, 59937, 37619, 109331, 0 };
            const std::uint32_t dim20389JoeKuoD6Init[]   =   { 1, 3, 7, 15, 25, 37, 43, 15, 385, 735, 1741, 3655, 4215, 1097, 19519, 44313, 99851, 204717, 0 };
            const std::uint32_t dim20390JoeKuoD6Init[]   =   { 1, 1, 3, 7, 15, 17, 17, 105, 399, 49, 105, 159, 465, 11991, 29797, 23907, 129609, 179013, 0 };
            const std::uint32_t dim20391JoeKuoD6Init[]   =   { 1, 1, 7, 13, 9, 17, 87, 51, 391, 695, 545, 3061, 4499, 2059, 10095, 13847, 68519, 60611, 0 };
            const std::uint32_t dim20392JoeKuoD6Init[]   =   { 1, 3, 3, 1, 31, 7, 11, 233, 231, 189, 1599, 1589, 401, 8759, 17273, 43613, 48709, 253521, 0 };
            const std::uint32_t dim20393JoeKuoD6Init[]   =   { 1, 1, 1, 11, 5, 9, 27, 77, 491, 951, 579, 1635, 3241, 14497, 27149, 45001, 56769, 160731, 0 };
            const std::uint32_t dim20394JoeKuoD6Init[]   =   { 1, 3, 7, 15, 29, 11, 125, 101, 19, 971, 107, 1525, 3939, 7633, 16355, 24727, 19475, 157571, 0 };
            const std::uint32_t dim20395JoeKuoD6Init[]   =   { 1, 1, 1, 9, 25, 7, 35, 187, 321, 483, 1919, 1911, 7869, 12903, 26977, 49419, 24973, 214731, 0 };
            const std::uint32_t dim20396JoeKuoD6Init[]   =   { 1, 1, 5, 3, 23, 1, 11, 143, 315, 1015, 1367, 1555, 1041, 6655, 10481, 49275, 49575, 101061, 0 };
            const std::uint32_t dim20397JoeKuoD6Init[]   =   { 1, 3, 5, 15, 15, 59, 13, 117, 217, 975, 1821, 3829, 1545, 921, 20875, 43305, 18793, 158651, 0 };
            const std::uint32_t dim20398JoeKuoD6Init[]   =   { 1, 3, 3, 11, 23, 23, 91, 7, 29, 613, 1093, 3881, 3301, 3751, 16137, 48277, 119813, 177341, 0 };
            const std::uint32_t dim20399JoeKuoD6Init[]   =   { 1, 3, 3, 15, 7, 37, 115, 19, 147, 585, 1877, 2395, 3343, 9567, 16199, 13969, 89731, 124835, 0 };
            const std::uint32_t dim20400JoeKuoD6Init[]   =   { 1, 1, 5, 7, 29, 3, 59, 141, 375, 527, 1219, 409, 7155, 2823, 32497, 23103, 73187, 53089, 0 };
            const std::uint32_t dim20401JoeKuoD6Init[]   =   { 1, 1, 5, 3, 13, 27, 111, 63, 189, 813, 643, 19, 3461, 13891, 26651, 52395, 74729, 148397, 0 };
            const std::uint32_t dim20402JoeKuoD6Init[]   =   { 1, 3, 5, 1, 27, 61, 97, 227, 123, 829, 1559, 2523, 7737, 6047, 213, 23613, 61571, 7093, 0 };
            const std::uint32_t dim20403JoeKuoD6Init[]   =   { 1, 1, 1, 11, 17, 1, 73, 203, 391, 937, 321, 3431, 7163, 3547, 29467, 65271, 69775, 226405, 0 };
            const std::uint32_t dim20404JoeKuoD6Init[]   =   { 1, 1, 5, 15, 25, 7, 75, 199, 511, 731, 1547, 2127, 1609, 5623, 26771, 29935, 76671, 178683, 0 };
            const std::uint32_t dim20405JoeKuoD6Init[]   =   { 1, 3, 5, 15, 25, 49, 99, 23, 281, 81, 507, 1499, 5235, 9945, 14099, 5993, 319, 178581, 0 };
            const std::uint32_t dim20406JoeKuoD6Init[]   =   { 1, 3, 7, 9, 5, 13, 105, 7, 135, 827, 927, 3463, 839, 7047, 19863, 63859, 13951, 221795, 0 };
            const std::uint32_t dim20407JoeKuoD6Init[]   =   { 1, 1, 1, 13, 7, 21, 59, 9, 467, 299, 1035, 1395, 7413, 7313, 24769, 44043, 50679, 72867, 0 };
            const std::uint32_t dim20408JoeKuoD6Init[]   =   { 1, 1, 7, 1, 31, 33, 95, 155, 429, 413, 493, 2025, 2069, 551, 507, 13515, 3507, 93873, 0 };
            const std::uint32_t dim20409JoeKuoD6Init[]   =   { 1, 1, 3, 5, 3, 33, 109, 1, 299, 727, 495, 2981, 3795, 11467, 27173, 4171, 6859, 129961, 0 };
            const std::uint32_t dim20410JoeKuoD6Init[]   =   { 1, 1, 7, 9, 23, 41, 113, 103, 161, 303, 1565, 2637, 7113, 11635, 13707, 3559, 21007, 250107, 0 };
            const std::uint32_t dim20411JoeKuoD6Init[]   =   { 1, 1, 5, 13, 1, 49, 11, 87, 31, 77, 1847, 1137, 3031, 1943, 28755, 32197, 96043, 152447, 0 };
            const std::uint32_t dim20412JoeKuoD6Init[]   =   { 1, 1, 3, 7, 3, 3, 123, 65, 175, 809, 681, 2135, 5279, 7119, 4573, 19287, 90235, 183391, 0 };
            const std::uint32_t dim20413JoeKuoD6Init[]   =   { 1, 3, 1, 13, 7, 5, 25, 151, 437, 155, 1841, 219, 5641, 12097, 6153, 11, 60315, 169293, 0 };
            const std::uint32_t dim20414JoeKuoD6Init[]   =   { 1, 1, 7, 5, 21, 29, 23, 83, 35, 651, 1507, 635, 3867, 12133, 25523, 55341, 105741, 240349, 0 };
            const std::uint32_t dim20415JoeKuoD6Init[]   =   { 1, 1, 1, 15, 9, 29, 27, 151, 463, 747, 547, 577, 1263, 15235, 6695, 60849, 72231, 175671, 0 };
            const std::uint32_t dim20416JoeKuoD6Init[]   =   { 1, 3, 5, 11, 11, 43, 81, 37, 505, 509, 1325, 3295, 839, 5855, 19795, 1403, 15711, 219481, 0 };
            const std::uint32_t dim20417JoeKuoD6Init[]   =   { 1, 3, 3, 15, 25, 61, 121, 37, 201, 133, 537, 1345, 4213, 13023, 18795, 8949, 84431, 105521, 0 };
            const std::uint32_t dim20418JoeKuoD6Init[]   =   { 1, 3, 7, 11, 13, 51, 87, 245, 357, 7, 699, 2003, 5963, 1399, 69, 19083, 114585, 232313, 0 };
            const std::uint32_t dim20419JoeKuoD6Init[]   =   { 1, 1, 1, 13, 9, 29, 65, 123, 37, 885, 227, 2795, 1037, 10905, 21217, 4081, 77643, 254245, 0 };
            const std::uint32_t dim20420JoeKuoD6Init[]   =   { 1, 3, 1, 3, 25, 23, 71, 189, 253, 785, 1337, 1275, 3285, 1067, 8607, 3883, 119099, 116637, 0 };
            const std::uint32_t dim20421JoeKuoD6Init[]   =   { 1, 1, 1, 15, 19, 43, 17, 89, 257, 175, 1943, 207, 597, 9279, 405, 33209, 65221, 39557, 0 };
            const std::uint32_t dim20422JoeKuoD6Init[]   =   { 1, 1, 7, 5, 7, 47, 127, 11, 197, 871, 23, 1951, 6829, 7831, 5223, 56287, 115649, 114283, 0 };
            const std::uint32_t dim20423JoeKuoD6Init[]   =   { 1, 3, 1, 3, 1, 35, 81, 189, 19, 117, 1683, 469, 8117, 5449, 22871, 5505, 125111, 128717, 0 };
            const std::uint32_t dim20424JoeKuoD6Init[]   =   { 1, 3, 7, 5, 7, 31, 105, 57, 387, 691, 1293, 3103, 2329, 16247, 18357, 55453, 112633, 225641, 0 };
            const std::uint32_t dim20425JoeKuoD6Init[]   =   { 1, 3, 1, 3, 13, 3, 65, 25, 47, 413, 521, 3507, 1793, 14431, 22341, 39813, 46399, 204501, 0 };
            const std::uint32_t dim20426JoeKuoD6Init[]   =   { 1, 3, 1, 1, 31, 37, 21, 45, 261, 665, 1243, 1937, 5001, 3789, 26473, 20153, 107131, 75523, 0 };
            const std::uint32_t dim20427JoeKuoD6Init[]   =   { 1, 3, 5, 15, 27, 61, 109, 139, 19, 583, 353, 445, 53, 67, 20753, 57827, 116527, 55109, 0 };
            const std::uint32_t dim20428JoeKuoD6Init[]   =   { 1, 1, 3, 3, 1, 37, 113, 21, 305, 967, 1703, 2095, 1059, 2843, 22381, 24871, 24765, 52425, 0 };
            const std::uint32_t dim20429JoeKuoD6Init[]   =   { 1, 3, 7, 11, 27, 59, 111, 111, 283, 79, 1227, 3631, 4169, 5671, 7769, 56553, 75503, 206259, 0 };
            const std::uint32_t dim20430JoeKuoD6Init[]   =   { 1, 1, 5, 11, 11, 1, 127, 13, 17, 255, 1383, 2879, 6785, 289, 7061, 53067, 11539, 131405, 0 };
            const std::uint32_t dim20431JoeKuoD6Init[]   =   { 1, 1, 5, 15, 29, 27, 67, 15, 247, 689, 579, 3237, 5279, 13847, 20305, 60237, 115841, 144855, 0 };
            const std::uint32_t dim20432JoeKuoD6Init[]   =   { 1, 1, 5, 1, 9, 25, 75, 11, 83, 1015, 281, 1617, 7449, 10673, 7033, 38839, 113703, 233101, 0 };
            const std::uint32_t dim20433JoeKuoD6Init[]   =   { 1, 3, 3, 3, 23, 41, 81, 109, 199, 969, 935, 1793, 6921, 4013, 9625, 48149, 54395, 1193, 0 };
            const std::uint32_t dim20434JoeKuoD6Init[]   =   { 1, 3, 5, 7, 19, 63, 25, 201, 63, 799, 765, 533, 1417, 3199, 7773, 44247, 112207, 11783, 0 };
            const std::uint32_t dim20435JoeKuoD6Init[]   =   { 1, 3, 1, 11, 7, 25, 87, 159, 491, 749, 1157, 667, 2951, 12019, 22259, 36933, 124159, 176041, 0 };
            const std::uint32_t dim20436JoeKuoD6Init[]   =   { 1, 1, 5, 15, 21, 19, 113, 175, 129, 385, 2025, 2685, 1925, 8547, 4835, 15953, 128023, 236341, 0 };
            const std::uint32_t dim20437JoeKuoD6Init[]   =   { 1, 1, 1, 9, 13, 47, 25, 81, 389, 249, 1857, 1061, 4439, 3717, 16299, 23247, 95275, 222701, 0 };
            const std::uint32_t dim20438JoeKuoD6Init[]   =   { 1, 3, 3, 1, 3, 61, 61, 117, 159, 689, 43, 113, 4203, 7699, 27607, 37195, 63415, 90481, 0 };
            const std::uint32_t dim20439JoeKuoD6Init[]   =   { 1, 3, 1, 5, 11, 49, 73, 13, 307, 655, 645, 2765, 6079, 12687, 22417, 44713, 5247, 40265, 0 };
            const std::uint32_t dim20440JoeKuoD6Init[]   =   { 1, 1, 7, 13, 5, 55, 57, 237, 317, 101, 481, 2515, 707, 6385, 9421, 50557, 92395, 193737, 0 };
            const std::uint32_t dim20441JoeKuoD6Init[]   =   { 1, 3, 5, 1, 27, 35, 65, 107, 63, 57, 1699, 4077, 4279, 8547, 15137, 11533, 117641, 64925, 0 };
            const std::uint32_t dim20442JoeKuoD6Init[]   =   { 1, 1, 5, 1, 13, 7, 7, 141, 305, 191, 2033, 2677, 6025, 12927, 4057, 12047, 60253, 90803, 0 };
            const std::uint32_t dim20443JoeKuoD6Init[]   =   { 1, 1, 7, 3, 1, 9, 63, 233, 185, 97, 913, 187, 4321, 8951, 27669, 27035, 30029, 218725, 0 };
            const std::uint32_t dim20444JoeKuoD6Init[]   =   { 1, 1, 7, 1, 11, 59, 41, 195, 335, 551, 491, 3079, 7777, 4003, 24543, 17165, 103261, 167505, 0 };
            const std::uint32_t dim20445JoeKuoD6Init[]   =   { 1, 1, 3, 3, 9, 59, 37, 185, 289, 845, 1083, 63, 7439, 4677, 29245, 40813, 16295, 45499, 0 };
            const std::uint32_t dim20446JoeKuoD6Init[]   =   { 1, 3, 5, 1, 1, 37, 89, 5, 277, 493, 155, 1641, 5395, 11389, 26247, 2833, 103803, 74447, 0 };
            const std::uint32_t dim20447JoeKuoD6Init[]   =   { 1, 1, 3, 1, 29, 55, 83, 211, 377, 583, 1075, 2679, 7157, 11719, 1653, 5977, 52263, 45531, 0 };
            const std::uint32_t dim20448JoeKuoD6Init[]   =   { 1, 1, 5, 15, 1, 31, 89, 7, 239, 821, 887, 1319, 225, 14555, 5443, 44717, 99803, 241577, 0 };
            const std::uint32_t dim20449JoeKuoD6Init[]   =   { 1, 3, 5, 11, 7, 23, 81, 161, 67, 1011, 177, 2837, 7767, 14385, 29415, 9377, 7407, 128403, 0 };
            const std::uint32_t dim20450JoeKuoD6Init[]   =   { 1, 1, 7, 11, 3, 13, 13, 237, 199, 601, 481, 3809, 6591, 8497, 25361, 22547, 28317, 22961, 0 };
            const std::uint32_t dim20451JoeKuoD6Init[]   =   { 1, 3, 1, 1, 31, 29, 105, 161, 483, 391, 321, 1087, 4149, 8803, 22291, 24611, 114447, 33645, 0 };
            const std::uint32_t dim20452JoeKuoD6Init[]   =   { 1, 3, 1, 11, 1, 47, 41, 45, 287, 503, 169, 2265, 1835, 6609, 25245, 7069, 61137, 160653, 0 };
            const std::uint32_t dim20453JoeKuoD6Init[]   =   { 1, 1, 7, 13, 11, 39, 29, 39, 489, 205, 741, 2871, 377, 10679, 11689, 50947, 85309, 95697, 0 };
            const std::uint32_t dim20454JoeKuoD6Init[]   =   { 1, 3, 7, 7, 23, 19, 103, 15, 79, 425, 369, 2009, 4417, 11031, 2113, 36969, 73241, 120903, 0 };
            const std::uint32_t dim20455JoeKuoD6Init[]   =   { 1, 3, 1, 7, 27, 9, 43, 33, 123, 895, 223, 1045, 2701, 3339, 12099, 24449, 52973, 175671, 0 };
            const std::uint32_t dim20456JoeKuoD6Init[]   =   { 1, 3, 5, 5, 3, 1, 13, 117, 429, 167, 1361, 2299, 7565, 1153, 9259, 29209, 25747, 71005, 0 };
            const std::uint32_t dim20457JoeKuoD6Init[]   =   { 1, 3, 1, 15, 7, 7, 13, 209, 73, 523, 1549, 2545, 5583, 10209, 27205, 41243, 14217, 208993, 0 };
            const std::uint32_t dim20458JoeKuoD6Init[]   =   { 1, 3, 5, 5, 3, 29, 99, 255, 479, 297, 1319, 2171, 7321, 14425, 15869, 44449, 10917, 171165, 0 };
            const std::uint32_t dim20459JoeKuoD6Init[]   =   { 1, 3, 3, 11, 13, 49, 29, 95, 79, 987, 161, 859, 6503, 8839, 14131, 30249, 16183, 40257, 0 };
            const std::uint32_t dim20460JoeKuoD6Init[]   =   { 1, 3, 3, 11, 27, 7, 27, 33, 255, 847, 789, 3897, 2599, 16107, 22379, 1853, 102713, 197547, 0 };
            const std::uint32_t dim20461JoeKuoD6Init[]   =   { 1, 1, 3, 9, 29, 11, 107, 227, 35, 183, 639, 1585, 313, 1451, 19789, 13855, 94277, 85569, 0 };
            const std::uint32_t dim20462JoeKuoD6Init[]   =   { 1, 3, 7, 7, 25, 33, 101, 49, 137, 457, 2027, 3317, 1961, 6097, 739, 12875, 69503, 95453, 0 };
            const std::uint32_t dim20463JoeKuoD6Init[]   =   { 1, 3, 3, 11, 29, 13, 127, 3, 31, 319, 1341, 927, 5067, 13891, 31265, 41381, 49341, 160343, 0 };
            const std::uint32_t dim20464JoeKuoD6Init[]   =   { 1, 1, 3, 15, 31, 21, 93, 155, 471, 707, 1395, 2995, 867, 10353, 8137, 44267, 24823, 6113, 0 };
            const std::uint32_t dim20465JoeKuoD6Init[]   =   { 1, 3, 1, 7, 7, 33, 83, 79, 349, 687, 1045, 1183, 4441, 15199, 1953, 36395, 84691, 134939, 0 };
            const std::uint32_t dim20466JoeKuoD6Init[]   =   { 1, 1, 3, 15, 13, 21, 41, 105, 189, 439, 1171, 4005, 7641, 1597, 24317, 58749, 35539, 220647, 0 };
            const std::uint32_t dim20467JoeKuoD6Init[]   =   { 1, 1, 3, 15, 13, 39, 49, 5, 461, 613, 1633, 1951, 7959, 5733, 10061, 18829, 49505, 90033, 0 };
            const std::uint32_t dim20468JoeKuoD6Init[]   =   { 1, 3, 5, 5, 29, 25, 19, 227, 379, 525, 687, 2629, 7729, 4791, 5911, 14481, 49063, 216669, 0 };
            const std::uint32_t dim20469JoeKuoD6Init[]   =   { 1, 3, 7, 7, 7, 63, 93, 227, 79, 165, 1971, 1695, 4485, 6009, 8769, 12861, 83653, 27667, 0 };
            const std::uint32_t dim20470JoeKuoD6Init[]   =   { 1, 1, 5, 5, 25, 11, 23, 89, 363, 491, 459, 4063, 3787, 9375, 28011, 44757, 56441, 116609, 0 };
            const std::uint32_t dim20471JoeKuoD6Init[]   =   { 1, 3, 5, 9, 7, 53, 43, 149, 435, 35, 135, 1759, 3197, 7749, 12731, 28295, 25901, 125847, 0 };
            const std::uint32_t dim20472JoeKuoD6Init[]   =   { 1, 1, 3, 5, 15, 15, 1, 215, 307, 711, 1971, 2795, 677, 11921, 10303, 37997, 6653, 51295, 0 };
            const std::uint32_t dim20473JoeKuoD6Init[]   =   { 1, 1, 5, 15, 1, 59, 75, 195, 51, 215, 1303, 3023, 8023, 10951, 13015, 23513, 37029, 23581, 0 };
            const std::uint32_t dim20474JoeKuoD6Init[]   =   { 1, 1, 1, 3, 27, 3, 77, 165, 97, 499, 937, 1129, 6649, 11305, 27763, 32849, 78251, 210407, 0 };
            const std::uint32_t dim20475JoeKuoD6Init[]   =   { 1, 3, 3, 3, 9, 21, 19, 197, 339, 53, 1875, 1057, 3485, 14645, 13417, 39307, 81437, 45857, 0 };
            const std::uint32_t dim20476JoeKuoD6Init[]   =   { 1, 1, 1, 5, 19, 5, 95, 205, 399, 699, 819, 1927, 7913, 8109, 1223, 28595, 397, 81051, 0 };
            const std::uint32_t dim20477JoeKuoD6Init[]   =   { 1, 3, 7, 13, 23, 11, 37, 167, 189, 813, 1199, 3545, 655, 13239, 10469, 33895, 119025, 185361, 0 };
            const std::uint32_t dim20478JoeKuoD6Init[]   =   { 1, 1, 5, 11, 9, 13, 41, 37, 443, 269, 1199, 1347, 7081, 11273, 14389, 64083, 117901, 51903, 0 };
            const std::uint32_t dim20479JoeKuoD6Init[]   =   { 1, 1, 3, 13, 5, 17, 117, 151, 155, 637, 731, 1839, 855, 9749, 19529, 18101, 20341, 21941, 0 };
            const std::uint32_t dim20480JoeKuoD6Init[]   =   { 1, 1, 1, 11, 15, 17, 35, 9, 91, 907, 667, 853, 1455, 10097, 31277, 749, 47089, 219517, 0 };
            const std::uint32_t dim20481JoeKuoD6Init[]   =   { 1, 3, 7, 1, 27, 31, 9, 145, 309, 811, 5, 2645, 7851, 1953, 21427, 18805, 108755, 77215, 0 };
            const std::uint32_t dim20482JoeKuoD6Init[]   =   { 1, 1, 7, 3, 21, 7, 25, 233, 145, 1015, 43, 2205, 4735, 13257, 24001, 50469, 42567, 253745, 0 };
            const std::uint32_t dim20483JoeKuoD6Init[]   =   { 1, 3, 1, 15, 3, 53, 51, 45, 397, 379, 641, 895, 7569, 15783, 23923, 6147, 121395, 261853, 0 };
            const std::uint32_t dim20484JoeKuoD6Init[]   =   { 1, 1, 1, 1, 23, 47, 35, 125, 289, 65, 1875, 2309, 519, 5435, 5271, 25319, 14557, 19389, 0 };
            const std::uint32_t dim20485JoeKuoD6Init[]   =   { 1, 3, 5, 7, 27, 43, 15, 61, 357, 791, 1781, 3671, 3911, 1325, 5607, 44107, 67873, 119849, 0 };
            const std::uint32_t dim20486JoeKuoD6Init[]   =   { 1, 3, 1, 5, 25, 37, 105, 51, 491, 407, 475, 1763, 1425, 14883, 31435, 48979, 120667, 131089, 0 };
            const std::uint32_t dim20487JoeKuoD6Init[]   =   { 1, 3, 5, 13, 1, 51, 109, 161, 215, 871, 185, 2389, 7977, 6705, 14045, 45569, 44557, 114795, 0 };
            const std::uint32_t dim20488JoeKuoD6Init[]   =   { 1, 3, 7, 11, 17, 21, 111, 183, 343, 593, 447, 3995, 759, 3709, 32655, 30141, 127225, 120899, 0 };
            const std::uint32_t dim20489JoeKuoD6Init[]   =   { 1, 1, 5, 3, 17, 3, 69, 25, 113, 897, 1933, 2717, 2003, 5847, 2541, 62415, 50975, 97903, 0 };
            const std::uint32_t dim20490JoeKuoD6Init[]   =   { 1, 1, 1, 1, 9, 35, 107, 81, 257, 57, 1719, 4049, 1237, 10659, 4689, 20887, 90791, 251911, 0 };
            const std::uint32_t dim20491JoeKuoD6Init[]   =   { 1, 1, 7, 11, 1, 49, 83, 213, 169, 169, 825, 2983, 5833, 2413, 32165, 47459, 129021, 156217, 0 };
            const std::uint32_t dim20492JoeKuoD6Init[]   =   { 1, 1, 5, 13, 15, 39, 61, 93, 407, 553, 839, 4035, 6609, 6327, 945, 49625, 127867, 240161, 0 };
            const std::uint32_t dim20493JoeKuoD6Init[]   =   { 1, 1, 1, 15, 23, 47, 21, 235, 81, 431, 1819, 1141, 7973, 4623, 4539, 23201, 83111, 230857, 0 };
            const std::uint32_t dim20494JoeKuoD6Init[]   =   { 1, 3, 3, 15, 9, 15, 15, 173, 29, 803, 1453, 2621, 8095, 6639, 6607, 21471, 44785, 122271, 0 };
            const std::uint32_t dim20495JoeKuoD6Init[]   =   { 1, 3, 3, 7, 21, 5, 127, 203, 43, 581, 1925, 165, 4615, 9141, 18563, 54413, 71559, 172791, 0 };
            const std::uint32_t dim20496JoeKuoD6Init[]   =   { 1, 3, 3, 3, 27, 31, 55, 3, 381, 971, 1087, 2659, 139, 10935, 9189, 3445, 15071, 218873, 0 };
            const std::uint32_t dim20497JoeKuoD6Init[]   =   { 1, 3, 1, 3, 1, 57, 47, 71, 85, 335, 207, 225, 2931, 14721, 21431, 17199, 745, 177403, 0 };
            const std::uint32_t dim20498JoeKuoD6Init[]   =   { 1, 3, 1, 7, 7, 17, 21, 57, 345, 29, 1147, 1179, 7371, 14725, 27445, 62061, 16483, 112489, 0 };
            const std::uint32_t dim20499JoeKuoD6Init[]   =   { 1, 3, 7, 15, 23, 11, 91, 1, 1, 117, 1665, 3899, 5683, 14497, 25633, 6233, 104029, 22155, 0 };
            const std::uint32_t dim20500JoeKuoD6Init[]   =   { 1, 3, 5, 9, 1, 27, 15, 187, 37, 329, 585, 729, 5651, 15715, 4339, 1899, 90611, 195643, 0 };
            const std::uint32_t dim20501JoeKuoD6Init[]   =   { 1, 1, 3, 11, 1, 45, 95, 103, 13, 83, 319, 2295, 6333, 13469, 19237, 55985, 129725, 141699, 0 };
            const std::uint32_t dim20502JoeKuoD6Init[]   =   { 1, 1, 5, 11, 7, 41, 97, 159, 511, 617, 1545, 3023, 7919, 8437, 8345, 16701, 69053, 105047, 0 };
            const std::uint32_t dim20503JoeKuoD6Init[]   =   { 1, 3, 3, 11, 29, 35, 23, 95, 277, 931, 857, 3887, 4597, 10841, 12947, 18009, 61499, 242827, 0 };
            const std::uint32_t dim20504JoeKuoD6Init[]   =   { 1, 1, 3, 3, 7, 63, 35, 161, 125, 637, 149, 1045, 3297, 16213, 1543, 8073, 80373, 61507, 0 };
            const std::uint32_t dim20505JoeKuoD6Init[]   =   { 1, 1, 7, 5, 31, 43, 113, 189, 181, 659, 1971, 3309, 4237, 4279, 31563, 29429, 17443, 154385, 0 };
            const std::uint32_t dim20506JoeKuoD6Init[]   =   { 1, 1, 1, 13, 19, 43, 99, 91, 47, 477, 153, 3295, 6281, 779, 17169, 343, 1723, 171133, 0 };
            const std::uint32_t dim20507JoeKuoD6Init[]   =   { 1, 1, 1, 15, 9, 35, 123, 45, 417, 631, 1415, 1835, 3063, 897, 18947, 62477, 12759, 97831, 0 };
            const std::uint32_t dim20508JoeKuoD6Init[]   =   { 1, 1, 3, 13, 31, 1, 31, 139, 411, 605, 1829, 303, 3891, 15807, 7335, 44833, 87427, 62183, 0 };
            const std::uint32_t dim20509JoeKuoD6Init[]   =   { 1, 1, 3, 13, 29, 55, 97, 107, 241, 981, 1281, 3295, 6825, 15865, 4221, 24695, 54203, 252069, 0 };
            const std::uint32_t dim20510JoeKuoD6Init[]   =   { 1, 3, 7, 13, 1, 3, 33, 165, 483, 813, 127, 1717, 8077, 3521, 23465, 41705, 2769, 173233, 0 };
            const std::uint32_t dim20511JoeKuoD6Init[]   =   { 1, 3, 1, 11, 11, 51, 39, 125, 375, 825, 1775, 2923, 4903, 4779, 907, 47787, 22293, 169631, 0 };
            const std::uint32_t dim20512JoeKuoD6Init[]   =   { 1, 3, 5, 5, 13, 27, 43, 229, 267, 153, 567, 3403, 2103, 6203, 29629, 29715, 116735, 122515, 0 };
            const std::uint32_t dim20513JoeKuoD6Init[]   =   { 1, 3, 5, 13, 3, 3, 15, 5, 345, 343, 691, 3703, 361, 2019, 9309, 26909, 22897, 103555, 0 };
            const std::uint32_t dim20514JoeKuoD6Init[]   =   { 1, 3, 1, 11, 9, 25, 123, 235, 131, 469, 1749, 3681, 3841, 10157, 15183, 61413, 42207, 170359, 0 };
            const std::uint32_t dim20515JoeKuoD6Init[]   =   { 1, 1, 7, 3, 13, 9, 7, 191, 239, 417, 817, 1381, 1179, 2719, 21025, 17429, 50295, 196485, 0 };
            const std::uint32_t dim20516JoeKuoD6Init[]   =   { 1, 1, 7, 9, 9, 31, 123, 229, 381, 569, 513, 1617, 6141, 9717, 31769, 30159, 113697, 254237, 0 };
            const std::uint32_t dim20517JoeKuoD6Init[]   =   { 1, 1, 1, 15, 31, 43, 37, 17, 283, 905, 297, 1317, 1883, 11313, 5653, 55655, 121029, 149831, 0 };
            const std::uint32_t dim20518JoeKuoD6Init[]   =   { 1, 1, 1, 7, 7, 47, 83, 101, 497, 465, 1133, 3877, 5371, 3355, 17161, 50185, 120837, 255103, 0 };
            const std::uint32_t dim20519JoeKuoD6Init[]   =   { 1, 1, 3, 5, 5, 19, 3, 251, 433, 303, 1193, 1263, 2139, 473, 10725, 57725, 111411, 133687, 0 };
            const std::uint32_t dim20520JoeKuoD6Init[]   =   { 1, 1, 1, 7, 3, 1, 99, 115, 481, 395, 115, 1699, 953, 2807, 7227, 52781, 2855, 161159, 0 };
            const std::uint32_t dim20521JoeKuoD6Init[]   =   { 1, 1, 5, 9, 25, 25, 85, 3, 451, 847, 837, 3669, 4717, 3661, 29111, 43735, 49445, 100379, 0 };
            const std::uint32_t dim20522JoeKuoD6Init[]   =   { 1, 1, 7, 9, 19, 61, 67, 123, 195, 483, 1741, 2719, 7809, 5035, 30689, 21325, 56191, 46127, 0 };
            const std::uint32_t dim20523JoeKuoD6Init[]   =   { 1, 1, 3, 11, 15, 39, 101, 27, 103, 807, 1557, 1647, 1285, 16169, 20203, 57153, 60749, 71361, 0 };
            const std::uint32_t dim20524JoeKuoD6Init[]   =   { 1, 3, 3, 3, 19, 1, 93, 31, 105, 925, 689, 3061, 7451, 12667, 27179, 36295, 61011, 90321, 0 };
            const std::uint32_t dim20525JoeKuoD6Init[]   =   { 1, 3, 7, 15, 19, 35, 47, 241, 261, 935, 1033, 751, 6519, 6911, 13519, 2539, 40285, 81535, 0 };
            const std::uint32_t dim20526JoeKuoD6Init[]   =   { 1, 1, 7, 13, 17, 31, 71, 135, 167, 5, 673, 2909, 4377, 3453, 31289, 38081, 21993, 192933, 0 };
            const std::uint32_t dim20527JoeKuoD6Init[]   =   { 1, 1, 5, 15, 23, 49, 85, 127, 13, 849, 1661, 2099, 3479, 3613, 21723, 58147, 56321, 203171, 0 };
            const std::uint32_t dim20528JoeKuoD6Init[]   =   { 1, 1, 7, 15, 23, 63, 3, 207, 445, 573, 1419, 1161, 2237, 1251, 23387, 65259, 81447, 74555, 0 };
            const std::uint32_t dim20529JoeKuoD6Init[]   =   { 1, 3, 5, 3, 25, 61, 37, 25, 287, 969, 37, 1615, 7923, 4457, 27611, 8519, 113957, 237427, 0 };
            const std::uint32_t dim20530JoeKuoD6Init[]   =   { 1, 3, 5, 11, 11, 25, 117, 169, 149, 701, 139, 2835, 6029, 9067, 841, 51707, 9287, 115825, 0 };
            const std::uint32_t dim20531JoeKuoD6Init[]   =   { 1, 1, 1, 13, 31, 5, 9, 5, 313, 1023, 551, 3635, 6765, 13379, 29135, 39737, 80913, 256355, 0 };
            const std::uint32_t dim20532JoeKuoD6Init[]   =   { 1, 3, 1, 13, 9, 23, 105, 117, 181, 211, 755, 555, 2763, 13965, 14743, 63725, 16377, 203435, 0 };
            const std::uint32_t dim20533JoeKuoD6Init[]   =   { 1, 3, 1, 15, 11, 45, 111, 147, 471, 321, 381, 2921, 6423, 629, 25117, 51213, 126941, 181931, 0 };
            const std::uint32_t dim20534JoeKuoD6Init[]   =   { 1, 1, 1, 11, 1, 49, 127, 105, 315, 1, 859, 1223, 5967, 2521, 14491, 58399, 45155, 192567, 0 };
            const std::uint32_t dim20535JoeKuoD6Init[]   =   { 1, 1, 3, 9, 19, 21, 73, 93, 95, 307, 293, 3243, 4765, 2253, 16775, 29861, 3785, 90357, 0 };
            const std::uint32_t dim20536JoeKuoD6Init[]   =   { 1, 1, 3, 7, 3, 53, 33, 167, 165, 509, 1133, 169, 6951, 7715, 26317, 5249, 86235, 39649, 0 };
            const std::uint32_t dim20537JoeKuoD6Init[]   =   { 1, 1, 5, 5, 3, 47, 105, 89, 201, 1003, 877, 635, 2225, 6391, 21247, 5707, 1233, 87055, 0 };
            const std::uint32_t dim20538JoeKuoD6Init[]   =   { 1, 1, 1, 1, 9, 39, 61, 201, 435, 843, 1245, 533, 1757, 1117, 19687, 54817, 32495, 228865, 0 };
            const std::uint32_t dim20539JoeKuoD6Init[]   =   { 1, 3, 1, 1, 3, 61, 63, 117, 143, 217, 435, 1977, 2647, 7631, 12969, 50211, 26483, 256329, 0 };
            const std::uint32_t dim20540JoeKuoD6Init[]   =   { 1, 3, 3, 9, 21, 25, 113, 243, 457, 143, 833, 1505, 3071, 1845, 17867, 58205, 103819, 185215, 0 };
            const std::uint32_t dim20541JoeKuoD6Init[]   =   { 1, 1, 5, 7, 23, 51, 11, 117, 195, 535, 685, 31, 3037, 9719, 22811, 42959, 21021, 126297, 0 };
            const std::uint32_t dim20542JoeKuoD6Init[]   =   { 1, 3, 3, 1, 1, 17, 107, 245, 257, 547, 887, 45, 5243, 2439, 22191, 19503, 2143, 75187, 0 };
            const std::uint32_t dim20543JoeKuoD6Init[]   =   { 1, 3, 7, 9, 11, 27, 123, 197, 353, 151, 1115, 403, 1105, 7425, 7463, 42065, 116187, 154537, 0 };
            const std::uint32_t dim20544JoeKuoD6Init[]   =   { 1, 3, 5, 15, 23, 5, 49, 177, 223, 615, 1255, 2081, 321, 8733, 19549, 53027, 275, 62739, 0 };
            const std::uint32_t dim20545JoeKuoD6Init[]   =   { 1, 3, 7, 1, 17, 61, 3, 233, 249, 763, 369, 555, 1621, 7221, 22575, 13295, 99793, 233635, 0 };
            const std::uint32_t dim20546JoeKuoD6Init[]   =   { 1, 1, 3, 1, 27, 41, 125, 113, 47, 583, 543, 453, 1213, 14187, 1645, 35761, 110051, 197081, 0 };
            const std::uint32_t dim20547JoeKuoD6Init[]   =   { 1, 1, 7, 9, 29, 43, 105, 125, 489, 135, 153, 2279, 4079, 6731, 12055, 60181, 82563, 173991, 0 };
            const std::uint32_t dim20548JoeKuoD6Init[]   =   { 1, 3, 7, 3, 29, 1, 67, 151, 127, 625, 113, 2127, 6723, 12359, 28609, 60605, 20375, 120129, 0 };
            const std::uint32_t dim20549JoeKuoD6Init[]   =   { 1, 1, 5, 7, 9, 13, 27, 171, 129, 199, 303, 4045, 2047, 8887, 22233, 57571, 40545, 36479, 0 };
            const std::uint32_t dim20550JoeKuoD6Init[]   =   { 1, 3, 1, 7, 1, 5, 127, 203, 213, 691, 1155, 27, 5409, 13519, 6747, 42371, 37089, 145855, 0 };
            const std::uint32_t dim20551JoeKuoD6Init[]   =   { 1, 3, 3, 9, 3, 33, 119, 25, 337, 715, 1093, 987, 7157, 14975, 28595, 19021, 1243, 148707, 0 };
            const std::uint32_t dim20552JoeKuoD6Init[]   =   { 1, 3, 1, 13, 3, 41, 81, 151, 23, 787, 181, 2357, 5077, 1997, 6451, 25505, 44875, 198341, 0 };
            const std::uint32_t dim20553JoeKuoD6Init[]   =   { 1, 1, 7, 3, 5, 15, 9, 169, 337, 487, 1325, 1505, 465, 2339, 20747, 8269, 96875, 108985, 0 };
            const std::uint32_t dim20554JoeKuoD6Init[]   =   { 1, 3, 1, 7, 23, 7, 113, 181, 25, 989, 1649, 1, 823, 6793, 18729, 3599, 97951, 239609, 0 };
            const std::uint32_t dim20555JoeKuoD6Init[]   =   { 1, 3, 7, 7, 3, 63, 63, 207, 419, 355, 1133, 2979, 2071, 11699, 32565, 61347, 106475, 16893, 0 };
            const std::uint32_t dim20556JoeKuoD6Init[]   =   { 1, 1, 7, 5, 7, 3, 119, 133, 189, 341, 1571, 1559, 4309, 16203, 22459, 21019, 80375, 3453, 0 };
            const std::uint32_t dim20557JoeKuoD6Init[]   =   { 1, 1, 3, 11, 21, 21, 45, 69, 485, 21, 727, 703, 5209, 14745, 3437, 54603, 104357, 151207, 0 };
            const std::uint32_t dim20558JoeKuoD6Init[]   =   { 1, 3, 7, 5, 25, 17, 13, 147, 329, 93, 121, 315, 2779, 6921, 425, 50441, 1133, 252291, 0 };
            const std::uint32_t dim20559JoeKuoD6Init[]   =   { 1, 1, 3, 5, 5, 51, 15, 135, 323, 841, 409, 1067, 3243, 4207, 6833, 59329, 90545, 116661, 0 };
            const std::uint32_t dim20560JoeKuoD6Init[]   =   { 1, 1, 3, 15, 25, 7, 43, 147, 153, 947, 79, 1897, 4519, 14441, 27181, 38517, 71673, 158597, 0 };
            const std::uint32_t dim20561JoeKuoD6Init[]   =   { 1, 3, 3, 3, 3, 47, 109, 111, 273, 271, 741, 3999, 649, 7367, 14933, 11785, 92709, 133815, 0 };
            const std::uint32_t dim20562JoeKuoD6Init[]   =   { 1, 1, 3, 13, 5, 41, 55, 15, 409, 355, 1255, 3043, 7503, 3523, 4261, 48927, 119901, 149411, 0 };
            const std::uint32_t dim20563JoeKuoD6Init[]   =   { 1, 1, 5, 1, 11, 57, 3, 149, 409, 287, 909, 3541, 4243, 4485, 3611, 63213, 102575, 49863, 0 };
            const std::uint32_t dim20564JoeKuoD6Init[]   =   { 1, 1, 3, 7, 15, 55, 119, 185, 511, 301, 237, 3701, 3195, 1323, 27511, 44635, 45363, 117683, 0 };
            const std::uint32_t dim20565JoeKuoD6Init[]   =   { 1, 3, 3, 11, 3, 61, 125, 15, 235, 819, 467, 1097, 1055, 16343, 8329, 37807, 38663, 145625, 0 };
            const std::uint32_t dim20566JoeKuoD6Init[]   =   { 1, 1, 7, 1, 25, 49, 117, 163, 413, 509, 63, 1313, 5113, 6505, 25475, 12059, 88021, 168037, 0 };
            const std::uint32_t dim20567JoeKuoD6Init[]   =   { 1, 3, 3, 9, 9, 37, 15, 185, 359, 231, 1483, 2999, 773, 10375, 27103, 39899, 100187, 54485, 0 };
            const std::uint32_t dim20568JoeKuoD6Init[]   =   { 1, 3, 3, 1, 13, 63, 111, 79, 133, 425, 1491, 3735, 533, 13417, 5161, 11455, 16907, 132267, 0 };
            const std::uint32_t dim20569JoeKuoD6Init[]   =   { 1, 3, 1, 15, 15, 47, 57, 157, 453, 681, 1811, 1685, 4329, 131, 22763, 1017, 66637, 1673, 0 };
            const std::uint32_t dim20570JoeKuoD6Init[]   =   { 1, 3, 7, 3, 31, 5, 105, 101, 431, 983, 1333, 845, 7369, 15041, 6527, 8617, 61911, 137513, 0 };
            const std::uint32_t dim20571JoeKuoD6Init[]   =   { 1, 3, 7, 15, 3, 45, 57, 23, 393, 495, 769, 215, 3611, 12907, 20637, 52997, 88345, 37961, 0 };
            const std::uint32_t dim20572JoeKuoD6Init[]   =   { 1, 3, 5, 7, 31, 3, 85, 249, 353, 559, 1803, 959, 4625, 9413, 22339, 6071, 124765, 43973, 0 };
            const std::uint32_t dim20573JoeKuoD6Init[]   =   { 1, 3, 1, 9, 31, 15, 109, 197, 179, 293, 457, 709, 627, 7743, 1997, 59625, 36919, 252849, 0 };
            const std::uint32_t dim20574JoeKuoD6Init[]   =   { 1, 1, 7, 11, 17, 21, 89, 11, 431, 617, 1029, 2649, 1725, 2723, 18367, 46103, 108063, 221855, 0 };
            const std::uint32_t dim20575JoeKuoD6Init[]   =   { 1, 3, 7, 1, 29, 7, 81, 187, 353, 807, 965, 3655, 3255, 9139, 28619, 32127, 107901, 139099, 0 };
            const std::uint32_t dim20576JoeKuoD6Init[]   =   { 1, 1, 5, 3, 17, 9, 39, 59, 431, 829, 525, 1885, 2387, 13381, 5271, 29739, 80413, 240595, 0 };
            const std::uint32_t dim20577JoeKuoD6Init[]   =   { 1, 3, 1, 5, 1, 5, 25, 9, 193, 971, 681, 2921, 3271, 3891, 20123, 37477, 33141, 82481, 0 };
            const std::uint32_t dim20578JoeKuoD6Init[]   =   { 1, 1, 3, 5, 1, 63, 77, 93, 63, 399, 1945, 387, 5457, 7339, 13279, 34119, 129903, 12621, 0 };
            const std::uint32_t dim20579JoeKuoD6Init[]   =   { 1, 3, 3, 11, 17, 11, 117, 189, 473, 23, 13, 1261, 2153, 12181, 21075, 33179, 43355, 168293, 0 };
            const std::uint32_t dim20580JoeKuoD6Init[]   =   { 1, 3, 5, 11, 21, 13, 73, 227, 211, 939, 885, 2091, 1123, 14809, 15705, 56675, 58087, 1451, 0 };
            const std::uint32_t dim20581JoeKuoD6Init[]   =   { 1, 3, 7, 1, 15, 15, 101, 235, 287, 675, 1741, 3885, 6211, 14817, 10235, 29289, 60401, 27639, 0 };
            const std::uint32_t dim20582JoeKuoD6Init[]   =   { 1, 3, 5, 13, 13, 7, 117, 31, 143, 505, 1823, 2841, 2133, 7305, 14093, 14229, 85179, 136793, 0 };
            const std::uint32_t dim20583JoeKuoD6Init[]   =   { 1, 1, 3, 15, 27, 15, 67, 237, 315, 793, 207, 3781, 5201, 13191, 9601, 44041, 116097, 178543, 0 };
            const std::uint32_t dim20584JoeKuoD6Init[]   =   { 1, 3, 1, 9, 9, 47, 53, 225, 109, 831, 1757, 349, 6353, 15417, 16395, 36295, 10901, 122349, 0 };
            const std::uint32_t dim20585JoeKuoD6Init[]   =   { 1, 1, 1, 1, 1, 17, 109, 13, 123, 537, 1859, 3717, 4441, 4271, 29017, 13601, 18533, 216695, 0 };
            const std::uint32_t dim20586JoeKuoD6Init[]   =   { 1, 3, 3, 13, 31, 23, 45, 233, 29, 295, 761, 757, 777, 3499, 26715, 24153, 113777, 256337, 0 };
            const std::uint32_t dim20587JoeKuoD6Init[]   =   { 1, 3, 5, 7, 23, 57, 37, 179, 511, 897, 2031, 1285, 3957, 15085, 19993, 28819, 39959, 187445, 0 };
            const std::uint32_t dim20588JoeKuoD6Init[]   =   { 1, 3, 1, 15, 25, 41, 121, 227, 433, 859, 357, 3107, 3241, 879, 10763, 59473, 73145, 258493, 0 };
            const std::uint32_t dim20589JoeKuoD6Init[]   =   { 1, 3, 3, 5, 13, 9, 85, 117, 347, 161, 995, 549, 5443, 9057, 28931, 57549, 27523, 54717, 0 };
            const std::uint32_t dim20590JoeKuoD6Init[]   =   { 1, 1, 5, 13, 13, 33, 97, 37, 55, 367, 403, 2361, 5717, 4433, 26921, 14227, 69445, 100337, 0 };
            const std::uint32_t dim20591JoeKuoD6Init[]   =   { 1, 3, 5, 7, 1, 41, 89, 165, 163, 1, 685, 3577, 1079, 1057, 125, 35853, 8387, 113035, 0 };
            const std::uint32_t dim20592JoeKuoD6Init[]   =   { 1, 3, 3, 13, 3, 59, 119, 51, 325, 205, 821, 1417, 2097, 13725, 31785, 53803, 15737, 2013, 0 };
            const std::uint32_t dim20593JoeKuoD6Init[]   =   { 1, 3, 7, 7, 1, 45, 95, 221, 249, 65, 1479, 2163, 5761, 15321, 8013, 25771, 110897, 214127, 0 };
            const std::uint32_t dim20594JoeKuoD6Init[]   =   { 1, 3, 3, 5, 25, 11, 27, 29, 95, 955, 1989, 3775, 609, 7073, 4571, 38857, 92205, 156209, 0 };
            const std::uint32_t dim20595JoeKuoD6Init[]   =   { 1, 3, 1, 13, 29, 57, 97, 47, 499, 641, 587, 2125, 2257, 13911, 13993, 1715, 46233, 181279, 0 };
            const std::uint32_t dim20596JoeKuoD6Init[]   =   { 1, 1, 7, 13, 7, 55, 69, 235, 379, 269, 1969, 2733, 3677, 1707, 26999, 64041, 98111, 138691, 0 };
            const std::uint32_t dim20597JoeKuoD6Init[]   =   { 1, 1, 3, 5, 27, 63, 65, 251, 413, 903, 1307, 2941, 5649, 11271, 1935, 49389, 37995, 218197, 0 };
            const std::uint32_t dim20598JoeKuoD6Init[]   =   { 1, 3, 3, 13, 7, 1, 45, 225, 13, 169, 581, 1657, 117, 10251, 23435, 40379, 127085, 88185, 0 };
            const std::uint32_t dim20599JoeKuoD6Init[]   =   { 1, 1, 7, 5, 21, 63, 69, 37, 459, 115, 1403, 1939, 6437, 13149, 3597, 50115, 129075, 260613, 0 };
            const std::uint32_t dim20600JoeKuoD6Init[]   =   { 1, 1, 3, 5, 29, 57, 15, 223, 131, 907, 1561, 1103, 4355, 2763, 6359, 55401, 1751, 53143, 0 };
            const std::uint32_t dim20601JoeKuoD6Init[]   =   { 1, 1, 7, 11, 15, 5, 17, 159, 505, 407, 1873, 2501, 2203, 12559, 5123, 53281, 29307, 16215, 0 };
            const std::uint32_t dim20602JoeKuoD6Init[]   =   { 1, 1, 1, 15, 9, 41, 77, 145, 325, 529, 1939, 3835, 3109, 12215, 18323, 2551, 89793, 94745, 0 };
            const std::uint32_t dim20603JoeKuoD6Init[]   =   { 1, 3, 1, 9, 21, 5, 7, 57, 99, 1005, 1211, 4063, 6851, 7653, 29283, 15463, 121289, 187055, 0 };
            const std::uint32_t dim20604JoeKuoD6Init[]   =   { 1, 1, 3, 3, 13, 11, 17, 125, 173, 283, 1419, 2533, 6875, 16031, 26633, 51027, 27343, 74257, 0 };
            const std::uint32_t dim20605JoeKuoD6Init[]   =   { 1, 1, 3, 11, 29, 49, 87, 19, 367, 941, 983, 1041, 8099, 8735, 30123, 62665, 87051, 98745, 0 };
            const std::uint32_t dim20606JoeKuoD6Init[]   =   { 1, 1, 1, 15, 25, 57, 97, 177, 467, 181, 923, 3833, 5405, 14335, 23495, 48323, 70331, 136825, 0 };
            const std::uint32_t dim20607JoeKuoD6Init[]   =   { 1, 1, 1, 13, 21, 17, 29, 237, 305, 117, 1077, 2999, 1879, 6875, 19321, 10999, 130513, 160883, 0 };
            const std::uint32_t dim20608JoeKuoD6Init[]   =   { 1, 3, 7, 15, 19, 47, 89, 153, 287, 7, 1429, 1507, 2853, 4197, 11195, 33891, 59063, 189601, 0 };
            const std::uint32_t dim20609JoeKuoD6Init[]   =   { 1, 1, 3, 15, 31, 5, 113, 71, 13, 925, 147, 451, 5701, 13671, 13943, 13799, 59627, 115715, 0 };
            const std::uint32_t dim20610JoeKuoD6Init[]   =   { 1, 1, 1, 5, 13, 25, 51, 11, 409, 393, 1479, 2583, 3101, 303, 17609, 10653, 69107, 150459, 0 };
            const std::uint32_t dim20611JoeKuoD6Init[]   =   { 1, 1, 5, 7, 21, 27, 107, 77, 61, 467, 1723, 1247, 287, 1039, 25347, 18111, 24837, 42903, 0 };
            const std::uint32_t dim20612JoeKuoD6Init[]   =   { 1, 3, 5, 5, 1, 29, 57, 177, 311, 9, 819, 3235, 3887, 9679, 11849, 31755, 68467, 135587, 0 };
            const std::uint32_t dim20613JoeKuoD6Init[]   =   { 1, 1, 5, 5, 29, 15, 13, 69, 163, 709, 1405, 3835, 777, 7567, 10153, 5043, 129465, 59113, 0 };
            const std::uint32_t dim20614JoeKuoD6Init[]   =   { 1, 1, 1, 13, 3, 47, 97, 101, 179, 53, 1919, 17, 3597, 11769, 17971, 39257, 76167, 255653, 0 };
            const std::uint32_t dim20615JoeKuoD6Init[]   =   { 1, 1, 7, 5, 1, 45, 121, 223, 299, 271, 1857, 1955, 5509, 1245, 9519, 60547, 78497, 191251, 0 };
            const std::uint32_t dim20616JoeKuoD6Init[]   =   { 1, 1, 1, 11, 5, 57, 87, 113, 59, 547, 1591, 1905, 475, 4687, 27591, 43807, 9617, 70769, 0 };
            const std::uint32_t dim20617JoeKuoD6Init[]   =   { 1, 1, 7, 1, 1, 35, 35, 11, 107, 401, 827, 2271, 2131, 12751, 25771, 51311, 46897, 198655, 0 };
            const std::uint32_t dim20618JoeKuoD6Init[]   =   { 1, 3, 3, 3, 15, 29, 91, 147, 9, 611, 1739, 3211, 3883, 14205, 24073, 37445, 54451, 208123, 0 };
            const std::uint32_t dim20619JoeKuoD6Init[]   =   { 1, 3, 7, 1, 25, 53, 33, 161, 365, 651, 1263, 1623, 1767, 3789, 18013, 52133, 60119, 100859, 0 };
            const std::uint32_t dim20620JoeKuoD6Init[]   =   { 1, 3, 5, 9, 15, 9, 97, 67, 379, 981, 1323, 1095, 3701, 3257, 13647, 12511, 53375, 156689, 0 };
            const std::uint32_t dim20621JoeKuoD6Init[]   =   { 1, 1, 3, 5, 9, 23, 97, 239, 171, 501, 1549, 1029, 8019, 5023, 9439, 14223, 54433, 152855, 0 };
            const std::uint32_t dim20622JoeKuoD6Init[]   =   { 1, 1, 7, 13, 17, 35, 111, 169, 81, 599, 1673, 3461, 7905, 7925, 16311, 20327, 57109, 158719, 0 };
            const std::uint32_t dim20623JoeKuoD6Init[]   =   { 1, 1, 3, 15, 7, 33, 23, 33, 273, 987, 1489, 363, 4017, 8919, 28839, 10143, 114179, 218155, 0 };
            const std::uint32_t dim20624JoeKuoD6Init[]   =   { 1, 3, 5, 13, 29, 5, 61, 133, 65, 933, 509, 551, 7365, 3703, 15003, 27849, 64211, 140383, 0 };
            const std::uint32_t dim20625JoeKuoD6Init[]   =   { 1, 1, 1, 13, 7, 25, 49, 1, 269, 601, 251, 33, 2443, 13725, 5805, 63347, 109489, 111491, 0 };
            const std::uint32_t dim20626JoeKuoD6Init[]   =   { 1, 1, 7, 9, 31, 23, 117, 71, 371, 733, 605, 4019, 4577, 3887, 31061, 24939, 57905, 148331, 0 };
            const std::uint32_t dim20627JoeKuoD6Init[]   =   { 1, 3, 5, 1, 3, 35, 35, 227, 355, 27, 1673, 2173, 5001, 14613, 6343, 40775, 72349, 101287, 0 };
            const std::uint32_t dim20628JoeKuoD6Init[]   =   { 1, 1, 7, 15, 29, 3, 43, 77, 43, 51, 1495, 2577, 2093, 7515, 20151, 44533, 32223, 6355, 0 };
            const std::uint32_t dim20629JoeKuoD6Init[]   =   { 1, 1, 5, 5, 11, 47, 91, 221, 35, 969, 343, 3287, 857, 4851, 12599, 939, 53615, 262125, 0 };
            const std::uint32_t dim20630JoeKuoD6Init[]   =   { 1, 1, 5, 7, 29, 11, 67, 155, 317, 629, 211, 583, 1061, 13243, 13999, 45405, 18187, 99021, 0 };
            const std::uint32_t dim20631JoeKuoD6Init[]   =   { 1, 3, 7, 13, 3, 39, 5, 207, 175, 515, 1181, 739, 379, 9919, 12079, 18903, 62475, 239383, 0 };
            const std::uint32_t dim20632JoeKuoD6Init[]   =   { 1, 1, 1, 15, 25, 15, 113, 215, 281, 861, 1055, 2577, 5545, 12365, 16097, 35775, 8331, 119353, 0 };
            const std::uint32_t dim20633JoeKuoD6Init[]   =   { 1, 1, 1, 1, 25, 55, 111, 185, 485, 361, 155, 4077, 5517, 16057, 19069, 40129, 38959, 211233, 0 };
            const std::uint32_t dim20634JoeKuoD6Init[]   =   { 1, 1, 3, 3, 13, 1, 93, 129, 243, 813, 115, 177, 53, 8251, 32351, 63847, 54537, 25527, 0 };
            const std::uint32_t dim20635JoeKuoD6Init[]   =   { 1, 3, 5, 11, 25, 47, 113, 69, 285, 451, 2011, 81, 6535, 3409, 8647, 56575, 975, 149571, 0 };
            const std::uint32_t dim20636JoeKuoD6Init[]   =   { 1, 1, 7, 7, 19, 1, 75, 123, 413, 697, 41, 3179, 4075, 15967, 2477, 17549, 54193, 258657, 0 };
            const std::uint32_t dim20637JoeKuoD6Init[]   =   { 1, 1, 5, 5, 11, 23, 19, 253, 303, 255, 901, 875, 1517, 6953, 25189, 26763, 28843, 167705, 0 };
            const std::uint32_t dim20638JoeKuoD6Init[]   =   { 1, 3, 7, 7, 17, 45, 31, 79, 279, 965, 1869, 1201, 1627, 14035, 11651, 45021, 76171, 49137, 0 };
            const std::uint32_t dim20639JoeKuoD6Init[]   =   { 1, 3, 1, 15, 9, 55, 83, 59, 437, 915, 1667, 89, 2797, 1841, 29261, 23497, 55785, 102265, 0 };
            const std::uint32_t dim20640JoeKuoD6Init[]   =   { 1, 1, 5, 5, 3, 59, 17, 131, 199, 541, 1647, 2175, 4449, 6081, 10609, 39467, 72945, 32423, 0 };
            const std::uint32_t dim20641JoeKuoD6Init[]   =   { 1, 3, 1, 7, 5, 7, 85, 11, 255, 397, 87, 1661, 6523, 5699, 29407, 28015, 50783, 246625, 0 };
            const std::uint32_t dim20642JoeKuoD6Init[]   =   { 1, 3, 3, 13, 5, 61, 123, 147, 295, 37, 301, 2549, 7615, 5725, 32477, 18121, 69353, 242579, 0 };
            const std::uint32_t dim20643JoeKuoD6Init[]   =   { 1, 3, 5, 7, 9, 45, 83, 211, 475, 281, 743, 3955, 7811, 6043, 30547, 5315, 53345, 25775, 0 };
            const std::uint32_t dim20644JoeKuoD6Init[]   =   { 1, 3, 3, 5, 7, 63, 125, 43, 131, 353, 345, 1689, 5483, 5467, 13445, 13041, 68381, 134567, 0 };
            const std::uint32_t dim20645JoeKuoD6Init[]   =   { 1, 3, 5, 11, 31, 9, 123, 53, 237, 911, 349, 3737, 1867, 7375, 3031, 4191, 8697, 182255, 0 };
            const std::uint32_t dim20646JoeKuoD6Init[]   =   { 1, 1, 3, 3, 11, 11, 89, 251, 69, 93, 1241, 1719, 2227, 1793, 21683, 58099, 110831, 24835, 0 };
            const std::uint32_t dim20647JoeKuoD6Init[]   =   { 1, 1, 5, 9, 3, 57, 3, 17, 11, 217, 923, 3623, 727, 1837, 21203, 63007, 33691, 216259, 0 };
            const std::uint32_t dim20648JoeKuoD6Init[]   =   { 1, 3, 3, 9, 21, 25, 83, 115, 325, 921, 811, 303, 3555, 10669, 5837, 45585, 61923, 159061, 0 };
            const std::uint32_t dim20649JoeKuoD6Init[]   =   { 1, 3, 3, 15, 17, 29, 77, 75, 509, 363, 199, 317, 7375, 11971, 15679, 17135, 101925, 103375, 0 };
            const std::uint32_t dim20650JoeKuoD6Init[]   =   { 1, 3, 5, 5, 29, 45, 85, 151, 73, 329, 911, 3055, 2381, 4717, 5133, 58987, 59885, 226689, 0 };
            const std::uint32_t dim20651JoeKuoD6Init[]   =   { 1, 3, 5, 1, 11, 59, 17, 83, 385, 867, 215, 2275, 7247, 10613, 6493, 63843, 74483, 134271, 0 };
            const std::uint32_t dim20652JoeKuoD6Init[]   =   { 1, 1, 7, 13, 29, 25, 77, 61, 281, 439, 353, 2213, 697, 14741, 1597, 7515, 7703, 149123, 0 };
            const std::uint32_t dim20653JoeKuoD6Init[]   =   { 1, 3, 7, 7, 7, 53, 77, 21, 483, 793, 969, 123, 3581, 12489, 22943, 54573, 25785, 178419, 0 };
            const std::uint32_t dim20654JoeKuoD6Init[]   =   { 1, 3, 5, 3, 17, 59, 75, 55, 125, 569, 1625, 77, 4593, 8493, 5259, 54537, 100479, 107509, 0 };
            const std::uint32_t dim20655JoeKuoD6Init[]   =   { 1, 1, 1, 15, 5, 7, 11, 169, 349, 133, 1113, 2877, 6109, 16275, 9755, 1385, 55005, 36095, 0 };
            const std::uint32_t dim20656JoeKuoD6Init[]   =   { 1, 1, 7, 7, 21, 25, 41, 161, 11, 321, 343, 705, 4601, 12867, 21997, 25283, 78467, 159089, 0 };
            const std::uint32_t dim20657JoeKuoD6Init[]   =   { 1, 3, 7, 1, 15, 3, 71, 227, 427, 883, 1021, 1405, 7791, 12669, 9159, 30931, 105993, 40917, 0 };
            const std::uint32_t dim20658JoeKuoD6Init[]   =   { 1, 1, 5, 5, 25, 41, 93, 57, 125, 915, 701, 2589, 7147, 15369, 28307, 54635, 13253, 97177, 0 };
            const std::uint32_t dim20659JoeKuoD6Init[]   =   { 1, 3, 1, 13, 11, 63, 103, 241, 317, 927, 965, 3179, 5213, 13849, 11509, 52665, 1637, 235647, 0 };
            const std::uint32_t dim20660JoeKuoD6Init[]   =   { 1, 3, 5, 3, 31, 31, 111, 9, 339, 1017, 1715, 101, 6849, 14329, 31607, 40741, 73067, 119001, 0 };
            const std::uint32_t dim20661JoeKuoD6Init[]   =   { 1, 3, 1, 13, 3, 55, 53, 15, 185, 717, 1447, 3029, 4899, 14217, 19949, 32817, 24829, 206829, 0 };
            const std::uint32_t dim20662JoeKuoD6Init[]   =   { 1, 3, 7, 9, 21, 11, 33, 213, 5, 769, 1807, 2179, 63, 5167, 23235, 25495, 113299, 129419, 0 };
            const std::uint32_t dim20663JoeKuoD6Init[]   =   { 1, 3, 7, 11, 11, 33, 23, 125, 21, 609, 595, 1329, 6175, 15837, 3889, 57797, 81453, 211413, 0 };
            const std::uint32_t dim20664JoeKuoD6Init[]   =   { 1, 1, 5, 11, 31, 7, 13, 73, 143, 559, 1541, 275, 3349, 2987, 21797, 32921, 125395, 247667, 0 };
            const std::uint32_t dim20665JoeKuoD6Init[]   =   { 1, 1, 3, 11, 19, 1, 23, 167, 337, 75, 1597, 3591, 2705, 7323, 5957, 7317, 58945, 44625, 0 };
            const std::uint32_t dim20666JoeKuoD6Init[]   =   { 1, 1, 5, 11, 27, 19, 63, 231, 353, 645, 531, 3861, 1681, 6901, 16217, 20639, 70077, 220233, 0 };
            const std::uint32_t dim20667JoeKuoD6Init[]   =   { 1, 1, 5, 15, 31, 41, 19, 253, 147, 365, 509, 1199, 6699, 14633, 1339, 48203, 58707, 83315, 0 };
            const std::uint32_t dim20668JoeKuoD6Init[]   =   { 1, 1, 5, 7, 19, 47, 47, 17, 267, 139, 549, 803, 4625, 6851, 32141, 12891, 43785, 211361, 0 };
            const std::uint32_t dim20669JoeKuoD6Init[]   =   { 1, 3, 1, 13, 19, 35, 13, 45, 167, 627, 1449, 3041, 5043, 9279, 15889, 41675, 25769, 13835, 0 };
            const std::uint32_t dim20670JoeKuoD6Init[]   =   { 1, 3, 7, 7, 19, 47, 13, 117, 403, 79, 1623, 3741, 3255, 2301, 25, 2311, 5237, 150879, 0 };
            const std::uint32_t dim20671JoeKuoD6Init[]   =   { 1, 1, 1, 15, 29, 43, 75, 21, 237, 809, 129, 2637, 181, 15921, 30709, 61281, 82405, 232885, 0 };
            const std::uint32_t dim20672JoeKuoD6Init[]   =   { 1, 1, 3, 15, 15, 15, 55, 217, 243, 579, 945, 3993, 1875, 2425, 25045, 36729, 42935, 213703, 0 };
            const std::uint32_t dim20673JoeKuoD6Init[]   =   { 1, 3, 3, 1, 5, 59, 115, 71, 483, 327, 701, 2893, 1815, 4611, 3843, 5893, 126479, 167807, 0 };
            const std::uint32_t dim20674JoeKuoD6Init[]   =   { 1, 3, 1, 7, 17, 59, 115, 191, 3, 615, 215, 2121, 5085, 15233, 16661, 6215, 31061, 192847, 0 };
            const std::uint32_t dim20675JoeKuoD6Init[]   =   { 1, 3, 1, 1, 21, 25, 41, 195, 151, 905, 1587, 439, 3317, 2275, 4743, 33505, 1185, 254873, 0 };
            const std::uint32_t dim20676JoeKuoD6Init[]   =   { 1, 1, 3, 9, 11, 49, 37, 117, 419, 1007, 789, 1323, 345, 2047, 20697, 57063, 69167, 219393, 0 };
            const std::uint32_t dim20677JoeKuoD6Init[]   =   { 1, 3, 1, 1, 25, 49, 81, 79, 117, 1015, 1777, 2427, 527, 10139, 16261, 42587, 33933, 19749, 0 };
            const std::uint32_t dim20678JoeKuoD6Init[]   =   { 1, 1, 5, 15, 31, 43, 19, 17, 97, 591, 891, 177, 7835, 3979, 15473, 2173, 65555, 182773, 0 };
            const std::uint32_t dim20679JoeKuoD6Init[]   =   { 1, 1, 3, 15, 13, 53, 31, 179, 247, 635, 683, 423, 2981, 14401, 26385, 10935, 68497, 181703, 0 };
            const std::uint32_t dim20680JoeKuoD6Init[]   =   { 1, 3, 3, 9, 25, 55, 43, 29, 487, 969, 989, 3561, 6425, 11619, 5773, 56515, 17461, 151239, 0 };
            const std::uint32_t dim20681JoeKuoD6Init[]   =   { 1, 1, 5, 13, 3, 31, 73, 51, 213, 215, 297, 783, 697, 14197, 7277, 60697, 985, 189995, 0 };
            const std::uint32_t dim20682JoeKuoD6Init[]   =   { 1, 3, 3, 5, 9, 47, 69, 27, 15, 407, 1029, 2541, 183, 4413, 5143, 33903, 49509, 49007, 0 };
            const std::uint32_t dim20683JoeKuoD6Init[]   =   { 1, 1, 1, 3, 5, 3, 9, 165, 215, 577, 1657, 363, 737, 5483, 5955, 34533, 45861, 104645, 0 };
            const std::uint32_t dim20684JoeKuoD6Init[]   =   { 1, 1, 5, 7, 31, 27, 37, 215, 125, 915, 1297, 3095, 1529, 12737, 25675, 29355, 83939, 106765, 0 };
            const std::uint32_t dim20685JoeKuoD6Init[]   =   { 1, 1, 3, 3, 1, 49, 29, 115, 395, 647, 147, 3905, 1025, 8873, 10587, 25471, 72089, 171467, 0 };
            const std::uint32_t dim20686JoeKuoD6Init[]   =   { 1, 3, 7, 1, 21, 55, 57, 233, 487, 883, 439, 929, 1405, 13709, 2389, 20205, 17579, 9129, 0 };
            const std::uint32_t dim20687JoeKuoD6Init[]   =   { 1, 3, 5, 5, 23, 51, 55, 45, 307, 855, 933, 1443, 4757, 8719, 28401, 35189, 105329, 9211, 0 };
            const std::uint32_t dim20688JoeKuoD6Init[]   =   { 1, 3, 7, 11, 29, 17, 17, 147, 221, 997, 1433, 59, 8027, 231, 30335, 2153, 21393, 116661, 0 };
            const std::uint32_t dim20689JoeKuoD6Init[]   =   { 1, 1, 7, 3, 5, 43, 47, 155, 357, 915, 1923, 3315, 4107, 9785, 4847, 57683, 87569, 179583, 0 };
            const std::uint32_t dim20690JoeKuoD6Init[]   =   { 1, 1, 7, 7, 27, 5, 37, 95, 265, 113, 143, 3755, 5793, 5601, 16621, 54777, 15989, 158933, 0 };
            const std::uint32_t dim20691JoeKuoD6Init[]   =   { 1, 3, 1, 1, 13, 31, 113, 255, 367, 559, 1777, 4065, 8061, 15785, 10345, 54833, 95277, 159347, 0 };
            const std::uint32_t dim20692JoeKuoD6Init[]   =   { 1, 1, 1, 15, 3, 43, 85, 251, 193, 19, 1685, 271, 1779, 11901, 18983, 65361, 128217, 248051, 0 };
            const std::uint32_t dim20693JoeKuoD6Init[]   =   { 1, 3, 5, 7, 29, 21, 5, 47, 263, 913, 83, 3233, 113, 8341, 14473, 37405, 2363, 155931, 0 };
            const std::uint32_t dim20694JoeKuoD6Init[]   =   { 1, 1, 7, 15, 7, 25, 41, 39, 315, 323, 827, 1277, 1211, 4465, 21161, 36865, 6689, 139147, 0 };
            const std::uint32_t dim20695JoeKuoD6Init[]   =   { 1, 1, 1, 9, 11, 45, 81, 235, 31, 247, 77, 1877, 7119, 16007, 2225, 65, 85537, 99251, 0 };
            const std::uint32_t dim20696JoeKuoD6Init[]   =   { 1, 1, 3, 11, 19, 5, 49, 179, 345, 961, 349, 2099, 2317, 12771, 27169, 59389, 116071, 68333, 0 };
            const std::uint32_t dim20697JoeKuoD6Init[]   =   { 1, 3, 3, 5, 15, 53, 47, 177, 103, 941, 87, 2813, 7729, 8003, 7717, 40095, 74569, 106617, 0 };
            const std::uint32_t dim20698JoeKuoD6Init[]   =   { 1, 1, 7, 7, 31, 23, 105, 205, 325, 855, 1529, 3601, 7151, 15827, 16241, 18221, 55771, 139225, 0 };
            const std::uint32_t dim20699JoeKuoD6Init[]   =   { 1, 3, 5, 13, 13, 5, 95, 167, 25, 779, 1147, 221, 5055, 10943, 28077, 15131, 89501, 137407, 0 };
            const std::uint32_t dim20700JoeKuoD6Init[]   =   { 1, 3, 7, 13, 31, 3, 105, 163, 41, 823, 1493, 2985, 5589, 3543, 24683, 34469, 40595, 200875, 0 };
            const std::uint32_t dim20701JoeKuoD6Init[]   =   { 1, 3, 5, 3, 27, 35, 105, 163, 477, 667, 45, 319, 3201, 11535, 19349, 55253, 60275, 209597, 0 };
            const std::uint32_t dim20702JoeKuoD6Init[]   =   { 1, 3, 1, 11, 5, 13, 25, 225, 169, 925, 1617, 537, 891, 5583, 7181, 39953, 97537, 104019, 0 };
            const std::uint32_t dim20703JoeKuoD6Init[]   =   { 1, 3, 5, 9, 13, 1, 69, 147, 465, 259, 1219, 2407, 4015, 4883, 4333, 40441, 31289, 52989, 0 };
            const std::uint32_t dim20704JoeKuoD6Init[]   =   { 1, 3, 5, 5, 17, 29, 105, 233, 307, 807, 1535, 251, 135, 925, 6865, 59739, 112757, 208275, 0 };
            const std::uint32_t dim20705JoeKuoD6Init[]   =   { 1, 1, 1, 7, 9, 21, 49, 247, 33, 127, 1277, 1745, 139, 12165, 23517, 50235, 101003, 109031, 0 };
            const std::uint32_t dim20706JoeKuoD6Init[]   =   { 1, 3, 5, 9, 19, 7, 9, 139, 511, 901, 551, 2717, 6091, 3213, 819, 51381, 108333, 119681, 0 };
            const std::uint32_t dim20707JoeKuoD6Init[]   =   { 1, 1, 1, 3, 19, 17, 73, 19, 313, 589, 1965, 1745, 921, 4237, 12527, 10735, 110139, 171513, 0 };
            const std::uint32_t dim20708JoeKuoD6Init[]   =   { 1, 1, 5, 15, 25, 29, 15, 217, 87, 793, 419, 915, 1359, 10507, 25343, 62977, 100913, 110041, 0 };
            const std::uint32_t dim20709JoeKuoD6Init[]   =   { 1, 3, 7, 15, 15, 15, 91, 243, 441, 437, 1759, 2659, 2319, 7783, 16857, 19051, 15463, 253115, 0 };
            const std::uint32_t dim20710JoeKuoD6Init[]   =   { 1, 1, 5, 13, 15, 5, 7, 165, 355, 559, 217, 235, 3565, 12047, 2387, 62285, 73363, 238551, 0 };
            const std::uint32_t dim20711JoeKuoD6Init[]   =   { 1, 3, 7, 11, 5, 5, 69, 205, 179, 815, 335, 979, 2129, 6221, 31987, 13623, 23103, 24373, 0 };
            const std::uint32_t dim20712JoeKuoD6Init[]   =   { 1, 1, 7, 11, 31, 51, 55, 93, 195, 219, 825, 2919, 4495, 5927, 11813, 16415, 121595, 188613, 0 };
            const std::uint32_t dim20713JoeKuoD6Init[]   =   { 1, 1, 3, 1, 3, 11, 73, 45, 141, 219, 337, 2569, 6549, 3699, 2417, 2945, 19389, 82561, 0 };
            const std::uint32_t dim20714JoeKuoD6Init[]   =   { 1, 3, 1, 13, 5, 47, 47, 81, 11, 57, 1965, 2173, 3209, 10617, 19887, 5571, 61403, 37401, 0 };
            const std::uint32_t dim20715JoeKuoD6Init[]   =   { 1, 3, 3, 7, 3, 5, 99, 253, 287, 655, 813, 3365, 2387, 8951, 1561, 37637, 97625, 148699, 0 };
            const std::uint32_t dim20716JoeKuoD6Init[]   =   { 1, 1, 3, 5, 9, 31, 49, 7, 55, 607, 1489, 3229, 5871, 1271, 22751, 32309, 16125, 93409, 0 };
            const std::uint32_t dim20717JoeKuoD6Init[]   =   { 1, 3, 1, 5, 19, 35, 29, 233, 407, 297, 1465, 3089, 7535, 7221, 24469, 42653, 65719, 196771, 0 };
            const std::uint32_t dim20718JoeKuoD6Init[]   =   { 1, 1, 7, 13, 17, 19, 37, 45, 211, 545, 963, 79, 13, 8319, 8045, 24975, 122749, 25845, 0 };
            const std::uint32_t dim20719JoeKuoD6Init[]   =   { 1, 3, 5, 3, 23, 23, 53, 101, 363, 49, 1351, 3419, 1603, 10795, 5289, 63695, 113911, 228301, 0 };
            const std::uint32_t dim20720JoeKuoD6Init[]   =   { 1, 3, 7, 9, 15, 59, 125, 59, 11, 397, 693, 397, 3829, 14349, 13973, 54739, 22093, 216009, 0 };
            const std::uint32_t dim20721JoeKuoD6Init[]   =   { 1, 1, 1, 13, 5, 63, 21, 23, 421, 35, 589, 803, 6193, 11375, 9501, 34441, 68421, 120109, 0 };
            const std::uint32_t dim20722JoeKuoD6Init[]   =   { 1, 3, 3, 7, 23, 25, 79, 203, 177, 173, 175, 809, 4331, 6953, 4999, 34345, 94481, 88683, 0 };
            const std::uint32_t dim20723JoeKuoD6Init[]   =   { 1, 3, 3, 3, 1, 51, 109, 195, 83, 747, 63, 325, 927, 1757, 32055, 37185, 22697, 41509, 0 };
            const std::uint32_t dim20724JoeKuoD6Init[]   =   { 1, 3, 5, 13, 1, 63, 45, 73, 121, 445, 1935, 3373, 563, 7503, 17941, 60313, 42219, 220917, 0 };
            const std::uint32_t dim20725JoeKuoD6Init[]   =   { 1, 3, 5, 13, 27, 31, 7, 83, 109, 387, 447, 1691, 1301, 7449, 8075, 30713, 87207, 84855, 0 };
            const std::uint32_t dim20726JoeKuoD6Init[]   =   { 1, 3, 1, 5, 25, 51, 83, 11, 261, 977, 1415, 2973, 1789, 12641, 16279, 4225, 44237, 173561, 0 };
            const std::uint32_t dim20727JoeKuoD6Init[]   =   { 1, 1, 5, 15, 17, 47, 105, 199, 83, 705, 1215, 2759, 7509, 10407, 4005, 4575, 65961, 209933, 0 };
            const std::uint32_t dim20728JoeKuoD6Init[]   =   { 1, 3, 1, 13, 27, 3, 5, 199, 405, 515, 291, 3399, 1497, 14755, 30229, 35075, 111585, 16633, 0 };
            const std::uint32_t dim20729JoeKuoD6Init[]   =   { 1, 1, 1, 13, 17, 53, 93, 161, 447, 903, 947, 1871, 3597, 10575, 18389, 48551, 65229, 32591, 0 };
            const std::uint32_t dim20730JoeKuoD6Init[]   =   { 1, 3, 5, 11, 9, 7, 53, 155, 299, 523, 1653, 3517, 2725, 9485, 27099, 47895, 30169, 260463, 0 };
            const std::uint32_t dim20731JoeKuoD6Init[]   =   { 1, 1, 3, 13, 11, 45, 31, 183, 445, 21, 313, 2597, 195, 16053, 7323, 52951, 25919, 9323, 0 };
            const std::uint32_t dim20732JoeKuoD6Init[]   =   { 1, 1, 1, 15, 1, 35, 15, 115, 53, 561, 1141, 3261, 83, 2547, 8925, 43455, 112755, 94157, 0 };
            const std::uint32_t dim20733JoeKuoD6Init[]   =   { 1, 1, 3, 5, 27, 25, 81, 51, 209, 87, 379, 3167, 4953, 13885, 20159, 103, 115363, 123585, 0 };
            const std::uint32_t dim20734JoeKuoD6Init[]   =   { 1, 3, 5, 1, 25, 29, 107, 225, 77, 435, 2009, 4069, 3703, 8855, 14101, 61683, 16993, 110823, 0 };
            const std::uint32_t dim20735JoeKuoD6Init[]   =   { 1, 3, 7, 3, 31, 25, 51, 117, 397, 271, 89, 3571, 2357, 4923, 16303, 2357, 107775, 73809, 0 };
            const std::uint32_t dim20736JoeKuoD6Init[]   =   { 1, 1, 3, 1, 29, 21, 33, 67, 363, 753, 915, 3715, 2013, 8439, 5779, 267, 32687, 104283, 0 };
            const std::uint32_t dim20737JoeKuoD6Init[]   =   { 1, 3, 1, 11, 11, 7, 31, 43, 339, 917, 2005, 759, 4285, 1933, 4341, 19111, 130651, 122853, 0 };
            const std::uint32_t dim20738JoeKuoD6Init[]   =   { 1, 1, 5, 1, 17, 63, 85, 63, 387, 127, 1313, 619, 6525, 9003, 10915, 64507, 13175, 45219, 0 };
            const std::uint32_t dim20739JoeKuoD6Init[]   =   { 1, 3, 7, 9, 25, 15, 43, 13, 411, 391, 571, 527, 8175, 10849, 20093, 2987, 29869, 77207, 0 };
            const std::uint32_t dim20740JoeKuoD6Init[]   =   { 1, 1, 5, 3, 29, 53, 105, 57, 91, 977, 1103, 2977, 5617, 7203, 26717, 28463, 55909, 59943, 0 };
            const std::uint32_t dim20741JoeKuoD6Init[]   =   { 1, 3, 1, 7, 1, 47, 111, 215, 189, 377, 11, 871, 2267, 5705, 8165, 38895, 71025, 10921, 0 };
            const std::uint32_t dim20742JoeKuoD6Init[]   =   { 1, 1, 7, 9, 29, 55, 1, 103, 505, 697, 317, 3209, 3643, 13689, 8499, 14671, 67937, 100467, 0 };
            const std::uint32_t dim20743JoeKuoD6Init[]   =   { 1, 3, 1, 5, 25, 15, 99, 199, 117, 957, 1421, 1719, 5185, 15247, 28615, 2657, 46867, 190135, 0 };
            const std::uint32_t dim20744JoeKuoD6Init[]   =   { 1, 1, 7, 9, 27, 55, 81, 47, 15, 497, 537, 857, 2905, 1909, 3341, 32625, 123189, 21875, 0 };
            const std::uint32_t dim20745JoeKuoD6Init[]   =   { 1, 3, 1, 3, 19, 51, 97, 143, 305, 1021, 543, 829, 7593, 8101, 6337, 4869, 19177, 38981, 0 };
            const std::uint32_t dim20746JoeKuoD6Init[]   =   { 1, 3, 3, 15, 9, 37, 51, 193, 295, 731, 809, 4065, 3377, 15303, 12505, 11327, 76191, 139899, 0 };
            const std::uint32_t dim20747JoeKuoD6Init[]   =   { 1, 1, 5, 1, 3, 19, 5, 223, 379, 7, 755, 1127, 505, 9429, 27409, 50817, 97599, 179019, 0 };
            const std::uint32_t dim20748JoeKuoD6Init[]   =   { 1, 3, 5, 3, 5, 11, 83, 119, 3, 311, 405, 2401, 1821, 1381, 4567, 44079, 61903, 183583, 0 };
            const std::uint32_t dim20749JoeKuoD6Init[]   =   { 1, 3, 7, 9, 7, 11, 107, 95, 271, 537, 335, 3079, 6695, 1163, 32055, 44985, 29075, 94235, 0 };
            const std::uint32_t dim20750JoeKuoD6Init[]   =   { 1, 3, 7, 7, 7, 57, 59, 85, 199, 563, 1835, 351, 7675, 2601, 3717, 57975, 92529, 101511, 0 };
            const std::uint32_t dim20751JoeKuoD6Init[]   =   { 1, 1, 1, 5, 17, 5, 97, 43, 101, 141, 1511, 199, 7157, 3169, 24815, 55653, 104195, 37951, 0 };
            const std::uint32_t dim20752JoeKuoD6Init[]   =   { 1, 1, 1, 11, 23, 29, 41, 47, 447, 583, 773, 859, 1657, 8707, 16709, 53477, 42037, 186809, 0 };
            const std::uint32_t dim20753JoeKuoD6Init[]   =   { 1, 1, 1, 13, 13, 5, 85, 9, 213, 511, 1003, 811, 2271, 14715, 21423, 48127, 50613, 214031, 0 };
            const std::uint32_t dim20754JoeKuoD6Init[]   =   { 1, 1, 3, 5, 7, 31, 87, 101, 297, 853, 1599, 1521, 4965, 9655, 23543, 62277, 11231, 49931, 0 };
            const std::uint32_t dim20755JoeKuoD6Init[]   =   { 1, 1, 7, 7, 19, 31, 9, 165, 207, 919, 739, 3849, 2121, 867, 3233, 40867, 75721, 5327, 0 };
            const std::uint32_t dim20756JoeKuoD6Init[]   =   { 1, 3, 7, 1, 17, 3, 27, 13, 431, 283, 465, 1427, 1937, 15601, 21793, 9315, 54285, 196453, 0 };
            const std::uint32_t dim20757JoeKuoD6Init[]   =   { 1, 1, 7, 3, 17, 39, 65, 137, 511, 19, 1357, 3373, 5227, 2485, 1151, 25061, 117507, 119219, 0 };
            const std::uint32_t dim20758JoeKuoD6Init[]   =   { 1, 3, 3, 9, 9, 23, 13, 235, 505, 625, 115, 3859, 6943, 14719, 6363, 14957, 28241, 187989, 0 };
            const std::uint32_t dim20759JoeKuoD6Init[]   =   { 1, 3, 7, 13, 11, 31, 23, 39, 463, 441, 1145, 417, 4177, 1655, 26491, 16895, 26263, 198157, 0 };
            const std::uint32_t dim20760JoeKuoD6Init[]   =   { 1, 3, 3, 7, 25, 55, 121, 157, 131, 537, 1891, 2367, 1717, 2331, 20251, 8679, 62657, 121957, 0 };
            const std::uint32_t dim20761JoeKuoD6Init[]   =   { 1, 1, 1, 11, 7, 43, 59, 101, 333, 961, 569, 1603, 3009, 6539, 9627, 5759, 44401, 127613, 0 };
            const std::uint32_t dim20762JoeKuoD6Init[]   =   { 1, 3, 3, 3, 1, 27, 15, 135, 235, 215, 627, 2427, 2647, 3201, 22873, 64445, 32635, 16587, 0 };
            const std::uint32_t dim20763JoeKuoD6Init[]   =   { 1, 3, 7, 7, 5, 49, 63, 103, 467, 897, 117, 1149, 6045, 5003, 5005, 6183, 90815, 190909, 0 };
            const std::uint32_t dim20764JoeKuoD6Init[]   =   { 1, 1, 3, 3, 31, 43, 45, 227, 363, 409, 1097, 3155, 1519, 14461, 29377, 19577, 52595, 94041, 0 };
            const std::uint32_t dim20765JoeKuoD6Init[]   =   { 1, 3, 1, 1, 3, 25, 83, 243, 57, 243, 389, 1427, 5197, 13125, 18571, 17845, 74961, 125569, 0 };
            const std::uint32_t dim20766JoeKuoD6Init[]   =   { 1, 3, 5, 5, 1, 39, 11, 175, 97, 1001, 143, 3653, 5887, 5845, 5691, 5433, 62629, 176261, 0 };
            const std::uint32_t dim20767JoeKuoD6Init[]   =   { 1, 1, 1, 13, 11, 41, 41, 155, 17, 823, 1507, 733, 5663, 13657, 24133, 9971, 27179, 108075, 0 };
            const std::uint32_t dim20768JoeKuoD6Init[]   =   { 1, 1, 7, 9, 19, 9, 103, 29, 427, 363, 931, 3959, 1629, 5127, 14807, 61937, 127175, 237233, 0 };
            const std::uint32_t dim20769JoeKuoD6Init[]   =   { 1, 1, 1, 5, 29, 53, 51, 229, 123, 1001, 697, 411, 4669, 5051, 18447, 55437, 129269, 72613, 0 };
            const std::uint32_t dim20770JoeKuoD6Init[]   =   { 1, 3, 7, 3, 19, 53, 111, 131, 255, 547, 653, 2839, 1447, 14397, 5707, 23773, 127897, 135177, 0 };
            const std::uint32_t dim20771JoeKuoD6Init[]   =   { 1, 3, 3, 5, 21, 37, 53, 219, 359, 341, 489, 2477, 3383, 6931, 7753, 2619, 114267, 63271, 0 };
            const std::uint32_t dim20772JoeKuoD6Init[]   =   { 1, 1, 3, 15, 15, 15, 95, 171, 301, 563, 603, 593, 4037, 7305, 10849, 11753, 103087, 74887, 0 };
            const std::uint32_t dim20773JoeKuoD6Init[]   =   { 1, 1, 5, 3, 11, 51, 105, 35, 155, 643, 569, 1697, 1679, 7547, 19289, 7065, 57359, 142855, 0 };
            const std::uint32_t dim20774JoeKuoD6Init[]   =   { 1, 1, 7, 15, 23, 55, 17, 67, 375, 559, 355, 165, 93, 973, 22831, 48027, 98435, 59945, 0 };
            const std::uint32_t dim20775JoeKuoD6Init[]   =   { 1, 3, 7, 3, 5, 43, 9, 253, 111, 819, 45, 3461, 4821, 14735, 14469, 29793, 30681, 26359, 0 };
            const std::uint32_t dim20776JoeKuoD6Init[]   =   { 1, 3, 3, 5, 15, 1, 39, 233, 63, 287, 131, 3453, 427, 4929, 30085, 18583, 50119, 262101, 0 };
            const std::uint32_t dim20777JoeKuoD6Init[]   =   { 1, 3, 7, 9, 31, 7, 127, 157, 287, 57, 1091, 1989, 5045, 13071, 27705, 58125, 85317, 66649, 0 };
            const std::uint32_t dim20778JoeKuoD6Init[]   =   { 1, 1, 1, 15, 17, 29, 25, 223, 311, 489, 1901, 3197, 1813, 10097, 31915, 54871, 32289, 227001, 0 };
            const std::uint32_t dim20779JoeKuoD6Init[]   =   { 1, 3, 7, 5, 31, 35, 69, 87, 131, 963, 1125, 1109, 8037, 3257, 27655, 50999, 3715, 57851, 0 };
            const std::uint32_t dim20780JoeKuoD6Init[]   =   { 1, 1, 5, 5, 27, 7, 119, 29, 425, 721, 541, 3069, 3349, 13623, 12293, 51395, 14033, 61545, 0 };
            const std::uint32_t dim20781JoeKuoD6Init[]   =   { 1, 3, 7, 3, 17, 49, 103, 115, 387, 729, 1389, 2257, 3273, 3375, 23143, 2835, 28071, 79533, 0 };
            const std::uint32_t dim20782JoeKuoD6Init[]   =   { 1, 1, 3, 7, 9, 19, 55, 159, 261, 467, 17, 2595, 3947, 7045, 193, 23629, 89067, 81197, 0 };
            const std::uint32_t dim20783JoeKuoD6Init[]   =   { 1, 1, 1, 15, 13, 39, 103, 195, 251, 769, 1003, 2707, 3263, 8451, 8007, 53789, 112653, 258717, 0 };
            const std::uint32_t dim20784JoeKuoD6Init[]   =   { 1, 3, 5, 1, 3, 21, 29, 217, 125, 779, 1597, 513, 2677, 3979, 31903, 64813, 69963, 92887, 0 };
            const std::uint32_t dim20785JoeKuoD6Init[]   =   { 1, 1, 3, 11, 11, 59, 81, 237, 447, 703, 41, 3369, 3547, 14935, 31693, 52005, 74149, 131039, 0 };
            const std::uint32_t dim20786JoeKuoD6Init[]   =   { 1, 1, 3, 1, 23, 1, 33, 93, 275, 847, 921, 2745, 533, 8975, 30529, 46809, 98975, 75541, 0 };
            const std::uint32_t dim20787JoeKuoD6Init[]   =   { 1, 1, 7, 7, 15, 1, 3, 213, 71, 1009, 1951, 3015, 713, 9365, 21949, 60983, 117633, 225387, 0 };
            const std::uint32_t dim20788JoeKuoD6Init[]   =   { 1, 1, 1, 11, 31, 27, 59, 179, 231, 635, 1555, 2765, 31, 15065, 22719, 59251, 84733, 96769, 0 };
            const std::uint32_t dim20789JoeKuoD6Init[]   =   { 1, 3, 7, 3, 19, 5, 35, 207, 317, 735, 943, 3987, 4021, 11229, 13015, 713, 125167, 55887, 0 };
            const std::uint32_t dim20790JoeKuoD6Init[]   =   { 1, 1, 3, 1, 27, 49, 81, 17, 253, 633, 43, 2953, 3151, 8429, 30625, 28551, 126683, 175087, 0 };
            const std::uint32_t dim20791JoeKuoD6Init[]   =   { 1, 3, 3, 3, 9, 53, 111, 245, 57, 557, 945, 2957, 7669, 12537, 17291, 9713, 87727, 44739, 0 };
            const std::uint32_t dim20792JoeKuoD6Init[]   =   { 1, 3, 1, 1, 5, 39, 77, 127, 87, 687, 1485, 1555, 2567, 13551, 17075, 24003, 47627, 129813, 0 };
            const std::uint32_t dim20793JoeKuoD6Init[]   =   { 1, 3, 5, 9, 25, 35, 87, 233, 439, 563, 1719, 419, 4459, 4285, 25157, 943, 111543, 232107, 0 };
            const std::uint32_t dim20794JoeKuoD6Init[]   =   { 1, 3, 5, 11, 1, 13, 97, 153, 459, 551, 73, 2087, 3985, 4661, 15603, 22211, 123163, 187233, 0 };
            const std::uint32_t dim20795JoeKuoD6Init[]   =   { 1, 1, 7, 13, 17, 59, 5, 219, 353, 441, 387, 441, 3009, 485, 20081, 38023, 50659, 159243, 0 };
            const std::uint32_t dim20796JoeKuoD6Init[]   =   { 1, 3, 1, 7, 21, 31, 117, 49, 227, 677, 417, 1153, 1611, 1669, 25161, 52223, 15109, 114759, 0 };
            const std::uint32_t dim20797JoeKuoD6Init[]   =   { 1, 1, 7, 9, 19, 13, 111, 7, 1, 701, 731, 2075, 685, 15679, 19149, 44315, 41719, 243975, 0 };
            const std::uint32_t dim20798JoeKuoD6Init[]   =   { 1, 3, 3, 7, 15, 63, 59, 105, 327, 39, 1497, 2407, 2865, 7065, 9957, 20031, 45359, 73657, 0 };
            const std::uint32_t dim20799JoeKuoD6Init[]   =   { 1, 3, 1, 13, 7, 3, 55, 221, 443, 953, 15, 2455, 4681, 16247, 18179, 44731, 41323, 172621, 0 };
            const std::uint32_t dim20800JoeKuoD6Init[]   =   { 1, 1, 3, 9, 1, 27, 65, 167, 115, 137, 819, 2129, 3393, 5901, 11735, 62753, 14941, 21425, 0 };
            const std::uint32_t dim20801JoeKuoD6Init[]   =   { 1, 3, 7, 11, 7, 9, 41, 175, 237, 481, 59, 265, 2135, 9419, 3937, 55959, 48343, 172549, 0 };
            const std::uint32_t dim20802JoeKuoD6Init[]   =   { 1, 1, 1, 13, 23, 33, 105, 87, 461, 297, 1345, 3715, 7715, 16369, 19017, 15141, 10873, 109641, 0 };
            const std::uint32_t dim20803JoeKuoD6Init[]   =   { 1, 3, 5, 1, 11, 1, 13, 41, 447, 511, 447, 2295, 2401, 14171, 16269, 50453, 40361, 205857, 0 };
            const std::uint32_t dim20804JoeKuoD6Init[]   =   { 1, 1, 3, 3, 27, 7, 35, 193, 113, 341, 335, 2113, 343, 4575, 20863, 40383, 86787, 142603, 0 };
            const std::uint32_t dim20805JoeKuoD6Init[]   =   { 1, 1, 7, 11, 17, 25, 51, 89, 341, 237, 1233, 1505, 7401, 6887, 26897, 20127, 51077, 107559, 0 };
            const std::uint32_t dim20806JoeKuoD6Init[]   =   { 1, 1, 1, 15, 9, 59, 29, 115, 339, 785, 201, 947, 1501, 6883, 169, 44059, 17527, 197623, 0 };
            const std::uint32_t dim20807JoeKuoD6Init[]   =   { 1, 3, 7, 3, 17, 59, 15, 5, 379, 347, 821, 4047, 3565, 13689, 23275, 27901, 121401, 43077, 0 };
            const std::uint32_t dim20808JoeKuoD6Init[]   =   { 1, 1, 1, 7, 15, 11, 35, 29, 59, 99, 181, 3035, 3239, 1553, 32319, 64195, 115247, 149211, 0 };
            const std::uint32_t dim20809JoeKuoD6Init[]   =   { 1, 1, 5, 3, 31, 49, 87, 177, 231, 167, 373, 1125, 5919, 4805, 31983, 42873, 30169, 91853, 0 };
            const std::uint32_t dim20810JoeKuoD6Init[]   =   { 1, 1, 5, 15, 7, 63, 37, 15, 459, 449, 1835, 1769, 2527, 2577, 4251, 62459, 76699, 81721, 0 };
            const std::uint32_t dim20811JoeKuoD6Init[]   =   { 1, 1, 1, 3, 21, 15, 19, 183, 423, 827, 341, 2101, 3797, 7103, 30845, 24511, 115337, 117019, 0 };
            const std::uint32_t dim20812JoeKuoD6Init[]   =   { 1, 3, 5, 5, 19, 1, 97, 13, 491, 51, 445, 1987, 7481, 2613, 23141, 36603, 26917, 177397, 0 };
            const std::uint32_t dim20813JoeKuoD6Init[]   =   { 1, 1, 1, 5, 15, 43, 21, 167, 259, 989, 1937, 1519, 2201, 13973, 18031, 31583, 57557, 252737, 0 };
            const std::uint32_t dim20814JoeKuoD6Init[]   =   { 1, 3, 3, 7, 31, 11, 89, 53, 279, 83, 1247, 1221, 5499, 1199, 361, 22269, 88633, 134975, 0 };
            const std::uint32_t dim20815JoeKuoD6Init[]   =   { 1, 1, 3, 5, 9, 5, 113, 41, 143, 655, 1147, 2043, 4229, 10523, 1453, 1735, 76259, 30607, 0 };
            const std::uint32_t dim20816JoeKuoD6Init[]   =   { 1, 1, 1, 11, 5, 7, 9, 155, 221, 619, 813, 3111, 6039, 10789, 10905, 33285, 62841, 229217, 0 };
            const std::uint32_t dim20817JoeKuoD6Init[]   =   { 1, 3, 5, 9, 19, 19, 123, 65, 419, 597, 87, 3843, 4857, 15903, 23655, 13023, 8389, 230803, 0 };
            const std::uint32_t dim20818JoeKuoD6Init[]   =   { 1, 3, 3, 15, 9, 19, 51, 223, 197, 759, 139, 59, 6547, 1043, 5077, 55267, 23681, 17099, 0 };
            const std::uint32_t dim20819JoeKuoD6Init[]   =   { 1, 1, 3, 3, 15, 43, 63, 85, 227, 961, 1043, 1069, 6557, 7499, 31639, 4345, 26991, 132783, 0 };
            const std::uint32_t dim20820JoeKuoD6Init[]   =   { 1, 3, 1, 1, 25, 33, 59, 219, 435, 105, 1001, 323, 2729, 12517, 16607, 57533, 101167, 53829, 0 };
            const std::uint32_t dim20821JoeKuoD6Init[]   =   { 1, 3, 7, 7, 9, 55, 3, 247, 303, 453, 861, 817, 705, 14337, 15965, 28867, 126763, 204005, 0 };
            const std::uint32_t dim20822JoeKuoD6Init[]   =   { 1, 1, 3, 7, 1, 39, 15, 39, 359, 313, 1753, 2835, 387, 16223, 10945, 19481, 19995, 29989, 0 };
            const std::uint32_t dim20823JoeKuoD6Init[]   =   { 1, 1, 1, 5, 3, 31, 103, 123, 493, 1023, 119, 2175, 2273, 11637, 21605, 23349, 100759, 41227, 0 };
            const std::uint32_t dim20824JoeKuoD6Init[]   =   { 1, 3, 7, 13, 5, 13, 17, 7, 341, 945, 621, 1421, 3893, 5825, 26777, 35497, 13791, 25415, 0 };
            const std::uint32_t dim20825JoeKuoD6Init[]   =   { 1, 1, 5, 1, 19, 27, 39, 7, 177, 749, 1217, 2133, 6913, 13489, 23713, 1085, 31529, 179741, 0 };
            const std::uint32_t dim20826JoeKuoD6Init[]   =   { 1, 3, 3, 3, 15, 21, 5, 145, 281, 131, 1347, 19, 4917, 8655, 2515, 36927, 56551, 202039, 0 };
            const std::uint32_t dim20827JoeKuoD6Init[]   =   { 1, 1, 3, 7, 27, 31, 33, 255, 511, 195, 1493, 2221, 2157, 9303, 3957, 14163, 70435, 215763, 0 };
            const std::uint32_t dim20828JoeKuoD6Init[]   =   { 1, 3, 3, 15, 31, 41, 33, 37, 239, 865, 375, 2217, 809, 11961, 29393, 52145, 76223, 202623, 0 };
            const std::uint32_t dim20829JoeKuoD6Init[]   =   { 1, 3, 5, 11, 5, 57, 73, 193, 341, 843, 1817, 231, 65, 5941, 29693, 31751, 57081, 180977, 0 };
            const std::uint32_t dim20830JoeKuoD6Init[]   =   { 1, 3, 1, 9, 29, 57, 85, 107, 343, 891, 465, 2413, 1965, 7303, 7461, 25857, 110517, 16995, 0 };
            const std::uint32_t dim20831JoeKuoD6Init[]   =   { 1, 1, 7, 15, 7, 49, 121, 211, 253, 511, 1385, 1205, 33, 7713, 20059, 47353, 3267, 215759, 0 };
            const std::uint32_t dim20832JoeKuoD6Init[]   =   { 1, 1, 3, 9, 15, 63, 45, 155, 415, 589, 651, 3707, 5429, 4497, 13733, 21231, 18953, 28671, 0 };
            const std::uint32_t dim20833JoeKuoD6Init[]   =   { 1, 1, 5, 15, 7, 57, 31, 109, 427, 921, 629, 3439, 7615, 4535, 1507, 58931, 49597, 214397, 0 };
            const std::uint32_t dim20834JoeKuoD6Init[]   =   { 1, 3, 3, 5, 21, 35, 9, 241, 67, 767, 659, 1639, 7797, 5209, 14851, 55311, 108549, 175937, 0 };
            const std::uint32_t dim20835JoeKuoD6Init[]   =   { 1, 1, 7, 15, 21, 61, 13, 47, 267, 269, 1169, 257, 2481, 8345, 1061, 28119, 127197, 95379, 0 };
            const std::uint32_t dim20836JoeKuoD6Init[]   =   { 1, 1, 3, 7, 21, 35, 121, 223, 145, 665, 1389, 2105, 5499, 1377, 32417, 39027, 5335, 248315, 0 };
            const std::uint32_t dim20837JoeKuoD6Init[]   =   { 1, 3, 3, 9, 13, 33, 57, 225, 123, 703, 1049, 709, 7347, 11317, 12339, 23247, 62157, 85931, 0 };
            const std::uint32_t dim20838JoeKuoD6Init[]   =   { 1, 3, 3, 3, 5, 3, 105, 115, 13, 675, 757, 987, 6429, 13017, 21347, 38829, 82153, 220677, 0 };
            const std::uint32_t dim20839JoeKuoD6Init[]   =   { 1, 3, 1, 13, 5, 51, 75, 205, 7, 561, 207, 1133, 3303, 1889, 17093, 5933, 48109, 244387, 0 };
            const std::uint32_t dim20840JoeKuoD6Init[]   =   { 1, 3, 3, 7, 11, 11, 71, 243, 235, 941, 1875, 2387, 1139, 16275, 4537, 18791, 67927, 156759, 0 };
            const std::uint32_t dim20841JoeKuoD6Init[]   =   { 1, 3, 5, 5, 11, 35, 29, 5, 351, 223, 847, 1539, 4903, 7619, 24907, 37071, 57899, 32981, 0 };
            const std::uint32_t dim20842JoeKuoD6Init[]   =   { 1, 3, 1, 7, 23, 7, 119, 17, 123, 845, 1423, 2995, 3595, 13287, 31217, 33939, 6891, 156477, 0 };
            const std::uint32_t dim20843JoeKuoD6Init[]   =   { 1, 1, 1, 9, 11, 55, 121, 85, 175, 757, 1093, 513, 1117, 14049, 22377, 4623, 38511, 51391, 0 };
            const std::uint32_t dim20844JoeKuoD6Init[]   =   { 1, 1, 7, 1, 17, 1, 7, 185, 173, 841, 61, 2735, 6679, 7617, 17309, 58047, 11791, 228635, 0 };
            const std::uint32_t dim20845JoeKuoD6Init[]   =   { 1, 1, 5, 5, 1, 1, 61, 57, 37, 857, 531, 2655, 1907, 4245, 3047, 50489, 93447, 116637, 0 };
            const std::uint32_t dim20846JoeKuoD6Init[]   =   { 1, 3, 5, 7, 27, 47, 121, 95, 73, 63, 539, 137, 1765, 4659, 31141, 24495, 109541, 16421, 0 };
            const std::uint32_t dim20847JoeKuoD6Init[]   =   { 1, 3, 7, 13, 13, 25, 47, 45, 97, 243, 1509, 3539, 4791, 5627, 31981, 57663, 65359, 32183, 0 };
            const std::uint32_t dim20848JoeKuoD6Init[]   =   { 1, 1, 1, 7, 15, 57, 117, 249, 183, 849, 557, 833, 5751, 8035, 3371, 11389, 125581, 248799, 0 };
            const std::uint32_t dim20849JoeKuoD6Init[]   =   { 1, 3, 1, 15, 13, 31, 59, 243, 17, 473, 289, 1527, 649, 2807, 6183, 6173, 74381, 261673, 0 };
            const std::uint32_t dim20850JoeKuoD6Init[]   =   { 1, 1, 7, 7, 19, 17, 95, 81, 191, 487, 2023, 307, 3261, 13885, 9285, 30831, 114009, 26483, 0 };
            const std::uint32_t dim20851JoeKuoD6Init[]   =   { 1, 1, 3, 11, 17, 21, 85, 193, 477, 267, 393, 39, 5793, 8621, 25379, 9721, 13947, 44235, 0 };
            const std::uint32_t dim20852JoeKuoD6Init[]   =   { 1, 1, 7, 5, 27, 33, 93, 9, 471, 751, 1279, 695, 2625, 7061, 29577, 5403, 80705, 77895, 0 };
            const std::uint32_t dim20853JoeKuoD6Init[]   =   { 1, 1, 3, 11, 7, 25, 125, 9, 233, 935, 1897, 3685, 595, 15499, 43, 29251, 18029, 250231, 0 };
            const std::uint32_t dim20854JoeKuoD6Init[]   =   { 1, 1, 5, 1, 9, 55, 125, 179, 287, 371, 233, 149, 5639, 5737, 25251, 103, 117015, 35579, 0 };
            const std::uint32_t dim20855JoeKuoD6Init[]   =   { 1, 1, 5, 9, 17, 33, 69, 15, 209, 521, 1083, 2469, 679, 9307, 31539, 63889, 48825, 126327, 0 };
            const std::uint32_t dim20856JoeKuoD6Init[]   =   { 1, 3, 5, 15, 15, 41, 105, 121, 21, 935, 721, 445, 6759, 4227, 15227, 54933, 69589, 2689, 0 };
            const std::uint32_t dim20857JoeKuoD6Init[]   =   { 1, 1, 7, 15, 1, 15, 111, 141, 279, 1013, 825, 1069, 3793, 12929, 153, 11463, 87759, 179987, 0 };
            const std::uint32_t dim20858JoeKuoD6Init[]   =   { 1, 1, 1, 9, 15, 59, 109, 103, 223, 695, 1979, 1241, 2559, 8627, 10559, 53319, 94311, 245193, 0 };
            const std::uint32_t dim20859JoeKuoD6Init[]   =   { 1, 1, 5, 3, 1, 41, 51, 129, 297, 15, 637, 2489, 343, 13549, 7707, 36757, 55703, 161043, 0 };
            const std::uint32_t dim20860JoeKuoD6Init[]   =   { 1, 3, 5, 1, 13, 35, 119, 219, 319, 733, 789, 1343, 8035, 15049, 981, 14477, 13717, 177481, 0 };
            const std::uint32_t dim20861JoeKuoD6Init[]   =   { 1, 1, 1, 11, 5, 17, 3, 43, 129, 705, 1701, 3635, 1201, 12283, 27443, 54257, 102281, 211859, 0 };
            const std::uint32_t dim20862JoeKuoD6Init[]   =   { 1, 3, 1, 13, 7, 63, 9, 45, 283, 41, 801, 131, 2797, 13329, 19011, 21055, 122965, 7961, 0 };
            const std::uint32_t dim20863JoeKuoD6Init[]   =   { 1, 3, 3, 5, 9, 27, 99, 129, 499, 523, 1939, 3661, 455, 12601, 11723, 3727, 32671, 78251, 0 };
            const std::uint32_t dim20864JoeKuoD6Init[]   =   { 1, 3, 7, 5, 9, 57, 63, 47, 49, 745, 945, 2927, 6659, 1023, 9991, 55379, 105295, 259901, 0 };
            const std::uint32_t dim20865JoeKuoD6Init[]   =   { 1, 1, 3, 3, 3, 47, 15, 237, 193, 409, 1165, 3581, 719, 3049, 14679, 31559, 7825, 96083, 0 };
            const std::uint32_t dim20866JoeKuoD6Init[]   =   { 1, 1, 7, 11, 9, 55, 29, 123, 163, 415, 2013, 97, 1471, 1409, 28867, 50405, 99417, 57113, 0 };
            const std::uint32_t dim20867JoeKuoD6Init[]   =   { 1, 1, 7, 15, 5, 17, 57, 123, 25, 119, 1699, 1289, 3139, 7177, 13465, 33583, 34517, 182669, 0 };
            const std::uint32_t dim20868JoeKuoD6Init[]   =   { 1, 1, 3, 1, 15, 45, 79, 7, 461, 223, 691, 3071, 6233, 14997, 4083, 65391, 60571, 82929, 0 };
            const std::uint32_t dim20869JoeKuoD6Init[]   =   { 1, 3, 5, 1, 25, 39, 89, 105, 497, 685, 1921, 133, 4849, 8467, 609, 62183, 123787, 223025, 0 };
            const std::uint32_t dim20870JoeKuoD6Init[]   =   { 1, 1, 1, 13, 3, 57, 117, 241, 501, 107, 1253, 3097, 603, 10645, 3395, 13997, 112527, 208263, 0 };
            const std::uint32_t dim20871JoeKuoD6Init[]   =   { 1, 1, 7, 9, 7, 31, 25, 97, 205, 785, 517, 549, 6841, 7097, 9635, 17151, 57135, 105469, 0 };
            const std::uint32_t dim20872JoeKuoD6Init[]   =   { 1, 3, 7, 1, 25, 35, 43, 75, 179, 1023, 1921, 1529, 2791, 6747, 9135, 61801, 46729, 26821, 0 };
            const std::uint32_t dim20873JoeKuoD6Init[]   =   { 1, 1, 3, 1, 31, 49, 107, 219, 285, 501, 1503, 3103, 5257, 14561, 31493, 7753, 34375, 260357, 0 };
            const std::uint32_t dim20874JoeKuoD6Init[]   =   { 1, 3, 7, 13, 15, 7, 75, 57, 329, 67, 1541, 2445, 3069, 6723, 10189, 22913, 110781, 243765, 0 };
            const std::uint32_t dim20875JoeKuoD6Init[]   =   { 1, 1, 5, 3, 5, 45, 47, 39, 493, 787, 1019, 3933, 535, 1763, 139, 45967, 123167, 115019, 0 };
            const std::uint32_t dim20876JoeKuoD6Init[]   =   { 1, 3, 1, 3, 23, 59, 93, 139, 349, 973, 1401, 2109, 701, 461, 19199, 21733, 80009, 37239, 0 };
            const std::uint32_t dim20877JoeKuoD6Init[]   =   { 1, 1, 3, 5, 3, 39, 117, 77, 257, 117, 1991, 3371, 509, 3963, 14579, 62459, 52281, 99209, 0 };
            const std::uint32_t dim20878JoeKuoD6Init[]   =   { 1, 3, 1, 15, 29, 47, 73, 157, 429, 497, 39, 123, 4851, 12871, 4567, 29453, 90777, 188683, 0 };
            const std::uint32_t dim20879JoeKuoD6Init[]   =   { 1, 3, 3, 1, 17, 25, 5, 247, 61, 81, 1555, 2167, 6003, 15911, 16023, 7841, 50731, 229163, 0 };
            const std::uint32_t dim20880JoeKuoD6Init[]   =   { 1, 1, 5, 9, 9, 39, 89, 37, 105, 133, 333, 2863, 7249, 2355, 9407, 28145, 25923, 68827, 0 };
            const std::uint32_t dim20881JoeKuoD6Init[]   =   { 1, 3, 7, 13, 15, 55, 11, 93, 197, 447, 1793, 1793, 4639, 1869, 1711, 1439, 15899, 106931, 0 };
            const std::uint32_t dim20882JoeKuoD6Init[]   =   { 1, 1, 5, 13, 23, 11, 67, 155, 511, 363, 1073, 2249, 719, 11167, 7953, 21699, 55735, 47353, 0 };
            const std::uint32_t dim20883JoeKuoD6Init[]   =   { 1, 1, 3, 3, 21, 59, 123, 227, 65, 695, 1769, 4057, 7071, 1827, 13639, 45711, 84019, 96897, 0 };
            const std::uint32_t dim20884JoeKuoD6Init[]   =   { 1, 3, 1, 11, 25, 51, 57, 139, 147, 589, 1565, 511, 3629, 7329, 9565, 62893, 85789, 112047, 0 };
            const std::uint32_t dim20885JoeKuoD6Init[]   =   { 1, 3, 5, 5, 23, 11, 93, 75, 25, 947, 1489, 4081, 3395, 4655, 27853, 41299, 89447, 100971, 0 };
            const std::uint32_t dim20886JoeKuoD6Init[]   =   { 1, 3, 5, 11, 25, 63, 93, 227, 411, 49, 403, 437, 1739, 8453, 31693, 51439, 89729, 113405, 0 };
            const std::uint32_t dim20887JoeKuoD6Init[]   =   { 1, 3, 7, 9, 29, 13, 51, 155, 403, 627, 173, 2111, 833, 11453, 17673, 7121, 52943, 114835, 0 };
            const std::uint32_t dim20888JoeKuoD6Init[]   =   { 1, 1, 5, 13, 11, 11, 105, 101, 309, 577, 1003, 3667, 3489, 11807, 6119, 13773, 89879, 12391, 0 };
            const std::uint32_t dim20889JoeKuoD6Init[]   =   { 1, 3, 7, 9, 17, 11, 111, 239, 225, 723, 933, 3353, 2003, 5273, 207, 38539, 82539, 209781, 0 };
            const std::uint32_t dim20890JoeKuoD6Init[]   =   { 1, 1, 7, 13, 15, 53, 69, 105, 155, 445, 353, 617, 5625, 13439, 29223, 60439, 119635, 49643, 0 };
            const std::uint32_t dim20891JoeKuoD6Init[]   =   { 1, 1, 3, 11, 13, 25, 107, 27, 109, 313, 1721, 2647, 1861, 10631, 17131, 31365, 65319, 102905, 0 };
            const std::uint32_t dim20892JoeKuoD6Init[]   =   { 1, 1, 1, 7, 21, 29, 39, 167, 341, 115, 1523, 2209, 95, 4399, 3881, 38875, 107691, 132471, 0 };
            const std::uint32_t dim20893JoeKuoD6Init[]   =   { 1, 1, 1, 13, 15, 61, 125, 23, 301, 407, 1497, 3731, 7013, 5405, 31233, 51701, 45619, 107407, 0 };
            const std::uint32_t dim20894JoeKuoD6Init[]   =   { 1, 3, 5, 5, 31, 27, 77, 21, 339, 1013, 371, 19, 5733, 2177, 15547, 27595, 6805, 172695, 0 };
            const std::uint32_t dim20895JoeKuoD6Init[]   =   { 1, 3, 5, 11, 5, 15, 71, 23, 441, 169, 1715, 437, 1791, 293, 13441, 11225, 119119, 223035, 0 };
            const std::uint32_t dim20896JoeKuoD6Init[]   =   { 1, 3, 1, 5, 11, 15, 95, 127, 433, 789, 899, 2591, 2339, 8237, 20765, 32897, 51511, 58437, 0 };
            const std::uint32_t dim20897JoeKuoD6Init[]   =   { 1, 3, 5, 9, 11, 57, 103, 5, 401, 51, 1813, 923, 1983, 1853, 21913, 3051, 56309, 19423, 0 };
            const std::uint32_t dim20898JoeKuoD6Init[]   =   { 1, 1, 3, 15, 3, 3, 41, 5, 231, 35, 391, 185, 7585, 1005, 20311, 11193, 18275, 114131, 0 };
            const std::uint32_t dim20899JoeKuoD6Init[]   =   { 1, 1, 3, 9, 13, 13, 115, 203, 223, 575, 459, 1839, 3949, 16027, 23137, 13723, 19195, 249337, 0 };
            const std::uint32_t dim20900JoeKuoD6Init[]   =   { 1, 1, 1, 9, 21, 51, 39, 245, 187, 609, 319, 2927, 3625, 10789, 31291, 45557, 45935, 132447, 0 };
            const std::uint32_t dim20901JoeKuoD6Init[]   =   { 1, 3, 3, 9, 25, 37, 47, 55, 219, 409, 1927, 553, 3953, 6209, 11807, 11133, 48047, 132437, 0 };
            const std::uint32_t dim20902JoeKuoD6Init[]   =   { 1, 3, 1, 13, 23, 31, 109, 167, 281, 179, 233, 1603, 7391, 9091, 27021, 31213, 13093, 86017, 0 };
            const std::uint32_t dim20903JoeKuoD6Init[]   =   { 1, 3, 1, 13, 13, 15, 7, 29, 409, 59, 505, 1307, 6247, 6055, 5531, 59727, 58069, 84049, 0 };
            const std::uint32_t dim20904JoeKuoD6Init[]   =   { 1, 1, 5, 7, 19, 7, 103, 245, 133, 609, 1087, 2365, 3341, 1689, 18841, 19625, 47413, 63445, 0 };
            const std::uint32_t dim20905JoeKuoD6Init[]   =   { 1, 1, 7, 3, 11, 27, 79, 75, 97, 355, 493, 2035, 3413, 11835, 9157, 51173, 1, 71797, 0 };
            const std::uint32_t dim20906JoeKuoD6Init[]   =   { 1, 1, 5, 5, 29, 1, 43, 135, 473, 329, 1197, 1693, 3823, 7723, 24771, 22349, 94383, 41461, 0 };
            const std::uint32_t dim20907JoeKuoD6Init[]   =   { 1, 3, 3, 15, 25, 9, 79, 213, 317, 615, 541, 441, 505, 13665, 3691, 17825, 49303, 91783, 0 };
            const std::uint32_t dim20908JoeKuoD6Init[]   =   { 1, 3, 1, 11, 27, 33, 65, 31, 469, 799, 1251, 3357, 5239, 5651, 13317, 28553, 64225, 9805, 0 };
            const std::uint32_t dim20909JoeKuoD6Init[]   =   { 1, 1, 7, 13, 9, 49, 77, 43, 363, 719, 1943, 1285, 1587, 1047, 29419, 24025, 89901, 229095, 0 };
            const std::uint32_t dim20910JoeKuoD6Init[]   =   { 1, 1, 1, 15, 19, 57, 33, 243, 111, 183, 497, 603, 923, 1957, 6493, 11833, 7331, 229975, 0 };
            const std::uint32_t dim20911JoeKuoD6Init[]   =   { 1, 3, 1, 1, 13, 43, 31, 25, 169, 303, 69, 723, 1745, 1025, 14301, 2523, 111887, 179519, 0 };
            const std::uint32_t dim20912JoeKuoD6Init[]   =   { 1, 3, 1, 5, 31, 55, 11, 103, 391, 881, 1885, 3923, 7507, 377, 29331, 32167, 56915, 44211, 0 };
            const std::uint32_t dim20913JoeKuoD6Init[]   =   { 1, 1, 7, 1, 27, 55, 33, 141, 393, 73, 701, 3173, 973, 15553, 10219, 51441, 55201, 131055, 0 };
            const std::uint32_t dim20914JoeKuoD6Init[]   =   { 1, 1, 3, 9, 1, 31, 115, 85, 173, 227, 163, 157, 5569, 8291, 27163, 7581, 8699, 104523, 0 };
            const std::uint32_t dim20915JoeKuoD6Init[]   =   { 1, 1, 1, 5, 5, 19, 11, 55, 217, 571, 1001, 945, 6237, 1993, 11809, 63893, 60081, 102997, 0 };
            const std::uint32_t dim20916JoeKuoD6Init[]   =   { 1, 3, 3, 15, 15, 7, 51, 161, 147, 263, 1701, 1079, 3027, 11779, 24885, 16127, 68985, 162975, 0 };
            const std::uint32_t dim20917JoeKuoD6Init[]   =   { 1, 3, 1, 9, 25, 1, 47, 107, 149, 997, 1779, 2905, 4951, 10345, 31059, 63831, 117219, 251935, 0 };
            const std::uint32_t dim20918JoeKuoD6Init[]   =   { 1, 3, 3, 9, 5, 23, 83, 95, 399, 343, 1597, 1733, 5959, 9685, 4721, 59109, 113633, 80365, 0 };
            const std::uint32_t dim20919JoeKuoD6Init[]   =   { 1, 1, 7, 11, 31, 43, 71, 133, 305, 529, 645, 3095, 6273, 4019, 14433, 41609, 64093, 79051, 0 };
            const std::uint32_t dim20920JoeKuoD6Init[]   =   { 1, 3, 5, 11, 1, 63, 123, 25, 245, 583, 1013, 3275, 2997, 13021, 27515, 16233, 113093, 249101, 0 };
            const std::uint32_t dim20921JoeKuoD6Init[]   =   { 1, 1, 1, 9, 3, 59, 113, 155, 125, 423, 259, 1559, 3745, 9105, 27673, 36601, 36117, 47953, 0 };
            const std::uint32_t dim20922JoeKuoD6Init[]   =   { 1, 3, 3, 7, 19, 41, 55, 87, 53, 801, 661, 329, 3391, 7581, 25487, 25751, 120171, 35953, 0 };
            const std::uint32_t dim20923JoeKuoD6Init[]   =   { 1, 1, 7, 15, 31, 57, 49, 179, 147, 139, 957, 289, 4321, 8747, 53, 46003, 40219, 96855, 0 };
            const std::uint32_t dim20924JoeKuoD6Init[]   =   { 1, 1, 7, 9, 29, 49, 71, 101, 389, 793, 1355, 3263, 6331, 4869, 28479, 8335, 74653, 8519, 0 };
            const std::uint32_t dim20925JoeKuoD6Init[]   =   { 1, 1, 1, 13, 1, 19, 31, 161, 261, 679, 1115, 985, 2855, 4395, 15087, 18593, 98535, 52537, 0 };
            const std::uint32_t dim20926JoeKuoD6Init[]   =   { 1, 1, 3, 11, 15, 51, 79, 7, 75, 75, 753, 2637, 7193, 7961, 21411, 24273, 7543, 6277, 0 };
            const std::uint32_t dim20927JoeKuoD6Init[]   =   { 1, 3, 1, 5, 5, 51, 67, 191, 201, 777, 587, 1439, 1027, 3759, 31141, 42159, 58475, 7355, 0 };
            const std::uint32_t dim20928JoeKuoD6Init[]   =   { 1, 3, 5, 3, 15, 37, 11, 251, 53, 799, 739, 2225, 6985, 9183, 12341, 29963, 44101, 23889, 0 };
            const std::uint32_t dim20929JoeKuoD6Init[]   =   { 1, 1, 3, 3, 5, 33, 81, 223, 89, 531, 301, 305, 2401, 4015, 18607, 65041, 82447, 228487, 0 };
            const std::uint32_t dim20930JoeKuoD6Init[]   =   { 1, 3, 1, 7, 15, 29, 71, 247, 445, 1005, 1229, 3897, 899, 11175, 6349, 29145, 103153, 90275, 0 };
            const std::uint32_t dim20931JoeKuoD6Init[]   =   { 1, 3, 3, 7, 15, 7, 75, 13, 417, 719, 121, 1345, 3737, 4119, 15259, 33579, 57727, 111517, 0 };
            const std::uint32_t dim20932JoeKuoD6Init[]   =   { 1, 3, 7, 3, 31, 11, 49, 61, 405, 741, 1607, 1561, 4655, 9775, 14349, 27431, 91791, 228607, 0 };
            const std::uint32_t dim20933JoeKuoD6Init[]   =   { 1, 3, 5, 13, 17, 27, 93, 153, 99, 683, 219, 3783, 6963, 1633, 6621, 8133, 5111, 57333, 0 };
            const std::uint32_t dim20934JoeKuoD6Init[]   =   { 1, 3, 3, 3, 25, 29, 75, 155, 159, 25, 637, 3053, 4737, 5831, 9651, 45331, 100407, 188607, 0 };
            const std::uint32_t dim20935JoeKuoD6Init[]   =   { 1, 3, 1, 9, 21, 55, 123, 27, 509, 227, 1569, 1379, 7137, 11749, 14257, 38349, 459, 54873, 0 };
            const std::uint32_t dim20936JoeKuoD6Init[]   =   { 1, 1, 7, 15, 29, 35, 81, 79, 237, 155, 1551, 343, 5127, 3233, 3691, 59917, 7367, 181979, 0 };
            const std::uint32_t dim20937JoeKuoD6Init[]   =   { 1, 3, 1, 15, 1, 57, 111, 121, 375, 635, 1529, 635, 2337, 6553, 22067, 36047, 80099, 116411, 0 };
            const std::uint32_t dim20938JoeKuoD6Init[]   =   { 1, 1, 3, 3, 29, 27, 19, 3, 69, 197, 1829, 1907, 5901, 12651, 3295, 7805, 57871, 47571, 0 };
            const std::uint32_t dim20939JoeKuoD6Init[]   =   { 1, 1, 1, 13, 21, 5, 115, 51, 203, 991, 1731, 1101, 1607, 14323, 12233, 48047, 33969, 147621, 0 };
            const std::uint32_t dim20940JoeKuoD6Init[]   =   { 1, 3, 3, 1, 25, 55, 41, 31, 101, 551, 1519, 1915, 6961, 13919, 15339, 13141, 107625, 9247, 0 };
            const std::uint32_t dim20941JoeKuoD6Init[]   =   { 1, 1, 7, 11, 17, 25, 87, 175, 341, 445, 1813, 2995, 3217, 6015, 1637, 65243, 72743, 248715, 0 };
            const std::uint32_t dim20942JoeKuoD6Init[]   =   { 1, 1, 5, 13, 11, 1, 61, 139, 233, 167, 1363, 1991, 7999, 16289, 25595, 8915, 32205, 169963, 0 };
            const std::uint32_t dim20943JoeKuoD6Init[]   =   { 1, 1, 1, 13, 31, 33, 67, 57, 121, 477, 755, 2035, 3683, 16205, 5511, 25615, 5169, 128843, 0 };
            const std::uint32_t dim20944JoeKuoD6Init[]   =   { 1, 3, 5, 15, 31, 1, 89, 29, 493, 379, 1627, 491, 2503, 8105, 30275, 27379, 43905, 46397, 0 };
            const std::uint32_t dim20945JoeKuoD6Init[]   =   { 1, 1, 7, 9, 31, 41, 127, 121, 61, 561, 223, 3231, 7321, 3683, 15455, 8019, 116739, 96557, 0 };
            const std::uint32_t dim20946JoeKuoD6Init[]   =   { 1, 1, 5, 9, 19, 41, 25, 65, 111, 535, 611, 1631, 4251, 107, 19787, 40749, 65701, 48749, 0 };
            const std::uint32_t dim20947JoeKuoD6Init[]   =   { 1, 3, 3, 11, 27, 49, 75, 93, 15, 937, 1517, 1577, 7485, 8713, 15979, 13799, 103057, 144799, 0 };
            const std::uint32_t dim20948JoeKuoD6Init[]   =   { 1, 1, 7, 7, 7, 29, 3, 63, 177, 781, 2001, 315, 6703, 8055, 19081, 33641, 44279, 87597, 0 };
            const std::uint32_t dim20949JoeKuoD6Init[]   =   { 1, 1, 7, 11, 29, 53, 83, 223, 275, 951, 1883, 2447, 1815, 9313, 9247, 17185, 8143, 135247, 0 };
            const std::uint32_t dim20950JoeKuoD6Init[]   =   { 1, 1, 5, 13, 21, 47, 87, 55, 169, 95, 777, 2787, 7227, 11373, 16707, 28237, 30789, 64589, 0 };
            const std::uint32_t dim20951JoeKuoD6Init[]   =   { 1, 1, 1, 11, 15, 41, 1, 55, 337, 493, 1379, 2505, 6831, 10955, 1875, 21821, 54101, 9379, 0 };
            const std::uint32_t dim20952JoeKuoD6Init[]   =   { 1, 3, 5, 15, 27, 9, 121, 49, 439, 781, 1457, 1341, 7433, 5879, 13039, 24001, 64059, 157077, 0 };
            const std::uint32_t dim20953JoeKuoD6Init[]   =   { 1, 1, 1, 9, 19, 55, 89, 37, 255, 345, 215, 4067, 8151, 14253, 12121, 3637, 29185, 60643, 0 };
            const std::uint32_t dim20954JoeKuoD6Init[]   =   { 1, 3, 1, 7, 31, 39, 71, 29, 71, 83, 1249, 871, 8037, 1001, 25245, 26651, 34509, 123607, 0 };
            const std::uint32_t dim20955JoeKuoD6Init[]   =   { 1, 1, 3, 11, 13, 21, 15, 171, 255, 373, 429, 2179, 4431, 16087, 17949, 16307, 129877, 186495, 0 };
            const std::uint32_t dim20956JoeKuoD6Init[]   =   { 1, 3, 3, 9, 17, 45, 75, 175, 3, 403, 215, 1781, 7875, 14113, 6967, 65263, 125885, 232983, 0 };
            const std::uint32_t dim20957JoeKuoD6Init[]   =   { 1, 1, 7, 9, 21, 57, 73, 105, 163, 583, 587, 2743, 2199, 5187, 5571, 56399, 797, 192405, 0 };
            const std::uint32_t dim20958JoeKuoD6Init[]   =   { 1, 1, 1, 3, 29, 27, 71, 145, 11, 455, 1505, 2789, 4083, 12345, 14785, 4981, 95121, 134977, 0 };
            const std::uint32_t dim20959JoeKuoD6Init[]   =   { 1, 1, 1, 1, 1, 27, 1, 145, 473, 483, 83, 3009, 7241, 13633, 15071, 30767, 128103, 94727, 0 };
            const std::uint32_t dim20960JoeKuoD6Init[]   =   { 1, 3, 5, 15, 17, 51, 71, 21, 237, 65, 901, 3365, 7831, 3027, 8751, 14435, 79445, 172587, 0 };
            const std::uint32_t dim20961JoeKuoD6Init[]   =   { 1, 1, 5, 1, 9, 49, 49, 31, 395, 339, 343, 1813, 2607, 9347, 11239, 6761, 127623, 43459, 0 };
            const std::uint32_t dim20962JoeKuoD6Init[]   =   { 1, 1, 1, 1, 13, 23, 71, 131, 225, 229, 117, 889, 8145, 5953, 10679, 38687, 80029, 63689, 0 };
            const std::uint32_t dim20963JoeKuoD6Init[]   =   { 1, 1, 5, 1, 29, 1, 87, 181, 441, 353, 257, 335, 203, 10897, 24085, 26967, 62573, 170285, 0 };
            const std::uint32_t dim20964JoeKuoD6Init[]   =   { 1, 1, 7, 3, 3, 39, 47, 135, 353, 977, 89, 259, 6411, 5511, 10697, 57623, 27367, 108451, 0 };
            const std::uint32_t dim20965JoeKuoD6Init[]   =   { 1, 3, 3, 11, 9, 57, 95, 211, 237, 281, 1703, 2107, 2179, 3411, 32621, 5387, 29971, 102889, 0 };
            const std::uint32_t dim20966JoeKuoD6Init[]   =   { 1, 1, 1, 13, 27, 49, 47, 49, 413, 985, 649, 1245, 807, 13637, 21741, 32565, 80135, 127971, 0 };
            const std::uint32_t dim20967JoeKuoD6Init[]   =   { 1, 3, 7, 13, 3, 19, 57, 97, 493, 597, 135, 1689, 5011, 4579, 6093, 28341, 37279, 142197, 0 };
            const std::uint32_t dim20968JoeKuoD6Init[]   =   { 1, 3, 1, 15, 15, 31, 3, 89, 327, 107, 827, 1111, 261, 6211, 4359, 38553, 43297, 75057, 0 };
            const std::uint32_t dim20969JoeKuoD6Init[]   =   { 1, 1, 1, 9, 19, 19, 53, 195, 141, 297, 141, 3859, 4173, 12243, 31399, 6353, 110505, 172219, 0 };
            const std::uint32_t dim20970JoeKuoD6Init[]   =   { 1, 3, 3, 9, 31, 51, 59, 53, 55, 723, 1575, 3399, 8057, 12317, 8393, 1719, 96987, 228955, 0 };
            const std::uint32_t dim20971JoeKuoD6Init[]   =   { 1, 1, 7, 11, 19, 59, 41, 9, 217, 267, 629, 2977, 4515, 463, 31773, 61765, 78827, 51331, 0 };
            const std::uint32_t dim20972JoeKuoD6Init[]   =   { 1, 3, 3, 13, 9, 55, 51, 177, 183, 431, 555, 3573, 7977, 3067, 21111, 12971, 78283, 260721, 0 };
            const std::uint32_t dim20973JoeKuoD6Init[]   =   { 1, 1, 1, 11, 27, 5, 89, 69, 435, 199, 221, 1017, 7703, 7469, 7755, 46319, 37941, 55285, 0 };
            const std::uint32_t dim20974JoeKuoD6Init[]   =   { 1, 1, 7, 13, 19, 55, 53, 207, 367, 177, 1483, 2857, 3753, 5493, 13349, 14033, 7933, 93457, 0 };
            const std::uint32_t dim20975JoeKuoD6Init[]   =   { 1, 1, 7, 3, 27, 35, 19, 223, 341, 137, 1195, 1263, 5937, 13517, 55, 6391, 106173, 176503, 0 };
            const std::uint32_t dim20976JoeKuoD6Init[]   =   { 1, 3, 7, 11, 23, 25, 37, 103, 351, 945, 1205, 2543, 3875, 155, 27777, 36647, 47979, 25113, 0 };
            const std::uint32_t dim20977JoeKuoD6Init[]   =   { 1, 1, 3, 15, 25, 59, 79, 39, 17, 553, 1119, 3353, 2619, 3851, 5945, 47501, 17369, 89355, 0 };
            const std::uint32_t dim20978JoeKuoD6Init[]   =   { 1, 1, 1, 13, 9, 55, 13, 173, 207, 925, 1855, 1871, 7851, 1361, 20117, 51677, 77703, 51309, 0 };
            const std::uint32_t dim20979JoeKuoD6Init[]   =   { 1, 3, 1, 1, 31, 57, 3, 25, 329, 927, 1683, 1447, 6853, 103, 9549, 21393, 415, 122749, 0 };
            const std::uint32_t dim20980JoeKuoD6Init[]   =   { 1, 1, 5, 5, 31, 61, 31, 213, 85, 531, 931, 999, 1189, 5189, 15127, 47799, 70769, 81901, 0 };
            const std::uint32_t dim20981JoeKuoD6Init[]   =   { 1, 1, 3, 1, 5, 59, 89, 53, 105, 761, 313, 3013, 4093, 9595, 4287, 51505, 20095, 232933, 0 };
            const std::uint32_t dim20982JoeKuoD6Init[]   =   { 1, 1, 7, 7, 23, 9, 41, 29, 399, 395, 759, 2541, 2373, 15365, 12083, 49579, 34401, 168121, 0 };
            const std::uint32_t dim20983JoeKuoD6Init[]   =   { 1, 1, 3, 1, 7, 23, 37, 183, 205, 377, 1081, 1081, 7767, 363, 14571, 16265, 18267, 102155, 0 };
            const std::uint32_t dim20984JoeKuoD6Init[]   =   { 1, 3, 3, 15, 19, 11, 59, 59, 465, 437, 965, 3707, 3505, 14785, 23605, 12505, 130607, 40693, 0 };
            const std::uint32_t dim20985JoeKuoD6Init[]   =   { 1, 1, 3, 13, 5, 15, 91, 33, 235, 215, 1997, 2035, 7407, 3203, 27143, 14007, 96411, 593, 0 };
            const std::uint32_t dim20986JoeKuoD6Init[]   =   { 1, 3, 7, 1, 19, 51, 1, 69, 489, 629, 1731, 393, 6807, 10521, 23971, 45649, 105183, 207351, 0 };
            const std::uint32_t dim20987JoeKuoD6Init[]   =   { 1, 3, 5, 3, 5, 41, 89, 141, 469, 177, 109, 2439, 7155, 2083, 31993, 13933, 100557, 137255, 0 };
            const std::uint32_t dim20988JoeKuoD6Init[]   =   { 1, 1, 7, 15, 21, 45, 41, 197, 365, 177, 61, 811, 2535, 5219, 3689, 53129, 42063, 60759, 0 };
            const std::uint32_t dim20989JoeKuoD6Init[]   =   { 1, 3, 5, 1, 23, 7, 19, 193, 253, 793, 539, 3747, 2611, 16211, 17199, 14875, 95377, 6999, 0 };
            const std::uint32_t dim20990JoeKuoD6Init[]   =   { 1, 1, 3, 5, 9, 5, 9, 129, 217, 473, 151, 3053, 6981, 8075, 32121, 31995, 41271, 208927, 0 };
            const std::uint32_t dim20991JoeKuoD6Init[]   =   { 1, 1, 5, 9, 9, 9, 89, 139, 381, 937, 1937, 1879, 8191, 2237, 25629, 51471, 87639, 173697, 0 };
            const std::uint32_t dim20992JoeKuoD6Init[]   =   { 1, 1, 5, 9, 17, 35, 81, 223, 161, 315, 139, 2597, 2599, 16191, 2567, 54947, 8603, 121589, 0 };
            const std::uint32_t dim20993JoeKuoD6Init[]   =   { 1, 1, 5, 5, 9, 7, 33, 49, 49, 723, 1013, 1055, 4025, 1471, 30081, 17475, 127931, 63723, 0 };
            const std::uint32_t dim20994JoeKuoD6Init[]   =   { 1, 3, 7, 7, 9, 49, 107, 17, 335, 119, 1959, 3613, 8129, 11033, 12197, 23803, 112595, 131655, 0 };
            const std::uint32_t dim20995JoeKuoD6Init[]   =   { 1, 3, 5, 11, 3, 45, 91, 17, 181, 1005, 985, 3045, 853, 8181, 5517, 48515, 16225, 237151, 0 };
            const std::uint32_t dim20996JoeKuoD6Init[]   =   { 1, 1, 3, 1, 3, 63, 35, 135, 61, 383, 1233, 675, 151, 2157, 18711, 37113, 40353, 61783, 0 };
            const std::uint32_t dim20997JoeKuoD6Init[]   =   { 1, 3, 5, 5, 29, 3, 105, 11, 351, 761, 165, 911, 6903, 10111, 1779, 24601, 3177, 110301, 0 };
            const std::uint32_t dim20998JoeKuoD6Init[]   =   { 1, 1, 3, 15, 25, 19, 73, 237, 263, 161, 731, 3853, 7705, 14497, 30799, 32979, 100729, 21761, 0 };
            const std::uint32_t dim20999JoeKuoD6Init[]   =   { 1, 1, 3, 5, 27, 9, 3, 149, 207, 715, 1435, 2563, 2451, 7951, 26313, 55115, 99423, 231639, 0 };
            const std::uint32_t dim21000JoeKuoD6Init[]   =   { 1, 1, 5, 15, 11, 51, 13, 47, 311, 969, 2013, 357, 4847, 1831, 2235, 22779, 32375, 40893, 0 };
            const std::uint32_t dim21001JoeKuoD6Init[]   =   { 1, 1, 3, 9, 21, 45, 11, 99, 275, 849, 443, 1257, 7855, 9121, 6549, 20289, 101337, 13869, 0 };
            const std::uint32_t dim21002JoeKuoD6Init[]   =   { 1, 1, 1, 15, 25, 27, 15, 111, 215, 437, 1923, 1985, 4603, 15469, 6667, 17941, 50433, 152759, 0 };
            const std::uint32_t dim21003JoeKuoD6Init[]   =   { 1, 3, 7, 15, 7, 37, 119, 53, 337, 853, 1785, 3507, 3743, 14303, 22757, 5149, 1539, 227051, 0 };
            const std::uint32_t dim21004JoeKuoD6Init[]   =   { 1, 1, 3, 13, 11, 23, 55, 19, 495, 531, 1021, 3831, 5993, 15819, 2121, 52773, 19775, 94643, 0 };
            const std::uint32_t dim21005JoeKuoD6Init[]   =   { 1, 1, 3, 3, 23, 55, 55, 69, 457, 755, 1187, 3993, 613, 12691, 1779, 21251, 2293, 236725, 0 };
            const std::uint32_t dim21006JoeKuoD6Init[]   =   { 1, 1, 5, 9, 23, 27, 61, 125, 113, 99, 503, 699, 6873, 13141, 10649, 65209, 21773, 162749, 0 };
            const std::uint32_t dim21007JoeKuoD6Init[]   =   { 1, 1, 1, 11, 15, 27, 111, 227, 493, 361, 1071, 607, 1409, 9281, 24515, 26739, 82421, 30463, 0 };
            const std::uint32_t dim21008JoeKuoD6Init[]   =   { 1, 3, 5, 1, 11, 57, 23, 239, 265, 675, 441, 4031, 5163, 15729, 2741, 26037, 32533, 140645, 0 };
            const std::uint32_t dim21009JoeKuoD6Init[]   =   { 1, 3, 3, 7, 3, 45, 105, 135, 493, 579, 1707, 2933, 1135, 11891, 3171, 45401, 24993, 175681, 0 };
            const std::uint32_t dim21010JoeKuoD6Init[]   =   { 1, 1, 1, 11, 11, 3, 67, 213, 483, 9, 1053, 213, 3205, 8487, 16093, 7305, 122591, 31811, 0 };
            const std::uint32_t dim21011JoeKuoD6Init[]   =   { 1, 1, 5, 13, 19, 31, 13, 65, 29, 929, 343, 463, 1885, 13467, 14997, 22737, 42869, 128239, 0 };
            const std::uint32_t dim21012JoeKuoD6Init[]   =   { 1, 3, 3, 13, 9, 47, 125, 33, 475, 285, 1901, 2525, 305, 11587, 27309, 30037, 70681, 180425, 0 };
            const std::uint32_t dim21013JoeKuoD6Init[]   =   { 1, 3, 5, 15, 9, 37, 45, 149, 19, 135, 555, 4037, 5173, 12473, 983, 40923, 28561, 185941, 0 };
            const std::uint32_t dim21014JoeKuoD6Init[]   =   { 1, 3, 3, 9, 23, 35, 35, 151, 113, 885, 1553, 2233, 351, 4071, 28127, 26109, 12299, 163973, 0 };
            const std::uint32_t dim21015JoeKuoD6Init[]   =   { 1, 3, 3, 11, 17, 55, 125, 87, 315, 917, 383, 2397, 1573, 9255, 10499, 16051, 99487, 139415, 0 };
            const std::uint32_t dim21016JoeKuoD6Init[]   =   { 1, 1, 3, 1, 29, 21, 101, 153, 5, 705, 1965, 1447, 8163, 13547, 25929, 28569, 57897, 173229, 0 };
            const std::uint32_t dim21017JoeKuoD6Init[]   =   { 1, 1, 7, 15, 3, 37, 113, 213, 495, 935, 529, 2299, 6901, 1765, 4255, 14579, 14175, 112333, 0 };
            const std::uint32_t dim21018JoeKuoD6Init[]   =   { 1, 3, 3, 9, 11, 53, 89, 27, 461, 235, 1525, 3533, 3061, 4351, 12847, 21649, 10843, 60901, 0 };
            const std::uint32_t dim21019JoeKuoD6Init[]   =   { 1, 1, 5, 1, 17, 11, 17, 157, 387, 887, 2017, 3641, 923, 12659, 19691, 18657, 3127, 218819, 0 };
            const std::uint32_t dim21020JoeKuoD6Init[]   =   { 1, 3, 1, 9, 5, 3, 49, 215, 379, 765, 1375, 345, 2285, 8197, 9531, 6725, 22475, 203883, 0 };
            const std::uint32_t dim21021JoeKuoD6Init[]   =   { 1, 1, 3, 9, 19, 41, 13, 233, 97, 755, 249, 2011, 5815, 6317, 4121, 63637, 43353, 154753, 0 };
            const std::uint32_t dim21022JoeKuoD6Init[]   =   { 1, 3, 7, 15, 31, 25, 93, 197, 455, 979, 1805, 2619, 803, 5705, 1679, 29317, 66477, 159187, 0 };
            const std::uint32_t dim21023JoeKuoD6Init[]   =   { 1, 1, 1, 13, 11, 25, 61, 233, 339, 171, 559, 427, 3239, 8889, 3711, 19743, 18099, 49201, 0 };
            const std::uint32_t dim21024JoeKuoD6Init[]   =   { 1, 3, 7, 13, 19, 5, 9, 183, 355, 137, 1767, 1113, 1149, 5791, 4099, 37911, 75945, 115397, 0 };
            const std::uint32_t dim21025JoeKuoD6Init[]   =   { 1, 1, 3, 13, 27, 25, 121, 3, 337, 195, 1841, 2009, 4181, 3197, 20275, 42493, 7495, 24407, 0 };
            const std::uint32_t dim21026JoeKuoD6Init[]   =   { 1, 1, 1, 15, 3, 43, 39, 25, 57, 829, 565, 1977, 4027, 11053, 13961, 13965, 4207, 1663, 0 };
            const std::uint32_t dim21027JoeKuoD6Init[]   =   { 1, 3, 5, 9, 11, 7, 107, 205, 479, 961, 1549, 1701, 6305, 15419, 23331, 46443, 55171, 235109, 0 };
            const std::uint32_t dim21028JoeKuoD6Init[]   =   { 1, 3, 5, 5, 19, 3, 39, 211, 429, 363, 765, 283, 2469, 1947, 10481, 1969, 95545, 187671, 0 };
            const std::uint32_t dim21029JoeKuoD6Init[]   =   { 1, 1, 1, 1, 11, 55, 47, 121, 251, 63, 767, 3673, 3233, 14865, 25713, 48443, 79139, 225021, 0 };
            const std::uint32_t dim21030JoeKuoD6Init[]   =   { 1, 1, 3, 11, 25, 35, 57, 103, 385, 155, 173, 4023, 489, 1733, 14423, 61843, 24793, 9871, 0 };
            const std::uint32_t dim21031JoeKuoD6Init[]   =   { 1, 3, 1, 15, 9, 29, 99, 187, 471, 877, 1321, 2489, 7439, 4259, 32703, 1459, 42093, 261097, 0 };
            const std::uint32_t dim21032JoeKuoD6Init[]   =   { 1, 1, 3, 11, 9, 25, 113, 251, 337, 405, 847, 2451, 5649, 3449, 11703, 18271, 108005, 208789, 0 };
            const std::uint32_t dim21033JoeKuoD6Init[]   =   { 1, 3, 3, 7, 13, 53, 61, 251, 461, 461, 1557, 1215, 6731, 13349, 21003, 11573, 66751, 79733, 0 };
            const std::uint32_t dim21034JoeKuoD6Init[]   =   { 1, 1, 5, 1, 23, 49, 101, 175, 251, 577, 1667, 2561, 6545, 16305, 18457, 65067, 35843, 123445, 0 };
            const std::uint32_t dim21035JoeKuoD6Init[]   =   { 1, 1, 5, 3, 7, 9, 61, 107, 395, 137, 559, 2315, 2559, 11929, 4843, 41661, 61361, 146163, 0 };
            const std::uint32_t dim21036JoeKuoD6Init[]   =   { 1, 3, 1, 5, 1, 3, 43, 251, 329, 289, 323, 2201, 4129, 4963, 27477, 18743, 46551, 93061, 0 };
            const std::uint32_t dim21037JoeKuoD6Init[]   =   { 1, 1, 7, 3, 17, 63, 21, 159, 447, 377, 69, 2517, 8181, 6043, 3039, 7747, 72465, 41027, 0 };
            const std::uint32_t dim21038JoeKuoD6Init[]   =   { 1, 1, 1, 1, 13, 3, 45, 93, 391, 509, 867, 1561, 5017, 11851, 24891, 22531, 18993, 129421, 0 };
            const std::uint32_t dim21039JoeKuoD6Init[]   =   { 1, 3, 3, 11, 15, 1, 127, 9, 161, 321, 2003, 239, 1379, 11903, 13503, 26529, 57725, 214797, 0 };
            const std::uint32_t dim21040JoeKuoD6Init[]   =   { 1, 1, 1, 13, 31, 11, 17, 25, 1, 645, 675, 735, 2083, 1919, 18977, 4995, 91559, 230463, 0 };
            const std::uint32_t dim21041JoeKuoD6Init[]   =   { 1, 3, 1, 13, 17, 21, 107, 167, 135, 797, 715, 3275, 5437, 4253, 11671, 14867, 36041, 71751, 0 };
            const std::uint32_t dim21042JoeKuoD6Init[]   =   { 1, 3, 5, 5, 11, 49, 93, 231, 431, 567, 1605, 3281, 7049, 2947, 863, 39593, 117167, 167301, 0 };
            const std::uint32_t dim21043JoeKuoD6Init[]   =   { 1, 1, 1, 1, 5, 13, 61, 91, 127, 189, 1879, 3921, 4303, 4831, 6765, 31005, 107627, 80693, 0 };
            const std::uint32_t dim21044JoeKuoD6Init[]   =   { 1, 3, 1, 3, 1, 49, 61, 9, 467, 891, 105, 317, 137, 12789, 12367, 57455, 39777, 88047, 0 };
            const std::uint32_t dim21045JoeKuoD6Init[]   =   { 1, 1, 3, 13, 23, 63, 37, 103, 23, 223, 647, 2523, 3211, 14551, 22663, 48237, 54777, 180297, 0 };
            const std::uint32_t dim21046JoeKuoD6Init[]   =   { 1, 3, 3, 7, 29, 51, 85, 179, 441, 431, 535, 2975, 8083, 8619, 30229, 31421, 54063, 163601, 0 };
            const std::uint32_t dim21047JoeKuoD6Init[]   =   { 1, 3, 1, 1, 27, 39, 125, 171, 57, 729, 511, 957, 7541, 2347, 1669, 32323, 108531, 69943, 0 };
            const std::uint32_t dim21048JoeKuoD6Init[]   =   { 1, 3, 3, 7, 1, 33, 89, 245, 95, 21, 699, 1441, 2659, 501, 32323, 39145, 82311, 155479, 0 };
            const std::uint32_t dim21049JoeKuoD6Init[]   =   { 1, 1, 3, 11, 29, 13, 87, 251, 329, 667, 325, 2411, 7959, 8069, 20817, 42445, 121675, 113421, 0 };
            const std::uint32_t dim21050JoeKuoD6Init[]   =   { 1, 1, 1, 7, 9, 57, 109, 237, 325, 535, 89, 1285, 5649, 13673, 29375, 51553, 81723, 11003, 0 };
            const std::uint32_t dim21051JoeKuoD6Init[]   =   { 1, 3, 1, 1, 13, 5, 31, 109, 157, 817, 1303, 725, 1841, 5503, 2255, 34637, 93603, 82825, 0 };
            const std::uint32_t dim21052JoeKuoD6Init[]   =   { 1, 3, 7, 7, 5, 33, 39, 233, 217, 157, 357, 2727, 3565, 1539, 5317, 23967, 30375, 260381, 0 };
            const std::uint32_t dim21053JoeKuoD6Init[]   =   { 1, 1, 5, 3, 23, 51, 45, 181, 353, 519, 949, 3043, 1517, 3387, 15081, 5997, 31523, 80007, 0 };
            const std::uint32_t dim21054JoeKuoD6Init[]   =   { 1, 1, 3, 5, 23, 21, 83, 51, 275, 629, 1433, 1821, 3761, 2367, 32089, 13813, 99629, 64603, 0 };
            const std::uint32_t dim21055JoeKuoD6Init[]   =   { 1, 1, 5, 15, 11, 49, 69, 197, 193, 459, 1915, 787, 3631, 5219, 11109, 12311, 56625, 117439, 0 };
            const std::uint32_t dim21056JoeKuoD6Init[]   =   { 1, 3, 3, 3, 31, 29, 57, 27, 43, 231, 777, 2139, 2609, 12273, 23777, 4151, 51749, 110013, 0 };
            const std::uint32_t dim21057JoeKuoD6Init[]   =   { 1, 1, 5, 13, 9, 63, 83, 69, 225, 913, 99, 1167, 5279, 14163, 3979, 55151, 84387, 234583, 0 };
            const std::uint32_t dim21058JoeKuoD6Init[]   =   { 1, 1, 7, 5, 9, 57, 87, 23, 335, 403, 1843, 725, 5187, 4137, 24299, 44807, 98523, 217815, 0 };
            const std::uint32_t dim21059JoeKuoD6Init[]   =   { 1, 3, 3, 3, 3, 23, 115, 229, 193, 655, 1205, 3159, 1935, 113, 20943, 32917, 69633, 2133, 0 };
            const std::uint32_t dim21060JoeKuoD6Init[]   =   { 1, 3, 3, 1, 17, 5, 59, 139, 75, 185, 1951, 3689, 4997, 2761, 8673, 41783, 75075, 101063, 0 };
            const std::uint32_t dim21061JoeKuoD6Init[]   =   { 1, 3, 1, 13, 1, 51, 63, 127, 67, 743, 1049, 2055, 4249, 131, 8153, 50237, 28135, 76059, 0 };
            const std::uint32_t dim21062JoeKuoD6Init[]   =   { 1, 3, 7, 13, 5, 39, 83, 63, 429, 573, 1915, 3801, 2223, 1585, 16997, 45571, 23311, 108099, 0 };
            const std::uint32_t dim21063JoeKuoD6Init[]   =   { 1, 3, 1, 3, 15, 49, 19, 65, 433, 401, 1901, 3653, 2399, 15171, 9695, 30257, 104877, 181221, 0 };
            const std::uint32_t dim21064JoeKuoD6Init[]   =   { 1, 3, 1, 1, 25, 37, 89, 7, 81, 343, 949, 3535, 1681, 10089, 23513, 3897, 127083, 214005, 0 };
            const std::uint32_t dim21065JoeKuoD6Init[]   =   { 1, 3, 7, 13, 1, 1, 123, 89, 433, 541, 1579, 931, 3459, 11095, 20729, 13117, 59323, 90309, 0 };
            const std::uint32_t dim21066JoeKuoD6Init[]   =   { 1, 1, 7, 1, 19, 9, 31, 211, 271, 25, 1053, 2249, 6549, 12785, 16947, 55633, 70155, 253741, 0 };
            const std::uint32_t dim21067JoeKuoD6Init[]   =   { 1, 3, 5, 9, 7, 49, 11, 251, 101, 795, 1015, 2037, 1239, 10151, 22179, 749, 2373, 224517, 0 };
            const std::uint32_t dim21068JoeKuoD6Init[]   =   { 1, 3, 7, 15, 21, 19, 15, 59, 439, 621, 1081, 3041, 1587, 3077, 2319, 51135, 110513, 222551, 0 };
            const std::uint32_t dim21069JoeKuoD6Init[]   =   { 1, 1, 5, 5, 9, 61, 49, 97, 361, 647, 351, 1977, 3023, 10213, 6889, 8753, 72203, 37521, 0 };
            const std::uint32_t dim21070JoeKuoD6Init[]   =   { 1, 3, 3, 1, 7, 29, 51, 117, 259, 81, 1263, 1829, 6541, 5699, 30367, 61325, 78795, 3491, 0 };
            const std::uint32_t dim21071JoeKuoD6Init[]   =   { 1, 1, 1, 5, 5, 23, 19, 255, 267, 251, 239, 3561, 6771, 10647, 4129, 40285, 11041, 27023, 0 };
            const std::uint32_t dim21072JoeKuoD6Init[]   =   { 1, 1, 7, 5, 29, 17, 121, 91, 427, 51, 243, 1617, 5389, 3633, 14105, 5329, 109507, 93719, 0 };
            const std::uint32_t dim21073JoeKuoD6Init[]   =   { 1, 3, 7, 5, 7, 59, 107, 89, 181, 719, 1029, 585, 2415, 9175, 11605, 9271, 12105, 42503, 0 };
            const std::uint32_t dim21074JoeKuoD6Init[]   =   { 1, 3, 5, 15, 27, 15, 83, 223, 489, 901, 1823, 1515, 6295, 12509, 27179, 181, 29813, 66163, 0 };
            const std::uint32_t dim21075JoeKuoD6Init[]   =   { 1, 1, 7, 15, 5, 9, 79, 29, 201, 391, 609, 935, 4025, 201, 8333, 24557, 33739, 257979, 0 };
            const std::uint32_t dim21076JoeKuoD6Init[]   =   { 1, 3, 3, 9, 9, 19, 55, 211, 347, 943, 559, 467, 1363, 10249, 7109, 41293, 28035, 205889, 0 };
            const std::uint32_t dim21077JoeKuoD6Init[]   =   { 1, 1, 5, 3, 21, 25, 25, 163, 95, 119, 789, 1679, 3845, 1427, 25531, 13375, 121029, 194845, 0 };
            const std::uint32_t dim21078JoeKuoD6Init[]   =   { 1, 1, 5, 3, 31, 21, 83, 27, 17, 59, 885, 3889, 4795, 4383, 28739, 55129, 10387, 176437, 0 };
            const std::uint32_t dim21079JoeKuoD6Init[]   =   { 1, 3, 1, 5, 31, 39, 37, 79, 433, 313, 1155, 3025, 6141, 10695, 27819, 28227, 32161, 250515, 0 };
            const std::uint32_t dim21080JoeKuoD6Init[]   =   { 1, 1, 5, 9, 27, 41, 3, 129, 235, 621, 1171, 3305, 6309, 5323, 15049, 16301, 13817, 238521, 0 };
            const std::uint32_t dim21081JoeKuoD6Init[]   =   { 1, 3, 7, 7, 27, 31, 63, 143, 183, 625, 1627, 3093, 6597, 14089, 30197, 60411, 66221, 221691, 0 };
            const std::uint32_t dim21082JoeKuoD6Init[]   =   { 1, 3, 7, 13, 21, 15, 59, 67, 441, 113, 1229, 1587, 5889, 6691, 10641, 11865, 89791, 82867, 0 };
            const std::uint32_t dim21083JoeKuoD6Init[]   =   { 1, 1, 7, 9, 13, 21, 53, 145, 235, 877, 2005, 1005, 7137, 6091, 19611, 25959, 124019, 216269, 0 };
            const std::uint32_t dim21084JoeKuoD6Init[]   =   { 1, 3, 7, 9, 17, 63, 5, 245, 397, 351, 1613, 4079, 7235, 4397, 18951, 11609, 71593, 148615, 0 };
            const std::uint32_t dim21085JoeKuoD6Init[]   =   { 1, 3, 3, 11, 5, 59, 65, 221, 237, 527, 861, 397, 249, 15273, 8415, 61185, 59419, 98115, 0 };
            const std::uint32_t dim21086JoeKuoD6Init[]   =   { 1, 1, 3, 5, 5, 59, 17, 247, 3, 765, 835, 1131, 3985, 9021, 18067, 28525, 86513, 250227, 0 };
            const std::uint32_t dim21087JoeKuoD6Init[]   =   { 1, 3, 7, 15, 25, 47, 119, 143, 143, 283, 1791, 59, 8171, 12577, 17079, 9809, 100299, 63977, 0 };
            const std::uint32_t dim21088JoeKuoD6Init[]   =   { 1, 3, 5, 13, 1, 47, 93, 159, 199, 863, 1279, 77, 4719, 3623, 30713, 39271, 126299, 130297, 0 };
            const std::uint32_t dim21089JoeKuoD6Init[]   =   { 1, 1, 5, 3, 23, 11, 119, 187, 57, 373, 747, 1507, 5165, 12929, 903, 49041, 70215, 117113, 0 };
            const std::uint32_t dim21090JoeKuoD6Init[]   =   { 1, 1, 5, 1, 3, 59, 23, 77, 151, 77, 627, 2865, 7055, 10469, 12095, 20481, 13429, 47573, 0 };
            const std::uint32_t dim21091JoeKuoD6Init[]   =   { 1, 3, 1, 13, 27, 13, 115, 233, 343, 407, 1321, 4011, 5589, 15369, 23495, 4435, 75421, 229325, 0 };
            const std::uint32_t dim21092JoeKuoD6Init[]   =   { 1, 3, 3, 3, 5, 51, 89, 53, 275, 279, 203, 2829, 4415, 4735, 25417, 17633, 99445, 183945, 0 };
            const std::uint32_t dim21093JoeKuoD6Init[]   =   { 1, 3, 3, 15, 7, 9, 91, 63, 143, 945, 453, 4001, 3943, 7285, 9359, 27507, 8571, 31827, 0 };
            const std::uint32_t dim21094JoeKuoD6Init[]   =   { 1, 3, 3, 11, 15, 49, 103, 25, 273, 791, 145, 2203, 4721, 7709, 25085, 33937, 98693, 97445, 0 };
            const std::uint32_t dim21095JoeKuoD6Init[]   =   { 1, 1, 5, 15, 9, 13, 87, 27, 331, 137, 1031, 585, 7841, 12213, 32259, 46953, 17813, 203379, 0 };
            const std::uint32_t dim21096JoeKuoD6Init[]   =   { 1, 3, 1, 5, 29, 53, 121, 179, 21, 311, 991, 2145, 6577, 12889, 8763, 46629, 128093, 105033, 0 };
            const std::uint32_t dim21097JoeKuoD6Init[]   =   { 1, 3, 1, 9, 7, 29, 57, 137, 333, 109, 615, 749, 2665, 13087, 13989, 41857, 102937, 125183, 0 };
            const std::uint32_t dim21098JoeKuoD6Init[]   =   { 1, 1, 5, 5, 3, 23, 107, 5, 319, 503, 1209, 47, 349, 11681, 28521, 44707, 112887, 232275, 0 };
            const std::uint32_t dim21099JoeKuoD6Init[]   =   { 1, 3, 3, 13, 13, 51, 13, 5, 293, 15, 555, 135, 2565, 13325, 30411, 14837, 65591, 249205, 0 };
            const std::uint32_t dim21100JoeKuoD6Init[]   =   { 1, 3, 5, 13, 17, 3, 73, 255, 447, 699, 503, 3655, 7735, 12163, 6167, 15027, 103831, 146395, 0 };
            const std::uint32_t dim21101JoeKuoD6Init[]   =   { 1, 3, 1, 13, 5, 9, 27, 45, 397, 463, 1739, 3193, 6731, 7533, 11217, 22359, 82603, 231613, 0 };
            const std::uint32_t dim21102JoeKuoD6Init[]   =   { 1, 1, 3, 15, 5, 43, 73, 191, 53, 187, 1905, 745, 1571, 9013, 8515, 59527, 104671, 227063, 0 };
            const std::uint32_t dim21103JoeKuoD6Init[]   =   { 1, 1, 3, 1, 5, 47, 57, 179, 433, 979, 147, 1701, 4019, 6855, 24487, 65495, 69919, 6659, 0 };
            const std::uint32_t dim21104JoeKuoD6Init[]   =   { 1, 3, 3, 1, 17, 17, 13, 75, 163, 781, 421, 1573, 2519, 9243, 20693, 60909, 65661, 208125, 0 };
            const std::uint32_t dim21105JoeKuoD6Init[]   =   { 1, 3, 5, 7, 27, 57, 39, 79, 157, 415, 729, 3651, 3581, 9443, 6409, 45993, 99051, 140977, 0 };
            const std::uint32_t dim21106JoeKuoD6Init[]   =   { 1, 3, 3, 13, 1, 7, 109, 77, 423, 185, 97, 3719, 2355, 10593, 2421, 37339, 24961, 24305, 0 };
            const std::uint32_t dim21107JoeKuoD6Init[]   =   { 1, 3, 5, 13, 17, 7, 125, 43, 453, 43, 643, 3757, 3721, 16083, 20871, 26451, 95201, 29153, 0 };
            const std::uint32_t dim21108JoeKuoD6Init[]   =   { 1, 1, 7, 3, 13, 49, 99, 253, 59, 21, 445, 3677, 6683, 2165, 32367, 55249, 5991, 155033, 0 };
            const std::uint32_t dim21109JoeKuoD6Init[]   =   { 1, 1, 3, 9, 21, 9, 15, 219, 175, 631, 665, 2455, 4701, 10639, 13907, 26937, 58867, 259861, 0 };
            const std::uint32_t dim21110JoeKuoD6Init[]   =   { 1, 3, 5, 5, 23, 5, 39, 233, 27, 811, 1435, 625, 4703, 3699, 20763, 50047, 123875, 10129, 0 };
            const std::uint32_t dim21111JoeKuoD6Init[]   =   { 1, 1, 7, 5, 23, 1, 49, 223, 309, 691, 953, 575, 5279, 10515, 11519, 35387, 48417, 134001, 0 };
            const std::uint32_t dim21112JoeKuoD6Init[]   =   { 1, 1, 7, 11, 3, 15, 125, 109, 39, 713, 1823, 1613, 4347, 6839, 29511, 26865, 102077, 31425, 0 };
            const std::uint32_t dim21113JoeKuoD6Init[]   =   { 1, 1, 1, 7, 31, 43, 13, 221, 115, 993, 1155, 1641, 1063, 2065, 18909, 45769, 65331, 188455, 0 };
            const std::uint32_t dim21114JoeKuoD6Init[]   =   { 1, 1, 7, 13, 21, 9, 59, 7, 79, 217, 2009, 667, 7685, 14761, 20149, 44133, 41037, 78369, 0 };
            const std::uint32_t dim21115JoeKuoD6Init[]   =   { 1, 3, 1, 9, 23, 57, 1, 193, 77, 681, 1135, 3657, 8149, 3559, 25011, 55027, 121903, 240157, 0 };
            const std::uint32_t dim21116JoeKuoD6Init[]   =   { 1, 3, 3, 5, 31, 41, 59, 5, 159, 627, 1569, 23, 2311, 2239, 20811, 54931, 130949, 193071, 0 };
            const std::uint32_t dim21117JoeKuoD6Init[]   =   { 1, 1, 1, 1, 27, 45, 43, 1, 381, 801, 451, 1361, 1611, 5379, 27819, 8949, 4953, 222335, 0 };
            const std::uint32_t dim21118JoeKuoD6Init[]   =   { 1, 1, 7, 7, 7, 11, 101, 17, 197, 561, 297, 159, 7443, 7273, 819, 23487, 24927, 151781, 0 };
            const std::uint32_t dim21119JoeKuoD6Init[]   =   { 1, 3, 1, 3, 15, 43, 119, 193, 205, 835, 7, 689, 8045, 11167, 19521, 65075, 87265, 53669, 0 };
            const std::uint32_t dim21120JoeKuoD6Init[]   =   { 1, 3, 7, 7, 9, 51, 43, 209, 239, 415, 995, 4037, 1219, 2683, 30459, 36161, 111157, 184551, 0 };
            const std::uint32_t dim21121JoeKuoD6Init[]   =   { 1, 3, 7, 11, 27, 3, 81, 43, 407, 463, 231, 3545, 2691, 5235, 22053, 37233, 98757, 149111, 0 };
            const std::uint32_t dim21122JoeKuoD6Init[]   =   { 1, 3, 1, 5, 17, 25, 47, 185, 487, 403, 1063, 1445, 4457, 15443, 11693, 54823, 131001, 9813, 0 };
            const std::uint32_t dim21123JoeKuoD6Init[]   =   { 1, 3, 5, 3, 5, 35, 127, 253, 173, 491, 133, 3575, 1981, 12735, 26021, 61615, 74615, 159829, 0 };
            const std::uint32_t dim21124JoeKuoD6Init[]   =   { 1, 1, 5, 9, 13, 37, 67, 155, 317, 389, 603, 4061, 3527, 9315, 32331, 43145, 82511, 240133, 0 };
            const std::uint32_t dim21125JoeKuoD6Init[]   =   { 1, 1, 5, 1, 21, 41, 89, 3, 61, 627, 1301, 2073, 447, 8139, 2509, 52075, 50687, 240239, 0 };
            const std::uint32_t dim21126JoeKuoD6Init[]   =   { 1, 3, 7, 13, 25, 61, 117, 107, 175, 7, 1173, 561, 5777, 10525, 20713, 34987, 48005, 214361, 0 };
            const std::uint32_t dim21127JoeKuoD6Init[]   =   { 1, 3, 7, 15, 25, 31, 127, 147, 177, 881, 95, 2115, 4765, 10485, 9253, 721, 193, 222459, 0 };
            const std::uint32_t dim21128JoeKuoD6Init[]   =   { 1, 3, 5, 3, 3, 13, 47, 77, 441, 1001, 215, 2365, 3603, 405, 11401, 14523, 65755, 258229, 0 };
            const std::uint32_t dim21129JoeKuoD6Init[]   =   { 1, 1, 3, 9, 19, 29, 71, 153, 77, 613, 1815, 2033, 1821, 15497, 18805, 28851, 88247, 143115, 0 };
            const std::uint32_t dim21130JoeKuoD6Init[]   =   { 1, 3, 1, 11, 21, 19, 37, 35, 427, 887, 1977, 1961, 3619, 10739, 30115, 55937, 102045, 110929, 0 };
            const std::uint32_t dim21131JoeKuoD6Init[]   =   { 1, 3, 3, 13, 21, 27, 49, 15, 405, 629, 2015, 867, 2121, 13789, 19225, 22343, 105629, 123113, 0 };
            const std::uint32_t dim21132JoeKuoD6Init[]   =   { 1, 1, 1, 1, 17, 19, 55, 207, 507, 1001, 1753, 315, 2799, 8643, 1519, 4057, 16599, 222223, 0 };
            const std::uint32_t dim21133JoeKuoD6Init[]   =   { 1, 1, 5, 7, 21, 37, 63, 53, 103, 261, 595, 389, 6041, 11127, 23625, 61683, 80953, 255891, 0 };
            const std::uint32_t dim21134JoeKuoD6Init[]   =   { 1, 1, 1, 5, 25, 21, 81, 233, 79, 57, 1311, 3965, 7747, 687, 32149, 397, 4551, 37657, 0 };
            const std::uint32_t dim21135JoeKuoD6Init[]   =   { 1, 1, 1, 5, 9, 19, 87, 67, 325, 157, 317, 591, 1401, 8275, 20413, 39529, 75349, 183679, 0 };
            const std::uint32_t dim21136JoeKuoD6Init[]   =   { 1, 3, 3, 15, 9, 3, 83, 205, 195, 599, 829, 3109, 3705, 13991, 8781, 41555, 31689, 86933, 0 };
            const std::uint32_t dim21137JoeKuoD6Init[]   =   { 1, 3, 5, 1, 3, 9, 37, 235, 271, 883, 561, 1473, 7693, 177, 14113, 19507, 75221, 67517, 0 };
            const std::uint32_t dim21138JoeKuoD6Init[]   =   { 1, 1, 1, 9, 7, 29, 87, 189, 239, 429, 537, 1657, 6373, 2449, 17621, 19649, 77235, 102775, 0 };
            const std::uint32_t dim21139JoeKuoD6Init[]   =   { 1, 1, 7, 7, 1, 43, 69, 207, 241, 561, 1809, 3119, 4657, 15797, 18751, 52169, 105005, 172657, 0 };
            const std::uint32_t dim21140JoeKuoD6Init[]   =   { 1, 1, 7, 5, 5, 59, 67, 231, 27, 435, 1073, 2689, 229, 733, 1579, 52289, 110285, 76721, 0 };
            const std::uint32_t dim21141JoeKuoD6Init[]   =   { 1, 3, 5, 9, 31, 19, 87, 41, 489, 705, 1363, 963, 5865, 8237, 10295, 43169, 81561, 177209, 0 };
            const std::uint32_t dim21142JoeKuoD6Init[]   =   { 1, 3, 3, 1, 25, 39, 63, 255, 403, 625, 1601, 71, 6609, 4165, 21987, 31269, 25473, 17063, 0 };
            const std::uint32_t dim21143JoeKuoD6Init[]   =   { 1, 3, 3, 11, 19, 13, 101, 245, 17, 687, 1037, 3345, 7257, 13081, 5131, 29003, 72319, 223505, 0 };
            const std::uint32_t dim21144JoeKuoD6Init[]   =   { 1, 3, 3, 3, 11, 49, 107, 29, 463, 465, 977, 4007, 2121, 4821, 1465, 53725, 36783, 247057, 0 };
            const std::uint32_t dim21145JoeKuoD6Init[]   =   { 1, 1, 1, 3, 1, 43, 71, 49, 261, 965, 1041, 3951, 3791, 2503, 26009, 52039, 4639, 141281, 0 };
            const std::uint32_t dim21146JoeKuoD6Init[]   =   { 1, 1, 3, 5, 29, 45, 79, 33, 119, 491, 1403, 1637, 853, 5609, 29853, 16435, 117877, 58443, 0 };
            const std::uint32_t dim21147JoeKuoD6Init[]   =   { 1, 1, 3, 5, 13, 17, 109, 187, 201, 705, 235, 1485, 7673, 6335, 3341, 20451, 64697, 129519, 0 };
            const std::uint32_t dim21148JoeKuoD6Init[]   =   { 1, 1, 7, 13, 11, 41, 95, 81, 135, 783, 1293, 2095, 3599, 10175, 3205, 56915, 131, 19281, 0 };
            const std::uint32_t dim21149JoeKuoD6Init[]   =   { 1, 3, 5, 9, 13, 19, 53, 223, 283, 733, 1915, 3029, 2779, 8133, 28163, 37263, 91245, 1927, 0 };
            const std::uint32_t dim21150JoeKuoD6Init[]   =   { 1, 3, 3, 3, 1, 55, 41, 123, 209, 195, 1423, 2467, 3809, 11169, 23593, 8703, 40975, 175651, 0 };
            const std::uint32_t dim21151JoeKuoD6Init[]   =   { 1, 3, 7, 9, 31, 57, 31, 115, 415, 445, 557, 3971, 1565, 15223, 7799, 10463, 117387, 225127, 0 };
            const std::uint32_t dim21152JoeKuoD6Init[]   =   { 1, 3, 5, 11, 31, 19, 3, 63, 315, 501, 903, 1925, 3393, 16149, 11013, 15483, 70765, 279, 0 };
            const std::uint32_t dim21153JoeKuoD6Init[]   =   { 1, 3, 3, 9, 29, 21, 13, 227, 263, 815, 1259, 2549, 955, 9237, 16083, 38891, 31145, 731, 0 };
            const std::uint32_t dim21154JoeKuoD6Init[]   =   { 1, 3, 3, 5, 27, 23, 33, 189, 107, 655, 889, 1549, 7315, 13341, 12721, 59339, 54503, 91679, 0 };
            const std::uint32_t dim21155JoeKuoD6Init[]   =   { 1, 3, 7, 5, 15, 9, 1, 255, 451, 91, 1279, 2359, 5913, 5215, 23161, 29327, 45275, 206709, 0 };
            const std::uint32_t dim21156JoeKuoD6Init[]   =   { 1, 3, 3, 9, 9, 41, 75, 91, 87, 695, 335, 3375, 7307, 14095, 5359, 7815, 9339, 46387, 0 };
            const std::uint32_t dim21157JoeKuoD6Init[]   =   { 1, 1, 3, 15, 5, 47, 69, 231, 423, 255, 1335, 3395, 2799, 8955, 31445, 59849, 104955, 240587, 0 };
            const std::uint32_t dim21158JoeKuoD6Init[]   =   { 1, 3, 5, 7, 7, 9, 21, 209, 321, 5, 653, 2199, 3657, 6397, 20229, 32349, 54543, 47971, 0 };
            const std::uint32_t dim21159JoeKuoD6Init[]   =   { 1, 3, 7, 11, 31, 21, 85, 49, 197, 865, 53, 609, 1867, 14503, 12671, 61703, 39245, 8493, 0 };
            const std::uint32_t dim21160JoeKuoD6Init[]   =   { 1, 3, 1, 13, 27, 31, 119, 247, 209, 65, 1729, 1563, 1597, 1617, 26597, 50139, 108667, 77035, 0 };
            const std::uint32_t dim21161JoeKuoD6Init[]   =   { 1, 1, 5, 13, 3, 49, 53, 219, 71, 1013, 1239, 3725, 117, 9273, 8277, 32619, 45933, 71509, 0 };
            const std::uint32_t dim21162JoeKuoD6Init[]   =   { 1, 3, 7, 13, 1, 3, 119, 153, 79, 555, 429, 1221, 3725, 6073, 1295, 7187, 117709, 258911, 0 };
            const std::uint32_t dim21163JoeKuoD6Init[]   =   { 1, 3, 3, 13, 1, 13, 105, 185, 81, 989, 563, 3761, 6725, 4699, 10539, 50247, 95307, 211927, 0 };
            const std::uint32_t dim21164JoeKuoD6Init[]   =   { 1, 3, 7, 3, 21, 11, 45, 81, 495, 391, 1437, 3495, 3789, 13701, 9479, 42505, 22561, 135019, 0 };
            const std::uint32_t dim21165JoeKuoD6Init[]   =   { 1, 3, 3, 11, 7, 61, 65, 211, 269, 997, 385, 3843, 4905, 2939, 28551, 19515, 25177, 68137, 0 };
            const std::uint32_t dim21166JoeKuoD6Init[]   =   { 1, 1, 3, 3, 3, 47, 73, 127, 15, 977, 209, 1791, 4711, 6733, 29093, 36311, 13665, 240603, 0 };
            const std::uint32_t dim21167JoeKuoD6Init[]   =   { 1, 3, 5, 5, 19, 39, 29, 211, 463, 755, 1723, 397, 213, 14009, 22701, 7131, 35587, 183885, 0 };
            const std::uint32_t dim21168JoeKuoD6Init[]   =   { 1, 3, 5, 9, 11, 29, 7, 25, 381, 631, 1343, 2255, 2535, 3239, 7287, 14161, 69295, 85245, 0 };
            const std::uint32_t dim21169JoeKuoD6Init[]   =   { 1, 1, 5, 5, 17, 47, 19, 217, 289, 411, 1855, 323, 4109, 2601, 5835, 61909, 99333, 99959, 0 };
            const std::uint32_t dim21170JoeKuoD6Init[]   =   { 1, 1, 3, 11, 1, 51, 121, 207, 403, 993, 1171, 3451, 3389, 957, 22125, 9333, 110775, 54125, 0 };
            const std::uint32_t dim21171JoeKuoD6Init[]   =   { 1, 3, 5, 15, 9, 51, 13, 251, 203, 861, 321, 2017, 6933, 10785, 20089, 65213, 105451, 117319, 0 };
            const std::uint32_t dim21172JoeKuoD6Init[]   =   { 1, 3, 3, 15, 19, 63, 89, 217, 269, 723, 57, 1923, 4267, 4895, 2191, 21605, 62401, 11063, 0 };
            const std::uint32_t dim21173JoeKuoD6Init[]   =   { 1, 3, 1, 3, 21, 47, 103, 75, 167, 989, 1401, 575, 3717, 10373, 21321, 5487, 36063, 140411, 0 };
            const std::uint32_t dim21174JoeKuoD6Init[]   =   { 1, 1, 7, 15, 19, 29, 121, 197, 429, 773, 901, 1875, 291, 11395, 31459, 55041, 49263, 185143, 0 };
            const std::uint32_t dim21175JoeKuoD6Init[]   =   { 1, 3, 3, 1, 19, 17, 19, 21, 41, 885, 1665, 547, 5887, 6205, 3317, 59399, 125559, 82721, 0 };
            const std::uint32_t dim21176JoeKuoD6Init[]   =   { 1, 3, 1, 9, 15, 39, 81, 9, 279, 33, 1287, 3035, 5759, 10647, 3933, 20953, 3137, 30693, 0 };
            const std::uint32_t dim21177JoeKuoD6Init[]   =   { 1, 3, 5, 13, 3, 33, 33, 169, 233, 83, 467, 3719, 5617, 6165, 15631, 56059, 95541, 245233, 0 };
            const std::uint32_t dim21178JoeKuoD6Init[]   =   { 1, 3, 5, 13, 5, 21, 81, 9, 413, 247, 1307, 3363, 3383, 11525, 1259, 8735, 36507, 98359, 0 };
            const std::uint32_t dim21179JoeKuoD6Init[]   =   { 1, 1, 1, 13, 17, 49, 105, 131, 385, 309, 1295, 565, 8031, 15391, 31263, 52657, 102721, 212195, 0 };
            const std::uint32_t dim21180JoeKuoD6Init[]   =   { 1, 3, 1, 7, 13, 41, 21, 103, 237, 649, 55, 1565, 6327, 8743, 15457, 29975, 34165, 80839, 0 };
            const std::uint32_t dim21181JoeKuoD6Init[]   =   { 1, 3, 5, 11, 15, 31, 121, 219, 375, 159, 731, 59, 3205, 15039, 10023, 46209, 34619, 110253, 0 };
            const std::uint32_t dim21182JoeKuoD6Init[]   =   { 1, 3, 3, 11, 31, 19, 79, 185, 363, 635, 463, 987, 2681, 6405, 30077, 21173, 14213, 58095, 0 };
            const std::uint32_t dim21183JoeKuoD6Init[]   =   { 1, 1, 5, 13, 23, 37, 57, 111, 293, 553, 269, 3393, 345, 1983, 1097, 47217, 22281, 212607, 0 };
            const std::uint32_t dim21184JoeKuoD6Init[]   =   { 1, 3, 5, 7, 7, 33, 65, 61, 185, 411, 187, 641, 6437, 4625, 17547, 38941, 81119, 48651, 0 };
            const std::uint32_t dim21185JoeKuoD6Init[]   =   { 1, 1, 7, 3, 19, 25, 39, 243, 139, 465, 691, 713, 7879, 14539, 31669, 35871, 130681, 255929, 0 };
            const std::uint32_t dim21186JoeKuoD6Init[]   =   { 1, 3, 1, 1, 3, 43, 87, 13, 179, 835, 719, 1189, 7207, 5863, 6077, 20669, 35469, 211155, 0 };
            const std::uint32_t dim21187JoeKuoD6Init[]   =   { 1, 3, 7, 13, 25, 59, 97, 129, 151, 985, 739, 1919, 7729, 14057, 21721, 17603, 82797, 181319, 0 };
            const std::uint32_t dim21188JoeKuoD6Init[]   =   { 1, 1, 7, 7, 5, 3, 21, 141, 379, 257, 207, 597, 4051, 7563, 25481, 59427, 45449, 61159, 0 };
            const std::uint32_t dim21189JoeKuoD6Init[]   =   { 1, 3, 3, 9, 11, 25, 5, 29, 131, 603, 637, 189, 4033, 13099, 15219, 4447, 73501, 135795, 0 };
            const std::uint32_t dim21190JoeKuoD6Init[]   =   { 1, 3, 1, 9, 1, 49, 57, 227, 141, 543, 1499, 3525, 3127, 11191, 4071, 47003, 7431, 155137, 0 };
            const std::uint32_t dim21191JoeKuoD6Init[]   =   { 1, 3, 1, 11, 27, 31, 15, 31, 113, 135, 1251, 245, 6965, 14263, 5679, 55201, 121453, 132503, 0 };
            const std::uint32_t dim21192JoeKuoD6Init[]   =   { 1, 1, 5, 15, 7, 23, 67, 163, 57, 513, 1809, 1343, 6165, 199, 31169, 30803, 86705, 71103, 0 };
            const std::uint32_t dim21193JoeKuoD6Init[]   =   { 1, 1, 3, 1, 15, 9, 75, 143, 273, 797, 819, 4037, 2305, 4841, 15697, 41191, 38187, 174131, 0 };
            const std::uint32_t dim21194JoeKuoD6Init[]   =   { 1, 3, 7, 7, 3, 55, 65, 135, 423, 185, 299, 2221, 7987, 4223, 28183, 32273, 95941, 260297, 0 };
            const std::uint32_t dim21195JoeKuoD6Init[]   =   { 1, 1, 7, 7, 7, 11, 67, 109, 507, 673, 1555, 2537, 7553, 4659, 3945, 20839, 32539, 43053, 0 };
            const std::uint32_t dim21196JoeKuoD6Init[]   =   { 1, 1, 7, 15, 1, 47, 61, 73, 211, 397, 1785, 4063, 6461, 13725, 11299, 17565, 80063, 118271, 0 };
            const std::uint32_t dim21197JoeKuoD6Init[]   =   { 1, 1, 7, 5, 29, 27, 97, 105, 379, 153, 915, 2795, 4933, 6729, 21207, 9995, 70241, 85641, 0 };
            const std::uint32_t dim21198JoeKuoD6Init[]   =   { 1, 3, 5, 5, 23, 13, 41, 67, 127, 649, 1351, 3597, 7077, 4989, 14649, 17401, 70883, 239841, 0 };
            const std::uint32_t dim21199JoeKuoD6Init[]   =   { 1, 1, 5, 1, 19, 1, 83, 3, 425, 873, 1943, 3935, 4257, 14587, 11829, 55217, 21963, 39683, 0 };
            const std::uint32_t dim21200JoeKuoD6Init[]   =   { 1, 1, 7, 11, 15, 7, 37, 239, 337, 245, 1557, 3681, 7357, 9639, 27367, 26869, 114603, 86317, 0 };

            const std::uint32_t * const JoeKuoD6initializers[21200]
            =
            {
                dim1JoeKuoD6Init,
                dim2JoeKuoD6Init,
                dim3JoeKuoD6Init,
                dim4JoeKuoD6Init,
                dim5JoeKuoD6Init,
                dim6JoeKuoD6Init,
                dim7JoeKuoD6Init,
                dim8JoeKuoD6Init,
                dim9JoeKuoD6Init,
                dim10JoeKuoD6Init,
                dim11JoeKuoD6Init,
                dim12JoeKuoD6Init,
                dim13JoeKuoD6Init,
                dim14JoeKuoD6Init,
                dim15JoeKuoD6Init,
                dim16JoeKuoD6Init,
                dim17JoeKuoD6Init,
                dim18JoeKuoD6Init,
                dim19JoeKuoD6Init,
                dim20JoeKuoD6Init,
                dim21JoeKuoD6Init,
                dim22JoeKuoD6Init,
                dim23JoeKuoD6Init,
                dim24JoeKuoD6Init,
                dim25JoeKuoD6Init,
                dim26JoeKuoD6Init,
                dim27JoeKuoD6Init,
                dim28JoeKuoD6Init,
                dim29JoeKuoD6Init,
                dim30JoeKuoD6Init,
                dim31JoeKuoD6Init,
                dim32JoeKuoD6Init,
                dim33JoeKuoD6Init,
                dim34JoeKuoD6Init,
                dim35JoeKuoD6Init,
                dim36JoeKuoD6Init,
                dim37JoeKuoD6Init,
                dim38JoeKuoD6Init,
                dim39JoeKuoD6Init,
                dim40JoeKuoD6Init,
                dim41JoeKuoD6Init,
                dim42JoeKuoD6Init,
                dim43JoeKuoD6Init,
                dim44JoeKuoD6Init,
                dim45JoeKuoD6Init,
                dim46JoeKuoD6Init,
                dim47JoeKuoD6Init,
                dim48JoeKuoD6Init,
                dim49JoeKuoD6Init,
                dim50JoeKuoD6Init,
                dim51JoeKuoD6Init,
                dim52JoeKuoD6Init,
                dim53JoeKuoD6Init,
                dim54JoeKuoD6Init,
                dim55JoeKuoD6Init,
                dim56JoeKuoD6Init,
                dim57JoeKuoD6Init,
                dim58JoeKuoD6Init,
                dim59JoeKuoD6Init,
                dim60JoeKuoD6Init,
                dim61JoeKuoD6Init,
                dim62JoeKuoD6Init,
                dim63JoeKuoD6Init,
                dim64JoeKuoD6Init,
                dim65JoeKuoD6Init,
                dim66JoeKuoD6Init,
                dim67JoeKuoD6Init,
                dim68JoeKuoD6Init,
                dim69JoeKuoD6Init,
                dim70JoeKuoD6Init,
                dim71JoeKuoD6Init,
                dim72JoeKuoD6Init,
                dim73JoeKuoD6Init,
                dim74JoeKuoD6Init,
                dim75JoeKuoD6Init,
                dim76JoeKuoD6Init,
                dim77JoeKuoD6Init,
                dim78JoeKuoD6Init,
                dim79JoeKuoD6Init,
                dim80JoeKuoD6Init,
                dim81JoeKuoD6Init,
                dim82JoeKuoD6Init,
                dim83JoeKuoD6Init,
                dim84JoeKuoD6Init,
                dim85JoeKuoD6Init,
                dim86JoeKuoD6Init,
                dim87JoeKuoD6Init,
                dim88JoeKuoD6Init,
                dim89JoeKuoD6Init,
                dim90JoeKuoD6Init,
                dim91JoeKuoD6Init,
                dim92JoeKuoD6Init,
                dim93JoeKuoD6Init,
                dim94JoeKuoD6Init,
                dim95JoeKuoD6Init,
                dim96JoeKuoD6Init,
                dim97JoeKuoD6Init,
                dim98JoeKuoD6Init,
                dim99JoeKuoD6Init,
                dim100JoeKuoD6Init,
                dim101JoeKuoD6Init,
                dim102JoeKuoD6Init,
                dim103JoeKuoD6Init,
                dim104JoeKuoD6Init,
                dim105JoeKuoD6Init,
                dim106JoeKuoD6Init,
                dim107JoeKuoD6Init,
                dim108JoeKuoD6Init,
                dim109JoeKuoD6Init,
                dim110JoeKuoD6Init,
                dim111JoeKuoD6Init,
                dim112JoeKuoD6Init,
                dim113JoeKuoD6Init,
                dim114JoeKuoD6Init,
                dim115JoeKuoD6Init,
                dim116JoeKuoD6Init,
                dim117JoeKuoD6Init,
                dim118JoeKuoD6Init,
                dim119JoeKuoD6Init,
                dim120JoeKuoD6Init,
                dim121JoeKuoD6Init,
                dim122JoeKuoD6Init,
                dim123JoeKuoD6Init,
                dim124JoeKuoD6Init,
                dim125JoeKuoD6Init,
                dim126JoeKuoD6Init,
                dim127JoeKuoD6Init,
                dim128JoeKuoD6Init,
                dim129JoeKuoD6Init,
                dim130JoeKuoD6Init,
                dim131JoeKuoD6Init,
                dim132JoeKuoD6Init,
                dim133JoeKuoD6Init,
                dim134JoeKuoD6Init,
                dim135JoeKuoD6Init,
                dim136JoeKuoD6Init,
                dim137JoeKuoD6Init,
                dim138JoeKuoD6Init,
                dim139JoeKuoD6Init,
                dim140JoeKuoD6Init,
                dim141JoeKuoD6Init,
                dim142JoeKuoD6Init,
                dim143JoeKuoD6Init,
                dim144JoeKuoD6Init,
                dim145JoeKuoD6Init,
                dim146JoeKuoD6Init,
                dim147JoeKuoD6Init,
                dim148JoeKuoD6Init,
                dim149JoeKuoD6Init,
                dim150JoeKuoD6Init,
                dim151JoeKuoD6Init,
                dim152JoeKuoD6Init,
                dim153JoeKuoD6Init,
                dim154JoeKuoD6Init,
                dim155JoeKuoD6Init,
                dim156JoeKuoD6Init,
                dim157JoeKuoD6Init,
                dim158JoeKuoD6Init,
                dim159JoeKuoD6Init,
                dim160JoeKuoD6Init,
                dim161JoeKuoD6Init,
                dim162JoeKuoD6Init,
                dim163JoeKuoD6Init,
                dim164JoeKuoD6Init,
                dim165JoeKuoD6Init,
                dim166JoeKuoD6Init,
                dim167JoeKuoD6Init,
                dim168JoeKuoD6Init,
                dim169JoeKuoD6Init,
                dim170JoeKuoD6Init,
                dim171JoeKuoD6Init,
                dim172JoeKuoD6Init,
                dim173JoeKuoD6Init,
                dim174JoeKuoD6Init,
                dim175JoeKuoD6Init,
                dim176JoeKuoD6Init,
                dim177JoeKuoD6Init,
                dim178JoeKuoD6Init,
                dim179JoeKuoD6Init,
                dim180JoeKuoD6Init,
                dim181JoeKuoD6Init,
                dim182JoeKuoD6Init,
                dim183JoeKuoD6Init,
                dim184JoeKuoD6Init,
                dim185JoeKuoD6Init,
                dim186JoeKuoD6Init,
                dim187JoeKuoD6Init,
                dim188JoeKuoD6Init,
                dim189JoeKuoD6Init,
                dim190JoeKuoD6Init,
                dim191JoeKuoD6Init,
                dim192JoeKuoD6Init,
                dim193JoeKuoD6Init,
                dim194JoeKuoD6Init,
                dim195JoeKuoD6Init,
                dim196JoeKuoD6Init,
                dim197JoeKuoD6Init,
                dim198JoeKuoD6Init,
                dim199JoeKuoD6Init,
                dim200JoeKuoD6Init,
                dim201JoeKuoD6Init,
                dim202JoeKuoD6Init,
                dim203JoeKuoD6Init,
                dim204JoeKuoD6Init,
                dim205JoeKuoD6Init,
                dim206JoeKuoD6Init,
                dim207JoeKuoD6Init,
                dim208JoeKuoD6Init,
                dim209JoeKuoD6Init,
                dim210JoeKuoD6Init,
                dim211JoeKuoD6Init,
                dim212JoeKuoD6Init,
                dim213JoeKuoD6Init,
                dim214JoeKuoD6Init,
                dim215JoeKuoD6Init,
                dim216JoeKuoD6Init,
                dim217JoeKuoD6Init,
                dim218JoeKuoD6Init,
                dim219JoeKuoD6Init,
                dim220JoeKuoD6Init,
                dim221JoeKuoD6Init,
                dim222JoeKuoD6Init,
                dim223JoeKuoD6Init,
                dim224JoeKuoD6Init,
                dim225JoeKuoD6Init,
                dim226JoeKuoD6Init,
                dim227JoeKuoD6Init,
                dim228JoeKuoD6Init,
                dim229JoeKuoD6Init,
                dim230JoeKuoD6Init,
                dim231JoeKuoD6Init,
                dim232JoeKuoD6Init,
                dim233JoeKuoD6Init,
                dim234JoeKuoD6Init,
                dim235JoeKuoD6Init,
                dim236JoeKuoD6Init,
                dim237JoeKuoD6Init,
                dim238JoeKuoD6Init,
                dim239JoeKuoD6Init,
                dim240JoeKuoD6Init,
                dim241JoeKuoD6Init,
                dim242JoeKuoD6Init,
                dim243JoeKuoD6Init,
                dim244JoeKuoD6Init,
                dim245JoeKuoD6Init,
                dim246JoeKuoD6Init,
                dim247JoeKuoD6Init,
                dim248JoeKuoD6Init,
                dim249JoeKuoD6Init,
                dim250JoeKuoD6Init,
                dim251JoeKuoD6Init,
                dim252JoeKuoD6Init,
                dim253JoeKuoD6Init,
                dim254JoeKuoD6Init,
                dim255JoeKuoD6Init,
                dim256JoeKuoD6Init,
                dim257JoeKuoD6Init,
                dim258JoeKuoD6Init,
                dim259JoeKuoD6Init,
                dim260JoeKuoD6Init,
                dim261JoeKuoD6Init,
                dim262JoeKuoD6Init,
                dim263JoeKuoD6Init,
                dim264JoeKuoD6Init,
                dim265JoeKuoD6Init,
                dim266JoeKuoD6Init,
                dim267JoeKuoD6Init,
                dim268JoeKuoD6Init,
                dim269JoeKuoD6Init,
                dim270JoeKuoD6Init,
                dim271JoeKuoD6Init,
                dim272JoeKuoD6Init,
                dim273JoeKuoD6Init,
                dim274JoeKuoD6Init,
                dim275JoeKuoD6Init,
                dim276JoeKuoD6Init,
                dim277JoeKuoD6Init,
                dim278JoeKuoD6Init,
                dim279JoeKuoD6Init,
                dim280JoeKuoD6Init,
                dim281JoeKuoD6Init,
                dim282JoeKuoD6Init,
                dim283JoeKuoD6Init,
                dim284JoeKuoD6Init,
                dim285JoeKuoD6Init,
                dim286JoeKuoD6Init,
                dim287JoeKuoD6Init,
                dim288JoeKuoD6Init,
                dim289JoeKuoD6Init,
                dim290JoeKuoD6Init,
                dim291JoeKuoD6Init,
                dim292JoeKuoD6Init,
                dim293JoeKuoD6Init,
                dim294JoeKuoD6Init,
                dim295JoeKuoD6Init,
                dim296JoeKuoD6Init,
                dim297JoeKuoD6Init,
                dim298JoeKuoD6Init,
                dim299JoeKuoD6Init,
                dim300JoeKuoD6Init,
                dim301JoeKuoD6Init,
                dim302JoeKuoD6Init,
                dim303JoeKuoD6Init,
                dim304JoeKuoD6Init,
                dim305JoeKuoD6Init,
                dim306JoeKuoD6Init,
                dim307JoeKuoD6Init,
                dim308JoeKuoD6Init,
                dim309JoeKuoD6Init,
                dim310JoeKuoD6Init,
                dim311JoeKuoD6Init,
                dim312JoeKuoD6Init,
                dim313JoeKuoD6Init,
                dim314JoeKuoD6Init,
                dim315JoeKuoD6Init,
                dim316JoeKuoD6Init,
                dim317JoeKuoD6Init,
                dim318JoeKuoD6Init,
                dim319JoeKuoD6Init,
                dim320JoeKuoD6Init,
                dim321JoeKuoD6Init,
                dim322JoeKuoD6Init,
                dim323JoeKuoD6Init,
                dim324JoeKuoD6Init,
                dim325JoeKuoD6Init,
                dim326JoeKuoD6Init,
                dim327JoeKuoD6Init,
                dim328JoeKuoD6Init,
                dim329JoeKuoD6Init,
                dim330JoeKuoD6Init,
                dim331JoeKuoD6Init,
                dim332JoeKuoD6Init,
                dim333JoeKuoD6Init,
                dim334JoeKuoD6Init,
                dim335JoeKuoD6Init,
                dim336JoeKuoD6Init,
                dim337JoeKuoD6Init,
                dim338JoeKuoD6Init,
                dim339JoeKuoD6Init,
                dim340JoeKuoD6Init,
                dim341JoeKuoD6Init,
                dim342JoeKuoD6Init,
                dim343JoeKuoD6Init,
                dim344JoeKuoD6Init,
                dim345JoeKuoD6Init,
                dim346JoeKuoD6Init,
                dim347JoeKuoD6Init,
                dim348JoeKuoD6Init,
                dim349JoeKuoD6Init,
                dim350JoeKuoD6Init,
                dim351JoeKuoD6Init,
                dim352JoeKuoD6Init,
                dim353JoeKuoD6Init,
                dim354JoeKuoD6Init,
                dim355JoeKuoD6Init,
                dim356JoeKuoD6Init,
                dim357JoeKuoD6Init,
                dim358JoeKuoD6Init,
                dim359JoeKuoD6Init,
                dim360JoeKuoD6Init,
                dim361JoeKuoD6Init,
                dim362JoeKuoD6Init,
                dim363JoeKuoD6Init,
                dim364JoeKuoD6Init,
                dim365JoeKuoD6Init,
                dim366JoeKuoD6Init,
                dim367JoeKuoD6Init,
                dim368JoeKuoD6Init,
                dim369JoeKuoD6Init,
                dim370JoeKuoD6Init,
                dim371JoeKuoD6Init,
                dim372JoeKuoD6Init,
                dim373JoeKuoD6Init,
                dim374JoeKuoD6Init,
                dim375JoeKuoD6Init,
                dim376JoeKuoD6Init,
                dim377JoeKuoD6Init,
                dim378JoeKuoD6Init,
                dim379JoeKuoD6Init,
                dim380JoeKuoD6Init,
                dim381JoeKuoD6Init,
                dim382JoeKuoD6Init,
                dim383JoeKuoD6Init,
                dim384JoeKuoD6Init,
                dim385JoeKuoD6Init,
                dim386JoeKuoD6Init,
                dim387JoeKuoD6Init,
                dim388JoeKuoD6Init,
                dim389JoeKuoD6Init,
                dim390JoeKuoD6Init,
                dim391JoeKuoD6Init,
                dim392JoeKuoD6Init,
                dim393JoeKuoD6Init,
                dim394JoeKuoD6Init,
                dim395JoeKuoD6Init,
                dim396JoeKuoD6Init,
                dim397JoeKuoD6Init,
                dim398JoeKuoD6Init,
                dim399JoeKuoD6Init,
                dim400JoeKuoD6Init,
                dim401JoeKuoD6Init,
                dim402JoeKuoD6Init,
                dim403JoeKuoD6Init,
                dim404JoeKuoD6Init,
                dim405JoeKuoD6Init,
                dim406JoeKuoD6Init,
                dim407JoeKuoD6Init,
                dim408JoeKuoD6Init,
                dim409JoeKuoD6Init,
                dim410JoeKuoD6Init,
                dim411JoeKuoD6Init,
                dim412JoeKuoD6Init,
                dim413JoeKuoD6Init,
                dim414JoeKuoD6Init,
                dim415JoeKuoD6Init,
                dim416JoeKuoD6Init,
                dim417JoeKuoD6Init,
                dim418JoeKuoD6Init,
                dim419JoeKuoD6Init,
                dim420JoeKuoD6Init,
                dim421JoeKuoD6Init,
                dim422JoeKuoD6Init,
                dim423JoeKuoD6Init,
                dim424JoeKuoD6Init,
                dim425JoeKuoD6Init,
                dim426JoeKuoD6Init,
                dim427JoeKuoD6Init,
                dim428JoeKuoD6Init,
                dim429JoeKuoD6Init,
                dim430JoeKuoD6Init,
                dim431JoeKuoD6Init,
                dim432JoeKuoD6Init,
                dim433JoeKuoD6Init,
                dim434JoeKuoD6Init,
                dim435JoeKuoD6Init,
                dim436JoeKuoD6Init,
                dim437JoeKuoD6Init,
                dim438JoeKuoD6Init,
                dim439JoeKuoD6Init,
                dim440JoeKuoD6Init,
                dim441JoeKuoD6Init,
                dim442JoeKuoD6Init,
                dim443JoeKuoD6Init,
                dim444JoeKuoD6Init,
                dim445JoeKuoD6Init,
                dim446JoeKuoD6Init,
                dim447JoeKuoD6Init,
                dim448JoeKuoD6Init,
                dim449JoeKuoD6Init,
                dim450JoeKuoD6Init,
                dim451JoeKuoD6Init,
                dim452JoeKuoD6Init,
                dim453JoeKuoD6Init,
                dim454JoeKuoD6Init,
                dim455JoeKuoD6Init,
                dim456JoeKuoD6Init,
                dim457JoeKuoD6Init,
                dim458JoeKuoD6Init,
                dim459JoeKuoD6Init,
                dim460JoeKuoD6Init,
                dim461JoeKuoD6Init,
                dim462JoeKuoD6Init,
                dim463JoeKuoD6Init,
                dim464JoeKuoD6Init,
                dim465JoeKuoD6Init,
                dim466JoeKuoD6Init,
                dim467JoeKuoD6Init,
                dim468JoeKuoD6Init,
                dim469JoeKuoD6Init,
                dim470JoeKuoD6Init,
                dim471JoeKuoD6Init,
                dim472JoeKuoD6Init,
                dim473JoeKuoD6Init,
                dim474JoeKuoD6Init,
                dim475JoeKuoD6Init,
                dim476JoeKuoD6Init,
                dim477JoeKuoD6Init,
                dim478JoeKuoD6Init,
                dim479JoeKuoD6Init,
                dim480JoeKuoD6Init,
                dim481JoeKuoD6Init,
                dim482JoeKuoD6Init,
                dim483JoeKuoD6Init,
                dim484JoeKuoD6Init,
                dim485JoeKuoD6Init,
                dim486JoeKuoD6Init,
                dim487JoeKuoD6Init,
                dim488JoeKuoD6Init,
                dim489JoeKuoD6Init,
                dim490JoeKuoD6Init,
                dim491JoeKuoD6Init,
                dim492JoeKuoD6Init,
                dim493JoeKuoD6Init,
                dim494JoeKuoD6Init,
                dim495JoeKuoD6Init,
                dim496JoeKuoD6Init,
                dim497JoeKuoD6Init,
                dim498JoeKuoD6Init,
                dim499JoeKuoD6Init,
                dim500JoeKuoD6Init,
                dim501JoeKuoD6Init,
                dim502JoeKuoD6Init,
                dim503JoeKuoD6Init,
                dim504JoeKuoD6Init,
                dim505JoeKuoD6Init,
                dim506JoeKuoD6Init,
                dim507JoeKuoD6Init,
                dim508JoeKuoD6Init,
                dim509JoeKuoD6Init,
                dim510JoeKuoD6Init,
                dim511JoeKuoD6Init,
                dim512JoeKuoD6Init,
                dim513JoeKuoD6Init,
                dim514JoeKuoD6Init,
                dim515JoeKuoD6Init,
                dim516JoeKuoD6Init,
                dim517JoeKuoD6Init,
                dim518JoeKuoD6Init,
                dim519JoeKuoD6Init,
                dim520JoeKuoD6Init,
                dim521JoeKuoD6Init,
                dim522JoeKuoD6Init,
                dim523JoeKuoD6Init,
                dim524JoeKuoD6Init,
                dim525JoeKuoD6Init,
                dim526JoeKuoD6Init,
                dim527JoeKuoD6Init,
                dim528JoeKuoD6Init,
                dim529JoeKuoD6Init,
                dim530JoeKuoD6Init,
                dim531JoeKuoD6Init,
                dim532JoeKuoD6Init,
                dim533JoeKuoD6Init,
                dim534JoeKuoD6Init,
                dim535JoeKuoD6Init,
                dim536JoeKuoD6Init,
                dim537JoeKuoD6Init,
                dim538JoeKuoD6Init,
                dim539JoeKuoD6Init,
                dim540JoeKuoD6Init,
                dim541JoeKuoD6Init,
                dim542JoeKuoD6Init,
                dim543JoeKuoD6Init,
                dim544JoeKuoD6Init,
                dim545JoeKuoD6Init,
                dim546JoeKuoD6Init,
                dim547JoeKuoD6Init,
                dim548JoeKuoD6Init,
                dim549JoeKuoD6Init,
                dim550JoeKuoD6Init,
                dim551JoeKuoD6Init,
                dim552JoeKuoD6Init,
                dim553JoeKuoD6Init,
                dim554JoeKuoD6Init,
                dim555JoeKuoD6Init,
                dim556JoeKuoD6Init,
                dim557JoeKuoD6Init,
                dim558JoeKuoD6Init,
                dim559JoeKuoD6Init,
                dim560JoeKuoD6Init,
                dim561JoeKuoD6Init,
                dim562JoeKuoD6Init,
                dim563JoeKuoD6Init,
                dim564JoeKuoD6Init,
                dim565JoeKuoD6Init,
                dim566JoeKuoD6Init,
                dim567JoeKuoD6Init,
                dim568JoeKuoD6Init,
                dim569JoeKuoD6Init,
                dim570JoeKuoD6Init,
                dim571JoeKuoD6Init,
                dim572JoeKuoD6Init,
                dim573JoeKuoD6Init,
                dim574JoeKuoD6Init,
                dim575JoeKuoD6Init,
                dim576JoeKuoD6Init,
                dim577JoeKuoD6Init,
                dim578JoeKuoD6Init,
                dim579JoeKuoD6Init,
                dim580JoeKuoD6Init,
                dim581JoeKuoD6Init,
                dim582JoeKuoD6Init,
                dim583JoeKuoD6Init,
                dim584JoeKuoD6Init,
                dim585JoeKuoD6Init,
                dim586JoeKuoD6Init,
                dim587JoeKuoD6Init,
                dim588JoeKuoD6Init,
                dim589JoeKuoD6Init,
                dim590JoeKuoD6Init,
                dim591JoeKuoD6Init,
                dim592JoeKuoD6Init,
                dim593JoeKuoD6Init,
                dim594JoeKuoD6Init,
                dim595JoeKuoD6Init,
                dim596JoeKuoD6Init,
                dim597JoeKuoD6Init,
                dim598JoeKuoD6Init,
                dim599JoeKuoD6Init,
                dim600JoeKuoD6Init,
                dim601JoeKuoD6Init,
                dim602JoeKuoD6Init,
                dim603JoeKuoD6Init,
                dim604JoeKuoD6Init,
                dim605JoeKuoD6Init,
                dim606JoeKuoD6Init,
                dim607JoeKuoD6Init,
                dim608JoeKuoD6Init,
                dim609JoeKuoD6Init,
                dim610JoeKuoD6Init,
                dim611JoeKuoD6Init,
                dim612JoeKuoD6Init,
                dim613JoeKuoD6Init,
                dim614JoeKuoD6Init,
                dim615JoeKuoD6Init,
                dim616JoeKuoD6Init,
                dim617JoeKuoD6Init,
                dim618JoeKuoD6Init,
                dim619JoeKuoD6Init,
                dim620JoeKuoD6Init,
                dim621JoeKuoD6Init,
                dim622JoeKuoD6Init,
                dim623JoeKuoD6Init,
                dim624JoeKuoD6Init,
                dim625JoeKuoD6Init,
                dim626JoeKuoD6Init,
                dim627JoeKuoD6Init,
                dim628JoeKuoD6Init,
                dim629JoeKuoD6Init,
                dim630JoeKuoD6Init,
                dim631JoeKuoD6Init,
                dim632JoeKuoD6Init,
                dim633JoeKuoD6Init,
                dim634JoeKuoD6Init,
                dim635JoeKuoD6Init,
                dim636JoeKuoD6Init,
                dim637JoeKuoD6Init,
                dim638JoeKuoD6Init,
                dim639JoeKuoD6Init,
                dim640JoeKuoD6Init,
                dim641JoeKuoD6Init,
                dim642JoeKuoD6Init,
                dim643JoeKuoD6Init,
                dim644JoeKuoD6Init,
                dim645JoeKuoD6Init,
                dim646JoeKuoD6Init,
                dim647JoeKuoD6Init,
                dim648JoeKuoD6Init,
                dim649JoeKuoD6Init,
                dim650JoeKuoD6Init,
                dim651JoeKuoD6Init,
                dim652JoeKuoD6Init,
                dim653JoeKuoD6Init,
                dim654JoeKuoD6Init,
                dim655JoeKuoD6Init,
                dim656JoeKuoD6Init,
                dim657JoeKuoD6Init,
                dim658JoeKuoD6Init,
                dim659JoeKuoD6Init,
                dim660JoeKuoD6Init,
                dim661JoeKuoD6Init,
                dim662JoeKuoD6Init,
                dim663JoeKuoD6Init,
                dim664JoeKuoD6Init,
                dim665JoeKuoD6Init,
                dim666JoeKuoD6Init,
                dim667JoeKuoD6Init,
                dim668JoeKuoD6Init,
                dim669JoeKuoD6Init,
                dim670JoeKuoD6Init,
                dim671JoeKuoD6Init,
                dim672JoeKuoD6Init,
                dim673JoeKuoD6Init,
                dim674JoeKuoD6Init,
                dim675JoeKuoD6Init,
                dim676JoeKuoD6Init,
                dim677JoeKuoD6Init,
                dim678JoeKuoD6Init,
                dim679JoeKuoD6Init,
                dim680JoeKuoD6Init,
                dim681JoeKuoD6Init,
                dim682JoeKuoD6Init,
                dim683JoeKuoD6Init,
                dim684JoeKuoD6Init,
                dim685JoeKuoD6Init,
                dim686JoeKuoD6Init,
                dim687JoeKuoD6Init,
                dim688JoeKuoD6Init,
                dim689JoeKuoD6Init,
                dim690JoeKuoD6Init,
                dim691JoeKuoD6Init,
                dim692JoeKuoD6Init,
                dim693JoeKuoD6Init,
                dim694JoeKuoD6Init,
                dim695JoeKuoD6Init,
                dim696JoeKuoD6Init,
                dim697JoeKuoD6Init,
                dim698JoeKuoD6Init,
                dim699JoeKuoD6Init,
                dim700JoeKuoD6Init,
                dim701JoeKuoD6Init,
                dim702JoeKuoD6Init,
                dim703JoeKuoD6Init,
                dim704JoeKuoD6Init,
                dim705JoeKuoD6Init,
                dim706JoeKuoD6Init,
                dim707JoeKuoD6Init,
                dim708JoeKuoD6Init,
                dim709JoeKuoD6Init,
                dim710JoeKuoD6Init,
                dim711JoeKuoD6Init,
                dim712JoeKuoD6Init,
                dim713JoeKuoD6Init,
                dim714JoeKuoD6Init,
                dim715JoeKuoD6Init,
                dim716JoeKuoD6Init,
                dim717JoeKuoD6Init,
                dim718JoeKuoD6Init,
                dim719JoeKuoD6Init,
                dim720JoeKuoD6Init,
                dim721JoeKuoD6Init,
                dim722JoeKuoD6Init,
                dim723JoeKuoD6Init,
                dim724JoeKuoD6Init,
                dim725JoeKuoD6Init,
                dim726JoeKuoD6Init,
                dim727JoeKuoD6Init,
                dim728JoeKuoD6Init,
                dim729JoeKuoD6Init,
                dim730JoeKuoD6Init,
                dim731JoeKuoD6Init,
                dim732JoeKuoD6Init,
                dim733JoeKuoD6Init,
                dim734JoeKuoD6Init,
                dim735JoeKuoD6Init,
                dim736JoeKuoD6Init,
                dim737JoeKuoD6Init,
                dim738JoeKuoD6Init,
                dim739JoeKuoD6Init,
                dim740JoeKuoD6Init,
                dim741JoeKuoD6Init,
                dim742JoeKuoD6Init,
                dim743JoeKuoD6Init,
                dim744JoeKuoD6Init,
                dim745JoeKuoD6Init,
                dim746JoeKuoD6Init,
                dim747JoeKuoD6Init,
                dim748JoeKuoD6Init,
                dim749JoeKuoD6Init,
                dim750JoeKuoD6Init,
                dim751JoeKuoD6Init,
                dim752JoeKuoD6Init,
                dim753JoeKuoD6Init,
                dim754JoeKuoD6Init,
                dim755JoeKuoD6Init,
                dim756JoeKuoD6Init,
                dim757JoeKuoD6Init,
                dim758JoeKuoD6Init,
                dim759JoeKuoD6Init,
                dim760JoeKuoD6Init,
                dim761JoeKuoD6Init,
                dim762JoeKuoD6Init,
                dim763JoeKuoD6Init,
                dim764JoeKuoD6Init,
                dim765JoeKuoD6Init,
                dim766JoeKuoD6Init,
                dim767JoeKuoD6Init,
                dim768JoeKuoD6Init,
                dim769JoeKuoD6Init,
                dim770JoeKuoD6Init,
                dim771JoeKuoD6Init,
                dim772JoeKuoD6Init,
                dim773JoeKuoD6Init,
                dim774JoeKuoD6Init,
                dim775JoeKuoD6Init,
                dim776JoeKuoD6Init,
                dim777JoeKuoD6Init,
                dim778JoeKuoD6Init,
                dim779JoeKuoD6Init,
                dim780JoeKuoD6Init,
                dim781JoeKuoD6Init,
                dim782JoeKuoD6Init,
                dim783JoeKuoD6Init,
                dim784JoeKuoD6Init,
                dim785JoeKuoD6Init,
                dim786JoeKuoD6Init,
                dim787JoeKuoD6Init,
                dim788JoeKuoD6Init,
                dim789JoeKuoD6Init,
                dim790JoeKuoD6Init,
                dim791JoeKuoD6Init,
                dim792JoeKuoD6Init,
                dim793JoeKuoD6Init,
                dim794JoeKuoD6Init,
                dim795JoeKuoD6Init,
                dim796JoeKuoD6Init,
                dim797JoeKuoD6Init,
                dim798JoeKuoD6Init,
                dim799JoeKuoD6Init,
                dim800JoeKuoD6Init,
                dim801JoeKuoD6Init,
                dim802JoeKuoD6Init,
                dim803JoeKuoD6Init,
                dim804JoeKuoD6Init,
                dim805JoeKuoD6Init,
                dim806JoeKuoD6Init,
                dim807JoeKuoD6Init,
                dim808JoeKuoD6Init,
                dim809JoeKuoD6Init,
                dim810JoeKuoD6Init,
                dim811JoeKuoD6Init,
                dim812JoeKuoD6Init,
                dim813JoeKuoD6Init,
                dim814JoeKuoD6Init,
                dim815JoeKuoD6Init,
                dim816JoeKuoD6Init,
                dim817JoeKuoD6Init,
                dim818JoeKuoD6Init,
                dim819JoeKuoD6Init,
                dim820JoeKuoD6Init,
                dim821JoeKuoD6Init,
                dim822JoeKuoD6Init,
                dim823JoeKuoD6Init,
                dim824JoeKuoD6Init,
                dim825JoeKuoD6Init,
                dim826JoeKuoD6Init,
                dim827JoeKuoD6Init,
                dim828JoeKuoD6Init,
                dim829JoeKuoD6Init,
                dim830JoeKuoD6Init,
                dim831JoeKuoD6Init,
                dim832JoeKuoD6Init,
                dim833JoeKuoD6Init,
                dim834JoeKuoD6Init,
                dim835JoeKuoD6Init,
                dim836JoeKuoD6Init,
                dim837JoeKuoD6Init,
                dim838JoeKuoD6Init,
                dim839JoeKuoD6Init,
                dim840JoeKuoD6Init,
                dim841JoeKuoD6Init,
                dim842JoeKuoD6Init,
                dim843JoeKuoD6Init,
                dim844JoeKuoD6Init,
                dim845JoeKuoD6Init,
                dim846JoeKuoD6Init,
                dim847JoeKuoD6Init,
                dim848JoeKuoD6Init,
                dim849JoeKuoD6Init,
                dim850JoeKuoD6Init,
                dim851JoeKuoD6Init,
                dim852JoeKuoD6Init,
                dim853JoeKuoD6Init,
                dim854JoeKuoD6Init,
                dim855JoeKuoD6Init,
                dim856JoeKuoD6Init,
                dim857JoeKuoD6Init,
                dim858JoeKuoD6Init,
                dim859JoeKuoD6Init,
                dim860JoeKuoD6Init,
                dim861JoeKuoD6Init,
                dim862JoeKuoD6Init,
                dim863JoeKuoD6Init,
                dim864JoeKuoD6Init,
                dim865JoeKuoD6Init,
                dim866JoeKuoD6Init,
                dim867JoeKuoD6Init,
                dim868JoeKuoD6Init,
                dim869JoeKuoD6Init,
                dim870JoeKuoD6Init,
                dim871JoeKuoD6Init,
                dim872JoeKuoD6Init,
                dim873JoeKuoD6Init,
                dim874JoeKuoD6Init,
                dim875JoeKuoD6Init,
                dim876JoeKuoD6Init,
                dim877JoeKuoD6Init,
                dim878JoeKuoD6Init,
                dim879JoeKuoD6Init,
                dim880JoeKuoD6Init,
                dim881JoeKuoD6Init,
                dim882JoeKuoD6Init,
                dim883JoeKuoD6Init,
                dim884JoeKuoD6Init,
                dim885JoeKuoD6Init,
                dim886JoeKuoD6Init,
                dim887JoeKuoD6Init,
                dim888JoeKuoD6Init,
                dim889JoeKuoD6Init,
                dim890JoeKuoD6Init,
                dim891JoeKuoD6Init,
                dim892JoeKuoD6Init,
                dim893JoeKuoD6Init,
                dim894JoeKuoD6Init,
                dim895JoeKuoD6Init,
                dim896JoeKuoD6Init,
                dim897JoeKuoD6Init,
                dim898JoeKuoD6Init,
                dim899JoeKuoD6Init,
                dim900JoeKuoD6Init,
                dim901JoeKuoD6Init,
                dim902JoeKuoD6Init,
                dim903JoeKuoD6Init,
                dim904JoeKuoD6Init,
                dim905JoeKuoD6Init,
                dim906JoeKuoD6Init,
                dim907JoeKuoD6Init,
                dim908JoeKuoD6Init,
                dim909JoeKuoD6Init,
                dim910JoeKuoD6Init,
                dim911JoeKuoD6Init,
                dim912JoeKuoD6Init,
                dim913JoeKuoD6Init,
                dim914JoeKuoD6Init,
                dim915JoeKuoD6Init,
                dim916JoeKuoD6Init,
                dim917JoeKuoD6Init,
                dim918JoeKuoD6Init,
                dim919JoeKuoD6Init,
                dim920JoeKuoD6Init,
                dim921JoeKuoD6Init,
                dim922JoeKuoD6Init,
                dim923JoeKuoD6Init,
                dim924JoeKuoD6Init,
                dim925JoeKuoD6Init,
                dim926JoeKuoD6Init,
                dim927JoeKuoD6Init,
                dim928JoeKuoD6Init,
                dim929JoeKuoD6Init,
                dim930JoeKuoD6Init,
                dim931JoeKuoD6Init,
                dim932JoeKuoD6Init,
                dim933JoeKuoD6Init,
                dim934JoeKuoD6Init,
                dim935JoeKuoD6Init,
                dim936JoeKuoD6Init,
                dim937JoeKuoD6Init,
                dim938JoeKuoD6Init,
                dim939JoeKuoD6Init,
                dim940JoeKuoD6Init,
                dim941JoeKuoD6Init,
                dim942JoeKuoD6Init,
                dim943JoeKuoD6Init,
                dim944JoeKuoD6Init,
                dim945JoeKuoD6Init,
                dim946JoeKuoD6Init,
                dim947JoeKuoD6Init,
                dim948JoeKuoD6Init,
                dim949JoeKuoD6Init,
                dim950JoeKuoD6Init,
                dim951JoeKuoD6Init,
                dim952JoeKuoD6Init,
                dim953JoeKuoD6Init,
                dim954JoeKuoD6Init,
                dim955JoeKuoD6Init,
                dim956JoeKuoD6Init,
                dim957JoeKuoD6Init,
                dim958JoeKuoD6Init,
                dim959JoeKuoD6Init,
                dim960JoeKuoD6Init,
                dim961JoeKuoD6Init,
                dim962JoeKuoD6Init,
                dim963JoeKuoD6Init,
                dim964JoeKuoD6Init,
                dim965JoeKuoD6Init,
                dim966JoeKuoD6Init,
                dim967JoeKuoD6Init,
                dim968JoeKuoD6Init,
                dim969JoeKuoD6Init,
                dim970JoeKuoD6Init,
                dim971JoeKuoD6Init,
                dim972JoeKuoD6Init,
                dim973JoeKuoD6Init,
                dim974JoeKuoD6Init,
                dim975JoeKuoD6Init,
                dim976JoeKuoD6Init,
                dim977JoeKuoD6Init,
                dim978JoeKuoD6Init,
                dim979JoeKuoD6Init,
                dim980JoeKuoD6Init,
                dim981JoeKuoD6Init,
                dim982JoeKuoD6Init,
                dim983JoeKuoD6Init,
                dim984JoeKuoD6Init,
                dim985JoeKuoD6Init,
                dim986JoeKuoD6Init,
                dim987JoeKuoD6Init,
                dim988JoeKuoD6Init,
                dim989JoeKuoD6Init,
                dim990JoeKuoD6Init,
                dim991JoeKuoD6Init,
                dim992JoeKuoD6Init,
                dim993JoeKuoD6Init,
                dim994JoeKuoD6Init,
                dim995JoeKuoD6Init,
                dim996JoeKuoD6Init,
                dim997JoeKuoD6Init,
                dim998JoeKuoD6Init,
                dim999JoeKuoD6Init,
                dim1000JoeKuoD6Init,
                dim1001JoeKuoD6Init,
                dim1002JoeKuoD6Init,
                dim1003JoeKuoD6Init,
                dim1004JoeKuoD6Init,
                dim1005JoeKuoD6Init,
                dim1006JoeKuoD6Init,
                dim1007JoeKuoD6Init,
                dim1008JoeKuoD6Init,
                dim1009JoeKuoD6Init,
                dim1010JoeKuoD6Init,
                dim1011JoeKuoD6Init,
                dim1012JoeKuoD6Init,
                dim1013JoeKuoD6Init,
                dim1014JoeKuoD6Init,
                dim1015JoeKuoD6Init,
                dim1016JoeKuoD6Init,
                dim1017JoeKuoD6Init,
                dim1018JoeKuoD6Init,
                dim1019JoeKuoD6Init,
                dim1020JoeKuoD6Init,
                dim1021JoeKuoD6Init,
                dim1022JoeKuoD6Init,
                dim1023JoeKuoD6Init,
                dim1024JoeKuoD6Init,
                dim1025JoeKuoD6Init,
                dim1026JoeKuoD6Init,
                dim1027JoeKuoD6Init,
                dim1028JoeKuoD6Init,
                dim1029JoeKuoD6Init,
                dim1030JoeKuoD6Init,
                dim1031JoeKuoD6Init,
                dim1032JoeKuoD6Init,
                dim1033JoeKuoD6Init,
                dim1034JoeKuoD6Init,
                dim1035JoeKuoD6Init,
                dim1036JoeKuoD6Init,
                dim1037JoeKuoD6Init,
                dim1038JoeKuoD6Init,
                dim1039JoeKuoD6Init,
                dim1040JoeKuoD6Init,
                dim1041JoeKuoD6Init,
                dim1042JoeKuoD6Init,
                dim1043JoeKuoD6Init,
                dim1044JoeKuoD6Init,
                dim1045JoeKuoD6Init,
                dim1046JoeKuoD6Init,
                dim1047JoeKuoD6Init,
                dim1048JoeKuoD6Init,
                dim1049JoeKuoD6Init,
                dim1050JoeKuoD6Init,
                dim1051JoeKuoD6Init,
                dim1052JoeKuoD6Init,
                dim1053JoeKuoD6Init,
                dim1054JoeKuoD6Init,
                dim1055JoeKuoD6Init,
                dim1056JoeKuoD6Init,
                dim1057JoeKuoD6Init,
                dim1058JoeKuoD6Init,
                dim1059JoeKuoD6Init,
                dim1060JoeKuoD6Init,
                dim1061JoeKuoD6Init,
                dim1062JoeKuoD6Init,
                dim1063JoeKuoD6Init,
                dim1064JoeKuoD6Init,
                dim1065JoeKuoD6Init,
                dim1066JoeKuoD6Init,
                dim1067JoeKuoD6Init,
                dim1068JoeKuoD6Init,
                dim1069JoeKuoD6Init,
                dim1070JoeKuoD6Init,
                dim1071JoeKuoD6Init,
                dim1072JoeKuoD6Init,
                dim1073JoeKuoD6Init,
                dim1074JoeKuoD6Init,
                dim1075JoeKuoD6Init,
                dim1076JoeKuoD6Init,
                dim1077JoeKuoD6Init,
                dim1078JoeKuoD6Init,
                dim1079JoeKuoD6Init,
                dim1080JoeKuoD6Init,
                dim1081JoeKuoD6Init,
                dim1082JoeKuoD6Init,
                dim1083JoeKuoD6Init,
                dim1084JoeKuoD6Init,
                dim1085JoeKuoD6Init,
                dim1086JoeKuoD6Init,
                dim1087JoeKuoD6Init,
                dim1088JoeKuoD6Init,
                dim1089JoeKuoD6Init,
                dim1090JoeKuoD6Init,
                dim1091JoeKuoD6Init,
                dim1092JoeKuoD6Init,
                dim1093JoeKuoD6Init,
                dim1094JoeKuoD6Init,
                dim1095JoeKuoD6Init,
                dim1096JoeKuoD6Init,
                dim1097JoeKuoD6Init,
                dim1098JoeKuoD6Init,
                dim1099JoeKuoD6Init,
                dim1100JoeKuoD6Init,
                dim1101JoeKuoD6Init,
                dim1102JoeKuoD6Init,
                dim1103JoeKuoD6Init,
                dim1104JoeKuoD6Init,
                dim1105JoeKuoD6Init,
                dim1106JoeKuoD6Init,
                dim1107JoeKuoD6Init,
                dim1108JoeKuoD6Init,
                dim1109JoeKuoD6Init,
                dim1110JoeKuoD6Init,
                dim1111JoeKuoD6Init,
                dim1112JoeKuoD6Init,
                dim1113JoeKuoD6Init,
                dim1114JoeKuoD6Init,
                dim1115JoeKuoD6Init,
                dim1116JoeKuoD6Init,
                dim1117JoeKuoD6Init,
                dim1118JoeKuoD6Init,
                dim1119JoeKuoD6Init,
                dim1120JoeKuoD6Init,
                dim1121JoeKuoD6Init,
                dim1122JoeKuoD6Init,
                dim1123JoeKuoD6Init,
                dim1124JoeKuoD6Init,
                dim1125JoeKuoD6Init,
                dim1126JoeKuoD6Init,
                dim1127JoeKuoD6Init,
                dim1128JoeKuoD6Init,
                dim1129JoeKuoD6Init,
                dim1130JoeKuoD6Init,
                dim1131JoeKuoD6Init,
                dim1132JoeKuoD6Init,
                dim1133JoeKuoD6Init,
                dim1134JoeKuoD6Init,
                dim1135JoeKuoD6Init,
                dim1136JoeKuoD6Init,
                dim1137JoeKuoD6Init,
                dim1138JoeKuoD6Init,
                dim1139JoeKuoD6Init,
                dim1140JoeKuoD6Init,
                dim1141JoeKuoD6Init,
                dim1142JoeKuoD6Init,
                dim1143JoeKuoD6Init,
                dim1144JoeKuoD6Init,
                dim1145JoeKuoD6Init,
                dim1146JoeKuoD6Init,
                dim1147JoeKuoD6Init,
                dim1148JoeKuoD6Init,
                dim1149JoeKuoD6Init,
                dim1150JoeKuoD6Init,
                dim1151JoeKuoD6Init,
                dim1152JoeKuoD6Init,
                dim1153JoeKuoD6Init,
                dim1154JoeKuoD6Init,
                dim1155JoeKuoD6Init,
                dim1156JoeKuoD6Init,
                dim1157JoeKuoD6Init,
                dim1158JoeKuoD6Init,
                dim1159JoeKuoD6Init,
                dim1160JoeKuoD6Init,
                dim1161JoeKuoD6Init,
                dim1162JoeKuoD6Init,
                dim1163JoeKuoD6Init,
                dim1164JoeKuoD6Init,
                dim1165JoeKuoD6Init,
                dim1166JoeKuoD6Init,
                dim1167JoeKuoD6Init,
                dim1168JoeKuoD6Init,
                dim1169JoeKuoD6Init,
                dim1170JoeKuoD6Init,
                dim1171JoeKuoD6Init,
                dim1172JoeKuoD6Init,
                dim1173JoeKuoD6Init,
                dim1174JoeKuoD6Init,
                dim1175JoeKuoD6Init,
                dim1176JoeKuoD6Init,
                dim1177JoeKuoD6Init,
                dim1178JoeKuoD6Init,
                dim1179JoeKuoD6Init,
                dim1180JoeKuoD6Init,
                dim1181JoeKuoD6Init,
                dim1182JoeKuoD6Init,
                dim1183JoeKuoD6Init,
                dim1184JoeKuoD6Init,
                dim1185JoeKuoD6Init,
                dim1186JoeKuoD6Init,
                dim1187JoeKuoD6Init,
                dim1188JoeKuoD6Init,
                dim1189JoeKuoD6Init,
                dim1190JoeKuoD6Init,
                dim1191JoeKuoD6Init,
                dim1192JoeKuoD6Init,
                dim1193JoeKuoD6Init,
                dim1194JoeKuoD6Init,
                dim1195JoeKuoD6Init,
                dim1196JoeKuoD6Init,
                dim1197JoeKuoD6Init,
                dim1198JoeKuoD6Init,
                dim1199JoeKuoD6Init,
                dim1200JoeKuoD6Init,
                dim1201JoeKuoD6Init,
                dim1202JoeKuoD6Init,
                dim1203JoeKuoD6Init,
                dim1204JoeKuoD6Init,
                dim1205JoeKuoD6Init,
                dim1206JoeKuoD6Init,
                dim1207JoeKuoD6Init,
                dim1208JoeKuoD6Init,
                dim1209JoeKuoD6Init,
                dim1210JoeKuoD6Init,
                dim1211JoeKuoD6Init,
                dim1212JoeKuoD6Init,
                dim1213JoeKuoD6Init,
                dim1214JoeKuoD6Init,
                dim1215JoeKuoD6Init,
                dim1216JoeKuoD6Init,
                dim1217JoeKuoD6Init,
                dim1218JoeKuoD6Init,
                dim1219JoeKuoD6Init,
                dim1220JoeKuoD6Init,
                dim1221JoeKuoD6Init,
                dim1222JoeKuoD6Init,
                dim1223JoeKuoD6Init,
                dim1224JoeKuoD6Init,
                dim1225JoeKuoD6Init,
                dim1226JoeKuoD6Init,
                dim1227JoeKuoD6Init,
                dim1228JoeKuoD6Init,
                dim1229JoeKuoD6Init,
                dim1230JoeKuoD6Init,
                dim1231JoeKuoD6Init,
                dim1232JoeKuoD6Init,
                dim1233JoeKuoD6Init,
                dim1234JoeKuoD6Init,
                dim1235JoeKuoD6Init,
                dim1236JoeKuoD6Init,
                dim1237JoeKuoD6Init,
                dim1238JoeKuoD6Init,
                dim1239JoeKuoD6Init,
                dim1240JoeKuoD6Init,
                dim1241JoeKuoD6Init,
                dim1242JoeKuoD6Init,
                dim1243JoeKuoD6Init,
                dim1244JoeKuoD6Init,
                dim1245JoeKuoD6Init,
                dim1246JoeKuoD6Init,
                dim1247JoeKuoD6Init,
                dim1248JoeKuoD6Init,
                dim1249JoeKuoD6Init,
                dim1250JoeKuoD6Init,
                dim1251JoeKuoD6Init,
                dim1252JoeKuoD6Init,
                dim1253JoeKuoD6Init,
                dim1254JoeKuoD6Init,
                dim1255JoeKuoD6Init,
                dim1256JoeKuoD6Init,
                dim1257JoeKuoD6Init,
                dim1258JoeKuoD6Init,
                dim1259JoeKuoD6Init,
                dim1260JoeKuoD6Init,
                dim1261JoeKuoD6Init,
                dim1262JoeKuoD6Init,
                dim1263JoeKuoD6Init,
                dim1264JoeKuoD6Init,
                dim1265JoeKuoD6Init,
                dim1266JoeKuoD6Init,
                dim1267JoeKuoD6Init,
                dim1268JoeKuoD6Init,
                dim1269JoeKuoD6Init,
                dim1270JoeKuoD6Init,
                dim1271JoeKuoD6Init,
                dim1272JoeKuoD6Init,
                dim1273JoeKuoD6Init,
                dim1274JoeKuoD6Init,
                dim1275JoeKuoD6Init,
                dim1276JoeKuoD6Init,
                dim1277JoeKuoD6Init,
                dim1278JoeKuoD6Init,
                dim1279JoeKuoD6Init,
                dim1280JoeKuoD6Init,
                dim1281JoeKuoD6Init,
                dim1282JoeKuoD6Init,
                dim1283JoeKuoD6Init,
                dim1284JoeKuoD6Init,
                dim1285JoeKuoD6Init,
                dim1286JoeKuoD6Init,
                dim1287JoeKuoD6Init,
                dim1288JoeKuoD6Init,
                dim1289JoeKuoD6Init,
                dim1290JoeKuoD6Init,
                dim1291JoeKuoD6Init,
                dim1292JoeKuoD6Init,
                dim1293JoeKuoD6Init,
                dim1294JoeKuoD6Init,
                dim1295JoeKuoD6Init,
                dim1296JoeKuoD6Init,
                dim1297JoeKuoD6Init,
                dim1298JoeKuoD6Init,
                dim1299JoeKuoD6Init,
                dim1300JoeKuoD6Init,
                dim1301JoeKuoD6Init,
                dim1302JoeKuoD6Init,
                dim1303JoeKuoD6Init,
                dim1304JoeKuoD6Init,
                dim1305JoeKuoD6Init,
                dim1306JoeKuoD6Init,
                dim1307JoeKuoD6Init,
                dim1308JoeKuoD6Init,
                dim1309JoeKuoD6Init,
                dim1310JoeKuoD6Init,
                dim1311JoeKuoD6Init,
                dim1312JoeKuoD6Init,
                dim1313JoeKuoD6Init,
                dim1314JoeKuoD6Init,
                dim1315JoeKuoD6Init,
                dim1316JoeKuoD6Init,
                dim1317JoeKuoD6Init,
                dim1318JoeKuoD6Init,
                dim1319JoeKuoD6Init,
                dim1320JoeKuoD6Init,
                dim1321JoeKuoD6Init,
                dim1322JoeKuoD6Init,
                dim1323JoeKuoD6Init,
                dim1324JoeKuoD6Init,
                dim1325JoeKuoD6Init,
                dim1326JoeKuoD6Init,
                dim1327JoeKuoD6Init,
                dim1328JoeKuoD6Init,
                dim1329JoeKuoD6Init,
                dim1330JoeKuoD6Init,
                dim1331JoeKuoD6Init,
                dim1332JoeKuoD6Init,
                dim1333JoeKuoD6Init,
                dim1334JoeKuoD6Init,
                dim1335JoeKuoD6Init,
                dim1336JoeKuoD6Init,
                dim1337JoeKuoD6Init,
                dim1338JoeKuoD6Init,
                dim1339JoeKuoD6Init,
                dim1340JoeKuoD6Init,
                dim1341JoeKuoD6Init,
                dim1342JoeKuoD6Init,
                dim1343JoeKuoD6Init,
                dim1344JoeKuoD6Init,
                dim1345JoeKuoD6Init,
                dim1346JoeKuoD6Init,
                dim1347JoeKuoD6Init,
                dim1348JoeKuoD6Init,
                dim1349JoeKuoD6Init,
                dim1350JoeKuoD6Init,
                dim1351JoeKuoD6Init,
                dim1352JoeKuoD6Init,
                dim1353JoeKuoD6Init,
                dim1354JoeKuoD6Init,
                dim1355JoeKuoD6Init,
                dim1356JoeKuoD6Init,
                dim1357JoeKuoD6Init,
                dim1358JoeKuoD6Init,
                dim1359JoeKuoD6Init,
                dim1360JoeKuoD6Init,
                dim1361JoeKuoD6Init,
                dim1362JoeKuoD6Init,
                dim1363JoeKuoD6Init,
                dim1364JoeKuoD6Init,
                dim1365JoeKuoD6Init,
                dim1366JoeKuoD6Init,
                dim1367JoeKuoD6Init,
                dim1368JoeKuoD6Init,
                dim1369JoeKuoD6Init,
                dim1370JoeKuoD6Init,
                dim1371JoeKuoD6Init,
                dim1372JoeKuoD6Init,
                dim1373JoeKuoD6Init,
                dim1374JoeKuoD6Init,
                dim1375JoeKuoD6Init,
                dim1376JoeKuoD6Init,
                dim1377JoeKuoD6Init,
                dim1378JoeKuoD6Init,
                dim1379JoeKuoD6Init,
                dim1380JoeKuoD6Init,
                dim1381JoeKuoD6Init,
                dim1382JoeKuoD6Init,
                dim1383JoeKuoD6Init,
                dim1384JoeKuoD6Init,
                dim1385JoeKuoD6Init,
                dim1386JoeKuoD6Init,
                dim1387JoeKuoD6Init,
                dim1388JoeKuoD6Init,
                dim1389JoeKuoD6Init,
                dim1390JoeKuoD6Init,
                dim1391JoeKuoD6Init,
                dim1392JoeKuoD6Init,
                dim1393JoeKuoD6Init,
                dim1394JoeKuoD6Init,
                dim1395JoeKuoD6Init,
                dim1396JoeKuoD6Init,
                dim1397JoeKuoD6Init,
                dim1398JoeKuoD6Init,
                dim1399JoeKuoD6Init,
                dim1400JoeKuoD6Init,
                dim1401JoeKuoD6Init,
                dim1402JoeKuoD6Init,
                dim1403JoeKuoD6Init,
                dim1404JoeKuoD6Init,
                dim1405JoeKuoD6Init,
                dim1406JoeKuoD6Init,
                dim1407JoeKuoD6Init,
                dim1408JoeKuoD6Init,
                dim1409JoeKuoD6Init,
                dim1410JoeKuoD6Init,
                dim1411JoeKuoD6Init,
                dim1412JoeKuoD6Init,
                dim1413JoeKuoD6Init,
                dim1414JoeKuoD6Init,
                dim1415JoeKuoD6Init,
                dim1416JoeKuoD6Init,
                dim1417JoeKuoD6Init,
                dim1418JoeKuoD6Init,
                dim1419JoeKuoD6Init,
                dim1420JoeKuoD6Init,
                dim1421JoeKuoD6Init,
                dim1422JoeKuoD6Init,
                dim1423JoeKuoD6Init,
                dim1424JoeKuoD6Init,
                dim1425JoeKuoD6Init,
                dim1426JoeKuoD6Init,
                dim1427JoeKuoD6Init,
                dim1428JoeKuoD6Init,
                dim1429JoeKuoD6Init,
                dim1430JoeKuoD6Init,
                dim1431JoeKuoD6Init,
                dim1432JoeKuoD6Init,
                dim1433JoeKuoD6Init,
                dim1434JoeKuoD6Init,
                dim1435JoeKuoD6Init,
                dim1436JoeKuoD6Init,
                dim1437JoeKuoD6Init,
                dim1438JoeKuoD6Init,
                dim1439JoeKuoD6Init,
                dim1440JoeKuoD6Init,
                dim1441JoeKuoD6Init,
                dim1442JoeKuoD6Init,
                dim1443JoeKuoD6Init,
                dim1444JoeKuoD6Init,
                dim1445JoeKuoD6Init,
                dim1446JoeKuoD6Init,
                dim1447JoeKuoD6Init,
                dim1448JoeKuoD6Init,
                dim1449JoeKuoD6Init,
                dim1450JoeKuoD6Init,
                dim1451JoeKuoD6Init,
                dim1452JoeKuoD6Init,
                dim1453JoeKuoD6Init,
                dim1454JoeKuoD6Init,
                dim1455JoeKuoD6Init,
                dim1456JoeKuoD6Init,
                dim1457JoeKuoD6Init,
                dim1458JoeKuoD6Init,
                dim1459JoeKuoD6Init,
                dim1460JoeKuoD6Init,
                dim1461JoeKuoD6Init,
                dim1462JoeKuoD6Init,
                dim1463JoeKuoD6Init,
                dim1464JoeKuoD6Init,
                dim1465JoeKuoD6Init,
                dim1466JoeKuoD6Init,
                dim1467JoeKuoD6Init,
                dim1468JoeKuoD6Init,
                dim1469JoeKuoD6Init,
                dim1470JoeKuoD6Init,
                dim1471JoeKuoD6Init,
                dim1472JoeKuoD6Init,
                dim1473JoeKuoD6Init,
                dim1474JoeKuoD6Init,
                dim1475JoeKuoD6Init,
                dim1476JoeKuoD6Init,
                dim1477JoeKuoD6Init,
                dim1478JoeKuoD6Init,
                dim1479JoeKuoD6Init,
                dim1480JoeKuoD6Init,
                dim1481JoeKuoD6Init,
                dim1482JoeKuoD6Init,
                dim1483JoeKuoD6Init,
                dim1484JoeKuoD6Init,
                dim1485JoeKuoD6Init,
                dim1486JoeKuoD6Init,
                dim1487JoeKuoD6Init,
                dim1488JoeKuoD6Init,
                dim1489JoeKuoD6Init,
                dim1490JoeKuoD6Init,
                dim1491JoeKuoD6Init,
                dim1492JoeKuoD6Init,
                dim1493JoeKuoD6Init,
                dim1494JoeKuoD6Init,
                dim1495JoeKuoD6Init,
                dim1496JoeKuoD6Init,
                dim1497JoeKuoD6Init,
                dim1498JoeKuoD6Init,
                dim1499JoeKuoD6Init,
                dim1500JoeKuoD6Init,
                dim1501JoeKuoD6Init,
                dim1502JoeKuoD6Init,
                dim1503JoeKuoD6Init,
                dim1504JoeKuoD6Init,
                dim1505JoeKuoD6Init,
                dim1506JoeKuoD6Init,
                dim1507JoeKuoD6Init,
                dim1508JoeKuoD6Init,
                dim1509JoeKuoD6Init,
                dim1510JoeKuoD6Init,
                dim1511JoeKuoD6Init,
                dim1512JoeKuoD6Init,
                dim1513JoeKuoD6Init,
                dim1514JoeKuoD6Init,
                dim1515JoeKuoD6Init,
                dim1516JoeKuoD6Init,
                dim1517JoeKuoD6Init,
                dim1518JoeKuoD6Init,
                dim1519JoeKuoD6Init,
                dim1520JoeKuoD6Init,
                dim1521JoeKuoD6Init,
                dim1522JoeKuoD6Init,
                dim1523JoeKuoD6Init,
                dim1524JoeKuoD6Init,
                dim1525JoeKuoD6Init,
                dim1526JoeKuoD6Init,
                dim1527JoeKuoD6Init,
                dim1528JoeKuoD6Init,
                dim1529JoeKuoD6Init,
                dim1530JoeKuoD6Init,
                dim1531JoeKuoD6Init,
                dim1532JoeKuoD6Init,
                dim1533JoeKuoD6Init,
                dim1534JoeKuoD6Init,
                dim1535JoeKuoD6Init,
                dim1536JoeKuoD6Init,
                dim1537JoeKuoD6Init,
                dim1538JoeKuoD6Init,
                dim1539JoeKuoD6Init,
                dim1540JoeKuoD6Init,
                dim1541JoeKuoD6Init,
                dim1542JoeKuoD6Init,
                dim1543JoeKuoD6Init,
                dim1544JoeKuoD6Init,
                dim1545JoeKuoD6Init,
                dim1546JoeKuoD6Init,
                dim1547JoeKuoD6Init,
                dim1548JoeKuoD6Init,
                dim1549JoeKuoD6Init,
                dim1550JoeKuoD6Init,
                dim1551JoeKuoD6Init,
                dim1552JoeKuoD6Init,
                dim1553JoeKuoD6Init,
                dim1554JoeKuoD6Init,
                dim1555JoeKuoD6Init,
                dim1556JoeKuoD6Init,
                dim1557JoeKuoD6Init,
                dim1558JoeKuoD6Init,
                dim1559JoeKuoD6Init,
                dim1560JoeKuoD6Init,
                dim1561JoeKuoD6Init,
                dim1562JoeKuoD6Init,
                dim1563JoeKuoD6Init,
                dim1564JoeKuoD6Init,
                dim1565JoeKuoD6Init,
                dim1566JoeKuoD6Init,
                dim1567JoeKuoD6Init,
                dim1568JoeKuoD6Init,
                dim1569JoeKuoD6Init,
                dim1570JoeKuoD6Init,
                dim1571JoeKuoD6Init,
                dim1572JoeKuoD6Init,
                dim1573JoeKuoD6Init,
                dim1574JoeKuoD6Init,
                dim1575JoeKuoD6Init,
                dim1576JoeKuoD6Init,
                dim1577JoeKuoD6Init,
                dim1578JoeKuoD6Init,
                dim1579JoeKuoD6Init,
                dim1580JoeKuoD6Init,
                dim1581JoeKuoD6Init,
                dim1582JoeKuoD6Init,
                dim1583JoeKuoD6Init,
                dim1584JoeKuoD6Init,
                dim1585JoeKuoD6Init,
                dim1586JoeKuoD6Init,
                dim1587JoeKuoD6Init,
                dim1588JoeKuoD6Init,
                dim1589JoeKuoD6Init,
                dim1590JoeKuoD6Init,
                dim1591JoeKuoD6Init,
                dim1592JoeKuoD6Init,
                dim1593JoeKuoD6Init,
                dim1594JoeKuoD6Init,
                dim1595JoeKuoD6Init,
                dim1596JoeKuoD6Init,
                dim1597JoeKuoD6Init,
                dim1598JoeKuoD6Init,
                dim1599JoeKuoD6Init,
                dim1600JoeKuoD6Init,
                dim1601JoeKuoD6Init,
                dim1602JoeKuoD6Init,
                dim1603JoeKuoD6Init,
                dim1604JoeKuoD6Init,
                dim1605JoeKuoD6Init,
                dim1606JoeKuoD6Init,
                dim1607JoeKuoD6Init,
                dim1608JoeKuoD6Init,
                dim1609JoeKuoD6Init,
                dim1610JoeKuoD6Init,
                dim1611JoeKuoD6Init,
                dim1612JoeKuoD6Init,
                dim1613JoeKuoD6Init,
                dim1614JoeKuoD6Init,
                dim1615JoeKuoD6Init,
                dim1616JoeKuoD6Init,
                dim1617JoeKuoD6Init,
                dim1618JoeKuoD6Init,
                dim1619JoeKuoD6Init,
                dim1620JoeKuoD6Init,
                dim1621JoeKuoD6Init,
                dim1622JoeKuoD6Init,
                dim1623JoeKuoD6Init,
                dim1624JoeKuoD6Init,
                dim1625JoeKuoD6Init,
                dim1626JoeKuoD6Init,
                dim1627JoeKuoD6Init,
                dim1628JoeKuoD6Init,
                dim1629JoeKuoD6Init,
                dim1630JoeKuoD6Init,
                dim1631JoeKuoD6Init,
                dim1632JoeKuoD6Init,
                dim1633JoeKuoD6Init,
                dim1634JoeKuoD6Init,
                dim1635JoeKuoD6Init,
                dim1636JoeKuoD6Init,
                dim1637JoeKuoD6Init,
                dim1638JoeKuoD6Init,
                dim1639JoeKuoD6Init,
                dim1640JoeKuoD6Init,
                dim1641JoeKuoD6Init,
                dim1642JoeKuoD6Init,
                dim1643JoeKuoD6Init,
                dim1644JoeKuoD6Init,
                dim1645JoeKuoD6Init,
                dim1646JoeKuoD6Init,
                dim1647JoeKuoD6Init,
                dim1648JoeKuoD6Init,
                dim1649JoeKuoD6Init,
                dim1650JoeKuoD6Init,
                dim1651JoeKuoD6Init,
                dim1652JoeKuoD6Init,
                dim1653JoeKuoD6Init,
                dim1654JoeKuoD6Init,
                dim1655JoeKuoD6Init,
                dim1656JoeKuoD6Init,
                dim1657JoeKuoD6Init,
                dim1658JoeKuoD6Init,
                dim1659JoeKuoD6Init,
                dim1660JoeKuoD6Init,
                dim1661JoeKuoD6Init,
                dim1662JoeKuoD6Init,
                dim1663JoeKuoD6Init,
                dim1664JoeKuoD6Init,
                dim1665JoeKuoD6Init,
                dim1666JoeKuoD6Init,
                dim1667JoeKuoD6Init,
                dim1668JoeKuoD6Init,
                dim1669JoeKuoD6Init,
                dim1670JoeKuoD6Init,
                dim1671JoeKuoD6Init,
                dim1672JoeKuoD6Init,
                dim1673JoeKuoD6Init,
                dim1674JoeKuoD6Init,
                dim1675JoeKuoD6Init,
                dim1676JoeKuoD6Init,
                dim1677JoeKuoD6Init,
                dim1678JoeKuoD6Init,
                dim1679JoeKuoD6Init,
                dim1680JoeKuoD6Init,
                dim1681JoeKuoD6Init,
                dim1682JoeKuoD6Init,
                dim1683JoeKuoD6Init,
                dim1684JoeKuoD6Init,
                dim1685JoeKuoD6Init,
                dim1686JoeKuoD6Init,
                dim1687JoeKuoD6Init,
                dim1688JoeKuoD6Init,
                dim1689JoeKuoD6Init,
                dim1690JoeKuoD6Init,
                dim1691JoeKuoD6Init,
                dim1692JoeKuoD6Init,
                dim1693JoeKuoD6Init,
                dim1694JoeKuoD6Init,
                dim1695JoeKuoD6Init,
                dim1696JoeKuoD6Init,
                dim1697JoeKuoD6Init,
                dim1698JoeKuoD6Init,
                dim1699JoeKuoD6Init,
                dim1700JoeKuoD6Init,
                dim1701JoeKuoD6Init,
                dim1702JoeKuoD6Init,
                dim1703JoeKuoD6Init,
                dim1704JoeKuoD6Init,
                dim1705JoeKuoD6Init,
                dim1706JoeKuoD6Init,
                dim1707JoeKuoD6Init,
                dim1708JoeKuoD6Init,
                dim1709JoeKuoD6Init,
                dim1710JoeKuoD6Init,
                dim1711JoeKuoD6Init,
                dim1712JoeKuoD6Init,
                dim1713JoeKuoD6Init,
                dim1714JoeKuoD6Init,
                dim1715JoeKuoD6Init,
                dim1716JoeKuoD6Init,
                dim1717JoeKuoD6Init,
                dim1718JoeKuoD6Init,
                dim1719JoeKuoD6Init,
                dim1720JoeKuoD6Init,
                dim1721JoeKuoD6Init,
                dim1722JoeKuoD6Init,
                dim1723JoeKuoD6Init,
                dim1724JoeKuoD6Init,
                dim1725JoeKuoD6Init,
                dim1726JoeKuoD6Init,
                dim1727JoeKuoD6Init,
                dim1728JoeKuoD6Init,
                dim1729JoeKuoD6Init,
                dim1730JoeKuoD6Init,
                dim1731JoeKuoD6Init,
                dim1732JoeKuoD6Init,
                dim1733JoeKuoD6Init,
                dim1734JoeKuoD6Init,
                dim1735JoeKuoD6Init,
                dim1736JoeKuoD6Init,
                dim1737JoeKuoD6Init,
                dim1738JoeKuoD6Init,
                dim1739JoeKuoD6Init,
                dim1740JoeKuoD6Init,
                dim1741JoeKuoD6Init,
                dim1742JoeKuoD6Init,
                dim1743JoeKuoD6Init,
                dim1744JoeKuoD6Init,
                dim1745JoeKuoD6Init,
                dim1746JoeKuoD6Init,
                dim1747JoeKuoD6Init,
                dim1748JoeKuoD6Init,
                dim1749JoeKuoD6Init,
                dim1750JoeKuoD6Init,
                dim1751JoeKuoD6Init,
                dim1752JoeKuoD6Init,
                dim1753JoeKuoD6Init,
                dim1754JoeKuoD6Init,
                dim1755JoeKuoD6Init,
                dim1756JoeKuoD6Init,
                dim1757JoeKuoD6Init,
                dim1758JoeKuoD6Init,
                dim1759JoeKuoD6Init,
                dim1760JoeKuoD6Init,
                dim1761JoeKuoD6Init,
                dim1762JoeKuoD6Init,
                dim1763JoeKuoD6Init,
                dim1764JoeKuoD6Init,
                dim1765JoeKuoD6Init,
                dim1766JoeKuoD6Init,
                dim1767JoeKuoD6Init,
                dim1768JoeKuoD6Init,
                dim1769JoeKuoD6Init,
                dim1770JoeKuoD6Init,
                dim1771JoeKuoD6Init,
                dim1772JoeKuoD6Init,
                dim1773JoeKuoD6Init,
                dim1774JoeKuoD6Init,
                dim1775JoeKuoD6Init,
                dim1776JoeKuoD6Init,
                dim1777JoeKuoD6Init,
                dim1778JoeKuoD6Init,
                dim1779JoeKuoD6Init,
                dim1780JoeKuoD6Init,
                dim1781JoeKuoD6Init,
                dim1782JoeKuoD6Init,
                dim1783JoeKuoD6Init,
                dim1784JoeKuoD6Init,
                dim1785JoeKuoD6Init,
                dim1786JoeKuoD6Init,
                dim1787JoeKuoD6Init,
                dim1788JoeKuoD6Init,
                dim1789JoeKuoD6Init,
                dim1790JoeKuoD6Init,
                dim1791JoeKuoD6Init,
                dim1792JoeKuoD6Init,
                dim1793JoeKuoD6Init,
                dim1794JoeKuoD6Init,
                dim1795JoeKuoD6Init,
                dim1796JoeKuoD6Init,
                dim1797JoeKuoD6Init,
                dim1798JoeKuoD6Init,
                dim1799JoeKuoD6Init,
                dim1800JoeKuoD6Init,
                dim1801JoeKuoD6Init,
                dim1802JoeKuoD6Init,
                dim1803JoeKuoD6Init,
                dim1804JoeKuoD6Init,
                dim1805JoeKuoD6Init,
                dim1806JoeKuoD6Init,
                dim1807JoeKuoD6Init,
                dim1808JoeKuoD6Init,
                dim1809JoeKuoD6Init,
                dim1810JoeKuoD6Init,
                dim1811JoeKuoD6Init,
                dim1812JoeKuoD6Init,
                dim1813JoeKuoD6Init,
                dim1814JoeKuoD6Init,
                dim1815JoeKuoD6Init,
                dim1816JoeKuoD6Init,
                dim1817JoeKuoD6Init,
                dim1818JoeKuoD6Init,
                dim1819JoeKuoD6Init,
                dim1820JoeKuoD6Init,
                dim1821JoeKuoD6Init,
                dim1822JoeKuoD6Init,
                dim1823JoeKuoD6Init,
                dim1824JoeKuoD6Init,
                dim1825JoeKuoD6Init,
                dim1826JoeKuoD6Init,
                dim1827JoeKuoD6Init,
                dim1828JoeKuoD6Init,
                dim1829JoeKuoD6Init,
                dim1830JoeKuoD6Init,
                dim1831JoeKuoD6Init,
                dim1832JoeKuoD6Init,
                dim1833JoeKuoD6Init,
                dim1834JoeKuoD6Init,
                dim1835JoeKuoD6Init,
                dim1836JoeKuoD6Init,
                dim1837JoeKuoD6Init,
                dim1838JoeKuoD6Init,
                dim1839JoeKuoD6Init,
                dim1840JoeKuoD6Init,
                dim1841JoeKuoD6Init,
                dim1842JoeKuoD6Init,
                dim1843JoeKuoD6Init,
                dim1844JoeKuoD6Init,
                dim1845JoeKuoD6Init,
                dim1846JoeKuoD6Init,
                dim1847JoeKuoD6Init,
                dim1848JoeKuoD6Init,
                dim1849JoeKuoD6Init,
                dim1850JoeKuoD6Init,
                dim1851JoeKuoD6Init,
                dim1852JoeKuoD6Init,
                dim1853JoeKuoD6Init,
                dim1854JoeKuoD6Init,
                dim1855JoeKuoD6Init,
                dim1856JoeKuoD6Init,
                dim1857JoeKuoD6Init,
                dim1858JoeKuoD6Init,
                dim1859JoeKuoD6Init,
                dim1860JoeKuoD6Init,
                dim1861JoeKuoD6Init,
                dim1862JoeKuoD6Init,
                dim1863JoeKuoD6Init,
                dim1864JoeKuoD6Init,
                dim1865JoeKuoD6Init,
                dim1866JoeKuoD6Init,
                dim1867JoeKuoD6Init,
                dim1868JoeKuoD6Init,
                dim1869JoeKuoD6Init,
                dim1870JoeKuoD6Init,
                dim1871JoeKuoD6Init,
                dim1872JoeKuoD6Init,
                dim1873JoeKuoD6Init,
                dim1874JoeKuoD6Init,
                dim1875JoeKuoD6Init,
                dim1876JoeKuoD6Init,
                dim1877JoeKuoD6Init,
                dim1878JoeKuoD6Init,
                dim1879JoeKuoD6Init,
                dim1880JoeKuoD6Init,
                dim1881JoeKuoD6Init,
                dim1882JoeKuoD6Init,
                dim1883JoeKuoD6Init,
                dim1884JoeKuoD6Init,
                dim1885JoeKuoD6Init,
                dim1886JoeKuoD6Init,
                dim1887JoeKuoD6Init,
                dim1888JoeKuoD6Init,
                dim1889JoeKuoD6Init,
                dim1890JoeKuoD6Init,
                dim1891JoeKuoD6Init,
                dim1892JoeKuoD6Init,
                dim1893JoeKuoD6Init,
                dim1894JoeKuoD6Init,
                dim1895JoeKuoD6Init,
                dim1896JoeKuoD6Init,
                dim1897JoeKuoD6Init,
                dim1898JoeKuoD6Init,
                dim1899JoeKuoD6Init,
                dim1900JoeKuoD6Init,
                dim1901JoeKuoD6Init,
                dim1902JoeKuoD6Init,
                dim1903JoeKuoD6Init,
                dim1904JoeKuoD6Init,
                dim1905JoeKuoD6Init,
                dim1906JoeKuoD6Init,
                dim1907JoeKuoD6Init,
                dim1908JoeKuoD6Init,
                dim1909JoeKuoD6Init,
                dim1910JoeKuoD6Init,
                dim1911JoeKuoD6Init,
                dim1912JoeKuoD6Init,
                dim1913JoeKuoD6Init,
                dim1914JoeKuoD6Init,
                dim1915JoeKuoD6Init,
                dim1916JoeKuoD6Init,
                dim1917JoeKuoD6Init,
                dim1918JoeKuoD6Init,
                dim1919JoeKuoD6Init,
                dim1920JoeKuoD6Init,
                dim1921JoeKuoD6Init,
                dim1922JoeKuoD6Init,
                dim1923JoeKuoD6Init,
                dim1924JoeKuoD6Init,
                dim1925JoeKuoD6Init,
                dim1926JoeKuoD6Init,
                dim1927JoeKuoD6Init,
                dim1928JoeKuoD6Init,
                dim1929JoeKuoD6Init,
                dim1930JoeKuoD6Init,
                dim1931JoeKuoD6Init,
                dim1932JoeKuoD6Init,
                dim1933JoeKuoD6Init,
                dim1934JoeKuoD6Init,
                dim1935JoeKuoD6Init,
                dim1936JoeKuoD6Init,
                dim1937JoeKuoD6Init,
                dim1938JoeKuoD6Init,
                dim1939JoeKuoD6Init,
                dim1940JoeKuoD6Init,
                dim1941JoeKuoD6Init,
                dim1942JoeKuoD6Init,
                dim1943JoeKuoD6Init,
                dim1944JoeKuoD6Init,
                dim1945JoeKuoD6Init,
                dim1946JoeKuoD6Init,
                dim1947JoeKuoD6Init,
                dim1948JoeKuoD6Init,
                dim1949JoeKuoD6Init,
                dim1950JoeKuoD6Init,
                dim1951JoeKuoD6Init,
                dim1952JoeKuoD6Init,
                dim1953JoeKuoD6Init,
                dim1954JoeKuoD6Init,
                dim1955JoeKuoD6Init,
                dim1956JoeKuoD6Init,
                dim1957JoeKuoD6Init,
                dim1958JoeKuoD6Init,
                dim1959JoeKuoD6Init,
                dim1960JoeKuoD6Init,
                dim1961JoeKuoD6Init,
                dim1962JoeKuoD6Init,
                dim1963JoeKuoD6Init,
                dim1964JoeKuoD6Init,
                dim1965JoeKuoD6Init,
                dim1966JoeKuoD6Init,
                dim1967JoeKuoD6Init,
                dim1968JoeKuoD6Init,
                dim1969JoeKuoD6Init,
                dim1970JoeKuoD6Init,
                dim1971JoeKuoD6Init,
                dim1972JoeKuoD6Init,
                dim1973JoeKuoD6Init,
                dim1974JoeKuoD6Init,
                dim1975JoeKuoD6Init,
                dim1976JoeKuoD6Init,
                dim1977JoeKuoD6Init,
                dim1978JoeKuoD6Init,
                dim1979JoeKuoD6Init,
                dim1980JoeKuoD6Init,
                dim1981JoeKuoD6Init,
                dim1982JoeKuoD6Init,
                dim1983JoeKuoD6Init,
                dim1984JoeKuoD6Init,
                dim1985JoeKuoD6Init,
                dim1986JoeKuoD6Init,
                dim1987JoeKuoD6Init,
                dim1988JoeKuoD6Init,
                dim1989JoeKuoD6Init,
                dim1990JoeKuoD6Init,
                dim1991JoeKuoD6Init,
                dim1992JoeKuoD6Init,
                dim1993JoeKuoD6Init,
                dim1994JoeKuoD6Init,
                dim1995JoeKuoD6Init,
                dim1996JoeKuoD6Init,
                dim1997JoeKuoD6Init,
                dim1998JoeKuoD6Init,
                dim1999JoeKuoD6Init,
                dim2000JoeKuoD6Init,
                dim2001JoeKuoD6Init,
                dim2002JoeKuoD6Init,
                dim2003JoeKuoD6Init,
                dim2004JoeKuoD6Init,
                dim2005JoeKuoD6Init,
                dim2006JoeKuoD6Init,
                dim2007JoeKuoD6Init,
                dim2008JoeKuoD6Init,
                dim2009JoeKuoD6Init,
                dim2010JoeKuoD6Init,
                dim2011JoeKuoD6Init,
                dim2012JoeKuoD6Init,
                dim2013JoeKuoD6Init,
                dim2014JoeKuoD6Init,
                dim2015JoeKuoD6Init,
                dim2016JoeKuoD6Init,
                dim2017JoeKuoD6Init,
                dim2018JoeKuoD6Init,
                dim2019JoeKuoD6Init,
                dim2020JoeKuoD6Init,
                dim2021JoeKuoD6Init,
                dim2022JoeKuoD6Init,
                dim2023JoeKuoD6Init,
                dim2024JoeKuoD6Init,
                dim2025JoeKuoD6Init,
                dim2026JoeKuoD6Init,
                dim2027JoeKuoD6Init,
                dim2028JoeKuoD6Init,
                dim2029JoeKuoD6Init,
                dim2030JoeKuoD6Init,
                dim2031JoeKuoD6Init,
                dim2032JoeKuoD6Init,
                dim2033JoeKuoD6Init,
                dim2034JoeKuoD6Init,
                dim2035JoeKuoD6Init,
                dim2036JoeKuoD6Init,
                dim2037JoeKuoD6Init,
                dim2038JoeKuoD6Init,
                dim2039JoeKuoD6Init,
                dim2040JoeKuoD6Init,
                dim2041JoeKuoD6Init,
                dim2042JoeKuoD6Init,
                dim2043JoeKuoD6Init,
                dim2044JoeKuoD6Init,
                dim2045JoeKuoD6Init,
                dim2046JoeKuoD6Init,
                dim2047JoeKuoD6Init,
                dim2048JoeKuoD6Init,
                dim2049JoeKuoD6Init,
                dim2050JoeKuoD6Init,
                dim2051JoeKuoD6Init,
                dim2052JoeKuoD6Init,
                dim2053JoeKuoD6Init,
                dim2054JoeKuoD6Init,
                dim2055JoeKuoD6Init,
                dim2056JoeKuoD6Init,
                dim2057JoeKuoD6Init,
                dim2058JoeKuoD6Init,
                dim2059JoeKuoD6Init,
                dim2060JoeKuoD6Init,
                dim2061JoeKuoD6Init,
                dim2062JoeKuoD6Init,
                dim2063JoeKuoD6Init,
                dim2064JoeKuoD6Init,
                dim2065JoeKuoD6Init,
                dim2066JoeKuoD6Init,
                dim2067JoeKuoD6Init,
                dim2068JoeKuoD6Init,
                dim2069JoeKuoD6Init,
                dim2070JoeKuoD6Init,
                dim2071JoeKuoD6Init,
                dim2072JoeKuoD6Init,
                dim2073JoeKuoD6Init,
                dim2074JoeKuoD6Init,
                dim2075JoeKuoD6Init,
                dim2076JoeKuoD6Init,
                dim2077JoeKuoD6Init,
                dim2078JoeKuoD6Init,
                dim2079JoeKuoD6Init,
                dim2080JoeKuoD6Init,
                dim2081JoeKuoD6Init,
                dim2082JoeKuoD6Init,
                dim2083JoeKuoD6Init,
                dim2084JoeKuoD6Init,
                dim2085JoeKuoD6Init,
                dim2086JoeKuoD6Init,
                dim2087JoeKuoD6Init,
                dim2088JoeKuoD6Init,
                dim2089JoeKuoD6Init,
                dim2090JoeKuoD6Init,
                dim2091JoeKuoD6Init,
                dim2092JoeKuoD6Init,
                dim2093JoeKuoD6Init,
                dim2094JoeKuoD6Init,
                dim2095JoeKuoD6Init,
                dim2096JoeKuoD6Init,
                dim2097JoeKuoD6Init,
                dim2098JoeKuoD6Init,
                dim2099JoeKuoD6Init,
                dim2100JoeKuoD6Init,
                dim2101JoeKuoD6Init,
                dim2102JoeKuoD6Init,
                dim2103JoeKuoD6Init,
                dim2104JoeKuoD6Init,
                dim2105JoeKuoD6Init,
                dim2106JoeKuoD6Init,
                dim2107JoeKuoD6Init,
                dim2108JoeKuoD6Init,
                dim2109JoeKuoD6Init,
                dim2110JoeKuoD6Init,
                dim2111JoeKuoD6Init,
                dim2112JoeKuoD6Init,
                dim2113JoeKuoD6Init,
                dim2114JoeKuoD6Init,
                dim2115JoeKuoD6Init,
                dim2116JoeKuoD6Init,
                dim2117JoeKuoD6Init,
                dim2118JoeKuoD6Init,
                dim2119JoeKuoD6Init,
                dim2120JoeKuoD6Init,
                dim2121JoeKuoD6Init,
                dim2122JoeKuoD6Init,
                dim2123JoeKuoD6Init,
                dim2124JoeKuoD6Init,
                dim2125JoeKuoD6Init,
                dim2126JoeKuoD6Init,
                dim2127JoeKuoD6Init,
                dim2128JoeKuoD6Init,
                dim2129JoeKuoD6Init,
                dim2130JoeKuoD6Init,
                dim2131JoeKuoD6Init,
                dim2132JoeKuoD6Init,
                dim2133JoeKuoD6Init,
                dim2134JoeKuoD6Init,
                dim2135JoeKuoD6Init,
                dim2136JoeKuoD6Init,
                dim2137JoeKuoD6Init,
                dim2138JoeKuoD6Init,
                dim2139JoeKuoD6Init,
                dim2140JoeKuoD6Init,
                dim2141JoeKuoD6Init,
                dim2142JoeKuoD6Init,
                dim2143JoeKuoD6Init,
                dim2144JoeKuoD6Init,
                dim2145JoeKuoD6Init,
                dim2146JoeKuoD6Init,
                dim2147JoeKuoD6Init,
                dim2148JoeKuoD6Init,
                dim2149JoeKuoD6Init,
                dim2150JoeKuoD6Init,
                dim2151JoeKuoD6Init,
                dim2152JoeKuoD6Init,
                dim2153JoeKuoD6Init,
                dim2154JoeKuoD6Init,
                dim2155JoeKuoD6Init,
                dim2156JoeKuoD6Init,
                dim2157JoeKuoD6Init,
                dim2158JoeKuoD6Init,
                dim2159JoeKuoD6Init,
                dim2160JoeKuoD6Init,
                dim2161JoeKuoD6Init,
                dim2162JoeKuoD6Init,
                dim2163JoeKuoD6Init,
                dim2164JoeKuoD6Init,
                dim2165JoeKuoD6Init,
                dim2166JoeKuoD6Init,
                dim2167JoeKuoD6Init,
                dim2168JoeKuoD6Init,
                dim2169JoeKuoD6Init,
                dim2170JoeKuoD6Init,
                dim2171JoeKuoD6Init,
                dim2172JoeKuoD6Init,
                dim2173JoeKuoD6Init,
                dim2174JoeKuoD6Init,
                dim2175JoeKuoD6Init,
                dim2176JoeKuoD6Init,
                dim2177JoeKuoD6Init,
                dim2178JoeKuoD6Init,
                dim2179JoeKuoD6Init,
                dim2180JoeKuoD6Init,
                dim2181JoeKuoD6Init,
                dim2182JoeKuoD6Init,
                dim2183JoeKuoD6Init,
                dim2184JoeKuoD6Init,
                dim2185JoeKuoD6Init,
                dim2186JoeKuoD6Init,
                dim2187JoeKuoD6Init,
                dim2188JoeKuoD6Init,
                dim2189JoeKuoD6Init,
                dim2190JoeKuoD6Init,
                dim2191JoeKuoD6Init,
                dim2192JoeKuoD6Init,
                dim2193JoeKuoD6Init,
                dim2194JoeKuoD6Init,
                dim2195JoeKuoD6Init,
                dim2196JoeKuoD6Init,
                dim2197JoeKuoD6Init,
                dim2198JoeKuoD6Init,
                dim2199JoeKuoD6Init,
                dim2200JoeKuoD6Init,
                dim2201JoeKuoD6Init,
                dim2202JoeKuoD6Init,
                dim2203JoeKuoD6Init,
                dim2204JoeKuoD6Init,
                dim2205JoeKuoD6Init,
                dim2206JoeKuoD6Init,
                dim2207JoeKuoD6Init,
                dim2208JoeKuoD6Init,
                dim2209JoeKuoD6Init,
                dim2210JoeKuoD6Init,
                dim2211JoeKuoD6Init,
                dim2212JoeKuoD6Init,
                dim2213JoeKuoD6Init,
                dim2214JoeKuoD6Init,
                dim2215JoeKuoD6Init,
                dim2216JoeKuoD6Init,
                dim2217JoeKuoD6Init,
                dim2218JoeKuoD6Init,
                dim2219JoeKuoD6Init,
                dim2220JoeKuoD6Init,
                dim2221JoeKuoD6Init,
                dim2222JoeKuoD6Init,
                dim2223JoeKuoD6Init,
                dim2224JoeKuoD6Init,
                dim2225JoeKuoD6Init,
                dim2226JoeKuoD6Init,
                dim2227JoeKuoD6Init,
                dim2228JoeKuoD6Init,
                dim2229JoeKuoD6Init,
                dim2230JoeKuoD6Init,
                dim2231JoeKuoD6Init,
                dim2232JoeKuoD6Init,
                dim2233JoeKuoD6Init,
                dim2234JoeKuoD6Init,
                dim2235JoeKuoD6Init,
                dim2236JoeKuoD6Init,
                dim2237JoeKuoD6Init,
                dim2238JoeKuoD6Init,
                dim2239JoeKuoD6Init,
                dim2240JoeKuoD6Init,
                dim2241JoeKuoD6Init,
                dim2242JoeKuoD6Init,
                dim2243JoeKuoD6Init,
                dim2244JoeKuoD6Init,
                dim2245JoeKuoD6Init,
                dim2246JoeKuoD6Init,
                dim2247JoeKuoD6Init,
                dim2248JoeKuoD6Init,
                dim2249JoeKuoD6Init,
                dim2250JoeKuoD6Init,
                dim2251JoeKuoD6Init,
                dim2252JoeKuoD6Init,
                dim2253JoeKuoD6Init,
                dim2254JoeKuoD6Init,
                dim2255JoeKuoD6Init,
                dim2256JoeKuoD6Init,
                dim2257JoeKuoD6Init,
                dim2258JoeKuoD6Init,
                dim2259JoeKuoD6Init,
                dim2260JoeKuoD6Init,
                dim2261JoeKuoD6Init,
                dim2262JoeKuoD6Init,
                dim2263JoeKuoD6Init,
                dim2264JoeKuoD6Init,
                dim2265JoeKuoD6Init,
                dim2266JoeKuoD6Init,
                dim2267JoeKuoD6Init,
                dim2268JoeKuoD6Init,
                dim2269JoeKuoD6Init,
                dim2270JoeKuoD6Init,
                dim2271JoeKuoD6Init,
                dim2272JoeKuoD6Init,
                dim2273JoeKuoD6Init,
                dim2274JoeKuoD6Init,
                dim2275JoeKuoD6Init,
                dim2276JoeKuoD6Init,
                dim2277JoeKuoD6Init,
                dim2278JoeKuoD6Init,
                dim2279JoeKuoD6Init,
                dim2280JoeKuoD6Init,
                dim2281JoeKuoD6Init,
                dim2282JoeKuoD6Init,
                dim2283JoeKuoD6Init,
                dim2284JoeKuoD6Init,
                dim2285JoeKuoD6Init,
                dim2286JoeKuoD6Init,
                dim2287JoeKuoD6Init,
                dim2288JoeKuoD6Init,
                dim2289JoeKuoD6Init,
                dim2290JoeKuoD6Init,
                dim2291JoeKuoD6Init,
                dim2292JoeKuoD6Init,
                dim2293JoeKuoD6Init,
                dim2294JoeKuoD6Init,
                dim2295JoeKuoD6Init,
                dim2296JoeKuoD6Init,
                dim2297JoeKuoD6Init,
                dim2298JoeKuoD6Init,
                dim2299JoeKuoD6Init,
                dim2300JoeKuoD6Init,
                dim2301JoeKuoD6Init,
                dim2302JoeKuoD6Init,
                dim2303JoeKuoD6Init,
                dim2304JoeKuoD6Init,
                dim2305JoeKuoD6Init,
                dim2306JoeKuoD6Init,
                dim2307JoeKuoD6Init,
                dim2308JoeKuoD6Init,
                dim2309JoeKuoD6Init,
                dim2310JoeKuoD6Init,
                dim2311JoeKuoD6Init,
                dim2312JoeKuoD6Init,
                dim2313JoeKuoD6Init,
                dim2314JoeKuoD6Init,
                dim2315JoeKuoD6Init,
                dim2316JoeKuoD6Init,
                dim2317JoeKuoD6Init,
                dim2318JoeKuoD6Init,
                dim2319JoeKuoD6Init,
                dim2320JoeKuoD6Init,
                dim2321JoeKuoD6Init,
                dim2322JoeKuoD6Init,
                dim2323JoeKuoD6Init,
                dim2324JoeKuoD6Init,
                dim2325JoeKuoD6Init,
                dim2326JoeKuoD6Init,
                dim2327JoeKuoD6Init,
                dim2328JoeKuoD6Init,
                dim2329JoeKuoD6Init,
                dim2330JoeKuoD6Init,
                dim2331JoeKuoD6Init,
                dim2332JoeKuoD6Init,
                dim2333JoeKuoD6Init,
                dim2334JoeKuoD6Init,
                dim2335JoeKuoD6Init,
                dim2336JoeKuoD6Init,
                dim2337JoeKuoD6Init,
                dim2338JoeKuoD6Init,
                dim2339JoeKuoD6Init,
                dim2340JoeKuoD6Init,
                dim2341JoeKuoD6Init,
                dim2342JoeKuoD6Init,
                dim2343JoeKuoD6Init,
                dim2344JoeKuoD6Init,
                dim2345JoeKuoD6Init,
                dim2346JoeKuoD6Init,
                dim2347JoeKuoD6Init,
                dim2348JoeKuoD6Init,
                dim2349JoeKuoD6Init,
                dim2350JoeKuoD6Init,
                dim2351JoeKuoD6Init,
                dim2352JoeKuoD6Init,
                dim2353JoeKuoD6Init,
                dim2354JoeKuoD6Init,
                dim2355JoeKuoD6Init,
                dim2356JoeKuoD6Init,
                dim2357JoeKuoD6Init,
                dim2358JoeKuoD6Init,
                dim2359JoeKuoD6Init,
                dim2360JoeKuoD6Init,
                dim2361JoeKuoD6Init,
                dim2362JoeKuoD6Init,
                dim2363JoeKuoD6Init,
                dim2364JoeKuoD6Init,
                dim2365JoeKuoD6Init,
                dim2366JoeKuoD6Init,
                dim2367JoeKuoD6Init,
                dim2368JoeKuoD6Init,
                dim2369JoeKuoD6Init,
                dim2370JoeKuoD6Init,
                dim2371JoeKuoD6Init,
                dim2372JoeKuoD6Init,
                dim2373JoeKuoD6Init,
                dim2374JoeKuoD6Init,
                dim2375JoeKuoD6Init,
                dim2376JoeKuoD6Init,
                dim2377JoeKuoD6Init,
                dim2378JoeKuoD6Init,
                dim2379JoeKuoD6Init,
                dim2380JoeKuoD6Init,
                dim2381JoeKuoD6Init,
                dim2382JoeKuoD6Init,
                dim2383JoeKuoD6Init,
                dim2384JoeKuoD6Init,
                dim2385JoeKuoD6Init,
                dim2386JoeKuoD6Init,
                dim2387JoeKuoD6Init,
                dim2388JoeKuoD6Init,
                dim2389JoeKuoD6Init,
                dim2390JoeKuoD6Init,
                dim2391JoeKuoD6Init,
                dim2392JoeKuoD6Init,
                dim2393JoeKuoD6Init,
                dim2394JoeKuoD6Init,
                dim2395JoeKuoD6Init,
                dim2396JoeKuoD6Init,
                dim2397JoeKuoD6Init,
                dim2398JoeKuoD6Init,
                dim2399JoeKuoD6Init,
                dim2400JoeKuoD6Init,
                dim2401JoeKuoD6Init,
                dim2402JoeKuoD6Init,
                dim2403JoeKuoD6Init,
                dim2404JoeKuoD6Init,
                dim2405JoeKuoD6Init,
                dim2406JoeKuoD6Init,
                dim2407JoeKuoD6Init,
                dim2408JoeKuoD6Init,
                dim2409JoeKuoD6Init,
                dim2410JoeKuoD6Init,
                dim2411JoeKuoD6Init,
                dim2412JoeKuoD6Init,
                dim2413JoeKuoD6Init,
                dim2414JoeKuoD6Init,
                dim2415JoeKuoD6Init,
                dim2416JoeKuoD6Init,
                dim2417JoeKuoD6Init,
                dim2418JoeKuoD6Init,
                dim2419JoeKuoD6Init,
                dim2420JoeKuoD6Init,
                dim2421JoeKuoD6Init,
                dim2422JoeKuoD6Init,
                dim2423JoeKuoD6Init,
                dim2424JoeKuoD6Init,
                dim2425JoeKuoD6Init,
                dim2426JoeKuoD6Init,
                dim2427JoeKuoD6Init,
                dim2428JoeKuoD6Init,
                dim2429JoeKuoD6Init,
                dim2430JoeKuoD6Init,
                dim2431JoeKuoD6Init,
                dim2432JoeKuoD6Init,
                dim2433JoeKuoD6Init,
                dim2434JoeKuoD6Init,
                dim2435JoeKuoD6Init,
                dim2436JoeKuoD6Init,
                dim2437JoeKuoD6Init,
                dim2438JoeKuoD6Init,
                dim2439JoeKuoD6Init,
                dim2440JoeKuoD6Init,
                dim2441JoeKuoD6Init,
                dim2442JoeKuoD6Init,
                dim2443JoeKuoD6Init,
                dim2444JoeKuoD6Init,
                dim2445JoeKuoD6Init,
                dim2446JoeKuoD6Init,
                dim2447JoeKuoD6Init,
                dim2448JoeKuoD6Init,
                dim2449JoeKuoD6Init,
                dim2450JoeKuoD6Init,
                dim2451JoeKuoD6Init,
                dim2452JoeKuoD6Init,
                dim2453JoeKuoD6Init,
                dim2454JoeKuoD6Init,
                dim2455JoeKuoD6Init,
                dim2456JoeKuoD6Init,
                dim2457JoeKuoD6Init,
                dim2458JoeKuoD6Init,
                dim2459JoeKuoD6Init,
                dim2460JoeKuoD6Init,
                dim2461JoeKuoD6Init,
                dim2462JoeKuoD6Init,
                dim2463JoeKuoD6Init,
                dim2464JoeKuoD6Init,
                dim2465JoeKuoD6Init,
                dim2466JoeKuoD6Init,
                dim2467JoeKuoD6Init,
                dim2468JoeKuoD6Init,
                dim2469JoeKuoD6Init,
                dim2470JoeKuoD6Init,
                dim2471JoeKuoD6Init,
                dim2472JoeKuoD6Init,
                dim2473JoeKuoD6Init,
                dim2474JoeKuoD6Init,
                dim2475JoeKuoD6Init,
                dim2476JoeKuoD6Init,
                dim2477JoeKuoD6Init,
                dim2478JoeKuoD6Init,
                dim2479JoeKuoD6Init,
                dim2480JoeKuoD6Init,
                dim2481JoeKuoD6Init,
                dim2482JoeKuoD6Init,
                dim2483JoeKuoD6Init,
                dim2484JoeKuoD6Init,
                dim2485JoeKuoD6Init,
                dim2486JoeKuoD6Init,
                dim2487JoeKuoD6Init,
                dim2488JoeKuoD6Init,
                dim2489JoeKuoD6Init,
                dim2490JoeKuoD6Init,
                dim2491JoeKuoD6Init,
                dim2492JoeKuoD6Init,
                dim2493JoeKuoD6Init,
                dim2494JoeKuoD6Init,
                dim2495JoeKuoD6Init,
                dim2496JoeKuoD6Init,
                dim2497JoeKuoD6Init,
                dim2498JoeKuoD6Init,
                dim2499JoeKuoD6Init,
                dim2500JoeKuoD6Init,
                dim2501JoeKuoD6Init,
                dim2502JoeKuoD6Init,
                dim2503JoeKuoD6Init,
                dim2504JoeKuoD6Init,
                dim2505JoeKuoD6Init,
                dim2506JoeKuoD6Init,
                dim2507JoeKuoD6Init,
                dim2508JoeKuoD6Init,
                dim2509JoeKuoD6Init,
                dim2510JoeKuoD6Init,
                dim2511JoeKuoD6Init,
                dim2512JoeKuoD6Init,
                dim2513JoeKuoD6Init,
                dim2514JoeKuoD6Init,
                dim2515JoeKuoD6Init,
                dim2516JoeKuoD6Init,
                dim2517JoeKuoD6Init,
                dim2518JoeKuoD6Init,
                dim2519JoeKuoD6Init,
                dim2520JoeKuoD6Init,
                dim2521JoeKuoD6Init,
                dim2522JoeKuoD6Init,
                dim2523JoeKuoD6Init,
                dim2524JoeKuoD6Init,
                dim2525JoeKuoD6Init,
                dim2526JoeKuoD6Init,
                dim2527JoeKuoD6Init,
                dim2528JoeKuoD6Init,
                dim2529JoeKuoD6Init,
                dim2530JoeKuoD6Init,
                dim2531JoeKuoD6Init,
                dim2532JoeKuoD6Init,
                dim2533JoeKuoD6Init,
                dim2534JoeKuoD6Init,
                dim2535JoeKuoD6Init,
                dim2536JoeKuoD6Init,
                dim2537JoeKuoD6Init,
                dim2538JoeKuoD6Init,
                dim2539JoeKuoD6Init,
                dim2540JoeKuoD6Init,
                dim2541JoeKuoD6Init,
                dim2542JoeKuoD6Init,
                dim2543JoeKuoD6Init,
                dim2544JoeKuoD6Init,
                dim2545JoeKuoD6Init,
                dim2546JoeKuoD6Init,
                dim2547JoeKuoD6Init,
                dim2548JoeKuoD6Init,
                dim2549JoeKuoD6Init,
                dim2550JoeKuoD6Init,
                dim2551JoeKuoD6Init,
                dim2552JoeKuoD6Init,
                dim2553JoeKuoD6Init,
                dim2554JoeKuoD6Init,
                dim2555JoeKuoD6Init,
                dim2556JoeKuoD6Init,
                dim2557JoeKuoD6Init,
                dim2558JoeKuoD6Init,
                dim2559JoeKuoD6Init,
                dim2560JoeKuoD6Init,
                dim2561JoeKuoD6Init,
                dim2562JoeKuoD6Init,
                dim2563JoeKuoD6Init,
                dim2564JoeKuoD6Init,
                dim2565JoeKuoD6Init,
                dim2566JoeKuoD6Init,
                dim2567JoeKuoD6Init,
                dim2568JoeKuoD6Init,
                dim2569JoeKuoD6Init,
                dim2570JoeKuoD6Init,
                dim2571JoeKuoD6Init,
                dim2572JoeKuoD6Init,
                dim2573JoeKuoD6Init,
                dim2574JoeKuoD6Init,
                dim2575JoeKuoD6Init,
                dim2576JoeKuoD6Init,
                dim2577JoeKuoD6Init,
                dim2578JoeKuoD6Init,
                dim2579JoeKuoD6Init,
                dim2580JoeKuoD6Init,
                dim2581JoeKuoD6Init,
                dim2582JoeKuoD6Init,
                dim2583JoeKuoD6Init,
                dim2584JoeKuoD6Init,
                dim2585JoeKuoD6Init,
                dim2586JoeKuoD6Init,
                dim2587JoeKuoD6Init,
                dim2588JoeKuoD6Init,
                dim2589JoeKuoD6Init,
                dim2590JoeKuoD6Init,
                dim2591JoeKuoD6Init,
                dim2592JoeKuoD6Init,
                dim2593JoeKuoD6Init,
                dim2594JoeKuoD6Init,
                dim2595JoeKuoD6Init,
                dim2596JoeKuoD6Init,
                dim2597JoeKuoD6Init,
                dim2598JoeKuoD6Init,
                dim2599JoeKuoD6Init,
                dim2600JoeKuoD6Init,
                dim2601JoeKuoD6Init,
                dim2602JoeKuoD6Init,
                dim2603JoeKuoD6Init,
                dim2604JoeKuoD6Init,
                dim2605JoeKuoD6Init,
                dim2606JoeKuoD6Init,
                dim2607JoeKuoD6Init,
                dim2608JoeKuoD6Init,
                dim2609JoeKuoD6Init,
                dim2610JoeKuoD6Init,
                dim2611JoeKuoD6Init,
                dim2612JoeKuoD6Init,
                dim2613JoeKuoD6Init,
                dim2614JoeKuoD6Init,
                dim2615JoeKuoD6Init,
                dim2616JoeKuoD6Init,
                dim2617JoeKuoD6Init,
                dim2618JoeKuoD6Init,
                dim2619JoeKuoD6Init,
                dim2620JoeKuoD6Init,
                dim2621JoeKuoD6Init,
                dim2622JoeKuoD6Init,
                dim2623JoeKuoD6Init,
                dim2624JoeKuoD6Init,
                dim2625JoeKuoD6Init,
                dim2626JoeKuoD6Init,
                dim2627JoeKuoD6Init,
                dim2628JoeKuoD6Init,
                dim2629JoeKuoD6Init,
                dim2630JoeKuoD6Init,
                dim2631JoeKuoD6Init,
                dim2632JoeKuoD6Init,
                dim2633JoeKuoD6Init,
                dim2634JoeKuoD6Init,
                dim2635JoeKuoD6Init,
                dim2636JoeKuoD6Init,
                dim2637JoeKuoD6Init,
                dim2638JoeKuoD6Init,
                dim2639JoeKuoD6Init,
                dim2640JoeKuoD6Init,
                dim2641JoeKuoD6Init,
                dim2642JoeKuoD6Init,
                dim2643JoeKuoD6Init,
                dim2644JoeKuoD6Init,
                dim2645JoeKuoD6Init,
                dim2646JoeKuoD6Init,
                dim2647JoeKuoD6Init,
                dim2648JoeKuoD6Init,
                dim2649JoeKuoD6Init,
                dim2650JoeKuoD6Init,
                dim2651JoeKuoD6Init,
                dim2652JoeKuoD6Init,
                dim2653JoeKuoD6Init,
                dim2654JoeKuoD6Init,
                dim2655JoeKuoD6Init,
                dim2656JoeKuoD6Init,
                dim2657JoeKuoD6Init,
                dim2658JoeKuoD6Init,
                dim2659JoeKuoD6Init,
                dim2660JoeKuoD6Init,
                dim2661JoeKuoD6Init,
                dim2662JoeKuoD6Init,
                dim2663JoeKuoD6Init,
                dim2664JoeKuoD6Init,
                dim2665JoeKuoD6Init,
                dim2666JoeKuoD6Init,
                dim2667JoeKuoD6Init,
                dim2668JoeKuoD6Init,
                dim2669JoeKuoD6Init,
                dim2670JoeKuoD6Init,
                dim2671JoeKuoD6Init,
                dim2672JoeKuoD6Init,
                dim2673JoeKuoD6Init,
                dim2674JoeKuoD6Init,
                dim2675JoeKuoD6Init,
                dim2676JoeKuoD6Init,
                dim2677JoeKuoD6Init,
                dim2678JoeKuoD6Init,
                dim2679JoeKuoD6Init,
                dim2680JoeKuoD6Init,
                dim2681JoeKuoD6Init,
                dim2682JoeKuoD6Init,
                dim2683JoeKuoD6Init,
                dim2684JoeKuoD6Init,
                dim2685JoeKuoD6Init,
                dim2686JoeKuoD6Init,
                dim2687JoeKuoD6Init,
                dim2688JoeKuoD6Init,
                dim2689JoeKuoD6Init,
                dim2690JoeKuoD6Init,
                dim2691JoeKuoD6Init,
                dim2692JoeKuoD6Init,
                dim2693JoeKuoD6Init,
                dim2694JoeKuoD6Init,
                dim2695JoeKuoD6Init,
                dim2696JoeKuoD6Init,
                dim2697JoeKuoD6Init,
                dim2698JoeKuoD6Init,
                dim2699JoeKuoD6Init,
                dim2700JoeKuoD6Init,
                dim2701JoeKuoD6Init,
                dim2702JoeKuoD6Init,
                dim2703JoeKuoD6Init,
                dim2704JoeKuoD6Init,
                dim2705JoeKuoD6Init,
                dim2706JoeKuoD6Init,
                dim2707JoeKuoD6Init,
                dim2708JoeKuoD6Init,
                dim2709JoeKuoD6Init,
                dim2710JoeKuoD6Init,
                dim2711JoeKuoD6Init,
                dim2712JoeKuoD6Init,
                dim2713JoeKuoD6Init,
                dim2714JoeKuoD6Init,
                dim2715JoeKuoD6Init,
                dim2716JoeKuoD6Init,
                dim2717JoeKuoD6Init,
                dim2718JoeKuoD6Init,
                dim2719JoeKuoD6Init,
                dim2720JoeKuoD6Init,
                dim2721JoeKuoD6Init,
                dim2722JoeKuoD6Init,
                dim2723JoeKuoD6Init,
                dim2724JoeKuoD6Init,
                dim2725JoeKuoD6Init,
                dim2726JoeKuoD6Init,
                dim2727JoeKuoD6Init,
                dim2728JoeKuoD6Init,
                dim2729JoeKuoD6Init,
                dim2730JoeKuoD6Init,
                dim2731JoeKuoD6Init,
                dim2732JoeKuoD6Init,
                dim2733JoeKuoD6Init,
                dim2734JoeKuoD6Init,
                dim2735JoeKuoD6Init,
                dim2736JoeKuoD6Init,
                dim2737JoeKuoD6Init,
                dim2738JoeKuoD6Init,
                dim2739JoeKuoD6Init,
                dim2740JoeKuoD6Init,
                dim2741JoeKuoD6Init,
                dim2742JoeKuoD6Init,
                dim2743JoeKuoD6Init,
                dim2744JoeKuoD6Init,
                dim2745JoeKuoD6Init,
                dim2746JoeKuoD6Init,
                dim2747JoeKuoD6Init,
                dim2748JoeKuoD6Init,
                dim2749JoeKuoD6Init,
                dim2750JoeKuoD6Init,
                dim2751JoeKuoD6Init,
                dim2752JoeKuoD6Init,
                dim2753JoeKuoD6Init,
                dim2754JoeKuoD6Init,
                dim2755JoeKuoD6Init,
                dim2756JoeKuoD6Init,
                dim2757JoeKuoD6Init,
                dim2758JoeKuoD6Init,
                dim2759JoeKuoD6Init,
                dim2760JoeKuoD6Init,
                dim2761JoeKuoD6Init,
                dim2762JoeKuoD6Init,
                dim2763JoeKuoD6Init,
                dim2764JoeKuoD6Init,
                dim2765JoeKuoD6Init,
                dim2766JoeKuoD6Init,
                dim2767JoeKuoD6Init,
                dim2768JoeKuoD6Init,
                dim2769JoeKuoD6Init,
                dim2770JoeKuoD6Init,
                dim2771JoeKuoD6Init,
                dim2772JoeKuoD6Init,
                dim2773JoeKuoD6Init,
                dim2774JoeKuoD6Init,
                dim2775JoeKuoD6Init,
                dim2776JoeKuoD6Init,
                dim2777JoeKuoD6Init,
                dim2778JoeKuoD6Init,
                dim2779JoeKuoD6Init,
                dim2780JoeKuoD6Init,
                dim2781JoeKuoD6Init,
                dim2782JoeKuoD6Init,
                dim2783JoeKuoD6Init,
                dim2784JoeKuoD6Init,
                dim2785JoeKuoD6Init,
                dim2786JoeKuoD6Init,
                dim2787JoeKuoD6Init,
                dim2788JoeKuoD6Init,
                dim2789JoeKuoD6Init,
                dim2790JoeKuoD6Init,
                dim2791JoeKuoD6Init,
                dim2792JoeKuoD6Init,
                dim2793JoeKuoD6Init,
                dim2794JoeKuoD6Init,
                dim2795JoeKuoD6Init,
                dim2796JoeKuoD6Init,
                dim2797JoeKuoD6Init,
                dim2798JoeKuoD6Init,
                dim2799JoeKuoD6Init,
                dim2800JoeKuoD6Init,
                dim2801JoeKuoD6Init,
                dim2802JoeKuoD6Init,
                dim2803JoeKuoD6Init,
                dim2804JoeKuoD6Init,
                dim2805JoeKuoD6Init,
                dim2806JoeKuoD6Init,
                dim2807JoeKuoD6Init,
                dim2808JoeKuoD6Init,
                dim2809JoeKuoD6Init,
                dim2810JoeKuoD6Init,
                dim2811JoeKuoD6Init,
                dim2812JoeKuoD6Init,
                dim2813JoeKuoD6Init,
                dim2814JoeKuoD6Init,
                dim2815JoeKuoD6Init,
                dim2816JoeKuoD6Init,
                dim2817JoeKuoD6Init,
                dim2818JoeKuoD6Init,
                dim2819JoeKuoD6Init,
                dim2820JoeKuoD6Init,
                dim2821JoeKuoD6Init,
                dim2822JoeKuoD6Init,
                dim2823JoeKuoD6Init,
                dim2824JoeKuoD6Init,
                dim2825JoeKuoD6Init,
                dim2826JoeKuoD6Init,
                dim2827JoeKuoD6Init,
                dim2828JoeKuoD6Init,
                dim2829JoeKuoD6Init,
                dim2830JoeKuoD6Init,
                dim2831JoeKuoD6Init,
                dim2832JoeKuoD6Init,
                dim2833JoeKuoD6Init,
                dim2834JoeKuoD6Init,
                dim2835JoeKuoD6Init,
                dim2836JoeKuoD6Init,
                dim2837JoeKuoD6Init,
                dim2838JoeKuoD6Init,
                dim2839JoeKuoD6Init,
                dim2840JoeKuoD6Init,
                dim2841JoeKuoD6Init,
                dim2842JoeKuoD6Init,
                dim2843JoeKuoD6Init,
                dim2844JoeKuoD6Init,
                dim2845JoeKuoD6Init,
                dim2846JoeKuoD6Init,
                dim2847JoeKuoD6Init,
                dim2848JoeKuoD6Init,
                dim2849JoeKuoD6Init,
                dim2850JoeKuoD6Init,
                dim2851JoeKuoD6Init,
                dim2852JoeKuoD6Init,
                dim2853JoeKuoD6Init,
                dim2854JoeKuoD6Init,
                dim2855JoeKuoD6Init,
                dim2856JoeKuoD6Init,
                dim2857JoeKuoD6Init,
                dim2858JoeKuoD6Init,
                dim2859JoeKuoD6Init,
                dim2860JoeKuoD6Init,
                dim2861JoeKuoD6Init,
                dim2862JoeKuoD6Init,
                dim2863JoeKuoD6Init,
                dim2864JoeKuoD6Init,
                dim2865JoeKuoD6Init,
                dim2866JoeKuoD6Init,
                dim2867JoeKuoD6Init,
                dim2868JoeKuoD6Init,
                dim2869JoeKuoD6Init,
                dim2870JoeKuoD6Init,
                dim2871JoeKuoD6Init,
                dim2872JoeKuoD6Init,
                dim2873JoeKuoD6Init,
                dim2874JoeKuoD6Init,
                dim2875JoeKuoD6Init,
                dim2876JoeKuoD6Init,
                dim2877JoeKuoD6Init,
                dim2878JoeKuoD6Init,
                dim2879JoeKuoD6Init,
                dim2880JoeKuoD6Init,
                dim2881JoeKuoD6Init,
                dim2882JoeKuoD6Init,
                dim2883JoeKuoD6Init,
                dim2884JoeKuoD6Init,
                dim2885JoeKuoD6Init,
                dim2886JoeKuoD6Init,
                dim2887JoeKuoD6Init,
                dim2888JoeKuoD6Init,
                dim2889JoeKuoD6Init,
                dim2890JoeKuoD6Init,
                dim2891JoeKuoD6Init,
                dim2892JoeKuoD6Init,
                dim2893JoeKuoD6Init,
                dim2894JoeKuoD6Init,
                dim2895JoeKuoD6Init,
                dim2896JoeKuoD6Init,
                dim2897JoeKuoD6Init,
                dim2898JoeKuoD6Init,
                dim2899JoeKuoD6Init,
                dim2900JoeKuoD6Init,
                dim2901JoeKuoD6Init,
                dim2902JoeKuoD6Init,
                dim2903JoeKuoD6Init,
                dim2904JoeKuoD6Init,
                dim2905JoeKuoD6Init,
                dim2906JoeKuoD6Init,
                dim2907JoeKuoD6Init,
                dim2908JoeKuoD6Init,
                dim2909JoeKuoD6Init,
                dim2910JoeKuoD6Init,
                dim2911JoeKuoD6Init,
                dim2912JoeKuoD6Init,
                dim2913JoeKuoD6Init,
                dim2914JoeKuoD6Init,
                dim2915JoeKuoD6Init,
                dim2916JoeKuoD6Init,
                dim2917JoeKuoD6Init,
                dim2918JoeKuoD6Init,
                dim2919JoeKuoD6Init,
                dim2920JoeKuoD6Init,
                dim2921JoeKuoD6Init,
                dim2922JoeKuoD6Init,
                dim2923JoeKuoD6Init,
                dim2924JoeKuoD6Init,
                dim2925JoeKuoD6Init,
                dim2926JoeKuoD6Init,
                dim2927JoeKuoD6Init,
                dim2928JoeKuoD6Init,
                dim2929JoeKuoD6Init,
                dim2930JoeKuoD6Init,
                dim2931JoeKuoD6Init,
                dim2932JoeKuoD6Init,
                dim2933JoeKuoD6Init,
                dim2934JoeKuoD6Init,
                dim2935JoeKuoD6Init,
                dim2936JoeKuoD6Init,
                dim2937JoeKuoD6Init,
                dim2938JoeKuoD6Init,
                dim2939JoeKuoD6Init,
                dim2940JoeKuoD6Init,
                dim2941JoeKuoD6Init,
                dim2942JoeKuoD6Init,
                dim2943JoeKuoD6Init,
                dim2944JoeKuoD6Init,
                dim2945JoeKuoD6Init,
                dim2946JoeKuoD6Init,
                dim2947JoeKuoD6Init,
                dim2948JoeKuoD6Init,
                dim2949JoeKuoD6Init,
                dim2950JoeKuoD6Init,
                dim2951JoeKuoD6Init,
                dim2952JoeKuoD6Init,
                dim2953JoeKuoD6Init,
                dim2954JoeKuoD6Init,
                dim2955JoeKuoD6Init,
                dim2956JoeKuoD6Init,
                dim2957JoeKuoD6Init,
                dim2958JoeKuoD6Init,
                dim2959JoeKuoD6Init,
                dim2960JoeKuoD6Init,
                dim2961JoeKuoD6Init,
                dim2962JoeKuoD6Init,
                dim2963JoeKuoD6Init,
                dim2964JoeKuoD6Init,
                dim2965JoeKuoD6Init,
                dim2966JoeKuoD6Init,
                dim2967JoeKuoD6Init,
                dim2968JoeKuoD6Init,
                dim2969JoeKuoD6Init,
                dim2970JoeKuoD6Init,
                dim2971JoeKuoD6Init,
                dim2972JoeKuoD6Init,
                dim2973JoeKuoD6Init,
                dim2974JoeKuoD6Init,
                dim2975JoeKuoD6Init,
                dim2976JoeKuoD6Init,
                dim2977JoeKuoD6Init,
                dim2978JoeKuoD6Init,
                dim2979JoeKuoD6Init,
                dim2980JoeKuoD6Init,
                dim2981JoeKuoD6Init,
                dim2982JoeKuoD6Init,
                dim2983JoeKuoD6Init,
                dim2984JoeKuoD6Init,
                dim2985JoeKuoD6Init,
                dim2986JoeKuoD6Init,
                dim2987JoeKuoD6Init,
                dim2988JoeKuoD6Init,
                dim2989JoeKuoD6Init,
                dim2990JoeKuoD6Init,
                dim2991JoeKuoD6Init,
                dim2992JoeKuoD6Init,
                dim2993JoeKuoD6Init,
                dim2994JoeKuoD6Init,
                dim2995JoeKuoD6Init,
                dim2996JoeKuoD6Init,
                dim2997JoeKuoD6Init,
                dim2998JoeKuoD6Init,
                dim2999JoeKuoD6Init,
                dim3000JoeKuoD6Init,
                dim3001JoeKuoD6Init,
                dim3002JoeKuoD6Init,
                dim3003JoeKuoD6Init,
                dim3004JoeKuoD6Init,
                dim3005JoeKuoD6Init,
                dim3006JoeKuoD6Init,
                dim3007JoeKuoD6Init,
                dim3008JoeKuoD6Init,
                dim3009JoeKuoD6Init,
                dim3010JoeKuoD6Init,
                dim3011JoeKuoD6Init,
                dim3012JoeKuoD6Init,
                dim3013JoeKuoD6Init,
                dim3014JoeKuoD6Init,
                dim3015JoeKuoD6Init,
                dim3016JoeKuoD6Init,
                dim3017JoeKuoD6Init,
                dim3018JoeKuoD6Init,
                dim3019JoeKuoD6Init,
                dim3020JoeKuoD6Init,
                dim3021JoeKuoD6Init,
                dim3022JoeKuoD6Init,
                dim3023JoeKuoD6Init,
                dim3024JoeKuoD6Init,
                dim3025JoeKuoD6Init,
                dim3026JoeKuoD6Init,
                dim3027JoeKuoD6Init,
                dim3028JoeKuoD6Init,
                dim3029JoeKuoD6Init,
                dim3030JoeKuoD6Init,
                dim3031JoeKuoD6Init,
                dim3032JoeKuoD6Init,
                dim3033JoeKuoD6Init,
                dim3034JoeKuoD6Init,
                dim3035JoeKuoD6Init,
                dim3036JoeKuoD6Init,
                dim3037JoeKuoD6Init,
                dim3038JoeKuoD6Init,
                dim3039JoeKuoD6Init,
                dim3040JoeKuoD6Init,
                dim3041JoeKuoD6Init,
                dim3042JoeKuoD6Init,
                dim3043JoeKuoD6Init,
                dim3044JoeKuoD6Init,
                dim3045JoeKuoD6Init,
                dim3046JoeKuoD6Init,
                dim3047JoeKuoD6Init,
                dim3048JoeKuoD6Init,
                dim3049JoeKuoD6Init,
                dim3050JoeKuoD6Init,
                dim3051JoeKuoD6Init,
                dim3052JoeKuoD6Init,
                dim3053JoeKuoD6Init,
                dim3054JoeKuoD6Init,
                dim3055JoeKuoD6Init,
                dim3056JoeKuoD6Init,
                dim3057JoeKuoD6Init,
                dim3058JoeKuoD6Init,
                dim3059JoeKuoD6Init,
                dim3060JoeKuoD6Init,
                dim3061JoeKuoD6Init,
                dim3062JoeKuoD6Init,
                dim3063JoeKuoD6Init,
                dim3064JoeKuoD6Init,
                dim3065JoeKuoD6Init,
                dim3066JoeKuoD6Init,
                dim3067JoeKuoD6Init,
                dim3068JoeKuoD6Init,
                dim3069JoeKuoD6Init,
                dim3070JoeKuoD6Init,
                dim3071JoeKuoD6Init,
                dim3072JoeKuoD6Init,
                dim3073JoeKuoD6Init,
                dim3074JoeKuoD6Init,
                dim3075JoeKuoD6Init,
                dim3076JoeKuoD6Init,
                dim3077JoeKuoD6Init,
                dim3078JoeKuoD6Init,
                dim3079JoeKuoD6Init,
                dim3080JoeKuoD6Init,
                dim3081JoeKuoD6Init,
                dim3082JoeKuoD6Init,
                dim3083JoeKuoD6Init,
                dim3084JoeKuoD6Init,
                dim3085JoeKuoD6Init,
                dim3086JoeKuoD6Init,
                dim3087JoeKuoD6Init,
                dim3088JoeKuoD6Init,
                dim3089JoeKuoD6Init,
                dim3090JoeKuoD6Init,
                dim3091JoeKuoD6Init,
                dim3092JoeKuoD6Init,
                dim3093JoeKuoD6Init,
                dim3094JoeKuoD6Init,
                dim3095JoeKuoD6Init,
                dim3096JoeKuoD6Init,
                dim3097JoeKuoD6Init,
                dim3098JoeKuoD6Init,
                dim3099JoeKuoD6Init,
                dim3100JoeKuoD6Init,
                dim3101JoeKuoD6Init,
                dim3102JoeKuoD6Init,
                dim3103JoeKuoD6Init,
                dim3104JoeKuoD6Init,
                dim3105JoeKuoD6Init,
                dim3106JoeKuoD6Init,
                dim3107JoeKuoD6Init,
                dim3108JoeKuoD6Init,
                dim3109JoeKuoD6Init,
                dim3110JoeKuoD6Init,
                dim3111JoeKuoD6Init,
                dim3112JoeKuoD6Init,
                dim3113JoeKuoD6Init,
                dim3114JoeKuoD6Init,
                dim3115JoeKuoD6Init,
                dim3116JoeKuoD6Init,
                dim3117JoeKuoD6Init,
                dim3118JoeKuoD6Init,
                dim3119JoeKuoD6Init,
                dim3120JoeKuoD6Init,
                dim3121JoeKuoD6Init,
                dim3122JoeKuoD6Init,
                dim3123JoeKuoD6Init,
                dim3124JoeKuoD6Init,
                dim3125JoeKuoD6Init,
                dim3126JoeKuoD6Init,
                dim3127JoeKuoD6Init,
                dim3128JoeKuoD6Init,
                dim3129JoeKuoD6Init,
                dim3130JoeKuoD6Init,
                dim3131JoeKuoD6Init,
                dim3132JoeKuoD6Init,
                dim3133JoeKuoD6Init,
                dim3134JoeKuoD6Init,
                dim3135JoeKuoD6Init,
                dim3136JoeKuoD6Init,
                dim3137JoeKuoD6Init,
                dim3138JoeKuoD6Init,
                dim3139JoeKuoD6Init,
                dim3140JoeKuoD6Init,
                dim3141JoeKuoD6Init,
                dim3142JoeKuoD6Init,
                dim3143JoeKuoD6Init,
                dim3144JoeKuoD6Init,
                dim3145JoeKuoD6Init,
                dim3146JoeKuoD6Init,
                dim3147JoeKuoD6Init,
                dim3148JoeKuoD6Init,
                dim3149JoeKuoD6Init,
                dim3150JoeKuoD6Init,
                dim3151JoeKuoD6Init,
                dim3152JoeKuoD6Init,
                dim3153JoeKuoD6Init,
                dim3154JoeKuoD6Init,
                dim3155JoeKuoD6Init,
                dim3156JoeKuoD6Init,
                dim3157JoeKuoD6Init,
                dim3158JoeKuoD6Init,
                dim3159JoeKuoD6Init,
                dim3160JoeKuoD6Init,
                dim3161JoeKuoD6Init,
                dim3162JoeKuoD6Init,
                dim3163JoeKuoD6Init,
                dim3164JoeKuoD6Init,
                dim3165JoeKuoD6Init,
                dim3166JoeKuoD6Init,
                dim3167JoeKuoD6Init,
                dim3168JoeKuoD6Init,
                dim3169JoeKuoD6Init,
                dim3170JoeKuoD6Init,
                dim3171JoeKuoD6Init,
                dim3172JoeKuoD6Init,
                dim3173JoeKuoD6Init,
                dim3174JoeKuoD6Init,
                dim3175JoeKuoD6Init,
                dim3176JoeKuoD6Init,
                dim3177JoeKuoD6Init,
                dim3178JoeKuoD6Init,
                dim3179JoeKuoD6Init,
                dim3180JoeKuoD6Init,
                dim3181JoeKuoD6Init,
                dim3182JoeKuoD6Init,
                dim3183JoeKuoD6Init,
                dim3184JoeKuoD6Init,
                dim3185JoeKuoD6Init,
                dim3186JoeKuoD6Init,
                dim3187JoeKuoD6Init,
                dim3188JoeKuoD6Init,
                dim3189JoeKuoD6Init,
                dim3190JoeKuoD6Init,
                dim3191JoeKuoD6Init,
                dim3192JoeKuoD6Init,
                dim3193JoeKuoD6Init,
                dim3194JoeKuoD6Init,
                dim3195JoeKuoD6Init,
                dim3196JoeKuoD6Init,
                dim3197JoeKuoD6Init,
                dim3198JoeKuoD6Init,
                dim3199JoeKuoD6Init,
                dim3200JoeKuoD6Init,
                dim3201JoeKuoD6Init,
                dim3202JoeKuoD6Init,
                dim3203JoeKuoD6Init,
                dim3204JoeKuoD6Init,
                dim3205JoeKuoD6Init,
                dim3206JoeKuoD6Init,
                dim3207JoeKuoD6Init,
                dim3208JoeKuoD6Init,
                dim3209JoeKuoD6Init,
                dim3210JoeKuoD6Init,
                dim3211JoeKuoD6Init,
                dim3212JoeKuoD6Init,
                dim3213JoeKuoD6Init,
                dim3214JoeKuoD6Init,
                dim3215JoeKuoD6Init,
                dim3216JoeKuoD6Init,
                dim3217JoeKuoD6Init,
                dim3218JoeKuoD6Init,
                dim3219JoeKuoD6Init,
                dim3220JoeKuoD6Init,
                dim3221JoeKuoD6Init,
                dim3222JoeKuoD6Init,
                dim3223JoeKuoD6Init,
                dim3224JoeKuoD6Init,
                dim3225JoeKuoD6Init,
                dim3226JoeKuoD6Init,
                dim3227JoeKuoD6Init,
                dim3228JoeKuoD6Init,
                dim3229JoeKuoD6Init,
                dim3230JoeKuoD6Init,
                dim3231JoeKuoD6Init,
                dim3232JoeKuoD6Init,
                dim3233JoeKuoD6Init,
                dim3234JoeKuoD6Init,
                dim3235JoeKuoD6Init,
                dim3236JoeKuoD6Init,
                dim3237JoeKuoD6Init,
                dim3238JoeKuoD6Init,
                dim3239JoeKuoD6Init,
                dim3240JoeKuoD6Init,
                dim3241JoeKuoD6Init,
                dim3242JoeKuoD6Init,
                dim3243JoeKuoD6Init,
                dim3244JoeKuoD6Init,
                dim3245JoeKuoD6Init,
                dim3246JoeKuoD6Init,
                dim3247JoeKuoD6Init,
                dim3248JoeKuoD6Init,
                dim3249JoeKuoD6Init,
                dim3250JoeKuoD6Init,
                dim3251JoeKuoD6Init,
                dim3252JoeKuoD6Init,
                dim3253JoeKuoD6Init,
                dim3254JoeKuoD6Init,
                dim3255JoeKuoD6Init,
                dim3256JoeKuoD6Init,
                dim3257JoeKuoD6Init,
                dim3258JoeKuoD6Init,
                dim3259JoeKuoD6Init,
                dim3260JoeKuoD6Init,
                dim3261JoeKuoD6Init,
                dim3262JoeKuoD6Init,
                dim3263JoeKuoD6Init,
                dim3264JoeKuoD6Init,
                dim3265JoeKuoD6Init,
                dim3266JoeKuoD6Init,
                dim3267JoeKuoD6Init,
                dim3268JoeKuoD6Init,
                dim3269JoeKuoD6Init,
                dim3270JoeKuoD6Init,
                dim3271JoeKuoD6Init,
                dim3272JoeKuoD6Init,
                dim3273JoeKuoD6Init,
                dim3274JoeKuoD6Init,
                dim3275JoeKuoD6Init,
                dim3276JoeKuoD6Init,
                dim3277JoeKuoD6Init,
                dim3278JoeKuoD6Init,
                dim3279JoeKuoD6Init,
                dim3280JoeKuoD6Init,
                dim3281JoeKuoD6Init,
                dim3282JoeKuoD6Init,
                dim3283JoeKuoD6Init,
                dim3284JoeKuoD6Init,
                dim3285JoeKuoD6Init,
                dim3286JoeKuoD6Init,
                dim3287JoeKuoD6Init,
                dim3288JoeKuoD6Init,
                dim3289JoeKuoD6Init,
                dim3290JoeKuoD6Init,
                dim3291JoeKuoD6Init,
                dim3292JoeKuoD6Init,
                dim3293JoeKuoD6Init,
                dim3294JoeKuoD6Init,
                dim3295JoeKuoD6Init,
                dim3296JoeKuoD6Init,
                dim3297JoeKuoD6Init,
                dim3298JoeKuoD6Init,
                dim3299JoeKuoD6Init,
                dim3300JoeKuoD6Init,
                dim3301JoeKuoD6Init,
                dim3302JoeKuoD6Init,
                dim3303JoeKuoD6Init,
                dim3304JoeKuoD6Init,
                dim3305JoeKuoD6Init,
                dim3306JoeKuoD6Init,
                dim3307JoeKuoD6Init,
                dim3308JoeKuoD6Init,
                dim3309JoeKuoD6Init,
                dim3310JoeKuoD6Init,
                dim3311JoeKuoD6Init,
                dim3312JoeKuoD6Init,
                dim3313JoeKuoD6Init,
                dim3314JoeKuoD6Init,
                dim3315JoeKuoD6Init,
                dim3316JoeKuoD6Init,
                dim3317JoeKuoD6Init,
                dim3318JoeKuoD6Init,
                dim3319JoeKuoD6Init,
                dim3320JoeKuoD6Init,
                dim3321JoeKuoD6Init,
                dim3322JoeKuoD6Init,
                dim3323JoeKuoD6Init,
                dim3324JoeKuoD6Init,
                dim3325JoeKuoD6Init,
                dim3326JoeKuoD6Init,
                dim3327JoeKuoD6Init,
                dim3328JoeKuoD6Init,
                dim3329JoeKuoD6Init,
                dim3330JoeKuoD6Init,
                dim3331JoeKuoD6Init,
                dim3332JoeKuoD6Init,
                dim3333JoeKuoD6Init,
                dim3334JoeKuoD6Init,
                dim3335JoeKuoD6Init,
                dim3336JoeKuoD6Init,
                dim3337JoeKuoD6Init,
                dim3338JoeKuoD6Init,
                dim3339JoeKuoD6Init,
                dim3340JoeKuoD6Init,
                dim3341JoeKuoD6Init,
                dim3342JoeKuoD6Init,
                dim3343JoeKuoD6Init,
                dim3344JoeKuoD6Init,
                dim3345JoeKuoD6Init,
                dim3346JoeKuoD6Init,
                dim3347JoeKuoD6Init,
                dim3348JoeKuoD6Init,
                dim3349JoeKuoD6Init,
                dim3350JoeKuoD6Init,
                dim3351JoeKuoD6Init,
                dim3352JoeKuoD6Init,
                dim3353JoeKuoD6Init,
                dim3354JoeKuoD6Init,
                dim3355JoeKuoD6Init,
                dim3356JoeKuoD6Init,
                dim3357JoeKuoD6Init,
                dim3358JoeKuoD6Init,
                dim3359JoeKuoD6Init,
                dim3360JoeKuoD6Init,
                dim3361JoeKuoD6Init,
                dim3362JoeKuoD6Init,
                dim3363JoeKuoD6Init,
                dim3364JoeKuoD6Init,
                dim3365JoeKuoD6Init,
                dim3366JoeKuoD6Init,
                dim3367JoeKuoD6Init,
                dim3368JoeKuoD6Init,
                dim3369JoeKuoD6Init,
                dim3370JoeKuoD6Init,
                dim3371JoeKuoD6Init,
                dim3372JoeKuoD6Init,
                dim3373JoeKuoD6Init,
                dim3374JoeKuoD6Init,
                dim3375JoeKuoD6Init,
                dim3376JoeKuoD6Init,
                dim3377JoeKuoD6Init,
                dim3378JoeKuoD6Init,
                dim3379JoeKuoD6Init,
                dim3380JoeKuoD6Init,
                dim3381JoeKuoD6Init,
                dim3382JoeKuoD6Init,
                dim3383JoeKuoD6Init,
                dim3384JoeKuoD6Init,
                dim3385JoeKuoD6Init,
                dim3386JoeKuoD6Init,
                dim3387JoeKuoD6Init,
                dim3388JoeKuoD6Init,
                dim3389JoeKuoD6Init,
                dim3390JoeKuoD6Init,
                dim3391JoeKuoD6Init,
                dim3392JoeKuoD6Init,
                dim3393JoeKuoD6Init,
                dim3394JoeKuoD6Init,
                dim3395JoeKuoD6Init,
                dim3396JoeKuoD6Init,
                dim3397JoeKuoD6Init,
                dim3398JoeKuoD6Init,
                dim3399JoeKuoD6Init,
                dim3400JoeKuoD6Init,
                dim3401JoeKuoD6Init,
                dim3402JoeKuoD6Init,
                dim3403JoeKuoD6Init,
                dim3404JoeKuoD6Init,
                dim3405JoeKuoD6Init,
                dim3406JoeKuoD6Init,
                dim3407JoeKuoD6Init,
                dim3408JoeKuoD6Init,
                dim3409JoeKuoD6Init,
                dim3410JoeKuoD6Init,
                dim3411JoeKuoD6Init,
                dim3412JoeKuoD6Init,
                dim3413JoeKuoD6Init,
                dim3414JoeKuoD6Init,
                dim3415JoeKuoD6Init,
                dim3416JoeKuoD6Init,
                dim3417JoeKuoD6Init,
                dim3418JoeKuoD6Init,
                dim3419JoeKuoD6Init,
                dim3420JoeKuoD6Init,
                dim3421JoeKuoD6Init,
                dim3422JoeKuoD6Init,
                dim3423JoeKuoD6Init,
                dim3424JoeKuoD6Init,
                dim3425JoeKuoD6Init,
                dim3426JoeKuoD6Init,
                dim3427JoeKuoD6Init,
                dim3428JoeKuoD6Init,
                dim3429JoeKuoD6Init,
                dim3430JoeKuoD6Init,
                dim3431JoeKuoD6Init,
                dim3432JoeKuoD6Init,
                dim3433JoeKuoD6Init,
                dim3434JoeKuoD6Init,
                dim3435JoeKuoD6Init,
                dim3436JoeKuoD6Init,
                dim3437JoeKuoD6Init,
                dim3438JoeKuoD6Init,
                dim3439JoeKuoD6Init,
                dim3440JoeKuoD6Init,
                dim3441JoeKuoD6Init,
                dim3442JoeKuoD6Init,
                dim3443JoeKuoD6Init,
                dim3444JoeKuoD6Init,
                dim3445JoeKuoD6Init,
                dim3446JoeKuoD6Init,
                dim3447JoeKuoD6Init,
                dim3448JoeKuoD6Init,
                dim3449JoeKuoD6Init,
                dim3450JoeKuoD6Init,
                dim3451JoeKuoD6Init,
                dim3452JoeKuoD6Init,
                dim3453JoeKuoD6Init,
                dim3454JoeKuoD6Init,
                dim3455JoeKuoD6Init,
                dim3456JoeKuoD6Init,
                dim3457JoeKuoD6Init,
                dim3458JoeKuoD6Init,
                dim3459JoeKuoD6Init,
                dim3460JoeKuoD6Init,
                dim3461JoeKuoD6Init,
                dim3462JoeKuoD6Init,
                dim3463JoeKuoD6Init,
                dim3464JoeKuoD6Init,
                dim3465JoeKuoD6Init,
                dim3466JoeKuoD6Init,
                dim3467JoeKuoD6Init,
                dim3468JoeKuoD6Init,
                dim3469JoeKuoD6Init,
                dim3470JoeKuoD6Init,
                dim3471JoeKuoD6Init,
                dim3472JoeKuoD6Init,
                dim3473JoeKuoD6Init,
                dim3474JoeKuoD6Init,
                dim3475JoeKuoD6Init,
                dim3476JoeKuoD6Init,
                dim3477JoeKuoD6Init,
                dim3478JoeKuoD6Init,
                dim3479JoeKuoD6Init,
                dim3480JoeKuoD6Init,
                dim3481JoeKuoD6Init,
                dim3482JoeKuoD6Init,
                dim3483JoeKuoD6Init,
                dim3484JoeKuoD6Init,
                dim3485JoeKuoD6Init,
                dim3486JoeKuoD6Init,
                dim3487JoeKuoD6Init,
                dim3488JoeKuoD6Init,
                dim3489JoeKuoD6Init,
                dim3490JoeKuoD6Init,
                dim3491JoeKuoD6Init,
                dim3492JoeKuoD6Init,
                dim3493JoeKuoD6Init,
                dim3494JoeKuoD6Init,
                dim3495JoeKuoD6Init,
                dim3496JoeKuoD6Init,
                dim3497JoeKuoD6Init,
                dim3498JoeKuoD6Init,
                dim3499JoeKuoD6Init,
                dim3500JoeKuoD6Init,
                dim3501JoeKuoD6Init,
                dim3502JoeKuoD6Init,
                dim3503JoeKuoD6Init,
                dim3504JoeKuoD6Init,
                dim3505JoeKuoD6Init,
                dim3506JoeKuoD6Init,
                dim3507JoeKuoD6Init,
                dim3508JoeKuoD6Init,
                dim3509JoeKuoD6Init,
                dim3510JoeKuoD6Init,
                dim3511JoeKuoD6Init,
                dim3512JoeKuoD6Init,
                dim3513JoeKuoD6Init,
                dim3514JoeKuoD6Init,
                dim3515JoeKuoD6Init,
                dim3516JoeKuoD6Init,
                dim3517JoeKuoD6Init,
                dim3518JoeKuoD6Init,
                dim3519JoeKuoD6Init,
                dim3520JoeKuoD6Init,
                dim3521JoeKuoD6Init,
                dim3522JoeKuoD6Init,
                dim3523JoeKuoD6Init,
                dim3524JoeKuoD6Init,
                dim3525JoeKuoD6Init,
                dim3526JoeKuoD6Init,
                dim3527JoeKuoD6Init,
                dim3528JoeKuoD6Init,
                dim3529JoeKuoD6Init,
                dim3530JoeKuoD6Init,
                dim3531JoeKuoD6Init,
                dim3532JoeKuoD6Init,
                dim3533JoeKuoD6Init,
                dim3534JoeKuoD6Init,
                dim3535JoeKuoD6Init,
                dim3536JoeKuoD6Init,
                dim3537JoeKuoD6Init,
                dim3538JoeKuoD6Init,
                dim3539JoeKuoD6Init,
                dim3540JoeKuoD6Init,
                dim3541JoeKuoD6Init,
                dim3542JoeKuoD6Init,
                dim3543JoeKuoD6Init,
                dim3544JoeKuoD6Init,
                dim3545JoeKuoD6Init,
                dim3546JoeKuoD6Init,
                dim3547JoeKuoD6Init,
                dim3548JoeKuoD6Init,
                dim3549JoeKuoD6Init,
                dim3550JoeKuoD6Init,
                dim3551JoeKuoD6Init,
                dim3552JoeKuoD6Init,
                dim3553JoeKuoD6Init,
                dim3554JoeKuoD6Init,
                dim3555JoeKuoD6Init,
                dim3556JoeKuoD6Init,
                dim3557JoeKuoD6Init,
                dim3558JoeKuoD6Init,
                dim3559JoeKuoD6Init,
                dim3560JoeKuoD6Init,
                dim3561JoeKuoD6Init,
                dim3562JoeKuoD6Init,
                dim3563JoeKuoD6Init,
                dim3564JoeKuoD6Init,
                dim3565JoeKuoD6Init,
                dim3566JoeKuoD6Init,
                dim3567JoeKuoD6Init,
                dim3568JoeKuoD6Init,
                dim3569JoeKuoD6Init,
                dim3570JoeKuoD6Init,
                dim3571JoeKuoD6Init,
                dim3572JoeKuoD6Init,
                dim3573JoeKuoD6Init,
                dim3574JoeKuoD6Init,
                dim3575JoeKuoD6Init,
                dim3576JoeKuoD6Init,
                dim3577JoeKuoD6Init,
                dim3578JoeKuoD6Init,
                dim3579JoeKuoD6Init,
                dim3580JoeKuoD6Init,
                dim3581JoeKuoD6Init,
                dim3582JoeKuoD6Init,
                dim3583JoeKuoD6Init,
                dim3584JoeKuoD6Init,
                dim3585JoeKuoD6Init,
                dim3586JoeKuoD6Init,
                dim3587JoeKuoD6Init,
                dim3588JoeKuoD6Init,
                dim3589JoeKuoD6Init,
                dim3590JoeKuoD6Init,
                dim3591JoeKuoD6Init,
                dim3592JoeKuoD6Init,
                dim3593JoeKuoD6Init,
                dim3594JoeKuoD6Init,
                dim3595JoeKuoD6Init,
                dim3596JoeKuoD6Init,
                dim3597JoeKuoD6Init,
                dim3598JoeKuoD6Init,
                dim3599JoeKuoD6Init,
                dim3600JoeKuoD6Init,
                dim3601JoeKuoD6Init,
                dim3602JoeKuoD6Init,
                dim3603JoeKuoD6Init,
                dim3604JoeKuoD6Init,
                dim3605JoeKuoD6Init,
                dim3606JoeKuoD6Init,
                dim3607JoeKuoD6Init,
                dim3608JoeKuoD6Init,
                dim3609JoeKuoD6Init,
                dim3610JoeKuoD6Init,
                dim3611JoeKuoD6Init,
                dim3612JoeKuoD6Init,
                dim3613JoeKuoD6Init,
                dim3614JoeKuoD6Init,
                dim3615JoeKuoD6Init,
                dim3616JoeKuoD6Init,
                dim3617JoeKuoD6Init,
                dim3618JoeKuoD6Init,
                dim3619JoeKuoD6Init,
                dim3620JoeKuoD6Init,
                dim3621JoeKuoD6Init,
                dim3622JoeKuoD6Init,
                dim3623JoeKuoD6Init,
                dim3624JoeKuoD6Init,
                dim3625JoeKuoD6Init,
                dim3626JoeKuoD6Init,
                dim3627JoeKuoD6Init,
                dim3628JoeKuoD6Init,
                dim3629JoeKuoD6Init,
                dim3630JoeKuoD6Init,
                dim3631JoeKuoD6Init,
                dim3632JoeKuoD6Init,
                dim3633JoeKuoD6Init,
                dim3634JoeKuoD6Init,
                dim3635JoeKuoD6Init,
                dim3636JoeKuoD6Init,
                dim3637JoeKuoD6Init,
                dim3638JoeKuoD6Init,
                dim3639JoeKuoD6Init,
                dim3640JoeKuoD6Init,
                dim3641JoeKuoD6Init,
                dim3642JoeKuoD6Init,
                dim3643JoeKuoD6Init,
                dim3644JoeKuoD6Init,
                dim3645JoeKuoD6Init,
                dim3646JoeKuoD6Init,
                dim3647JoeKuoD6Init,
                dim3648JoeKuoD6Init,
                dim3649JoeKuoD6Init,
                dim3650JoeKuoD6Init,
                dim3651JoeKuoD6Init,
                dim3652JoeKuoD6Init,
                dim3653JoeKuoD6Init,
                dim3654JoeKuoD6Init,
                dim3655JoeKuoD6Init,
                dim3656JoeKuoD6Init,
                dim3657JoeKuoD6Init,
                dim3658JoeKuoD6Init,
                dim3659JoeKuoD6Init,
                dim3660JoeKuoD6Init,
                dim3661JoeKuoD6Init,
                dim3662JoeKuoD6Init,
                dim3663JoeKuoD6Init,
                dim3664JoeKuoD6Init,
                dim3665JoeKuoD6Init,
                dim3666JoeKuoD6Init,
                dim3667JoeKuoD6Init,
                dim3668JoeKuoD6Init,
                dim3669JoeKuoD6Init,
                dim3670JoeKuoD6Init,
                dim3671JoeKuoD6Init,
                dim3672JoeKuoD6Init,
                dim3673JoeKuoD6Init,
                dim3674JoeKuoD6Init,
                dim3675JoeKuoD6Init,
                dim3676JoeKuoD6Init,
                dim3677JoeKuoD6Init,
                dim3678JoeKuoD6Init,
                dim3679JoeKuoD6Init,
                dim3680JoeKuoD6Init,
                dim3681JoeKuoD6Init,
                dim3682JoeKuoD6Init,
                dim3683JoeKuoD6Init,
                dim3684JoeKuoD6Init,
                dim3685JoeKuoD6Init,
                dim3686JoeKuoD6Init,
                dim3687JoeKuoD6Init,
                dim3688JoeKuoD6Init,
                dim3689JoeKuoD6Init,
                dim3690JoeKuoD6Init,
                dim3691JoeKuoD6Init,
                dim3692JoeKuoD6Init,
                dim3693JoeKuoD6Init,
                dim3694JoeKuoD6Init,
                dim3695JoeKuoD6Init,
                dim3696JoeKuoD6Init,
                dim3697JoeKuoD6Init,
                dim3698JoeKuoD6Init,
                dim3699JoeKuoD6Init,
                dim3700JoeKuoD6Init,
                dim3701JoeKuoD6Init,
                dim3702JoeKuoD6Init,
                dim3703JoeKuoD6Init,
                dim3704JoeKuoD6Init,
                dim3705JoeKuoD6Init,
                dim3706JoeKuoD6Init,
                dim3707JoeKuoD6Init,
                dim3708JoeKuoD6Init,
                dim3709JoeKuoD6Init,
                dim3710JoeKuoD6Init,
                dim3711JoeKuoD6Init,
                dim3712JoeKuoD6Init,
                dim3713JoeKuoD6Init,
                dim3714JoeKuoD6Init,
                dim3715JoeKuoD6Init,
                dim3716JoeKuoD6Init,
                dim3717JoeKuoD6Init,
                dim3718JoeKuoD6Init,
                dim3719JoeKuoD6Init,
                dim3720JoeKuoD6Init,
                dim3721JoeKuoD6Init,
                dim3722JoeKuoD6Init,
                dim3723JoeKuoD6Init,
                dim3724JoeKuoD6Init,
                dim3725JoeKuoD6Init,
                dim3726JoeKuoD6Init,
                dim3727JoeKuoD6Init,
                dim3728JoeKuoD6Init,
                dim3729JoeKuoD6Init,
                dim3730JoeKuoD6Init,
                dim3731JoeKuoD6Init,
                dim3732JoeKuoD6Init,
                dim3733JoeKuoD6Init,
                dim3734JoeKuoD6Init,
                dim3735JoeKuoD6Init,
                dim3736JoeKuoD6Init,
                dim3737JoeKuoD6Init,
                dim3738JoeKuoD6Init,
                dim3739JoeKuoD6Init,
                dim3740JoeKuoD6Init,
                dim3741JoeKuoD6Init,
                dim3742JoeKuoD6Init,
                dim3743JoeKuoD6Init,
                dim3744JoeKuoD6Init,
                dim3745JoeKuoD6Init,
                dim3746JoeKuoD6Init,
                dim3747JoeKuoD6Init,
                dim3748JoeKuoD6Init,
                dim3749JoeKuoD6Init,
                dim3750JoeKuoD6Init,
                dim3751JoeKuoD6Init,
                dim3752JoeKuoD6Init,
                dim3753JoeKuoD6Init,
                dim3754JoeKuoD6Init,
                dim3755JoeKuoD6Init,
                dim3756JoeKuoD6Init,
                dim3757JoeKuoD6Init,
                dim3758JoeKuoD6Init,
                dim3759JoeKuoD6Init,
                dim3760JoeKuoD6Init,
                dim3761JoeKuoD6Init,
                dim3762JoeKuoD6Init,
                dim3763JoeKuoD6Init,
                dim3764JoeKuoD6Init,
                dim3765JoeKuoD6Init,
                dim3766JoeKuoD6Init,
                dim3767JoeKuoD6Init,
                dim3768JoeKuoD6Init,
                dim3769JoeKuoD6Init,
                dim3770JoeKuoD6Init,
                dim3771JoeKuoD6Init,
                dim3772JoeKuoD6Init,
                dim3773JoeKuoD6Init,
                dim3774JoeKuoD6Init,
                dim3775JoeKuoD6Init,
                dim3776JoeKuoD6Init,
                dim3777JoeKuoD6Init,
                dim3778JoeKuoD6Init,
                dim3779JoeKuoD6Init,
                dim3780JoeKuoD6Init,
                dim3781JoeKuoD6Init,
                dim3782JoeKuoD6Init,
                dim3783JoeKuoD6Init,
                dim3784JoeKuoD6Init,
                dim3785JoeKuoD6Init,
                dim3786JoeKuoD6Init,
                dim3787JoeKuoD6Init,
                dim3788JoeKuoD6Init,
                dim3789JoeKuoD6Init,
                dim3790JoeKuoD6Init,
                dim3791JoeKuoD6Init,
                dim3792JoeKuoD6Init,
                dim3793JoeKuoD6Init,
                dim3794JoeKuoD6Init,
                dim3795JoeKuoD6Init,
                dim3796JoeKuoD6Init,
                dim3797JoeKuoD6Init,
                dim3798JoeKuoD6Init,
                dim3799JoeKuoD6Init,
                dim3800JoeKuoD6Init,
                dim3801JoeKuoD6Init,
                dim3802JoeKuoD6Init,
                dim3803JoeKuoD6Init,
                dim3804JoeKuoD6Init,
                dim3805JoeKuoD6Init,
                dim3806JoeKuoD6Init,
                dim3807JoeKuoD6Init,
                dim3808JoeKuoD6Init,
                dim3809JoeKuoD6Init,
                dim3810JoeKuoD6Init,
                dim3811JoeKuoD6Init,
                dim3812JoeKuoD6Init,
                dim3813JoeKuoD6Init,
                dim3814JoeKuoD6Init,
                dim3815JoeKuoD6Init,
                dim3816JoeKuoD6Init,
                dim3817JoeKuoD6Init,
                dim3818JoeKuoD6Init,
                dim3819JoeKuoD6Init,
                dim3820JoeKuoD6Init,
                dim3821JoeKuoD6Init,
                dim3822JoeKuoD6Init,
                dim3823JoeKuoD6Init,
                dim3824JoeKuoD6Init,
                dim3825JoeKuoD6Init,
                dim3826JoeKuoD6Init,
                dim3827JoeKuoD6Init,
                dim3828JoeKuoD6Init,
                dim3829JoeKuoD6Init,
                dim3830JoeKuoD6Init,
                dim3831JoeKuoD6Init,
                dim3832JoeKuoD6Init,
                dim3833JoeKuoD6Init,
                dim3834JoeKuoD6Init,
                dim3835JoeKuoD6Init,
                dim3836JoeKuoD6Init,
                dim3837JoeKuoD6Init,
                dim3838JoeKuoD6Init,
                dim3839JoeKuoD6Init,
                dim3840JoeKuoD6Init,
                dim3841JoeKuoD6Init,
                dim3842JoeKuoD6Init,
                dim3843JoeKuoD6Init,
                dim3844JoeKuoD6Init,
                dim3845JoeKuoD6Init,
                dim3846JoeKuoD6Init,
                dim3847JoeKuoD6Init,
                dim3848JoeKuoD6Init,
                dim3849JoeKuoD6Init,
                dim3850JoeKuoD6Init,
                dim3851JoeKuoD6Init,
                dim3852JoeKuoD6Init,
                dim3853JoeKuoD6Init,
                dim3854JoeKuoD6Init,
                dim3855JoeKuoD6Init,
                dim3856JoeKuoD6Init,
                dim3857JoeKuoD6Init,
                dim3858JoeKuoD6Init,
                dim3859JoeKuoD6Init,
                dim3860JoeKuoD6Init,
                dim3861JoeKuoD6Init,
                dim3862JoeKuoD6Init,
                dim3863JoeKuoD6Init,
                dim3864JoeKuoD6Init,
                dim3865JoeKuoD6Init,
                dim3866JoeKuoD6Init,
                dim3867JoeKuoD6Init,
                dim3868JoeKuoD6Init,
                dim3869JoeKuoD6Init,
                dim3870JoeKuoD6Init,
                dim3871JoeKuoD6Init,
                dim3872JoeKuoD6Init,
                dim3873JoeKuoD6Init,
                dim3874JoeKuoD6Init,
                dim3875JoeKuoD6Init,
                dim3876JoeKuoD6Init,
                dim3877JoeKuoD6Init,
                dim3878JoeKuoD6Init,
                dim3879JoeKuoD6Init,
                dim3880JoeKuoD6Init,
                dim3881JoeKuoD6Init,
                dim3882JoeKuoD6Init,
                dim3883JoeKuoD6Init,
                dim3884JoeKuoD6Init,
                dim3885JoeKuoD6Init,
                dim3886JoeKuoD6Init,
                dim3887JoeKuoD6Init,
                dim3888JoeKuoD6Init,
                dim3889JoeKuoD6Init,
                dim3890JoeKuoD6Init,
                dim3891JoeKuoD6Init,
                dim3892JoeKuoD6Init,
                dim3893JoeKuoD6Init,
                dim3894JoeKuoD6Init,
                dim3895JoeKuoD6Init,
                dim3896JoeKuoD6Init,
                dim3897JoeKuoD6Init,
                dim3898JoeKuoD6Init,
                dim3899JoeKuoD6Init,
                dim3900JoeKuoD6Init,
                dim3901JoeKuoD6Init,
                dim3902JoeKuoD6Init,
                dim3903JoeKuoD6Init,
                dim3904JoeKuoD6Init,
                dim3905JoeKuoD6Init,
                dim3906JoeKuoD6Init,
                dim3907JoeKuoD6Init,
                dim3908JoeKuoD6Init,
                dim3909JoeKuoD6Init,
                dim3910JoeKuoD6Init,
                dim3911JoeKuoD6Init,
                dim3912JoeKuoD6Init,
                dim3913JoeKuoD6Init,
                dim3914JoeKuoD6Init,
                dim3915JoeKuoD6Init,
                dim3916JoeKuoD6Init,
                dim3917JoeKuoD6Init,
                dim3918JoeKuoD6Init,
                dim3919JoeKuoD6Init,
                dim3920JoeKuoD6Init,
                dim3921JoeKuoD6Init,
                dim3922JoeKuoD6Init,
                dim3923JoeKuoD6Init,
                dim3924JoeKuoD6Init,
                dim3925JoeKuoD6Init,
                dim3926JoeKuoD6Init,
                dim3927JoeKuoD6Init,
                dim3928JoeKuoD6Init,
                dim3929JoeKuoD6Init,
                dim3930JoeKuoD6Init,
                dim3931JoeKuoD6Init,
                dim3932JoeKuoD6Init,
                dim3933JoeKuoD6Init,
                dim3934JoeKuoD6Init,
                dim3935JoeKuoD6Init,
                dim3936JoeKuoD6Init,
                dim3937JoeKuoD6Init,
                dim3938JoeKuoD6Init,
                dim3939JoeKuoD6Init,
                dim3940JoeKuoD6Init,
                dim3941JoeKuoD6Init,
                dim3942JoeKuoD6Init,
                dim3943JoeKuoD6Init,
                dim3944JoeKuoD6Init,
                dim3945JoeKuoD6Init,
                dim3946JoeKuoD6Init,
                dim3947JoeKuoD6Init,
                dim3948JoeKuoD6Init,
                dim3949JoeKuoD6Init,
                dim3950JoeKuoD6Init,
                dim3951JoeKuoD6Init,
                dim3952JoeKuoD6Init,
                dim3953JoeKuoD6Init,
                dim3954JoeKuoD6Init,
                dim3955JoeKuoD6Init,
                dim3956JoeKuoD6Init,
                dim3957JoeKuoD6Init,
                dim3958JoeKuoD6Init,
                dim3959JoeKuoD6Init,
                dim3960JoeKuoD6Init,
                dim3961JoeKuoD6Init,
                dim3962JoeKuoD6Init,
                dim3963JoeKuoD6Init,
                dim3964JoeKuoD6Init,
                dim3965JoeKuoD6Init,
                dim3966JoeKuoD6Init,
                dim3967JoeKuoD6Init,
                dim3968JoeKuoD6Init,
                dim3969JoeKuoD6Init,
                dim3970JoeKuoD6Init,
                dim3971JoeKuoD6Init,
                dim3972JoeKuoD6Init,
                dim3973JoeKuoD6Init,
                dim3974JoeKuoD6Init,
                dim3975JoeKuoD6Init,
                dim3976JoeKuoD6Init,
                dim3977JoeKuoD6Init,
                dim3978JoeKuoD6Init,
                dim3979JoeKuoD6Init,
                dim3980JoeKuoD6Init,
                dim3981JoeKuoD6Init,
                dim3982JoeKuoD6Init,
                dim3983JoeKuoD6Init,
                dim3984JoeKuoD6Init,
                dim3985JoeKuoD6Init,
                dim3986JoeKuoD6Init,
                dim3987JoeKuoD6Init,
                dim3988JoeKuoD6Init,
                dim3989JoeKuoD6Init,
                dim3990JoeKuoD6Init,
                dim3991JoeKuoD6Init,
                dim3992JoeKuoD6Init,
                dim3993JoeKuoD6Init,
                dim3994JoeKuoD6Init,
                dim3995JoeKuoD6Init,
                dim3996JoeKuoD6Init,
                dim3997JoeKuoD6Init,
                dim3998JoeKuoD6Init,
                dim3999JoeKuoD6Init,
                dim4000JoeKuoD6Init,
                dim4001JoeKuoD6Init,
                dim4002JoeKuoD6Init,
                dim4003JoeKuoD6Init,
                dim4004JoeKuoD6Init,
                dim4005JoeKuoD6Init,
                dim4006JoeKuoD6Init,
                dim4007JoeKuoD6Init,
                dim4008JoeKuoD6Init,
                dim4009JoeKuoD6Init,
                dim4010JoeKuoD6Init,
                dim4011JoeKuoD6Init,
                dim4012JoeKuoD6Init,
                dim4013JoeKuoD6Init,
                dim4014JoeKuoD6Init,
                dim4015JoeKuoD6Init,
                dim4016JoeKuoD6Init,
                dim4017JoeKuoD6Init,
                dim4018JoeKuoD6Init,
                dim4019JoeKuoD6Init,
                dim4020JoeKuoD6Init,
                dim4021JoeKuoD6Init,
                dim4022JoeKuoD6Init,
                dim4023JoeKuoD6Init,
                dim4024JoeKuoD6Init,
                dim4025JoeKuoD6Init,
                dim4026JoeKuoD6Init,
                dim4027JoeKuoD6Init,
                dim4028JoeKuoD6Init,
                dim4029JoeKuoD6Init,
                dim4030JoeKuoD6Init,
                dim4031JoeKuoD6Init,
                dim4032JoeKuoD6Init,
                dim4033JoeKuoD6Init,
                dim4034JoeKuoD6Init,
                dim4035JoeKuoD6Init,
                dim4036JoeKuoD6Init,
                dim4037JoeKuoD6Init,
                dim4038JoeKuoD6Init,
                dim4039JoeKuoD6Init,
                dim4040JoeKuoD6Init,
                dim4041JoeKuoD6Init,
                dim4042JoeKuoD6Init,
                dim4043JoeKuoD6Init,
                dim4044JoeKuoD6Init,
                dim4045JoeKuoD6Init,
                dim4046JoeKuoD6Init,
                dim4047JoeKuoD6Init,
                dim4048JoeKuoD6Init,
                dim4049JoeKuoD6Init,
                dim4050JoeKuoD6Init,
                dim4051JoeKuoD6Init,
                dim4052JoeKuoD6Init,
                dim4053JoeKuoD6Init,
                dim4054JoeKuoD6Init,
                dim4055JoeKuoD6Init,
                dim4056JoeKuoD6Init,
                dim4057JoeKuoD6Init,
                dim4058JoeKuoD6Init,
                dim4059JoeKuoD6Init,
                dim4060JoeKuoD6Init,
                dim4061JoeKuoD6Init,
                dim4062JoeKuoD6Init,
                dim4063JoeKuoD6Init,
                dim4064JoeKuoD6Init,
                dim4065JoeKuoD6Init,
                dim4066JoeKuoD6Init,
                dim4067JoeKuoD6Init,
                dim4068JoeKuoD6Init,
                dim4069JoeKuoD6Init,
                dim4070JoeKuoD6Init,
                dim4071JoeKuoD6Init,
                dim4072JoeKuoD6Init,
                dim4073JoeKuoD6Init,
                dim4074JoeKuoD6Init,
                dim4075JoeKuoD6Init,
                dim4076JoeKuoD6Init,
                dim4077JoeKuoD6Init,
                dim4078JoeKuoD6Init,
                dim4079JoeKuoD6Init,
                dim4080JoeKuoD6Init,
                dim4081JoeKuoD6Init,
                dim4082JoeKuoD6Init,
                dim4083JoeKuoD6Init,
                dim4084JoeKuoD6Init,
                dim4085JoeKuoD6Init,
                dim4086JoeKuoD6Init,
                dim4087JoeKuoD6Init,
                dim4088JoeKuoD6Init,
                dim4089JoeKuoD6Init,
                dim4090JoeKuoD6Init,
                dim4091JoeKuoD6Init,
                dim4092JoeKuoD6Init,
                dim4093JoeKuoD6Init,
                dim4094JoeKuoD6Init,
                dim4095JoeKuoD6Init,
                dim4096JoeKuoD6Init,
                dim4097JoeKuoD6Init,
                dim4098JoeKuoD6Init,
                dim4099JoeKuoD6Init,
                dim4100JoeKuoD6Init,
                dim4101JoeKuoD6Init,
                dim4102JoeKuoD6Init,
                dim4103JoeKuoD6Init,
                dim4104JoeKuoD6Init,
                dim4105JoeKuoD6Init,
                dim4106JoeKuoD6Init,
                dim4107JoeKuoD6Init,
                dim4108JoeKuoD6Init,
                dim4109JoeKuoD6Init,
                dim4110JoeKuoD6Init,
                dim4111JoeKuoD6Init,
                dim4112JoeKuoD6Init,
                dim4113JoeKuoD6Init,
                dim4114JoeKuoD6Init,
                dim4115JoeKuoD6Init,
                dim4116JoeKuoD6Init,
                dim4117JoeKuoD6Init,
                dim4118JoeKuoD6Init,
                dim4119JoeKuoD6Init,
                dim4120JoeKuoD6Init,
                dim4121JoeKuoD6Init,
                dim4122JoeKuoD6Init,
                dim4123JoeKuoD6Init,
                dim4124JoeKuoD6Init,
                dim4125JoeKuoD6Init,
                dim4126JoeKuoD6Init,
                dim4127JoeKuoD6Init,
                dim4128JoeKuoD6Init,
                dim4129JoeKuoD6Init,
                dim4130JoeKuoD6Init,
                dim4131JoeKuoD6Init,
                dim4132JoeKuoD6Init,
                dim4133JoeKuoD6Init,
                dim4134JoeKuoD6Init,
                dim4135JoeKuoD6Init,
                dim4136JoeKuoD6Init,
                dim4137JoeKuoD6Init,
                dim4138JoeKuoD6Init,
                dim4139JoeKuoD6Init,
                dim4140JoeKuoD6Init,
                dim4141JoeKuoD6Init,
                dim4142JoeKuoD6Init,
                dim4143JoeKuoD6Init,
                dim4144JoeKuoD6Init,
                dim4145JoeKuoD6Init,
                dim4146JoeKuoD6Init,
                dim4147JoeKuoD6Init,
                dim4148JoeKuoD6Init,
                dim4149JoeKuoD6Init,
                dim4150JoeKuoD6Init,
                dim4151JoeKuoD6Init,
                dim4152JoeKuoD6Init,
                dim4153JoeKuoD6Init,
                dim4154JoeKuoD6Init,
                dim4155JoeKuoD6Init,
                dim4156JoeKuoD6Init,
                dim4157JoeKuoD6Init,
                dim4158JoeKuoD6Init,
                dim4159JoeKuoD6Init,
                dim4160JoeKuoD6Init,
                dim4161JoeKuoD6Init,
                dim4162JoeKuoD6Init,
                dim4163JoeKuoD6Init,
                dim4164JoeKuoD6Init,
                dim4165JoeKuoD6Init,
                dim4166JoeKuoD6Init,
                dim4167JoeKuoD6Init,
                dim4168JoeKuoD6Init,
                dim4169JoeKuoD6Init,
                dim4170JoeKuoD6Init,
                dim4171JoeKuoD6Init,
                dim4172JoeKuoD6Init,
                dim4173JoeKuoD6Init,
                dim4174JoeKuoD6Init,
                dim4175JoeKuoD6Init,
                dim4176JoeKuoD6Init,
                dim4177JoeKuoD6Init,
                dim4178JoeKuoD6Init,
                dim4179JoeKuoD6Init,
                dim4180JoeKuoD6Init,
                dim4181JoeKuoD6Init,
                dim4182JoeKuoD6Init,
                dim4183JoeKuoD6Init,
                dim4184JoeKuoD6Init,
                dim4185JoeKuoD6Init,
                dim4186JoeKuoD6Init,
                dim4187JoeKuoD6Init,
                dim4188JoeKuoD6Init,
                dim4189JoeKuoD6Init,
                dim4190JoeKuoD6Init,
                dim4191JoeKuoD6Init,
                dim4192JoeKuoD6Init,
                dim4193JoeKuoD6Init,
                dim4194JoeKuoD6Init,
                dim4195JoeKuoD6Init,
                dim4196JoeKuoD6Init,
                dim4197JoeKuoD6Init,
                dim4198JoeKuoD6Init,
                dim4199JoeKuoD6Init,
                dim4200JoeKuoD6Init,
                dim4201JoeKuoD6Init,
                dim4202JoeKuoD6Init,
                dim4203JoeKuoD6Init,
                dim4204JoeKuoD6Init,
                dim4205JoeKuoD6Init,
                dim4206JoeKuoD6Init,
                dim4207JoeKuoD6Init,
                dim4208JoeKuoD6Init,
                dim4209JoeKuoD6Init,
                dim4210JoeKuoD6Init,
                dim4211JoeKuoD6Init,
                dim4212JoeKuoD6Init,
                dim4213JoeKuoD6Init,
                dim4214JoeKuoD6Init,
                dim4215JoeKuoD6Init,
                dim4216JoeKuoD6Init,
                dim4217JoeKuoD6Init,
                dim4218JoeKuoD6Init,
                dim4219JoeKuoD6Init,
                dim4220JoeKuoD6Init,
                dim4221JoeKuoD6Init,
                dim4222JoeKuoD6Init,
                dim4223JoeKuoD6Init,
                dim4224JoeKuoD6Init,
                dim4225JoeKuoD6Init,
                dim4226JoeKuoD6Init,
                dim4227JoeKuoD6Init,
                dim4228JoeKuoD6Init,
                dim4229JoeKuoD6Init,
                dim4230JoeKuoD6Init,
                dim4231JoeKuoD6Init,
                dim4232JoeKuoD6Init,
                dim4233JoeKuoD6Init,
                dim4234JoeKuoD6Init,
                dim4235JoeKuoD6Init,
                dim4236JoeKuoD6Init,
                dim4237JoeKuoD6Init,
                dim4238JoeKuoD6Init,
                dim4239JoeKuoD6Init,
                dim4240JoeKuoD6Init,
                dim4241JoeKuoD6Init,
                dim4242JoeKuoD6Init,
                dim4243JoeKuoD6Init,
                dim4244JoeKuoD6Init,
                dim4245JoeKuoD6Init,
                dim4246JoeKuoD6Init,
                dim4247JoeKuoD6Init,
                dim4248JoeKuoD6Init,
                dim4249JoeKuoD6Init,
                dim4250JoeKuoD6Init,
                dim4251JoeKuoD6Init,
                dim4252JoeKuoD6Init,
                dim4253JoeKuoD6Init,
                dim4254JoeKuoD6Init,
                dim4255JoeKuoD6Init,
                dim4256JoeKuoD6Init,
                dim4257JoeKuoD6Init,
                dim4258JoeKuoD6Init,
                dim4259JoeKuoD6Init,
                dim4260JoeKuoD6Init,
                dim4261JoeKuoD6Init,
                dim4262JoeKuoD6Init,
                dim4263JoeKuoD6Init,
                dim4264JoeKuoD6Init,
                dim4265JoeKuoD6Init,
                dim4266JoeKuoD6Init,
                dim4267JoeKuoD6Init,
                dim4268JoeKuoD6Init,
                dim4269JoeKuoD6Init,
                dim4270JoeKuoD6Init,
                dim4271JoeKuoD6Init,
                dim4272JoeKuoD6Init,
                dim4273JoeKuoD6Init,
                dim4274JoeKuoD6Init,
                dim4275JoeKuoD6Init,
                dim4276JoeKuoD6Init,
                dim4277JoeKuoD6Init,
                dim4278JoeKuoD6Init,
                dim4279JoeKuoD6Init,
                dim4280JoeKuoD6Init,
                dim4281JoeKuoD6Init,
                dim4282JoeKuoD6Init,
                dim4283JoeKuoD6Init,
                dim4284JoeKuoD6Init,
                dim4285JoeKuoD6Init,
                dim4286JoeKuoD6Init,
                dim4287JoeKuoD6Init,
                dim4288JoeKuoD6Init,
                dim4289JoeKuoD6Init,
                dim4290JoeKuoD6Init,
                dim4291JoeKuoD6Init,
                dim4292JoeKuoD6Init,
                dim4293JoeKuoD6Init,
                dim4294JoeKuoD6Init,
                dim4295JoeKuoD6Init,
                dim4296JoeKuoD6Init,
                dim4297JoeKuoD6Init,
                dim4298JoeKuoD6Init,
                dim4299JoeKuoD6Init,
                dim4300JoeKuoD6Init,
                dim4301JoeKuoD6Init,
                dim4302JoeKuoD6Init,
                dim4303JoeKuoD6Init,
                dim4304JoeKuoD6Init,
                dim4305JoeKuoD6Init,
                dim4306JoeKuoD6Init,
                dim4307JoeKuoD6Init,
                dim4308JoeKuoD6Init,
                dim4309JoeKuoD6Init,
                dim4310JoeKuoD6Init,
                dim4311JoeKuoD6Init,
                dim4312JoeKuoD6Init,
                dim4313JoeKuoD6Init,
                dim4314JoeKuoD6Init,
                dim4315JoeKuoD6Init,
                dim4316JoeKuoD6Init,
                dim4317JoeKuoD6Init,
                dim4318JoeKuoD6Init,
                dim4319JoeKuoD6Init,
                dim4320JoeKuoD6Init,
                dim4321JoeKuoD6Init,
                dim4322JoeKuoD6Init,
                dim4323JoeKuoD6Init,
                dim4324JoeKuoD6Init,
                dim4325JoeKuoD6Init,
                dim4326JoeKuoD6Init,
                dim4327JoeKuoD6Init,
                dim4328JoeKuoD6Init,
                dim4329JoeKuoD6Init,
                dim4330JoeKuoD6Init,
                dim4331JoeKuoD6Init,
                dim4332JoeKuoD6Init,
                dim4333JoeKuoD6Init,
                dim4334JoeKuoD6Init,
                dim4335JoeKuoD6Init,
                dim4336JoeKuoD6Init,
                dim4337JoeKuoD6Init,
                dim4338JoeKuoD6Init,
                dim4339JoeKuoD6Init,
                dim4340JoeKuoD6Init,
                dim4341JoeKuoD6Init,
                dim4342JoeKuoD6Init,
                dim4343JoeKuoD6Init,
                dim4344JoeKuoD6Init,
                dim4345JoeKuoD6Init,
                dim4346JoeKuoD6Init,
                dim4347JoeKuoD6Init,
                dim4348JoeKuoD6Init,
                dim4349JoeKuoD6Init,
                dim4350JoeKuoD6Init,
                dim4351JoeKuoD6Init,
                dim4352JoeKuoD6Init,
                dim4353JoeKuoD6Init,
                dim4354JoeKuoD6Init,
                dim4355JoeKuoD6Init,
                dim4356JoeKuoD6Init,
                dim4357JoeKuoD6Init,
                dim4358JoeKuoD6Init,
                dim4359JoeKuoD6Init,
                dim4360JoeKuoD6Init,
                dim4361JoeKuoD6Init,
                dim4362JoeKuoD6Init,
                dim4363JoeKuoD6Init,
                dim4364JoeKuoD6Init,
                dim4365JoeKuoD6Init,
                dim4366JoeKuoD6Init,
                dim4367JoeKuoD6Init,
                dim4368JoeKuoD6Init,
                dim4369JoeKuoD6Init,
                dim4370JoeKuoD6Init,
                dim4371JoeKuoD6Init,
                dim4372JoeKuoD6Init,
                dim4373JoeKuoD6Init,
                dim4374JoeKuoD6Init,
                dim4375JoeKuoD6Init,
                dim4376JoeKuoD6Init,
                dim4377JoeKuoD6Init,
                dim4378JoeKuoD6Init,
                dim4379JoeKuoD6Init,
                dim4380JoeKuoD6Init,
                dim4381JoeKuoD6Init,
                dim4382JoeKuoD6Init,
                dim4383JoeKuoD6Init,
                dim4384JoeKuoD6Init,
                dim4385JoeKuoD6Init,
                dim4386JoeKuoD6Init,
                dim4387JoeKuoD6Init,
                dim4388JoeKuoD6Init,
                dim4389JoeKuoD6Init,
                dim4390JoeKuoD6Init,
                dim4391JoeKuoD6Init,
                dim4392JoeKuoD6Init,
                dim4393JoeKuoD6Init,
                dim4394JoeKuoD6Init,
                dim4395JoeKuoD6Init,
                dim4396JoeKuoD6Init,
                dim4397JoeKuoD6Init,
                dim4398JoeKuoD6Init,
                dim4399JoeKuoD6Init,
                dim4400JoeKuoD6Init,
                dim4401JoeKuoD6Init,
                dim4402JoeKuoD6Init,
                dim4403JoeKuoD6Init,
                dim4404JoeKuoD6Init,
                dim4405JoeKuoD6Init,
                dim4406JoeKuoD6Init,
                dim4407JoeKuoD6Init,
                dim4408JoeKuoD6Init,
                dim4409JoeKuoD6Init,
                dim4410JoeKuoD6Init,
                dim4411JoeKuoD6Init,
                dim4412JoeKuoD6Init,
                dim4413JoeKuoD6Init,
                dim4414JoeKuoD6Init,
                dim4415JoeKuoD6Init,
                dim4416JoeKuoD6Init,
                dim4417JoeKuoD6Init,
                dim4418JoeKuoD6Init,
                dim4419JoeKuoD6Init,
                dim4420JoeKuoD6Init,
                dim4421JoeKuoD6Init,
                dim4422JoeKuoD6Init,
                dim4423JoeKuoD6Init,
                dim4424JoeKuoD6Init,
                dim4425JoeKuoD6Init,
                dim4426JoeKuoD6Init,
                dim4427JoeKuoD6Init,
                dim4428JoeKuoD6Init,
                dim4429JoeKuoD6Init,
                dim4430JoeKuoD6Init,
                dim4431JoeKuoD6Init,
                dim4432JoeKuoD6Init,
                dim4433JoeKuoD6Init,
                dim4434JoeKuoD6Init,
                dim4435JoeKuoD6Init,
                dim4436JoeKuoD6Init,
                dim4437JoeKuoD6Init,
                dim4438JoeKuoD6Init,
                dim4439JoeKuoD6Init,
                dim4440JoeKuoD6Init,
                dim4441JoeKuoD6Init,
                dim4442JoeKuoD6Init,
                dim4443JoeKuoD6Init,
                dim4444JoeKuoD6Init,
                dim4445JoeKuoD6Init,
                dim4446JoeKuoD6Init,
                dim4447JoeKuoD6Init,
                dim4448JoeKuoD6Init,
                dim4449JoeKuoD6Init,
                dim4450JoeKuoD6Init,
                dim4451JoeKuoD6Init,
                dim4452JoeKuoD6Init,
                dim4453JoeKuoD6Init,
                dim4454JoeKuoD6Init,
                dim4455JoeKuoD6Init,
                dim4456JoeKuoD6Init,
                dim4457JoeKuoD6Init,
                dim4458JoeKuoD6Init,
                dim4459JoeKuoD6Init,
                dim4460JoeKuoD6Init,
                dim4461JoeKuoD6Init,
                dim4462JoeKuoD6Init,
                dim4463JoeKuoD6Init,
                dim4464JoeKuoD6Init,
                dim4465JoeKuoD6Init,
                dim4466JoeKuoD6Init,
                dim4467JoeKuoD6Init,
                dim4468JoeKuoD6Init,
                dim4469JoeKuoD6Init,
                dim4470JoeKuoD6Init,
                dim4471JoeKuoD6Init,
                dim4472JoeKuoD6Init,
                dim4473JoeKuoD6Init,
                dim4474JoeKuoD6Init,
                dim4475JoeKuoD6Init,
                dim4476JoeKuoD6Init,
                dim4477JoeKuoD6Init,
                dim4478JoeKuoD6Init,
                dim4479JoeKuoD6Init,
                dim4480JoeKuoD6Init,
                dim4481JoeKuoD6Init,
                dim4482JoeKuoD6Init,
                dim4483JoeKuoD6Init,
                dim4484JoeKuoD6Init,
                dim4485JoeKuoD6Init,
                dim4486JoeKuoD6Init,
                dim4487JoeKuoD6Init,
                dim4488JoeKuoD6Init,
                dim4489JoeKuoD6Init,
                dim4490JoeKuoD6Init,
                dim4491JoeKuoD6Init,
                dim4492JoeKuoD6Init,
                dim4493JoeKuoD6Init,
                dim4494JoeKuoD6Init,
                dim4495JoeKuoD6Init,
                dim4496JoeKuoD6Init,
                dim4497JoeKuoD6Init,
                dim4498JoeKuoD6Init,
                dim4499JoeKuoD6Init,
                dim4500JoeKuoD6Init,
                dim4501JoeKuoD6Init,
                dim4502JoeKuoD6Init,
                dim4503JoeKuoD6Init,
                dim4504JoeKuoD6Init,
                dim4505JoeKuoD6Init,
                dim4506JoeKuoD6Init,
                dim4507JoeKuoD6Init,
                dim4508JoeKuoD6Init,
                dim4509JoeKuoD6Init,
                dim4510JoeKuoD6Init,
                dim4511JoeKuoD6Init,
                dim4512JoeKuoD6Init,
                dim4513JoeKuoD6Init,
                dim4514JoeKuoD6Init,
                dim4515JoeKuoD6Init,
                dim4516JoeKuoD6Init,
                dim4517JoeKuoD6Init,
                dim4518JoeKuoD6Init,
                dim4519JoeKuoD6Init,
                dim4520JoeKuoD6Init,
                dim4521JoeKuoD6Init,
                dim4522JoeKuoD6Init,
                dim4523JoeKuoD6Init,
                dim4524JoeKuoD6Init,
                dim4525JoeKuoD6Init,
                dim4526JoeKuoD6Init,
                dim4527JoeKuoD6Init,
                dim4528JoeKuoD6Init,
                dim4529JoeKuoD6Init,
                dim4530JoeKuoD6Init,
                dim4531JoeKuoD6Init,
                dim4532JoeKuoD6Init,
                dim4533JoeKuoD6Init,
                dim4534JoeKuoD6Init,
                dim4535JoeKuoD6Init,
                dim4536JoeKuoD6Init,
                dim4537JoeKuoD6Init,
                dim4538JoeKuoD6Init,
                dim4539JoeKuoD6Init,
                dim4540JoeKuoD6Init,
                dim4541JoeKuoD6Init,
                dim4542JoeKuoD6Init,
                dim4543JoeKuoD6Init,
                dim4544JoeKuoD6Init,
                dim4545JoeKuoD6Init,
                dim4546JoeKuoD6Init,
                dim4547JoeKuoD6Init,
                dim4548JoeKuoD6Init,
                dim4549JoeKuoD6Init,
                dim4550JoeKuoD6Init,
                dim4551JoeKuoD6Init,
                dim4552JoeKuoD6Init,
                dim4553JoeKuoD6Init,
                dim4554JoeKuoD6Init,
                dim4555JoeKuoD6Init,
                dim4556JoeKuoD6Init,
                dim4557JoeKuoD6Init,
                dim4558JoeKuoD6Init,
                dim4559JoeKuoD6Init,
                dim4560JoeKuoD6Init,
                dim4561JoeKuoD6Init,
                dim4562JoeKuoD6Init,
                dim4563JoeKuoD6Init,
                dim4564JoeKuoD6Init,
                dim4565JoeKuoD6Init,
                dim4566JoeKuoD6Init,
                dim4567JoeKuoD6Init,
                dim4568JoeKuoD6Init,
                dim4569JoeKuoD6Init,
                dim4570JoeKuoD6Init,
                dim4571JoeKuoD6Init,
                dim4572JoeKuoD6Init,
                dim4573JoeKuoD6Init,
                dim4574JoeKuoD6Init,
                dim4575JoeKuoD6Init,
                dim4576JoeKuoD6Init,
                dim4577JoeKuoD6Init,
                dim4578JoeKuoD6Init,
                dim4579JoeKuoD6Init,
                dim4580JoeKuoD6Init,
                dim4581JoeKuoD6Init,
                dim4582JoeKuoD6Init,
                dim4583JoeKuoD6Init,
                dim4584JoeKuoD6Init,
                dim4585JoeKuoD6Init,
                dim4586JoeKuoD6Init,
                dim4587JoeKuoD6Init,
                dim4588JoeKuoD6Init,
                dim4589JoeKuoD6Init,
                dim4590JoeKuoD6Init,
                dim4591JoeKuoD6Init,
                dim4592JoeKuoD6Init,
                dim4593JoeKuoD6Init,
                dim4594JoeKuoD6Init,
                dim4595JoeKuoD6Init,
                dim4596JoeKuoD6Init,
                dim4597JoeKuoD6Init,
                dim4598JoeKuoD6Init,
                dim4599JoeKuoD6Init,
                dim4600JoeKuoD6Init,
                dim4601JoeKuoD6Init,
                dim4602JoeKuoD6Init,
                dim4603JoeKuoD6Init,
                dim4604JoeKuoD6Init,
                dim4605JoeKuoD6Init,
                dim4606JoeKuoD6Init,
                dim4607JoeKuoD6Init,
                dim4608JoeKuoD6Init,
                dim4609JoeKuoD6Init,
                dim4610JoeKuoD6Init,
                dim4611JoeKuoD6Init,
                dim4612JoeKuoD6Init,
                dim4613JoeKuoD6Init,
                dim4614JoeKuoD6Init,
                dim4615JoeKuoD6Init,
                dim4616JoeKuoD6Init,
                dim4617JoeKuoD6Init,
                dim4618JoeKuoD6Init,
                dim4619JoeKuoD6Init,
                dim4620JoeKuoD6Init,
                dim4621JoeKuoD6Init,
                dim4622JoeKuoD6Init,
                dim4623JoeKuoD6Init,
                dim4624JoeKuoD6Init,
                dim4625JoeKuoD6Init,
                dim4626JoeKuoD6Init,
                dim4627JoeKuoD6Init,
                dim4628JoeKuoD6Init,
                dim4629JoeKuoD6Init,
                dim4630JoeKuoD6Init,
                dim4631JoeKuoD6Init,
                dim4632JoeKuoD6Init,
                dim4633JoeKuoD6Init,
                dim4634JoeKuoD6Init,
                dim4635JoeKuoD6Init,
                dim4636JoeKuoD6Init,
                dim4637JoeKuoD6Init,
                dim4638JoeKuoD6Init,
                dim4639JoeKuoD6Init,
                dim4640JoeKuoD6Init,
                dim4641JoeKuoD6Init,
                dim4642JoeKuoD6Init,
                dim4643JoeKuoD6Init,
                dim4644JoeKuoD6Init,
                dim4645JoeKuoD6Init,
                dim4646JoeKuoD6Init,
                dim4647JoeKuoD6Init,
                dim4648JoeKuoD6Init,
                dim4649JoeKuoD6Init,
                dim4650JoeKuoD6Init,
                dim4651JoeKuoD6Init,
                dim4652JoeKuoD6Init,
                dim4653JoeKuoD6Init,
                dim4654JoeKuoD6Init,
                dim4655JoeKuoD6Init,
                dim4656JoeKuoD6Init,
                dim4657JoeKuoD6Init,
                dim4658JoeKuoD6Init,
                dim4659JoeKuoD6Init,
                dim4660JoeKuoD6Init,
                dim4661JoeKuoD6Init,
                dim4662JoeKuoD6Init,
                dim4663JoeKuoD6Init,
                dim4664JoeKuoD6Init,
                dim4665JoeKuoD6Init,
                dim4666JoeKuoD6Init,
                dim4667JoeKuoD6Init,
                dim4668JoeKuoD6Init,
                dim4669JoeKuoD6Init,
                dim4670JoeKuoD6Init,
                dim4671JoeKuoD6Init,
                dim4672JoeKuoD6Init,
                dim4673JoeKuoD6Init,
                dim4674JoeKuoD6Init,
                dim4675JoeKuoD6Init,
                dim4676JoeKuoD6Init,
                dim4677JoeKuoD6Init,
                dim4678JoeKuoD6Init,
                dim4679JoeKuoD6Init,
                dim4680JoeKuoD6Init,
                dim4681JoeKuoD6Init,
                dim4682JoeKuoD6Init,
                dim4683JoeKuoD6Init,
                dim4684JoeKuoD6Init,
                dim4685JoeKuoD6Init,
                dim4686JoeKuoD6Init,
                dim4687JoeKuoD6Init,
                dim4688JoeKuoD6Init,
                dim4689JoeKuoD6Init,
                dim4690JoeKuoD6Init,
                dim4691JoeKuoD6Init,
                dim4692JoeKuoD6Init,
                dim4693JoeKuoD6Init,
                dim4694JoeKuoD6Init,
                dim4695JoeKuoD6Init,
                dim4696JoeKuoD6Init,
                dim4697JoeKuoD6Init,
                dim4698JoeKuoD6Init,
                dim4699JoeKuoD6Init,
                dim4700JoeKuoD6Init,
                dim4701JoeKuoD6Init,
                dim4702JoeKuoD6Init,
                dim4703JoeKuoD6Init,
                dim4704JoeKuoD6Init,
                dim4705JoeKuoD6Init,
                dim4706JoeKuoD6Init,
                dim4707JoeKuoD6Init,
                dim4708JoeKuoD6Init,
                dim4709JoeKuoD6Init,
                dim4710JoeKuoD6Init,
                dim4711JoeKuoD6Init,
                dim4712JoeKuoD6Init,
                dim4713JoeKuoD6Init,
                dim4714JoeKuoD6Init,
                dim4715JoeKuoD6Init,
                dim4716JoeKuoD6Init,
                dim4717JoeKuoD6Init,
                dim4718JoeKuoD6Init,
                dim4719JoeKuoD6Init,
                dim4720JoeKuoD6Init,
                dim4721JoeKuoD6Init,
                dim4722JoeKuoD6Init,
                dim4723JoeKuoD6Init,
                dim4724JoeKuoD6Init,
                dim4725JoeKuoD6Init,
                dim4726JoeKuoD6Init,
                dim4727JoeKuoD6Init,
                dim4728JoeKuoD6Init,
                dim4729JoeKuoD6Init,
                dim4730JoeKuoD6Init,
                dim4731JoeKuoD6Init,
                dim4732JoeKuoD6Init,
                dim4733JoeKuoD6Init,
                dim4734JoeKuoD6Init,
                dim4735JoeKuoD6Init,
                dim4736JoeKuoD6Init,
                dim4737JoeKuoD6Init,
                dim4738JoeKuoD6Init,
                dim4739JoeKuoD6Init,
                dim4740JoeKuoD6Init,
                dim4741JoeKuoD6Init,
                dim4742JoeKuoD6Init,
                dim4743JoeKuoD6Init,
                dim4744JoeKuoD6Init,
                dim4745JoeKuoD6Init,
                dim4746JoeKuoD6Init,
                dim4747JoeKuoD6Init,
                dim4748JoeKuoD6Init,
                dim4749JoeKuoD6Init,
                dim4750JoeKuoD6Init,
                dim4751JoeKuoD6Init,
                dim4752JoeKuoD6Init,
                dim4753JoeKuoD6Init,
                dim4754JoeKuoD6Init,
                dim4755JoeKuoD6Init,
                dim4756JoeKuoD6Init,
                dim4757JoeKuoD6Init,
                dim4758JoeKuoD6Init,
                dim4759JoeKuoD6Init,
                dim4760JoeKuoD6Init,
                dim4761JoeKuoD6Init,
                dim4762JoeKuoD6Init,
                dim4763JoeKuoD6Init,
                dim4764JoeKuoD6Init,
                dim4765JoeKuoD6Init,
                dim4766JoeKuoD6Init,
                dim4767JoeKuoD6Init,
                dim4768JoeKuoD6Init,
                dim4769JoeKuoD6Init,
                dim4770JoeKuoD6Init,
                dim4771JoeKuoD6Init,
                dim4772JoeKuoD6Init,
                dim4773JoeKuoD6Init,
                dim4774JoeKuoD6Init,
                dim4775JoeKuoD6Init,
                dim4776JoeKuoD6Init,
                dim4777JoeKuoD6Init,
                dim4778JoeKuoD6Init,
                dim4779JoeKuoD6Init,
                dim4780JoeKuoD6Init,
                dim4781JoeKuoD6Init,
                dim4782JoeKuoD6Init,
                dim4783JoeKuoD6Init,
                dim4784JoeKuoD6Init,
                dim4785JoeKuoD6Init,
                dim4786JoeKuoD6Init,
                dim4787JoeKuoD6Init,
                dim4788JoeKuoD6Init,
                dim4789JoeKuoD6Init,
                dim4790JoeKuoD6Init,
                dim4791JoeKuoD6Init,
                dim4792JoeKuoD6Init,
                dim4793JoeKuoD6Init,
                dim4794JoeKuoD6Init,
                dim4795JoeKuoD6Init,
                dim4796JoeKuoD6Init,
                dim4797JoeKuoD6Init,
                dim4798JoeKuoD6Init,
                dim4799JoeKuoD6Init,
                dim4800JoeKuoD6Init,
                dim4801JoeKuoD6Init,
                dim4802JoeKuoD6Init,
                dim4803JoeKuoD6Init,
                dim4804JoeKuoD6Init,
                dim4805JoeKuoD6Init,
                dim4806JoeKuoD6Init,
                dim4807JoeKuoD6Init,
                dim4808JoeKuoD6Init,
                dim4809JoeKuoD6Init,
                dim4810JoeKuoD6Init,
                dim4811JoeKuoD6Init,
                dim4812JoeKuoD6Init,
                dim4813JoeKuoD6Init,
                dim4814JoeKuoD6Init,
                dim4815JoeKuoD6Init,
                dim4816JoeKuoD6Init,
                dim4817JoeKuoD6Init,
                dim4818JoeKuoD6Init,
                dim4819JoeKuoD6Init,
                dim4820JoeKuoD6Init,
                dim4821JoeKuoD6Init,
                dim4822JoeKuoD6Init,
                dim4823JoeKuoD6Init,
                dim4824JoeKuoD6Init,
                dim4825JoeKuoD6Init,
                dim4826JoeKuoD6Init,
                dim4827JoeKuoD6Init,
                dim4828JoeKuoD6Init,
                dim4829JoeKuoD6Init,
                dim4830JoeKuoD6Init,
                dim4831JoeKuoD6Init,
                dim4832JoeKuoD6Init,
                dim4833JoeKuoD6Init,
                dim4834JoeKuoD6Init,
                dim4835JoeKuoD6Init,
                dim4836JoeKuoD6Init,
                dim4837JoeKuoD6Init,
                dim4838JoeKuoD6Init,
                dim4839JoeKuoD6Init,
                dim4840JoeKuoD6Init,
                dim4841JoeKuoD6Init,
                dim4842JoeKuoD6Init,
                dim4843JoeKuoD6Init,
                dim4844JoeKuoD6Init,
                dim4845JoeKuoD6Init,
                dim4846JoeKuoD6Init,
                dim4847JoeKuoD6Init,
                dim4848JoeKuoD6Init,
                dim4849JoeKuoD6Init,
                dim4850JoeKuoD6Init,
                dim4851JoeKuoD6Init,
                dim4852JoeKuoD6Init,
                dim4853JoeKuoD6Init,
                dim4854JoeKuoD6Init,
                dim4855JoeKuoD6Init,
                dim4856JoeKuoD6Init,
                dim4857JoeKuoD6Init,
                dim4858JoeKuoD6Init,
                dim4859JoeKuoD6Init,
                dim4860JoeKuoD6Init,
                dim4861JoeKuoD6Init,
                dim4862JoeKuoD6Init,
                dim4863JoeKuoD6Init,
                dim4864JoeKuoD6Init,
                dim4865JoeKuoD6Init,
                dim4866JoeKuoD6Init,
                dim4867JoeKuoD6Init,
                dim4868JoeKuoD6Init,
                dim4869JoeKuoD6Init,
                dim4870JoeKuoD6Init,
                dim4871JoeKuoD6Init,
                dim4872JoeKuoD6Init,
                dim4873JoeKuoD6Init,
                dim4874JoeKuoD6Init,
                dim4875JoeKuoD6Init,
                dim4876JoeKuoD6Init,
                dim4877JoeKuoD6Init,
                dim4878JoeKuoD6Init,
                dim4879JoeKuoD6Init,
                dim4880JoeKuoD6Init,
                dim4881JoeKuoD6Init,
                dim4882JoeKuoD6Init,
                dim4883JoeKuoD6Init,
                dim4884JoeKuoD6Init,
                dim4885JoeKuoD6Init,
                dim4886JoeKuoD6Init,
                dim4887JoeKuoD6Init,
                dim4888JoeKuoD6Init,
                dim4889JoeKuoD6Init,
                dim4890JoeKuoD6Init,
                dim4891JoeKuoD6Init,
                dim4892JoeKuoD6Init,
                dim4893JoeKuoD6Init,
                dim4894JoeKuoD6Init,
                dim4895JoeKuoD6Init,
                dim4896JoeKuoD6Init,
                dim4897JoeKuoD6Init,
                dim4898JoeKuoD6Init,
                dim4899JoeKuoD6Init,
                dim4900JoeKuoD6Init,
                dim4901JoeKuoD6Init,
                dim4902JoeKuoD6Init,
                dim4903JoeKuoD6Init,
                dim4904JoeKuoD6Init,
                dim4905JoeKuoD6Init,
                dim4906JoeKuoD6Init,
                dim4907JoeKuoD6Init,
                dim4908JoeKuoD6Init,
                dim4909JoeKuoD6Init,
                dim4910JoeKuoD6Init,
                dim4911JoeKuoD6Init,
                dim4912JoeKuoD6Init,
                dim4913JoeKuoD6Init,
                dim4914JoeKuoD6Init,
                dim4915JoeKuoD6Init,
                dim4916JoeKuoD6Init,
                dim4917JoeKuoD6Init,
                dim4918JoeKuoD6Init,
                dim4919JoeKuoD6Init,
                dim4920JoeKuoD6Init,
                dim4921JoeKuoD6Init,
                dim4922JoeKuoD6Init,
                dim4923JoeKuoD6Init,
                dim4924JoeKuoD6Init,
                dim4925JoeKuoD6Init,
                dim4926JoeKuoD6Init,
                dim4927JoeKuoD6Init,
                dim4928JoeKuoD6Init,
                dim4929JoeKuoD6Init,
                dim4930JoeKuoD6Init,
                dim4931JoeKuoD6Init,
                dim4932JoeKuoD6Init,
                dim4933JoeKuoD6Init,
                dim4934JoeKuoD6Init,
                dim4935JoeKuoD6Init,
                dim4936JoeKuoD6Init,
                dim4937JoeKuoD6Init,
                dim4938JoeKuoD6Init,
                dim4939JoeKuoD6Init,
                dim4940JoeKuoD6Init,
                dim4941JoeKuoD6Init,
                dim4942JoeKuoD6Init,
                dim4943JoeKuoD6Init,
                dim4944JoeKuoD6Init,
                dim4945JoeKuoD6Init,
                dim4946JoeKuoD6Init,
                dim4947JoeKuoD6Init,
                dim4948JoeKuoD6Init,
                dim4949JoeKuoD6Init,
                dim4950JoeKuoD6Init,
                dim4951JoeKuoD6Init,
                dim4952JoeKuoD6Init,
                dim4953JoeKuoD6Init,
                dim4954JoeKuoD6Init,
                dim4955JoeKuoD6Init,
                dim4956JoeKuoD6Init,
                dim4957JoeKuoD6Init,
                dim4958JoeKuoD6Init,
                dim4959JoeKuoD6Init,
                dim4960JoeKuoD6Init,
                dim4961JoeKuoD6Init,
                dim4962JoeKuoD6Init,
                dim4963JoeKuoD6Init,
                dim4964JoeKuoD6Init,
                dim4965JoeKuoD6Init,
                dim4966JoeKuoD6Init,
                dim4967JoeKuoD6Init,
                dim4968JoeKuoD6Init,
                dim4969JoeKuoD6Init,
                dim4970JoeKuoD6Init,
                dim4971JoeKuoD6Init,
                dim4972JoeKuoD6Init,
                dim4973JoeKuoD6Init,
                dim4974JoeKuoD6Init,
                dim4975JoeKuoD6Init,
                dim4976JoeKuoD6Init,
                dim4977JoeKuoD6Init,
                dim4978JoeKuoD6Init,
                dim4979JoeKuoD6Init,
                dim4980JoeKuoD6Init,
                dim4981JoeKuoD6Init,
                dim4982JoeKuoD6Init,
                dim4983JoeKuoD6Init,
                dim4984JoeKuoD6Init,
                dim4985JoeKuoD6Init,
                dim4986JoeKuoD6Init,
                dim4987JoeKuoD6Init,
                dim4988JoeKuoD6Init,
                dim4989JoeKuoD6Init,
                dim4990JoeKuoD6Init,
                dim4991JoeKuoD6Init,
                dim4992JoeKuoD6Init,
                dim4993JoeKuoD6Init,
                dim4994JoeKuoD6Init,
                dim4995JoeKuoD6Init,
                dim4996JoeKuoD6Init,
                dim4997JoeKuoD6Init,
                dim4998JoeKuoD6Init,
                dim4999JoeKuoD6Init,
                dim5000JoeKuoD6Init,
                dim5001JoeKuoD6Init,
                dim5002JoeKuoD6Init,
                dim5003JoeKuoD6Init,
                dim5004JoeKuoD6Init,
                dim5005JoeKuoD6Init,
                dim5006JoeKuoD6Init,
                dim5007JoeKuoD6Init,
                dim5008JoeKuoD6Init,
                dim5009JoeKuoD6Init,
                dim5010JoeKuoD6Init,
                dim5011JoeKuoD6Init,
                dim5012JoeKuoD6Init,
                dim5013JoeKuoD6Init,
                dim5014JoeKuoD6Init,
                dim5015JoeKuoD6Init,
                dim5016JoeKuoD6Init,
                dim5017JoeKuoD6Init,
                dim5018JoeKuoD6Init,
                dim5019JoeKuoD6Init,
                dim5020JoeKuoD6Init,
                dim5021JoeKuoD6Init,
                dim5022JoeKuoD6Init,
                dim5023JoeKuoD6Init,
                dim5024JoeKuoD6Init,
                dim5025JoeKuoD6Init,
                dim5026JoeKuoD6Init,
                dim5027JoeKuoD6Init,
                dim5028JoeKuoD6Init,
                dim5029JoeKuoD6Init,
                dim5030JoeKuoD6Init,
                dim5031JoeKuoD6Init,
                dim5032JoeKuoD6Init,
                dim5033JoeKuoD6Init,
                dim5034JoeKuoD6Init,
                dim5035JoeKuoD6Init,
                dim5036JoeKuoD6Init,
                dim5037JoeKuoD6Init,
                dim5038JoeKuoD6Init,
                dim5039JoeKuoD6Init,
                dim5040JoeKuoD6Init,
                dim5041JoeKuoD6Init,
                dim5042JoeKuoD6Init,
                dim5043JoeKuoD6Init,
                dim5044JoeKuoD6Init,
                dim5045JoeKuoD6Init,
                dim5046JoeKuoD6Init,
                dim5047JoeKuoD6Init,
                dim5048JoeKuoD6Init,
                dim5049JoeKuoD6Init,
                dim5050JoeKuoD6Init,
                dim5051JoeKuoD6Init,
                dim5052JoeKuoD6Init,
                dim5053JoeKuoD6Init,
                dim5054JoeKuoD6Init,
                dim5055JoeKuoD6Init,
                dim5056JoeKuoD6Init,
                dim5057JoeKuoD6Init,
                dim5058JoeKuoD6Init,
                dim5059JoeKuoD6Init,
                dim5060JoeKuoD6Init,
                dim5061JoeKuoD6Init,
                dim5062JoeKuoD6Init,
                dim5063JoeKuoD6Init,
                dim5064JoeKuoD6Init,
                dim5065JoeKuoD6Init,
                dim5066JoeKuoD6Init,
                dim5067JoeKuoD6Init,
                dim5068JoeKuoD6Init,
                dim5069JoeKuoD6Init,
                dim5070JoeKuoD6Init,
                dim5071JoeKuoD6Init,
                dim5072JoeKuoD6Init,
                dim5073JoeKuoD6Init,
                dim5074JoeKuoD6Init,
                dim5075JoeKuoD6Init,
                dim5076JoeKuoD6Init,
                dim5077JoeKuoD6Init,
                dim5078JoeKuoD6Init,
                dim5079JoeKuoD6Init,
                dim5080JoeKuoD6Init,
                dim5081JoeKuoD6Init,
                dim5082JoeKuoD6Init,
                dim5083JoeKuoD6Init,
                dim5084JoeKuoD6Init,
                dim5085JoeKuoD6Init,
                dim5086JoeKuoD6Init,
                dim5087JoeKuoD6Init,
                dim5088JoeKuoD6Init,
                dim5089JoeKuoD6Init,
                dim5090JoeKuoD6Init,
                dim5091JoeKuoD6Init,
                dim5092JoeKuoD6Init,
                dim5093JoeKuoD6Init,
                dim5094JoeKuoD6Init,
                dim5095JoeKuoD6Init,
                dim5096JoeKuoD6Init,
                dim5097JoeKuoD6Init,
                dim5098JoeKuoD6Init,
                dim5099JoeKuoD6Init,
                dim5100JoeKuoD6Init,
                dim5101JoeKuoD6Init,
                dim5102JoeKuoD6Init,
                dim5103JoeKuoD6Init,
                dim5104JoeKuoD6Init,
                dim5105JoeKuoD6Init,
                dim5106JoeKuoD6Init,
                dim5107JoeKuoD6Init,
                dim5108JoeKuoD6Init,
                dim5109JoeKuoD6Init,
                dim5110JoeKuoD6Init,
                dim5111JoeKuoD6Init,
                dim5112JoeKuoD6Init,
                dim5113JoeKuoD6Init,
                dim5114JoeKuoD6Init,
                dim5115JoeKuoD6Init,
                dim5116JoeKuoD6Init,
                dim5117JoeKuoD6Init,
                dim5118JoeKuoD6Init,
                dim5119JoeKuoD6Init,
                dim5120JoeKuoD6Init,
                dim5121JoeKuoD6Init,
                dim5122JoeKuoD6Init,
                dim5123JoeKuoD6Init,
                dim5124JoeKuoD6Init,
                dim5125JoeKuoD6Init,
                dim5126JoeKuoD6Init,
                dim5127JoeKuoD6Init,
                dim5128JoeKuoD6Init,
                dim5129JoeKuoD6Init,
                dim5130JoeKuoD6Init,
                dim5131JoeKuoD6Init,
                dim5132JoeKuoD6Init,
                dim5133JoeKuoD6Init,
                dim5134JoeKuoD6Init,
                dim5135JoeKuoD6Init,
                dim5136JoeKuoD6Init,
                dim5137JoeKuoD6Init,
                dim5138JoeKuoD6Init,
                dim5139JoeKuoD6Init,
                dim5140JoeKuoD6Init,
                dim5141JoeKuoD6Init,
                dim5142JoeKuoD6Init,
                dim5143JoeKuoD6Init,
                dim5144JoeKuoD6Init,
                dim5145JoeKuoD6Init,
                dim5146JoeKuoD6Init,
                dim5147JoeKuoD6Init,
                dim5148JoeKuoD6Init,
                dim5149JoeKuoD6Init,
                dim5150JoeKuoD6Init,
                dim5151JoeKuoD6Init,
                dim5152JoeKuoD6Init,
                dim5153JoeKuoD6Init,
                dim5154JoeKuoD6Init,
                dim5155JoeKuoD6Init,
                dim5156JoeKuoD6Init,
                dim5157JoeKuoD6Init,
                dim5158JoeKuoD6Init,
                dim5159JoeKuoD6Init,
                dim5160JoeKuoD6Init,
                dim5161JoeKuoD6Init,
                dim5162JoeKuoD6Init,
                dim5163JoeKuoD6Init,
                dim5164JoeKuoD6Init,
                dim5165JoeKuoD6Init,
                dim5166JoeKuoD6Init,
                dim5167JoeKuoD6Init,
                dim5168JoeKuoD6Init,
                dim5169JoeKuoD6Init,
                dim5170JoeKuoD6Init,
                dim5171JoeKuoD6Init,
                dim5172JoeKuoD6Init,
                dim5173JoeKuoD6Init,
                dim5174JoeKuoD6Init,
                dim5175JoeKuoD6Init,
                dim5176JoeKuoD6Init,
                dim5177JoeKuoD6Init,
                dim5178JoeKuoD6Init,
                dim5179JoeKuoD6Init,
                dim5180JoeKuoD6Init,
                dim5181JoeKuoD6Init,
                dim5182JoeKuoD6Init,
                dim5183JoeKuoD6Init,
                dim5184JoeKuoD6Init,
                dim5185JoeKuoD6Init,
                dim5186JoeKuoD6Init,
                dim5187JoeKuoD6Init,
                dim5188JoeKuoD6Init,
                dim5189JoeKuoD6Init,
                dim5190JoeKuoD6Init,
                dim5191JoeKuoD6Init,
                dim5192JoeKuoD6Init,
                dim5193JoeKuoD6Init,
                dim5194JoeKuoD6Init,
                dim5195JoeKuoD6Init,
                dim5196JoeKuoD6Init,
                dim5197JoeKuoD6Init,
                dim5198JoeKuoD6Init,
                dim5199JoeKuoD6Init,
                dim5200JoeKuoD6Init,
                dim5201JoeKuoD6Init,
                dim5202JoeKuoD6Init,
                dim5203JoeKuoD6Init,
                dim5204JoeKuoD6Init,
                dim5205JoeKuoD6Init,
                dim5206JoeKuoD6Init,
                dim5207JoeKuoD6Init,
                dim5208JoeKuoD6Init,
                dim5209JoeKuoD6Init,
                dim5210JoeKuoD6Init,
                dim5211JoeKuoD6Init,
                dim5212JoeKuoD6Init,
                dim5213JoeKuoD6Init,
                dim5214JoeKuoD6Init,
                dim5215JoeKuoD6Init,
                dim5216JoeKuoD6Init,
                dim5217JoeKuoD6Init,
                dim5218JoeKuoD6Init,
                dim5219JoeKuoD6Init,
                dim5220JoeKuoD6Init,
                dim5221JoeKuoD6Init,
                dim5222JoeKuoD6Init,
                dim5223JoeKuoD6Init,
                dim5224JoeKuoD6Init,
                dim5225JoeKuoD6Init,
                dim5226JoeKuoD6Init,
                dim5227JoeKuoD6Init,
                dim5228JoeKuoD6Init,
                dim5229JoeKuoD6Init,
                dim5230JoeKuoD6Init,
                dim5231JoeKuoD6Init,
                dim5232JoeKuoD6Init,
                dim5233JoeKuoD6Init,
                dim5234JoeKuoD6Init,
                dim5235JoeKuoD6Init,
                dim5236JoeKuoD6Init,
                dim5237JoeKuoD6Init,
                dim5238JoeKuoD6Init,
                dim5239JoeKuoD6Init,
                dim5240JoeKuoD6Init,
                dim5241JoeKuoD6Init,
                dim5242JoeKuoD6Init,
                dim5243JoeKuoD6Init,
                dim5244JoeKuoD6Init,
                dim5245JoeKuoD6Init,
                dim5246JoeKuoD6Init,
                dim5247JoeKuoD6Init,
                dim5248JoeKuoD6Init,
                dim5249JoeKuoD6Init,
                dim5250JoeKuoD6Init,
                dim5251JoeKuoD6Init,
                dim5252JoeKuoD6Init,
                dim5253JoeKuoD6Init,
                dim5254JoeKuoD6Init,
                dim5255JoeKuoD6Init,
                dim5256JoeKuoD6Init,
                dim5257JoeKuoD6Init,
                dim5258JoeKuoD6Init,
                dim5259JoeKuoD6Init,
                dim5260JoeKuoD6Init,
                dim5261JoeKuoD6Init,
                dim5262JoeKuoD6Init,
                dim5263JoeKuoD6Init,
                dim5264JoeKuoD6Init,
                dim5265JoeKuoD6Init,
                dim5266JoeKuoD6Init,
                dim5267JoeKuoD6Init,
                dim5268JoeKuoD6Init,
                dim5269JoeKuoD6Init,
                dim5270JoeKuoD6Init,
                dim5271JoeKuoD6Init,
                dim5272JoeKuoD6Init,
                dim5273JoeKuoD6Init,
                dim5274JoeKuoD6Init,
                dim5275JoeKuoD6Init,
                dim5276JoeKuoD6Init,
                dim5277JoeKuoD6Init,
                dim5278JoeKuoD6Init,
                dim5279JoeKuoD6Init,
                dim5280JoeKuoD6Init,
                dim5281JoeKuoD6Init,
                dim5282JoeKuoD6Init,
                dim5283JoeKuoD6Init,
                dim5284JoeKuoD6Init,
                dim5285JoeKuoD6Init,
                dim5286JoeKuoD6Init,
                dim5287JoeKuoD6Init,
                dim5288JoeKuoD6Init,
                dim5289JoeKuoD6Init,
                dim5290JoeKuoD6Init,
                dim5291JoeKuoD6Init,
                dim5292JoeKuoD6Init,
                dim5293JoeKuoD6Init,
                dim5294JoeKuoD6Init,
                dim5295JoeKuoD6Init,
                dim5296JoeKuoD6Init,
                dim5297JoeKuoD6Init,
                dim5298JoeKuoD6Init,
                dim5299JoeKuoD6Init,
                dim5300JoeKuoD6Init,
                dim5301JoeKuoD6Init,
                dim5302JoeKuoD6Init,
                dim5303JoeKuoD6Init,
                dim5304JoeKuoD6Init,
                dim5305JoeKuoD6Init,
                dim5306JoeKuoD6Init,
                dim5307JoeKuoD6Init,
                dim5308JoeKuoD6Init,
                dim5309JoeKuoD6Init,
                dim5310JoeKuoD6Init,
                dim5311JoeKuoD6Init,
                dim5312JoeKuoD6Init,
                dim5313JoeKuoD6Init,
                dim5314JoeKuoD6Init,
                dim5315JoeKuoD6Init,
                dim5316JoeKuoD6Init,
                dim5317JoeKuoD6Init,
                dim5318JoeKuoD6Init,
                dim5319JoeKuoD6Init,
                dim5320JoeKuoD6Init,
                dim5321JoeKuoD6Init,
                dim5322JoeKuoD6Init,
                dim5323JoeKuoD6Init,
                dim5324JoeKuoD6Init,
                dim5325JoeKuoD6Init,
                dim5326JoeKuoD6Init,
                dim5327JoeKuoD6Init,
                dim5328JoeKuoD6Init,
                dim5329JoeKuoD6Init,
                dim5330JoeKuoD6Init,
                dim5331JoeKuoD6Init,
                dim5332JoeKuoD6Init,
                dim5333JoeKuoD6Init,
                dim5334JoeKuoD6Init,
                dim5335JoeKuoD6Init,
                dim5336JoeKuoD6Init,
                dim5337JoeKuoD6Init,
                dim5338JoeKuoD6Init,
                dim5339JoeKuoD6Init,
                dim5340JoeKuoD6Init,
                dim5341JoeKuoD6Init,
                dim5342JoeKuoD6Init,
                dim5343JoeKuoD6Init,
                dim5344JoeKuoD6Init,
                dim5345JoeKuoD6Init,
                dim5346JoeKuoD6Init,
                dim5347JoeKuoD6Init,
                dim5348JoeKuoD6Init,
                dim5349JoeKuoD6Init,
                dim5350JoeKuoD6Init,
                dim5351JoeKuoD6Init,
                dim5352JoeKuoD6Init,
                dim5353JoeKuoD6Init,
                dim5354JoeKuoD6Init,
                dim5355JoeKuoD6Init,
                dim5356JoeKuoD6Init,
                dim5357JoeKuoD6Init,
                dim5358JoeKuoD6Init,
                dim5359JoeKuoD6Init,
                dim5360JoeKuoD6Init,
                dim5361JoeKuoD6Init,
                dim5362JoeKuoD6Init,
                dim5363JoeKuoD6Init,
                dim5364JoeKuoD6Init,
                dim5365JoeKuoD6Init,
                dim5366JoeKuoD6Init,
                dim5367JoeKuoD6Init,
                dim5368JoeKuoD6Init,
                dim5369JoeKuoD6Init,
                dim5370JoeKuoD6Init,
                dim5371JoeKuoD6Init,
                dim5372JoeKuoD6Init,
                dim5373JoeKuoD6Init,
                dim5374JoeKuoD6Init,
                dim5375JoeKuoD6Init,
                dim5376JoeKuoD6Init,
                dim5377JoeKuoD6Init,
                dim5378JoeKuoD6Init,
                dim5379JoeKuoD6Init,
                dim5380JoeKuoD6Init,
                dim5381JoeKuoD6Init,
                dim5382JoeKuoD6Init,
                dim5383JoeKuoD6Init,
                dim5384JoeKuoD6Init,
                dim5385JoeKuoD6Init,
                dim5386JoeKuoD6Init,
                dim5387JoeKuoD6Init,
                dim5388JoeKuoD6Init,
                dim5389JoeKuoD6Init,
                dim5390JoeKuoD6Init,
                dim5391JoeKuoD6Init,
                dim5392JoeKuoD6Init,
                dim5393JoeKuoD6Init,
                dim5394JoeKuoD6Init,
                dim5395JoeKuoD6Init,
                dim5396JoeKuoD6Init,
                dim5397JoeKuoD6Init,
                dim5398JoeKuoD6Init,
                dim5399JoeKuoD6Init,
                dim5400JoeKuoD6Init,
                dim5401JoeKuoD6Init,
                dim5402JoeKuoD6Init,
                dim5403JoeKuoD6Init,
                dim5404JoeKuoD6Init,
                dim5405JoeKuoD6Init,
                dim5406JoeKuoD6Init,
                dim5407JoeKuoD6Init,
                dim5408JoeKuoD6Init,
                dim5409JoeKuoD6Init,
                dim5410JoeKuoD6Init,
                dim5411JoeKuoD6Init,
                dim5412JoeKuoD6Init,
                dim5413JoeKuoD6Init,
                dim5414JoeKuoD6Init,
                dim5415JoeKuoD6Init,
                dim5416JoeKuoD6Init,
                dim5417JoeKuoD6Init,
                dim5418JoeKuoD6Init,
                dim5419JoeKuoD6Init,
                dim5420JoeKuoD6Init,
                dim5421JoeKuoD6Init,
                dim5422JoeKuoD6Init,
                dim5423JoeKuoD6Init,
                dim5424JoeKuoD6Init,
                dim5425JoeKuoD6Init,
                dim5426JoeKuoD6Init,
                dim5427JoeKuoD6Init,
                dim5428JoeKuoD6Init,
                dim5429JoeKuoD6Init,
                dim5430JoeKuoD6Init,
                dim5431JoeKuoD6Init,
                dim5432JoeKuoD6Init,
                dim5433JoeKuoD6Init,
                dim5434JoeKuoD6Init,
                dim5435JoeKuoD6Init,
                dim5436JoeKuoD6Init,
                dim5437JoeKuoD6Init,
                dim5438JoeKuoD6Init,
                dim5439JoeKuoD6Init,
                dim5440JoeKuoD6Init,
                dim5441JoeKuoD6Init,
                dim5442JoeKuoD6Init,
                dim5443JoeKuoD6Init,
                dim5444JoeKuoD6Init,
                dim5445JoeKuoD6Init,
                dim5446JoeKuoD6Init,
                dim5447JoeKuoD6Init,
                dim5448JoeKuoD6Init,
                dim5449JoeKuoD6Init,
                dim5450JoeKuoD6Init,
                dim5451JoeKuoD6Init,
                dim5452JoeKuoD6Init,
                dim5453JoeKuoD6Init,
                dim5454JoeKuoD6Init,
                dim5455JoeKuoD6Init,
                dim5456JoeKuoD6Init,
                dim5457JoeKuoD6Init,
                dim5458JoeKuoD6Init,
                dim5459JoeKuoD6Init,
                dim5460JoeKuoD6Init,
                dim5461JoeKuoD6Init,
                dim5462JoeKuoD6Init,
                dim5463JoeKuoD6Init,
                dim5464JoeKuoD6Init,
                dim5465JoeKuoD6Init,
                dim5466JoeKuoD6Init,
                dim5467JoeKuoD6Init,
                dim5468JoeKuoD6Init,
                dim5469JoeKuoD6Init,
                dim5470JoeKuoD6Init,
                dim5471JoeKuoD6Init,
                dim5472JoeKuoD6Init,
                dim5473JoeKuoD6Init,
                dim5474JoeKuoD6Init,
                dim5475JoeKuoD6Init,
                dim5476JoeKuoD6Init,
                dim5477JoeKuoD6Init,
                dim5478JoeKuoD6Init,
                dim5479JoeKuoD6Init,
                dim5480JoeKuoD6Init,
                dim5481JoeKuoD6Init,
                dim5482JoeKuoD6Init,
                dim5483JoeKuoD6Init,
                dim5484JoeKuoD6Init,
                dim5485JoeKuoD6Init,
                dim5486JoeKuoD6Init,
                dim5487JoeKuoD6Init,
                dim5488JoeKuoD6Init,
                dim5489JoeKuoD6Init,
                dim5490JoeKuoD6Init,
                dim5491JoeKuoD6Init,
                dim5492JoeKuoD6Init,
                dim5493JoeKuoD6Init,
                dim5494JoeKuoD6Init,
                dim5495JoeKuoD6Init,
                dim5496JoeKuoD6Init,
                dim5497JoeKuoD6Init,
                dim5498JoeKuoD6Init,
                dim5499JoeKuoD6Init,
                dim5500JoeKuoD6Init,
                dim5501JoeKuoD6Init,
                dim5502JoeKuoD6Init,
                dim5503JoeKuoD6Init,
                dim5504JoeKuoD6Init,
                dim5505JoeKuoD6Init,
                dim5506JoeKuoD6Init,
                dim5507JoeKuoD6Init,
                dim5508JoeKuoD6Init,
                dim5509JoeKuoD6Init,
                dim5510JoeKuoD6Init,
                dim5511JoeKuoD6Init,
                dim5512JoeKuoD6Init,
                dim5513JoeKuoD6Init,
                dim5514JoeKuoD6Init,
                dim5515JoeKuoD6Init,
                dim5516JoeKuoD6Init,
                dim5517JoeKuoD6Init,
                dim5518JoeKuoD6Init,
                dim5519JoeKuoD6Init,
                dim5520JoeKuoD6Init,
                dim5521JoeKuoD6Init,
                dim5522JoeKuoD6Init,
                dim5523JoeKuoD6Init,
                dim5524JoeKuoD6Init,
                dim5525JoeKuoD6Init,
                dim5526JoeKuoD6Init,
                dim5527JoeKuoD6Init,
                dim5528JoeKuoD6Init,
                dim5529JoeKuoD6Init,
                dim5530JoeKuoD6Init,
                dim5531JoeKuoD6Init,
                dim5532JoeKuoD6Init,
                dim5533JoeKuoD6Init,
                dim5534JoeKuoD6Init,
                dim5535JoeKuoD6Init,
                dim5536JoeKuoD6Init,
                dim5537JoeKuoD6Init,
                dim5538JoeKuoD6Init,
                dim5539JoeKuoD6Init,
                dim5540JoeKuoD6Init,
                dim5541JoeKuoD6Init,
                dim5542JoeKuoD6Init,
                dim5543JoeKuoD6Init,
                dim5544JoeKuoD6Init,
                dim5545JoeKuoD6Init,
                dim5546JoeKuoD6Init,
                dim5547JoeKuoD6Init,
                dim5548JoeKuoD6Init,
                dim5549JoeKuoD6Init,
                dim5550JoeKuoD6Init,
                dim5551JoeKuoD6Init,
                dim5552JoeKuoD6Init,
                dim5553JoeKuoD6Init,
                dim5554JoeKuoD6Init,
                dim5555JoeKuoD6Init,
                dim5556JoeKuoD6Init,
                dim5557JoeKuoD6Init,
                dim5558JoeKuoD6Init,
                dim5559JoeKuoD6Init,
                dim5560JoeKuoD6Init,
                dim5561JoeKuoD6Init,
                dim5562JoeKuoD6Init,
                dim5563JoeKuoD6Init,
                dim5564JoeKuoD6Init,
                dim5565JoeKuoD6Init,
                dim5566JoeKuoD6Init,
                dim5567JoeKuoD6Init,
                dim5568JoeKuoD6Init,
                dim5569JoeKuoD6Init,
                dim5570JoeKuoD6Init,
                dim5571JoeKuoD6Init,
                dim5572JoeKuoD6Init,
                dim5573JoeKuoD6Init,
                dim5574JoeKuoD6Init,
                dim5575JoeKuoD6Init,
                dim5576JoeKuoD6Init,
                dim5577JoeKuoD6Init,
                dim5578JoeKuoD6Init,
                dim5579JoeKuoD6Init,
                dim5580JoeKuoD6Init,
                dim5581JoeKuoD6Init,
                dim5582JoeKuoD6Init,
                dim5583JoeKuoD6Init,
                dim5584JoeKuoD6Init,
                dim5585JoeKuoD6Init,
                dim5586JoeKuoD6Init,
                dim5587JoeKuoD6Init,
                dim5588JoeKuoD6Init,
                dim5589JoeKuoD6Init,
                dim5590JoeKuoD6Init,
                dim5591JoeKuoD6Init,
                dim5592JoeKuoD6Init,
                dim5593JoeKuoD6Init,
                dim5594JoeKuoD6Init,
                dim5595JoeKuoD6Init,
                dim5596JoeKuoD6Init,
                dim5597JoeKuoD6Init,
                dim5598JoeKuoD6Init,
                dim5599JoeKuoD6Init,
                dim5600JoeKuoD6Init,
                dim5601JoeKuoD6Init,
                dim5602JoeKuoD6Init,
                dim5603JoeKuoD6Init,
                dim5604JoeKuoD6Init,
                dim5605JoeKuoD6Init,
                dim5606JoeKuoD6Init,
                dim5607JoeKuoD6Init,
                dim5608JoeKuoD6Init,
                dim5609JoeKuoD6Init,
                dim5610JoeKuoD6Init,
                dim5611JoeKuoD6Init,
                dim5612JoeKuoD6Init,
                dim5613JoeKuoD6Init,
                dim5614JoeKuoD6Init,
                dim5615JoeKuoD6Init,
                dim5616JoeKuoD6Init,
                dim5617JoeKuoD6Init,
                dim5618JoeKuoD6Init,
                dim5619JoeKuoD6Init,
                dim5620JoeKuoD6Init,
                dim5621JoeKuoD6Init,
                dim5622JoeKuoD6Init,
                dim5623JoeKuoD6Init,
                dim5624JoeKuoD6Init,
                dim5625JoeKuoD6Init,
                dim5626JoeKuoD6Init,
                dim5627JoeKuoD6Init,
                dim5628JoeKuoD6Init,
                dim5629JoeKuoD6Init,
                dim5630JoeKuoD6Init,
                dim5631JoeKuoD6Init,
                dim5632JoeKuoD6Init,
                dim5633JoeKuoD6Init,
                dim5634JoeKuoD6Init,
                dim5635JoeKuoD6Init,
                dim5636JoeKuoD6Init,
                dim5637JoeKuoD6Init,
                dim5638JoeKuoD6Init,
                dim5639JoeKuoD6Init,
                dim5640JoeKuoD6Init,
                dim5641JoeKuoD6Init,
                dim5642JoeKuoD6Init,
                dim5643JoeKuoD6Init,
                dim5644JoeKuoD6Init,
                dim5645JoeKuoD6Init,
                dim5646JoeKuoD6Init,
                dim5647JoeKuoD6Init,
                dim5648JoeKuoD6Init,
                dim5649JoeKuoD6Init,
                dim5650JoeKuoD6Init,
                dim5651JoeKuoD6Init,
                dim5652JoeKuoD6Init,
                dim5653JoeKuoD6Init,
                dim5654JoeKuoD6Init,
                dim5655JoeKuoD6Init,
                dim5656JoeKuoD6Init,
                dim5657JoeKuoD6Init,
                dim5658JoeKuoD6Init,
                dim5659JoeKuoD6Init,
                dim5660JoeKuoD6Init,
                dim5661JoeKuoD6Init,
                dim5662JoeKuoD6Init,
                dim5663JoeKuoD6Init,
                dim5664JoeKuoD6Init,
                dim5665JoeKuoD6Init,
                dim5666JoeKuoD6Init,
                dim5667JoeKuoD6Init,
                dim5668JoeKuoD6Init,
                dim5669JoeKuoD6Init,
                dim5670JoeKuoD6Init,
                dim5671JoeKuoD6Init,
                dim5672JoeKuoD6Init,
                dim5673JoeKuoD6Init,
                dim5674JoeKuoD6Init,
                dim5675JoeKuoD6Init,
                dim5676JoeKuoD6Init,
                dim5677JoeKuoD6Init,
                dim5678JoeKuoD6Init,
                dim5679JoeKuoD6Init,
                dim5680JoeKuoD6Init,
                dim5681JoeKuoD6Init,
                dim5682JoeKuoD6Init,
                dim5683JoeKuoD6Init,
                dim5684JoeKuoD6Init,
                dim5685JoeKuoD6Init,
                dim5686JoeKuoD6Init,
                dim5687JoeKuoD6Init,
                dim5688JoeKuoD6Init,
                dim5689JoeKuoD6Init,
                dim5690JoeKuoD6Init,
                dim5691JoeKuoD6Init,
                dim5692JoeKuoD6Init,
                dim5693JoeKuoD6Init,
                dim5694JoeKuoD6Init,
                dim5695JoeKuoD6Init,
                dim5696JoeKuoD6Init,
                dim5697JoeKuoD6Init,
                dim5698JoeKuoD6Init,
                dim5699JoeKuoD6Init,
                dim5700JoeKuoD6Init,
                dim5701JoeKuoD6Init,
                dim5702JoeKuoD6Init,
                dim5703JoeKuoD6Init,
                dim5704JoeKuoD6Init,
                dim5705JoeKuoD6Init,
                dim5706JoeKuoD6Init,
                dim5707JoeKuoD6Init,
                dim5708JoeKuoD6Init,
                dim5709JoeKuoD6Init,
                dim5710JoeKuoD6Init,
                dim5711JoeKuoD6Init,
                dim5712JoeKuoD6Init,
                dim5713JoeKuoD6Init,
                dim5714JoeKuoD6Init,
                dim5715JoeKuoD6Init,
                dim5716JoeKuoD6Init,
                dim5717JoeKuoD6Init,
                dim5718JoeKuoD6Init,
                dim5719JoeKuoD6Init,
                dim5720JoeKuoD6Init,
                dim5721JoeKuoD6Init,
                dim5722JoeKuoD6Init,
                dim5723JoeKuoD6Init,
                dim5724JoeKuoD6Init,
                dim5725JoeKuoD6Init,
                dim5726JoeKuoD6Init,
                dim5727JoeKuoD6Init,
                dim5728JoeKuoD6Init,
                dim5729JoeKuoD6Init,
                dim5730JoeKuoD6Init,
                dim5731JoeKuoD6Init,
                dim5732JoeKuoD6Init,
                dim5733JoeKuoD6Init,
                dim5734JoeKuoD6Init,
                dim5735JoeKuoD6Init,
                dim5736JoeKuoD6Init,
                dim5737JoeKuoD6Init,
                dim5738JoeKuoD6Init,
                dim5739JoeKuoD6Init,
                dim5740JoeKuoD6Init,
                dim5741JoeKuoD6Init,
                dim5742JoeKuoD6Init,
                dim5743JoeKuoD6Init,
                dim5744JoeKuoD6Init,
                dim5745JoeKuoD6Init,
                dim5746JoeKuoD6Init,
                dim5747JoeKuoD6Init,
                dim5748JoeKuoD6Init,
                dim5749JoeKuoD6Init,
                dim5750JoeKuoD6Init,
                dim5751JoeKuoD6Init,
                dim5752JoeKuoD6Init,
                dim5753JoeKuoD6Init,
                dim5754JoeKuoD6Init,
                dim5755JoeKuoD6Init,
                dim5756JoeKuoD6Init,
                dim5757JoeKuoD6Init,
                dim5758JoeKuoD6Init,
                dim5759JoeKuoD6Init,
                dim5760JoeKuoD6Init,
                dim5761JoeKuoD6Init,
                dim5762JoeKuoD6Init,
                dim5763JoeKuoD6Init,
                dim5764JoeKuoD6Init,
                dim5765JoeKuoD6Init,
                dim5766JoeKuoD6Init,
                dim5767JoeKuoD6Init,
                dim5768JoeKuoD6Init,
                dim5769JoeKuoD6Init,
                dim5770JoeKuoD6Init,
                dim5771JoeKuoD6Init,
                dim5772JoeKuoD6Init,
                dim5773JoeKuoD6Init,
                dim5774JoeKuoD6Init,
                dim5775JoeKuoD6Init,
                dim5776JoeKuoD6Init,
                dim5777JoeKuoD6Init,
                dim5778JoeKuoD6Init,
                dim5779JoeKuoD6Init,
                dim5780JoeKuoD6Init,
                dim5781JoeKuoD6Init,
                dim5782JoeKuoD6Init,
                dim5783JoeKuoD6Init,
                dim5784JoeKuoD6Init,
                dim5785JoeKuoD6Init,
                dim5786JoeKuoD6Init,
                dim5787JoeKuoD6Init,
                dim5788JoeKuoD6Init,
                dim5789JoeKuoD6Init,
                dim5790JoeKuoD6Init,
                dim5791JoeKuoD6Init,
                dim5792JoeKuoD6Init,
                dim5793JoeKuoD6Init,
                dim5794JoeKuoD6Init,
                dim5795JoeKuoD6Init,
                dim5796JoeKuoD6Init,
                dim5797JoeKuoD6Init,
                dim5798JoeKuoD6Init,
                dim5799JoeKuoD6Init,
                dim5800JoeKuoD6Init,
                dim5801JoeKuoD6Init,
                dim5802JoeKuoD6Init,
                dim5803JoeKuoD6Init,
                dim5804JoeKuoD6Init,
                dim5805JoeKuoD6Init,
                dim5806JoeKuoD6Init,
                dim5807JoeKuoD6Init,
                dim5808JoeKuoD6Init,
                dim5809JoeKuoD6Init,
                dim5810JoeKuoD6Init,
                dim5811JoeKuoD6Init,
                dim5812JoeKuoD6Init,
                dim5813JoeKuoD6Init,
                dim5814JoeKuoD6Init,
                dim5815JoeKuoD6Init,
                dim5816JoeKuoD6Init,
                dim5817JoeKuoD6Init,
                dim5818JoeKuoD6Init,
                dim5819JoeKuoD6Init,
                dim5820JoeKuoD6Init,
                dim5821JoeKuoD6Init,
                dim5822JoeKuoD6Init,
                dim5823JoeKuoD6Init,
                dim5824JoeKuoD6Init,
                dim5825JoeKuoD6Init,
                dim5826JoeKuoD6Init,
                dim5827JoeKuoD6Init,
                dim5828JoeKuoD6Init,
                dim5829JoeKuoD6Init,
                dim5830JoeKuoD6Init,
                dim5831JoeKuoD6Init,
                dim5832JoeKuoD6Init,
                dim5833JoeKuoD6Init,
                dim5834JoeKuoD6Init,
                dim5835JoeKuoD6Init,
                dim5836JoeKuoD6Init,
                dim5837JoeKuoD6Init,
                dim5838JoeKuoD6Init,
                dim5839JoeKuoD6Init,
                dim5840JoeKuoD6Init,
                dim5841JoeKuoD6Init,
                dim5842JoeKuoD6Init,
                dim5843JoeKuoD6Init,
                dim5844JoeKuoD6Init,
                dim5845JoeKuoD6Init,
                dim5846JoeKuoD6Init,
                dim5847JoeKuoD6Init,
                dim5848JoeKuoD6Init,
                dim5849JoeKuoD6Init,
                dim5850JoeKuoD6Init,
                dim5851JoeKuoD6Init,
                dim5852JoeKuoD6Init,
                dim5853JoeKuoD6Init,
                dim5854JoeKuoD6Init,
                dim5855JoeKuoD6Init,
                dim5856JoeKuoD6Init,
                dim5857JoeKuoD6Init,
                dim5858JoeKuoD6Init,
                dim5859JoeKuoD6Init,
                dim5860JoeKuoD6Init,
                dim5861JoeKuoD6Init,
                dim5862JoeKuoD6Init,
                dim5863JoeKuoD6Init,
                dim5864JoeKuoD6Init,
                dim5865JoeKuoD6Init,
                dim5866JoeKuoD6Init,
                dim5867JoeKuoD6Init,
                dim5868JoeKuoD6Init,
                dim5869JoeKuoD6Init,
                dim5870JoeKuoD6Init,
                dim5871JoeKuoD6Init,
                dim5872JoeKuoD6Init,
                dim5873JoeKuoD6Init,
                dim5874JoeKuoD6Init,
                dim5875JoeKuoD6Init,
                dim5876JoeKuoD6Init,
                dim5877JoeKuoD6Init,
                dim5878JoeKuoD6Init,
                dim5879JoeKuoD6Init,
                dim5880JoeKuoD6Init,
                dim5881JoeKuoD6Init,
                dim5882JoeKuoD6Init,
                dim5883JoeKuoD6Init,
                dim5884JoeKuoD6Init,
                dim5885JoeKuoD6Init,
                dim5886JoeKuoD6Init,
                dim5887JoeKuoD6Init,
                dim5888JoeKuoD6Init,
                dim5889JoeKuoD6Init,
                dim5890JoeKuoD6Init,
                dim5891JoeKuoD6Init,
                dim5892JoeKuoD6Init,
                dim5893JoeKuoD6Init,
                dim5894JoeKuoD6Init,
                dim5895JoeKuoD6Init,
                dim5896JoeKuoD6Init,
                dim5897JoeKuoD6Init,
                dim5898JoeKuoD6Init,
                dim5899JoeKuoD6Init,
                dim5900JoeKuoD6Init,
                dim5901JoeKuoD6Init,
                dim5902JoeKuoD6Init,
                dim5903JoeKuoD6Init,
                dim5904JoeKuoD6Init,
                dim5905JoeKuoD6Init,
                dim5906JoeKuoD6Init,
                dim5907JoeKuoD6Init,
                dim5908JoeKuoD6Init,
                dim5909JoeKuoD6Init,
                dim5910JoeKuoD6Init,
                dim5911JoeKuoD6Init,
                dim5912JoeKuoD6Init,
                dim5913JoeKuoD6Init,
                dim5914JoeKuoD6Init,
                dim5915JoeKuoD6Init,
                dim5916JoeKuoD6Init,
                dim5917JoeKuoD6Init,
                dim5918JoeKuoD6Init,
                dim5919JoeKuoD6Init,
                dim5920JoeKuoD6Init,
                dim5921JoeKuoD6Init,
                dim5922JoeKuoD6Init,
                dim5923JoeKuoD6Init,
                dim5924JoeKuoD6Init,
                dim5925JoeKuoD6Init,
                dim5926JoeKuoD6Init,
                dim5927JoeKuoD6Init,
                dim5928JoeKuoD6Init,
                dim5929JoeKuoD6Init,
                dim5930JoeKuoD6Init,
                dim5931JoeKuoD6Init,
                dim5932JoeKuoD6Init,
                dim5933JoeKuoD6Init,
                dim5934JoeKuoD6Init,
                dim5935JoeKuoD6Init,
                dim5936JoeKuoD6Init,
                dim5937JoeKuoD6Init,
                dim5938JoeKuoD6Init,
                dim5939JoeKuoD6Init,
                dim5940JoeKuoD6Init,
                dim5941JoeKuoD6Init,
                dim5942JoeKuoD6Init,
                dim5943JoeKuoD6Init,
                dim5944JoeKuoD6Init,
                dim5945JoeKuoD6Init,
                dim5946JoeKuoD6Init,
                dim5947JoeKuoD6Init,
                dim5948JoeKuoD6Init,
                dim5949JoeKuoD6Init,
                dim5950JoeKuoD6Init,
                dim5951JoeKuoD6Init,
                dim5952JoeKuoD6Init,
                dim5953JoeKuoD6Init,
                dim5954JoeKuoD6Init,
                dim5955JoeKuoD6Init,
                dim5956JoeKuoD6Init,
                dim5957JoeKuoD6Init,
                dim5958JoeKuoD6Init,
                dim5959JoeKuoD6Init,
                dim5960JoeKuoD6Init,
                dim5961JoeKuoD6Init,
                dim5962JoeKuoD6Init,
                dim5963JoeKuoD6Init,
                dim5964JoeKuoD6Init,
                dim5965JoeKuoD6Init,
                dim5966JoeKuoD6Init,
                dim5967JoeKuoD6Init,
                dim5968JoeKuoD6Init,
                dim5969JoeKuoD6Init,
                dim5970JoeKuoD6Init,
                dim5971JoeKuoD6Init,
                dim5972JoeKuoD6Init,
                dim5973JoeKuoD6Init,
                dim5974JoeKuoD6Init,
                dim5975JoeKuoD6Init,
                dim5976JoeKuoD6Init,
                dim5977JoeKuoD6Init,
                dim5978JoeKuoD6Init,
                dim5979JoeKuoD6Init,
                dim5980JoeKuoD6Init,
                dim5981JoeKuoD6Init,
                dim5982JoeKuoD6Init,
                dim5983JoeKuoD6Init,
                dim5984JoeKuoD6Init,
                dim5985JoeKuoD6Init,
                dim5986JoeKuoD6Init,
                dim5987JoeKuoD6Init,
                dim5988JoeKuoD6Init,
                dim5989JoeKuoD6Init,
                dim5990JoeKuoD6Init,
                dim5991JoeKuoD6Init,
                dim5992JoeKuoD6Init,
                dim5993JoeKuoD6Init,
                dim5994JoeKuoD6Init,
                dim5995JoeKuoD6Init,
                dim5996JoeKuoD6Init,
                dim5997JoeKuoD6Init,
                dim5998JoeKuoD6Init,
                dim5999JoeKuoD6Init,
                dim6000JoeKuoD6Init,
                dim6001JoeKuoD6Init,
                dim6002JoeKuoD6Init,
                dim6003JoeKuoD6Init,
                dim6004JoeKuoD6Init,
                dim6005JoeKuoD6Init,
                dim6006JoeKuoD6Init,
                dim6007JoeKuoD6Init,
                dim6008JoeKuoD6Init,
                dim6009JoeKuoD6Init,
                dim6010JoeKuoD6Init,
                dim6011JoeKuoD6Init,
                dim6012JoeKuoD6Init,
                dim6013JoeKuoD6Init,
                dim6014JoeKuoD6Init,
                dim6015JoeKuoD6Init,
                dim6016JoeKuoD6Init,
                dim6017JoeKuoD6Init,
                dim6018JoeKuoD6Init,
                dim6019JoeKuoD6Init,
                dim6020JoeKuoD6Init,
                dim6021JoeKuoD6Init,
                dim6022JoeKuoD6Init,
                dim6023JoeKuoD6Init,
                dim6024JoeKuoD6Init,
                dim6025JoeKuoD6Init,
                dim6026JoeKuoD6Init,
                dim6027JoeKuoD6Init,
                dim6028JoeKuoD6Init,
                dim6029JoeKuoD6Init,
                dim6030JoeKuoD6Init,
                dim6031JoeKuoD6Init,
                dim6032JoeKuoD6Init,
                dim6033JoeKuoD6Init,
                dim6034JoeKuoD6Init,
                dim6035JoeKuoD6Init,
                dim6036JoeKuoD6Init,
                dim6037JoeKuoD6Init,
                dim6038JoeKuoD6Init,
                dim6039JoeKuoD6Init,
                dim6040JoeKuoD6Init,
                dim6041JoeKuoD6Init,
                dim6042JoeKuoD6Init,
                dim6043JoeKuoD6Init,
                dim6044JoeKuoD6Init,
                dim6045JoeKuoD6Init,
                dim6046JoeKuoD6Init,
                dim6047JoeKuoD6Init,
                dim6048JoeKuoD6Init,
                dim6049JoeKuoD6Init,
                dim6050JoeKuoD6Init,
                dim6051JoeKuoD6Init,
                dim6052JoeKuoD6Init,
                dim6053JoeKuoD6Init,
                dim6054JoeKuoD6Init,
                dim6055JoeKuoD6Init,
                dim6056JoeKuoD6Init,
                dim6057JoeKuoD6Init,
                dim6058JoeKuoD6Init,
                dim6059JoeKuoD6Init,
                dim6060JoeKuoD6Init,
                dim6061JoeKuoD6Init,
                dim6062JoeKuoD6Init,
                dim6063JoeKuoD6Init,
                dim6064JoeKuoD6Init,
                dim6065JoeKuoD6Init,
                dim6066JoeKuoD6Init,
                dim6067JoeKuoD6Init,
                dim6068JoeKuoD6Init,
                dim6069JoeKuoD6Init,
                dim6070JoeKuoD6Init,
                dim6071JoeKuoD6Init,
                dim6072JoeKuoD6Init,
                dim6073JoeKuoD6Init,
                dim6074JoeKuoD6Init,
                dim6075JoeKuoD6Init,
                dim6076JoeKuoD6Init,
                dim6077JoeKuoD6Init,
                dim6078JoeKuoD6Init,
                dim6079JoeKuoD6Init,
                dim6080JoeKuoD6Init,
                dim6081JoeKuoD6Init,
                dim6082JoeKuoD6Init,
                dim6083JoeKuoD6Init,
                dim6084JoeKuoD6Init,
                dim6085JoeKuoD6Init,
                dim6086JoeKuoD6Init,
                dim6087JoeKuoD6Init,
                dim6088JoeKuoD6Init,
                dim6089JoeKuoD6Init,
                dim6090JoeKuoD6Init,
                dim6091JoeKuoD6Init,
                dim6092JoeKuoD6Init,
                dim6093JoeKuoD6Init,
                dim6094JoeKuoD6Init,
                dim6095JoeKuoD6Init,
                dim6096JoeKuoD6Init,
                dim6097JoeKuoD6Init,
                dim6098JoeKuoD6Init,
                dim6099JoeKuoD6Init,
                dim6100JoeKuoD6Init,
                dim6101JoeKuoD6Init,
                dim6102JoeKuoD6Init,
                dim6103JoeKuoD6Init,
                dim6104JoeKuoD6Init,
                dim6105JoeKuoD6Init,
                dim6106JoeKuoD6Init,
                dim6107JoeKuoD6Init,
                dim6108JoeKuoD6Init,
                dim6109JoeKuoD6Init,
                dim6110JoeKuoD6Init,
                dim6111JoeKuoD6Init,
                dim6112JoeKuoD6Init,
                dim6113JoeKuoD6Init,
                dim6114JoeKuoD6Init,
                dim6115JoeKuoD6Init,
                dim6116JoeKuoD6Init,
                dim6117JoeKuoD6Init,
                dim6118JoeKuoD6Init,
                dim6119JoeKuoD6Init,
                dim6120JoeKuoD6Init,
                dim6121JoeKuoD6Init,
                dim6122JoeKuoD6Init,
                dim6123JoeKuoD6Init,
                dim6124JoeKuoD6Init,
                dim6125JoeKuoD6Init,
                dim6126JoeKuoD6Init,
                dim6127JoeKuoD6Init,
                dim6128JoeKuoD6Init,
                dim6129JoeKuoD6Init,
                dim6130JoeKuoD6Init,
                dim6131JoeKuoD6Init,
                dim6132JoeKuoD6Init,
                dim6133JoeKuoD6Init,
                dim6134JoeKuoD6Init,
                dim6135JoeKuoD6Init,
                dim6136JoeKuoD6Init,
                dim6137JoeKuoD6Init,
                dim6138JoeKuoD6Init,
                dim6139JoeKuoD6Init,
                dim6140JoeKuoD6Init,
                dim6141JoeKuoD6Init,
                dim6142JoeKuoD6Init,
                dim6143JoeKuoD6Init,
                dim6144JoeKuoD6Init,
                dim6145JoeKuoD6Init,
                dim6146JoeKuoD6Init,
                dim6147JoeKuoD6Init,
                dim6148JoeKuoD6Init,
                dim6149JoeKuoD6Init,
                dim6150JoeKuoD6Init,
                dim6151JoeKuoD6Init,
                dim6152JoeKuoD6Init,
                dim6153JoeKuoD6Init,
                dim6154JoeKuoD6Init,
                dim6155JoeKuoD6Init,
                dim6156JoeKuoD6Init,
                dim6157JoeKuoD6Init,
                dim6158JoeKuoD6Init,
                dim6159JoeKuoD6Init,
                dim6160JoeKuoD6Init,
                dim6161JoeKuoD6Init,
                dim6162JoeKuoD6Init,
                dim6163JoeKuoD6Init,
                dim6164JoeKuoD6Init,
                dim6165JoeKuoD6Init,
                dim6166JoeKuoD6Init,
                dim6167JoeKuoD6Init,
                dim6168JoeKuoD6Init,
                dim6169JoeKuoD6Init,
                dim6170JoeKuoD6Init,
                dim6171JoeKuoD6Init,
                dim6172JoeKuoD6Init,
                dim6173JoeKuoD6Init,
                dim6174JoeKuoD6Init,
                dim6175JoeKuoD6Init,
                dim6176JoeKuoD6Init,
                dim6177JoeKuoD6Init,
                dim6178JoeKuoD6Init,
                dim6179JoeKuoD6Init,
                dim6180JoeKuoD6Init,
                dim6181JoeKuoD6Init,
                dim6182JoeKuoD6Init,
                dim6183JoeKuoD6Init,
                dim6184JoeKuoD6Init,
                dim6185JoeKuoD6Init,
                dim6186JoeKuoD6Init,
                dim6187JoeKuoD6Init,
                dim6188JoeKuoD6Init,
                dim6189JoeKuoD6Init,
                dim6190JoeKuoD6Init,
                dim6191JoeKuoD6Init,
                dim6192JoeKuoD6Init,
                dim6193JoeKuoD6Init,
                dim6194JoeKuoD6Init,
                dim6195JoeKuoD6Init,
                dim6196JoeKuoD6Init,
                dim6197JoeKuoD6Init,
                dim6198JoeKuoD6Init,
                dim6199JoeKuoD6Init,
                dim6200JoeKuoD6Init,
                dim6201JoeKuoD6Init,
                dim6202JoeKuoD6Init,
                dim6203JoeKuoD6Init,
                dim6204JoeKuoD6Init,
                dim6205JoeKuoD6Init,
                dim6206JoeKuoD6Init,
                dim6207JoeKuoD6Init,
                dim6208JoeKuoD6Init,
                dim6209JoeKuoD6Init,
                dim6210JoeKuoD6Init,
                dim6211JoeKuoD6Init,
                dim6212JoeKuoD6Init,
                dim6213JoeKuoD6Init,
                dim6214JoeKuoD6Init,
                dim6215JoeKuoD6Init,
                dim6216JoeKuoD6Init,
                dim6217JoeKuoD6Init,
                dim6218JoeKuoD6Init,
                dim6219JoeKuoD6Init,
                dim6220JoeKuoD6Init,
                dim6221JoeKuoD6Init,
                dim6222JoeKuoD6Init,
                dim6223JoeKuoD6Init,
                dim6224JoeKuoD6Init,
                dim6225JoeKuoD6Init,
                dim6226JoeKuoD6Init,
                dim6227JoeKuoD6Init,
                dim6228JoeKuoD6Init,
                dim6229JoeKuoD6Init,
                dim6230JoeKuoD6Init,
                dim6231JoeKuoD6Init,
                dim6232JoeKuoD6Init,
                dim6233JoeKuoD6Init,
                dim6234JoeKuoD6Init,
                dim6235JoeKuoD6Init,
                dim6236JoeKuoD6Init,
                dim6237JoeKuoD6Init,
                dim6238JoeKuoD6Init,
                dim6239JoeKuoD6Init,
                dim6240JoeKuoD6Init,
                dim6241JoeKuoD6Init,
                dim6242JoeKuoD6Init,
                dim6243JoeKuoD6Init,
                dim6244JoeKuoD6Init,
                dim6245JoeKuoD6Init,
                dim6246JoeKuoD6Init,
                dim6247JoeKuoD6Init,
                dim6248JoeKuoD6Init,
                dim6249JoeKuoD6Init,
                dim6250JoeKuoD6Init,
                dim6251JoeKuoD6Init,
                dim6252JoeKuoD6Init,
                dim6253JoeKuoD6Init,
                dim6254JoeKuoD6Init,
                dim6255JoeKuoD6Init,
                dim6256JoeKuoD6Init,
                dim6257JoeKuoD6Init,
                dim6258JoeKuoD6Init,
                dim6259JoeKuoD6Init,
                dim6260JoeKuoD6Init,
                dim6261JoeKuoD6Init,
                dim6262JoeKuoD6Init,
                dim6263JoeKuoD6Init,
                dim6264JoeKuoD6Init,
                dim6265JoeKuoD6Init,
                dim6266JoeKuoD6Init,
                dim6267JoeKuoD6Init,
                dim6268JoeKuoD6Init,
                dim6269JoeKuoD6Init,
                dim6270JoeKuoD6Init,
                dim6271JoeKuoD6Init,
                dim6272JoeKuoD6Init,
                dim6273JoeKuoD6Init,
                dim6274JoeKuoD6Init,
                dim6275JoeKuoD6Init,
                dim6276JoeKuoD6Init,
                dim6277JoeKuoD6Init,
                dim6278JoeKuoD6Init,
                dim6279JoeKuoD6Init,
                dim6280JoeKuoD6Init,
                dim6281JoeKuoD6Init,
                dim6282JoeKuoD6Init,
                dim6283JoeKuoD6Init,
                dim6284JoeKuoD6Init,
                dim6285JoeKuoD6Init,
                dim6286JoeKuoD6Init,
                dim6287JoeKuoD6Init,
                dim6288JoeKuoD6Init,
                dim6289JoeKuoD6Init,
                dim6290JoeKuoD6Init,
                dim6291JoeKuoD6Init,
                dim6292JoeKuoD6Init,
                dim6293JoeKuoD6Init,
                dim6294JoeKuoD6Init,
                dim6295JoeKuoD6Init,
                dim6296JoeKuoD6Init,
                dim6297JoeKuoD6Init,
                dim6298JoeKuoD6Init,
                dim6299JoeKuoD6Init,
                dim6300JoeKuoD6Init,
                dim6301JoeKuoD6Init,
                dim6302JoeKuoD6Init,
                dim6303JoeKuoD6Init,
                dim6304JoeKuoD6Init,
                dim6305JoeKuoD6Init,
                dim6306JoeKuoD6Init,
                dim6307JoeKuoD6Init,
                dim6308JoeKuoD6Init,
                dim6309JoeKuoD6Init,
                dim6310JoeKuoD6Init,
                dim6311JoeKuoD6Init,
                dim6312JoeKuoD6Init,
                dim6313JoeKuoD6Init,
                dim6314JoeKuoD6Init,
                dim6315JoeKuoD6Init,
                dim6316JoeKuoD6Init,
                dim6317JoeKuoD6Init,
                dim6318JoeKuoD6Init,
                dim6319JoeKuoD6Init,
                dim6320JoeKuoD6Init,
                dim6321JoeKuoD6Init,
                dim6322JoeKuoD6Init,
                dim6323JoeKuoD6Init,
                dim6324JoeKuoD6Init,
                dim6325JoeKuoD6Init,
                dim6326JoeKuoD6Init,
                dim6327JoeKuoD6Init,
                dim6328JoeKuoD6Init,
                dim6329JoeKuoD6Init,
                dim6330JoeKuoD6Init,
                dim6331JoeKuoD6Init,
                dim6332JoeKuoD6Init,
                dim6333JoeKuoD6Init,
                dim6334JoeKuoD6Init,
                dim6335JoeKuoD6Init,
                dim6336JoeKuoD6Init,
                dim6337JoeKuoD6Init,
                dim6338JoeKuoD6Init,
                dim6339JoeKuoD6Init,
                dim6340JoeKuoD6Init,
                dim6341JoeKuoD6Init,
                dim6342JoeKuoD6Init,
                dim6343JoeKuoD6Init,
                dim6344JoeKuoD6Init,
                dim6345JoeKuoD6Init,
                dim6346JoeKuoD6Init,
                dim6347JoeKuoD6Init,
                dim6348JoeKuoD6Init,
                dim6349JoeKuoD6Init,
                dim6350JoeKuoD6Init,
                dim6351JoeKuoD6Init,
                dim6352JoeKuoD6Init,
                dim6353JoeKuoD6Init,
                dim6354JoeKuoD6Init,
                dim6355JoeKuoD6Init,
                dim6356JoeKuoD6Init,
                dim6357JoeKuoD6Init,
                dim6358JoeKuoD6Init,
                dim6359JoeKuoD6Init,
                dim6360JoeKuoD6Init,
                dim6361JoeKuoD6Init,
                dim6362JoeKuoD6Init,
                dim6363JoeKuoD6Init,
                dim6364JoeKuoD6Init,
                dim6365JoeKuoD6Init,
                dim6366JoeKuoD6Init,
                dim6367JoeKuoD6Init,
                dim6368JoeKuoD6Init,
                dim6369JoeKuoD6Init,
                dim6370JoeKuoD6Init,
                dim6371JoeKuoD6Init,
                dim6372JoeKuoD6Init,
                dim6373JoeKuoD6Init,
                dim6374JoeKuoD6Init,
                dim6375JoeKuoD6Init,
                dim6376JoeKuoD6Init,
                dim6377JoeKuoD6Init,
                dim6378JoeKuoD6Init,
                dim6379JoeKuoD6Init,
                dim6380JoeKuoD6Init,
                dim6381JoeKuoD6Init,
                dim6382JoeKuoD6Init,
                dim6383JoeKuoD6Init,
                dim6384JoeKuoD6Init,
                dim6385JoeKuoD6Init,
                dim6386JoeKuoD6Init,
                dim6387JoeKuoD6Init,
                dim6388JoeKuoD6Init,
                dim6389JoeKuoD6Init,
                dim6390JoeKuoD6Init,
                dim6391JoeKuoD6Init,
                dim6392JoeKuoD6Init,
                dim6393JoeKuoD6Init,
                dim6394JoeKuoD6Init,
                dim6395JoeKuoD6Init,
                dim6396JoeKuoD6Init,
                dim6397JoeKuoD6Init,
                dim6398JoeKuoD6Init,
                dim6399JoeKuoD6Init,
                dim6400JoeKuoD6Init,
                dim6401JoeKuoD6Init,
                dim6402JoeKuoD6Init,
                dim6403JoeKuoD6Init,
                dim6404JoeKuoD6Init,
                dim6405JoeKuoD6Init,
                dim6406JoeKuoD6Init,
                dim6407JoeKuoD6Init,
                dim6408JoeKuoD6Init,
                dim6409JoeKuoD6Init,
                dim6410JoeKuoD6Init,
                dim6411JoeKuoD6Init,
                dim6412JoeKuoD6Init,
                dim6413JoeKuoD6Init,
                dim6414JoeKuoD6Init,
                dim6415JoeKuoD6Init,
                dim6416JoeKuoD6Init,
                dim6417JoeKuoD6Init,
                dim6418JoeKuoD6Init,
                dim6419JoeKuoD6Init,
                dim6420JoeKuoD6Init,
                dim6421JoeKuoD6Init,
                dim6422JoeKuoD6Init,
                dim6423JoeKuoD6Init,
                dim6424JoeKuoD6Init,
                dim6425JoeKuoD6Init,
                dim6426JoeKuoD6Init,
                dim6427JoeKuoD6Init,
                dim6428JoeKuoD6Init,
                dim6429JoeKuoD6Init,
                dim6430JoeKuoD6Init,
                dim6431JoeKuoD6Init,
                dim6432JoeKuoD6Init,
                dim6433JoeKuoD6Init,
                dim6434JoeKuoD6Init,
                dim6435JoeKuoD6Init,
                dim6436JoeKuoD6Init,
                dim6437JoeKuoD6Init,
                dim6438JoeKuoD6Init,
                dim6439JoeKuoD6Init,
                dim6440JoeKuoD6Init,
                dim6441JoeKuoD6Init,
                dim6442JoeKuoD6Init,
                dim6443JoeKuoD6Init,
                dim6444JoeKuoD6Init,
                dim6445JoeKuoD6Init,
                dim6446JoeKuoD6Init,
                dim6447JoeKuoD6Init,
                dim6448JoeKuoD6Init,
                dim6449JoeKuoD6Init,
                dim6450JoeKuoD6Init,
                dim6451JoeKuoD6Init,
                dim6452JoeKuoD6Init,
                dim6453JoeKuoD6Init,
                dim6454JoeKuoD6Init,
                dim6455JoeKuoD6Init,
                dim6456JoeKuoD6Init,
                dim6457JoeKuoD6Init,
                dim6458JoeKuoD6Init,
                dim6459JoeKuoD6Init,
                dim6460JoeKuoD6Init,
                dim6461JoeKuoD6Init,
                dim6462JoeKuoD6Init,
                dim6463JoeKuoD6Init,
                dim6464JoeKuoD6Init,
                dim6465JoeKuoD6Init,
                dim6466JoeKuoD6Init,
                dim6467JoeKuoD6Init,
                dim6468JoeKuoD6Init,
                dim6469JoeKuoD6Init,
                dim6470JoeKuoD6Init,
                dim6471JoeKuoD6Init,
                dim6472JoeKuoD6Init,
                dim6473JoeKuoD6Init,
                dim6474JoeKuoD6Init,
                dim6475JoeKuoD6Init,
                dim6476JoeKuoD6Init,
                dim6477JoeKuoD6Init,
                dim6478JoeKuoD6Init,
                dim6479JoeKuoD6Init,
                dim6480JoeKuoD6Init,
                dim6481JoeKuoD6Init,
                dim6482JoeKuoD6Init,
                dim6483JoeKuoD6Init,
                dim6484JoeKuoD6Init,
                dim6485JoeKuoD6Init,
                dim6486JoeKuoD6Init,
                dim6487JoeKuoD6Init,
                dim6488JoeKuoD6Init,
                dim6489JoeKuoD6Init,
                dim6490JoeKuoD6Init,
                dim6491JoeKuoD6Init,
                dim6492JoeKuoD6Init,
                dim6493JoeKuoD6Init,
                dim6494JoeKuoD6Init,
                dim6495JoeKuoD6Init,
                dim6496JoeKuoD6Init,
                dim6497JoeKuoD6Init,
                dim6498JoeKuoD6Init,
                dim6499JoeKuoD6Init,
                dim6500JoeKuoD6Init,
                dim6501JoeKuoD6Init,
                dim6502JoeKuoD6Init,
                dim6503JoeKuoD6Init,
                dim6504JoeKuoD6Init,
                dim6505JoeKuoD6Init,
                dim6506JoeKuoD6Init,
                dim6507JoeKuoD6Init,
                dim6508JoeKuoD6Init,
                dim6509JoeKuoD6Init,
                dim6510JoeKuoD6Init,
                dim6511JoeKuoD6Init,
                dim6512JoeKuoD6Init,
                dim6513JoeKuoD6Init,
                dim6514JoeKuoD6Init,
                dim6515JoeKuoD6Init,
                dim6516JoeKuoD6Init,
                dim6517JoeKuoD6Init,
                dim6518JoeKuoD6Init,
                dim6519JoeKuoD6Init,
                dim6520JoeKuoD6Init,
                dim6521JoeKuoD6Init,
                dim6522JoeKuoD6Init,
                dim6523JoeKuoD6Init,
                dim6524JoeKuoD6Init,
                dim6525JoeKuoD6Init,
                dim6526JoeKuoD6Init,
                dim6527JoeKuoD6Init,
                dim6528JoeKuoD6Init,
                dim6529JoeKuoD6Init,
                dim6530JoeKuoD6Init,
                dim6531JoeKuoD6Init,
                dim6532JoeKuoD6Init,
                dim6533JoeKuoD6Init,
                dim6534JoeKuoD6Init,
                dim6535JoeKuoD6Init,
                dim6536JoeKuoD6Init,
                dim6537JoeKuoD6Init,
                dim6538JoeKuoD6Init,
                dim6539JoeKuoD6Init,
                dim6540JoeKuoD6Init,
                dim6541JoeKuoD6Init,
                dim6542JoeKuoD6Init,
                dim6543JoeKuoD6Init,
                dim6544JoeKuoD6Init,
                dim6545JoeKuoD6Init,
                dim6546JoeKuoD6Init,
                dim6547JoeKuoD6Init,
                dim6548JoeKuoD6Init,
                dim6549JoeKuoD6Init,
                dim6550JoeKuoD6Init,
                dim6551JoeKuoD6Init,
                dim6552JoeKuoD6Init,
                dim6553JoeKuoD6Init,
                dim6554JoeKuoD6Init,
                dim6555JoeKuoD6Init,
                dim6556JoeKuoD6Init,
                dim6557JoeKuoD6Init,
                dim6558JoeKuoD6Init,
                dim6559JoeKuoD6Init,
                dim6560JoeKuoD6Init,
                dim6561JoeKuoD6Init,
                dim6562JoeKuoD6Init,
                dim6563JoeKuoD6Init,
                dim6564JoeKuoD6Init,
                dim6565JoeKuoD6Init,
                dim6566JoeKuoD6Init,
                dim6567JoeKuoD6Init,
                dim6568JoeKuoD6Init,
                dim6569JoeKuoD6Init,
                dim6570JoeKuoD6Init,
                dim6571JoeKuoD6Init,
                dim6572JoeKuoD6Init,
                dim6573JoeKuoD6Init,
                dim6574JoeKuoD6Init,
                dim6575JoeKuoD6Init,
                dim6576JoeKuoD6Init,
                dim6577JoeKuoD6Init,
                dim6578JoeKuoD6Init,
                dim6579JoeKuoD6Init,
                dim6580JoeKuoD6Init,
                dim6581JoeKuoD6Init,
                dim6582JoeKuoD6Init,
                dim6583JoeKuoD6Init,
                dim6584JoeKuoD6Init,
                dim6585JoeKuoD6Init,
                dim6586JoeKuoD6Init,
                dim6587JoeKuoD6Init,
                dim6588JoeKuoD6Init,
                dim6589JoeKuoD6Init,
                dim6590JoeKuoD6Init,
                dim6591JoeKuoD6Init,
                dim6592JoeKuoD6Init,
                dim6593JoeKuoD6Init,
                dim6594JoeKuoD6Init,
                dim6595JoeKuoD6Init,
                dim6596JoeKuoD6Init,
                dim6597JoeKuoD6Init,
                dim6598JoeKuoD6Init,
                dim6599JoeKuoD6Init,
                dim6600JoeKuoD6Init,
                dim6601JoeKuoD6Init,
                dim6602JoeKuoD6Init,
                dim6603JoeKuoD6Init,
                dim6604JoeKuoD6Init,
                dim6605JoeKuoD6Init,
                dim6606JoeKuoD6Init,
                dim6607JoeKuoD6Init,
                dim6608JoeKuoD6Init,
                dim6609JoeKuoD6Init,
                dim6610JoeKuoD6Init,
                dim6611JoeKuoD6Init,
                dim6612JoeKuoD6Init,
                dim6613JoeKuoD6Init,
                dim6614JoeKuoD6Init,
                dim6615JoeKuoD6Init,
                dim6616JoeKuoD6Init,
                dim6617JoeKuoD6Init,
                dim6618JoeKuoD6Init,
                dim6619JoeKuoD6Init,
                dim6620JoeKuoD6Init,
                dim6621JoeKuoD6Init,
                dim6622JoeKuoD6Init,
                dim6623JoeKuoD6Init,
                dim6624JoeKuoD6Init,
                dim6625JoeKuoD6Init,
                dim6626JoeKuoD6Init,
                dim6627JoeKuoD6Init,
                dim6628JoeKuoD6Init,
                dim6629JoeKuoD6Init,
                dim6630JoeKuoD6Init,
                dim6631JoeKuoD6Init,
                dim6632JoeKuoD6Init,
                dim6633JoeKuoD6Init,
                dim6634JoeKuoD6Init,
                dim6635JoeKuoD6Init,
                dim6636JoeKuoD6Init,
                dim6637JoeKuoD6Init,
                dim6638JoeKuoD6Init,
                dim6639JoeKuoD6Init,
                dim6640JoeKuoD6Init,
                dim6641JoeKuoD6Init,
                dim6642JoeKuoD6Init,
                dim6643JoeKuoD6Init,
                dim6644JoeKuoD6Init,
                dim6645JoeKuoD6Init,
                dim6646JoeKuoD6Init,
                dim6647JoeKuoD6Init,
                dim6648JoeKuoD6Init,
                dim6649JoeKuoD6Init,
                dim6650JoeKuoD6Init,
                dim6651JoeKuoD6Init,
                dim6652JoeKuoD6Init,
                dim6653JoeKuoD6Init,
                dim6654JoeKuoD6Init,
                dim6655JoeKuoD6Init,
                dim6656JoeKuoD6Init,
                dim6657JoeKuoD6Init,
                dim6658JoeKuoD6Init,
                dim6659JoeKuoD6Init,
                dim6660JoeKuoD6Init,
                dim6661JoeKuoD6Init,
                dim6662JoeKuoD6Init,
                dim6663JoeKuoD6Init,
                dim6664JoeKuoD6Init,
                dim6665JoeKuoD6Init,
                dim6666JoeKuoD6Init,
                dim6667JoeKuoD6Init,
                dim6668JoeKuoD6Init,
                dim6669JoeKuoD6Init,
                dim6670JoeKuoD6Init,
                dim6671JoeKuoD6Init,
                dim6672JoeKuoD6Init,
                dim6673JoeKuoD6Init,
                dim6674JoeKuoD6Init,
                dim6675JoeKuoD6Init,
                dim6676JoeKuoD6Init,
                dim6677JoeKuoD6Init,
                dim6678JoeKuoD6Init,
                dim6679JoeKuoD6Init,
                dim6680JoeKuoD6Init,
                dim6681JoeKuoD6Init,
                dim6682JoeKuoD6Init,
                dim6683JoeKuoD6Init,
                dim6684JoeKuoD6Init,
                dim6685JoeKuoD6Init,
                dim6686JoeKuoD6Init,
                dim6687JoeKuoD6Init,
                dim6688JoeKuoD6Init,
                dim6689JoeKuoD6Init,
                dim6690JoeKuoD6Init,
                dim6691JoeKuoD6Init,
                dim6692JoeKuoD6Init,
                dim6693JoeKuoD6Init,
                dim6694JoeKuoD6Init,
                dim6695JoeKuoD6Init,
                dim6696JoeKuoD6Init,
                dim6697JoeKuoD6Init,
                dim6698JoeKuoD6Init,
                dim6699JoeKuoD6Init,
                dim6700JoeKuoD6Init,
                dim6701JoeKuoD6Init,
                dim6702JoeKuoD6Init,
                dim6703JoeKuoD6Init,
                dim6704JoeKuoD6Init,
                dim6705JoeKuoD6Init,
                dim6706JoeKuoD6Init,
                dim6707JoeKuoD6Init,
                dim6708JoeKuoD6Init,
                dim6709JoeKuoD6Init,
                dim6710JoeKuoD6Init,
                dim6711JoeKuoD6Init,
                dim6712JoeKuoD6Init,
                dim6713JoeKuoD6Init,
                dim6714JoeKuoD6Init,
                dim6715JoeKuoD6Init,
                dim6716JoeKuoD6Init,
                dim6717JoeKuoD6Init,
                dim6718JoeKuoD6Init,
                dim6719JoeKuoD6Init,
                dim6720JoeKuoD6Init,
                dim6721JoeKuoD6Init,
                dim6722JoeKuoD6Init,
                dim6723JoeKuoD6Init,
                dim6724JoeKuoD6Init,
                dim6725JoeKuoD6Init,
                dim6726JoeKuoD6Init,
                dim6727JoeKuoD6Init,
                dim6728JoeKuoD6Init,
                dim6729JoeKuoD6Init,
                dim6730JoeKuoD6Init,
                dim6731JoeKuoD6Init,
                dim6732JoeKuoD6Init,
                dim6733JoeKuoD6Init,
                dim6734JoeKuoD6Init,
                dim6735JoeKuoD6Init,
                dim6736JoeKuoD6Init,
                dim6737JoeKuoD6Init,
                dim6738JoeKuoD6Init,
                dim6739JoeKuoD6Init,
                dim6740JoeKuoD6Init,
                dim6741JoeKuoD6Init,
                dim6742JoeKuoD6Init,
                dim6743JoeKuoD6Init,
                dim6744JoeKuoD6Init,
                dim6745JoeKuoD6Init,
                dim6746JoeKuoD6Init,
                dim6747JoeKuoD6Init,
                dim6748JoeKuoD6Init,
                dim6749JoeKuoD6Init,
                dim6750JoeKuoD6Init,
                dim6751JoeKuoD6Init,
                dim6752JoeKuoD6Init,
                dim6753JoeKuoD6Init,
                dim6754JoeKuoD6Init,
                dim6755JoeKuoD6Init,
                dim6756JoeKuoD6Init,
                dim6757JoeKuoD6Init,
                dim6758JoeKuoD6Init,
                dim6759JoeKuoD6Init,
                dim6760JoeKuoD6Init,
                dim6761JoeKuoD6Init,
                dim6762JoeKuoD6Init,
                dim6763JoeKuoD6Init,
                dim6764JoeKuoD6Init,
                dim6765JoeKuoD6Init,
                dim6766JoeKuoD6Init,
                dim6767JoeKuoD6Init,
                dim6768JoeKuoD6Init,
                dim6769JoeKuoD6Init,
                dim6770JoeKuoD6Init,
                dim6771JoeKuoD6Init,
                dim6772JoeKuoD6Init,
                dim6773JoeKuoD6Init,
                dim6774JoeKuoD6Init,
                dim6775JoeKuoD6Init,
                dim6776JoeKuoD6Init,
                dim6777JoeKuoD6Init,
                dim6778JoeKuoD6Init,
                dim6779JoeKuoD6Init,
                dim6780JoeKuoD6Init,
                dim6781JoeKuoD6Init,
                dim6782JoeKuoD6Init,
                dim6783JoeKuoD6Init,
                dim6784JoeKuoD6Init,
                dim6785JoeKuoD6Init,
                dim6786JoeKuoD6Init,
                dim6787JoeKuoD6Init,
                dim6788JoeKuoD6Init,
                dim6789JoeKuoD6Init,
                dim6790JoeKuoD6Init,
                dim6791JoeKuoD6Init,
                dim6792JoeKuoD6Init,
                dim6793JoeKuoD6Init,
                dim6794JoeKuoD6Init,
                dim6795JoeKuoD6Init,
                dim6796JoeKuoD6Init,
                dim6797JoeKuoD6Init,
                dim6798JoeKuoD6Init,
                dim6799JoeKuoD6Init,
                dim6800JoeKuoD6Init,
                dim6801JoeKuoD6Init,
                dim6802JoeKuoD6Init,
                dim6803JoeKuoD6Init,
                dim6804JoeKuoD6Init,
                dim6805JoeKuoD6Init,
                dim6806JoeKuoD6Init,
                dim6807JoeKuoD6Init,
                dim6808JoeKuoD6Init,
                dim6809JoeKuoD6Init,
                dim6810JoeKuoD6Init,
                dim6811JoeKuoD6Init,
                dim6812JoeKuoD6Init,
                dim6813JoeKuoD6Init,
                dim6814JoeKuoD6Init,
                dim6815JoeKuoD6Init,
                dim6816JoeKuoD6Init,
                dim6817JoeKuoD6Init,
                dim6818JoeKuoD6Init,
                dim6819JoeKuoD6Init,
                dim6820JoeKuoD6Init,
                dim6821JoeKuoD6Init,
                dim6822JoeKuoD6Init,
                dim6823JoeKuoD6Init,
                dim6824JoeKuoD6Init,
                dim6825JoeKuoD6Init,
                dim6826JoeKuoD6Init,
                dim6827JoeKuoD6Init,
                dim6828JoeKuoD6Init,
                dim6829JoeKuoD6Init,
                dim6830JoeKuoD6Init,
                dim6831JoeKuoD6Init,
                dim6832JoeKuoD6Init,
                dim6833JoeKuoD6Init,
                dim6834JoeKuoD6Init,
                dim6835JoeKuoD6Init,
                dim6836JoeKuoD6Init,
                dim6837JoeKuoD6Init,
                dim6838JoeKuoD6Init,
                dim6839JoeKuoD6Init,
                dim6840JoeKuoD6Init,
                dim6841JoeKuoD6Init,
                dim6842JoeKuoD6Init,
                dim6843JoeKuoD6Init,
                dim6844JoeKuoD6Init,
                dim6845JoeKuoD6Init,
                dim6846JoeKuoD6Init,
                dim6847JoeKuoD6Init,
                dim6848JoeKuoD6Init,
                dim6849JoeKuoD6Init,
                dim6850JoeKuoD6Init,
                dim6851JoeKuoD6Init,
                dim6852JoeKuoD6Init,
                dim6853JoeKuoD6Init,
                dim6854JoeKuoD6Init,
                dim6855JoeKuoD6Init,
                dim6856JoeKuoD6Init,
                dim6857JoeKuoD6Init,
                dim6858JoeKuoD6Init,
                dim6859JoeKuoD6Init,
                dim6860JoeKuoD6Init,
                dim6861JoeKuoD6Init,
                dim6862JoeKuoD6Init,
                dim6863JoeKuoD6Init,
                dim6864JoeKuoD6Init,
                dim6865JoeKuoD6Init,
                dim6866JoeKuoD6Init,
                dim6867JoeKuoD6Init,
                dim6868JoeKuoD6Init,
                dim6869JoeKuoD6Init,
                dim6870JoeKuoD6Init,
                dim6871JoeKuoD6Init,
                dim6872JoeKuoD6Init,
                dim6873JoeKuoD6Init,
                dim6874JoeKuoD6Init,
                dim6875JoeKuoD6Init,
                dim6876JoeKuoD6Init,
                dim6877JoeKuoD6Init,
                dim6878JoeKuoD6Init,
                dim6879JoeKuoD6Init,
                dim6880JoeKuoD6Init,
                dim6881JoeKuoD6Init,
                dim6882JoeKuoD6Init,
                dim6883JoeKuoD6Init,
                dim6884JoeKuoD6Init,
                dim6885JoeKuoD6Init,
                dim6886JoeKuoD6Init,
                dim6887JoeKuoD6Init,
                dim6888JoeKuoD6Init,
                dim6889JoeKuoD6Init,
                dim6890JoeKuoD6Init,
                dim6891JoeKuoD6Init,
                dim6892JoeKuoD6Init,
                dim6893JoeKuoD6Init,
                dim6894JoeKuoD6Init,
                dim6895JoeKuoD6Init,
                dim6896JoeKuoD6Init,
                dim6897JoeKuoD6Init,
                dim6898JoeKuoD6Init,
                dim6899JoeKuoD6Init,
                dim6900JoeKuoD6Init,
                dim6901JoeKuoD6Init,
                dim6902JoeKuoD6Init,
                dim6903JoeKuoD6Init,
                dim6904JoeKuoD6Init,
                dim6905JoeKuoD6Init,
                dim6906JoeKuoD6Init,
                dim6907JoeKuoD6Init,
                dim6908JoeKuoD6Init,
                dim6909JoeKuoD6Init,
                dim6910JoeKuoD6Init,
                dim6911JoeKuoD6Init,
                dim6912JoeKuoD6Init,
                dim6913JoeKuoD6Init,
                dim6914JoeKuoD6Init,
                dim6915JoeKuoD6Init,
                dim6916JoeKuoD6Init,
                dim6917JoeKuoD6Init,
                dim6918JoeKuoD6Init,
                dim6919JoeKuoD6Init,
                dim6920JoeKuoD6Init,
                dim6921JoeKuoD6Init,
                dim6922JoeKuoD6Init,
                dim6923JoeKuoD6Init,
                dim6924JoeKuoD6Init,
                dim6925JoeKuoD6Init,
                dim6926JoeKuoD6Init,
                dim6927JoeKuoD6Init,
                dim6928JoeKuoD6Init,
                dim6929JoeKuoD6Init,
                dim6930JoeKuoD6Init,
                dim6931JoeKuoD6Init,
                dim6932JoeKuoD6Init,
                dim6933JoeKuoD6Init,
                dim6934JoeKuoD6Init,
                dim6935JoeKuoD6Init,
                dim6936JoeKuoD6Init,
                dim6937JoeKuoD6Init,
                dim6938JoeKuoD6Init,
                dim6939JoeKuoD6Init,
                dim6940JoeKuoD6Init,
                dim6941JoeKuoD6Init,
                dim6942JoeKuoD6Init,
                dim6943JoeKuoD6Init,
                dim6944JoeKuoD6Init,
                dim6945JoeKuoD6Init,
                dim6946JoeKuoD6Init,
                dim6947JoeKuoD6Init,
                dim6948JoeKuoD6Init,
                dim6949JoeKuoD6Init,
                dim6950JoeKuoD6Init,
                dim6951JoeKuoD6Init,
                dim6952JoeKuoD6Init,
                dim6953JoeKuoD6Init,
                dim6954JoeKuoD6Init,
                dim6955JoeKuoD6Init,
                dim6956JoeKuoD6Init,
                dim6957JoeKuoD6Init,
                dim6958JoeKuoD6Init,
                dim6959JoeKuoD6Init,
                dim6960JoeKuoD6Init,
                dim6961JoeKuoD6Init,
                dim6962JoeKuoD6Init,
                dim6963JoeKuoD6Init,
                dim6964JoeKuoD6Init,
                dim6965JoeKuoD6Init,
                dim6966JoeKuoD6Init,
                dim6967JoeKuoD6Init,
                dim6968JoeKuoD6Init,
                dim6969JoeKuoD6Init,
                dim6970JoeKuoD6Init,
                dim6971JoeKuoD6Init,
                dim6972JoeKuoD6Init,
                dim6973JoeKuoD6Init,
                dim6974JoeKuoD6Init,
                dim6975JoeKuoD6Init,
                dim6976JoeKuoD6Init,
                dim6977JoeKuoD6Init,
                dim6978JoeKuoD6Init,
                dim6979JoeKuoD6Init,
                dim6980JoeKuoD6Init,
                dim6981JoeKuoD6Init,
                dim6982JoeKuoD6Init,
                dim6983JoeKuoD6Init,
                dim6984JoeKuoD6Init,
                dim6985JoeKuoD6Init,
                dim6986JoeKuoD6Init,
                dim6987JoeKuoD6Init,
                dim6988JoeKuoD6Init,
                dim6989JoeKuoD6Init,
                dim6990JoeKuoD6Init,
                dim6991JoeKuoD6Init,
                dim6992JoeKuoD6Init,
                dim6993JoeKuoD6Init,
                dim6994JoeKuoD6Init,
                dim6995JoeKuoD6Init,
                dim6996JoeKuoD6Init,
                dim6997JoeKuoD6Init,
                dim6998JoeKuoD6Init,
                dim6999JoeKuoD6Init,
                dim7000JoeKuoD6Init,
                dim7001JoeKuoD6Init,
                dim7002JoeKuoD6Init,
                dim7003JoeKuoD6Init,
                dim7004JoeKuoD6Init,
                dim7005JoeKuoD6Init,
                dim7006JoeKuoD6Init,
                dim7007JoeKuoD6Init,
                dim7008JoeKuoD6Init,
                dim7009JoeKuoD6Init,
                dim7010JoeKuoD6Init,
                dim7011JoeKuoD6Init,
                dim7012JoeKuoD6Init,
                dim7013JoeKuoD6Init,
                dim7014JoeKuoD6Init,
                dim7015JoeKuoD6Init,
                dim7016JoeKuoD6Init,
                dim7017JoeKuoD6Init,
                dim7018JoeKuoD6Init,
                dim7019JoeKuoD6Init,
                dim7020JoeKuoD6Init,
                dim7021JoeKuoD6Init,
                dim7022JoeKuoD6Init,
                dim7023JoeKuoD6Init,
                dim7024JoeKuoD6Init,
                dim7025JoeKuoD6Init,
                dim7026JoeKuoD6Init,
                dim7027JoeKuoD6Init,
                dim7028JoeKuoD6Init,
                dim7029JoeKuoD6Init,
                dim7030JoeKuoD6Init,
                dim7031JoeKuoD6Init,
                dim7032JoeKuoD6Init,
                dim7033JoeKuoD6Init,
                dim7034JoeKuoD6Init,
                dim7035JoeKuoD6Init,
                dim7036JoeKuoD6Init,
                dim7037JoeKuoD6Init,
                dim7038JoeKuoD6Init,
                dim7039JoeKuoD6Init,
                dim7040JoeKuoD6Init,
                dim7041JoeKuoD6Init,
                dim7042JoeKuoD6Init,
                dim7043JoeKuoD6Init,
                dim7044JoeKuoD6Init,
                dim7045JoeKuoD6Init,
                dim7046JoeKuoD6Init,
                dim7047JoeKuoD6Init,
                dim7048JoeKuoD6Init,
                dim7049JoeKuoD6Init,
                dim7050JoeKuoD6Init,
                dim7051JoeKuoD6Init,
                dim7052JoeKuoD6Init,
                dim7053JoeKuoD6Init,
                dim7054JoeKuoD6Init,
                dim7055JoeKuoD6Init,
                dim7056JoeKuoD6Init,
                dim7057JoeKuoD6Init,
                dim7058JoeKuoD6Init,
                dim7059JoeKuoD6Init,
                dim7060JoeKuoD6Init,
                dim7061JoeKuoD6Init,
                dim7062JoeKuoD6Init,
                dim7063JoeKuoD6Init,
                dim7064JoeKuoD6Init,
                dim7065JoeKuoD6Init,
                dim7066JoeKuoD6Init,
                dim7067JoeKuoD6Init,
                dim7068JoeKuoD6Init,
                dim7069JoeKuoD6Init,
                dim7070JoeKuoD6Init,
                dim7071JoeKuoD6Init,
                dim7072JoeKuoD6Init,
                dim7073JoeKuoD6Init,
                dim7074JoeKuoD6Init,
                dim7075JoeKuoD6Init,
                dim7076JoeKuoD6Init,
                dim7077JoeKuoD6Init,
                dim7078JoeKuoD6Init,
                dim7079JoeKuoD6Init,
                dim7080JoeKuoD6Init,
                dim7081JoeKuoD6Init,
                dim7082JoeKuoD6Init,
                dim7083JoeKuoD6Init,
                dim7084JoeKuoD6Init,
                dim7085JoeKuoD6Init,
                dim7086JoeKuoD6Init,
                dim7087JoeKuoD6Init,
                dim7088JoeKuoD6Init,
                dim7089JoeKuoD6Init,
                dim7090JoeKuoD6Init,
                dim7091JoeKuoD6Init,
                dim7092JoeKuoD6Init,
                dim7093JoeKuoD6Init,
                dim7094JoeKuoD6Init,
                dim7095JoeKuoD6Init,
                dim7096JoeKuoD6Init,
                dim7097JoeKuoD6Init,
                dim7098JoeKuoD6Init,
                dim7099JoeKuoD6Init,
                dim7100JoeKuoD6Init,
                dim7101JoeKuoD6Init,
                dim7102JoeKuoD6Init,
                dim7103JoeKuoD6Init,
                dim7104JoeKuoD6Init,
                dim7105JoeKuoD6Init,
                dim7106JoeKuoD6Init,
                dim7107JoeKuoD6Init,
                dim7108JoeKuoD6Init,
                dim7109JoeKuoD6Init,
                dim7110JoeKuoD6Init,
                dim7111JoeKuoD6Init,
                dim7112JoeKuoD6Init,
                dim7113JoeKuoD6Init,
                dim7114JoeKuoD6Init,
                dim7115JoeKuoD6Init,
                dim7116JoeKuoD6Init,
                dim7117JoeKuoD6Init,
                dim7118JoeKuoD6Init,
                dim7119JoeKuoD6Init,
                dim7120JoeKuoD6Init,
                dim7121JoeKuoD6Init,
                dim7122JoeKuoD6Init,
                dim7123JoeKuoD6Init,
                dim7124JoeKuoD6Init,
                dim7125JoeKuoD6Init,
                dim7126JoeKuoD6Init,
                dim7127JoeKuoD6Init,
                dim7128JoeKuoD6Init,
                dim7129JoeKuoD6Init,
                dim7130JoeKuoD6Init,
                dim7131JoeKuoD6Init,
                dim7132JoeKuoD6Init,
                dim7133JoeKuoD6Init,
                dim7134JoeKuoD6Init,
                dim7135JoeKuoD6Init,
                dim7136JoeKuoD6Init,
                dim7137JoeKuoD6Init,
                dim7138JoeKuoD6Init,
                dim7139JoeKuoD6Init,
                dim7140JoeKuoD6Init,
                dim7141JoeKuoD6Init,
                dim7142JoeKuoD6Init,
                dim7143JoeKuoD6Init,
                dim7144JoeKuoD6Init,
                dim7145JoeKuoD6Init,
                dim7146JoeKuoD6Init,
                dim7147JoeKuoD6Init,
                dim7148JoeKuoD6Init,
                dim7149JoeKuoD6Init,
                dim7150JoeKuoD6Init,
                dim7151JoeKuoD6Init,
                dim7152JoeKuoD6Init,
                dim7153JoeKuoD6Init,
                dim7154JoeKuoD6Init,
                dim7155JoeKuoD6Init,
                dim7156JoeKuoD6Init,
                dim7157JoeKuoD6Init,
                dim7158JoeKuoD6Init,
                dim7159JoeKuoD6Init,
                dim7160JoeKuoD6Init,
                dim7161JoeKuoD6Init,
                dim7162JoeKuoD6Init,
                dim7163JoeKuoD6Init,
                dim7164JoeKuoD6Init,
                dim7165JoeKuoD6Init,
                dim7166JoeKuoD6Init,
                dim7167JoeKuoD6Init,
                dim7168JoeKuoD6Init,
                dim7169JoeKuoD6Init,
                dim7170JoeKuoD6Init,
                dim7171JoeKuoD6Init,
                dim7172JoeKuoD6Init,
                dim7173JoeKuoD6Init,
                dim7174JoeKuoD6Init,
                dim7175JoeKuoD6Init,
                dim7176JoeKuoD6Init,
                dim7177JoeKuoD6Init,
                dim7178JoeKuoD6Init,
                dim7179JoeKuoD6Init,
                dim7180JoeKuoD6Init,
                dim7181JoeKuoD6Init,
                dim7182JoeKuoD6Init,
                dim7183JoeKuoD6Init,
                dim7184JoeKuoD6Init,
                dim7185JoeKuoD6Init,
                dim7186JoeKuoD6Init,
                dim7187JoeKuoD6Init,
                dim7188JoeKuoD6Init,
                dim7189JoeKuoD6Init,
                dim7190JoeKuoD6Init,
                dim7191JoeKuoD6Init,
                dim7192JoeKuoD6Init,
                dim7193JoeKuoD6Init,
                dim7194JoeKuoD6Init,
                dim7195JoeKuoD6Init,
                dim7196JoeKuoD6Init,
                dim7197JoeKuoD6Init,
                dim7198JoeKuoD6Init,
                dim7199JoeKuoD6Init,
                dim7200JoeKuoD6Init,
                dim7201JoeKuoD6Init,
                dim7202JoeKuoD6Init,
                dim7203JoeKuoD6Init,
                dim7204JoeKuoD6Init,
                dim7205JoeKuoD6Init,
                dim7206JoeKuoD6Init,
                dim7207JoeKuoD6Init,
                dim7208JoeKuoD6Init,
                dim7209JoeKuoD6Init,
                dim7210JoeKuoD6Init,
                dim7211JoeKuoD6Init,
                dim7212JoeKuoD6Init,
                dim7213JoeKuoD6Init,
                dim7214JoeKuoD6Init,
                dim7215JoeKuoD6Init,
                dim7216JoeKuoD6Init,
                dim7217JoeKuoD6Init,
                dim7218JoeKuoD6Init,
                dim7219JoeKuoD6Init,
                dim7220JoeKuoD6Init,
                dim7221JoeKuoD6Init,
                dim7222JoeKuoD6Init,
                dim7223JoeKuoD6Init,
                dim7224JoeKuoD6Init,
                dim7225JoeKuoD6Init,
                dim7226JoeKuoD6Init,
                dim7227JoeKuoD6Init,
                dim7228JoeKuoD6Init,
                dim7229JoeKuoD6Init,
                dim7230JoeKuoD6Init,
                dim7231JoeKuoD6Init,
                dim7232JoeKuoD6Init,
                dim7233JoeKuoD6Init,
                dim7234JoeKuoD6Init,
                dim7235JoeKuoD6Init,
                dim7236JoeKuoD6Init,
                dim7237JoeKuoD6Init,
                dim7238JoeKuoD6Init,
                dim7239JoeKuoD6Init,
                dim7240JoeKuoD6Init,
                dim7241JoeKuoD6Init,
                dim7242JoeKuoD6Init,
                dim7243JoeKuoD6Init,
                dim7244JoeKuoD6Init,
                dim7245JoeKuoD6Init,
                dim7246JoeKuoD6Init,
                dim7247JoeKuoD6Init,
                dim7248JoeKuoD6Init,
                dim7249JoeKuoD6Init,
                dim7250JoeKuoD6Init,
                dim7251JoeKuoD6Init,
                dim7252JoeKuoD6Init,
                dim7253JoeKuoD6Init,
                dim7254JoeKuoD6Init,
                dim7255JoeKuoD6Init,
                dim7256JoeKuoD6Init,
                dim7257JoeKuoD6Init,
                dim7258JoeKuoD6Init,
                dim7259JoeKuoD6Init,
                dim7260JoeKuoD6Init,
                dim7261JoeKuoD6Init,
                dim7262JoeKuoD6Init,
                dim7263JoeKuoD6Init,
                dim7264JoeKuoD6Init,
                dim7265JoeKuoD6Init,
                dim7266JoeKuoD6Init,
                dim7267JoeKuoD6Init,
                dim7268JoeKuoD6Init,
                dim7269JoeKuoD6Init,
                dim7270JoeKuoD6Init,
                dim7271JoeKuoD6Init,
                dim7272JoeKuoD6Init,
                dim7273JoeKuoD6Init,
                dim7274JoeKuoD6Init,
                dim7275JoeKuoD6Init,
                dim7276JoeKuoD6Init,
                dim7277JoeKuoD6Init,
                dim7278JoeKuoD6Init,
                dim7279JoeKuoD6Init,
                dim7280JoeKuoD6Init,
                dim7281JoeKuoD6Init,
                dim7282JoeKuoD6Init,
                dim7283JoeKuoD6Init,
                dim7284JoeKuoD6Init,
                dim7285JoeKuoD6Init,
                dim7286JoeKuoD6Init,
                dim7287JoeKuoD6Init,
                dim7288JoeKuoD6Init,
                dim7289JoeKuoD6Init,
                dim7290JoeKuoD6Init,
                dim7291JoeKuoD6Init,
                dim7292JoeKuoD6Init,
                dim7293JoeKuoD6Init,
                dim7294JoeKuoD6Init,
                dim7295JoeKuoD6Init,
                dim7296JoeKuoD6Init,
                dim7297JoeKuoD6Init,
                dim7298JoeKuoD6Init,
                dim7299JoeKuoD6Init,
                dim7300JoeKuoD6Init,
                dim7301JoeKuoD6Init,
                dim7302JoeKuoD6Init,
                dim7303JoeKuoD6Init,
                dim7304JoeKuoD6Init,
                dim7305JoeKuoD6Init,
                dim7306JoeKuoD6Init,
                dim7307JoeKuoD6Init,
                dim7308JoeKuoD6Init,
                dim7309JoeKuoD6Init,
                dim7310JoeKuoD6Init,
                dim7311JoeKuoD6Init,
                dim7312JoeKuoD6Init,
                dim7313JoeKuoD6Init,
                dim7314JoeKuoD6Init,
                dim7315JoeKuoD6Init,
                dim7316JoeKuoD6Init,
                dim7317JoeKuoD6Init,
                dim7318JoeKuoD6Init,
                dim7319JoeKuoD6Init,
                dim7320JoeKuoD6Init,
                dim7321JoeKuoD6Init,
                dim7322JoeKuoD6Init,
                dim7323JoeKuoD6Init,
                dim7324JoeKuoD6Init,
                dim7325JoeKuoD6Init,
                dim7326JoeKuoD6Init,
                dim7327JoeKuoD6Init,
                dim7328JoeKuoD6Init,
                dim7329JoeKuoD6Init,
                dim7330JoeKuoD6Init,
                dim7331JoeKuoD6Init,
                dim7332JoeKuoD6Init,
                dim7333JoeKuoD6Init,
                dim7334JoeKuoD6Init,
                dim7335JoeKuoD6Init,
                dim7336JoeKuoD6Init,
                dim7337JoeKuoD6Init,
                dim7338JoeKuoD6Init,
                dim7339JoeKuoD6Init,
                dim7340JoeKuoD6Init,
                dim7341JoeKuoD6Init,
                dim7342JoeKuoD6Init,
                dim7343JoeKuoD6Init,
                dim7344JoeKuoD6Init,
                dim7345JoeKuoD6Init,
                dim7346JoeKuoD6Init,
                dim7347JoeKuoD6Init,
                dim7348JoeKuoD6Init,
                dim7349JoeKuoD6Init,
                dim7350JoeKuoD6Init,
                dim7351JoeKuoD6Init,
                dim7352JoeKuoD6Init,
                dim7353JoeKuoD6Init,
                dim7354JoeKuoD6Init,
                dim7355JoeKuoD6Init,
                dim7356JoeKuoD6Init,
                dim7357JoeKuoD6Init,
                dim7358JoeKuoD6Init,
                dim7359JoeKuoD6Init,
                dim7360JoeKuoD6Init,
                dim7361JoeKuoD6Init,
                dim7362JoeKuoD6Init,
                dim7363JoeKuoD6Init,
                dim7364JoeKuoD6Init,
                dim7365JoeKuoD6Init,
                dim7366JoeKuoD6Init,
                dim7367JoeKuoD6Init,
                dim7368JoeKuoD6Init,
                dim7369JoeKuoD6Init,
                dim7370JoeKuoD6Init,
                dim7371JoeKuoD6Init,
                dim7372JoeKuoD6Init,
                dim7373JoeKuoD6Init,
                dim7374JoeKuoD6Init,
                dim7375JoeKuoD6Init,
                dim7376JoeKuoD6Init,
                dim7377JoeKuoD6Init,
                dim7378JoeKuoD6Init,
                dim7379JoeKuoD6Init,
                dim7380JoeKuoD6Init,
                dim7381JoeKuoD6Init,
                dim7382JoeKuoD6Init,
                dim7383JoeKuoD6Init,
                dim7384JoeKuoD6Init,
                dim7385JoeKuoD6Init,
                dim7386JoeKuoD6Init,
                dim7387JoeKuoD6Init,
                dim7388JoeKuoD6Init,
                dim7389JoeKuoD6Init,
                dim7390JoeKuoD6Init,
                dim7391JoeKuoD6Init,
                dim7392JoeKuoD6Init,
                dim7393JoeKuoD6Init,
                dim7394JoeKuoD6Init,
                dim7395JoeKuoD6Init,
                dim7396JoeKuoD6Init,
                dim7397JoeKuoD6Init,
                dim7398JoeKuoD6Init,
                dim7399JoeKuoD6Init,
                dim7400JoeKuoD6Init,
                dim7401JoeKuoD6Init,
                dim7402JoeKuoD6Init,
                dim7403JoeKuoD6Init,
                dim7404JoeKuoD6Init,
                dim7405JoeKuoD6Init,
                dim7406JoeKuoD6Init,
                dim7407JoeKuoD6Init,
                dim7408JoeKuoD6Init,
                dim7409JoeKuoD6Init,
                dim7410JoeKuoD6Init,
                dim7411JoeKuoD6Init,
                dim7412JoeKuoD6Init,
                dim7413JoeKuoD6Init,
                dim7414JoeKuoD6Init,
                dim7415JoeKuoD6Init,
                dim7416JoeKuoD6Init,
                dim7417JoeKuoD6Init,
                dim7418JoeKuoD6Init,
                dim7419JoeKuoD6Init,
                dim7420JoeKuoD6Init,
                dim7421JoeKuoD6Init,
                dim7422JoeKuoD6Init,
                dim7423JoeKuoD6Init,
                dim7424JoeKuoD6Init,
                dim7425JoeKuoD6Init,
                dim7426JoeKuoD6Init,
                dim7427JoeKuoD6Init,
                dim7428JoeKuoD6Init,
                dim7429JoeKuoD6Init,
                dim7430JoeKuoD6Init,
                dim7431JoeKuoD6Init,
                dim7432JoeKuoD6Init,
                dim7433JoeKuoD6Init,
                dim7434JoeKuoD6Init,
                dim7435JoeKuoD6Init,
                dim7436JoeKuoD6Init,
                dim7437JoeKuoD6Init,
                dim7438JoeKuoD6Init,
                dim7439JoeKuoD6Init,
                dim7440JoeKuoD6Init,
                dim7441JoeKuoD6Init,
                dim7442JoeKuoD6Init,
                dim7443JoeKuoD6Init,
                dim7444JoeKuoD6Init,
                dim7445JoeKuoD6Init,
                dim7446JoeKuoD6Init,
                dim7447JoeKuoD6Init,
                dim7448JoeKuoD6Init,
                dim7449JoeKuoD6Init,
                dim7450JoeKuoD6Init,
                dim7451JoeKuoD6Init,
                dim7452JoeKuoD6Init,
                dim7453JoeKuoD6Init,
                dim7454JoeKuoD6Init,
                dim7455JoeKuoD6Init,
                dim7456JoeKuoD6Init,
                dim7457JoeKuoD6Init,
                dim7458JoeKuoD6Init,
                dim7459JoeKuoD6Init,
                dim7460JoeKuoD6Init,
                dim7461JoeKuoD6Init,
                dim7462JoeKuoD6Init,
                dim7463JoeKuoD6Init,
                dim7464JoeKuoD6Init,
                dim7465JoeKuoD6Init,
                dim7466JoeKuoD6Init,
                dim7467JoeKuoD6Init,
                dim7468JoeKuoD6Init,
                dim7469JoeKuoD6Init,
                dim7470JoeKuoD6Init,
                dim7471JoeKuoD6Init,
                dim7472JoeKuoD6Init,
                dim7473JoeKuoD6Init,
                dim7474JoeKuoD6Init,
                dim7475JoeKuoD6Init,
                dim7476JoeKuoD6Init,
                dim7477JoeKuoD6Init,
                dim7478JoeKuoD6Init,
                dim7479JoeKuoD6Init,
                dim7480JoeKuoD6Init,
                dim7481JoeKuoD6Init,
                dim7482JoeKuoD6Init,
                dim7483JoeKuoD6Init,
                dim7484JoeKuoD6Init,
                dim7485JoeKuoD6Init,
                dim7486JoeKuoD6Init,
                dim7487JoeKuoD6Init,
                dim7488JoeKuoD6Init,
                dim7489JoeKuoD6Init,
                dim7490JoeKuoD6Init,
                dim7491JoeKuoD6Init,
                dim7492JoeKuoD6Init,
                dim7493JoeKuoD6Init,
                dim7494JoeKuoD6Init,
                dim7495JoeKuoD6Init,
                dim7496JoeKuoD6Init,
                dim7497JoeKuoD6Init,
                dim7498JoeKuoD6Init,
                dim7499JoeKuoD6Init,
                dim7500JoeKuoD6Init,
                dim7501JoeKuoD6Init,
                dim7502JoeKuoD6Init,
                dim7503JoeKuoD6Init,
                dim7504JoeKuoD6Init,
                dim7505JoeKuoD6Init,
                dim7506JoeKuoD6Init,
                dim7507JoeKuoD6Init,
                dim7508JoeKuoD6Init,
                dim7509JoeKuoD6Init,
                dim7510JoeKuoD6Init,
                dim7511JoeKuoD6Init,
                dim7512JoeKuoD6Init,
                dim7513JoeKuoD6Init,
                dim7514JoeKuoD6Init,
                dim7515JoeKuoD6Init,
                dim7516JoeKuoD6Init,
                dim7517JoeKuoD6Init,
                dim7518JoeKuoD6Init,
                dim7519JoeKuoD6Init,
                dim7520JoeKuoD6Init,
                dim7521JoeKuoD6Init,
                dim7522JoeKuoD6Init,
                dim7523JoeKuoD6Init,
                dim7524JoeKuoD6Init,
                dim7525JoeKuoD6Init,
                dim7526JoeKuoD6Init,
                dim7527JoeKuoD6Init,
                dim7528JoeKuoD6Init,
                dim7529JoeKuoD6Init,
                dim7530JoeKuoD6Init,
                dim7531JoeKuoD6Init,
                dim7532JoeKuoD6Init,
                dim7533JoeKuoD6Init,
                dim7534JoeKuoD6Init,
                dim7535JoeKuoD6Init,
                dim7536JoeKuoD6Init,
                dim7537JoeKuoD6Init,
                dim7538JoeKuoD6Init,
                dim7539JoeKuoD6Init,
                dim7540JoeKuoD6Init,
                dim7541JoeKuoD6Init,
                dim7542JoeKuoD6Init,
                dim7543JoeKuoD6Init,
                dim7544JoeKuoD6Init,
                dim7545JoeKuoD6Init,
                dim7546JoeKuoD6Init,
                dim7547JoeKuoD6Init,
                dim7548JoeKuoD6Init,
                dim7549JoeKuoD6Init,
                dim7550JoeKuoD6Init,
                dim7551JoeKuoD6Init,
                dim7552JoeKuoD6Init,
                dim7553JoeKuoD6Init,
                dim7554JoeKuoD6Init,
                dim7555JoeKuoD6Init,
                dim7556JoeKuoD6Init,
                dim7557JoeKuoD6Init,
                dim7558JoeKuoD6Init,
                dim7559JoeKuoD6Init,
                dim7560JoeKuoD6Init,
                dim7561JoeKuoD6Init,
                dim7562JoeKuoD6Init,
                dim7563JoeKuoD6Init,
                dim7564JoeKuoD6Init,
                dim7565JoeKuoD6Init,
                dim7566JoeKuoD6Init,
                dim7567JoeKuoD6Init,
                dim7568JoeKuoD6Init,
                dim7569JoeKuoD6Init,
                dim7570JoeKuoD6Init,
                dim7571JoeKuoD6Init,
                dim7572JoeKuoD6Init,
                dim7573JoeKuoD6Init,
                dim7574JoeKuoD6Init,
                dim7575JoeKuoD6Init,
                dim7576JoeKuoD6Init,
                dim7577JoeKuoD6Init,
                dim7578JoeKuoD6Init,
                dim7579JoeKuoD6Init,
                dim7580JoeKuoD6Init,
                dim7581JoeKuoD6Init,
                dim7582JoeKuoD6Init,
                dim7583JoeKuoD6Init,
                dim7584JoeKuoD6Init,
                dim7585JoeKuoD6Init,
                dim7586JoeKuoD6Init,
                dim7587JoeKuoD6Init,
                dim7588JoeKuoD6Init,
                dim7589JoeKuoD6Init,
                dim7590JoeKuoD6Init,
                dim7591JoeKuoD6Init,
                dim7592JoeKuoD6Init,
                dim7593JoeKuoD6Init,
                dim7594JoeKuoD6Init,
                dim7595JoeKuoD6Init,
                dim7596JoeKuoD6Init,
                dim7597JoeKuoD6Init,
                dim7598JoeKuoD6Init,
                dim7599JoeKuoD6Init,
                dim7600JoeKuoD6Init,
                dim7601JoeKuoD6Init,
                dim7602JoeKuoD6Init,
                dim7603JoeKuoD6Init,
                dim7604JoeKuoD6Init,
                dim7605JoeKuoD6Init,
                dim7606JoeKuoD6Init,
                dim7607JoeKuoD6Init,
                dim7608JoeKuoD6Init,
                dim7609JoeKuoD6Init,
                dim7610JoeKuoD6Init,
                dim7611JoeKuoD6Init,
                dim7612JoeKuoD6Init,
                dim7613JoeKuoD6Init,
                dim7614JoeKuoD6Init,
                dim7615JoeKuoD6Init,
                dim7616JoeKuoD6Init,
                dim7617JoeKuoD6Init,
                dim7618JoeKuoD6Init,
                dim7619JoeKuoD6Init,
                dim7620JoeKuoD6Init,
                dim7621JoeKuoD6Init,
                dim7622JoeKuoD6Init,
                dim7623JoeKuoD6Init,
                dim7624JoeKuoD6Init,
                dim7625JoeKuoD6Init,
                dim7626JoeKuoD6Init,
                dim7627JoeKuoD6Init,
                dim7628JoeKuoD6Init,
                dim7629JoeKuoD6Init,
                dim7630JoeKuoD6Init,
                dim7631JoeKuoD6Init,
                dim7632JoeKuoD6Init,
                dim7633JoeKuoD6Init,
                dim7634JoeKuoD6Init,
                dim7635JoeKuoD6Init,
                dim7636JoeKuoD6Init,
                dim7637JoeKuoD6Init,
                dim7638JoeKuoD6Init,
                dim7639JoeKuoD6Init,
                dim7640JoeKuoD6Init,
                dim7641JoeKuoD6Init,
                dim7642JoeKuoD6Init,
                dim7643JoeKuoD6Init,
                dim7644JoeKuoD6Init,
                dim7645JoeKuoD6Init,
                dim7646JoeKuoD6Init,
                dim7647JoeKuoD6Init,
                dim7648JoeKuoD6Init,
                dim7649JoeKuoD6Init,
                dim7650JoeKuoD6Init,
                dim7651JoeKuoD6Init,
                dim7652JoeKuoD6Init,
                dim7653JoeKuoD6Init,
                dim7654JoeKuoD6Init,
                dim7655JoeKuoD6Init,
                dim7656JoeKuoD6Init,
                dim7657JoeKuoD6Init,
                dim7658JoeKuoD6Init,
                dim7659JoeKuoD6Init,
                dim7660JoeKuoD6Init,
                dim7661JoeKuoD6Init,
                dim7662JoeKuoD6Init,
                dim7663JoeKuoD6Init,
                dim7664JoeKuoD6Init,
                dim7665JoeKuoD6Init,
                dim7666JoeKuoD6Init,
                dim7667JoeKuoD6Init,
                dim7668JoeKuoD6Init,
                dim7669JoeKuoD6Init,
                dim7670JoeKuoD6Init,
                dim7671JoeKuoD6Init,
                dim7672JoeKuoD6Init,
                dim7673JoeKuoD6Init,
                dim7674JoeKuoD6Init,
                dim7675JoeKuoD6Init,
                dim7676JoeKuoD6Init,
                dim7677JoeKuoD6Init,
                dim7678JoeKuoD6Init,
                dim7679JoeKuoD6Init,
                dim7680JoeKuoD6Init,
                dim7681JoeKuoD6Init,
                dim7682JoeKuoD6Init,
                dim7683JoeKuoD6Init,
                dim7684JoeKuoD6Init,
                dim7685JoeKuoD6Init,
                dim7686JoeKuoD6Init,
                dim7687JoeKuoD6Init,
                dim7688JoeKuoD6Init,
                dim7689JoeKuoD6Init,
                dim7690JoeKuoD6Init,
                dim7691JoeKuoD6Init,
                dim7692JoeKuoD6Init,
                dim7693JoeKuoD6Init,
                dim7694JoeKuoD6Init,
                dim7695JoeKuoD6Init,
                dim7696JoeKuoD6Init,
                dim7697JoeKuoD6Init,
                dim7698JoeKuoD6Init,
                dim7699JoeKuoD6Init,
                dim7700JoeKuoD6Init,
                dim7701JoeKuoD6Init,
                dim7702JoeKuoD6Init,
                dim7703JoeKuoD6Init,
                dim7704JoeKuoD6Init,
                dim7705JoeKuoD6Init,
                dim7706JoeKuoD6Init,
                dim7707JoeKuoD6Init,
                dim7708JoeKuoD6Init,
                dim7709JoeKuoD6Init,
                dim7710JoeKuoD6Init,
                dim7711JoeKuoD6Init,
                dim7712JoeKuoD6Init,
                dim7713JoeKuoD6Init,
                dim7714JoeKuoD6Init,
                dim7715JoeKuoD6Init,
                dim7716JoeKuoD6Init,
                dim7717JoeKuoD6Init,
                dim7718JoeKuoD6Init,
                dim7719JoeKuoD6Init,
                dim7720JoeKuoD6Init,
                dim7721JoeKuoD6Init,
                dim7722JoeKuoD6Init,
                dim7723JoeKuoD6Init,
                dim7724JoeKuoD6Init,
                dim7725JoeKuoD6Init,
                dim7726JoeKuoD6Init,
                dim7727JoeKuoD6Init,
                dim7728JoeKuoD6Init,
                dim7729JoeKuoD6Init,
                dim7730JoeKuoD6Init,
                dim7731JoeKuoD6Init,
                dim7732JoeKuoD6Init,
                dim7733JoeKuoD6Init,
                dim7734JoeKuoD6Init,
                dim7735JoeKuoD6Init,
                dim7736JoeKuoD6Init,
                dim7737JoeKuoD6Init,
                dim7738JoeKuoD6Init,
                dim7739JoeKuoD6Init,
                dim7740JoeKuoD6Init,
                dim7741JoeKuoD6Init,
                dim7742JoeKuoD6Init,
                dim7743JoeKuoD6Init,
                dim7744JoeKuoD6Init,
                dim7745JoeKuoD6Init,
                dim7746JoeKuoD6Init,
                dim7747JoeKuoD6Init,
                dim7748JoeKuoD6Init,
                dim7749JoeKuoD6Init,
                dim7750JoeKuoD6Init,
                dim7751JoeKuoD6Init,
                dim7752JoeKuoD6Init,
                dim7753JoeKuoD6Init,
                dim7754JoeKuoD6Init,
                dim7755JoeKuoD6Init,
                dim7756JoeKuoD6Init,
                dim7757JoeKuoD6Init,
                dim7758JoeKuoD6Init,
                dim7759JoeKuoD6Init,
                dim7760JoeKuoD6Init,
                dim7761JoeKuoD6Init,
                dim7762JoeKuoD6Init,
                dim7763JoeKuoD6Init,
                dim7764JoeKuoD6Init,
                dim7765JoeKuoD6Init,
                dim7766JoeKuoD6Init,
                dim7767JoeKuoD6Init,
                dim7768JoeKuoD6Init,
                dim7769JoeKuoD6Init,
                dim7770JoeKuoD6Init,
                dim7771JoeKuoD6Init,
                dim7772JoeKuoD6Init,
                dim7773JoeKuoD6Init,
                dim7774JoeKuoD6Init,
                dim7775JoeKuoD6Init,
                dim7776JoeKuoD6Init,
                dim7777JoeKuoD6Init,
                dim7778JoeKuoD6Init,
                dim7779JoeKuoD6Init,
                dim7780JoeKuoD6Init,
                dim7781JoeKuoD6Init,
                dim7782JoeKuoD6Init,
                dim7783JoeKuoD6Init,
                dim7784JoeKuoD6Init,
                dim7785JoeKuoD6Init,
                dim7786JoeKuoD6Init,
                dim7787JoeKuoD6Init,
                dim7788JoeKuoD6Init,
                dim7789JoeKuoD6Init,
                dim7790JoeKuoD6Init,
                dim7791JoeKuoD6Init,
                dim7792JoeKuoD6Init,
                dim7793JoeKuoD6Init,
                dim7794JoeKuoD6Init,
                dim7795JoeKuoD6Init,
                dim7796JoeKuoD6Init,
                dim7797JoeKuoD6Init,
                dim7798JoeKuoD6Init,
                dim7799JoeKuoD6Init,
                dim7800JoeKuoD6Init,
                dim7801JoeKuoD6Init,
                dim7802JoeKuoD6Init,
                dim7803JoeKuoD6Init,
                dim7804JoeKuoD6Init,
                dim7805JoeKuoD6Init,
                dim7806JoeKuoD6Init,
                dim7807JoeKuoD6Init,
                dim7808JoeKuoD6Init,
                dim7809JoeKuoD6Init,
                dim7810JoeKuoD6Init,
                dim7811JoeKuoD6Init,
                dim7812JoeKuoD6Init,
                dim7813JoeKuoD6Init,
                dim7814JoeKuoD6Init,
                dim7815JoeKuoD6Init,
                dim7816JoeKuoD6Init,
                dim7817JoeKuoD6Init,
                dim7818JoeKuoD6Init,
                dim7819JoeKuoD6Init,
                dim7820JoeKuoD6Init,
                dim7821JoeKuoD6Init,
                dim7822JoeKuoD6Init,
                dim7823JoeKuoD6Init,
                dim7824JoeKuoD6Init,
                dim7825JoeKuoD6Init,
                dim7826JoeKuoD6Init,
                dim7827JoeKuoD6Init,
                dim7828JoeKuoD6Init,
                dim7829JoeKuoD6Init,
                dim7830JoeKuoD6Init,
                dim7831JoeKuoD6Init,
                dim7832JoeKuoD6Init,
                dim7833JoeKuoD6Init,
                dim7834JoeKuoD6Init,
                dim7835JoeKuoD6Init,
                dim7836JoeKuoD6Init,
                dim7837JoeKuoD6Init,
                dim7838JoeKuoD6Init,
                dim7839JoeKuoD6Init,
                dim7840JoeKuoD6Init,
                dim7841JoeKuoD6Init,
                dim7842JoeKuoD6Init,
                dim7843JoeKuoD6Init,
                dim7844JoeKuoD6Init,
                dim7845JoeKuoD6Init,
                dim7846JoeKuoD6Init,
                dim7847JoeKuoD6Init,
                dim7848JoeKuoD6Init,
                dim7849JoeKuoD6Init,
                dim7850JoeKuoD6Init,
                dim7851JoeKuoD6Init,
                dim7852JoeKuoD6Init,
                dim7853JoeKuoD6Init,
                dim7854JoeKuoD6Init,
                dim7855JoeKuoD6Init,
                dim7856JoeKuoD6Init,
                dim7857JoeKuoD6Init,
                dim7858JoeKuoD6Init,
                dim7859JoeKuoD6Init,
                dim7860JoeKuoD6Init,
                dim7861JoeKuoD6Init,
                dim7862JoeKuoD6Init,
                dim7863JoeKuoD6Init,
                dim7864JoeKuoD6Init,
                dim7865JoeKuoD6Init,
                dim7866JoeKuoD6Init,
                dim7867JoeKuoD6Init,
                dim7868JoeKuoD6Init,
                dim7869JoeKuoD6Init,
                dim7870JoeKuoD6Init,
                dim7871JoeKuoD6Init,
                dim7872JoeKuoD6Init,
                dim7873JoeKuoD6Init,
                dim7874JoeKuoD6Init,
                dim7875JoeKuoD6Init,
                dim7876JoeKuoD6Init,
                dim7877JoeKuoD6Init,
                dim7878JoeKuoD6Init,
                dim7879JoeKuoD6Init,
                dim7880JoeKuoD6Init,
                dim7881JoeKuoD6Init,
                dim7882JoeKuoD6Init,
                dim7883JoeKuoD6Init,
                dim7884JoeKuoD6Init,
                dim7885JoeKuoD6Init,
                dim7886JoeKuoD6Init,
                dim7887JoeKuoD6Init,
                dim7888JoeKuoD6Init,
                dim7889JoeKuoD6Init,
                dim7890JoeKuoD6Init,
                dim7891JoeKuoD6Init,
                dim7892JoeKuoD6Init,
                dim7893JoeKuoD6Init,
                dim7894JoeKuoD6Init,
                dim7895JoeKuoD6Init,
                dim7896JoeKuoD6Init,
                dim7897JoeKuoD6Init,
                dim7898JoeKuoD6Init,
                dim7899JoeKuoD6Init,
                dim7900JoeKuoD6Init,
                dim7901JoeKuoD6Init,
                dim7902JoeKuoD6Init,
                dim7903JoeKuoD6Init,
                dim7904JoeKuoD6Init,
                dim7905JoeKuoD6Init,
                dim7906JoeKuoD6Init,
                dim7907JoeKuoD6Init,
                dim7908JoeKuoD6Init,
                dim7909JoeKuoD6Init,
                dim7910JoeKuoD6Init,
                dim7911JoeKuoD6Init,
                dim7912JoeKuoD6Init,
                dim7913JoeKuoD6Init,
                dim7914JoeKuoD6Init,
                dim7915JoeKuoD6Init,
                dim7916JoeKuoD6Init,
                dim7917JoeKuoD6Init,
                dim7918JoeKuoD6Init,
                dim7919JoeKuoD6Init,
                dim7920JoeKuoD6Init,
                dim7921JoeKuoD6Init,
                dim7922JoeKuoD6Init,
                dim7923JoeKuoD6Init,
                dim7924JoeKuoD6Init,
                dim7925JoeKuoD6Init,
                dim7926JoeKuoD6Init,
                dim7927JoeKuoD6Init,
                dim7928JoeKuoD6Init,
                dim7929JoeKuoD6Init,
                dim7930JoeKuoD6Init,
                dim7931JoeKuoD6Init,
                dim7932JoeKuoD6Init,
                dim7933JoeKuoD6Init,
                dim7934JoeKuoD6Init,
                dim7935JoeKuoD6Init,
                dim7936JoeKuoD6Init,
                dim7937JoeKuoD6Init,
                dim7938JoeKuoD6Init,
                dim7939JoeKuoD6Init,
                dim7940JoeKuoD6Init,
                dim7941JoeKuoD6Init,
                dim7942JoeKuoD6Init,
                dim7943JoeKuoD6Init,
                dim7944JoeKuoD6Init,
                dim7945JoeKuoD6Init,
                dim7946JoeKuoD6Init,
                dim7947JoeKuoD6Init,
                dim7948JoeKuoD6Init,
                dim7949JoeKuoD6Init,
                dim7950JoeKuoD6Init,
                dim7951JoeKuoD6Init,
                dim7952JoeKuoD6Init,
                dim7953JoeKuoD6Init,
                dim7954JoeKuoD6Init,
                dim7955JoeKuoD6Init,
                dim7956JoeKuoD6Init,
                dim7957JoeKuoD6Init,
                dim7958JoeKuoD6Init,
                dim7959JoeKuoD6Init,
                dim7960JoeKuoD6Init,
                dim7961JoeKuoD6Init,
                dim7962JoeKuoD6Init,
                dim7963JoeKuoD6Init,
                dim7964JoeKuoD6Init,
                dim7965JoeKuoD6Init,
                dim7966JoeKuoD6Init,
                dim7967JoeKuoD6Init,
                dim7968JoeKuoD6Init,
                dim7969JoeKuoD6Init,
                dim7970JoeKuoD6Init,
                dim7971JoeKuoD6Init,
                dim7972JoeKuoD6Init,
                dim7973JoeKuoD6Init,
                dim7974JoeKuoD6Init,
                dim7975JoeKuoD6Init,
                dim7976JoeKuoD6Init,
                dim7977JoeKuoD6Init,
                dim7978JoeKuoD6Init,
                dim7979JoeKuoD6Init,
                dim7980JoeKuoD6Init,
                dim7981JoeKuoD6Init,
                dim7982JoeKuoD6Init,
                dim7983JoeKuoD6Init,
                dim7984JoeKuoD6Init,
                dim7985JoeKuoD6Init,
                dim7986JoeKuoD6Init,
                dim7987JoeKuoD6Init,
                dim7988JoeKuoD6Init,
                dim7989JoeKuoD6Init,
                dim7990JoeKuoD6Init,
                dim7991JoeKuoD6Init,
                dim7992JoeKuoD6Init,
                dim7993JoeKuoD6Init,
                dim7994JoeKuoD6Init,
                dim7995JoeKuoD6Init,
                dim7996JoeKuoD6Init,
                dim7997JoeKuoD6Init,
                dim7998JoeKuoD6Init,
                dim7999JoeKuoD6Init,
                dim8000JoeKuoD6Init,
                dim8001JoeKuoD6Init,
                dim8002JoeKuoD6Init,
                dim8003JoeKuoD6Init,
                dim8004JoeKuoD6Init,
                dim8005JoeKuoD6Init,
                dim8006JoeKuoD6Init,
                dim8007JoeKuoD6Init,
                dim8008JoeKuoD6Init,
                dim8009JoeKuoD6Init,
                dim8010JoeKuoD6Init,
                dim8011JoeKuoD6Init,
                dim8012JoeKuoD6Init,
                dim8013JoeKuoD6Init,
                dim8014JoeKuoD6Init,
                dim8015JoeKuoD6Init,
                dim8016JoeKuoD6Init,
                dim8017JoeKuoD6Init,
                dim8018JoeKuoD6Init,
                dim8019JoeKuoD6Init,
                dim8020JoeKuoD6Init,
                dim8021JoeKuoD6Init,
                dim8022JoeKuoD6Init,
                dim8023JoeKuoD6Init,
                dim8024JoeKuoD6Init,
                dim8025JoeKuoD6Init,
                dim8026JoeKuoD6Init,
                dim8027JoeKuoD6Init,
                dim8028JoeKuoD6Init,
                dim8029JoeKuoD6Init,
                dim8030JoeKuoD6Init,
                dim8031JoeKuoD6Init,
                dim8032JoeKuoD6Init,
                dim8033JoeKuoD6Init,
                dim8034JoeKuoD6Init,
                dim8035JoeKuoD6Init,
                dim8036JoeKuoD6Init,
                dim8037JoeKuoD6Init,
                dim8038JoeKuoD6Init,
                dim8039JoeKuoD6Init,
                dim8040JoeKuoD6Init,
                dim8041JoeKuoD6Init,
                dim8042JoeKuoD6Init,
                dim8043JoeKuoD6Init,
                dim8044JoeKuoD6Init,
                dim8045JoeKuoD6Init,
                dim8046JoeKuoD6Init,
                dim8047JoeKuoD6Init,
                dim8048JoeKuoD6Init,
                dim8049JoeKuoD6Init,
                dim8050JoeKuoD6Init,
                dim8051JoeKuoD6Init,
                dim8052JoeKuoD6Init,
                dim8053JoeKuoD6Init,
                dim8054JoeKuoD6Init,
                dim8055JoeKuoD6Init,
                dim8056JoeKuoD6Init,
                dim8057JoeKuoD6Init,
                dim8058JoeKuoD6Init,
                dim8059JoeKuoD6Init,
                dim8060JoeKuoD6Init,
                dim8061JoeKuoD6Init,
                dim8062JoeKuoD6Init,
                dim8063JoeKuoD6Init,
                dim8064JoeKuoD6Init,
                dim8065JoeKuoD6Init,
                dim8066JoeKuoD6Init,
                dim8067JoeKuoD6Init,
                dim8068JoeKuoD6Init,
                dim8069JoeKuoD6Init,
                dim8070JoeKuoD6Init,
                dim8071JoeKuoD6Init,
                dim8072JoeKuoD6Init,
                dim8073JoeKuoD6Init,
                dim8074JoeKuoD6Init,
                dim8075JoeKuoD6Init,
                dim8076JoeKuoD6Init,
                dim8077JoeKuoD6Init,
                dim8078JoeKuoD6Init,
                dim8079JoeKuoD6Init,
                dim8080JoeKuoD6Init,
                dim8081JoeKuoD6Init,
                dim8082JoeKuoD6Init,
                dim8083JoeKuoD6Init,
                dim8084JoeKuoD6Init,
                dim8085JoeKuoD6Init,
                dim8086JoeKuoD6Init,
                dim8087JoeKuoD6Init,
                dim8088JoeKuoD6Init,
                dim8089JoeKuoD6Init,
                dim8090JoeKuoD6Init,
                dim8091JoeKuoD6Init,
                dim8092JoeKuoD6Init,
                dim8093JoeKuoD6Init,
                dim8094JoeKuoD6Init,
                dim8095JoeKuoD6Init,
                dim8096JoeKuoD6Init,
                dim8097JoeKuoD6Init,
                dim8098JoeKuoD6Init,
                dim8099JoeKuoD6Init,
                dim8100JoeKuoD6Init,
                dim8101JoeKuoD6Init,
                dim8102JoeKuoD6Init,
                dim8103JoeKuoD6Init,
                dim8104JoeKuoD6Init,
                dim8105JoeKuoD6Init,
                dim8106JoeKuoD6Init,
                dim8107JoeKuoD6Init,
                dim8108JoeKuoD6Init,
                dim8109JoeKuoD6Init,
                dim8110JoeKuoD6Init,
                dim8111JoeKuoD6Init,
                dim8112JoeKuoD6Init,
                dim8113JoeKuoD6Init,
                dim8114JoeKuoD6Init,
                dim8115JoeKuoD6Init,
                dim8116JoeKuoD6Init,
                dim8117JoeKuoD6Init,
                dim8118JoeKuoD6Init,
                dim8119JoeKuoD6Init,
                dim8120JoeKuoD6Init,
                dim8121JoeKuoD6Init,
                dim8122JoeKuoD6Init,
                dim8123JoeKuoD6Init,
                dim8124JoeKuoD6Init,
                dim8125JoeKuoD6Init,
                dim8126JoeKuoD6Init,
                dim8127JoeKuoD6Init,
                dim8128JoeKuoD6Init,
                dim8129JoeKuoD6Init,
                dim8130JoeKuoD6Init,
                dim8131JoeKuoD6Init,
                dim8132JoeKuoD6Init,
                dim8133JoeKuoD6Init,
                dim8134JoeKuoD6Init,
                dim8135JoeKuoD6Init,
                dim8136JoeKuoD6Init,
                dim8137JoeKuoD6Init,
                dim8138JoeKuoD6Init,
                dim8139JoeKuoD6Init,
                dim8140JoeKuoD6Init,
                dim8141JoeKuoD6Init,
                dim8142JoeKuoD6Init,
                dim8143JoeKuoD6Init,
                dim8144JoeKuoD6Init,
                dim8145JoeKuoD6Init,
                dim8146JoeKuoD6Init,
                dim8147JoeKuoD6Init,
                dim8148JoeKuoD6Init,
                dim8149JoeKuoD6Init,
                dim8150JoeKuoD6Init,
                dim8151JoeKuoD6Init,
                dim8152JoeKuoD6Init,
                dim8153JoeKuoD6Init,
                dim8154JoeKuoD6Init,
                dim8155JoeKuoD6Init,
                dim8156JoeKuoD6Init,
                dim8157JoeKuoD6Init,
                dim8158JoeKuoD6Init,
                dim8159JoeKuoD6Init,
                dim8160JoeKuoD6Init,
                dim8161JoeKuoD6Init,
                dim8162JoeKuoD6Init,
                dim8163JoeKuoD6Init,
                dim8164JoeKuoD6Init,
                dim8165JoeKuoD6Init,
                dim8166JoeKuoD6Init,
                dim8167JoeKuoD6Init,
                dim8168JoeKuoD6Init,
                dim8169JoeKuoD6Init,
                dim8170JoeKuoD6Init,
                dim8171JoeKuoD6Init,
                dim8172JoeKuoD6Init,
                dim8173JoeKuoD6Init,
                dim8174JoeKuoD6Init,
                dim8175JoeKuoD6Init,
                dim8176JoeKuoD6Init,
                dim8177JoeKuoD6Init,
                dim8178JoeKuoD6Init,
                dim8179JoeKuoD6Init,
                dim8180JoeKuoD6Init,
                dim8181JoeKuoD6Init,
                dim8182JoeKuoD6Init,
                dim8183JoeKuoD6Init,
                dim8184JoeKuoD6Init,
                dim8185JoeKuoD6Init,
                dim8186JoeKuoD6Init,
                dim8187JoeKuoD6Init,
                dim8188JoeKuoD6Init,
                dim8189JoeKuoD6Init,
                dim8190JoeKuoD6Init,
                dim8191JoeKuoD6Init,
                dim8192JoeKuoD6Init,
                dim8193JoeKuoD6Init,
                dim8194JoeKuoD6Init,
                dim8195JoeKuoD6Init,
                dim8196JoeKuoD6Init,
                dim8197JoeKuoD6Init,
                dim8198JoeKuoD6Init,
                dim8199JoeKuoD6Init,
                dim8200JoeKuoD6Init,
                dim8201JoeKuoD6Init,
                dim8202JoeKuoD6Init,
                dim8203JoeKuoD6Init,
                dim8204JoeKuoD6Init,
                dim8205JoeKuoD6Init,
                dim8206JoeKuoD6Init,
                dim8207JoeKuoD6Init,
                dim8208JoeKuoD6Init,
                dim8209JoeKuoD6Init,
                dim8210JoeKuoD6Init,
                dim8211JoeKuoD6Init,
                dim8212JoeKuoD6Init,
                dim8213JoeKuoD6Init,
                dim8214JoeKuoD6Init,
                dim8215JoeKuoD6Init,
                dim8216JoeKuoD6Init,
                dim8217JoeKuoD6Init,
                dim8218JoeKuoD6Init,
                dim8219JoeKuoD6Init,
                dim8220JoeKuoD6Init,
                dim8221JoeKuoD6Init,
                dim8222JoeKuoD6Init,
                dim8223JoeKuoD6Init,
                dim8224JoeKuoD6Init,
                dim8225JoeKuoD6Init,
                dim8226JoeKuoD6Init,
                dim8227JoeKuoD6Init,
                dim8228JoeKuoD6Init,
                dim8229JoeKuoD6Init,
                dim8230JoeKuoD6Init,
                dim8231JoeKuoD6Init,
                dim8232JoeKuoD6Init,
                dim8233JoeKuoD6Init,
                dim8234JoeKuoD6Init,
                dim8235JoeKuoD6Init,
                dim8236JoeKuoD6Init,
                dim8237JoeKuoD6Init,
                dim8238JoeKuoD6Init,
                dim8239JoeKuoD6Init,
                dim8240JoeKuoD6Init,
                dim8241JoeKuoD6Init,
                dim8242JoeKuoD6Init,
                dim8243JoeKuoD6Init,
                dim8244JoeKuoD6Init,
                dim8245JoeKuoD6Init,
                dim8246JoeKuoD6Init,
                dim8247JoeKuoD6Init,
                dim8248JoeKuoD6Init,
                dim8249JoeKuoD6Init,
                dim8250JoeKuoD6Init,
                dim8251JoeKuoD6Init,
                dim8252JoeKuoD6Init,
                dim8253JoeKuoD6Init,
                dim8254JoeKuoD6Init,
                dim8255JoeKuoD6Init,
                dim8256JoeKuoD6Init,
                dim8257JoeKuoD6Init,
                dim8258JoeKuoD6Init,
                dim8259JoeKuoD6Init,
                dim8260JoeKuoD6Init,
                dim8261JoeKuoD6Init,
                dim8262JoeKuoD6Init,
                dim8263JoeKuoD6Init,
                dim8264JoeKuoD6Init,
                dim8265JoeKuoD6Init,
                dim8266JoeKuoD6Init,
                dim8267JoeKuoD6Init,
                dim8268JoeKuoD6Init,
                dim8269JoeKuoD6Init,
                dim8270JoeKuoD6Init,
                dim8271JoeKuoD6Init,
                dim8272JoeKuoD6Init,
                dim8273JoeKuoD6Init,
                dim8274JoeKuoD6Init,
                dim8275JoeKuoD6Init,
                dim8276JoeKuoD6Init,
                dim8277JoeKuoD6Init,
                dim8278JoeKuoD6Init,
                dim8279JoeKuoD6Init,
                dim8280JoeKuoD6Init,
                dim8281JoeKuoD6Init,
                dim8282JoeKuoD6Init,
                dim8283JoeKuoD6Init,
                dim8284JoeKuoD6Init,
                dim8285JoeKuoD6Init,
                dim8286JoeKuoD6Init,
                dim8287JoeKuoD6Init,
                dim8288JoeKuoD6Init,
                dim8289JoeKuoD6Init,
                dim8290JoeKuoD6Init,
                dim8291JoeKuoD6Init,
                dim8292JoeKuoD6Init,
                dim8293JoeKuoD6Init,
                dim8294JoeKuoD6Init,
                dim8295JoeKuoD6Init,
                dim8296JoeKuoD6Init,
                dim8297JoeKuoD6Init,
                dim8298JoeKuoD6Init,
                dim8299JoeKuoD6Init,
                dim8300JoeKuoD6Init,
                dim8301JoeKuoD6Init,
                dim8302JoeKuoD6Init,
                dim8303JoeKuoD6Init,
                dim8304JoeKuoD6Init,
                dim8305JoeKuoD6Init,
                dim8306JoeKuoD6Init,
                dim8307JoeKuoD6Init,
                dim8308JoeKuoD6Init,
                dim8309JoeKuoD6Init,
                dim8310JoeKuoD6Init,
                dim8311JoeKuoD6Init,
                dim8312JoeKuoD6Init,
                dim8313JoeKuoD6Init,
                dim8314JoeKuoD6Init,
                dim8315JoeKuoD6Init,
                dim8316JoeKuoD6Init,
                dim8317JoeKuoD6Init,
                dim8318JoeKuoD6Init,
                dim8319JoeKuoD6Init,
                dim8320JoeKuoD6Init,
                dim8321JoeKuoD6Init,
                dim8322JoeKuoD6Init,
                dim8323JoeKuoD6Init,
                dim8324JoeKuoD6Init,
                dim8325JoeKuoD6Init,
                dim8326JoeKuoD6Init,
                dim8327JoeKuoD6Init,
                dim8328JoeKuoD6Init,
                dim8329JoeKuoD6Init,
                dim8330JoeKuoD6Init,
                dim8331JoeKuoD6Init,
                dim8332JoeKuoD6Init,
                dim8333JoeKuoD6Init,
                dim8334JoeKuoD6Init,
                dim8335JoeKuoD6Init,
                dim8336JoeKuoD6Init,
                dim8337JoeKuoD6Init,
                dim8338JoeKuoD6Init,
                dim8339JoeKuoD6Init,
                dim8340JoeKuoD6Init,
                dim8341JoeKuoD6Init,
                dim8342JoeKuoD6Init,
                dim8343JoeKuoD6Init,
                dim8344JoeKuoD6Init,
                dim8345JoeKuoD6Init,
                dim8346JoeKuoD6Init,
                dim8347JoeKuoD6Init,
                dim8348JoeKuoD6Init,
                dim8349JoeKuoD6Init,
                dim8350JoeKuoD6Init,
                dim8351JoeKuoD6Init,
                dim8352JoeKuoD6Init,
                dim8353JoeKuoD6Init,
                dim8354JoeKuoD6Init,
                dim8355JoeKuoD6Init,
                dim8356JoeKuoD6Init,
                dim8357JoeKuoD6Init,
                dim8358JoeKuoD6Init,
                dim8359JoeKuoD6Init,
                dim8360JoeKuoD6Init,
                dim8361JoeKuoD6Init,
                dim8362JoeKuoD6Init,
                dim8363JoeKuoD6Init,
                dim8364JoeKuoD6Init,
                dim8365JoeKuoD6Init,
                dim8366JoeKuoD6Init,
                dim8367JoeKuoD6Init,
                dim8368JoeKuoD6Init,
                dim8369JoeKuoD6Init,
                dim8370JoeKuoD6Init,
                dim8371JoeKuoD6Init,
                dim8372JoeKuoD6Init,
                dim8373JoeKuoD6Init,
                dim8374JoeKuoD6Init,
                dim8375JoeKuoD6Init,
                dim8376JoeKuoD6Init,
                dim8377JoeKuoD6Init,
                dim8378JoeKuoD6Init,
                dim8379JoeKuoD6Init,
                dim8380JoeKuoD6Init,
                dim8381JoeKuoD6Init,
                dim8382JoeKuoD6Init,
                dim8383JoeKuoD6Init,
                dim8384JoeKuoD6Init,
                dim8385JoeKuoD6Init,
                dim8386JoeKuoD6Init,
                dim8387JoeKuoD6Init,
                dim8388JoeKuoD6Init,
                dim8389JoeKuoD6Init,
                dim8390JoeKuoD6Init,
                dim8391JoeKuoD6Init,
                dim8392JoeKuoD6Init,
                dim8393JoeKuoD6Init,
                dim8394JoeKuoD6Init,
                dim8395JoeKuoD6Init,
                dim8396JoeKuoD6Init,
                dim8397JoeKuoD6Init,
                dim8398JoeKuoD6Init,
                dim8399JoeKuoD6Init,
                dim8400JoeKuoD6Init,
                dim8401JoeKuoD6Init,
                dim8402JoeKuoD6Init,
                dim8403JoeKuoD6Init,
                dim8404JoeKuoD6Init,
                dim8405JoeKuoD6Init,
                dim8406JoeKuoD6Init,
                dim8407JoeKuoD6Init,
                dim8408JoeKuoD6Init,
                dim8409JoeKuoD6Init,
                dim8410JoeKuoD6Init,
                dim8411JoeKuoD6Init,
                dim8412JoeKuoD6Init,
                dim8413JoeKuoD6Init,
                dim8414JoeKuoD6Init,
                dim8415JoeKuoD6Init,
                dim8416JoeKuoD6Init,
                dim8417JoeKuoD6Init,
                dim8418JoeKuoD6Init,
                dim8419JoeKuoD6Init,
                dim8420JoeKuoD6Init,
                dim8421JoeKuoD6Init,
                dim8422JoeKuoD6Init,
                dim8423JoeKuoD6Init,
                dim8424JoeKuoD6Init,
                dim8425JoeKuoD6Init,
                dim8426JoeKuoD6Init,
                dim8427JoeKuoD6Init,
                dim8428JoeKuoD6Init,
                dim8429JoeKuoD6Init,
                dim8430JoeKuoD6Init,
                dim8431JoeKuoD6Init,
                dim8432JoeKuoD6Init,
                dim8433JoeKuoD6Init,
                dim8434JoeKuoD6Init,
                dim8435JoeKuoD6Init,
                dim8436JoeKuoD6Init,
                dim8437JoeKuoD6Init,
                dim8438JoeKuoD6Init,
                dim8439JoeKuoD6Init,
                dim8440JoeKuoD6Init,
                dim8441JoeKuoD6Init,
                dim8442JoeKuoD6Init,
                dim8443JoeKuoD6Init,
                dim8444JoeKuoD6Init,
                dim8445JoeKuoD6Init,
                dim8446JoeKuoD6Init,
                dim8447JoeKuoD6Init,
                dim8448JoeKuoD6Init,
                dim8449JoeKuoD6Init,
                dim8450JoeKuoD6Init,
                dim8451JoeKuoD6Init,
                dim8452JoeKuoD6Init,
                dim8453JoeKuoD6Init,
                dim8454JoeKuoD6Init,
                dim8455JoeKuoD6Init,
                dim8456JoeKuoD6Init,
                dim8457JoeKuoD6Init,
                dim8458JoeKuoD6Init,
                dim8459JoeKuoD6Init,
                dim8460JoeKuoD6Init,
                dim8461JoeKuoD6Init,
                dim8462JoeKuoD6Init,
                dim8463JoeKuoD6Init,
                dim8464JoeKuoD6Init,
                dim8465JoeKuoD6Init,
                dim8466JoeKuoD6Init,
                dim8467JoeKuoD6Init,
                dim8468JoeKuoD6Init,
                dim8469JoeKuoD6Init,
                dim8470JoeKuoD6Init,
                dim8471JoeKuoD6Init,
                dim8472JoeKuoD6Init,
                dim8473JoeKuoD6Init,
                dim8474JoeKuoD6Init,
                dim8475JoeKuoD6Init,
                dim8476JoeKuoD6Init,
                dim8477JoeKuoD6Init,
                dim8478JoeKuoD6Init,
                dim8479JoeKuoD6Init,
                dim8480JoeKuoD6Init,
                dim8481JoeKuoD6Init,
                dim8482JoeKuoD6Init,
                dim8483JoeKuoD6Init,
                dim8484JoeKuoD6Init,
                dim8485JoeKuoD6Init,
                dim8486JoeKuoD6Init,
                dim8487JoeKuoD6Init,
                dim8488JoeKuoD6Init,
                dim8489JoeKuoD6Init,
                dim8490JoeKuoD6Init,
                dim8491JoeKuoD6Init,
                dim8492JoeKuoD6Init,
                dim8493JoeKuoD6Init,
                dim8494JoeKuoD6Init,
                dim8495JoeKuoD6Init,
                dim8496JoeKuoD6Init,
                dim8497JoeKuoD6Init,
                dim8498JoeKuoD6Init,
                dim8499JoeKuoD6Init,
                dim8500JoeKuoD6Init,
                dim8501JoeKuoD6Init,
                dim8502JoeKuoD6Init,
                dim8503JoeKuoD6Init,
                dim8504JoeKuoD6Init,
                dim8505JoeKuoD6Init,
                dim8506JoeKuoD6Init,
                dim8507JoeKuoD6Init,
                dim8508JoeKuoD6Init,
                dim8509JoeKuoD6Init,
                dim8510JoeKuoD6Init,
                dim8511JoeKuoD6Init,
                dim8512JoeKuoD6Init,
                dim8513JoeKuoD6Init,
                dim8514JoeKuoD6Init,
                dim8515JoeKuoD6Init,
                dim8516JoeKuoD6Init,
                dim8517JoeKuoD6Init,
                dim8518JoeKuoD6Init,
                dim8519JoeKuoD6Init,
                dim8520JoeKuoD6Init,
                dim8521JoeKuoD6Init,
                dim8522JoeKuoD6Init,
                dim8523JoeKuoD6Init,
                dim8524JoeKuoD6Init,
                dim8525JoeKuoD6Init,
                dim8526JoeKuoD6Init,
                dim8527JoeKuoD6Init,
                dim8528JoeKuoD6Init,
                dim8529JoeKuoD6Init,
                dim8530JoeKuoD6Init,
                dim8531JoeKuoD6Init,
                dim8532JoeKuoD6Init,
                dim8533JoeKuoD6Init,
                dim8534JoeKuoD6Init,
                dim8535JoeKuoD6Init,
                dim8536JoeKuoD6Init,
                dim8537JoeKuoD6Init,
                dim8538JoeKuoD6Init,
                dim8539JoeKuoD6Init,
                dim8540JoeKuoD6Init,
                dim8541JoeKuoD6Init,
                dim8542JoeKuoD6Init,
                dim8543JoeKuoD6Init,
                dim8544JoeKuoD6Init,
                dim8545JoeKuoD6Init,
                dim8546JoeKuoD6Init,
                dim8547JoeKuoD6Init,
                dim8548JoeKuoD6Init,
                dim8549JoeKuoD6Init,
                dim8550JoeKuoD6Init,
                dim8551JoeKuoD6Init,
                dim8552JoeKuoD6Init,
                dim8553JoeKuoD6Init,
                dim8554JoeKuoD6Init,
                dim8555JoeKuoD6Init,
                dim8556JoeKuoD6Init,
                dim8557JoeKuoD6Init,
                dim8558JoeKuoD6Init,
                dim8559JoeKuoD6Init,
                dim8560JoeKuoD6Init,
                dim8561JoeKuoD6Init,
                dim8562JoeKuoD6Init,
                dim8563JoeKuoD6Init,
                dim8564JoeKuoD6Init,
                dim8565JoeKuoD6Init,
                dim8566JoeKuoD6Init,
                dim8567JoeKuoD6Init,
                dim8568JoeKuoD6Init,
                dim8569JoeKuoD6Init,
                dim8570JoeKuoD6Init,
                dim8571JoeKuoD6Init,
                dim8572JoeKuoD6Init,
                dim8573JoeKuoD6Init,
                dim8574JoeKuoD6Init,
                dim8575JoeKuoD6Init,
                dim8576JoeKuoD6Init,
                dim8577JoeKuoD6Init,
                dim8578JoeKuoD6Init,
                dim8579JoeKuoD6Init,
                dim8580JoeKuoD6Init,
                dim8581JoeKuoD6Init,
                dim8582JoeKuoD6Init,
                dim8583JoeKuoD6Init,
                dim8584JoeKuoD6Init,
                dim8585JoeKuoD6Init,
                dim8586JoeKuoD6Init,
                dim8587JoeKuoD6Init,
                dim8588JoeKuoD6Init,
                dim8589JoeKuoD6Init,
                dim8590JoeKuoD6Init,
                dim8591JoeKuoD6Init,
                dim8592JoeKuoD6Init,
                dim8593JoeKuoD6Init,
                dim8594JoeKuoD6Init,
                dim8595JoeKuoD6Init,
                dim8596JoeKuoD6Init,
                dim8597JoeKuoD6Init,
                dim8598JoeKuoD6Init,
                dim8599JoeKuoD6Init,
                dim8600JoeKuoD6Init,
                dim8601JoeKuoD6Init,
                dim8602JoeKuoD6Init,
                dim8603JoeKuoD6Init,
                dim8604JoeKuoD6Init,
                dim8605JoeKuoD6Init,
                dim8606JoeKuoD6Init,
                dim8607JoeKuoD6Init,
                dim8608JoeKuoD6Init,
                dim8609JoeKuoD6Init,
                dim8610JoeKuoD6Init,
                dim8611JoeKuoD6Init,
                dim8612JoeKuoD6Init,
                dim8613JoeKuoD6Init,
                dim8614JoeKuoD6Init,
                dim8615JoeKuoD6Init,
                dim8616JoeKuoD6Init,
                dim8617JoeKuoD6Init,
                dim8618JoeKuoD6Init,
                dim8619JoeKuoD6Init,
                dim8620JoeKuoD6Init,
                dim8621JoeKuoD6Init,
                dim8622JoeKuoD6Init,
                dim8623JoeKuoD6Init,
                dim8624JoeKuoD6Init,
                dim8625JoeKuoD6Init,
                dim8626JoeKuoD6Init,
                dim8627JoeKuoD6Init,
                dim8628JoeKuoD6Init,
                dim8629JoeKuoD6Init,
                dim8630JoeKuoD6Init,
                dim8631JoeKuoD6Init,
                dim8632JoeKuoD6Init,
                dim8633JoeKuoD6Init,
                dim8634JoeKuoD6Init,
                dim8635JoeKuoD6Init,
                dim8636JoeKuoD6Init,
                dim8637JoeKuoD6Init,
                dim8638JoeKuoD6Init,
                dim8639JoeKuoD6Init,
                dim8640JoeKuoD6Init,
                dim8641JoeKuoD6Init,
                dim8642JoeKuoD6Init,
                dim8643JoeKuoD6Init,
                dim8644JoeKuoD6Init,
                dim8645JoeKuoD6Init,
                dim8646JoeKuoD6Init,
                dim8647JoeKuoD6Init,
                dim8648JoeKuoD6Init,
                dim8649JoeKuoD6Init,
                dim8650JoeKuoD6Init,
                dim8651JoeKuoD6Init,
                dim8652JoeKuoD6Init,
                dim8653JoeKuoD6Init,
                dim8654JoeKuoD6Init,
                dim8655JoeKuoD6Init,
                dim8656JoeKuoD6Init,
                dim8657JoeKuoD6Init,
                dim8658JoeKuoD6Init,
                dim8659JoeKuoD6Init,
                dim8660JoeKuoD6Init,
                dim8661JoeKuoD6Init,
                dim8662JoeKuoD6Init,
                dim8663JoeKuoD6Init,
                dim8664JoeKuoD6Init,
                dim8665JoeKuoD6Init,
                dim8666JoeKuoD6Init,
                dim8667JoeKuoD6Init,
                dim8668JoeKuoD6Init,
                dim8669JoeKuoD6Init,
                dim8670JoeKuoD6Init,
                dim8671JoeKuoD6Init,
                dim8672JoeKuoD6Init,
                dim8673JoeKuoD6Init,
                dim8674JoeKuoD6Init,
                dim8675JoeKuoD6Init,
                dim8676JoeKuoD6Init,
                dim8677JoeKuoD6Init,
                dim8678JoeKuoD6Init,
                dim8679JoeKuoD6Init,
                dim8680JoeKuoD6Init,
                dim8681JoeKuoD6Init,
                dim8682JoeKuoD6Init,
                dim8683JoeKuoD6Init,
                dim8684JoeKuoD6Init,
                dim8685JoeKuoD6Init,
                dim8686JoeKuoD6Init,
                dim8687JoeKuoD6Init,
                dim8688JoeKuoD6Init,
                dim8689JoeKuoD6Init,
                dim8690JoeKuoD6Init,
                dim8691JoeKuoD6Init,
                dim8692JoeKuoD6Init,
                dim8693JoeKuoD6Init,
                dim8694JoeKuoD6Init,
                dim8695JoeKuoD6Init,
                dim8696JoeKuoD6Init,
                dim8697JoeKuoD6Init,
                dim8698JoeKuoD6Init,
                dim8699JoeKuoD6Init,
                dim8700JoeKuoD6Init,
                dim8701JoeKuoD6Init,
                dim8702JoeKuoD6Init,
                dim8703JoeKuoD6Init,
                dim8704JoeKuoD6Init,
                dim8705JoeKuoD6Init,
                dim8706JoeKuoD6Init,
                dim8707JoeKuoD6Init,
                dim8708JoeKuoD6Init,
                dim8709JoeKuoD6Init,
                dim8710JoeKuoD6Init,
                dim8711JoeKuoD6Init,
                dim8712JoeKuoD6Init,
                dim8713JoeKuoD6Init,
                dim8714JoeKuoD6Init,
                dim8715JoeKuoD6Init,
                dim8716JoeKuoD6Init,
                dim8717JoeKuoD6Init,
                dim8718JoeKuoD6Init,
                dim8719JoeKuoD6Init,
                dim8720JoeKuoD6Init,
                dim8721JoeKuoD6Init,
                dim8722JoeKuoD6Init,
                dim8723JoeKuoD6Init,
                dim8724JoeKuoD6Init,
                dim8725JoeKuoD6Init,
                dim8726JoeKuoD6Init,
                dim8727JoeKuoD6Init,
                dim8728JoeKuoD6Init,
                dim8729JoeKuoD6Init,
                dim8730JoeKuoD6Init,
                dim8731JoeKuoD6Init,
                dim8732JoeKuoD6Init,
                dim8733JoeKuoD6Init,
                dim8734JoeKuoD6Init,
                dim8735JoeKuoD6Init,
                dim8736JoeKuoD6Init,
                dim8737JoeKuoD6Init,
                dim8738JoeKuoD6Init,
                dim8739JoeKuoD6Init,
                dim8740JoeKuoD6Init,
                dim8741JoeKuoD6Init,
                dim8742JoeKuoD6Init,
                dim8743JoeKuoD6Init,
                dim8744JoeKuoD6Init,
                dim8745JoeKuoD6Init,
                dim8746JoeKuoD6Init,
                dim8747JoeKuoD6Init,
                dim8748JoeKuoD6Init,
                dim8749JoeKuoD6Init,
                dim8750JoeKuoD6Init,
                dim8751JoeKuoD6Init,
                dim8752JoeKuoD6Init,
                dim8753JoeKuoD6Init,
                dim8754JoeKuoD6Init,
                dim8755JoeKuoD6Init,
                dim8756JoeKuoD6Init,
                dim8757JoeKuoD6Init,
                dim8758JoeKuoD6Init,
                dim8759JoeKuoD6Init,
                dim8760JoeKuoD6Init,
                dim8761JoeKuoD6Init,
                dim8762JoeKuoD6Init,
                dim8763JoeKuoD6Init,
                dim8764JoeKuoD6Init,
                dim8765JoeKuoD6Init,
                dim8766JoeKuoD6Init,
                dim8767JoeKuoD6Init,
                dim8768JoeKuoD6Init,
                dim8769JoeKuoD6Init,
                dim8770JoeKuoD6Init,
                dim8771JoeKuoD6Init,
                dim8772JoeKuoD6Init,
                dim8773JoeKuoD6Init,
                dim8774JoeKuoD6Init,
                dim8775JoeKuoD6Init,
                dim8776JoeKuoD6Init,
                dim8777JoeKuoD6Init,
                dim8778JoeKuoD6Init,
                dim8779JoeKuoD6Init,
                dim8780JoeKuoD6Init,
                dim8781JoeKuoD6Init,
                dim8782JoeKuoD6Init,
                dim8783JoeKuoD6Init,
                dim8784JoeKuoD6Init,
                dim8785JoeKuoD6Init,
                dim8786JoeKuoD6Init,
                dim8787JoeKuoD6Init,
                dim8788JoeKuoD6Init,
                dim8789JoeKuoD6Init,
                dim8790JoeKuoD6Init,
                dim8791JoeKuoD6Init,
                dim8792JoeKuoD6Init,
                dim8793JoeKuoD6Init,
                dim8794JoeKuoD6Init,
                dim8795JoeKuoD6Init,
                dim8796JoeKuoD6Init,
                dim8797JoeKuoD6Init,
                dim8798JoeKuoD6Init,
                dim8799JoeKuoD6Init,
                dim8800JoeKuoD6Init,
                dim8801JoeKuoD6Init,
                dim8802JoeKuoD6Init,
                dim8803JoeKuoD6Init,
                dim8804JoeKuoD6Init,
                dim8805JoeKuoD6Init,
                dim8806JoeKuoD6Init,
                dim8807JoeKuoD6Init,
                dim8808JoeKuoD6Init,
                dim8809JoeKuoD6Init,
                dim8810JoeKuoD6Init,
                dim8811JoeKuoD6Init,
                dim8812JoeKuoD6Init,
                dim8813JoeKuoD6Init,
                dim8814JoeKuoD6Init,
                dim8815JoeKuoD6Init,
                dim8816JoeKuoD6Init,
                dim8817JoeKuoD6Init,
                dim8818JoeKuoD6Init,
                dim8819JoeKuoD6Init,
                dim8820JoeKuoD6Init,
                dim8821JoeKuoD6Init,
                dim8822JoeKuoD6Init,
                dim8823JoeKuoD6Init,
                dim8824JoeKuoD6Init,
                dim8825JoeKuoD6Init,
                dim8826JoeKuoD6Init,
                dim8827JoeKuoD6Init,
                dim8828JoeKuoD6Init,
                dim8829JoeKuoD6Init,
                dim8830JoeKuoD6Init,
                dim8831JoeKuoD6Init,
                dim8832JoeKuoD6Init,
                dim8833JoeKuoD6Init,
                dim8834JoeKuoD6Init,
                dim8835JoeKuoD6Init,
                dim8836JoeKuoD6Init,
                dim8837JoeKuoD6Init,
                dim8838JoeKuoD6Init,
                dim8839JoeKuoD6Init,
                dim8840JoeKuoD6Init,
                dim8841JoeKuoD6Init,
                dim8842JoeKuoD6Init,
                dim8843JoeKuoD6Init,
                dim8844JoeKuoD6Init,
                dim8845JoeKuoD6Init,
                dim8846JoeKuoD6Init,
                dim8847JoeKuoD6Init,
                dim8848JoeKuoD6Init,
                dim8849JoeKuoD6Init,
                dim8850JoeKuoD6Init,
                dim8851JoeKuoD6Init,
                dim8852JoeKuoD6Init,
                dim8853JoeKuoD6Init,
                dim8854JoeKuoD6Init,
                dim8855JoeKuoD6Init,
                dim8856JoeKuoD6Init,
                dim8857JoeKuoD6Init,
                dim8858JoeKuoD6Init,
                dim8859JoeKuoD6Init,
                dim8860JoeKuoD6Init,
                dim8861JoeKuoD6Init,
                dim8862JoeKuoD6Init,
                dim8863JoeKuoD6Init,
                dim8864JoeKuoD6Init,
                dim8865JoeKuoD6Init,
                dim8866JoeKuoD6Init,
                dim8867JoeKuoD6Init,
                dim8868JoeKuoD6Init,
                dim8869JoeKuoD6Init,
                dim8870JoeKuoD6Init,
                dim8871JoeKuoD6Init,
                dim8872JoeKuoD6Init,
                dim8873JoeKuoD6Init,
                dim8874JoeKuoD6Init,
                dim8875JoeKuoD6Init,
                dim8876JoeKuoD6Init,
                dim8877JoeKuoD6Init,
                dim8878JoeKuoD6Init,
                dim8879JoeKuoD6Init,
                dim8880JoeKuoD6Init,
                dim8881JoeKuoD6Init,
                dim8882JoeKuoD6Init,
                dim8883JoeKuoD6Init,
                dim8884JoeKuoD6Init,
                dim8885JoeKuoD6Init,
                dim8886JoeKuoD6Init,
                dim8887JoeKuoD6Init,
                dim8888JoeKuoD6Init,
                dim8889JoeKuoD6Init,
                dim8890JoeKuoD6Init,
                dim8891JoeKuoD6Init,
                dim8892JoeKuoD6Init,
                dim8893JoeKuoD6Init,
                dim8894JoeKuoD6Init,
                dim8895JoeKuoD6Init,
                dim8896JoeKuoD6Init,
                dim8897JoeKuoD6Init,
                dim8898JoeKuoD6Init,
                dim8899JoeKuoD6Init,
                dim8900JoeKuoD6Init,
                dim8901JoeKuoD6Init,
                dim8902JoeKuoD6Init,
                dim8903JoeKuoD6Init,
                dim8904JoeKuoD6Init,
                dim8905JoeKuoD6Init,
                dim8906JoeKuoD6Init,
                dim8907JoeKuoD6Init,
                dim8908JoeKuoD6Init,
                dim8909JoeKuoD6Init,
                dim8910JoeKuoD6Init,
                dim8911JoeKuoD6Init,
                dim8912JoeKuoD6Init,
                dim8913JoeKuoD6Init,
                dim8914JoeKuoD6Init,
                dim8915JoeKuoD6Init,
                dim8916JoeKuoD6Init,
                dim8917JoeKuoD6Init,
                dim8918JoeKuoD6Init,
                dim8919JoeKuoD6Init,
                dim8920JoeKuoD6Init,
                dim8921JoeKuoD6Init,
                dim8922JoeKuoD6Init,
                dim8923JoeKuoD6Init,
                dim8924JoeKuoD6Init,
                dim8925JoeKuoD6Init,
                dim8926JoeKuoD6Init,
                dim8927JoeKuoD6Init,
                dim8928JoeKuoD6Init,
                dim8929JoeKuoD6Init,
                dim8930JoeKuoD6Init,
                dim8931JoeKuoD6Init,
                dim8932JoeKuoD6Init,
                dim8933JoeKuoD6Init,
                dim8934JoeKuoD6Init,
                dim8935JoeKuoD6Init,
                dim8936JoeKuoD6Init,
                dim8937JoeKuoD6Init,
                dim8938JoeKuoD6Init,
                dim8939JoeKuoD6Init,
                dim8940JoeKuoD6Init,
                dim8941JoeKuoD6Init,
                dim8942JoeKuoD6Init,
                dim8943JoeKuoD6Init,
                dim8944JoeKuoD6Init,
                dim8945JoeKuoD6Init,
                dim8946JoeKuoD6Init,
                dim8947JoeKuoD6Init,
                dim8948JoeKuoD6Init,
                dim8949JoeKuoD6Init,
                dim8950JoeKuoD6Init,
                dim8951JoeKuoD6Init,
                dim8952JoeKuoD6Init,
                dim8953JoeKuoD6Init,
                dim8954JoeKuoD6Init,
                dim8955JoeKuoD6Init,
                dim8956JoeKuoD6Init,
                dim8957JoeKuoD6Init,
                dim8958JoeKuoD6Init,
                dim8959JoeKuoD6Init,
                dim8960JoeKuoD6Init,
                dim8961JoeKuoD6Init,
                dim8962JoeKuoD6Init,
                dim8963JoeKuoD6Init,
                dim8964JoeKuoD6Init,
                dim8965JoeKuoD6Init,
                dim8966JoeKuoD6Init,
                dim8967JoeKuoD6Init,
                dim8968JoeKuoD6Init,
                dim8969JoeKuoD6Init,
                dim8970JoeKuoD6Init,
                dim8971JoeKuoD6Init,
                dim8972JoeKuoD6Init,
                dim8973JoeKuoD6Init,
                dim8974JoeKuoD6Init,
                dim8975JoeKuoD6Init,
                dim8976JoeKuoD6Init,
                dim8977JoeKuoD6Init,
                dim8978JoeKuoD6Init,
                dim8979JoeKuoD6Init,
                dim8980JoeKuoD6Init,
                dim8981JoeKuoD6Init,
                dim8982JoeKuoD6Init,
                dim8983JoeKuoD6Init,
                dim8984JoeKuoD6Init,
                dim8985JoeKuoD6Init,
                dim8986JoeKuoD6Init,
                dim8987JoeKuoD6Init,
                dim8988JoeKuoD6Init,
                dim8989JoeKuoD6Init,
                dim8990JoeKuoD6Init,
                dim8991JoeKuoD6Init,
                dim8992JoeKuoD6Init,
                dim8993JoeKuoD6Init,
                dim8994JoeKuoD6Init,
                dim8995JoeKuoD6Init,
                dim8996JoeKuoD6Init,
                dim8997JoeKuoD6Init,
                dim8998JoeKuoD6Init,
                dim8999JoeKuoD6Init,
                dim9000JoeKuoD6Init,
                dim9001JoeKuoD6Init,
                dim9002JoeKuoD6Init,
                dim9003JoeKuoD6Init,
                dim9004JoeKuoD6Init,
                dim9005JoeKuoD6Init,
                dim9006JoeKuoD6Init,
                dim9007JoeKuoD6Init,
                dim9008JoeKuoD6Init,
                dim9009JoeKuoD6Init,
                dim9010JoeKuoD6Init,
                dim9011JoeKuoD6Init,
                dim9012JoeKuoD6Init,
                dim9013JoeKuoD6Init,
                dim9014JoeKuoD6Init,
                dim9015JoeKuoD6Init,
                dim9016JoeKuoD6Init,
                dim9017JoeKuoD6Init,
                dim9018JoeKuoD6Init,
                dim9019JoeKuoD6Init,
                dim9020JoeKuoD6Init,
                dim9021JoeKuoD6Init,
                dim9022JoeKuoD6Init,
                dim9023JoeKuoD6Init,
                dim9024JoeKuoD6Init,
                dim9025JoeKuoD6Init,
                dim9026JoeKuoD6Init,
                dim9027JoeKuoD6Init,
                dim9028JoeKuoD6Init,
                dim9029JoeKuoD6Init,
                dim9030JoeKuoD6Init,
                dim9031JoeKuoD6Init,
                dim9032JoeKuoD6Init,
                dim9033JoeKuoD6Init,
                dim9034JoeKuoD6Init,
                dim9035JoeKuoD6Init,
                dim9036JoeKuoD6Init,
                dim9037JoeKuoD6Init,
                dim9038JoeKuoD6Init,
                dim9039JoeKuoD6Init,
                dim9040JoeKuoD6Init,
                dim9041JoeKuoD6Init,
                dim9042JoeKuoD6Init,
                dim9043JoeKuoD6Init,
                dim9044JoeKuoD6Init,
                dim9045JoeKuoD6Init,
                dim9046JoeKuoD6Init,
                dim9047JoeKuoD6Init,
                dim9048JoeKuoD6Init,
                dim9049JoeKuoD6Init,
                dim9050JoeKuoD6Init,
                dim9051JoeKuoD6Init,
                dim9052JoeKuoD6Init,
                dim9053JoeKuoD6Init,
                dim9054JoeKuoD6Init,
                dim9055JoeKuoD6Init,
                dim9056JoeKuoD6Init,
                dim9057JoeKuoD6Init,
                dim9058JoeKuoD6Init,
                dim9059JoeKuoD6Init,
                dim9060JoeKuoD6Init,
                dim9061JoeKuoD6Init,
                dim9062JoeKuoD6Init,
                dim9063JoeKuoD6Init,
                dim9064JoeKuoD6Init,
                dim9065JoeKuoD6Init,
                dim9066JoeKuoD6Init,
                dim9067JoeKuoD6Init,
                dim9068JoeKuoD6Init,
                dim9069JoeKuoD6Init,
                dim9070JoeKuoD6Init,
                dim9071JoeKuoD6Init,
                dim9072JoeKuoD6Init,
                dim9073JoeKuoD6Init,
                dim9074JoeKuoD6Init,
                dim9075JoeKuoD6Init,
                dim9076JoeKuoD6Init,
                dim9077JoeKuoD6Init,
                dim9078JoeKuoD6Init,
                dim9079JoeKuoD6Init,
                dim9080JoeKuoD6Init,
                dim9081JoeKuoD6Init,
                dim9082JoeKuoD6Init,
                dim9083JoeKuoD6Init,
                dim9084JoeKuoD6Init,
                dim9085JoeKuoD6Init,
                dim9086JoeKuoD6Init,
                dim9087JoeKuoD6Init,
                dim9088JoeKuoD6Init,
                dim9089JoeKuoD6Init,
                dim9090JoeKuoD6Init,
                dim9091JoeKuoD6Init,
                dim9092JoeKuoD6Init,
                dim9093JoeKuoD6Init,
                dim9094JoeKuoD6Init,
                dim9095JoeKuoD6Init,
                dim9096JoeKuoD6Init,
                dim9097JoeKuoD6Init,
                dim9098JoeKuoD6Init,
                dim9099JoeKuoD6Init,
                dim9100JoeKuoD6Init,
                dim9101JoeKuoD6Init,
                dim9102JoeKuoD6Init,
                dim9103JoeKuoD6Init,
                dim9104JoeKuoD6Init,
                dim9105JoeKuoD6Init,
                dim9106JoeKuoD6Init,
                dim9107JoeKuoD6Init,
                dim9108JoeKuoD6Init,
                dim9109JoeKuoD6Init,
                dim9110JoeKuoD6Init,
                dim9111JoeKuoD6Init,
                dim9112JoeKuoD6Init,
                dim9113JoeKuoD6Init,
                dim9114JoeKuoD6Init,
                dim9115JoeKuoD6Init,
                dim9116JoeKuoD6Init,
                dim9117JoeKuoD6Init,
                dim9118JoeKuoD6Init,
                dim9119JoeKuoD6Init,
                dim9120JoeKuoD6Init,
                dim9121JoeKuoD6Init,
                dim9122JoeKuoD6Init,
                dim9123JoeKuoD6Init,
                dim9124JoeKuoD6Init,
                dim9125JoeKuoD6Init,
                dim9126JoeKuoD6Init,
                dim9127JoeKuoD6Init,
                dim9128JoeKuoD6Init,
                dim9129JoeKuoD6Init,
                dim9130JoeKuoD6Init,
                dim9131JoeKuoD6Init,
                dim9132JoeKuoD6Init,
                dim9133JoeKuoD6Init,
                dim9134JoeKuoD6Init,
                dim9135JoeKuoD6Init,
                dim9136JoeKuoD6Init,
                dim9137JoeKuoD6Init,
                dim9138JoeKuoD6Init,
                dim9139JoeKuoD6Init,
                dim9140JoeKuoD6Init,
                dim9141JoeKuoD6Init,
                dim9142JoeKuoD6Init,
                dim9143JoeKuoD6Init,
                dim9144JoeKuoD6Init,
                dim9145JoeKuoD6Init,
                dim9146JoeKuoD6Init,
                dim9147JoeKuoD6Init,
                dim9148JoeKuoD6Init,
                dim9149JoeKuoD6Init,
                dim9150JoeKuoD6Init,
                dim9151JoeKuoD6Init,
                dim9152JoeKuoD6Init,
                dim9153JoeKuoD6Init,
                dim9154JoeKuoD6Init,
                dim9155JoeKuoD6Init,
                dim9156JoeKuoD6Init,
                dim9157JoeKuoD6Init,
                dim9158JoeKuoD6Init,
                dim9159JoeKuoD6Init,
                dim9160JoeKuoD6Init,
                dim9161JoeKuoD6Init,
                dim9162JoeKuoD6Init,
                dim9163JoeKuoD6Init,
                dim9164JoeKuoD6Init,
                dim9165JoeKuoD6Init,
                dim9166JoeKuoD6Init,
                dim9167JoeKuoD6Init,
                dim9168JoeKuoD6Init,
                dim9169JoeKuoD6Init,
                dim9170JoeKuoD6Init,
                dim9171JoeKuoD6Init,
                dim9172JoeKuoD6Init,
                dim9173JoeKuoD6Init,
                dim9174JoeKuoD6Init,
                dim9175JoeKuoD6Init,
                dim9176JoeKuoD6Init,
                dim9177JoeKuoD6Init,
                dim9178JoeKuoD6Init,
                dim9179JoeKuoD6Init,
                dim9180JoeKuoD6Init,
                dim9181JoeKuoD6Init,
                dim9182JoeKuoD6Init,
                dim9183JoeKuoD6Init,
                dim9184JoeKuoD6Init,
                dim9185JoeKuoD6Init,
                dim9186JoeKuoD6Init,
                dim9187JoeKuoD6Init,
                dim9188JoeKuoD6Init,
                dim9189JoeKuoD6Init,
                dim9190JoeKuoD6Init,
                dim9191JoeKuoD6Init,
                dim9192JoeKuoD6Init,
                dim9193JoeKuoD6Init,
                dim9194JoeKuoD6Init,
                dim9195JoeKuoD6Init,
                dim9196JoeKuoD6Init,
                dim9197JoeKuoD6Init,
                dim9198JoeKuoD6Init,
                dim9199JoeKuoD6Init,
                dim9200JoeKuoD6Init,
                dim9201JoeKuoD6Init,
                dim9202JoeKuoD6Init,
                dim9203JoeKuoD6Init,
                dim9204JoeKuoD6Init,
                dim9205JoeKuoD6Init,
                dim9206JoeKuoD6Init,
                dim9207JoeKuoD6Init,
                dim9208JoeKuoD6Init,
                dim9209JoeKuoD6Init,
                dim9210JoeKuoD6Init,
                dim9211JoeKuoD6Init,
                dim9212JoeKuoD6Init,
                dim9213JoeKuoD6Init,
                dim9214JoeKuoD6Init,
                dim9215JoeKuoD6Init,
                dim9216JoeKuoD6Init,
                dim9217JoeKuoD6Init,
                dim9218JoeKuoD6Init,
                dim9219JoeKuoD6Init,
                dim9220JoeKuoD6Init,
                dim9221JoeKuoD6Init,
                dim9222JoeKuoD6Init,
                dim9223JoeKuoD6Init,
                dim9224JoeKuoD6Init,
                dim9225JoeKuoD6Init,
                dim9226JoeKuoD6Init,
                dim9227JoeKuoD6Init,
                dim9228JoeKuoD6Init,
                dim9229JoeKuoD6Init,
                dim9230JoeKuoD6Init,
                dim9231JoeKuoD6Init,
                dim9232JoeKuoD6Init,
                dim9233JoeKuoD6Init,
                dim9234JoeKuoD6Init,
                dim9235JoeKuoD6Init,
                dim9236JoeKuoD6Init,
                dim9237JoeKuoD6Init,
                dim9238JoeKuoD6Init,
                dim9239JoeKuoD6Init,
                dim9240JoeKuoD6Init,
                dim9241JoeKuoD6Init,
                dim9242JoeKuoD6Init,
                dim9243JoeKuoD6Init,
                dim9244JoeKuoD6Init,
                dim9245JoeKuoD6Init,
                dim9246JoeKuoD6Init,
                dim9247JoeKuoD6Init,
                dim9248JoeKuoD6Init,
                dim9249JoeKuoD6Init,
                dim9250JoeKuoD6Init,
                dim9251JoeKuoD6Init,
                dim9252JoeKuoD6Init,
                dim9253JoeKuoD6Init,
                dim9254JoeKuoD6Init,
                dim9255JoeKuoD6Init,
                dim9256JoeKuoD6Init,
                dim9257JoeKuoD6Init,
                dim9258JoeKuoD6Init,
                dim9259JoeKuoD6Init,
                dim9260JoeKuoD6Init,
                dim9261JoeKuoD6Init,
                dim9262JoeKuoD6Init,
                dim9263JoeKuoD6Init,
                dim9264JoeKuoD6Init,
                dim9265JoeKuoD6Init,
                dim9266JoeKuoD6Init,
                dim9267JoeKuoD6Init,
                dim9268JoeKuoD6Init,
                dim9269JoeKuoD6Init,
                dim9270JoeKuoD6Init,
                dim9271JoeKuoD6Init,
                dim9272JoeKuoD6Init,
                dim9273JoeKuoD6Init,
                dim9274JoeKuoD6Init,
                dim9275JoeKuoD6Init,
                dim9276JoeKuoD6Init,
                dim9277JoeKuoD6Init,
                dim9278JoeKuoD6Init,
                dim9279JoeKuoD6Init,
                dim9280JoeKuoD6Init,
                dim9281JoeKuoD6Init,
                dim9282JoeKuoD6Init,
                dim9283JoeKuoD6Init,
                dim9284JoeKuoD6Init,
                dim9285JoeKuoD6Init,
                dim9286JoeKuoD6Init,
                dim9287JoeKuoD6Init,
                dim9288JoeKuoD6Init,
                dim9289JoeKuoD6Init,
                dim9290JoeKuoD6Init,
                dim9291JoeKuoD6Init,
                dim9292JoeKuoD6Init,
                dim9293JoeKuoD6Init,
                dim9294JoeKuoD6Init,
                dim9295JoeKuoD6Init,
                dim9296JoeKuoD6Init,
                dim9297JoeKuoD6Init,
                dim9298JoeKuoD6Init,
                dim9299JoeKuoD6Init,
                dim9300JoeKuoD6Init,
                dim9301JoeKuoD6Init,
                dim9302JoeKuoD6Init,
                dim9303JoeKuoD6Init,
                dim9304JoeKuoD6Init,
                dim9305JoeKuoD6Init,
                dim9306JoeKuoD6Init,
                dim9307JoeKuoD6Init,
                dim9308JoeKuoD6Init,
                dim9309JoeKuoD6Init,
                dim9310JoeKuoD6Init,
                dim9311JoeKuoD6Init,
                dim9312JoeKuoD6Init,
                dim9313JoeKuoD6Init,
                dim9314JoeKuoD6Init,
                dim9315JoeKuoD6Init,
                dim9316JoeKuoD6Init,
                dim9317JoeKuoD6Init,
                dim9318JoeKuoD6Init,
                dim9319JoeKuoD6Init,
                dim9320JoeKuoD6Init,
                dim9321JoeKuoD6Init,
                dim9322JoeKuoD6Init,
                dim9323JoeKuoD6Init,
                dim9324JoeKuoD6Init,
                dim9325JoeKuoD6Init,
                dim9326JoeKuoD6Init,
                dim9327JoeKuoD6Init,
                dim9328JoeKuoD6Init,
                dim9329JoeKuoD6Init,
                dim9330JoeKuoD6Init,
                dim9331JoeKuoD6Init,
                dim9332JoeKuoD6Init,
                dim9333JoeKuoD6Init,
                dim9334JoeKuoD6Init,
                dim9335JoeKuoD6Init,
                dim9336JoeKuoD6Init,
                dim9337JoeKuoD6Init,
                dim9338JoeKuoD6Init,
                dim9339JoeKuoD6Init,
                dim9340JoeKuoD6Init,
                dim9341JoeKuoD6Init,
                dim9342JoeKuoD6Init,
                dim9343JoeKuoD6Init,
                dim9344JoeKuoD6Init,
                dim9345JoeKuoD6Init,
                dim9346JoeKuoD6Init,
                dim9347JoeKuoD6Init,
                dim9348JoeKuoD6Init,
                dim9349JoeKuoD6Init,
                dim9350JoeKuoD6Init,
                dim9351JoeKuoD6Init,
                dim9352JoeKuoD6Init,
                dim9353JoeKuoD6Init,
                dim9354JoeKuoD6Init,
                dim9355JoeKuoD6Init,
                dim9356JoeKuoD6Init,
                dim9357JoeKuoD6Init,
                dim9358JoeKuoD6Init,
                dim9359JoeKuoD6Init,
                dim9360JoeKuoD6Init,
                dim9361JoeKuoD6Init,
                dim9362JoeKuoD6Init,
                dim9363JoeKuoD6Init,
                dim9364JoeKuoD6Init,
                dim9365JoeKuoD6Init,
                dim9366JoeKuoD6Init,
                dim9367JoeKuoD6Init,
                dim9368JoeKuoD6Init,
                dim9369JoeKuoD6Init,
                dim9370JoeKuoD6Init,
                dim9371JoeKuoD6Init,
                dim9372JoeKuoD6Init,
                dim9373JoeKuoD6Init,
                dim9374JoeKuoD6Init,
                dim9375JoeKuoD6Init,
                dim9376JoeKuoD6Init,
                dim9377JoeKuoD6Init,
                dim9378JoeKuoD6Init,
                dim9379JoeKuoD6Init,
                dim9380JoeKuoD6Init,
                dim9381JoeKuoD6Init,
                dim9382JoeKuoD6Init,
                dim9383JoeKuoD6Init,
                dim9384JoeKuoD6Init,
                dim9385JoeKuoD6Init,
                dim9386JoeKuoD6Init,
                dim9387JoeKuoD6Init,
                dim9388JoeKuoD6Init,
                dim9389JoeKuoD6Init,
                dim9390JoeKuoD6Init,
                dim9391JoeKuoD6Init,
                dim9392JoeKuoD6Init,
                dim9393JoeKuoD6Init,
                dim9394JoeKuoD6Init,
                dim9395JoeKuoD6Init,
                dim9396JoeKuoD6Init,
                dim9397JoeKuoD6Init,
                dim9398JoeKuoD6Init,
                dim9399JoeKuoD6Init,
                dim9400JoeKuoD6Init,
                dim9401JoeKuoD6Init,
                dim9402JoeKuoD6Init,
                dim9403JoeKuoD6Init,
                dim9404JoeKuoD6Init,
                dim9405JoeKuoD6Init,
                dim9406JoeKuoD6Init,
                dim9407JoeKuoD6Init,
                dim9408JoeKuoD6Init,
                dim9409JoeKuoD6Init,
                dim9410JoeKuoD6Init,
                dim9411JoeKuoD6Init,
                dim9412JoeKuoD6Init,
                dim9413JoeKuoD6Init,
                dim9414JoeKuoD6Init,
                dim9415JoeKuoD6Init,
                dim9416JoeKuoD6Init,
                dim9417JoeKuoD6Init,
                dim9418JoeKuoD6Init,
                dim9419JoeKuoD6Init,
                dim9420JoeKuoD6Init,
                dim9421JoeKuoD6Init,
                dim9422JoeKuoD6Init,
                dim9423JoeKuoD6Init,
                dim9424JoeKuoD6Init,
                dim9425JoeKuoD6Init,
                dim9426JoeKuoD6Init,
                dim9427JoeKuoD6Init,
                dim9428JoeKuoD6Init,
                dim9429JoeKuoD6Init,
                dim9430JoeKuoD6Init,
                dim9431JoeKuoD6Init,
                dim9432JoeKuoD6Init,
                dim9433JoeKuoD6Init,
                dim9434JoeKuoD6Init,
                dim9435JoeKuoD6Init,
                dim9436JoeKuoD6Init,
                dim9437JoeKuoD6Init,
                dim9438JoeKuoD6Init,
                dim9439JoeKuoD6Init,
                dim9440JoeKuoD6Init,
                dim9441JoeKuoD6Init,
                dim9442JoeKuoD6Init,
                dim9443JoeKuoD6Init,
                dim9444JoeKuoD6Init,
                dim9445JoeKuoD6Init,
                dim9446JoeKuoD6Init,
                dim9447JoeKuoD6Init,
                dim9448JoeKuoD6Init,
                dim9449JoeKuoD6Init,
                dim9450JoeKuoD6Init,
                dim9451JoeKuoD6Init,
                dim9452JoeKuoD6Init,
                dim9453JoeKuoD6Init,
                dim9454JoeKuoD6Init,
                dim9455JoeKuoD6Init,
                dim9456JoeKuoD6Init,
                dim9457JoeKuoD6Init,
                dim9458JoeKuoD6Init,
                dim9459JoeKuoD6Init,
                dim9460JoeKuoD6Init,
                dim9461JoeKuoD6Init,
                dim9462JoeKuoD6Init,
                dim9463JoeKuoD6Init,
                dim9464JoeKuoD6Init,
                dim9465JoeKuoD6Init,
                dim9466JoeKuoD6Init,
                dim9467JoeKuoD6Init,
                dim9468JoeKuoD6Init,
                dim9469JoeKuoD6Init,
                dim9470JoeKuoD6Init,
                dim9471JoeKuoD6Init,
                dim9472JoeKuoD6Init,
                dim9473JoeKuoD6Init,
                dim9474JoeKuoD6Init,
                dim9475JoeKuoD6Init,
                dim9476JoeKuoD6Init,
                dim9477JoeKuoD6Init,
                dim9478JoeKuoD6Init,
                dim9479JoeKuoD6Init,
                dim9480JoeKuoD6Init,
                dim9481JoeKuoD6Init,
                dim9482JoeKuoD6Init,
                dim9483JoeKuoD6Init,
                dim9484JoeKuoD6Init,
                dim9485JoeKuoD6Init,
                dim9486JoeKuoD6Init,
                dim9487JoeKuoD6Init,
                dim9488JoeKuoD6Init,
                dim9489JoeKuoD6Init,
                dim9490JoeKuoD6Init,
                dim9491JoeKuoD6Init,
                dim9492JoeKuoD6Init,
                dim9493JoeKuoD6Init,
                dim9494JoeKuoD6Init,
                dim9495JoeKuoD6Init,
                dim9496JoeKuoD6Init,
                dim9497JoeKuoD6Init,
                dim9498JoeKuoD6Init,
                dim9499JoeKuoD6Init,
                dim9500JoeKuoD6Init,
                dim9501JoeKuoD6Init,
                dim9502JoeKuoD6Init,
                dim9503JoeKuoD6Init,
                dim9504JoeKuoD6Init,
                dim9505JoeKuoD6Init,
                dim9506JoeKuoD6Init,
                dim9507JoeKuoD6Init,
                dim9508JoeKuoD6Init,
                dim9509JoeKuoD6Init,
                dim9510JoeKuoD6Init,
                dim9511JoeKuoD6Init,
                dim9512JoeKuoD6Init,
                dim9513JoeKuoD6Init,
                dim9514JoeKuoD6Init,
                dim9515JoeKuoD6Init,
                dim9516JoeKuoD6Init,
                dim9517JoeKuoD6Init,
                dim9518JoeKuoD6Init,
                dim9519JoeKuoD6Init,
                dim9520JoeKuoD6Init,
                dim9521JoeKuoD6Init,
                dim9522JoeKuoD6Init,
                dim9523JoeKuoD6Init,
                dim9524JoeKuoD6Init,
                dim9525JoeKuoD6Init,
                dim9526JoeKuoD6Init,
                dim9527JoeKuoD6Init,
                dim9528JoeKuoD6Init,
                dim9529JoeKuoD6Init,
                dim9530JoeKuoD6Init,
                dim9531JoeKuoD6Init,
                dim9532JoeKuoD6Init,
                dim9533JoeKuoD6Init,
                dim9534JoeKuoD6Init,
                dim9535JoeKuoD6Init,
                dim9536JoeKuoD6Init,
                dim9537JoeKuoD6Init,
                dim9538JoeKuoD6Init,
                dim9539JoeKuoD6Init,
                dim9540JoeKuoD6Init,
                dim9541JoeKuoD6Init,
                dim9542JoeKuoD6Init,
                dim9543JoeKuoD6Init,
                dim9544JoeKuoD6Init,
                dim9545JoeKuoD6Init,
                dim9546JoeKuoD6Init,
                dim9547JoeKuoD6Init,
                dim9548JoeKuoD6Init,
                dim9549JoeKuoD6Init,
                dim9550JoeKuoD6Init,
                dim9551JoeKuoD6Init,
                dim9552JoeKuoD6Init,
                dim9553JoeKuoD6Init,
                dim9554JoeKuoD6Init,
                dim9555JoeKuoD6Init,
                dim9556JoeKuoD6Init,
                dim9557JoeKuoD6Init,
                dim9558JoeKuoD6Init,
                dim9559JoeKuoD6Init,
                dim9560JoeKuoD6Init,
                dim9561JoeKuoD6Init,
                dim9562JoeKuoD6Init,
                dim9563JoeKuoD6Init,
                dim9564JoeKuoD6Init,
                dim9565JoeKuoD6Init,
                dim9566JoeKuoD6Init,
                dim9567JoeKuoD6Init,
                dim9568JoeKuoD6Init,
                dim9569JoeKuoD6Init,
                dim9570JoeKuoD6Init,
                dim9571JoeKuoD6Init,
                dim9572JoeKuoD6Init,
                dim9573JoeKuoD6Init,
                dim9574JoeKuoD6Init,
                dim9575JoeKuoD6Init,
                dim9576JoeKuoD6Init,
                dim9577JoeKuoD6Init,
                dim9578JoeKuoD6Init,
                dim9579JoeKuoD6Init,
                dim9580JoeKuoD6Init,
                dim9581JoeKuoD6Init,
                dim9582JoeKuoD6Init,
                dim9583JoeKuoD6Init,
                dim9584JoeKuoD6Init,
                dim9585JoeKuoD6Init,
                dim9586JoeKuoD6Init,
                dim9587JoeKuoD6Init,
                dim9588JoeKuoD6Init,
                dim9589JoeKuoD6Init,
                dim9590JoeKuoD6Init,
                dim9591JoeKuoD6Init,
                dim9592JoeKuoD6Init,
                dim9593JoeKuoD6Init,
                dim9594JoeKuoD6Init,
                dim9595JoeKuoD6Init,
                dim9596JoeKuoD6Init,
                dim9597JoeKuoD6Init,
                dim9598JoeKuoD6Init,
                dim9599JoeKuoD6Init,
                dim9600JoeKuoD6Init,
                dim9601JoeKuoD6Init,
                dim9602JoeKuoD6Init,
                dim9603JoeKuoD6Init,
                dim9604JoeKuoD6Init,
                dim9605JoeKuoD6Init,
                dim9606JoeKuoD6Init,
                dim9607JoeKuoD6Init,
                dim9608JoeKuoD6Init,
                dim9609JoeKuoD6Init,
                dim9610JoeKuoD6Init,
                dim9611JoeKuoD6Init,
                dim9612JoeKuoD6Init,
                dim9613JoeKuoD6Init,
                dim9614JoeKuoD6Init,
                dim9615JoeKuoD6Init,
                dim9616JoeKuoD6Init,
                dim9617JoeKuoD6Init,
                dim9618JoeKuoD6Init,
                dim9619JoeKuoD6Init,
                dim9620JoeKuoD6Init,
                dim9621JoeKuoD6Init,
                dim9622JoeKuoD6Init,
                dim9623JoeKuoD6Init,
                dim9624JoeKuoD6Init,
                dim9625JoeKuoD6Init,
                dim9626JoeKuoD6Init,
                dim9627JoeKuoD6Init,
                dim9628JoeKuoD6Init,
                dim9629JoeKuoD6Init,
                dim9630JoeKuoD6Init,
                dim9631JoeKuoD6Init,
                dim9632JoeKuoD6Init,
                dim9633JoeKuoD6Init,
                dim9634JoeKuoD6Init,
                dim9635JoeKuoD6Init,
                dim9636JoeKuoD6Init,
                dim9637JoeKuoD6Init,
                dim9638JoeKuoD6Init,
                dim9639JoeKuoD6Init,
                dim9640JoeKuoD6Init,
                dim9641JoeKuoD6Init,
                dim9642JoeKuoD6Init,
                dim9643JoeKuoD6Init,
                dim9644JoeKuoD6Init,
                dim9645JoeKuoD6Init,
                dim9646JoeKuoD6Init,
                dim9647JoeKuoD6Init,
                dim9648JoeKuoD6Init,
                dim9649JoeKuoD6Init,
                dim9650JoeKuoD6Init,
                dim9651JoeKuoD6Init,
                dim9652JoeKuoD6Init,
                dim9653JoeKuoD6Init,
                dim9654JoeKuoD6Init,
                dim9655JoeKuoD6Init,
                dim9656JoeKuoD6Init,
                dim9657JoeKuoD6Init,
                dim9658JoeKuoD6Init,
                dim9659JoeKuoD6Init,
                dim9660JoeKuoD6Init,
                dim9661JoeKuoD6Init,
                dim9662JoeKuoD6Init,
                dim9663JoeKuoD6Init,
                dim9664JoeKuoD6Init,
                dim9665JoeKuoD6Init,
                dim9666JoeKuoD6Init,
                dim9667JoeKuoD6Init,
                dim9668JoeKuoD6Init,
                dim9669JoeKuoD6Init,
                dim9670JoeKuoD6Init,
                dim9671JoeKuoD6Init,
                dim9672JoeKuoD6Init,
                dim9673JoeKuoD6Init,
                dim9674JoeKuoD6Init,
                dim9675JoeKuoD6Init,
                dim9676JoeKuoD6Init,
                dim9677JoeKuoD6Init,
                dim9678JoeKuoD6Init,
                dim9679JoeKuoD6Init,
                dim9680JoeKuoD6Init,
                dim9681JoeKuoD6Init,
                dim9682JoeKuoD6Init,
                dim9683JoeKuoD6Init,
                dim9684JoeKuoD6Init,
                dim9685JoeKuoD6Init,
                dim9686JoeKuoD6Init,
                dim9687JoeKuoD6Init,
                dim9688JoeKuoD6Init,
                dim9689JoeKuoD6Init,
                dim9690JoeKuoD6Init,
                dim9691JoeKuoD6Init,
                dim9692JoeKuoD6Init,
                dim9693JoeKuoD6Init,
                dim9694JoeKuoD6Init,
                dim9695JoeKuoD6Init,
                dim9696JoeKuoD6Init,
                dim9697JoeKuoD6Init,
                dim9698JoeKuoD6Init,
                dim9699JoeKuoD6Init,
                dim9700JoeKuoD6Init,
                dim9701JoeKuoD6Init,
                dim9702JoeKuoD6Init,
                dim9703JoeKuoD6Init,
                dim9704JoeKuoD6Init,
                dim9705JoeKuoD6Init,
                dim9706JoeKuoD6Init,
                dim9707JoeKuoD6Init,
                dim9708JoeKuoD6Init,
                dim9709JoeKuoD6Init,
                dim9710JoeKuoD6Init,
                dim9711JoeKuoD6Init,
                dim9712JoeKuoD6Init,
                dim9713JoeKuoD6Init,
                dim9714JoeKuoD6Init,
                dim9715JoeKuoD6Init,
                dim9716JoeKuoD6Init,
                dim9717JoeKuoD6Init,
                dim9718JoeKuoD6Init,
                dim9719JoeKuoD6Init,
                dim9720JoeKuoD6Init,
                dim9721JoeKuoD6Init,
                dim9722JoeKuoD6Init,
                dim9723JoeKuoD6Init,
                dim9724JoeKuoD6Init,
                dim9725JoeKuoD6Init,
                dim9726JoeKuoD6Init,
                dim9727JoeKuoD6Init,
                dim9728JoeKuoD6Init,
                dim9729JoeKuoD6Init,
                dim9730JoeKuoD6Init,
                dim9731JoeKuoD6Init,
                dim9732JoeKuoD6Init,
                dim9733JoeKuoD6Init,
                dim9734JoeKuoD6Init,
                dim9735JoeKuoD6Init,
                dim9736JoeKuoD6Init,
                dim9737JoeKuoD6Init,
                dim9738JoeKuoD6Init,
                dim9739JoeKuoD6Init,
                dim9740JoeKuoD6Init,
                dim9741JoeKuoD6Init,
                dim9742JoeKuoD6Init,
                dim9743JoeKuoD6Init,
                dim9744JoeKuoD6Init,
                dim9745JoeKuoD6Init,
                dim9746JoeKuoD6Init,
                dim9747JoeKuoD6Init,
                dim9748JoeKuoD6Init,
                dim9749JoeKuoD6Init,
                dim9750JoeKuoD6Init,
                dim9751JoeKuoD6Init,
                dim9752JoeKuoD6Init,
                dim9753JoeKuoD6Init,
                dim9754JoeKuoD6Init,
                dim9755JoeKuoD6Init,
                dim9756JoeKuoD6Init,
                dim9757JoeKuoD6Init,
                dim9758JoeKuoD6Init,
                dim9759JoeKuoD6Init,
                dim9760JoeKuoD6Init,
                dim9761JoeKuoD6Init,
                dim9762JoeKuoD6Init,
                dim9763JoeKuoD6Init,
                dim9764JoeKuoD6Init,
                dim9765JoeKuoD6Init,
                dim9766JoeKuoD6Init,
                dim9767JoeKuoD6Init,
                dim9768JoeKuoD6Init,
                dim9769JoeKuoD6Init,
                dim9770JoeKuoD6Init,
                dim9771JoeKuoD6Init,
                dim9772JoeKuoD6Init,
                dim9773JoeKuoD6Init,
                dim9774JoeKuoD6Init,
                dim9775JoeKuoD6Init,
                dim9776JoeKuoD6Init,
                dim9777JoeKuoD6Init,
                dim9778JoeKuoD6Init,
                dim9779JoeKuoD6Init,
                dim9780JoeKuoD6Init,
                dim9781JoeKuoD6Init,
                dim9782JoeKuoD6Init,
                dim9783JoeKuoD6Init,
                dim9784JoeKuoD6Init,
                dim9785JoeKuoD6Init,
                dim9786JoeKuoD6Init,
                dim9787JoeKuoD6Init,
                dim9788JoeKuoD6Init,
                dim9789JoeKuoD6Init,
                dim9790JoeKuoD6Init,
                dim9791JoeKuoD6Init,
                dim9792JoeKuoD6Init,
                dim9793JoeKuoD6Init,
                dim9794JoeKuoD6Init,
                dim9795JoeKuoD6Init,
                dim9796JoeKuoD6Init,
                dim9797JoeKuoD6Init,
                dim9798JoeKuoD6Init,
                dim9799JoeKuoD6Init,
                dim9800JoeKuoD6Init,
                dim9801JoeKuoD6Init,
                dim9802JoeKuoD6Init,
                dim9803JoeKuoD6Init,
                dim9804JoeKuoD6Init,
                dim9805JoeKuoD6Init,
                dim9806JoeKuoD6Init,
                dim9807JoeKuoD6Init,
                dim9808JoeKuoD6Init,
                dim9809JoeKuoD6Init,
                dim9810JoeKuoD6Init,
                dim9811JoeKuoD6Init,
                dim9812JoeKuoD6Init,
                dim9813JoeKuoD6Init,
                dim9814JoeKuoD6Init,
                dim9815JoeKuoD6Init,
                dim9816JoeKuoD6Init,
                dim9817JoeKuoD6Init,
                dim9818JoeKuoD6Init,
                dim9819JoeKuoD6Init,
                dim9820JoeKuoD6Init,
                dim9821JoeKuoD6Init,
                dim9822JoeKuoD6Init,
                dim9823JoeKuoD6Init,
                dim9824JoeKuoD6Init,
                dim9825JoeKuoD6Init,
                dim9826JoeKuoD6Init,
                dim9827JoeKuoD6Init,
                dim9828JoeKuoD6Init,
                dim9829JoeKuoD6Init,
                dim9830JoeKuoD6Init,
                dim9831JoeKuoD6Init,
                dim9832JoeKuoD6Init,
                dim9833JoeKuoD6Init,
                dim9834JoeKuoD6Init,
                dim9835JoeKuoD6Init,
                dim9836JoeKuoD6Init,
                dim9837JoeKuoD6Init,
                dim9838JoeKuoD6Init,
                dim9839JoeKuoD6Init,
                dim9840JoeKuoD6Init,
                dim9841JoeKuoD6Init,
                dim9842JoeKuoD6Init,
                dim9843JoeKuoD6Init,
                dim9844JoeKuoD6Init,
                dim9845JoeKuoD6Init,
                dim9846JoeKuoD6Init,
                dim9847JoeKuoD6Init,
                dim9848JoeKuoD6Init,
                dim9849JoeKuoD6Init,
                dim9850JoeKuoD6Init,
                dim9851JoeKuoD6Init,
                dim9852JoeKuoD6Init,
                dim9853JoeKuoD6Init,
                dim9854JoeKuoD6Init,
                dim9855JoeKuoD6Init,
                dim9856JoeKuoD6Init,
                dim9857JoeKuoD6Init,
                dim9858JoeKuoD6Init,
                dim9859JoeKuoD6Init,
                dim9860JoeKuoD6Init,
                dim9861JoeKuoD6Init,
                dim9862JoeKuoD6Init,
                dim9863JoeKuoD6Init,
                dim9864JoeKuoD6Init,
                dim9865JoeKuoD6Init,
                dim9866JoeKuoD6Init,
                dim9867JoeKuoD6Init,
                dim9868JoeKuoD6Init,
                dim9869JoeKuoD6Init,
                dim9870JoeKuoD6Init,
                dim9871JoeKuoD6Init,
                dim9872JoeKuoD6Init,
                dim9873JoeKuoD6Init,
                dim9874JoeKuoD6Init,
                dim9875JoeKuoD6Init,
                dim9876JoeKuoD6Init,
                dim9877JoeKuoD6Init,
                dim9878JoeKuoD6Init,
                dim9879JoeKuoD6Init,
                dim9880JoeKuoD6Init,
                dim9881JoeKuoD6Init,
                dim9882JoeKuoD6Init,
                dim9883JoeKuoD6Init,
                dim9884JoeKuoD6Init,
                dim9885JoeKuoD6Init,
                dim9886JoeKuoD6Init,
                dim9887JoeKuoD6Init,
                dim9888JoeKuoD6Init,
                dim9889JoeKuoD6Init,
                dim9890JoeKuoD6Init,
                dim9891JoeKuoD6Init,
                dim9892JoeKuoD6Init,
                dim9893JoeKuoD6Init,
                dim9894JoeKuoD6Init,
                dim9895JoeKuoD6Init,
                dim9896JoeKuoD6Init,
                dim9897JoeKuoD6Init,
                dim9898JoeKuoD6Init,
                dim9899JoeKuoD6Init,
                dim9900JoeKuoD6Init,
                dim9901JoeKuoD6Init,
                dim9902JoeKuoD6Init,
                dim9903JoeKuoD6Init,
                dim9904JoeKuoD6Init,
                dim9905JoeKuoD6Init,
                dim9906JoeKuoD6Init,
                dim9907JoeKuoD6Init,
                dim9908JoeKuoD6Init,
                dim9909JoeKuoD6Init,
                dim9910JoeKuoD6Init,
                dim9911JoeKuoD6Init,
                dim9912JoeKuoD6Init,
                dim9913JoeKuoD6Init,
                dim9914JoeKuoD6Init,
                dim9915JoeKuoD6Init,
                dim9916JoeKuoD6Init,
                dim9917JoeKuoD6Init,
                dim9918JoeKuoD6Init,
                dim9919JoeKuoD6Init,
                dim9920JoeKuoD6Init,
                dim9921JoeKuoD6Init,
                dim9922JoeKuoD6Init,
                dim9923JoeKuoD6Init,
                dim9924JoeKuoD6Init,
                dim9925JoeKuoD6Init,
                dim9926JoeKuoD6Init,
                dim9927JoeKuoD6Init,
                dim9928JoeKuoD6Init,
                dim9929JoeKuoD6Init,
                dim9930JoeKuoD6Init,
                dim9931JoeKuoD6Init,
                dim9932JoeKuoD6Init,
                dim9933JoeKuoD6Init,
                dim9934JoeKuoD6Init,
                dim9935JoeKuoD6Init,
                dim9936JoeKuoD6Init,
                dim9937JoeKuoD6Init,
                dim9938JoeKuoD6Init,
                dim9939JoeKuoD6Init,
                dim9940JoeKuoD6Init,
                dim9941JoeKuoD6Init,
                dim9942JoeKuoD6Init,
                dim9943JoeKuoD6Init,
                dim9944JoeKuoD6Init,
                dim9945JoeKuoD6Init,
                dim9946JoeKuoD6Init,
                dim9947JoeKuoD6Init,
                dim9948JoeKuoD6Init,
                dim9949JoeKuoD6Init,
                dim9950JoeKuoD6Init,
                dim9951JoeKuoD6Init,
                dim9952JoeKuoD6Init,
                dim9953JoeKuoD6Init,
                dim9954JoeKuoD6Init,
                dim9955JoeKuoD6Init,
                dim9956JoeKuoD6Init,
                dim9957JoeKuoD6Init,
                dim9958JoeKuoD6Init,
                dim9959JoeKuoD6Init,
                dim9960JoeKuoD6Init,
                dim9961JoeKuoD6Init,
                dim9962JoeKuoD6Init,
                dim9963JoeKuoD6Init,
                dim9964JoeKuoD6Init,
                dim9965JoeKuoD6Init,
                dim9966JoeKuoD6Init,
                dim9967JoeKuoD6Init,
                dim9968JoeKuoD6Init,
                dim9969JoeKuoD6Init,
                dim9970JoeKuoD6Init,
                dim9971JoeKuoD6Init,
                dim9972JoeKuoD6Init,
                dim9973JoeKuoD6Init,
                dim9974JoeKuoD6Init,
                dim9975JoeKuoD6Init,
                dim9976JoeKuoD6Init,
                dim9977JoeKuoD6Init,
                dim9978JoeKuoD6Init,
                dim9979JoeKuoD6Init,
                dim9980JoeKuoD6Init,
                dim9981JoeKuoD6Init,
                dim9982JoeKuoD6Init,
                dim9983JoeKuoD6Init,
                dim9984JoeKuoD6Init,
                dim9985JoeKuoD6Init,
                dim9986JoeKuoD6Init,
                dim9987JoeKuoD6Init,
                dim9988JoeKuoD6Init,
                dim9989JoeKuoD6Init,
                dim9990JoeKuoD6Init,
                dim9991JoeKuoD6Init,
                dim9992JoeKuoD6Init,
                dim9993JoeKuoD6Init,
                dim9994JoeKuoD6Init,
                dim9995JoeKuoD6Init,
                dim9996JoeKuoD6Init,
                dim9997JoeKuoD6Init,
                dim9998JoeKuoD6Init,
                dim9999JoeKuoD6Init,
                dim10000JoeKuoD6Init,
                dim10001JoeKuoD6Init,
                dim10002JoeKuoD6Init,
                dim10003JoeKuoD6Init,
                dim10004JoeKuoD6Init,
                dim10005JoeKuoD6Init,
                dim10006JoeKuoD6Init,
                dim10007JoeKuoD6Init,
                dim10008JoeKuoD6Init,
                dim10009JoeKuoD6Init,
                dim10010JoeKuoD6Init,
                dim10011JoeKuoD6Init,
                dim10012JoeKuoD6Init,
                dim10013JoeKuoD6Init,
                dim10014JoeKuoD6Init,
                dim10015JoeKuoD6Init,
                dim10016JoeKuoD6Init,
                dim10017JoeKuoD6Init,
                dim10018JoeKuoD6Init,
                dim10019JoeKuoD6Init,
                dim10020JoeKuoD6Init,
                dim10021JoeKuoD6Init,
                dim10022JoeKuoD6Init,
                dim10023JoeKuoD6Init,
                dim10024JoeKuoD6Init,
                dim10025JoeKuoD6Init,
                dim10026JoeKuoD6Init,
                dim10027JoeKuoD6Init,
                dim10028JoeKuoD6Init,
                dim10029JoeKuoD6Init,
                dim10030JoeKuoD6Init,
                dim10031JoeKuoD6Init,
                dim10032JoeKuoD6Init,
                dim10033JoeKuoD6Init,
                dim10034JoeKuoD6Init,
                dim10035JoeKuoD6Init,
                dim10036JoeKuoD6Init,
                dim10037JoeKuoD6Init,
                dim10038JoeKuoD6Init,
                dim10039JoeKuoD6Init,
                dim10040JoeKuoD6Init,
                dim10041JoeKuoD6Init,
                dim10042JoeKuoD6Init,
                dim10043JoeKuoD6Init,
                dim10044JoeKuoD6Init,
                dim10045JoeKuoD6Init,
                dim10046JoeKuoD6Init,
                dim10047JoeKuoD6Init,
                dim10048JoeKuoD6Init,
                dim10049JoeKuoD6Init,
                dim10050JoeKuoD6Init,
                dim10051JoeKuoD6Init,
                dim10052JoeKuoD6Init,
                dim10053JoeKuoD6Init,
                dim10054JoeKuoD6Init,
                dim10055JoeKuoD6Init,
                dim10056JoeKuoD6Init,
                dim10057JoeKuoD6Init,
                dim10058JoeKuoD6Init,
                dim10059JoeKuoD6Init,
                dim10060JoeKuoD6Init,
                dim10061JoeKuoD6Init,
                dim10062JoeKuoD6Init,
                dim10063JoeKuoD6Init,
                dim10064JoeKuoD6Init,
                dim10065JoeKuoD6Init,
                dim10066JoeKuoD6Init,
                dim10067JoeKuoD6Init,
                dim10068JoeKuoD6Init,
                dim10069JoeKuoD6Init,
                dim10070JoeKuoD6Init,
                dim10071JoeKuoD6Init,
                dim10072JoeKuoD6Init,
                dim10073JoeKuoD6Init,
                dim10074JoeKuoD6Init,
                dim10075JoeKuoD6Init,
                dim10076JoeKuoD6Init,
                dim10077JoeKuoD6Init,
                dim10078JoeKuoD6Init,
                dim10079JoeKuoD6Init,
                dim10080JoeKuoD6Init,
                dim10081JoeKuoD6Init,
                dim10082JoeKuoD6Init,
                dim10083JoeKuoD6Init,
                dim10084JoeKuoD6Init,
                dim10085JoeKuoD6Init,
                dim10086JoeKuoD6Init,
                dim10087JoeKuoD6Init,
                dim10088JoeKuoD6Init,
                dim10089JoeKuoD6Init,
                dim10090JoeKuoD6Init,
                dim10091JoeKuoD6Init,
                dim10092JoeKuoD6Init,
                dim10093JoeKuoD6Init,
                dim10094JoeKuoD6Init,
                dim10095JoeKuoD6Init,
                dim10096JoeKuoD6Init,
                dim10097JoeKuoD6Init,
                dim10098JoeKuoD6Init,
                dim10099JoeKuoD6Init,
                dim10100JoeKuoD6Init,
                dim10101JoeKuoD6Init,
                dim10102JoeKuoD6Init,
                dim10103JoeKuoD6Init,
                dim10104JoeKuoD6Init,
                dim10105JoeKuoD6Init,
                dim10106JoeKuoD6Init,
                dim10107JoeKuoD6Init,
                dim10108JoeKuoD6Init,
                dim10109JoeKuoD6Init,
                dim10110JoeKuoD6Init,
                dim10111JoeKuoD6Init,
                dim10112JoeKuoD6Init,
                dim10113JoeKuoD6Init,
                dim10114JoeKuoD6Init,
                dim10115JoeKuoD6Init,
                dim10116JoeKuoD6Init,
                dim10117JoeKuoD6Init,
                dim10118JoeKuoD6Init,
                dim10119JoeKuoD6Init,
                dim10120JoeKuoD6Init,
                dim10121JoeKuoD6Init,
                dim10122JoeKuoD6Init,
                dim10123JoeKuoD6Init,
                dim10124JoeKuoD6Init,
                dim10125JoeKuoD6Init,
                dim10126JoeKuoD6Init,
                dim10127JoeKuoD6Init,
                dim10128JoeKuoD6Init,
                dim10129JoeKuoD6Init,
                dim10130JoeKuoD6Init,
                dim10131JoeKuoD6Init,
                dim10132JoeKuoD6Init,
                dim10133JoeKuoD6Init,
                dim10134JoeKuoD6Init,
                dim10135JoeKuoD6Init,
                dim10136JoeKuoD6Init,
                dim10137JoeKuoD6Init,
                dim10138JoeKuoD6Init,
                dim10139JoeKuoD6Init,
                dim10140JoeKuoD6Init,
                dim10141JoeKuoD6Init,
                dim10142JoeKuoD6Init,
                dim10143JoeKuoD6Init,
                dim10144JoeKuoD6Init,
                dim10145JoeKuoD6Init,
                dim10146JoeKuoD6Init,
                dim10147JoeKuoD6Init,
                dim10148JoeKuoD6Init,
                dim10149JoeKuoD6Init,
                dim10150JoeKuoD6Init,
                dim10151JoeKuoD6Init,
                dim10152JoeKuoD6Init,
                dim10153JoeKuoD6Init,
                dim10154JoeKuoD6Init,
                dim10155JoeKuoD6Init,
                dim10156JoeKuoD6Init,
                dim10157JoeKuoD6Init,
                dim10158JoeKuoD6Init,
                dim10159JoeKuoD6Init,
                dim10160JoeKuoD6Init,
                dim10161JoeKuoD6Init,
                dim10162JoeKuoD6Init,
                dim10163JoeKuoD6Init,
                dim10164JoeKuoD6Init,
                dim10165JoeKuoD6Init,
                dim10166JoeKuoD6Init,
                dim10167JoeKuoD6Init,
                dim10168JoeKuoD6Init,
                dim10169JoeKuoD6Init,
                dim10170JoeKuoD6Init,
                dim10171JoeKuoD6Init,
                dim10172JoeKuoD6Init,
                dim10173JoeKuoD6Init,
                dim10174JoeKuoD6Init,
                dim10175JoeKuoD6Init,
                dim10176JoeKuoD6Init,
                dim10177JoeKuoD6Init,
                dim10178JoeKuoD6Init,
                dim10179JoeKuoD6Init,
                dim10180JoeKuoD6Init,
                dim10181JoeKuoD6Init,
                dim10182JoeKuoD6Init,
                dim10183JoeKuoD6Init,
                dim10184JoeKuoD6Init,
                dim10185JoeKuoD6Init,
                dim10186JoeKuoD6Init,
                dim10187JoeKuoD6Init,
                dim10188JoeKuoD6Init,
                dim10189JoeKuoD6Init,
                dim10190JoeKuoD6Init,
                dim10191JoeKuoD6Init,
                dim10192JoeKuoD6Init,
                dim10193JoeKuoD6Init,
                dim10194JoeKuoD6Init,
                dim10195JoeKuoD6Init,
                dim10196JoeKuoD6Init,
                dim10197JoeKuoD6Init,
                dim10198JoeKuoD6Init,
                dim10199JoeKuoD6Init,
                dim10200JoeKuoD6Init,
                dim10201JoeKuoD6Init,
                dim10202JoeKuoD6Init,
                dim10203JoeKuoD6Init,
                dim10204JoeKuoD6Init,
                dim10205JoeKuoD6Init,
                dim10206JoeKuoD6Init,
                dim10207JoeKuoD6Init,
                dim10208JoeKuoD6Init,
                dim10209JoeKuoD6Init,
                dim10210JoeKuoD6Init,
                dim10211JoeKuoD6Init,
                dim10212JoeKuoD6Init,
                dim10213JoeKuoD6Init,
                dim10214JoeKuoD6Init,
                dim10215JoeKuoD6Init,
                dim10216JoeKuoD6Init,
                dim10217JoeKuoD6Init,
                dim10218JoeKuoD6Init,
                dim10219JoeKuoD6Init,
                dim10220JoeKuoD6Init,
                dim10221JoeKuoD6Init,
                dim10222JoeKuoD6Init,
                dim10223JoeKuoD6Init,
                dim10224JoeKuoD6Init,
                dim10225JoeKuoD6Init,
                dim10226JoeKuoD6Init,
                dim10227JoeKuoD6Init,
                dim10228JoeKuoD6Init,
                dim10229JoeKuoD6Init,
                dim10230JoeKuoD6Init,
                dim10231JoeKuoD6Init,
                dim10232JoeKuoD6Init,
                dim10233JoeKuoD6Init,
                dim10234JoeKuoD6Init,
                dim10235JoeKuoD6Init,
                dim10236JoeKuoD6Init,
                dim10237JoeKuoD6Init,
                dim10238JoeKuoD6Init,
                dim10239JoeKuoD6Init,
                dim10240JoeKuoD6Init,
                dim10241JoeKuoD6Init,
                dim10242JoeKuoD6Init,
                dim10243JoeKuoD6Init,
                dim10244JoeKuoD6Init,
                dim10245JoeKuoD6Init,
                dim10246JoeKuoD6Init,
                dim10247JoeKuoD6Init,
                dim10248JoeKuoD6Init,
                dim10249JoeKuoD6Init,
                dim10250JoeKuoD6Init,
                dim10251JoeKuoD6Init,
                dim10252JoeKuoD6Init,
                dim10253JoeKuoD6Init,
                dim10254JoeKuoD6Init,
                dim10255JoeKuoD6Init,
                dim10256JoeKuoD6Init,
                dim10257JoeKuoD6Init,
                dim10258JoeKuoD6Init,
                dim10259JoeKuoD6Init,
                dim10260JoeKuoD6Init,
                dim10261JoeKuoD6Init,
                dim10262JoeKuoD6Init,
                dim10263JoeKuoD6Init,
                dim10264JoeKuoD6Init,
                dim10265JoeKuoD6Init,
                dim10266JoeKuoD6Init,
                dim10267JoeKuoD6Init,
                dim10268JoeKuoD6Init,
                dim10269JoeKuoD6Init,
                dim10270JoeKuoD6Init,
                dim10271JoeKuoD6Init,
                dim10272JoeKuoD6Init,
                dim10273JoeKuoD6Init,
                dim10274JoeKuoD6Init,
                dim10275JoeKuoD6Init,
                dim10276JoeKuoD6Init,
                dim10277JoeKuoD6Init,
                dim10278JoeKuoD6Init,
                dim10279JoeKuoD6Init,
                dim10280JoeKuoD6Init,
                dim10281JoeKuoD6Init,
                dim10282JoeKuoD6Init,
                dim10283JoeKuoD6Init,
                dim10284JoeKuoD6Init,
                dim10285JoeKuoD6Init,
                dim10286JoeKuoD6Init,
                dim10287JoeKuoD6Init,
                dim10288JoeKuoD6Init,
                dim10289JoeKuoD6Init,
                dim10290JoeKuoD6Init,
                dim10291JoeKuoD6Init,
                dim10292JoeKuoD6Init,
                dim10293JoeKuoD6Init,
                dim10294JoeKuoD6Init,
                dim10295JoeKuoD6Init,
                dim10296JoeKuoD6Init,
                dim10297JoeKuoD6Init,
                dim10298JoeKuoD6Init,
                dim10299JoeKuoD6Init,
                dim10300JoeKuoD6Init,
                dim10301JoeKuoD6Init,
                dim10302JoeKuoD6Init,
                dim10303JoeKuoD6Init,
                dim10304JoeKuoD6Init,
                dim10305JoeKuoD6Init,
                dim10306JoeKuoD6Init,
                dim10307JoeKuoD6Init,
                dim10308JoeKuoD6Init,
                dim10309JoeKuoD6Init,
                dim10310JoeKuoD6Init,
                dim10311JoeKuoD6Init,
                dim10312JoeKuoD6Init,
                dim10313JoeKuoD6Init,
                dim10314JoeKuoD6Init,
                dim10315JoeKuoD6Init,
                dim10316JoeKuoD6Init,
                dim10317JoeKuoD6Init,
                dim10318JoeKuoD6Init,
                dim10319JoeKuoD6Init,
                dim10320JoeKuoD6Init,
                dim10321JoeKuoD6Init,
                dim10322JoeKuoD6Init,
                dim10323JoeKuoD6Init,
                dim10324JoeKuoD6Init,
                dim10325JoeKuoD6Init,
                dim10326JoeKuoD6Init,
                dim10327JoeKuoD6Init,
                dim10328JoeKuoD6Init,
                dim10329JoeKuoD6Init,
                dim10330JoeKuoD6Init,
                dim10331JoeKuoD6Init,
                dim10332JoeKuoD6Init,
                dim10333JoeKuoD6Init,
                dim10334JoeKuoD6Init,
                dim10335JoeKuoD6Init,
                dim10336JoeKuoD6Init,
                dim10337JoeKuoD6Init,
                dim10338JoeKuoD6Init,
                dim10339JoeKuoD6Init,
                dim10340JoeKuoD6Init,
                dim10341JoeKuoD6Init,
                dim10342JoeKuoD6Init,
                dim10343JoeKuoD6Init,
                dim10344JoeKuoD6Init,
                dim10345JoeKuoD6Init,
                dim10346JoeKuoD6Init,
                dim10347JoeKuoD6Init,
                dim10348JoeKuoD6Init,
                dim10349JoeKuoD6Init,
                dim10350JoeKuoD6Init,
                dim10351JoeKuoD6Init,
                dim10352JoeKuoD6Init,
                dim10353JoeKuoD6Init,
                dim10354JoeKuoD6Init,
                dim10355JoeKuoD6Init,
                dim10356JoeKuoD6Init,
                dim10357JoeKuoD6Init,
                dim10358JoeKuoD6Init,
                dim10359JoeKuoD6Init,
                dim10360JoeKuoD6Init,
                dim10361JoeKuoD6Init,
                dim10362JoeKuoD6Init,
                dim10363JoeKuoD6Init,
                dim10364JoeKuoD6Init,
                dim10365JoeKuoD6Init,
                dim10366JoeKuoD6Init,
                dim10367JoeKuoD6Init,
                dim10368JoeKuoD6Init,
                dim10369JoeKuoD6Init,
                dim10370JoeKuoD6Init,
                dim10371JoeKuoD6Init,
                dim10372JoeKuoD6Init,
                dim10373JoeKuoD6Init,
                dim10374JoeKuoD6Init,
                dim10375JoeKuoD6Init,
                dim10376JoeKuoD6Init,
                dim10377JoeKuoD6Init,
                dim10378JoeKuoD6Init,
                dim10379JoeKuoD6Init,
                dim10380JoeKuoD6Init,
                dim10381JoeKuoD6Init,
                dim10382JoeKuoD6Init,
                dim10383JoeKuoD6Init,
                dim10384JoeKuoD6Init,
                dim10385JoeKuoD6Init,
                dim10386JoeKuoD6Init,
                dim10387JoeKuoD6Init,
                dim10388JoeKuoD6Init,
                dim10389JoeKuoD6Init,
                dim10390JoeKuoD6Init,
                dim10391JoeKuoD6Init,
                dim10392JoeKuoD6Init,
                dim10393JoeKuoD6Init,
                dim10394JoeKuoD6Init,
                dim10395JoeKuoD6Init,
                dim10396JoeKuoD6Init,
                dim10397JoeKuoD6Init,
                dim10398JoeKuoD6Init,
                dim10399JoeKuoD6Init,
                dim10400JoeKuoD6Init,
                dim10401JoeKuoD6Init,
                dim10402JoeKuoD6Init,
                dim10403JoeKuoD6Init,
                dim10404JoeKuoD6Init,
                dim10405JoeKuoD6Init,
                dim10406JoeKuoD6Init,
                dim10407JoeKuoD6Init,
                dim10408JoeKuoD6Init,
                dim10409JoeKuoD6Init,
                dim10410JoeKuoD6Init,
                dim10411JoeKuoD6Init,
                dim10412JoeKuoD6Init,
                dim10413JoeKuoD6Init,
                dim10414JoeKuoD6Init,
                dim10415JoeKuoD6Init,
                dim10416JoeKuoD6Init,
                dim10417JoeKuoD6Init,
                dim10418JoeKuoD6Init,
                dim10419JoeKuoD6Init,
                dim10420JoeKuoD6Init,
                dim10421JoeKuoD6Init,
                dim10422JoeKuoD6Init,
                dim10423JoeKuoD6Init,
                dim10424JoeKuoD6Init,
                dim10425JoeKuoD6Init,
                dim10426JoeKuoD6Init,
                dim10427JoeKuoD6Init,
                dim10428JoeKuoD6Init,
                dim10429JoeKuoD6Init,
                dim10430JoeKuoD6Init,
                dim10431JoeKuoD6Init,
                dim10432JoeKuoD6Init,
                dim10433JoeKuoD6Init,
                dim10434JoeKuoD6Init,
                dim10435JoeKuoD6Init,
                dim10436JoeKuoD6Init,
                dim10437JoeKuoD6Init,
                dim10438JoeKuoD6Init,
                dim10439JoeKuoD6Init,
                dim10440JoeKuoD6Init,
                dim10441JoeKuoD6Init,
                dim10442JoeKuoD6Init,
                dim10443JoeKuoD6Init,
                dim10444JoeKuoD6Init,
                dim10445JoeKuoD6Init,
                dim10446JoeKuoD6Init,
                dim10447JoeKuoD6Init,
                dim10448JoeKuoD6Init,
                dim10449JoeKuoD6Init,
                dim10450JoeKuoD6Init,
                dim10451JoeKuoD6Init,
                dim10452JoeKuoD6Init,
                dim10453JoeKuoD6Init,
                dim10454JoeKuoD6Init,
                dim10455JoeKuoD6Init,
                dim10456JoeKuoD6Init,
                dim10457JoeKuoD6Init,
                dim10458JoeKuoD6Init,
                dim10459JoeKuoD6Init,
                dim10460JoeKuoD6Init,
                dim10461JoeKuoD6Init,
                dim10462JoeKuoD6Init,
                dim10463JoeKuoD6Init,
                dim10464JoeKuoD6Init,
                dim10465JoeKuoD6Init,
                dim10466JoeKuoD6Init,
                dim10467JoeKuoD6Init,
                dim10468JoeKuoD6Init,
                dim10469JoeKuoD6Init,
                dim10470JoeKuoD6Init,
                dim10471JoeKuoD6Init,
                dim10472JoeKuoD6Init,
                dim10473JoeKuoD6Init,
                dim10474JoeKuoD6Init,
                dim10475JoeKuoD6Init,
                dim10476JoeKuoD6Init,
                dim10477JoeKuoD6Init,
                dim10478JoeKuoD6Init,
                dim10479JoeKuoD6Init,
                dim10480JoeKuoD6Init,
                dim10481JoeKuoD6Init,
                dim10482JoeKuoD6Init,
                dim10483JoeKuoD6Init,
                dim10484JoeKuoD6Init,
                dim10485JoeKuoD6Init,
                dim10486JoeKuoD6Init,
                dim10487JoeKuoD6Init,
                dim10488JoeKuoD6Init,
                dim10489JoeKuoD6Init,
                dim10490JoeKuoD6Init,
                dim10491JoeKuoD6Init,
                dim10492JoeKuoD6Init,
                dim10493JoeKuoD6Init,
                dim10494JoeKuoD6Init,
                dim10495JoeKuoD6Init,
                dim10496JoeKuoD6Init,
                dim10497JoeKuoD6Init,
                dim10498JoeKuoD6Init,
                dim10499JoeKuoD6Init,
                dim10500JoeKuoD6Init,
                dim10501JoeKuoD6Init,
                dim10502JoeKuoD6Init,
                dim10503JoeKuoD6Init,
                dim10504JoeKuoD6Init,
                dim10505JoeKuoD6Init,
                dim10506JoeKuoD6Init,
                dim10507JoeKuoD6Init,
                dim10508JoeKuoD6Init,
                dim10509JoeKuoD6Init,
                dim10510JoeKuoD6Init,
                dim10511JoeKuoD6Init,
                dim10512JoeKuoD6Init,
                dim10513JoeKuoD6Init,
                dim10514JoeKuoD6Init,
                dim10515JoeKuoD6Init,
                dim10516JoeKuoD6Init,
                dim10517JoeKuoD6Init,
                dim10518JoeKuoD6Init,
                dim10519JoeKuoD6Init,
                dim10520JoeKuoD6Init,
                dim10521JoeKuoD6Init,
                dim10522JoeKuoD6Init,
                dim10523JoeKuoD6Init,
                dim10524JoeKuoD6Init,
                dim10525JoeKuoD6Init,
                dim10526JoeKuoD6Init,
                dim10527JoeKuoD6Init,
                dim10528JoeKuoD6Init,
                dim10529JoeKuoD6Init,
                dim10530JoeKuoD6Init,
                dim10531JoeKuoD6Init,
                dim10532JoeKuoD6Init,
                dim10533JoeKuoD6Init,
                dim10534JoeKuoD6Init,
                dim10535JoeKuoD6Init,
                dim10536JoeKuoD6Init,
                dim10537JoeKuoD6Init,
                dim10538JoeKuoD6Init,
                dim10539JoeKuoD6Init,
                dim10540JoeKuoD6Init,
                dim10541JoeKuoD6Init,
                dim10542JoeKuoD6Init,
                dim10543JoeKuoD6Init,
                dim10544JoeKuoD6Init,
                dim10545JoeKuoD6Init,
                dim10546JoeKuoD6Init,
                dim10547JoeKuoD6Init,
                dim10548JoeKuoD6Init,
                dim10549JoeKuoD6Init,
                dim10550JoeKuoD6Init,
                dim10551JoeKuoD6Init,
                dim10552JoeKuoD6Init,
                dim10553JoeKuoD6Init,
                dim10554JoeKuoD6Init,
                dim10555JoeKuoD6Init,
                dim10556JoeKuoD6Init,
                dim10557JoeKuoD6Init,
                dim10558JoeKuoD6Init,
                dim10559JoeKuoD6Init,
                dim10560JoeKuoD6Init,
                dim10561JoeKuoD6Init,
                dim10562JoeKuoD6Init,
                dim10563JoeKuoD6Init,
                dim10564JoeKuoD6Init,
                dim10565JoeKuoD6Init,
                dim10566JoeKuoD6Init,
                dim10567JoeKuoD6Init,
                dim10568JoeKuoD6Init,
                dim10569JoeKuoD6Init,
                dim10570JoeKuoD6Init,
                dim10571JoeKuoD6Init,
                dim10572JoeKuoD6Init,
                dim10573JoeKuoD6Init,
                dim10574JoeKuoD6Init,
                dim10575JoeKuoD6Init,
                dim10576JoeKuoD6Init,
                dim10577JoeKuoD6Init,
                dim10578JoeKuoD6Init,
                dim10579JoeKuoD6Init,
                dim10580JoeKuoD6Init,
                dim10581JoeKuoD6Init,
                dim10582JoeKuoD6Init,
                dim10583JoeKuoD6Init,
                dim10584JoeKuoD6Init,
                dim10585JoeKuoD6Init,
                dim10586JoeKuoD6Init,
                dim10587JoeKuoD6Init,
                dim10588JoeKuoD6Init,
                dim10589JoeKuoD6Init,
                dim10590JoeKuoD6Init,
                dim10591JoeKuoD6Init,
                dim10592JoeKuoD6Init,
                dim10593JoeKuoD6Init,
                dim10594JoeKuoD6Init,
                dim10595JoeKuoD6Init,
                dim10596JoeKuoD6Init,
                dim10597JoeKuoD6Init,
                dim10598JoeKuoD6Init,
                dim10599JoeKuoD6Init,
                dim10600JoeKuoD6Init,
                dim10601JoeKuoD6Init,
                dim10602JoeKuoD6Init,
                dim10603JoeKuoD6Init,
                dim10604JoeKuoD6Init,
                dim10605JoeKuoD6Init,
                dim10606JoeKuoD6Init,
                dim10607JoeKuoD6Init,
                dim10608JoeKuoD6Init,
                dim10609JoeKuoD6Init,
                dim10610JoeKuoD6Init,
                dim10611JoeKuoD6Init,
                dim10612JoeKuoD6Init,
                dim10613JoeKuoD6Init,
                dim10614JoeKuoD6Init,
                dim10615JoeKuoD6Init,
                dim10616JoeKuoD6Init,
                dim10617JoeKuoD6Init,
                dim10618JoeKuoD6Init,
                dim10619JoeKuoD6Init,
                dim10620JoeKuoD6Init,
                dim10621JoeKuoD6Init,
                dim10622JoeKuoD6Init,
                dim10623JoeKuoD6Init,
                dim10624JoeKuoD6Init,
                dim10625JoeKuoD6Init,
                dim10626JoeKuoD6Init,
                dim10627JoeKuoD6Init,
                dim10628JoeKuoD6Init,
                dim10629JoeKuoD6Init,
                dim10630JoeKuoD6Init,
                dim10631JoeKuoD6Init,
                dim10632JoeKuoD6Init,
                dim10633JoeKuoD6Init,
                dim10634JoeKuoD6Init,
                dim10635JoeKuoD6Init,
                dim10636JoeKuoD6Init,
                dim10637JoeKuoD6Init,
                dim10638JoeKuoD6Init,
                dim10639JoeKuoD6Init,
                dim10640JoeKuoD6Init,
                dim10641JoeKuoD6Init,
                dim10642JoeKuoD6Init,
                dim10643JoeKuoD6Init,
                dim10644JoeKuoD6Init,
                dim10645JoeKuoD6Init,
                dim10646JoeKuoD6Init,
                dim10647JoeKuoD6Init,
                dim10648JoeKuoD6Init,
                dim10649JoeKuoD6Init,
                dim10650JoeKuoD6Init,
                dim10651JoeKuoD6Init,
                dim10652JoeKuoD6Init,
                dim10653JoeKuoD6Init,
                dim10654JoeKuoD6Init,
                dim10655JoeKuoD6Init,
                dim10656JoeKuoD6Init,
                dim10657JoeKuoD6Init,
                dim10658JoeKuoD6Init,
                dim10659JoeKuoD6Init,
                dim10660JoeKuoD6Init,
                dim10661JoeKuoD6Init,
                dim10662JoeKuoD6Init,
                dim10663JoeKuoD6Init,
                dim10664JoeKuoD6Init,
                dim10665JoeKuoD6Init,
                dim10666JoeKuoD6Init,
                dim10667JoeKuoD6Init,
                dim10668JoeKuoD6Init,
                dim10669JoeKuoD6Init,
                dim10670JoeKuoD6Init,
                dim10671JoeKuoD6Init,
                dim10672JoeKuoD6Init,
                dim10673JoeKuoD6Init,
                dim10674JoeKuoD6Init,
                dim10675JoeKuoD6Init,
                dim10676JoeKuoD6Init,
                dim10677JoeKuoD6Init,
                dim10678JoeKuoD6Init,
                dim10679JoeKuoD6Init,
                dim10680JoeKuoD6Init,
                dim10681JoeKuoD6Init,
                dim10682JoeKuoD6Init,
                dim10683JoeKuoD6Init,
                dim10684JoeKuoD6Init,
                dim10685JoeKuoD6Init,
                dim10686JoeKuoD6Init,
                dim10687JoeKuoD6Init,
                dim10688JoeKuoD6Init,
                dim10689JoeKuoD6Init,
                dim10690JoeKuoD6Init,
                dim10691JoeKuoD6Init,
                dim10692JoeKuoD6Init,
                dim10693JoeKuoD6Init,
                dim10694JoeKuoD6Init,
                dim10695JoeKuoD6Init,
                dim10696JoeKuoD6Init,
                dim10697JoeKuoD6Init,
                dim10698JoeKuoD6Init,
                dim10699JoeKuoD6Init,
                dim10700JoeKuoD6Init,
                dim10701JoeKuoD6Init,
                dim10702JoeKuoD6Init,
                dim10703JoeKuoD6Init,
                dim10704JoeKuoD6Init,
                dim10705JoeKuoD6Init,
                dim10706JoeKuoD6Init,
                dim10707JoeKuoD6Init,
                dim10708JoeKuoD6Init,
                dim10709JoeKuoD6Init,
                dim10710JoeKuoD6Init,
                dim10711JoeKuoD6Init,
                dim10712JoeKuoD6Init,
                dim10713JoeKuoD6Init,
                dim10714JoeKuoD6Init,
                dim10715JoeKuoD6Init,
                dim10716JoeKuoD6Init,
                dim10717JoeKuoD6Init,
                dim10718JoeKuoD6Init,
                dim10719JoeKuoD6Init,
                dim10720JoeKuoD6Init,
                dim10721JoeKuoD6Init,
                dim10722JoeKuoD6Init,
                dim10723JoeKuoD6Init,
                dim10724JoeKuoD6Init,
                dim10725JoeKuoD6Init,
                dim10726JoeKuoD6Init,
                dim10727JoeKuoD6Init,
                dim10728JoeKuoD6Init,
                dim10729JoeKuoD6Init,
                dim10730JoeKuoD6Init,
                dim10731JoeKuoD6Init,
                dim10732JoeKuoD6Init,
                dim10733JoeKuoD6Init,
                dim10734JoeKuoD6Init,
                dim10735JoeKuoD6Init,
                dim10736JoeKuoD6Init,
                dim10737JoeKuoD6Init,
                dim10738JoeKuoD6Init,
                dim10739JoeKuoD6Init,
                dim10740JoeKuoD6Init,
                dim10741JoeKuoD6Init,
                dim10742JoeKuoD6Init,
                dim10743JoeKuoD6Init,
                dim10744JoeKuoD6Init,
                dim10745JoeKuoD6Init,
                dim10746JoeKuoD6Init,
                dim10747JoeKuoD6Init,
                dim10748JoeKuoD6Init,
                dim10749JoeKuoD6Init,
                dim10750JoeKuoD6Init,
                dim10751JoeKuoD6Init,
                dim10752JoeKuoD6Init,
                dim10753JoeKuoD6Init,
                dim10754JoeKuoD6Init,
                dim10755JoeKuoD6Init,
                dim10756JoeKuoD6Init,
                dim10757JoeKuoD6Init,
                dim10758JoeKuoD6Init,
                dim10759JoeKuoD6Init,
                dim10760JoeKuoD6Init,
                dim10761JoeKuoD6Init,
                dim10762JoeKuoD6Init,
                dim10763JoeKuoD6Init,
                dim10764JoeKuoD6Init,
                dim10765JoeKuoD6Init,
                dim10766JoeKuoD6Init,
                dim10767JoeKuoD6Init,
                dim10768JoeKuoD6Init,
                dim10769JoeKuoD6Init,
                dim10770JoeKuoD6Init,
                dim10771JoeKuoD6Init,
                dim10772JoeKuoD6Init,
                dim10773JoeKuoD6Init,
                dim10774JoeKuoD6Init,
                dim10775JoeKuoD6Init,
                dim10776JoeKuoD6Init,
                dim10777JoeKuoD6Init,
                dim10778JoeKuoD6Init,
                dim10779JoeKuoD6Init,
                dim10780JoeKuoD6Init,
                dim10781JoeKuoD6Init,
                dim10782JoeKuoD6Init,
                dim10783JoeKuoD6Init,
                dim10784JoeKuoD6Init,
                dim10785JoeKuoD6Init,
                dim10786JoeKuoD6Init,
                dim10787JoeKuoD6Init,
                dim10788JoeKuoD6Init,
                dim10789JoeKuoD6Init,
                dim10790JoeKuoD6Init,
                dim10791JoeKuoD6Init,
                dim10792JoeKuoD6Init,
                dim10793JoeKuoD6Init,
                dim10794JoeKuoD6Init,
                dim10795JoeKuoD6Init,
                dim10796JoeKuoD6Init,
                dim10797JoeKuoD6Init,
                dim10798JoeKuoD6Init,
                dim10799JoeKuoD6Init,
                dim10800JoeKuoD6Init,
                dim10801JoeKuoD6Init,
                dim10802JoeKuoD6Init,
                dim10803JoeKuoD6Init,
                dim10804JoeKuoD6Init,
                dim10805JoeKuoD6Init,
                dim10806JoeKuoD6Init,
                dim10807JoeKuoD6Init,
                dim10808JoeKuoD6Init,
                dim10809JoeKuoD6Init,
                dim10810JoeKuoD6Init,
                dim10811JoeKuoD6Init,
                dim10812JoeKuoD6Init,
                dim10813JoeKuoD6Init,
                dim10814JoeKuoD6Init,
                dim10815JoeKuoD6Init,
                dim10816JoeKuoD6Init,
                dim10817JoeKuoD6Init,
                dim10818JoeKuoD6Init,
                dim10819JoeKuoD6Init,
                dim10820JoeKuoD6Init,
                dim10821JoeKuoD6Init,
                dim10822JoeKuoD6Init,
                dim10823JoeKuoD6Init,
                dim10824JoeKuoD6Init,
                dim10825JoeKuoD6Init,
                dim10826JoeKuoD6Init,
                dim10827JoeKuoD6Init,
                dim10828JoeKuoD6Init,
                dim10829JoeKuoD6Init,
                dim10830JoeKuoD6Init,
                dim10831JoeKuoD6Init,
                dim10832JoeKuoD6Init,
                dim10833JoeKuoD6Init,
                dim10834JoeKuoD6Init,
                dim10835JoeKuoD6Init,
                dim10836JoeKuoD6Init,
                dim10837JoeKuoD6Init,
                dim10838JoeKuoD6Init,
                dim10839JoeKuoD6Init,
                dim10840JoeKuoD6Init,
                dim10841JoeKuoD6Init,
                dim10842JoeKuoD6Init,
                dim10843JoeKuoD6Init,
                dim10844JoeKuoD6Init,
                dim10845JoeKuoD6Init,
                dim10846JoeKuoD6Init,
                dim10847JoeKuoD6Init,
                dim10848JoeKuoD6Init,
                dim10849JoeKuoD6Init,
                dim10850JoeKuoD6Init,
                dim10851JoeKuoD6Init,
                dim10852JoeKuoD6Init,
                dim10853JoeKuoD6Init,
                dim10854JoeKuoD6Init,
                dim10855JoeKuoD6Init,
                dim10856JoeKuoD6Init,
                dim10857JoeKuoD6Init,
                dim10858JoeKuoD6Init,
                dim10859JoeKuoD6Init,
                dim10860JoeKuoD6Init,
                dim10861JoeKuoD6Init,
                dim10862JoeKuoD6Init,
                dim10863JoeKuoD6Init,
                dim10864JoeKuoD6Init,
                dim10865JoeKuoD6Init,
                dim10866JoeKuoD6Init,
                dim10867JoeKuoD6Init,
                dim10868JoeKuoD6Init,
                dim10869JoeKuoD6Init,
                dim10870JoeKuoD6Init,
                dim10871JoeKuoD6Init,
                dim10872JoeKuoD6Init,
                dim10873JoeKuoD6Init,
                dim10874JoeKuoD6Init,
                dim10875JoeKuoD6Init,
                dim10876JoeKuoD6Init,
                dim10877JoeKuoD6Init,
                dim10878JoeKuoD6Init,
                dim10879JoeKuoD6Init,
                dim10880JoeKuoD6Init,
                dim10881JoeKuoD6Init,
                dim10882JoeKuoD6Init,
                dim10883JoeKuoD6Init,
                dim10884JoeKuoD6Init,
                dim10885JoeKuoD6Init,
                dim10886JoeKuoD6Init,
                dim10887JoeKuoD6Init,
                dim10888JoeKuoD6Init,
                dim10889JoeKuoD6Init,
                dim10890JoeKuoD6Init,
                dim10891JoeKuoD6Init,
                dim10892JoeKuoD6Init,
                dim10893JoeKuoD6Init,
                dim10894JoeKuoD6Init,
                dim10895JoeKuoD6Init,
                dim10896JoeKuoD6Init,
                dim10897JoeKuoD6Init,
                dim10898JoeKuoD6Init,
                dim10899JoeKuoD6Init,
                dim10900JoeKuoD6Init,
                dim10901JoeKuoD6Init,
                dim10902JoeKuoD6Init,
                dim10903JoeKuoD6Init,
                dim10904JoeKuoD6Init,
                dim10905JoeKuoD6Init,
                dim10906JoeKuoD6Init,
                dim10907JoeKuoD6Init,
                dim10908JoeKuoD6Init,
                dim10909JoeKuoD6Init,
                dim10910JoeKuoD6Init,
                dim10911JoeKuoD6Init,
                dim10912JoeKuoD6Init,
                dim10913JoeKuoD6Init,
                dim10914JoeKuoD6Init,
                dim10915JoeKuoD6Init,
                dim10916JoeKuoD6Init,
                dim10917JoeKuoD6Init,
                dim10918JoeKuoD6Init,
                dim10919JoeKuoD6Init,
                dim10920JoeKuoD6Init,
                dim10921JoeKuoD6Init,
                dim10922JoeKuoD6Init,
                dim10923JoeKuoD6Init,
                dim10924JoeKuoD6Init,
                dim10925JoeKuoD6Init,
                dim10926JoeKuoD6Init,
                dim10927JoeKuoD6Init,
                dim10928JoeKuoD6Init,
                dim10929JoeKuoD6Init,
                dim10930JoeKuoD6Init,
                dim10931JoeKuoD6Init,
                dim10932JoeKuoD6Init,
                dim10933JoeKuoD6Init,
                dim10934JoeKuoD6Init,
                dim10935JoeKuoD6Init,
                dim10936JoeKuoD6Init,
                dim10937JoeKuoD6Init,
                dim10938JoeKuoD6Init,
                dim10939JoeKuoD6Init,
                dim10940JoeKuoD6Init,
                dim10941JoeKuoD6Init,
                dim10942JoeKuoD6Init,
                dim10943JoeKuoD6Init,
                dim10944JoeKuoD6Init,
                dim10945JoeKuoD6Init,
                dim10946JoeKuoD6Init,
                dim10947JoeKuoD6Init,
                dim10948JoeKuoD6Init,
                dim10949JoeKuoD6Init,
                dim10950JoeKuoD6Init,
                dim10951JoeKuoD6Init,
                dim10952JoeKuoD6Init,
                dim10953JoeKuoD6Init,
                dim10954JoeKuoD6Init,
                dim10955JoeKuoD6Init,
                dim10956JoeKuoD6Init,
                dim10957JoeKuoD6Init,
                dim10958JoeKuoD6Init,
                dim10959JoeKuoD6Init,
                dim10960JoeKuoD6Init,
                dim10961JoeKuoD6Init,
                dim10962JoeKuoD6Init,
                dim10963JoeKuoD6Init,
                dim10964JoeKuoD6Init,
                dim10965JoeKuoD6Init,
                dim10966JoeKuoD6Init,
                dim10967JoeKuoD6Init,
                dim10968JoeKuoD6Init,
                dim10969JoeKuoD6Init,
                dim10970JoeKuoD6Init,
                dim10971JoeKuoD6Init,
                dim10972JoeKuoD6Init,
                dim10973JoeKuoD6Init,
                dim10974JoeKuoD6Init,
                dim10975JoeKuoD6Init,
                dim10976JoeKuoD6Init,
                dim10977JoeKuoD6Init,
                dim10978JoeKuoD6Init,
                dim10979JoeKuoD6Init,
                dim10980JoeKuoD6Init,
                dim10981JoeKuoD6Init,
                dim10982JoeKuoD6Init,
                dim10983JoeKuoD6Init,
                dim10984JoeKuoD6Init,
                dim10985JoeKuoD6Init,
                dim10986JoeKuoD6Init,
                dim10987JoeKuoD6Init,
                dim10988JoeKuoD6Init,
                dim10989JoeKuoD6Init,
                dim10990JoeKuoD6Init,
                dim10991JoeKuoD6Init,
                dim10992JoeKuoD6Init,
                dim10993JoeKuoD6Init,
                dim10994JoeKuoD6Init,
                dim10995JoeKuoD6Init,
                dim10996JoeKuoD6Init,
                dim10997JoeKuoD6Init,
                dim10998JoeKuoD6Init,
                dim10999JoeKuoD6Init,
                dim11000JoeKuoD6Init,
                dim11001JoeKuoD6Init,
                dim11002JoeKuoD6Init,
                dim11003JoeKuoD6Init,
                dim11004JoeKuoD6Init,
                dim11005JoeKuoD6Init,
                dim11006JoeKuoD6Init,
                dim11007JoeKuoD6Init,
                dim11008JoeKuoD6Init,
                dim11009JoeKuoD6Init,
                dim11010JoeKuoD6Init,
                dim11011JoeKuoD6Init,
                dim11012JoeKuoD6Init,
                dim11013JoeKuoD6Init,
                dim11014JoeKuoD6Init,
                dim11015JoeKuoD6Init,
                dim11016JoeKuoD6Init,
                dim11017JoeKuoD6Init,
                dim11018JoeKuoD6Init,
                dim11019JoeKuoD6Init,
                dim11020JoeKuoD6Init,
                dim11021JoeKuoD6Init,
                dim11022JoeKuoD6Init,
                dim11023JoeKuoD6Init,
                dim11024JoeKuoD6Init,
                dim11025JoeKuoD6Init,
                dim11026JoeKuoD6Init,
                dim11027JoeKuoD6Init,
                dim11028JoeKuoD6Init,
                dim11029JoeKuoD6Init,
                dim11030JoeKuoD6Init,
                dim11031JoeKuoD6Init,
                dim11032JoeKuoD6Init,
                dim11033JoeKuoD6Init,
                dim11034JoeKuoD6Init,
                dim11035JoeKuoD6Init,
                dim11036JoeKuoD6Init,
                dim11037JoeKuoD6Init,
                dim11038JoeKuoD6Init,
                dim11039JoeKuoD6Init,
                dim11040JoeKuoD6Init,
                dim11041JoeKuoD6Init,
                dim11042JoeKuoD6Init,
                dim11043JoeKuoD6Init,
                dim11044JoeKuoD6Init,
                dim11045JoeKuoD6Init,
                dim11046JoeKuoD6Init,
                dim11047JoeKuoD6Init,
                dim11048JoeKuoD6Init,
                dim11049JoeKuoD6Init,
                dim11050JoeKuoD6Init,
                dim11051JoeKuoD6Init,
                dim11052JoeKuoD6Init,
                dim11053JoeKuoD6Init,
                dim11054JoeKuoD6Init,
                dim11055JoeKuoD6Init,
                dim11056JoeKuoD6Init,
                dim11057JoeKuoD6Init,
                dim11058JoeKuoD6Init,
                dim11059JoeKuoD6Init,
                dim11060JoeKuoD6Init,
                dim11061JoeKuoD6Init,
                dim11062JoeKuoD6Init,
                dim11063JoeKuoD6Init,
                dim11064JoeKuoD6Init,
                dim11065JoeKuoD6Init,
                dim11066JoeKuoD6Init,
                dim11067JoeKuoD6Init,
                dim11068JoeKuoD6Init,
                dim11069JoeKuoD6Init,
                dim11070JoeKuoD6Init,
                dim11071JoeKuoD6Init,
                dim11072JoeKuoD6Init,
                dim11073JoeKuoD6Init,
                dim11074JoeKuoD6Init,
                dim11075JoeKuoD6Init,
                dim11076JoeKuoD6Init,
                dim11077JoeKuoD6Init,
                dim11078JoeKuoD6Init,
                dim11079JoeKuoD6Init,
                dim11080JoeKuoD6Init,
                dim11081JoeKuoD6Init,
                dim11082JoeKuoD6Init,
                dim11083JoeKuoD6Init,
                dim11084JoeKuoD6Init,
                dim11085JoeKuoD6Init,
                dim11086JoeKuoD6Init,
                dim11087JoeKuoD6Init,
                dim11088JoeKuoD6Init,
                dim11089JoeKuoD6Init,
                dim11090JoeKuoD6Init,
                dim11091JoeKuoD6Init,
                dim11092JoeKuoD6Init,
                dim11093JoeKuoD6Init,
                dim11094JoeKuoD6Init,
                dim11095JoeKuoD6Init,
                dim11096JoeKuoD6Init,
                dim11097JoeKuoD6Init,
                dim11098JoeKuoD6Init,
                dim11099JoeKuoD6Init,
                dim11100JoeKuoD6Init,
                dim11101JoeKuoD6Init,
                dim11102JoeKuoD6Init,
                dim11103JoeKuoD6Init,
                dim11104JoeKuoD6Init,
                dim11105JoeKuoD6Init,
                dim11106JoeKuoD6Init,
                dim11107JoeKuoD6Init,
                dim11108JoeKuoD6Init,
                dim11109JoeKuoD6Init,
                dim11110JoeKuoD6Init,
                dim11111JoeKuoD6Init,
                dim11112JoeKuoD6Init,
                dim11113JoeKuoD6Init,
                dim11114JoeKuoD6Init,
                dim11115JoeKuoD6Init,
                dim11116JoeKuoD6Init,
                dim11117JoeKuoD6Init,
                dim11118JoeKuoD6Init,
                dim11119JoeKuoD6Init,
                dim11120JoeKuoD6Init,
                dim11121JoeKuoD6Init,
                dim11122JoeKuoD6Init,
                dim11123JoeKuoD6Init,
                dim11124JoeKuoD6Init,
                dim11125JoeKuoD6Init,
                dim11126JoeKuoD6Init,
                dim11127JoeKuoD6Init,
                dim11128JoeKuoD6Init,
                dim11129JoeKuoD6Init,
                dim11130JoeKuoD6Init,
                dim11131JoeKuoD6Init,
                dim11132JoeKuoD6Init,
                dim11133JoeKuoD6Init,
                dim11134JoeKuoD6Init,
                dim11135JoeKuoD6Init,
                dim11136JoeKuoD6Init,
                dim11137JoeKuoD6Init,
                dim11138JoeKuoD6Init,
                dim11139JoeKuoD6Init,
                dim11140JoeKuoD6Init,
                dim11141JoeKuoD6Init,
                dim11142JoeKuoD6Init,
                dim11143JoeKuoD6Init,
                dim11144JoeKuoD6Init,
                dim11145JoeKuoD6Init,
                dim11146JoeKuoD6Init,
                dim11147JoeKuoD6Init,
                dim11148JoeKuoD6Init,
                dim11149JoeKuoD6Init,
                dim11150JoeKuoD6Init,
                dim11151JoeKuoD6Init,
                dim11152JoeKuoD6Init,
                dim11153JoeKuoD6Init,
                dim11154JoeKuoD6Init,
                dim11155JoeKuoD6Init,
                dim11156JoeKuoD6Init,
                dim11157JoeKuoD6Init,
                dim11158JoeKuoD6Init,
                dim11159JoeKuoD6Init,
                dim11160JoeKuoD6Init,
                dim11161JoeKuoD6Init,
                dim11162JoeKuoD6Init,
                dim11163JoeKuoD6Init,
                dim11164JoeKuoD6Init,
                dim11165JoeKuoD6Init,
                dim11166JoeKuoD6Init,
                dim11167JoeKuoD6Init,
                dim11168JoeKuoD6Init,
                dim11169JoeKuoD6Init,
                dim11170JoeKuoD6Init,
                dim11171JoeKuoD6Init,
                dim11172JoeKuoD6Init,
                dim11173JoeKuoD6Init,
                dim11174JoeKuoD6Init,
                dim11175JoeKuoD6Init,
                dim11176JoeKuoD6Init,
                dim11177JoeKuoD6Init,
                dim11178JoeKuoD6Init,
                dim11179JoeKuoD6Init,
                dim11180JoeKuoD6Init,
                dim11181JoeKuoD6Init,
                dim11182JoeKuoD6Init,
                dim11183JoeKuoD6Init,
                dim11184JoeKuoD6Init,
                dim11185JoeKuoD6Init,
                dim11186JoeKuoD6Init,
                dim11187JoeKuoD6Init,
                dim11188JoeKuoD6Init,
                dim11189JoeKuoD6Init,
                dim11190JoeKuoD6Init,
                dim11191JoeKuoD6Init,
                dim11192JoeKuoD6Init,
                dim11193JoeKuoD6Init,
                dim11194JoeKuoD6Init,
                dim11195JoeKuoD6Init,
                dim11196JoeKuoD6Init,
                dim11197JoeKuoD6Init,
                dim11198JoeKuoD6Init,
                dim11199JoeKuoD6Init,
                dim11200JoeKuoD6Init,
                dim11201JoeKuoD6Init,
                dim11202JoeKuoD6Init,
                dim11203JoeKuoD6Init,
                dim11204JoeKuoD6Init,
                dim11205JoeKuoD6Init,
                dim11206JoeKuoD6Init,
                dim11207JoeKuoD6Init,
                dim11208JoeKuoD6Init,
                dim11209JoeKuoD6Init,
                dim11210JoeKuoD6Init,
                dim11211JoeKuoD6Init,
                dim11212JoeKuoD6Init,
                dim11213JoeKuoD6Init,
                dim11214JoeKuoD6Init,
                dim11215JoeKuoD6Init,
                dim11216JoeKuoD6Init,
                dim11217JoeKuoD6Init,
                dim11218JoeKuoD6Init,
                dim11219JoeKuoD6Init,
                dim11220JoeKuoD6Init,
                dim11221JoeKuoD6Init,
                dim11222JoeKuoD6Init,
                dim11223JoeKuoD6Init,
                dim11224JoeKuoD6Init,
                dim11225JoeKuoD6Init,
                dim11226JoeKuoD6Init,
                dim11227JoeKuoD6Init,
                dim11228JoeKuoD6Init,
                dim11229JoeKuoD6Init,
                dim11230JoeKuoD6Init,
                dim11231JoeKuoD6Init,
                dim11232JoeKuoD6Init,
                dim11233JoeKuoD6Init,
                dim11234JoeKuoD6Init,
                dim11235JoeKuoD6Init,
                dim11236JoeKuoD6Init,
                dim11237JoeKuoD6Init,
                dim11238JoeKuoD6Init,
                dim11239JoeKuoD6Init,
                dim11240JoeKuoD6Init,
                dim11241JoeKuoD6Init,
                dim11242JoeKuoD6Init,
                dim11243JoeKuoD6Init,
                dim11244JoeKuoD6Init,
                dim11245JoeKuoD6Init,
                dim11246JoeKuoD6Init,
                dim11247JoeKuoD6Init,
                dim11248JoeKuoD6Init,
                dim11249JoeKuoD6Init,
                dim11250JoeKuoD6Init,
                dim11251JoeKuoD6Init,
                dim11252JoeKuoD6Init,
                dim11253JoeKuoD6Init,
                dim11254JoeKuoD6Init,
                dim11255JoeKuoD6Init,
                dim11256JoeKuoD6Init,
                dim11257JoeKuoD6Init,
                dim11258JoeKuoD6Init,
                dim11259JoeKuoD6Init,
                dim11260JoeKuoD6Init,
                dim11261JoeKuoD6Init,
                dim11262JoeKuoD6Init,
                dim11263JoeKuoD6Init,
                dim11264JoeKuoD6Init,
                dim11265JoeKuoD6Init,
                dim11266JoeKuoD6Init,
                dim11267JoeKuoD6Init,
                dim11268JoeKuoD6Init,
                dim11269JoeKuoD6Init,
                dim11270JoeKuoD6Init,
                dim11271JoeKuoD6Init,
                dim11272JoeKuoD6Init,
                dim11273JoeKuoD6Init,
                dim11274JoeKuoD6Init,
                dim11275JoeKuoD6Init,
                dim11276JoeKuoD6Init,
                dim11277JoeKuoD6Init,
                dim11278JoeKuoD6Init,
                dim11279JoeKuoD6Init,
                dim11280JoeKuoD6Init,
                dim11281JoeKuoD6Init,
                dim11282JoeKuoD6Init,
                dim11283JoeKuoD6Init,
                dim11284JoeKuoD6Init,
                dim11285JoeKuoD6Init,
                dim11286JoeKuoD6Init,
                dim11287JoeKuoD6Init,
                dim11288JoeKuoD6Init,
                dim11289JoeKuoD6Init,
                dim11290JoeKuoD6Init,
                dim11291JoeKuoD6Init,
                dim11292JoeKuoD6Init,
                dim11293JoeKuoD6Init,
                dim11294JoeKuoD6Init,
                dim11295JoeKuoD6Init,
                dim11296JoeKuoD6Init,
                dim11297JoeKuoD6Init,
                dim11298JoeKuoD6Init,
                dim11299JoeKuoD6Init,
                dim11300JoeKuoD6Init,
                dim11301JoeKuoD6Init,
                dim11302JoeKuoD6Init,
                dim11303JoeKuoD6Init,
                dim11304JoeKuoD6Init,
                dim11305JoeKuoD6Init,
                dim11306JoeKuoD6Init,
                dim11307JoeKuoD6Init,
                dim11308JoeKuoD6Init,
                dim11309JoeKuoD6Init,
                dim11310JoeKuoD6Init,
                dim11311JoeKuoD6Init,
                dim11312JoeKuoD6Init,
                dim11313JoeKuoD6Init,
                dim11314JoeKuoD6Init,
                dim11315JoeKuoD6Init,
                dim11316JoeKuoD6Init,
                dim11317JoeKuoD6Init,
                dim11318JoeKuoD6Init,
                dim11319JoeKuoD6Init,
                dim11320JoeKuoD6Init,
                dim11321JoeKuoD6Init,
                dim11322JoeKuoD6Init,
                dim11323JoeKuoD6Init,
                dim11324JoeKuoD6Init,
                dim11325JoeKuoD6Init,
                dim11326JoeKuoD6Init,
                dim11327JoeKuoD6Init,
                dim11328JoeKuoD6Init,
                dim11329JoeKuoD6Init,
                dim11330JoeKuoD6Init,
                dim11331JoeKuoD6Init,
                dim11332JoeKuoD6Init,
                dim11333JoeKuoD6Init,
                dim11334JoeKuoD6Init,
                dim11335JoeKuoD6Init,
                dim11336JoeKuoD6Init,
                dim11337JoeKuoD6Init,
                dim11338JoeKuoD6Init,
                dim11339JoeKuoD6Init,
                dim11340JoeKuoD6Init,
                dim11341JoeKuoD6Init,
                dim11342JoeKuoD6Init,
                dim11343JoeKuoD6Init,
                dim11344JoeKuoD6Init,
                dim11345JoeKuoD6Init,
                dim11346JoeKuoD6Init,
                dim11347JoeKuoD6Init,
                dim11348JoeKuoD6Init,
                dim11349JoeKuoD6Init,
                dim11350JoeKuoD6Init,
                dim11351JoeKuoD6Init,
                dim11352JoeKuoD6Init,
                dim11353JoeKuoD6Init,
                dim11354JoeKuoD6Init,
                dim11355JoeKuoD6Init,
                dim11356JoeKuoD6Init,
                dim11357JoeKuoD6Init,
                dim11358JoeKuoD6Init,
                dim11359JoeKuoD6Init,
                dim11360JoeKuoD6Init,
                dim11361JoeKuoD6Init,
                dim11362JoeKuoD6Init,
                dim11363JoeKuoD6Init,
                dim11364JoeKuoD6Init,
                dim11365JoeKuoD6Init,
                dim11366JoeKuoD6Init,
                dim11367JoeKuoD6Init,
                dim11368JoeKuoD6Init,
                dim11369JoeKuoD6Init,
                dim11370JoeKuoD6Init,
                dim11371JoeKuoD6Init,
                dim11372JoeKuoD6Init,
                dim11373JoeKuoD6Init,
                dim11374JoeKuoD6Init,
                dim11375JoeKuoD6Init,
                dim11376JoeKuoD6Init,
                dim11377JoeKuoD6Init,
                dim11378JoeKuoD6Init,
                dim11379JoeKuoD6Init,
                dim11380JoeKuoD6Init,
                dim11381JoeKuoD6Init,
                dim11382JoeKuoD6Init,
                dim11383JoeKuoD6Init,
                dim11384JoeKuoD6Init,
                dim11385JoeKuoD6Init,
                dim11386JoeKuoD6Init,
                dim11387JoeKuoD6Init,
                dim11388JoeKuoD6Init,
                dim11389JoeKuoD6Init,
                dim11390JoeKuoD6Init,
                dim11391JoeKuoD6Init,
                dim11392JoeKuoD6Init,
                dim11393JoeKuoD6Init,
                dim11394JoeKuoD6Init,
                dim11395JoeKuoD6Init,
                dim11396JoeKuoD6Init,
                dim11397JoeKuoD6Init,
                dim11398JoeKuoD6Init,
                dim11399JoeKuoD6Init,
                dim11400JoeKuoD6Init,
                dim11401JoeKuoD6Init,
                dim11402JoeKuoD6Init,
                dim11403JoeKuoD6Init,
                dim11404JoeKuoD6Init,
                dim11405JoeKuoD6Init,
                dim11406JoeKuoD6Init,
                dim11407JoeKuoD6Init,
                dim11408JoeKuoD6Init,
                dim11409JoeKuoD6Init,
                dim11410JoeKuoD6Init,
                dim11411JoeKuoD6Init,
                dim11412JoeKuoD6Init,
                dim11413JoeKuoD6Init,
                dim11414JoeKuoD6Init,
                dim11415JoeKuoD6Init,
                dim11416JoeKuoD6Init,
                dim11417JoeKuoD6Init,
                dim11418JoeKuoD6Init,
                dim11419JoeKuoD6Init,
                dim11420JoeKuoD6Init,
                dim11421JoeKuoD6Init,
                dim11422JoeKuoD6Init,
                dim11423JoeKuoD6Init,
                dim11424JoeKuoD6Init,
                dim11425JoeKuoD6Init,
                dim11426JoeKuoD6Init,
                dim11427JoeKuoD6Init,
                dim11428JoeKuoD6Init,
                dim11429JoeKuoD6Init,
                dim11430JoeKuoD6Init,
                dim11431JoeKuoD6Init,
                dim11432JoeKuoD6Init,
                dim11433JoeKuoD6Init,
                dim11434JoeKuoD6Init,
                dim11435JoeKuoD6Init,
                dim11436JoeKuoD6Init,
                dim11437JoeKuoD6Init,
                dim11438JoeKuoD6Init,
                dim11439JoeKuoD6Init,
                dim11440JoeKuoD6Init,
                dim11441JoeKuoD6Init,
                dim11442JoeKuoD6Init,
                dim11443JoeKuoD6Init,
                dim11444JoeKuoD6Init,
                dim11445JoeKuoD6Init,
                dim11446JoeKuoD6Init,
                dim11447JoeKuoD6Init,
                dim11448JoeKuoD6Init,
                dim11449JoeKuoD6Init,
                dim11450JoeKuoD6Init,
                dim11451JoeKuoD6Init,
                dim11452JoeKuoD6Init,
                dim11453JoeKuoD6Init,
                dim11454JoeKuoD6Init,
                dim11455JoeKuoD6Init,
                dim11456JoeKuoD6Init,
                dim11457JoeKuoD6Init,
                dim11458JoeKuoD6Init,
                dim11459JoeKuoD6Init,
                dim11460JoeKuoD6Init,
                dim11461JoeKuoD6Init,
                dim11462JoeKuoD6Init,
                dim11463JoeKuoD6Init,
                dim11464JoeKuoD6Init,
                dim11465JoeKuoD6Init,
                dim11466JoeKuoD6Init,
                dim11467JoeKuoD6Init,
                dim11468JoeKuoD6Init,
                dim11469JoeKuoD6Init,
                dim11470JoeKuoD6Init,
                dim11471JoeKuoD6Init,
                dim11472JoeKuoD6Init,
                dim11473JoeKuoD6Init,
                dim11474JoeKuoD6Init,
                dim11475JoeKuoD6Init,
                dim11476JoeKuoD6Init,
                dim11477JoeKuoD6Init,
                dim11478JoeKuoD6Init,
                dim11479JoeKuoD6Init,
                dim11480JoeKuoD6Init,
                dim11481JoeKuoD6Init,
                dim11482JoeKuoD6Init,
                dim11483JoeKuoD6Init,
                dim11484JoeKuoD6Init,
                dim11485JoeKuoD6Init,
                dim11486JoeKuoD6Init,
                dim11487JoeKuoD6Init,
                dim11488JoeKuoD6Init,
                dim11489JoeKuoD6Init,
                dim11490JoeKuoD6Init,
                dim11491JoeKuoD6Init,
                dim11492JoeKuoD6Init,
                dim11493JoeKuoD6Init,
                dim11494JoeKuoD6Init,
                dim11495JoeKuoD6Init,
                dim11496JoeKuoD6Init,
                dim11497JoeKuoD6Init,
                dim11498JoeKuoD6Init,
                dim11499JoeKuoD6Init,
                dim11500JoeKuoD6Init,
                dim11501JoeKuoD6Init,
                dim11502JoeKuoD6Init,
                dim11503JoeKuoD6Init,
                dim11504JoeKuoD6Init,
                dim11505JoeKuoD6Init,
                dim11506JoeKuoD6Init,
                dim11507JoeKuoD6Init,
                dim11508JoeKuoD6Init,
                dim11509JoeKuoD6Init,
                dim11510JoeKuoD6Init,
                dim11511JoeKuoD6Init,
                dim11512JoeKuoD6Init,
                dim11513JoeKuoD6Init,
                dim11514JoeKuoD6Init,
                dim11515JoeKuoD6Init,
                dim11516JoeKuoD6Init,
                dim11517JoeKuoD6Init,
                dim11518JoeKuoD6Init,
                dim11519JoeKuoD6Init,
                dim11520JoeKuoD6Init,
                dim11521JoeKuoD6Init,
                dim11522JoeKuoD6Init,
                dim11523JoeKuoD6Init,
                dim11524JoeKuoD6Init,
                dim11525JoeKuoD6Init,
                dim11526JoeKuoD6Init,
                dim11527JoeKuoD6Init,
                dim11528JoeKuoD6Init,
                dim11529JoeKuoD6Init,
                dim11530JoeKuoD6Init,
                dim11531JoeKuoD6Init,
                dim11532JoeKuoD6Init,
                dim11533JoeKuoD6Init,
                dim11534JoeKuoD6Init,
                dim11535JoeKuoD6Init,
                dim11536JoeKuoD6Init,
                dim11537JoeKuoD6Init,
                dim11538JoeKuoD6Init,
                dim11539JoeKuoD6Init,
                dim11540JoeKuoD6Init,
                dim11541JoeKuoD6Init,
                dim11542JoeKuoD6Init,
                dim11543JoeKuoD6Init,
                dim11544JoeKuoD6Init,
                dim11545JoeKuoD6Init,
                dim11546JoeKuoD6Init,
                dim11547JoeKuoD6Init,
                dim11548JoeKuoD6Init,
                dim11549JoeKuoD6Init,
                dim11550JoeKuoD6Init,
                dim11551JoeKuoD6Init,
                dim11552JoeKuoD6Init,
                dim11553JoeKuoD6Init,
                dim11554JoeKuoD6Init,
                dim11555JoeKuoD6Init,
                dim11556JoeKuoD6Init,
                dim11557JoeKuoD6Init,
                dim11558JoeKuoD6Init,
                dim11559JoeKuoD6Init,
                dim11560JoeKuoD6Init,
                dim11561JoeKuoD6Init,
                dim11562JoeKuoD6Init,
                dim11563JoeKuoD6Init,
                dim11564JoeKuoD6Init,
                dim11565JoeKuoD6Init,
                dim11566JoeKuoD6Init,
                dim11567JoeKuoD6Init,
                dim11568JoeKuoD6Init,
                dim11569JoeKuoD6Init,
                dim11570JoeKuoD6Init,
                dim11571JoeKuoD6Init,
                dim11572JoeKuoD6Init,
                dim11573JoeKuoD6Init,
                dim11574JoeKuoD6Init,
                dim11575JoeKuoD6Init,
                dim11576JoeKuoD6Init,
                dim11577JoeKuoD6Init,
                dim11578JoeKuoD6Init,
                dim11579JoeKuoD6Init,
                dim11580JoeKuoD6Init,
                dim11581JoeKuoD6Init,
                dim11582JoeKuoD6Init,
                dim11583JoeKuoD6Init,
                dim11584JoeKuoD6Init,
                dim11585JoeKuoD6Init,
                dim11586JoeKuoD6Init,
                dim11587JoeKuoD6Init,
                dim11588JoeKuoD6Init,
                dim11589JoeKuoD6Init,
                dim11590JoeKuoD6Init,
                dim11591JoeKuoD6Init,
                dim11592JoeKuoD6Init,
                dim11593JoeKuoD6Init,
                dim11594JoeKuoD6Init,
                dim11595JoeKuoD6Init,
                dim11596JoeKuoD6Init,
                dim11597JoeKuoD6Init,
                dim11598JoeKuoD6Init,
                dim11599JoeKuoD6Init,
                dim11600JoeKuoD6Init,
                dim11601JoeKuoD6Init,
                dim11602JoeKuoD6Init,
                dim11603JoeKuoD6Init,
                dim11604JoeKuoD6Init,
                dim11605JoeKuoD6Init,
                dim11606JoeKuoD6Init,
                dim11607JoeKuoD6Init,
                dim11608JoeKuoD6Init,
                dim11609JoeKuoD6Init,
                dim11610JoeKuoD6Init,
                dim11611JoeKuoD6Init,
                dim11612JoeKuoD6Init,
                dim11613JoeKuoD6Init,
                dim11614JoeKuoD6Init,
                dim11615JoeKuoD6Init,
                dim11616JoeKuoD6Init,
                dim11617JoeKuoD6Init,
                dim11618JoeKuoD6Init,
                dim11619JoeKuoD6Init,
                dim11620JoeKuoD6Init,
                dim11621JoeKuoD6Init,
                dim11622JoeKuoD6Init,
                dim11623JoeKuoD6Init,
                dim11624JoeKuoD6Init,
                dim11625JoeKuoD6Init,
                dim11626JoeKuoD6Init,
                dim11627JoeKuoD6Init,
                dim11628JoeKuoD6Init,
                dim11629JoeKuoD6Init,
                dim11630JoeKuoD6Init,
                dim11631JoeKuoD6Init,
                dim11632JoeKuoD6Init,
                dim11633JoeKuoD6Init,
                dim11634JoeKuoD6Init,
                dim11635JoeKuoD6Init,
                dim11636JoeKuoD6Init,
                dim11637JoeKuoD6Init,
                dim11638JoeKuoD6Init,
                dim11639JoeKuoD6Init,
                dim11640JoeKuoD6Init,
                dim11641JoeKuoD6Init,
                dim11642JoeKuoD6Init,
                dim11643JoeKuoD6Init,
                dim11644JoeKuoD6Init,
                dim11645JoeKuoD6Init,
                dim11646JoeKuoD6Init,
                dim11647JoeKuoD6Init,
                dim11648JoeKuoD6Init,
                dim11649JoeKuoD6Init,
                dim11650JoeKuoD6Init,
                dim11651JoeKuoD6Init,
                dim11652JoeKuoD6Init,
                dim11653JoeKuoD6Init,
                dim11654JoeKuoD6Init,
                dim11655JoeKuoD6Init,
                dim11656JoeKuoD6Init,
                dim11657JoeKuoD6Init,
                dim11658JoeKuoD6Init,
                dim11659JoeKuoD6Init,
                dim11660JoeKuoD6Init,
                dim11661JoeKuoD6Init,
                dim11662JoeKuoD6Init,
                dim11663JoeKuoD6Init,
                dim11664JoeKuoD6Init,
                dim11665JoeKuoD6Init,
                dim11666JoeKuoD6Init,
                dim11667JoeKuoD6Init,
                dim11668JoeKuoD6Init,
                dim11669JoeKuoD6Init,
                dim11670JoeKuoD6Init,
                dim11671JoeKuoD6Init,
                dim11672JoeKuoD6Init,
                dim11673JoeKuoD6Init,
                dim11674JoeKuoD6Init,
                dim11675JoeKuoD6Init,
                dim11676JoeKuoD6Init,
                dim11677JoeKuoD6Init,
                dim11678JoeKuoD6Init,
                dim11679JoeKuoD6Init,
                dim11680JoeKuoD6Init,
                dim11681JoeKuoD6Init,
                dim11682JoeKuoD6Init,
                dim11683JoeKuoD6Init,
                dim11684JoeKuoD6Init,
                dim11685JoeKuoD6Init,
                dim11686JoeKuoD6Init,
                dim11687JoeKuoD6Init,
                dim11688JoeKuoD6Init,
                dim11689JoeKuoD6Init,
                dim11690JoeKuoD6Init,
                dim11691JoeKuoD6Init,
                dim11692JoeKuoD6Init,
                dim11693JoeKuoD6Init,
                dim11694JoeKuoD6Init,
                dim11695JoeKuoD6Init,
                dim11696JoeKuoD6Init,
                dim11697JoeKuoD6Init,
                dim11698JoeKuoD6Init,
                dim11699JoeKuoD6Init,
                dim11700JoeKuoD6Init,
                dim11701JoeKuoD6Init,
                dim11702JoeKuoD6Init,
                dim11703JoeKuoD6Init,
                dim11704JoeKuoD6Init,
                dim11705JoeKuoD6Init,
                dim11706JoeKuoD6Init,
                dim11707JoeKuoD6Init,
                dim11708JoeKuoD6Init,
                dim11709JoeKuoD6Init,
                dim11710JoeKuoD6Init,
                dim11711JoeKuoD6Init,
                dim11712JoeKuoD6Init,
                dim11713JoeKuoD6Init,
                dim11714JoeKuoD6Init,
                dim11715JoeKuoD6Init,
                dim11716JoeKuoD6Init,
                dim11717JoeKuoD6Init,
                dim11718JoeKuoD6Init,
                dim11719JoeKuoD6Init,
                dim11720JoeKuoD6Init,
                dim11721JoeKuoD6Init,
                dim11722JoeKuoD6Init,
                dim11723JoeKuoD6Init,
                dim11724JoeKuoD6Init,
                dim11725JoeKuoD6Init,
                dim11726JoeKuoD6Init,
                dim11727JoeKuoD6Init,
                dim11728JoeKuoD6Init,
                dim11729JoeKuoD6Init,
                dim11730JoeKuoD6Init,
                dim11731JoeKuoD6Init,
                dim11732JoeKuoD6Init,
                dim11733JoeKuoD6Init,
                dim11734JoeKuoD6Init,
                dim11735JoeKuoD6Init,
                dim11736JoeKuoD6Init,
                dim11737JoeKuoD6Init,
                dim11738JoeKuoD6Init,
                dim11739JoeKuoD6Init,
                dim11740JoeKuoD6Init,
                dim11741JoeKuoD6Init,
                dim11742JoeKuoD6Init,
                dim11743JoeKuoD6Init,
                dim11744JoeKuoD6Init,
                dim11745JoeKuoD6Init,
                dim11746JoeKuoD6Init,
                dim11747JoeKuoD6Init,
                dim11748JoeKuoD6Init,
                dim11749JoeKuoD6Init,
                dim11750JoeKuoD6Init,
                dim11751JoeKuoD6Init,
                dim11752JoeKuoD6Init,
                dim11753JoeKuoD6Init,
                dim11754JoeKuoD6Init,
                dim11755JoeKuoD6Init,
                dim11756JoeKuoD6Init,
                dim11757JoeKuoD6Init,
                dim11758JoeKuoD6Init,
                dim11759JoeKuoD6Init,
                dim11760JoeKuoD6Init,
                dim11761JoeKuoD6Init,
                dim11762JoeKuoD6Init,
                dim11763JoeKuoD6Init,
                dim11764JoeKuoD6Init,
                dim11765JoeKuoD6Init,
                dim11766JoeKuoD6Init,
                dim11767JoeKuoD6Init,
                dim11768JoeKuoD6Init,
                dim11769JoeKuoD6Init,
                dim11770JoeKuoD6Init,
                dim11771JoeKuoD6Init,
                dim11772JoeKuoD6Init,
                dim11773JoeKuoD6Init,
                dim11774JoeKuoD6Init,
                dim11775JoeKuoD6Init,
                dim11776JoeKuoD6Init,
                dim11777JoeKuoD6Init,
                dim11778JoeKuoD6Init,
                dim11779JoeKuoD6Init,
                dim11780JoeKuoD6Init,
                dim11781JoeKuoD6Init,
                dim11782JoeKuoD6Init,
                dim11783JoeKuoD6Init,
                dim11784JoeKuoD6Init,
                dim11785JoeKuoD6Init,
                dim11786JoeKuoD6Init,
                dim11787JoeKuoD6Init,
                dim11788JoeKuoD6Init,
                dim11789JoeKuoD6Init,
                dim11790JoeKuoD6Init,
                dim11791JoeKuoD6Init,
                dim11792JoeKuoD6Init,
                dim11793JoeKuoD6Init,
                dim11794JoeKuoD6Init,
                dim11795JoeKuoD6Init,
                dim11796JoeKuoD6Init,
                dim11797JoeKuoD6Init,
                dim11798JoeKuoD6Init,
                dim11799JoeKuoD6Init,
                dim11800JoeKuoD6Init,
                dim11801JoeKuoD6Init,
                dim11802JoeKuoD6Init,
                dim11803JoeKuoD6Init,
                dim11804JoeKuoD6Init,
                dim11805JoeKuoD6Init,
                dim11806JoeKuoD6Init,
                dim11807JoeKuoD6Init,
                dim11808JoeKuoD6Init,
                dim11809JoeKuoD6Init,
                dim11810JoeKuoD6Init,
                dim11811JoeKuoD6Init,
                dim11812JoeKuoD6Init,
                dim11813JoeKuoD6Init,
                dim11814JoeKuoD6Init,
                dim11815JoeKuoD6Init,
                dim11816JoeKuoD6Init,
                dim11817JoeKuoD6Init,
                dim11818JoeKuoD6Init,
                dim11819JoeKuoD6Init,
                dim11820JoeKuoD6Init,
                dim11821JoeKuoD6Init,
                dim11822JoeKuoD6Init,
                dim11823JoeKuoD6Init,
                dim11824JoeKuoD6Init,
                dim11825JoeKuoD6Init,
                dim11826JoeKuoD6Init,
                dim11827JoeKuoD6Init,
                dim11828JoeKuoD6Init,
                dim11829JoeKuoD6Init,
                dim11830JoeKuoD6Init,
                dim11831JoeKuoD6Init,
                dim11832JoeKuoD6Init,
                dim11833JoeKuoD6Init,
                dim11834JoeKuoD6Init,
                dim11835JoeKuoD6Init,
                dim11836JoeKuoD6Init,
                dim11837JoeKuoD6Init,
                dim11838JoeKuoD6Init,
                dim11839JoeKuoD6Init,
                dim11840JoeKuoD6Init,
                dim11841JoeKuoD6Init,
                dim11842JoeKuoD6Init,
                dim11843JoeKuoD6Init,
                dim11844JoeKuoD6Init,
                dim11845JoeKuoD6Init,
                dim11846JoeKuoD6Init,
                dim11847JoeKuoD6Init,
                dim11848JoeKuoD6Init,
                dim11849JoeKuoD6Init,
                dim11850JoeKuoD6Init,
                dim11851JoeKuoD6Init,
                dim11852JoeKuoD6Init,
                dim11853JoeKuoD6Init,
                dim11854JoeKuoD6Init,
                dim11855JoeKuoD6Init,
                dim11856JoeKuoD6Init,
                dim11857JoeKuoD6Init,
                dim11858JoeKuoD6Init,
                dim11859JoeKuoD6Init,
                dim11860JoeKuoD6Init,
                dim11861JoeKuoD6Init,
                dim11862JoeKuoD6Init,
                dim11863JoeKuoD6Init,
                dim11864JoeKuoD6Init,
                dim11865JoeKuoD6Init,
                dim11866JoeKuoD6Init,
                dim11867JoeKuoD6Init,
                dim11868JoeKuoD6Init,
                dim11869JoeKuoD6Init,
                dim11870JoeKuoD6Init,
                dim11871JoeKuoD6Init,
                dim11872JoeKuoD6Init,
                dim11873JoeKuoD6Init,
                dim11874JoeKuoD6Init,
                dim11875JoeKuoD6Init,
                dim11876JoeKuoD6Init,
                dim11877JoeKuoD6Init,
                dim11878JoeKuoD6Init,
                dim11879JoeKuoD6Init,
                dim11880JoeKuoD6Init,
                dim11881JoeKuoD6Init,
                dim11882JoeKuoD6Init,
                dim11883JoeKuoD6Init,
                dim11884JoeKuoD6Init,
                dim11885JoeKuoD6Init,
                dim11886JoeKuoD6Init,
                dim11887JoeKuoD6Init,
                dim11888JoeKuoD6Init,
                dim11889JoeKuoD6Init,
                dim11890JoeKuoD6Init,
                dim11891JoeKuoD6Init,
                dim11892JoeKuoD6Init,
                dim11893JoeKuoD6Init,
                dim11894JoeKuoD6Init,
                dim11895JoeKuoD6Init,
                dim11896JoeKuoD6Init,
                dim11897JoeKuoD6Init,
                dim11898JoeKuoD6Init,
                dim11899JoeKuoD6Init,
                dim11900JoeKuoD6Init,
                dim11901JoeKuoD6Init,
                dim11902JoeKuoD6Init,
                dim11903JoeKuoD6Init,
                dim11904JoeKuoD6Init,
                dim11905JoeKuoD6Init,
                dim11906JoeKuoD6Init,
                dim11907JoeKuoD6Init,
                dim11908JoeKuoD6Init,
                dim11909JoeKuoD6Init,
                dim11910JoeKuoD6Init,
                dim11911JoeKuoD6Init,
                dim11912JoeKuoD6Init,
                dim11913JoeKuoD6Init,
                dim11914JoeKuoD6Init,
                dim11915JoeKuoD6Init,
                dim11916JoeKuoD6Init,
                dim11917JoeKuoD6Init,
                dim11918JoeKuoD6Init,
                dim11919JoeKuoD6Init,
                dim11920JoeKuoD6Init,
                dim11921JoeKuoD6Init,
                dim11922JoeKuoD6Init,
                dim11923JoeKuoD6Init,
                dim11924JoeKuoD6Init,
                dim11925JoeKuoD6Init,
                dim11926JoeKuoD6Init,
                dim11927JoeKuoD6Init,
                dim11928JoeKuoD6Init,
                dim11929JoeKuoD6Init,
                dim11930JoeKuoD6Init,
                dim11931JoeKuoD6Init,
                dim11932JoeKuoD6Init,
                dim11933JoeKuoD6Init,
                dim11934JoeKuoD6Init,
                dim11935JoeKuoD6Init,
                dim11936JoeKuoD6Init,
                dim11937JoeKuoD6Init,
                dim11938JoeKuoD6Init,
                dim11939JoeKuoD6Init,
                dim11940JoeKuoD6Init,
                dim11941JoeKuoD6Init,
                dim11942JoeKuoD6Init,
                dim11943JoeKuoD6Init,
                dim11944JoeKuoD6Init,
                dim11945JoeKuoD6Init,
                dim11946JoeKuoD6Init,
                dim11947JoeKuoD6Init,
                dim11948JoeKuoD6Init,
                dim11949JoeKuoD6Init,
                dim11950JoeKuoD6Init,
                dim11951JoeKuoD6Init,
                dim11952JoeKuoD6Init,
                dim11953JoeKuoD6Init,
                dim11954JoeKuoD6Init,
                dim11955JoeKuoD6Init,
                dim11956JoeKuoD6Init,
                dim11957JoeKuoD6Init,
                dim11958JoeKuoD6Init,
                dim11959JoeKuoD6Init,
                dim11960JoeKuoD6Init,
                dim11961JoeKuoD6Init,
                dim11962JoeKuoD6Init,
                dim11963JoeKuoD6Init,
                dim11964JoeKuoD6Init,
                dim11965JoeKuoD6Init,
                dim11966JoeKuoD6Init,
                dim11967JoeKuoD6Init,
                dim11968JoeKuoD6Init,
                dim11969JoeKuoD6Init,
                dim11970JoeKuoD6Init,
                dim11971JoeKuoD6Init,
                dim11972JoeKuoD6Init,
                dim11973JoeKuoD6Init,
                dim11974JoeKuoD6Init,
                dim11975JoeKuoD6Init,
                dim11976JoeKuoD6Init,
                dim11977JoeKuoD6Init,
                dim11978JoeKuoD6Init,
                dim11979JoeKuoD6Init,
                dim11980JoeKuoD6Init,
                dim11981JoeKuoD6Init,
                dim11982JoeKuoD6Init,
                dim11983JoeKuoD6Init,
                dim11984JoeKuoD6Init,
                dim11985JoeKuoD6Init,
                dim11986JoeKuoD6Init,
                dim11987JoeKuoD6Init,
                dim11988JoeKuoD6Init,
                dim11989JoeKuoD6Init,
                dim11990JoeKuoD6Init,
                dim11991JoeKuoD6Init,
                dim11992JoeKuoD6Init,
                dim11993JoeKuoD6Init,
                dim11994JoeKuoD6Init,
                dim11995JoeKuoD6Init,
                dim11996JoeKuoD6Init,
                dim11997JoeKuoD6Init,
                dim11998JoeKuoD6Init,
                dim11999JoeKuoD6Init,
                dim12000JoeKuoD6Init,
                dim12001JoeKuoD6Init,
                dim12002JoeKuoD6Init,
                dim12003JoeKuoD6Init,
                dim12004JoeKuoD6Init,
                dim12005JoeKuoD6Init,
                dim12006JoeKuoD6Init,
                dim12007JoeKuoD6Init,
                dim12008JoeKuoD6Init,
                dim12009JoeKuoD6Init,
                dim12010JoeKuoD6Init,
                dim12011JoeKuoD6Init,
                dim12012JoeKuoD6Init,
                dim12013JoeKuoD6Init,
                dim12014JoeKuoD6Init,
                dim12015JoeKuoD6Init,
                dim12016JoeKuoD6Init,
                dim12017JoeKuoD6Init,
                dim12018JoeKuoD6Init,
                dim12019JoeKuoD6Init,
                dim12020JoeKuoD6Init,
                dim12021JoeKuoD6Init,
                dim12022JoeKuoD6Init,
                dim12023JoeKuoD6Init,
                dim12024JoeKuoD6Init,
                dim12025JoeKuoD6Init,
                dim12026JoeKuoD6Init,
                dim12027JoeKuoD6Init,
                dim12028JoeKuoD6Init,
                dim12029JoeKuoD6Init,
                dim12030JoeKuoD6Init,
                dim12031JoeKuoD6Init,
                dim12032JoeKuoD6Init,
                dim12033JoeKuoD6Init,
                dim12034JoeKuoD6Init,
                dim12035JoeKuoD6Init,
                dim12036JoeKuoD6Init,
                dim12037JoeKuoD6Init,
                dim12038JoeKuoD6Init,
                dim12039JoeKuoD6Init,
                dim12040JoeKuoD6Init,
                dim12041JoeKuoD6Init,
                dim12042JoeKuoD6Init,
                dim12043JoeKuoD6Init,
                dim12044JoeKuoD6Init,
                dim12045JoeKuoD6Init,
                dim12046JoeKuoD6Init,
                dim12047JoeKuoD6Init,
                dim12048JoeKuoD6Init,
                dim12049JoeKuoD6Init,
                dim12050JoeKuoD6Init,
                dim12051JoeKuoD6Init,
                dim12052JoeKuoD6Init,
                dim12053JoeKuoD6Init,
                dim12054JoeKuoD6Init,
                dim12055JoeKuoD6Init,
                dim12056JoeKuoD6Init,
                dim12057JoeKuoD6Init,
                dim12058JoeKuoD6Init,
                dim12059JoeKuoD6Init,
                dim12060JoeKuoD6Init,
                dim12061JoeKuoD6Init,
                dim12062JoeKuoD6Init,
                dim12063JoeKuoD6Init,
                dim12064JoeKuoD6Init,
                dim12065JoeKuoD6Init,
                dim12066JoeKuoD6Init,
                dim12067JoeKuoD6Init,
                dim12068JoeKuoD6Init,
                dim12069JoeKuoD6Init,
                dim12070JoeKuoD6Init,
                dim12071JoeKuoD6Init,
                dim12072JoeKuoD6Init,
                dim12073JoeKuoD6Init,
                dim12074JoeKuoD6Init,
                dim12075JoeKuoD6Init,
                dim12076JoeKuoD6Init,
                dim12077JoeKuoD6Init,
                dim12078JoeKuoD6Init,
                dim12079JoeKuoD6Init,
                dim12080JoeKuoD6Init,
                dim12081JoeKuoD6Init,
                dim12082JoeKuoD6Init,
                dim12083JoeKuoD6Init,
                dim12084JoeKuoD6Init,
                dim12085JoeKuoD6Init,
                dim12086JoeKuoD6Init,
                dim12087JoeKuoD6Init,
                dim12088JoeKuoD6Init,
                dim12089JoeKuoD6Init,
                dim12090JoeKuoD6Init,
                dim12091JoeKuoD6Init,
                dim12092JoeKuoD6Init,
                dim12093JoeKuoD6Init,
                dim12094JoeKuoD6Init,
                dim12095JoeKuoD6Init,
                dim12096JoeKuoD6Init,
                dim12097JoeKuoD6Init,
                dim12098JoeKuoD6Init,
                dim12099JoeKuoD6Init,
                dim12100JoeKuoD6Init,
                dim12101JoeKuoD6Init,
                dim12102JoeKuoD6Init,
                dim12103JoeKuoD6Init,
                dim12104JoeKuoD6Init,
                dim12105JoeKuoD6Init,
                dim12106JoeKuoD6Init,
                dim12107JoeKuoD6Init,
                dim12108JoeKuoD6Init,
                dim12109JoeKuoD6Init,
                dim12110JoeKuoD6Init,
                dim12111JoeKuoD6Init,
                dim12112JoeKuoD6Init,
                dim12113JoeKuoD6Init,
                dim12114JoeKuoD6Init,
                dim12115JoeKuoD6Init,
                dim12116JoeKuoD6Init,
                dim12117JoeKuoD6Init,
                dim12118JoeKuoD6Init,
                dim12119JoeKuoD6Init,
                dim12120JoeKuoD6Init,
                dim12121JoeKuoD6Init,
                dim12122JoeKuoD6Init,
                dim12123JoeKuoD6Init,
                dim12124JoeKuoD6Init,
                dim12125JoeKuoD6Init,
                dim12126JoeKuoD6Init,
                dim12127JoeKuoD6Init,
                dim12128JoeKuoD6Init,
                dim12129JoeKuoD6Init,
                dim12130JoeKuoD6Init,
                dim12131JoeKuoD6Init,
                dim12132JoeKuoD6Init,
                dim12133JoeKuoD6Init,
                dim12134JoeKuoD6Init,
                dim12135JoeKuoD6Init,
                dim12136JoeKuoD6Init,
                dim12137JoeKuoD6Init,
                dim12138JoeKuoD6Init,
                dim12139JoeKuoD6Init,
                dim12140JoeKuoD6Init,
                dim12141JoeKuoD6Init,
                dim12142JoeKuoD6Init,
                dim12143JoeKuoD6Init,
                dim12144JoeKuoD6Init,
                dim12145JoeKuoD6Init,
                dim12146JoeKuoD6Init,
                dim12147JoeKuoD6Init,
                dim12148JoeKuoD6Init,
                dim12149JoeKuoD6Init,
                dim12150JoeKuoD6Init,
                dim12151JoeKuoD6Init,
                dim12152JoeKuoD6Init,
                dim12153JoeKuoD6Init,
                dim12154JoeKuoD6Init,
                dim12155JoeKuoD6Init,
                dim12156JoeKuoD6Init,
                dim12157JoeKuoD6Init,
                dim12158JoeKuoD6Init,
                dim12159JoeKuoD6Init,
                dim12160JoeKuoD6Init,
                dim12161JoeKuoD6Init,
                dim12162JoeKuoD6Init,
                dim12163JoeKuoD6Init,
                dim12164JoeKuoD6Init,
                dim12165JoeKuoD6Init,
                dim12166JoeKuoD6Init,
                dim12167JoeKuoD6Init,
                dim12168JoeKuoD6Init,
                dim12169JoeKuoD6Init,
                dim12170JoeKuoD6Init,
                dim12171JoeKuoD6Init,
                dim12172JoeKuoD6Init,
                dim12173JoeKuoD6Init,
                dim12174JoeKuoD6Init,
                dim12175JoeKuoD6Init,
                dim12176JoeKuoD6Init,
                dim12177JoeKuoD6Init,
                dim12178JoeKuoD6Init,
                dim12179JoeKuoD6Init,
                dim12180JoeKuoD6Init,
                dim12181JoeKuoD6Init,
                dim12182JoeKuoD6Init,
                dim12183JoeKuoD6Init,
                dim12184JoeKuoD6Init,
                dim12185JoeKuoD6Init,
                dim12186JoeKuoD6Init,
                dim12187JoeKuoD6Init,
                dim12188JoeKuoD6Init,
                dim12189JoeKuoD6Init,
                dim12190JoeKuoD6Init,
                dim12191JoeKuoD6Init,
                dim12192JoeKuoD6Init,
                dim12193JoeKuoD6Init,
                dim12194JoeKuoD6Init,
                dim12195JoeKuoD6Init,
                dim12196JoeKuoD6Init,
                dim12197JoeKuoD6Init,
                dim12198JoeKuoD6Init,
                dim12199JoeKuoD6Init,
                dim12200JoeKuoD6Init,
                dim12201JoeKuoD6Init,
                dim12202JoeKuoD6Init,
                dim12203JoeKuoD6Init,
                dim12204JoeKuoD6Init,
                dim12205JoeKuoD6Init,
                dim12206JoeKuoD6Init,
                dim12207JoeKuoD6Init,
                dim12208JoeKuoD6Init,
                dim12209JoeKuoD6Init,
                dim12210JoeKuoD6Init,
                dim12211JoeKuoD6Init,
                dim12212JoeKuoD6Init,
                dim12213JoeKuoD6Init,
                dim12214JoeKuoD6Init,
                dim12215JoeKuoD6Init,
                dim12216JoeKuoD6Init,
                dim12217JoeKuoD6Init,
                dim12218JoeKuoD6Init,
                dim12219JoeKuoD6Init,
                dim12220JoeKuoD6Init,
                dim12221JoeKuoD6Init,
                dim12222JoeKuoD6Init,
                dim12223JoeKuoD6Init,
                dim12224JoeKuoD6Init,
                dim12225JoeKuoD6Init,
                dim12226JoeKuoD6Init,
                dim12227JoeKuoD6Init,
                dim12228JoeKuoD6Init,
                dim12229JoeKuoD6Init,
                dim12230JoeKuoD6Init,
                dim12231JoeKuoD6Init,
                dim12232JoeKuoD6Init,
                dim12233JoeKuoD6Init,
                dim12234JoeKuoD6Init,
                dim12235JoeKuoD6Init,
                dim12236JoeKuoD6Init,
                dim12237JoeKuoD6Init,
                dim12238JoeKuoD6Init,
                dim12239JoeKuoD6Init,
                dim12240JoeKuoD6Init,
                dim12241JoeKuoD6Init,
                dim12242JoeKuoD6Init,
                dim12243JoeKuoD6Init,
                dim12244JoeKuoD6Init,
                dim12245JoeKuoD6Init,
                dim12246JoeKuoD6Init,
                dim12247JoeKuoD6Init,
                dim12248JoeKuoD6Init,
                dim12249JoeKuoD6Init,
                dim12250JoeKuoD6Init,
                dim12251JoeKuoD6Init,
                dim12252JoeKuoD6Init,
                dim12253JoeKuoD6Init,
                dim12254JoeKuoD6Init,
                dim12255JoeKuoD6Init,
                dim12256JoeKuoD6Init,
                dim12257JoeKuoD6Init,
                dim12258JoeKuoD6Init,
                dim12259JoeKuoD6Init,
                dim12260JoeKuoD6Init,
                dim12261JoeKuoD6Init,
                dim12262JoeKuoD6Init,
                dim12263JoeKuoD6Init,
                dim12264JoeKuoD6Init,
                dim12265JoeKuoD6Init,
                dim12266JoeKuoD6Init,
                dim12267JoeKuoD6Init,
                dim12268JoeKuoD6Init,
                dim12269JoeKuoD6Init,
                dim12270JoeKuoD6Init,
                dim12271JoeKuoD6Init,
                dim12272JoeKuoD6Init,
                dim12273JoeKuoD6Init,
                dim12274JoeKuoD6Init,
                dim12275JoeKuoD6Init,
                dim12276JoeKuoD6Init,
                dim12277JoeKuoD6Init,
                dim12278JoeKuoD6Init,
                dim12279JoeKuoD6Init,
                dim12280JoeKuoD6Init,
                dim12281JoeKuoD6Init,
                dim12282JoeKuoD6Init,
                dim12283JoeKuoD6Init,
                dim12284JoeKuoD6Init,
                dim12285JoeKuoD6Init,
                dim12286JoeKuoD6Init,
                dim12287JoeKuoD6Init,
                dim12288JoeKuoD6Init,
                dim12289JoeKuoD6Init,
                dim12290JoeKuoD6Init,
                dim12291JoeKuoD6Init,
                dim12292JoeKuoD6Init,
                dim12293JoeKuoD6Init,
                dim12294JoeKuoD6Init,
                dim12295JoeKuoD6Init,
                dim12296JoeKuoD6Init,
                dim12297JoeKuoD6Init,
                dim12298JoeKuoD6Init,
                dim12299JoeKuoD6Init,
                dim12300JoeKuoD6Init,
                dim12301JoeKuoD6Init,
                dim12302JoeKuoD6Init,
                dim12303JoeKuoD6Init,
                dim12304JoeKuoD6Init,
                dim12305JoeKuoD6Init,
                dim12306JoeKuoD6Init,
                dim12307JoeKuoD6Init,
                dim12308JoeKuoD6Init,
                dim12309JoeKuoD6Init,
                dim12310JoeKuoD6Init,
                dim12311JoeKuoD6Init,
                dim12312JoeKuoD6Init,
                dim12313JoeKuoD6Init,
                dim12314JoeKuoD6Init,
                dim12315JoeKuoD6Init,
                dim12316JoeKuoD6Init,
                dim12317JoeKuoD6Init,
                dim12318JoeKuoD6Init,
                dim12319JoeKuoD6Init,
                dim12320JoeKuoD6Init,
                dim12321JoeKuoD6Init,
                dim12322JoeKuoD6Init,
                dim12323JoeKuoD6Init,
                dim12324JoeKuoD6Init,
                dim12325JoeKuoD6Init,
                dim12326JoeKuoD6Init,
                dim12327JoeKuoD6Init,
                dim12328JoeKuoD6Init,
                dim12329JoeKuoD6Init,
                dim12330JoeKuoD6Init,
                dim12331JoeKuoD6Init,
                dim12332JoeKuoD6Init,
                dim12333JoeKuoD6Init,
                dim12334JoeKuoD6Init,
                dim12335JoeKuoD6Init,
                dim12336JoeKuoD6Init,
                dim12337JoeKuoD6Init,
                dim12338JoeKuoD6Init,
                dim12339JoeKuoD6Init,
                dim12340JoeKuoD6Init,
                dim12341JoeKuoD6Init,
                dim12342JoeKuoD6Init,
                dim12343JoeKuoD6Init,
                dim12344JoeKuoD6Init,
                dim12345JoeKuoD6Init,
                dim12346JoeKuoD6Init,
                dim12347JoeKuoD6Init,
                dim12348JoeKuoD6Init,
                dim12349JoeKuoD6Init,
                dim12350JoeKuoD6Init,
                dim12351JoeKuoD6Init,
                dim12352JoeKuoD6Init,
                dim12353JoeKuoD6Init,
                dim12354JoeKuoD6Init,
                dim12355JoeKuoD6Init,
                dim12356JoeKuoD6Init,
                dim12357JoeKuoD6Init,
                dim12358JoeKuoD6Init,
                dim12359JoeKuoD6Init,
                dim12360JoeKuoD6Init,
                dim12361JoeKuoD6Init,
                dim12362JoeKuoD6Init,
                dim12363JoeKuoD6Init,
                dim12364JoeKuoD6Init,
                dim12365JoeKuoD6Init,
                dim12366JoeKuoD6Init,
                dim12367JoeKuoD6Init,
                dim12368JoeKuoD6Init,
                dim12369JoeKuoD6Init,
                dim12370JoeKuoD6Init,
                dim12371JoeKuoD6Init,
                dim12372JoeKuoD6Init,
                dim12373JoeKuoD6Init,
                dim12374JoeKuoD6Init,
                dim12375JoeKuoD6Init,
                dim12376JoeKuoD6Init,
                dim12377JoeKuoD6Init,
                dim12378JoeKuoD6Init,
                dim12379JoeKuoD6Init,
                dim12380JoeKuoD6Init,
                dim12381JoeKuoD6Init,
                dim12382JoeKuoD6Init,
                dim12383JoeKuoD6Init,
                dim12384JoeKuoD6Init,
                dim12385JoeKuoD6Init,
                dim12386JoeKuoD6Init,
                dim12387JoeKuoD6Init,
                dim12388JoeKuoD6Init,
                dim12389JoeKuoD6Init,
                dim12390JoeKuoD6Init,
                dim12391JoeKuoD6Init,
                dim12392JoeKuoD6Init,
                dim12393JoeKuoD6Init,
                dim12394JoeKuoD6Init,
                dim12395JoeKuoD6Init,
                dim12396JoeKuoD6Init,
                dim12397JoeKuoD6Init,
                dim12398JoeKuoD6Init,
                dim12399JoeKuoD6Init,
                dim12400JoeKuoD6Init,
                dim12401JoeKuoD6Init,
                dim12402JoeKuoD6Init,
                dim12403JoeKuoD6Init,
                dim12404JoeKuoD6Init,
                dim12405JoeKuoD6Init,
                dim12406JoeKuoD6Init,
                dim12407JoeKuoD6Init,
                dim12408JoeKuoD6Init,
                dim12409JoeKuoD6Init,
                dim12410JoeKuoD6Init,
                dim12411JoeKuoD6Init,
                dim12412JoeKuoD6Init,
                dim12413JoeKuoD6Init,
                dim12414JoeKuoD6Init,
                dim12415JoeKuoD6Init,
                dim12416JoeKuoD6Init,
                dim12417JoeKuoD6Init,
                dim12418JoeKuoD6Init,
                dim12419JoeKuoD6Init,
                dim12420JoeKuoD6Init,
                dim12421JoeKuoD6Init,
                dim12422JoeKuoD6Init,
                dim12423JoeKuoD6Init,
                dim12424JoeKuoD6Init,
                dim12425JoeKuoD6Init,
                dim12426JoeKuoD6Init,
                dim12427JoeKuoD6Init,
                dim12428JoeKuoD6Init,
                dim12429JoeKuoD6Init,
                dim12430JoeKuoD6Init,
                dim12431JoeKuoD6Init,
                dim12432JoeKuoD6Init,
                dim12433JoeKuoD6Init,
                dim12434JoeKuoD6Init,
                dim12435JoeKuoD6Init,
                dim12436JoeKuoD6Init,
                dim12437JoeKuoD6Init,
                dim12438JoeKuoD6Init,
                dim12439JoeKuoD6Init,
                dim12440JoeKuoD6Init,
                dim12441JoeKuoD6Init,
                dim12442JoeKuoD6Init,
                dim12443JoeKuoD6Init,
                dim12444JoeKuoD6Init,
                dim12445JoeKuoD6Init,
                dim12446JoeKuoD6Init,
                dim12447JoeKuoD6Init,
                dim12448JoeKuoD6Init,
                dim12449JoeKuoD6Init,
                dim12450JoeKuoD6Init,
                dim12451JoeKuoD6Init,
                dim12452JoeKuoD6Init,
                dim12453JoeKuoD6Init,
                dim12454JoeKuoD6Init,
                dim12455JoeKuoD6Init,
                dim12456JoeKuoD6Init,
                dim12457JoeKuoD6Init,
                dim12458JoeKuoD6Init,
                dim12459JoeKuoD6Init,
                dim12460JoeKuoD6Init,
                dim12461JoeKuoD6Init,
                dim12462JoeKuoD6Init,
                dim12463JoeKuoD6Init,
                dim12464JoeKuoD6Init,
                dim12465JoeKuoD6Init,
                dim12466JoeKuoD6Init,
                dim12467JoeKuoD6Init,
                dim12468JoeKuoD6Init,
                dim12469JoeKuoD6Init,
                dim12470JoeKuoD6Init,
                dim12471JoeKuoD6Init,
                dim12472JoeKuoD6Init,
                dim12473JoeKuoD6Init,
                dim12474JoeKuoD6Init,
                dim12475JoeKuoD6Init,
                dim12476JoeKuoD6Init,
                dim12477JoeKuoD6Init,
                dim12478JoeKuoD6Init,
                dim12479JoeKuoD6Init,
                dim12480JoeKuoD6Init,
                dim12481JoeKuoD6Init,
                dim12482JoeKuoD6Init,
                dim12483JoeKuoD6Init,
                dim12484JoeKuoD6Init,
                dim12485JoeKuoD6Init,
                dim12486JoeKuoD6Init,
                dim12487JoeKuoD6Init,
                dim12488JoeKuoD6Init,
                dim12489JoeKuoD6Init,
                dim12490JoeKuoD6Init,
                dim12491JoeKuoD6Init,
                dim12492JoeKuoD6Init,
                dim12493JoeKuoD6Init,
                dim12494JoeKuoD6Init,
                dim12495JoeKuoD6Init,
                dim12496JoeKuoD6Init,
                dim12497JoeKuoD6Init,
                dim12498JoeKuoD6Init,
                dim12499JoeKuoD6Init,
                dim12500JoeKuoD6Init,
                dim12501JoeKuoD6Init,
                dim12502JoeKuoD6Init,
                dim12503JoeKuoD6Init,
                dim12504JoeKuoD6Init,
                dim12505JoeKuoD6Init,
                dim12506JoeKuoD6Init,
                dim12507JoeKuoD6Init,
                dim12508JoeKuoD6Init,
                dim12509JoeKuoD6Init,
                dim12510JoeKuoD6Init,
                dim12511JoeKuoD6Init,
                dim12512JoeKuoD6Init,
                dim12513JoeKuoD6Init,
                dim12514JoeKuoD6Init,
                dim12515JoeKuoD6Init,
                dim12516JoeKuoD6Init,
                dim12517JoeKuoD6Init,
                dim12518JoeKuoD6Init,
                dim12519JoeKuoD6Init,
                dim12520JoeKuoD6Init,
                dim12521JoeKuoD6Init,
                dim12522JoeKuoD6Init,
                dim12523JoeKuoD6Init,
                dim12524JoeKuoD6Init,
                dim12525JoeKuoD6Init,
                dim12526JoeKuoD6Init,
                dim12527JoeKuoD6Init,
                dim12528JoeKuoD6Init,
                dim12529JoeKuoD6Init,
                dim12530JoeKuoD6Init,
                dim12531JoeKuoD6Init,
                dim12532JoeKuoD6Init,
                dim12533JoeKuoD6Init,
                dim12534JoeKuoD6Init,
                dim12535JoeKuoD6Init,
                dim12536JoeKuoD6Init,
                dim12537JoeKuoD6Init,
                dim12538JoeKuoD6Init,
                dim12539JoeKuoD6Init,
                dim12540JoeKuoD6Init,
                dim12541JoeKuoD6Init,
                dim12542JoeKuoD6Init,
                dim12543JoeKuoD6Init,
                dim12544JoeKuoD6Init,
                dim12545JoeKuoD6Init,
                dim12546JoeKuoD6Init,
                dim12547JoeKuoD6Init,
                dim12548JoeKuoD6Init,
                dim12549JoeKuoD6Init,
                dim12550JoeKuoD6Init,
                dim12551JoeKuoD6Init,
                dim12552JoeKuoD6Init,
                dim12553JoeKuoD6Init,
                dim12554JoeKuoD6Init,
                dim12555JoeKuoD6Init,
                dim12556JoeKuoD6Init,
                dim12557JoeKuoD6Init,
                dim12558JoeKuoD6Init,
                dim12559JoeKuoD6Init,
                dim12560JoeKuoD6Init,
                dim12561JoeKuoD6Init,
                dim12562JoeKuoD6Init,
                dim12563JoeKuoD6Init,
                dim12564JoeKuoD6Init,
                dim12565JoeKuoD6Init,
                dim12566JoeKuoD6Init,
                dim12567JoeKuoD6Init,
                dim12568JoeKuoD6Init,
                dim12569JoeKuoD6Init,
                dim12570JoeKuoD6Init,
                dim12571JoeKuoD6Init,
                dim12572JoeKuoD6Init,
                dim12573JoeKuoD6Init,
                dim12574JoeKuoD6Init,
                dim12575JoeKuoD6Init,
                dim12576JoeKuoD6Init,
                dim12577JoeKuoD6Init,
                dim12578JoeKuoD6Init,
                dim12579JoeKuoD6Init,
                dim12580JoeKuoD6Init,
                dim12581JoeKuoD6Init,
                dim12582JoeKuoD6Init,
                dim12583JoeKuoD6Init,
                dim12584JoeKuoD6Init,
                dim12585JoeKuoD6Init,
                dim12586JoeKuoD6Init,
                dim12587JoeKuoD6Init,
                dim12588JoeKuoD6Init,
                dim12589JoeKuoD6Init,
                dim12590JoeKuoD6Init,
                dim12591JoeKuoD6Init,
                dim12592JoeKuoD6Init,
                dim12593JoeKuoD6Init,
                dim12594JoeKuoD6Init,
                dim12595JoeKuoD6Init,
                dim12596JoeKuoD6Init,
                dim12597JoeKuoD6Init,
                dim12598JoeKuoD6Init,
                dim12599JoeKuoD6Init,
                dim12600JoeKuoD6Init,
                dim12601JoeKuoD6Init,
                dim12602JoeKuoD6Init,
                dim12603JoeKuoD6Init,
                dim12604JoeKuoD6Init,
                dim12605JoeKuoD6Init,
                dim12606JoeKuoD6Init,
                dim12607JoeKuoD6Init,
                dim12608JoeKuoD6Init,
                dim12609JoeKuoD6Init,
                dim12610JoeKuoD6Init,
                dim12611JoeKuoD6Init,
                dim12612JoeKuoD6Init,
                dim12613JoeKuoD6Init,
                dim12614JoeKuoD6Init,
                dim12615JoeKuoD6Init,
                dim12616JoeKuoD6Init,
                dim12617JoeKuoD6Init,
                dim12618JoeKuoD6Init,
                dim12619JoeKuoD6Init,
                dim12620JoeKuoD6Init,
                dim12621JoeKuoD6Init,
                dim12622JoeKuoD6Init,
                dim12623JoeKuoD6Init,
                dim12624JoeKuoD6Init,
                dim12625JoeKuoD6Init,
                dim12626JoeKuoD6Init,
                dim12627JoeKuoD6Init,
                dim12628JoeKuoD6Init,
                dim12629JoeKuoD6Init,
                dim12630JoeKuoD6Init,
                dim12631JoeKuoD6Init,
                dim12632JoeKuoD6Init,
                dim12633JoeKuoD6Init,
                dim12634JoeKuoD6Init,
                dim12635JoeKuoD6Init,
                dim12636JoeKuoD6Init,
                dim12637JoeKuoD6Init,
                dim12638JoeKuoD6Init,
                dim12639JoeKuoD6Init,
                dim12640JoeKuoD6Init,
                dim12641JoeKuoD6Init,
                dim12642JoeKuoD6Init,
                dim12643JoeKuoD6Init,
                dim12644JoeKuoD6Init,
                dim12645JoeKuoD6Init,
                dim12646JoeKuoD6Init,
                dim12647JoeKuoD6Init,
                dim12648JoeKuoD6Init,
                dim12649JoeKuoD6Init,
                dim12650JoeKuoD6Init,
                dim12651JoeKuoD6Init,
                dim12652JoeKuoD6Init,
                dim12653JoeKuoD6Init,
                dim12654JoeKuoD6Init,
                dim12655JoeKuoD6Init,
                dim12656JoeKuoD6Init,
                dim12657JoeKuoD6Init,
                dim12658JoeKuoD6Init,
                dim12659JoeKuoD6Init,
                dim12660JoeKuoD6Init,
                dim12661JoeKuoD6Init,
                dim12662JoeKuoD6Init,
                dim12663JoeKuoD6Init,
                dim12664JoeKuoD6Init,
                dim12665JoeKuoD6Init,
                dim12666JoeKuoD6Init,
                dim12667JoeKuoD6Init,
                dim12668JoeKuoD6Init,
                dim12669JoeKuoD6Init,
                dim12670JoeKuoD6Init,
                dim12671JoeKuoD6Init,
                dim12672JoeKuoD6Init,
                dim12673JoeKuoD6Init,
                dim12674JoeKuoD6Init,
                dim12675JoeKuoD6Init,
                dim12676JoeKuoD6Init,
                dim12677JoeKuoD6Init,
                dim12678JoeKuoD6Init,
                dim12679JoeKuoD6Init,
                dim12680JoeKuoD6Init,
                dim12681JoeKuoD6Init,
                dim12682JoeKuoD6Init,
                dim12683JoeKuoD6Init,
                dim12684JoeKuoD6Init,
                dim12685JoeKuoD6Init,
                dim12686JoeKuoD6Init,
                dim12687JoeKuoD6Init,
                dim12688JoeKuoD6Init,
                dim12689JoeKuoD6Init,
                dim12690JoeKuoD6Init,
                dim12691JoeKuoD6Init,
                dim12692JoeKuoD6Init,
                dim12693JoeKuoD6Init,
                dim12694JoeKuoD6Init,
                dim12695JoeKuoD6Init,
                dim12696JoeKuoD6Init,
                dim12697JoeKuoD6Init,
                dim12698JoeKuoD6Init,
                dim12699JoeKuoD6Init,
                dim12700JoeKuoD6Init,
                dim12701JoeKuoD6Init,
                dim12702JoeKuoD6Init,
                dim12703JoeKuoD6Init,
                dim12704JoeKuoD6Init,
                dim12705JoeKuoD6Init,
                dim12706JoeKuoD6Init,
                dim12707JoeKuoD6Init,
                dim12708JoeKuoD6Init,
                dim12709JoeKuoD6Init,
                dim12710JoeKuoD6Init,
                dim12711JoeKuoD6Init,
                dim12712JoeKuoD6Init,
                dim12713JoeKuoD6Init,
                dim12714JoeKuoD6Init,
                dim12715JoeKuoD6Init,
                dim12716JoeKuoD6Init,
                dim12717JoeKuoD6Init,
                dim12718JoeKuoD6Init,
                dim12719JoeKuoD6Init,
                dim12720JoeKuoD6Init,
                dim12721JoeKuoD6Init,
                dim12722JoeKuoD6Init,
                dim12723JoeKuoD6Init,
                dim12724JoeKuoD6Init,
                dim12725JoeKuoD6Init,
                dim12726JoeKuoD6Init,
                dim12727JoeKuoD6Init,
                dim12728JoeKuoD6Init,
                dim12729JoeKuoD6Init,
                dim12730JoeKuoD6Init,
                dim12731JoeKuoD6Init,
                dim12732JoeKuoD6Init,
                dim12733JoeKuoD6Init,
                dim12734JoeKuoD6Init,
                dim12735JoeKuoD6Init,
                dim12736JoeKuoD6Init,
                dim12737JoeKuoD6Init,
                dim12738JoeKuoD6Init,
                dim12739JoeKuoD6Init,
                dim12740JoeKuoD6Init,
                dim12741JoeKuoD6Init,
                dim12742JoeKuoD6Init,
                dim12743JoeKuoD6Init,
                dim12744JoeKuoD6Init,
                dim12745JoeKuoD6Init,
                dim12746JoeKuoD6Init,
                dim12747JoeKuoD6Init,
                dim12748JoeKuoD6Init,
                dim12749JoeKuoD6Init,
                dim12750JoeKuoD6Init,
                dim12751JoeKuoD6Init,
                dim12752JoeKuoD6Init,
                dim12753JoeKuoD6Init,
                dim12754JoeKuoD6Init,
                dim12755JoeKuoD6Init,
                dim12756JoeKuoD6Init,
                dim12757JoeKuoD6Init,
                dim12758JoeKuoD6Init,
                dim12759JoeKuoD6Init,
                dim12760JoeKuoD6Init,
                dim12761JoeKuoD6Init,
                dim12762JoeKuoD6Init,
                dim12763JoeKuoD6Init,
                dim12764JoeKuoD6Init,
                dim12765JoeKuoD6Init,
                dim12766JoeKuoD6Init,
                dim12767JoeKuoD6Init,
                dim12768JoeKuoD6Init,
                dim12769JoeKuoD6Init,
                dim12770JoeKuoD6Init,
                dim12771JoeKuoD6Init,
                dim12772JoeKuoD6Init,
                dim12773JoeKuoD6Init,
                dim12774JoeKuoD6Init,
                dim12775JoeKuoD6Init,
                dim12776JoeKuoD6Init,
                dim12777JoeKuoD6Init,
                dim12778JoeKuoD6Init,
                dim12779JoeKuoD6Init,
                dim12780JoeKuoD6Init,
                dim12781JoeKuoD6Init,
                dim12782JoeKuoD6Init,
                dim12783JoeKuoD6Init,
                dim12784JoeKuoD6Init,
                dim12785JoeKuoD6Init,
                dim12786JoeKuoD6Init,
                dim12787JoeKuoD6Init,
                dim12788JoeKuoD6Init,
                dim12789JoeKuoD6Init,
                dim12790JoeKuoD6Init,
                dim12791JoeKuoD6Init,
                dim12792JoeKuoD6Init,
                dim12793JoeKuoD6Init,
                dim12794JoeKuoD6Init,
                dim12795JoeKuoD6Init,
                dim12796JoeKuoD6Init,
                dim12797JoeKuoD6Init,
                dim12798JoeKuoD6Init,
                dim12799JoeKuoD6Init,
                dim12800JoeKuoD6Init,
                dim12801JoeKuoD6Init,
                dim12802JoeKuoD6Init,
                dim12803JoeKuoD6Init,
                dim12804JoeKuoD6Init,
                dim12805JoeKuoD6Init,
                dim12806JoeKuoD6Init,
                dim12807JoeKuoD6Init,
                dim12808JoeKuoD6Init,
                dim12809JoeKuoD6Init,
                dim12810JoeKuoD6Init,
                dim12811JoeKuoD6Init,
                dim12812JoeKuoD6Init,
                dim12813JoeKuoD6Init,
                dim12814JoeKuoD6Init,
                dim12815JoeKuoD6Init,
                dim12816JoeKuoD6Init,
                dim12817JoeKuoD6Init,
                dim12818JoeKuoD6Init,
                dim12819JoeKuoD6Init,
                dim12820JoeKuoD6Init,
                dim12821JoeKuoD6Init,
                dim12822JoeKuoD6Init,
                dim12823JoeKuoD6Init,
                dim12824JoeKuoD6Init,
                dim12825JoeKuoD6Init,
                dim12826JoeKuoD6Init,
                dim12827JoeKuoD6Init,
                dim12828JoeKuoD6Init,
                dim12829JoeKuoD6Init,
                dim12830JoeKuoD6Init,
                dim12831JoeKuoD6Init,
                dim12832JoeKuoD6Init,
                dim12833JoeKuoD6Init,
                dim12834JoeKuoD6Init,
                dim12835JoeKuoD6Init,
                dim12836JoeKuoD6Init,
                dim12837JoeKuoD6Init,
                dim12838JoeKuoD6Init,
                dim12839JoeKuoD6Init,
                dim12840JoeKuoD6Init,
                dim12841JoeKuoD6Init,
                dim12842JoeKuoD6Init,
                dim12843JoeKuoD6Init,
                dim12844JoeKuoD6Init,
                dim12845JoeKuoD6Init,
                dim12846JoeKuoD6Init,
                dim12847JoeKuoD6Init,
                dim12848JoeKuoD6Init,
                dim12849JoeKuoD6Init,
                dim12850JoeKuoD6Init,
                dim12851JoeKuoD6Init,
                dim12852JoeKuoD6Init,
                dim12853JoeKuoD6Init,
                dim12854JoeKuoD6Init,
                dim12855JoeKuoD6Init,
                dim12856JoeKuoD6Init,
                dim12857JoeKuoD6Init,
                dim12858JoeKuoD6Init,
                dim12859JoeKuoD6Init,
                dim12860JoeKuoD6Init,
                dim12861JoeKuoD6Init,
                dim12862JoeKuoD6Init,
                dim12863JoeKuoD6Init,
                dim12864JoeKuoD6Init,
                dim12865JoeKuoD6Init,
                dim12866JoeKuoD6Init,
                dim12867JoeKuoD6Init,
                dim12868JoeKuoD6Init,
                dim12869JoeKuoD6Init,
                dim12870JoeKuoD6Init,
                dim12871JoeKuoD6Init,
                dim12872JoeKuoD6Init,
                dim12873JoeKuoD6Init,
                dim12874JoeKuoD6Init,
                dim12875JoeKuoD6Init,
                dim12876JoeKuoD6Init,
                dim12877JoeKuoD6Init,
                dim12878JoeKuoD6Init,
                dim12879JoeKuoD6Init,
                dim12880JoeKuoD6Init,
                dim12881JoeKuoD6Init,
                dim12882JoeKuoD6Init,
                dim12883JoeKuoD6Init,
                dim12884JoeKuoD6Init,
                dim12885JoeKuoD6Init,
                dim12886JoeKuoD6Init,
                dim12887JoeKuoD6Init,
                dim12888JoeKuoD6Init,
                dim12889JoeKuoD6Init,
                dim12890JoeKuoD6Init,
                dim12891JoeKuoD6Init,
                dim12892JoeKuoD6Init,
                dim12893JoeKuoD6Init,
                dim12894JoeKuoD6Init,
                dim12895JoeKuoD6Init,
                dim12896JoeKuoD6Init,
                dim12897JoeKuoD6Init,
                dim12898JoeKuoD6Init,
                dim12899JoeKuoD6Init,
                dim12900JoeKuoD6Init,
                dim12901JoeKuoD6Init,
                dim12902JoeKuoD6Init,
                dim12903JoeKuoD6Init,
                dim12904JoeKuoD6Init,
                dim12905JoeKuoD6Init,
                dim12906JoeKuoD6Init,
                dim12907JoeKuoD6Init,
                dim12908JoeKuoD6Init,
                dim12909JoeKuoD6Init,
                dim12910JoeKuoD6Init,
                dim12911JoeKuoD6Init,
                dim12912JoeKuoD6Init,
                dim12913JoeKuoD6Init,
                dim12914JoeKuoD6Init,
                dim12915JoeKuoD6Init,
                dim12916JoeKuoD6Init,
                dim12917JoeKuoD6Init,
                dim12918JoeKuoD6Init,
                dim12919JoeKuoD6Init,
                dim12920JoeKuoD6Init,
                dim12921JoeKuoD6Init,
                dim12922JoeKuoD6Init,
                dim12923JoeKuoD6Init,
                dim12924JoeKuoD6Init,
                dim12925JoeKuoD6Init,
                dim12926JoeKuoD6Init,
                dim12927JoeKuoD6Init,
                dim12928JoeKuoD6Init,
                dim12929JoeKuoD6Init,
                dim12930JoeKuoD6Init,
                dim12931JoeKuoD6Init,
                dim12932JoeKuoD6Init,
                dim12933JoeKuoD6Init,
                dim12934JoeKuoD6Init,
                dim12935JoeKuoD6Init,
                dim12936JoeKuoD6Init,
                dim12937JoeKuoD6Init,
                dim12938JoeKuoD6Init,
                dim12939JoeKuoD6Init,
                dim12940JoeKuoD6Init,
                dim12941JoeKuoD6Init,
                dim12942JoeKuoD6Init,
                dim12943JoeKuoD6Init,
                dim12944JoeKuoD6Init,
                dim12945JoeKuoD6Init,
                dim12946JoeKuoD6Init,
                dim12947JoeKuoD6Init,
                dim12948JoeKuoD6Init,
                dim12949JoeKuoD6Init,
                dim12950JoeKuoD6Init,
                dim12951JoeKuoD6Init,
                dim12952JoeKuoD6Init,
                dim12953JoeKuoD6Init,
                dim12954JoeKuoD6Init,
                dim12955JoeKuoD6Init,
                dim12956JoeKuoD6Init,
                dim12957JoeKuoD6Init,
                dim12958JoeKuoD6Init,
                dim12959JoeKuoD6Init,
                dim12960JoeKuoD6Init,
                dim12961JoeKuoD6Init,
                dim12962JoeKuoD6Init,
                dim12963JoeKuoD6Init,
                dim12964JoeKuoD6Init,
                dim12965JoeKuoD6Init,
                dim12966JoeKuoD6Init,
                dim12967JoeKuoD6Init,
                dim12968JoeKuoD6Init,
                dim12969JoeKuoD6Init,
                dim12970JoeKuoD6Init,
                dim12971JoeKuoD6Init,
                dim12972JoeKuoD6Init,
                dim12973JoeKuoD6Init,
                dim12974JoeKuoD6Init,
                dim12975JoeKuoD6Init,
                dim12976JoeKuoD6Init,
                dim12977JoeKuoD6Init,
                dim12978JoeKuoD6Init,
                dim12979JoeKuoD6Init,
                dim12980JoeKuoD6Init,
                dim12981JoeKuoD6Init,
                dim12982JoeKuoD6Init,
                dim12983JoeKuoD6Init,
                dim12984JoeKuoD6Init,
                dim12985JoeKuoD6Init,
                dim12986JoeKuoD6Init,
                dim12987JoeKuoD6Init,
                dim12988JoeKuoD6Init,
                dim12989JoeKuoD6Init,
                dim12990JoeKuoD6Init,
                dim12991JoeKuoD6Init,
                dim12992JoeKuoD6Init,
                dim12993JoeKuoD6Init,
                dim12994JoeKuoD6Init,
                dim12995JoeKuoD6Init,
                dim12996JoeKuoD6Init,
                dim12997JoeKuoD6Init,
                dim12998JoeKuoD6Init,
                dim12999JoeKuoD6Init,
                dim13000JoeKuoD6Init,
                dim13001JoeKuoD6Init,
                dim13002JoeKuoD6Init,
                dim13003JoeKuoD6Init,
                dim13004JoeKuoD6Init,
                dim13005JoeKuoD6Init,
                dim13006JoeKuoD6Init,
                dim13007JoeKuoD6Init,
                dim13008JoeKuoD6Init,
                dim13009JoeKuoD6Init,
                dim13010JoeKuoD6Init,
                dim13011JoeKuoD6Init,
                dim13012JoeKuoD6Init,
                dim13013JoeKuoD6Init,
                dim13014JoeKuoD6Init,
                dim13015JoeKuoD6Init,
                dim13016JoeKuoD6Init,
                dim13017JoeKuoD6Init,
                dim13018JoeKuoD6Init,
                dim13019JoeKuoD6Init,
                dim13020JoeKuoD6Init,
                dim13021JoeKuoD6Init,
                dim13022JoeKuoD6Init,
                dim13023JoeKuoD6Init,
                dim13024JoeKuoD6Init,
                dim13025JoeKuoD6Init,
                dim13026JoeKuoD6Init,
                dim13027JoeKuoD6Init,
                dim13028JoeKuoD6Init,
                dim13029JoeKuoD6Init,
                dim13030JoeKuoD6Init,
                dim13031JoeKuoD6Init,
                dim13032JoeKuoD6Init,
                dim13033JoeKuoD6Init,
                dim13034JoeKuoD6Init,
                dim13035JoeKuoD6Init,
                dim13036JoeKuoD6Init,
                dim13037JoeKuoD6Init,
                dim13038JoeKuoD6Init,
                dim13039JoeKuoD6Init,
                dim13040JoeKuoD6Init,
                dim13041JoeKuoD6Init,
                dim13042JoeKuoD6Init,
                dim13043JoeKuoD6Init,
                dim13044JoeKuoD6Init,
                dim13045JoeKuoD6Init,
                dim13046JoeKuoD6Init,
                dim13047JoeKuoD6Init,
                dim13048JoeKuoD6Init,
                dim13049JoeKuoD6Init,
                dim13050JoeKuoD6Init,
                dim13051JoeKuoD6Init,
                dim13052JoeKuoD6Init,
                dim13053JoeKuoD6Init,
                dim13054JoeKuoD6Init,
                dim13055JoeKuoD6Init,
                dim13056JoeKuoD6Init,
                dim13057JoeKuoD6Init,
                dim13058JoeKuoD6Init,
                dim13059JoeKuoD6Init,
                dim13060JoeKuoD6Init,
                dim13061JoeKuoD6Init,
                dim13062JoeKuoD6Init,
                dim13063JoeKuoD6Init,
                dim13064JoeKuoD6Init,
                dim13065JoeKuoD6Init,
                dim13066JoeKuoD6Init,
                dim13067JoeKuoD6Init,
                dim13068JoeKuoD6Init,
                dim13069JoeKuoD6Init,
                dim13070JoeKuoD6Init,
                dim13071JoeKuoD6Init,
                dim13072JoeKuoD6Init,
                dim13073JoeKuoD6Init,
                dim13074JoeKuoD6Init,
                dim13075JoeKuoD6Init,
                dim13076JoeKuoD6Init,
                dim13077JoeKuoD6Init,
                dim13078JoeKuoD6Init,
                dim13079JoeKuoD6Init,
                dim13080JoeKuoD6Init,
                dim13081JoeKuoD6Init,
                dim13082JoeKuoD6Init,
                dim13083JoeKuoD6Init,
                dim13084JoeKuoD6Init,
                dim13085JoeKuoD6Init,
                dim13086JoeKuoD6Init,
                dim13087JoeKuoD6Init,
                dim13088JoeKuoD6Init,
                dim13089JoeKuoD6Init,
                dim13090JoeKuoD6Init,
                dim13091JoeKuoD6Init,
                dim13092JoeKuoD6Init,
                dim13093JoeKuoD6Init,
                dim13094JoeKuoD6Init,
                dim13095JoeKuoD6Init,
                dim13096JoeKuoD6Init,
                dim13097JoeKuoD6Init,
                dim13098JoeKuoD6Init,
                dim13099JoeKuoD6Init,
                dim13100JoeKuoD6Init,
                dim13101JoeKuoD6Init,
                dim13102JoeKuoD6Init,
                dim13103JoeKuoD6Init,
                dim13104JoeKuoD6Init,
                dim13105JoeKuoD6Init,
                dim13106JoeKuoD6Init,
                dim13107JoeKuoD6Init,
                dim13108JoeKuoD6Init,
                dim13109JoeKuoD6Init,
                dim13110JoeKuoD6Init,
                dim13111JoeKuoD6Init,
                dim13112JoeKuoD6Init,
                dim13113JoeKuoD6Init,
                dim13114JoeKuoD6Init,
                dim13115JoeKuoD6Init,
                dim13116JoeKuoD6Init,
                dim13117JoeKuoD6Init,
                dim13118JoeKuoD6Init,
                dim13119JoeKuoD6Init,
                dim13120JoeKuoD6Init,
                dim13121JoeKuoD6Init,
                dim13122JoeKuoD6Init,
                dim13123JoeKuoD6Init,
                dim13124JoeKuoD6Init,
                dim13125JoeKuoD6Init,
                dim13126JoeKuoD6Init,
                dim13127JoeKuoD6Init,
                dim13128JoeKuoD6Init,
                dim13129JoeKuoD6Init,
                dim13130JoeKuoD6Init,
                dim13131JoeKuoD6Init,
                dim13132JoeKuoD6Init,
                dim13133JoeKuoD6Init,
                dim13134JoeKuoD6Init,
                dim13135JoeKuoD6Init,
                dim13136JoeKuoD6Init,
                dim13137JoeKuoD6Init,
                dim13138JoeKuoD6Init,
                dim13139JoeKuoD6Init,
                dim13140JoeKuoD6Init,
                dim13141JoeKuoD6Init,
                dim13142JoeKuoD6Init,
                dim13143JoeKuoD6Init,
                dim13144JoeKuoD6Init,
                dim13145JoeKuoD6Init,
                dim13146JoeKuoD6Init,
                dim13147JoeKuoD6Init,
                dim13148JoeKuoD6Init,
                dim13149JoeKuoD6Init,
                dim13150JoeKuoD6Init,
                dim13151JoeKuoD6Init,
                dim13152JoeKuoD6Init,
                dim13153JoeKuoD6Init,
                dim13154JoeKuoD6Init,
                dim13155JoeKuoD6Init,
                dim13156JoeKuoD6Init,
                dim13157JoeKuoD6Init,
                dim13158JoeKuoD6Init,
                dim13159JoeKuoD6Init,
                dim13160JoeKuoD6Init,
                dim13161JoeKuoD6Init,
                dim13162JoeKuoD6Init,
                dim13163JoeKuoD6Init,
                dim13164JoeKuoD6Init,
                dim13165JoeKuoD6Init,
                dim13166JoeKuoD6Init,
                dim13167JoeKuoD6Init,
                dim13168JoeKuoD6Init,
                dim13169JoeKuoD6Init,
                dim13170JoeKuoD6Init,
                dim13171JoeKuoD6Init,
                dim13172JoeKuoD6Init,
                dim13173JoeKuoD6Init,
                dim13174JoeKuoD6Init,
                dim13175JoeKuoD6Init,
                dim13176JoeKuoD6Init,
                dim13177JoeKuoD6Init,
                dim13178JoeKuoD6Init,
                dim13179JoeKuoD6Init,
                dim13180JoeKuoD6Init,
                dim13181JoeKuoD6Init,
                dim13182JoeKuoD6Init,
                dim13183JoeKuoD6Init,
                dim13184JoeKuoD6Init,
                dim13185JoeKuoD6Init,
                dim13186JoeKuoD6Init,
                dim13187JoeKuoD6Init,
                dim13188JoeKuoD6Init,
                dim13189JoeKuoD6Init,
                dim13190JoeKuoD6Init,
                dim13191JoeKuoD6Init,
                dim13192JoeKuoD6Init,
                dim13193JoeKuoD6Init,
                dim13194JoeKuoD6Init,
                dim13195JoeKuoD6Init,
                dim13196JoeKuoD6Init,
                dim13197JoeKuoD6Init,
                dim13198JoeKuoD6Init,
                dim13199JoeKuoD6Init,
                dim13200JoeKuoD6Init,
                dim13201JoeKuoD6Init,
                dim13202JoeKuoD6Init,
                dim13203JoeKuoD6Init,
                dim13204JoeKuoD6Init,
                dim13205JoeKuoD6Init,
                dim13206JoeKuoD6Init,
                dim13207JoeKuoD6Init,
                dim13208JoeKuoD6Init,
                dim13209JoeKuoD6Init,
                dim13210JoeKuoD6Init,
                dim13211JoeKuoD6Init,
                dim13212JoeKuoD6Init,
                dim13213JoeKuoD6Init,
                dim13214JoeKuoD6Init,
                dim13215JoeKuoD6Init,
                dim13216JoeKuoD6Init,
                dim13217JoeKuoD6Init,
                dim13218JoeKuoD6Init,
                dim13219JoeKuoD6Init,
                dim13220JoeKuoD6Init,
                dim13221JoeKuoD6Init,
                dim13222JoeKuoD6Init,
                dim13223JoeKuoD6Init,
                dim13224JoeKuoD6Init,
                dim13225JoeKuoD6Init,
                dim13226JoeKuoD6Init,
                dim13227JoeKuoD6Init,
                dim13228JoeKuoD6Init,
                dim13229JoeKuoD6Init,
                dim13230JoeKuoD6Init,
                dim13231JoeKuoD6Init,
                dim13232JoeKuoD6Init,
                dim13233JoeKuoD6Init,
                dim13234JoeKuoD6Init,
                dim13235JoeKuoD6Init,
                dim13236JoeKuoD6Init,
                dim13237JoeKuoD6Init,
                dim13238JoeKuoD6Init,
                dim13239JoeKuoD6Init,
                dim13240JoeKuoD6Init,
                dim13241JoeKuoD6Init,
                dim13242JoeKuoD6Init,
                dim13243JoeKuoD6Init,
                dim13244JoeKuoD6Init,
                dim13245JoeKuoD6Init,
                dim13246JoeKuoD6Init,
                dim13247JoeKuoD6Init,
                dim13248JoeKuoD6Init,
                dim13249JoeKuoD6Init,
                dim13250JoeKuoD6Init,
                dim13251JoeKuoD6Init,
                dim13252JoeKuoD6Init,
                dim13253JoeKuoD6Init,
                dim13254JoeKuoD6Init,
                dim13255JoeKuoD6Init,
                dim13256JoeKuoD6Init,
                dim13257JoeKuoD6Init,
                dim13258JoeKuoD6Init,
                dim13259JoeKuoD6Init,
                dim13260JoeKuoD6Init,
                dim13261JoeKuoD6Init,
                dim13262JoeKuoD6Init,
                dim13263JoeKuoD6Init,
                dim13264JoeKuoD6Init,
                dim13265JoeKuoD6Init,
                dim13266JoeKuoD6Init,
                dim13267JoeKuoD6Init,
                dim13268JoeKuoD6Init,
                dim13269JoeKuoD6Init,
                dim13270JoeKuoD6Init,
                dim13271JoeKuoD6Init,
                dim13272JoeKuoD6Init,
                dim13273JoeKuoD6Init,
                dim13274JoeKuoD6Init,
                dim13275JoeKuoD6Init,
                dim13276JoeKuoD6Init,
                dim13277JoeKuoD6Init,
                dim13278JoeKuoD6Init,
                dim13279JoeKuoD6Init,
                dim13280JoeKuoD6Init,
                dim13281JoeKuoD6Init,
                dim13282JoeKuoD6Init,
                dim13283JoeKuoD6Init,
                dim13284JoeKuoD6Init,
                dim13285JoeKuoD6Init,
                dim13286JoeKuoD6Init,
                dim13287JoeKuoD6Init,
                dim13288JoeKuoD6Init,
                dim13289JoeKuoD6Init,
                dim13290JoeKuoD6Init,
                dim13291JoeKuoD6Init,
                dim13292JoeKuoD6Init,
                dim13293JoeKuoD6Init,
                dim13294JoeKuoD6Init,
                dim13295JoeKuoD6Init,
                dim13296JoeKuoD6Init,
                dim13297JoeKuoD6Init,
                dim13298JoeKuoD6Init,
                dim13299JoeKuoD6Init,
                dim13300JoeKuoD6Init,
                dim13301JoeKuoD6Init,
                dim13302JoeKuoD6Init,
                dim13303JoeKuoD6Init,
                dim13304JoeKuoD6Init,
                dim13305JoeKuoD6Init,
                dim13306JoeKuoD6Init,
                dim13307JoeKuoD6Init,
                dim13308JoeKuoD6Init,
                dim13309JoeKuoD6Init,
                dim13310JoeKuoD6Init,
                dim13311JoeKuoD6Init,
                dim13312JoeKuoD6Init,
                dim13313JoeKuoD6Init,
                dim13314JoeKuoD6Init,
                dim13315JoeKuoD6Init,
                dim13316JoeKuoD6Init,
                dim13317JoeKuoD6Init,
                dim13318JoeKuoD6Init,
                dim13319JoeKuoD6Init,
                dim13320JoeKuoD6Init,
                dim13321JoeKuoD6Init,
                dim13322JoeKuoD6Init,
                dim13323JoeKuoD6Init,
                dim13324JoeKuoD6Init,
                dim13325JoeKuoD6Init,
                dim13326JoeKuoD6Init,
                dim13327JoeKuoD6Init,
                dim13328JoeKuoD6Init,
                dim13329JoeKuoD6Init,
                dim13330JoeKuoD6Init,
                dim13331JoeKuoD6Init,
                dim13332JoeKuoD6Init,
                dim13333JoeKuoD6Init,
                dim13334JoeKuoD6Init,
                dim13335JoeKuoD6Init,
                dim13336JoeKuoD6Init,
                dim13337JoeKuoD6Init,
                dim13338JoeKuoD6Init,
                dim13339JoeKuoD6Init,
                dim13340JoeKuoD6Init,
                dim13341JoeKuoD6Init,
                dim13342JoeKuoD6Init,
                dim13343JoeKuoD6Init,
                dim13344JoeKuoD6Init,
                dim13345JoeKuoD6Init,
                dim13346JoeKuoD6Init,
                dim13347JoeKuoD6Init,
                dim13348JoeKuoD6Init,
                dim13349JoeKuoD6Init,
                dim13350JoeKuoD6Init,
                dim13351JoeKuoD6Init,
                dim13352JoeKuoD6Init,
                dim13353JoeKuoD6Init,
                dim13354JoeKuoD6Init,
                dim13355JoeKuoD6Init,
                dim13356JoeKuoD6Init,
                dim13357JoeKuoD6Init,
                dim13358JoeKuoD6Init,
                dim13359JoeKuoD6Init,
                dim13360JoeKuoD6Init,
                dim13361JoeKuoD6Init,
                dim13362JoeKuoD6Init,
                dim13363JoeKuoD6Init,
                dim13364JoeKuoD6Init,
                dim13365JoeKuoD6Init,
                dim13366JoeKuoD6Init,
                dim13367JoeKuoD6Init,
                dim13368JoeKuoD6Init,
                dim13369JoeKuoD6Init,
                dim13370JoeKuoD6Init,
                dim13371JoeKuoD6Init,
                dim13372JoeKuoD6Init,
                dim13373JoeKuoD6Init,
                dim13374JoeKuoD6Init,
                dim13375JoeKuoD6Init,
                dim13376JoeKuoD6Init,
                dim13377JoeKuoD6Init,
                dim13378JoeKuoD6Init,
                dim13379JoeKuoD6Init,
                dim13380JoeKuoD6Init,
                dim13381JoeKuoD6Init,
                dim13382JoeKuoD6Init,
                dim13383JoeKuoD6Init,
                dim13384JoeKuoD6Init,
                dim13385JoeKuoD6Init,
                dim13386JoeKuoD6Init,
                dim13387JoeKuoD6Init,
                dim13388JoeKuoD6Init,
                dim13389JoeKuoD6Init,
                dim13390JoeKuoD6Init,
                dim13391JoeKuoD6Init,
                dim13392JoeKuoD6Init,
                dim13393JoeKuoD6Init,
                dim13394JoeKuoD6Init,
                dim13395JoeKuoD6Init,
                dim13396JoeKuoD6Init,
                dim13397JoeKuoD6Init,
                dim13398JoeKuoD6Init,
                dim13399JoeKuoD6Init,
                dim13400JoeKuoD6Init,
                dim13401JoeKuoD6Init,
                dim13402JoeKuoD6Init,
                dim13403JoeKuoD6Init,
                dim13404JoeKuoD6Init,
                dim13405JoeKuoD6Init,
                dim13406JoeKuoD6Init,
                dim13407JoeKuoD6Init,
                dim13408JoeKuoD6Init,
                dim13409JoeKuoD6Init,
                dim13410JoeKuoD6Init,
                dim13411JoeKuoD6Init,
                dim13412JoeKuoD6Init,
                dim13413JoeKuoD6Init,
                dim13414JoeKuoD6Init,
                dim13415JoeKuoD6Init,
                dim13416JoeKuoD6Init,
                dim13417JoeKuoD6Init,
                dim13418JoeKuoD6Init,
                dim13419JoeKuoD6Init,
                dim13420JoeKuoD6Init,
                dim13421JoeKuoD6Init,
                dim13422JoeKuoD6Init,
                dim13423JoeKuoD6Init,
                dim13424JoeKuoD6Init,
                dim13425JoeKuoD6Init,
                dim13426JoeKuoD6Init,
                dim13427JoeKuoD6Init,
                dim13428JoeKuoD6Init,
                dim13429JoeKuoD6Init,
                dim13430JoeKuoD6Init,
                dim13431JoeKuoD6Init,
                dim13432JoeKuoD6Init,
                dim13433JoeKuoD6Init,
                dim13434JoeKuoD6Init,
                dim13435JoeKuoD6Init,
                dim13436JoeKuoD6Init,
                dim13437JoeKuoD6Init,
                dim13438JoeKuoD6Init,
                dim13439JoeKuoD6Init,
                dim13440JoeKuoD6Init,
                dim13441JoeKuoD6Init,
                dim13442JoeKuoD6Init,
                dim13443JoeKuoD6Init,
                dim13444JoeKuoD6Init,
                dim13445JoeKuoD6Init,
                dim13446JoeKuoD6Init,
                dim13447JoeKuoD6Init,
                dim13448JoeKuoD6Init,
                dim13449JoeKuoD6Init,
                dim13450JoeKuoD6Init,
                dim13451JoeKuoD6Init,
                dim13452JoeKuoD6Init,
                dim13453JoeKuoD6Init,
                dim13454JoeKuoD6Init,
                dim13455JoeKuoD6Init,
                dim13456JoeKuoD6Init,
                dim13457JoeKuoD6Init,
                dim13458JoeKuoD6Init,
                dim13459JoeKuoD6Init,
                dim13460JoeKuoD6Init,
                dim13461JoeKuoD6Init,
                dim13462JoeKuoD6Init,
                dim13463JoeKuoD6Init,
                dim13464JoeKuoD6Init,
                dim13465JoeKuoD6Init,
                dim13466JoeKuoD6Init,
                dim13467JoeKuoD6Init,
                dim13468JoeKuoD6Init,
                dim13469JoeKuoD6Init,
                dim13470JoeKuoD6Init,
                dim13471JoeKuoD6Init,
                dim13472JoeKuoD6Init,
                dim13473JoeKuoD6Init,
                dim13474JoeKuoD6Init,
                dim13475JoeKuoD6Init,
                dim13476JoeKuoD6Init,
                dim13477JoeKuoD6Init,
                dim13478JoeKuoD6Init,
                dim13479JoeKuoD6Init,
                dim13480JoeKuoD6Init,
                dim13481JoeKuoD6Init,
                dim13482JoeKuoD6Init,
                dim13483JoeKuoD6Init,
                dim13484JoeKuoD6Init,
                dim13485JoeKuoD6Init,
                dim13486JoeKuoD6Init,
                dim13487JoeKuoD6Init,
                dim13488JoeKuoD6Init,
                dim13489JoeKuoD6Init,
                dim13490JoeKuoD6Init,
                dim13491JoeKuoD6Init,
                dim13492JoeKuoD6Init,
                dim13493JoeKuoD6Init,
                dim13494JoeKuoD6Init,
                dim13495JoeKuoD6Init,
                dim13496JoeKuoD6Init,
                dim13497JoeKuoD6Init,
                dim13498JoeKuoD6Init,
                dim13499JoeKuoD6Init,
                dim13500JoeKuoD6Init,
                dim13501JoeKuoD6Init,
                dim13502JoeKuoD6Init,
                dim13503JoeKuoD6Init,
                dim13504JoeKuoD6Init,
                dim13505JoeKuoD6Init,
                dim13506JoeKuoD6Init,
                dim13507JoeKuoD6Init,
                dim13508JoeKuoD6Init,
                dim13509JoeKuoD6Init,
                dim13510JoeKuoD6Init,
                dim13511JoeKuoD6Init,
                dim13512JoeKuoD6Init,
                dim13513JoeKuoD6Init,
                dim13514JoeKuoD6Init,
                dim13515JoeKuoD6Init,
                dim13516JoeKuoD6Init,
                dim13517JoeKuoD6Init,
                dim13518JoeKuoD6Init,
                dim13519JoeKuoD6Init,
                dim13520JoeKuoD6Init,
                dim13521JoeKuoD6Init,
                dim13522JoeKuoD6Init,
                dim13523JoeKuoD6Init,
                dim13524JoeKuoD6Init,
                dim13525JoeKuoD6Init,
                dim13526JoeKuoD6Init,
                dim13527JoeKuoD6Init,
                dim13528JoeKuoD6Init,
                dim13529JoeKuoD6Init,
                dim13530JoeKuoD6Init,
                dim13531JoeKuoD6Init,
                dim13532JoeKuoD6Init,
                dim13533JoeKuoD6Init,
                dim13534JoeKuoD6Init,
                dim13535JoeKuoD6Init,
                dim13536JoeKuoD6Init,
                dim13537JoeKuoD6Init,
                dim13538JoeKuoD6Init,
                dim13539JoeKuoD6Init,
                dim13540JoeKuoD6Init,
                dim13541JoeKuoD6Init,
                dim13542JoeKuoD6Init,
                dim13543JoeKuoD6Init,
                dim13544JoeKuoD6Init,
                dim13545JoeKuoD6Init,
                dim13546JoeKuoD6Init,
                dim13547JoeKuoD6Init,
                dim13548JoeKuoD6Init,
                dim13549JoeKuoD6Init,
                dim13550JoeKuoD6Init,
                dim13551JoeKuoD6Init,
                dim13552JoeKuoD6Init,
                dim13553JoeKuoD6Init,
                dim13554JoeKuoD6Init,
                dim13555JoeKuoD6Init,
                dim13556JoeKuoD6Init,
                dim13557JoeKuoD6Init,
                dim13558JoeKuoD6Init,
                dim13559JoeKuoD6Init,
                dim13560JoeKuoD6Init,
                dim13561JoeKuoD6Init,
                dim13562JoeKuoD6Init,
                dim13563JoeKuoD6Init,
                dim13564JoeKuoD6Init,
                dim13565JoeKuoD6Init,
                dim13566JoeKuoD6Init,
                dim13567JoeKuoD6Init,
                dim13568JoeKuoD6Init,
                dim13569JoeKuoD6Init,
                dim13570JoeKuoD6Init,
                dim13571JoeKuoD6Init,
                dim13572JoeKuoD6Init,
                dim13573JoeKuoD6Init,
                dim13574JoeKuoD6Init,
                dim13575JoeKuoD6Init,
                dim13576JoeKuoD6Init,
                dim13577JoeKuoD6Init,
                dim13578JoeKuoD6Init,
                dim13579JoeKuoD6Init,
                dim13580JoeKuoD6Init,
                dim13581JoeKuoD6Init,
                dim13582JoeKuoD6Init,
                dim13583JoeKuoD6Init,
                dim13584JoeKuoD6Init,
                dim13585JoeKuoD6Init,
                dim13586JoeKuoD6Init,
                dim13587JoeKuoD6Init,
                dim13588JoeKuoD6Init,
                dim13589JoeKuoD6Init,
                dim13590JoeKuoD6Init,
                dim13591JoeKuoD6Init,
                dim13592JoeKuoD6Init,
                dim13593JoeKuoD6Init,
                dim13594JoeKuoD6Init,
                dim13595JoeKuoD6Init,
                dim13596JoeKuoD6Init,
                dim13597JoeKuoD6Init,
                dim13598JoeKuoD6Init,
                dim13599JoeKuoD6Init,
                dim13600JoeKuoD6Init,
                dim13601JoeKuoD6Init,
                dim13602JoeKuoD6Init,
                dim13603JoeKuoD6Init,
                dim13604JoeKuoD6Init,
                dim13605JoeKuoD6Init,
                dim13606JoeKuoD6Init,
                dim13607JoeKuoD6Init,
                dim13608JoeKuoD6Init,
                dim13609JoeKuoD6Init,
                dim13610JoeKuoD6Init,
                dim13611JoeKuoD6Init,
                dim13612JoeKuoD6Init,
                dim13613JoeKuoD6Init,
                dim13614JoeKuoD6Init,
                dim13615JoeKuoD6Init,
                dim13616JoeKuoD6Init,
                dim13617JoeKuoD6Init,
                dim13618JoeKuoD6Init,
                dim13619JoeKuoD6Init,
                dim13620JoeKuoD6Init,
                dim13621JoeKuoD6Init,
                dim13622JoeKuoD6Init,
                dim13623JoeKuoD6Init,
                dim13624JoeKuoD6Init,
                dim13625JoeKuoD6Init,
                dim13626JoeKuoD6Init,
                dim13627JoeKuoD6Init,
                dim13628JoeKuoD6Init,
                dim13629JoeKuoD6Init,
                dim13630JoeKuoD6Init,
                dim13631JoeKuoD6Init,
                dim13632JoeKuoD6Init,
                dim13633JoeKuoD6Init,
                dim13634JoeKuoD6Init,
                dim13635JoeKuoD6Init,
                dim13636JoeKuoD6Init,
                dim13637JoeKuoD6Init,
                dim13638JoeKuoD6Init,
                dim13639JoeKuoD6Init,
                dim13640JoeKuoD6Init,
                dim13641JoeKuoD6Init,
                dim13642JoeKuoD6Init,
                dim13643JoeKuoD6Init,
                dim13644JoeKuoD6Init,
                dim13645JoeKuoD6Init,
                dim13646JoeKuoD6Init,
                dim13647JoeKuoD6Init,
                dim13648JoeKuoD6Init,
                dim13649JoeKuoD6Init,
                dim13650JoeKuoD6Init,
                dim13651JoeKuoD6Init,
                dim13652JoeKuoD6Init,
                dim13653JoeKuoD6Init,
                dim13654JoeKuoD6Init,
                dim13655JoeKuoD6Init,
                dim13656JoeKuoD6Init,
                dim13657JoeKuoD6Init,
                dim13658JoeKuoD6Init,
                dim13659JoeKuoD6Init,
                dim13660JoeKuoD6Init,
                dim13661JoeKuoD6Init,
                dim13662JoeKuoD6Init,
                dim13663JoeKuoD6Init,
                dim13664JoeKuoD6Init,
                dim13665JoeKuoD6Init,
                dim13666JoeKuoD6Init,
                dim13667JoeKuoD6Init,
                dim13668JoeKuoD6Init,
                dim13669JoeKuoD6Init,
                dim13670JoeKuoD6Init,
                dim13671JoeKuoD6Init,
                dim13672JoeKuoD6Init,
                dim13673JoeKuoD6Init,
                dim13674JoeKuoD6Init,
                dim13675JoeKuoD6Init,
                dim13676JoeKuoD6Init,
                dim13677JoeKuoD6Init,
                dim13678JoeKuoD6Init,
                dim13679JoeKuoD6Init,
                dim13680JoeKuoD6Init,
                dim13681JoeKuoD6Init,
                dim13682JoeKuoD6Init,
                dim13683JoeKuoD6Init,
                dim13684JoeKuoD6Init,
                dim13685JoeKuoD6Init,
                dim13686JoeKuoD6Init,
                dim13687JoeKuoD6Init,
                dim13688JoeKuoD6Init,
                dim13689JoeKuoD6Init,
                dim13690JoeKuoD6Init,
                dim13691JoeKuoD6Init,
                dim13692JoeKuoD6Init,
                dim13693JoeKuoD6Init,
                dim13694JoeKuoD6Init,
                dim13695JoeKuoD6Init,
                dim13696JoeKuoD6Init,
                dim13697JoeKuoD6Init,
                dim13698JoeKuoD6Init,
                dim13699JoeKuoD6Init,
                dim13700JoeKuoD6Init,
                dim13701JoeKuoD6Init,
                dim13702JoeKuoD6Init,
                dim13703JoeKuoD6Init,
                dim13704JoeKuoD6Init,
                dim13705JoeKuoD6Init,
                dim13706JoeKuoD6Init,
                dim13707JoeKuoD6Init,
                dim13708JoeKuoD6Init,
                dim13709JoeKuoD6Init,
                dim13710JoeKuoD6Init,
                dim13711JoeKuoD6Init,
                dim13712JoeKuoD6Init,
                dim13713JoeKuoD6Init,
                dim13714JoeKuoD6Init,
                dim13715JoeKuoD6Init,
                dim13716JoeKuoD6Init,
                dim13717JoeKuoD6Init,
                dim13718JoeKuoD6Init,
                dim13719JoeKuoD6Init,
                dim13720JoeKuoD6Init,
                dim13721JoeKuoD6Init,
                dim13722JoeKuoD6Init,
                dim13723JoeKuoD6Init,
                dim13724JoeKuoD6Init,
                dim13725JoeKuoD6Init,
                dim13726JoeKuoD6Init,
                dim13727JoeKuoD6Init,
                dim13728JoeKuoD6Init,
                dim13729JoeKuoD6Init,
                dim13730JoeKuoD6Init,
                dim13731JoeKuoD6Init,
                dim13732JoeKuoD6Init,
                dim13733JoeKuoD6Init,
                dim13734JoeKuoD6Init,
                dim13735JoeKuoD6Init,
                dim13736JoeKuoD6Init,
                dim13737JoeKuoD6Init,
                dim13738JoeKuoD6Init,
                dim13739JoeKuoD6Init,
                dim13740JoeKuoD6Init,
                dim13741JoeKuoD6Init,
                dim13742JoeKuoD6Init,
                dim13743JoeKuoD6Init,
                dim13744JoeKuoD6Init,
                dim13745JoeKuoD6Init,
                dim13746JoeKuoD6Init,
                dim13747JoeKuoD6Init,
                dim13748JoeKuoD6Init,
                dim13749JoeKuoD6Init,
                dim13750JoeKuoD6Init,
                dim13751JoeKuoD6Init,
                dim13752JoeKuoD6Init,
                dim13753JoeKuoD6Init,
                dim13754JoeKuoD6Init,
                dim13755JoeKuoD6Init,
                dim13756JoeKuoD6Init,
                dim13757JoeKuoD6Init,
                dim13758JoeKuoD6Init,
                dim13759JoeKuoD6Init,
                dim13760JoeKuoD6Init,
                dim13761JoeKuoD6Init,
                dim13762JoeKuoD6Init,
                dim13763JoeKuoD6Init,
                dim13764JoeKuoD6Init,
                dim13765JoeKuoD6Init,
                dim13766JoeKuoD6Init,
                dim13767JoeKuoD6Init,
                dim13768JoeKuoD6Init,
                dim13769JoeKuoD6Init,
                dim13770JoeKuoD6Init,
                dim13771JoeKuoD6Init,
                dim13772JoeKuoD6Init,
                dim13773JoeKuoD6Init,
                dim13774JoeKuoD6Init,
                dim13775JoeKuoD6Init,
                dim13776JoeKuoD6Init,
                dim13777JoeKuoD6Init,
                dim13778JoeKuoD6Init,
                dim13779JoeKuoD6Init,
                dim13780JoeKuoD6Init,
                dim13781JoeKuoD6Init,
                dim13782JoeKuoD6Init,
                dim13783JoeKuoD6Init,
                dim13784JoeKuoD6Init,
                dim13785JoeKuoD6Init,
                dim13786JoeKuoD6Init,
                dim13787JoeKuoD6Init,
                dim13788JoeKuoD6Init,
                dim13789JoeKuoD6Init,
                dim13790JoeKuoD6Init,
                dim13791JoeKuoD6Init,
                dim13792JoeKuoD6Init,
                dim13793JoeKuoD6Init,
                dim13794JoeKuoD6Init,
                dim13795JoeKuoD6Init,
                dim13796JoeKuoD6Init,
                dim13797JoeKuoD6Init,
                dim13798JoeKuoD6Init,
                dim13799JoeKuoD6Init,
                dim13800JoeKuoD6Init,
                dim13801JoeKuoD6Init,
                dim13802JoeKuoD6Init,
                dim13803JoeKuoD6Init,
                dim13804JoeKuoD6Init,
                dim13805JoeKuoD6Init,
                dim13806JoeKuoD6Init,
                dim13807JoeKuoD6Init,
                dim13808JoeKuoD6Init,
                dim13809JoeKuoD6Init,
                dim13810JoeKuoD6Init,
                dim13811JoeKuoD6Init,
                dim13812JoeKuoD6Init,
                dim13813JoeKuoD6Init,
                dim13814JoeKuoD6Init,
                dim13815JoeKuoD6Init,
                dim13816JoeKuoD6Init,
                dim13817JoeKuoD6Init,
                dim13818JoeKuoD6Init,
                dim13819JoeKuoD6Init,
                dim13820JoeKuoD6Init,
                dim13821JoeKuoD6Init,
                dim13822JoeKuoD6Init,
                dim13823JoeKuoD6Init,
                dim13824JoeKuoD6Init,
                dim13825JoeKuoD6Init,
                dim13826JoeKuoD6Init,
                dim13827JoeKuoD6Init,
                dim13828JoeKuoD6Init,
                dim13829JoeKuoD6Init,
                dim13830JoeKuoD6Init,
                dim13831JoeKuoD6Init,
                dim13832JoeKuoD6Init,
                dim13833JoeKuoD6Init,
                dim13834JoeKuoD6Init,
                dim13835JoeKuoD6Init,
                dim13836JoeKuoD6Init,
                dim13837JoeKuoD6Init,
                dim13838JoeKuoD6Init,
                dim13839JoeKuoD6Init,
                dim13840JoeKuoD6Init,
                dim13841JoeKuoD6Init,
                dim13842JoeKuoD6Init,
                dim13843JoeKuoD6Init,
                dim13844JoeKuoD6Init,
                dim13845JoeKuoD6Init,
                dim13846JoeKuoD6Init,
                dim13847JoeKuoD6Init,
                dim13848JoeKuoD6Init,
                dim13849JoeKuoD6Init,
                dim13850JoeKuoD6Init,
                dim13851JoeKuoD6Init,
                dim13852JoeKuoD6Init,
                dim13853JoeKuoD6Init,
                dim13854JoeKuoD6Init,
                dim13855JoeKuoD6Init,
                dim13856JoeKuoD6Init,
                dim13857JoeKuoD6Init,
                dim13858JoeKuoD6Init,
                dim13859JoeKuoD6Init,
                dim13860JoeKuoD6Init,
                dim13861JoeKuoD6Init,
                dim13862JoeKuoD6Init,
                dim13863JoeKuoD6Init,
                dim13864JoeKuoD6Init,
                dim13865JoeKuoD6Init,
                dim13866JoeKuoD6Init,
                dim13867JoeKuoD6Init,
                dim13868JoeKuoD6Init,
                dim13869JoeKuoD6Init,
                dim13870JoeKuoD6Init,
                dim13871JoeKuoD6Init,
                dim13872JoeKuoD6Init,
                dim13873JoeKuoD6Init,
                dim13874JoeKuoD6Init,
                dim13875JoeKuoD6Init,
                dim13876JoeKuoD6Init,
                dim13877JoeKuoD6Init,
                dim13878JoeKuoD6Init,
                dim13879JoeKuoD6Init,
                dim13880JoeKuoD6Init,
                dim13881JoeKuoD6Init,
                dim13882JoeKuoD6Init,
                dim13883JoeKuoD6Init,
                dim13884JoeKuoD6Init,
                dim13885JoeKuoD6Init,
                dim13886JoeKuoD6Init,
                dim13887JoeKuoD6Init,
                dim13888JoeKuoD6Init,
                dim13889JoeKuoD6Init,
                dim13890JoeKuoD6Init,
                dim13891JoeKuoD6Init,
                dim13892JoeKuoD6Init,
                dim13893JoeKuoD6Init,
                dim13894JoeKuoD6Init,
                dim13895JoeKuoD6Init,
                dim13896JoeKuoD6Init,
                dim13897JoeKuoD6Init,
                dim13898JoeKuoD6Init,
                dim13899JoeKuoD6Init,
                dim13900JoeKuoD6Init,
                dim13901JoeKuoD6Init,
                dim13902JoeKuoD6Init,
                dim13903JoeKuoD6Init,
                dim13904JoeKuoD6Init,
                dim13905JoeKuoD6Init,
                dim13906JoeKuoD6Init,
                dim13907JoeKuoD6Init,
                dim13908JoeKuoD6Init,
                dim13909JoeKuoD6Init,
                dim13910JoeKuoD6Init,
                dim13911JoeKuoD6Init,
                dim13912JoeKuoD6Init,
                dim13913JoeKuoD6Init,
                dim13914JoeKuoD6Init,
                dim13915JoeKuoD6Init,
                dim13916JoeKuoD6Init,
                dim13917JoeKuoD6Init,
                dim13918JoeKuoD6Init,
                dim13919JoeKuoD6Init,
                dim13920JoeKuoD6Init,
                dim13921JoeKuoD6Init,
                dim13922JoeKuoD6Init,
                dim13923JoeKuoD6Init,
                dim13924JoeKuoD6Init,
                dim13925JoeKuoD6Init,
                dim13926JoeKuoD6Init,
                dim13927JoeKuoD6Init,
                dim13928JoeKuoD6Init,
                dim13929JoeKuoD6Init,
                dim13930JoeKuoD6Init,
                dim13931JoeKuoD6Init,
                dim13932JoeKuoD6Init,
                dim13933JoeKuoD6Init,
                dim13934JoeKuoD6Init,
                dim13935JoeKuoD6Init,
                dim13936JoeKuoD6Init,
                dim13937JoeKuoD6Init,
                dim13938JoeKuoD6Init,
                dim13939JoeKuoD6Init,
                dim13940JoeKuoD6Init,
                dim13941JoeKuoD6Init,
                dim13942JoeKuoD6Init,
                dim13943JoeKuoD6Init,
                dim13944JoeKuoD6Init,
                dim13945JoeKuoD6Init,
                dim13946JoeKuoD6Init,
                dim13947JoeKuoD6Init,
                dim13948JoeKuoD6Init,
                dim13949JoeKuoD6Init,
                dim13950JoeKuoD6Init,
                dim13951JoeKuoD6Init,
                dim13952JoeKuoD6Init,
                dim13953JoeKuoD6Init,
                dim13954JoeKuoD6Init,
                dim13955JoeKuoD6Init,
                dim13956JoeKuoD6Init,
                dim13957JoeKuoD6Init,
                dim13958JoeKuoD6Init,
                dim13959JoeKuoD6Init,
                dim13960JoeKuoD6Init,
                dim13961JoeKuoD6Init,
                dim13962JoeKuoD6Init,
                dim13963JoeKuoD6Init,
                dim13964JoeKuoD6Init,
                dim13965JoeKuoD6Init,
                dim13966JoeKuoD6Init,
                dim13967JoeKuoD6Init,
                dim13968JoeKuoD6Init,
                dim13969JoeKuoD6Init,
                dim13970JoeKuoD6Init,
                dim13971JoeKuoD6Init,
                dim13972JoeKuoD6Init,
                dim13973JoeKuoD6Init,
                dim13974JoeKuoD6Init,
                dim13975JoeKuoD6Init,
                dim13976JoeKuoD6Init,
                dim13977JoeKuoD6Init,
                dim13978JoeKuoD6Init,
                dim13979JoeKuoD6Init,
                dim13980JoeKuoD6Init,
                dim13981JoeKuoD6Init,
                dim13982JoeKuoD6Init,
                dim13983JoeKuoD6Init,
                dim13984JoeKuoD6Init,
                dim13985JoeKuoD6Init,
                dim13986JoeKuoD6Init,
                dim13987JoeKuoD6Init,
                dim13988JoeKuoD6Init,
                dim13989JoeKuoD6Init,
                dim13990JoeKuoD6Init,
                dim13991JoeKuoD6Init,
                dim13992JoeKuoD6Init,
                dim13993JoeKuoD6Init,
                dim13994JoeKuoD6Init,
                dim13995JoeKuoD6Init,
                dim13996JoeKuoD6Init,
                dim13997JoeKuoD6Init,
                dim13998JoeKuoD6Init,
                dim13999JoeKuoD6Init,
                dim14000JoeKuoD6Init,
                dim14001JoeKuoD6Init,
                dim14002JoeKuoD6Init,
                dim14003JoeKuoD6Init,
                dim14004JoeKuoD6Init,
                dim14005JoeKuoD6Init,
                dim14006JoeKuoD6Init,
                dim14007JoeKuoD6Init,
                dim14008JoeKuoD6Init,
                dim14009JoeKuoD6Init,
                dim14010JoeKuoD6Init,
                dim14011JoeKuoD6Init,
                dim14012JoeKuoD6Init,
                dim14013JoeKuoD6Init,
                dim14014JoeKuoD6Init,
                dim14015JoeKuoD6Init,
                dim14016JoeKuoD6Init,
                dim14017JoeKuoD6Init,
                dim14018JoeKuoD6Init,
                dim14019JoeKuoD6Init,
                dim14020JoeKuoD6Init,
                dim14021JoeKuoD6Init,
                dim14022JoeKuoD6Init,
                dim14023JoeKuoD6Init,
                dim14024JoeKuoD6Init,
                dim14025JoeKuoD6Init,
                dim14026JoeKuoD6Init,
                dim14027JoeKuoD6Init,
                dim14028JoeKuoD6Init,
                dim14029JoeKuoD6Init,
                dim14030JoeKuoD6Init,
                dim14031JoeKuoD6Init,
                dim14032JoeKuoD6Init,
                dim14033JoeKuoD6Init,
                dim14034JoeKuoD6Init,
                dim14035JoeKuoD6Init,
                dim14036JoeKuoD6Init,
                dim14037JoeKuoD6Init,
                dim14038JoeKuoD6Init,
                dim14039JoeKuoD6Init,
                dim14040JoeKuoD6Init,
                dim14041JoeKuoD6Init,
                dim14042JoeKuoD6Init,
                dim14043JoeKuoD6Init,
                dim14044JoeKuoD6Init,
                dim14045JoeKuoD6Init,
                dim14046JoeKuoD6Init,
                dim14047JoeKuoD6Init,
                dim14048JoeKuoD6Init,
                dim14049JoeKuoD6Init,
                dim14050JoeKuoD6Init,
                dim14051JoeKuoD6Init,
                dim14052JoeKuoD6Init,
                dim14053JoeKuoD6Init,
                dim14054JoeKuoD6Init,
                dim14055JoeKuoD6Init,
                dim14056JoeKuoD6Init,
                dim14057JoeKuoD6Init,
                dim14058JoeKuoD6Init,
                dim14059JoeKuoD6Init,
                dim14060JoeKuoD6Init,
                dim14061JoeKuoD6Init,
                dim14062JoeKuoD6Init,
                dim14063JoeKuoD6Init,
                dim14064JoeKuoD6Init,
                dim14065JoeKuoD6Init,
                dim14066JoeKuoD6Init,
                dim14067JoeKuoD6Init,
                dim14068JoeKuoD6Init,
                dim14069JoeKuoD6Init,
                dim14070JoeKuoD6Init,
                dim14071JoeKuoD6Init,
                dim14072JoeKuoD6Init,
                dim14073JoeKuoD6Init,
                dim14074JoeKuoD6Init,
                dim14075JoeKuoD6Init,
                dim14076JoeKuoD6Init,
                dim14077JoeKuoD6Init,
                dim14078JoeKuoD6Init,
                dim14079JoeKuoD6Init,
                dim14080JoeKuoD6Init,
                dim14081JoeKuoD6Init,
                dim14082JoeKuoD6Init,
                dim14083JoeKuoD6Init,
                dim14084JoeKuoD6Init,
                dim14085JoeKuoD6Init,
                dim14086JoeKuoD6Init,
                dim14087JoeKuoD6Init,
                dim14088JoeKuoD6Init,
                dim14089JoeKuoD6Init,
                dim14090JoeKuoD6Init,
                dim14091JoeKuoD6Init,
                dim14092JoeKuoD6Init,
                dim14093JoeKuoD6Init,
                dim14094JoeKuoD6Init,
                dim14095JoeKuoD6Init,
                dim14096JoeKuoD6Init,
                dim14097JoeKuoD6Init,
                dim14098JoeKuoD6Init,
                dim14099JoeKuoD6Init,
                dim14100JoeKuoD6Init,
                dim14101JoeKuoD6Init,
                dim14102JoeKuoD6Init,
                dim14103JoeKuoD6Init,
                dim14104JoeKuoD6Init,
                dim14105JoeKuoD6Init,
                dim14106JoeKuoD6Init,
                dim14107JoeKuoD6Init,
                dim14108JoeKuoD6Init,
                dim14109JoeKuoD6Init,
                dim14110JoeKuoD6Init,
                dim14111JoeKuoD6Init,
                dim14112JoeKuoD6Init,
                dim14113JoeKuoD6Init,
                dim14114JoeKuoD6Init,
                dim14115JoeKuoD6Init,
                dim14116JoeKuoD6Init,
                dim14117JoeKuoD6Init,
                dim14118JoeKuoD6Init,
                dim14119JoeKuoD6Init,
                dim14120JoeKuoD6Init,
                dim14121JoeKuoD6Init,
                dim14122JoeKuoD6Init,
                dim14123JoeKuoD6Init,
                dim14124JoeKuoD6Init,
                dim14125JoeKuoD6Init,
                dim14126JoeKuoD6Init,
                dim14127JoeKuoD6Init,
                dim14128JoeKuoD6Init,
                dim14129JoeKuoD6Init,
                dim14130JoeKuoD6Init,
                dim14131JoeKuoD6Init,
                dim14132JoeKuoD6Init,
                dim14133JoeKuoD6Init,
                dim14134JoeKuoD6Init,
                dim14135JoeKuoD6Init,
                dim14136JoeKuoD6Init,
                dim14137JoeKuoD6Init,
                dim14138JoeKuoD6Init,
                dim14139JoeKuoD6Init,
                dim14140JoeKuoD6Init,
                dim14141JoeKuoD6Init,
                dim14142JoeKuoD6Init,
                dim14143JoeKuoD6Init,
                dim14144JoeKuoD6Init,
                dim14145JoeKuoD6Init,
                dim14146JoeKuoD6Init,
                dim14147JoeKuoD6Init,
                dim14148JoeKuoD6Init,
                dim14149JoeKuoD6Init,
                dim14150JoeKuoD6Init,
                dim14151JoeKuoD6Init,
                dim14152JoeKuoD6Init,
                dim14153JoeKuoD6Init,
                dim14154JoeKuoD6Init,
                dim14155JoeKuoD6Init,
                dim14156JoeKuoD6Init,
                dim14157JoeKuoD6Init,
                dim14158JoeKuoD6Init,
                dim14159JoeKuoD6Init,
                dim14160JoeKuoD6Init,
                dim14161JoeKuoD6Init,
                dim14162JoeKuoD6Init,
                dim14163JoeKuoD6Init,
                dim14164JoeKuoD6Init,
                dim14165JoeKuoD6Init,
                dim14166JoeKuoD6Init,
                dim14167JoeKuoD6Init,
                dim14168JoeKuoD6Init,
                dim14169JoeKuoD6Init,
                dim14170JoeKuoD6Init,
                dim14171JoeKuoD6Init,
                dim14172JoeKuoD6Init,
                dim14173JoeKuoD6Init,
                dim14174JoeKuoD6Init,
                dim14175JoeKuoD6Init,
                dim14176JoeKuoD6Init,
                dim14177JoeKuoD6Init,
                dim14178JoeKuoD6Init,
                dim14179JoeKuoD6Init,
                dim14180JoeKuoD6Init,
                dim14181JoeKuoD6Init,
                dim14182JoeKuoD6Init,
                dim14183JoeKuoD6Init,
                dim14184JoeKuoD6Init,
                dim14185JoeKuoD6Init,
                dim14186JoeKuoD6Init,
                dim14187JoeKuoD6Init,
                dim14188JoeKuoD6Init,
                dim14189JoeKuoD6Init,
                dim14190JoeKuoD6Init,
                dim14191JoeKuoD6Init,
                dim14192JoeKuoD6Init,
                dim14193JoeKuoD6Init,
                dim14194JoeKuoD6Init,
                dim14195JoeKuoD6Init,
                dim14196JoeKuoD6Init,
                dim14197JoeKuoD6Init,
                dim14198JoeKuoD6Init,
                dim14199JoeKuoD6Init,
                dim14200JoeKuoD6Init,
                dim14201JoeKuoD6Init,
                dim14202JoeKuoD6Init,
                dim14203JoeKuoD6Init,
                dim14204JoeKuoD6Init,
                dim14205JoeKuoD6Init,
                dim14206JoeKuoD6Init,
                dim14207JoeKuoD6Init,
                dim14208JoeKuoD6Init,
                dim14209JoeKuoD6Init,
                dim14210JoeKuoD6Init,
                dim14211JoeKuoD6Init,
                dim14212JoeKuoD6Init,
                dim14213JoeKuoD6Init,
                dim14214JoeKuoD6Init,
                dim14215JoeKuoD6Init,
                dim14216JoeKuoD6Init,
                dim14217JoeKuoD6Init,
                dim14218JoeKuoD6Init,
                dim14219JoeKuoD6Init,
                dim14220JoeKuoD6Init,
                dim14221JoeKuoD6Init,
                dim14222JoeKuoD6Init,
                dim14223JoeKuoD6Init,
                dim14224JoeKuoD6Init,
                dim14225JoeKuoD6Init,
                dim14226JoeKuoD6Init,
                dim14227JoeKuoD6Init,
                dim14228JoeKuoD6Init,
                dim14229JoeKuoD6Init,
                dim14230JoeKuoD6Init,
                dim14231JoeKuoD6Init,
                dim14232JoeKuoD6Init,
                dim14233JoeKuoD6Init,
                dim14234JoeKuoD6Init,
                dim14235JoeKuoD6Init,
                dim14236JoeKuoD6Init,
                dim14237JoeKuoD6Init,
                dim14238JoeKuoD6Init,
                dim14239JoeKuoD6Init,
                dim14240JoeKuoD6Init,
                dim14241JoeKuoD6Init,
                dim14242JoeKuoD6Init,
                dim14243JoeKuoD6Init,
                dim14244JoeKuoD6Init,
                dim14245JoeKuoD6Init,
                dim14246JoeKuoD6Init,
                dim14247JoeKuoD6Init,
                dim14248JoeKuoD6Init,
                dim14249JoeKuoD6Init,
                dim14250JoeKuoD6Init,
                dim14251JoeKuoD6Init,
                dim14252JoeKuoD6Init,
                dim14253JoeKuoD6Init,
                dim14254JoeKuoD6Init,
                dim14255JoeKuoD6Init,
                dim14256JoeKuoD6Init,
                dim14257JoeKuoD6Init,
                dim14258JoeKuoD6Init,
                dim14259JoeKuoD6Init,
                dim14260JoeKuoD6Init,
                dim14261JoeKuoD6Init,
                dim14262JoeKuoD6Init,
                dim14263JoeKuoD6Init,
                dim14264JoeKuoD6Init,
                dim14265JoeKuoD6Init,
                dim14266JoeKuoD6Init,
                dim14267JoeKuoD6Init,
                dim14268JoeKuoD6Init,
                dim14269JoeKuoD6Init,
                dim14270JoeKuoD6Init,
                dim14271JoeKuoD6Init,
                dim14272JoeKuoD6Init,
                dim14273JoeKuoD6Init,
                dim14274JoeKuoD6Init,
                dim14275JoeKuoD6Init,
                dim14276JoeKuoD6Init,
                dim14277JoeKuoD6Init,
                dim14278JoeKuoD6Init,
                dim14279JoeKuoD6Init,
                dim14280JoeKuoD6Init,
                dim14281JoeKuoD6Init,
                dim14282JoeKuoD6Init,
                dim14283JoeKuoD6Init,
                dim14284JoeKuoD6Init,
                dim14285JoeKuoD6Init,
                dim14286JoeKuoD6Init,
                dim14287JoeKuoD6Init,
                dim14288JoeKuoD6Init,
                dim14289JoeKuoD6Init,
                dim14290JoeKuoD6Init,
                dim14291JoeKuoD6Init,
                dim14292JoeKuoD6Init,
                dim14293JoeKuoD6Init,
                dim14294JoeKuoD6Init,
                dim14295JoeKuoD6Init,
                dim14296JoeKuoD6Init,
                dim14297JoeKuoD6Init,
                dim14298JoeKuoD6Init,
                dim14299JoeKuoD6Init,
                dim14300JoeKuoD6Init,
                dim14301JoeKuoD6Init,
                dim14302JoeKuoD6Init,
                dim14303JoeKuoD6Init,
                dim14304JoeKuoD6Init,
                dim14305JoeKuoD6Init,
                dim14306JoeKuoD6Init,
                dim14307JoeKuoD6Init,
                dim14308JoeKuoD6Init,
                dim14309JoeKuoD6Init,
                dim14310JoeKuoD6Init,
                dim14311JoeKuoD6Init,
                dim14312JoeKuoD6Init,
                dim14313JoeKuoD6Init,
                dim14314JoeKuoD6Init,
                dim14315JoeKuoD6Init,
                dim14316JoeKuoD6Init,
                dim14317JoeKuoD6Init,
                dim14318JoeKuoD6Init,
                dim14319JoeKuoD6Init,
                dim14320JoeKuoD6Init,
                dim14321JoeKuoD6Init,
                dim14322JoeKuoD6Init,
                dim14323JoeKuoD6Init,
                dim14324JoeKuoD6Init,
                dim14325JoeKuoD6Init,
                dim14326JoeKuoD6Init,
                dim14327JoeKuoD6Init,
                dim14328JoeKuoD6Init,
                dim14329JoeKuoD6Init,
                dim14330JoeKuoD6Init,
                dim14331JoeKuoD6Init,
                dim14332JoeKuoD6Init,
                dim14333JoeKuoD6Init,
                dim14334JoeKuoD6Init,
                dim14335JoeKuoD6Init,
                dim14336JoeKuoD6Init,
                dim14337JoeKuoD6Init,
                dim14338JoeKuoD6Init,
                dim14339JoeKuoD6Init,
                dim14340JoeKuoD6Init,
                dim14341JoeKuoD6Init,
                dim14342JoeKuoD6Init,
                dim14343JoeKuoD6Init,
                dim14344JoeKuoD6Init,
                dim14345JoeKuoD6Init,
                dim14346JoeKuoD6Init,
                dim14347JoeKuoD6Init,
                dim14348JoeKuoD6Init,
                dim14349JoeKuoD6Init,
                dim14350JoeKuoD6Init,
                dim14351JoeKuoD6Init,
                dim14352JoeKuoD6Init,
                dim14353JoeKuoD6Init,
                dim14354JoeKuoD6Init,
                dim14355JoeKuoD6Init,
                dim14356JoeKuoD6Init,
                dim14357JoeKuoD6Init,
                dim14358JoeKuoD6Init,
                dim14359JoeKuoD6Init,
                dim14360JoeKuoD6Init,
                dim14361JoeKuoD6Init,
                dim14362JoeKuoD6Init,
                dim14363JoeKuoD6Init,
                dim14364JoeKuoD6Init,
                dim14365JoeKuoD6Init,
                dim14366JoeKuoD6Init,
                dim14367JoeKuoD6Init,
                dim14368JoeKuoD6Init,
                dim14369JoeKuoD6Init,
                dim14370JoeKuoD6Init,
                dim14371JoeKuoD6Init,
                dim14372JoeKuoD6Init,
                dim14373JoeKuoD6Init,
                dim14374JoeKuoD6Init,
                dim14375JoeKuoD6Init,
                dim14376JoeKuoD6Init,
                dim14377JoeKuoD6Init,
                dim14378JoeKuoD6Init,
                dim14379JoeKuoD6Init,
                dim14380JoeKuoD6Init,
                dim14381JoeKuoD6Init,
                dim14382JoeKuoD6Init,
                dim14383JoeKuoD6Init,
                dim14384JoeKuoD6Init,
                dim14385JoeKuoD6Init,
                dim14386JoeKuoD6Init,
                dim14387JoeKuoD6Init,
                dim14388JoeKuoD6Init,
                dim14389JoeKuoD6Init,
                dim14390JoeKuoD6Init,
                dim14391JoeKuoD6Init,
                dim14392JoeKuoD6Init,
                dim14393JoeKuoD6Init,
                dim14394JoeKuoD6Init,
                dim14395JoeKuoD6Init,
                dim14396JoeKuoD6Init,
                dim14397JoeKuoD6Init,
                dim14398JoeKuoD6Init,
                dim14399JoeKuoD6Init,
                dim14400JoeKuoD6Init,
                dim14401JoeKuoD6Init,
                dim14402JoeKuoD6Init,
                dim14403JoeKuoD6Init,
                dim14404JoeKuoD6Init,
                dim14405JoeKuoD6Init,
                dim14406JoeKuoD6Init,
                dim14407JoeKuoD6Init,
                dim14408JoeKuoD6Init,
                dim14409JoeKuoD6Init,
                dim14410JoeKuoD6Init,
                dim14411JoeKuoD6Init,
                dim14412JoeKuoD6Init,
                dim14413JoeKuoD6Init,
                dim14414JoeKuoD6Init,
                dim14415JoeKuoD6Init,
                dim14416JoeKuoD6Init,
                dim14417JoeKuoD6Init,
                dim14418JoeKuoD6Init,
                dim14419JoeKuoD6Init,
                dim14420JoeKuoD6Init,
                dim14421JoeKuoD6Init,
                dim14422JoeKuoD6Init,
                dim14423JoeKuoD6Init,
                dim14424JoeKuoD6Init,
                dim14425JoeKuoD6Init,
                dim14426JoeKuoD6Init,
                dim14427JoeKuoD6Init,
                dim14428JoeKuoD6Init,
                dim14429JoeKuoD6Init,
                dim14430JoeKuoD6Init,
                dim14431JoeKuoD6Init,
                dim14432JoeKuoD6Init,
                dim14433JoeKuoD6Init,
                dim14434JoeKuoD6Init,
                dim14435JoeKuoD6Init,
                dim14436JoeKuoD6Init,
                dim14437JoeKuoD6Init,
                dim14438JoeKuoD6Init,
                dim14439JoeKuoD6Init,
                dim14440JoeKuoD6Init,
                dim14441JoeKuoD6Init,
                dim14442JoeKuoD6Init,
                dim14443JoeKuoD6Init,
                dim14444JoeKuoD6Init,
                dim14445JoeKuoD6Init,
                dim14446JoeKuoD6Init,
                dim14447JoeKuoD6Init,
                dim14448JoeKuoD6Init,
                dim14449JoeKuoD6Init,
                dim14450JoeKuoD6Init,
                dim14451JoeKuoD6Init,
                dim14452JoeKuoD6Init,
                dim14453JoeKuoD6Init,
                dim14454JoeKuoD6Init,
                dim14455JoeKuoD6Init,
                dim14456JoeKuoD6Init,
                dim14457JoeKuoD6Init,
                dim14458JoeKuoD6Init,
                dim14459JoeKuoD6Init,
                dim14460JoeKuoD6Init,
                dim14461JoeKuoD6Init,
                dim14462JoeKuoD6Init,
                dim14463JoeKuoD6Init,
                dim14464JoeKuoD6Init,
                dim14465JoeKuoD6Init,
                dim14466JoeKuoD6Init,
                dim14467JoeKuoD6Init,
                dim14468JoeKuoD6Init,
                dim14469JoeKuoD6Init,
                dim14470JoeKuoD6Init,
                dim14471JoeKuoD6Init,
                dim14472JoeKuoD6Init,
                dim14473JoeKuoD6Init,
                dim14474JoeKuoD6Init,
                dim14475JoeKuoD6Init,
                dim14476JoeKuoD6Init,
                dim14477JoeKuoD6Init,
                dim14478JoeKuoD6Init,
                dim14479JoeKuoD6Init,
                dim14480JoeKuoD6Init,
                dim14481JoeKuoD6Init,
                dim14482JoeKuoD6Init,
                dim14483JoeKuoD6Init,
                dim14484JoeKuoD6Init,
                dim14485JoeKuoD6Init,
                dim14486JoeKuoD6Init,
                dim14487JoeKuoD6Init,
                dim14488JoeKuoD6Init,
                dim14489JoeKuoD6Init,
                dim14490JoeKuoD6Init,
                dim14491JoeKuoD6Init,
                dim14492JoeKuoD6Init,
                dim14493JoeKuoD6Init,
                dim14494JoeKuoD6Init,
                dim14495JoeKuoD6Init,
                dim14496JoeKuoD6Init,
                dim14497JoeKuoD6Init,
                dim14498JoeKuoD6Init,
                dim14499JoeKuoD6Init,
                dim14500JoeKuoD6Init,
                dim14501JoeKuoD6Init,
                dim14502JoeKuoD6Init,
                dim14503JoeKuoD6Init,
                dim14504JoeKuoD6Init,
                dim14505JoeKuoD6Init,
                dim14506JoeKuoD6Init,
                dim14507JoeKuoD6Init,
                dim14508JoeKuoD6Init,
                dim14509JoeKuoD6Init,
                dim14510JoeKuoD6Init,
                dim14511JoeKuoD6Init,
                dim14512JoeKuoD6Init,
                dim14513JoeKuoD6Init,
                dim14514JoeKuoD6Init,
                dim14515JoeKuoD6Init,
                dim14516JoeKuoD6Init,
                dim14517JoeKuoD6Init,
                dim14518JoeKuoD6Init,
                dim14519JoeKuoD6Init,
                dim14520JoeKuoD6Init,
                dim14521JoeKuoD6Init,
                dim14522JoeKuoD6Init,
                dim14523JoeKuoD6Init,
                dim14524JoeKuoD6Init,
                dim14525JoeKuoD6Init,
                dim14526JoeKuoD6Init,
                dim14527JoeKuoD6Init,
                dim14528JoeKuoD6Init,
                dim14529JoeKuoD6Init,
                dim14530JoeKuoD6Init,
                dim14531JoeKuoD6Init,
                dim14532JoeKuoD6Init,
                dim14533JoeKuoD6Init,
                dim14534JoeKuoD6Init,
                dim14535JoeKuoD6Init,
                dim14536JoeKuoD6Init,
                dim14537JoeKuoD6Init,
                dim14538JoeKuoD6Init,
                dim14539JoeKuoD6Init,
                dim14540JoeKuoD6Init,
                dim14541JoeKuoD6Init,
                dim14542JoeKuoD6Init,
                dim14543JoeKuoD6Init,
                dim14544JoeKuoD6Init,
                dim14545JoeKuoD6Init,
                dim14546JoeKuoD6Init,
                dim14547JoeKuoD6Init,
                dim14548JoeKuoD6Init,
                dim14549JoeKuoD6Init,
                dim14550JoeKuoD6Init,
                dim14551JoeKuoD6Init,
                dim14552JoeKuoD6Init,
                dim14553JoeKuoD6Init,
                dim14554JoeKuoD6Init,
                dim14555JoeKuoD6Init,
                dim14556JoeKuoD6Init,
                dim14557JoeKuoD6Init,
                dim14558JoeKuoD6Init,
                dim14559JoeKuoD6Init,
                dim14560JoeKuoD6Init,
                dim14561JoeKuoD6Init,
                dim14562JoeKuoD6Init,
                dim14563JoeKuoD6Init,
                dim14564JoeKuoD6Init,
                dim14565JoeKuoD6Init,
                dim14566JoeKuoD6Init,
                dim14567JoeKuoD6Init,
                dim14568JoeKuoD6Init,
                dim14569JoeKuoD6Init,
                dim14570JoeKuoD6Init,
                dim14571JoeKuoD6Init,
                dim14572JoeKuoD6Init,
                dim14573JoeKuoD6Init,
                dim14574JoeKuoD6Init,
                dim14575JoeKuoD6Init,
                dim14576JoeKuoD6Init,
                dim14577JoeKuoD6Init,
                dim14578JoeKuoD6Init,
                dim14579JoeKuoD6Init,
                dim14580JoeKuoD6Init,
                dim14581JoeKuoD6Init,
                dim14582JoeKuoD6Init,
                dim14583JoeKuoD6Init,
                dim14584JoeKuoD6Init,
                dim14585JoeKuoD6Init,
                dim14586JoeKuoD6Init,
                dim14587JoeKuoD6Init,
                dim14588JoeKuoD6Init,
                dim14589JoeKuoD6Init,
                dim14590JoeKuoD6Init,
                dim14591JoeKuoD6Init,
                dim14592JoeKuoD6Init,
                dim14593JoeKuoD6Init,
                dim14594JoeKuoD6Init,
                dim14595JoeKuoD6Init,
                dim14596JoeKuoD6Init,
                dim14597JoeKuoD6Init,
                dim14598JoeKuoD6Init,
                dim14599JoeKuoD6Init,
                dim14600JoeKuoD6Init,
                dim14601JoeKuoD6Init,
                dim14602JoeKuoD6Init,
                dim14603JoeKuoD6Init,
                dim14604JoeKuoD6Init,
                dim14605JoeKuoD6Init,
                dim14606JoeKuoD6Init,
                dim14607JoeKuoD6Init,
                dim14608JoeKuoD6Init,
                dim14609JoeKuoD6Init,
                dim14610JoeKuoD6Init,
                dim14611JoeKuoD6Init,
                dim14612JoeKuoD6Init,
                dim14613JoeKuoD6Init,
                dim14614JoeKuoD6Init,
                dim14615JoeKuoD6Init,
                dim14616JoeKuoD6Init,
                dim14617JoeKuoD6Init,
                dim14618JoeKuoD6Init,
                dim14619JoeKuoD6Init,
                dim14620JoeKuoD6Init,
                dim14621JoeKuoD6Init,
                dim14622JoeKuoD6Init,
                dim14623JoeKuoD6Init,
                dim14624JoeKuoD6Init,
                dim14625JoeKuoD6Init,
                dim14626JoeKuoD6Init,
                dim14627JoeKuoD6Init,
                dim14628JoeKuoD6Init,
                dim14629JoeKuoD6Init,
                dim14630JoeKuoD6Init,
                dim14631JoeKuoD6Init,
                dim14632JoeKuoD6Init,
                dim14633JoeKuoD6Init,
                dim14634JoeKuoD6Init,
                dim14635JoeKuoD6Init,
                dim14636JoeKuoD6Init,
                dim14637JoeKuoD6Init,
                dim14638JoeKuoD6Init,
                dim14639JoeKuoD6Init,
                dim14640JoeKuoD6Init,
                dim14641JoeKuoD6Init,
                dim14642JoeKuoD6Init,
                dim14643JoeKuoD6Init,
                dim14644JoeKuoD6Init,
                dim14645JoeKuoD6Init,
                dim14646JoeKuoD6Init,
                dim14647JoeKuoD6Init,
                dim14648JoeKuoD6Init,
                dim14649JoeKuoD6Init,
                dim14650JoeKuoD6Init,
                dim14651JoeKuoD6Init,
                dim14652JoeKuoD6Init,
                dim14653JoeKuoD6Init,
                dim14654JoeKuoD6Init,
                dim14655JoeKuoD6Init,
                dim14656JoeKuoD6Init,
                dim14657JoeKuoD6Init,
                dim14658JoeKuoD6Init,
                dim14659JoeKuoD6Init,
                dim14660JoeKuoD6Init,
                dim14661JoeKuoD6Init,
                dim14662JoeKuoD6Init,
                dim14663JoeKuoD6Init,
                dim14664JoeKuoD6Init,
                dim14665JoeKuoD6Init,
                dim14666JoeKuoD6Init,
                dim14667JoeKuoD6Init,
                dim14668JoeKuoD6Init,
                dim14669JoeKuoD6Init,
                dim14670JoeKuoD6Init,
                dim14671JoeKuoD6Init,
                dim14672JoeKuoD6Init,
                dim14673JoeKuoD6Init,
                dim14674JoeKuoD6Init,
                dim14675JoeKuoD6Init,
                dim14676JoeKuoD6Init,
                dim14677JoeKuoD6Init,
                dim14678JoeKuoD6Init,
                dim14679JoeKuoD6Init,
                dim14680JoeKuoD6Init,
                dim14681JoeKuoD6Init,
                dim14682JoeKuoD6Init,
                dim14683JoeKuoD6Init,
                dim14684JoeKuoD6Init,
                dim14685JoeKuoD6Init,
                dim14686JoeKuoD6Init,
                dim14687JoeKuoD6Init,
                dim14688JoeKuoD6Init,
                dim14689JoeKuoD6Init,
                dim14690JoeKuoD6Init,
                dim14691JoeKuoD6Init,
                dim14692JoeKuoD6Init,
                dim14693JoeKuoD6Init,
                dim14694JoeKuoD6Init,
                dim14695JoeKuoD6Init,
                dim14696JoeKuoD6Init,
                dim14697JoeKuoD6Init,
                dim14698JoeKuoD6Init,
                dim14699JoeKuoD6Init,
                dim14700JoeKuoD6Init,
                dim14701JoeKuoD6Init,
                dim14702JoeKuoD6Init,
                dim14703JoeKuoD6Init,
                dim14704JoeKuoD6Init,
                dim14705JoeKuoD6Init,
                dim14706JoeKuoD6Init,
                dim14707JoeKuoD6Init,
                dim14708JoeKuoD6Init,
                dim14709JoeKuoD6Init,
                dim14710JoeKuoD6Init,
                dim14711JoeKuoD6Init,
                dim14712JoeKuoD6Init,
                dim14713JoeKuoD6Init,
                dim14714JoeKuoD6Init,
                dim14715JoeKuoD6Init,
                dim14716JoeKuoD6Init,
                dim14717JoeKuoD6Init,
                dim14718JoeKuoD6Init,
                dim14719JoeKuoD6Init,
                dim14720JoeKuoD6Init,
                dim14721JoeKuoD6Init,
                dim14722JoeKuoD6Init,
                dim14723JoeKuoD6Init,
                dim14724JoeKuoD6Init,
                dim14725JoeKuoD6Init,
                dim14726JoeKuoD6Init,
                dim14727JoeKuoD6Init,
                dim14728JoeKuoD6Init,
                dim14729JoeKuoD6Init,
                dim14730JoeKuoD6Init,
                dim14731JoeKuoD6Init,
                dim14732JoeKuoD6Init,
                dim14733JoeKuoD6Init,
                dim14734JoeKuoD6Init,
                dim14735JoeKuoD6Init,
                dim14736JoeKuoD6Init,
                dim14737JoeKuoD6Init,
                dim14738JoeKuoD6Init,
                dim14739JoeKuoD6Init,
                dim14740JoeKuoD6Init,
                dim14741JoeKuoD6Init,
                dim14742JoeKuoD6Init,
                dim14743JoeKuoD6Init,
                dim14744JoeKuoD6Init,
                dim14745JoeKuoD6Init,
                dim14746JoeKuoD6Init,
                dim14747JoeKuoD6Init,
                dim14748JoeKuoD6Init,
                dim14749JoeKuoD6Init,
                dim14750JoeKuoD6Init,
                dim14751JoeKuoD6Init,
                dim14752JoeKuoD6Init,
                dim14753JoeKuoD6Init,
                dim14754JoeKuoD6Init,
                dim14755JoeKuoD6Init,
                dim14756JoeKuoD6Init,
                dim14757JoeKuoD6Init,
                dim14758JoeKuoD6Init,
                dim14759JoeKuoD6Init,
                dim14760JoeKuoD6Init,
                dim14761JoeKuoD6Init,
                dim14762JoeKuoD6Init,
                dim14763JoeKuoD6Init,
                dim14764JoeKuoD6Init,
                dim14765JoeKuoD6Init,
                dim14766JoeKuoD6Init,
                dim14767JoeKuoD6Init,
                dim14768JoeKuoD6Init,
                dim14769JoeKuoD6Init,
                dim14770JoeKuoD6Init,
                dim14771JoeKuoD6Init,
                dim14772JoeKuoD6Init,
                dim14773JoeKuoD6Init,
                dim14774JoeKuoD6Init,
                dim14775JoeKuoD6Init,
                dim14776JoeKuoD6Init,
                dim14777JoeKuoD6Init,
                dim14778JoeKuoD6Init,
                dim14779JoeKuoD6Init,
                dim14780JoeKuoD6Init,
                dim14781JoeKuoD6Init,
                dim14782JoeKuoD6Init,
                dim14783JoeKuoD6Init,
                dim14784JoeKuoD6Init,
                dim14785JoeKuoD6Init,
                dim14786JoeKuoD6Init,
                dim14787JoeKuoD6Init,
                dim14788JoeKuoD6Init,
                dim14789JoeKuoD6Init,
                dim14790JoeKuoD6Init,
                dim14791JoeKuoD6Init,
                dim14792JoeKuoD6Init,
                dim14793JoeKuoD6Init,
                dim14794JoeKuoD6Init,
                dim14795JoeKuoD6Init,
                dim14796JoeKuoD6Init,
                dim14797JoeKuoD6Init,
                dim14798JoeKuoD6Init,
                dim14799JoeKuoD6Init,
                dim14800JoeKuoD6Init,
                dim14801JoeKuoD6Init,
                dim14802JoeKuoD6Init,
                dim14803JoeKuoD6Init,
                dim14804JoeKuoD6Init,
                dim14805JoeKuoD6Init,
                dim14806JoeKuoD6Init,
                dim14807JoeKuoD6Init,
                dim14808JoeKuoD6Init,
                dim14809JoeKuoD6Init,
                dim14810JoeKuoD6Init,
                dim14811JoeKuoD6Init,
                dim14812JoeKuoD6Init,
                dim14813JoeKuoD6Init,
                dim14814JoeKuoD6Init,
                dim14815JoeKuoD6Init,
                dim14816JoeKuoD6Init,
                dim14817JoeKuoD6Init,
                dim14818JoeKuoD6Init,
                dim14819JoeKuoD6Init,
                dim14820JoeKuoD6Init,
                dim14821JoeKuoD6Init,
                dim14822JoeKuoD6Init,
                dim14823JoeKuoD6Init,
                dim14824JoeKuoD6Init,
                dim14825JoeKuoD6Init,
                dim14826JoeKuoD6Init,
                dim14827JoeKuoD6Init,
                dim14828JoeKuoD6Init,
                dim14829JoeKuoD6Init,
                dim14830JoeKuoD6Init,
                dim14831JoeKuoD6Init,
                dim14832JoeKuoD6Init,
                dim14833JoeKuoD6Init,
                dim14834JoeKuoD6Init,
                dim14835JoeKuoD6Init,
                dim14836JoeKuoD6Init,
                dim14837JoeKuoD6Init,
                dim14838JoeKuoD6Init,
                dim14839JoeKuoD6Init,
                dim14840JoeKuoD6Init,
                dim14841JoeKuoD6Init,
                dim14842JoeKuoD6Init,
                dim14843JoeKuoD6Init,
                dim14844JoeKuoD6Init,
                dim14845JoeKuoD6Init,
                dim14846JoeKuoD6Init,
                dim14847JoeKuoD6Init,
                dim14848JoeKuoD6Init,
                dim14849JoeKuoD6Init,
                dim14850JoeKuoD6Init,
                dim14851JoeKuoD6Init,
                dim14852JoeKuoD6Init,
                dim14853JoeKuoD6Init,
                dim14854JoeKuoD6Init,
                dim14855JoeKuoD6Init,
                dim14856JoeKuoD6Init,
                dim14857JoeKuoD6Init,
                dim14858JoeKuoD6Init,
                dim14859JoeKuoD6Init,
                dim14860JoeKuoD6Init,
                dim14861JoeKuoD6Init,
                dim14862JoeKuoD6Init,
                dim14863JoeKuoD6Init,
                dim14864JoeKuoD6Init,
                dim14865JoeKuoD6Init,
                dim14866JoeKuoD6Init,
                dim14867JoeKuoD6Init,
                dim14868JoeKuoD6Init,
                dim14869JoeKuoD6Init,
                dim14870JoeKuoD6Init,
                dim14871JoeKuoD6Init,
                dim14872JoeKuoD6Init,
                dim14873JoeKuoD6Init,
                dim14874JoeKuoD6Init,
                dim14875JoeKuoD6Init,
                dim14876JoeKuoD6Init,
                dim14877JoeKuoD6Init,
                dim14878JoeKuoD6Init,
                dim14879JoeKuoD6Init,
                dim14880JoeKuoD6Init,
                dim14881JoeKuoD6Init,
                dim14882JoeKuoD6Init,
                dim14883JoeKuoD6Init,
                dim14884JoeKuoD6Init,
                dim14885JoeKuoD6Init,
                dim14886JoeKuoD6Init,
                dim14887JoeKuoD6Init,
                dim14888JoeKuoD6Init,
                dim14889JoeKuoD6Init,
                dim14890JoeKuoD6Init,
                dim14891JoeKuoD6Init,
                dim14892JoeKuoD6Init,
                dim14893JoeKuoD6Init,
                dim14894JoeKuoD6Init,
                dim14895JoeKuoD6Init,
                dim14896JoeKuoD6Init,
                dim14897JoeKuoD6Init,
                dim14898JoeKuoD6Init,
                dim14899JoeKuoD6Init,
                dim14900JoeKuoD6Init,
                dim14901JoeKuoD6Init,
                dim14902JoeKuoD6Init,
                dim14903JoeKuoD6Init,
                dim14904JoeKuoD6Init,
                dim14905JoeKuoD6Init,
                dim14906JoeKuoD6Init,
                dim14907JoeKuoD6Init,
                dim14908JoeKuoD6Init,
                dim14909JoeKuoD6Init,
                dim14910JoeKuoD6Init,
                dim14911JoeKuoD6Init,
                dim14912JoeKuoD6Init,
                dim14913JoeKuoD6Init,
                dim14914JoeKuoD6Init,
                dim14915JoeKuoD6Init,
                dim14916JoeKuoD6Init,
                dim14917JoeKuoD6Init,
                dim14918JoeKuoD6Init,
                dim14919JoeKuoD6Init,
                dim14920JoeKuoD6Init,
                dim14921JoeKuoD6Init,
                dim14922JoeKuoD6Init,
                dim14923JoeKuoD6Init,
                dim14924JoeKuoD6Init,
                dim14925JoeKuoD6Init,
                dim14926JoeKuoD6Init,
                dim14927JoeKuoD6Init,
                dim14928JoeKuoD6Init,
                dim14929JoeKuoD6Init,
                dim14930JoeKuoD6Init,
                dim14931JoeKuoD6Init,
                dim14932JoeKuoD6Init,
                dim14933JoeKuoD6Init,
                dim14934JoeKuoD6Init,
                dim14935JoeKuoD6Init,
                dim14936JoeKuoD6Init,
                dim14937JoeKuoD6Init,
                dim14938JoeKuoD6Init,
                dim14939JoeKuoD6Init,
                dim14940JoeKuoD6Init,
                dim14941JoeKuoD6Init,
                dim14942JoeKuoD6Init,
                dim14943JoeKuoD6Init,
                dim14944JoeKuoD6Init,
                dim14945JoeKuoD6Init,
                dim14946JoeKuoD6Init,
                dim14947JoeKuoD6Init,
                dim14948JoeKuoD6Init,
                dim14949JoeKuoD6Init,
                dim14950JoeKuoD6Init,
                dim14951JoeKuoD6Init,
                dim14952JoeKuoD6Init,
                dim14953JoeKuoD6Init,
                dim14954JoeKuoD6Init,
                dim14955JoeKuoD6Init,
                dim14956JoeKuoD6Init,
                dim14957JoeKuoD6Init,
                dim14958JoeKuoD6Init,
                dim14959JoeKuoD6Init,
                dim14960JoeKuoD6Init,
                dim14961JoeKuoD6Init,
                dim14962JoeKuoD6Init,
                dim14963JoeKuoD6Init,
                dim14964JoeKuoD6Init,
                dim14965JoeKuoD6Init,
                dim14966JoeKuoD6Init,
                dim14967JoeKuoD6Init,
                dim14968JoeKuoD6Init,
                dim14969JoeKuoD6Init,
                dim14970JoeKuoD6Init,
                dim14971JoeKuoD6Init,
                dim14972JoeKuoD6Init,
                dim14973JoeKuoD6Init,
                dim14974JoeKuoD6Init,
                dim14975JoeKuoD6Init,
                dim14976JoeKuoD6Init,
                dim14977JoeKuoD6Init,
                dim14978JoeKuoD6Init,
                dim14979JoeKuoD6Init,
                dim14980JoeKuoD6Init,
                dim14981JoeKuoD6Init,
                dim14982JoeKuoD6Init,
                dim14983JoeKuoD6Init,
                dim14984JoeKuoD6Init,
                dim14985JoeKuoD6Init,
                dim14986JoeKuoD6Init,
                dim14987JoeKuoD6Init,
                dim14988JoeKuoD6Init,
                dim14989JoeKuoD6Init,
                dim14990JoeKuoD6Init,
                dim14991JoeKuoD6Init,
                dim14992JoeKuoD6Init,
                dim14993JoeKuoD6Init,
                dim14994JoeKuoD6Init,
                dim14995JoeKuoD6Init,
                dim14996JoeKuoD6Init,
                dim14997JoeKuoD6Init,
                dim14998JoeKuoD6Init,
                dim14999JoeKuoD6Init,
                dim15000JoeKuoD6Init,
                dim15001JoeKuoD6Init,
                dim15002JoeKuoD6Init,
                dim15003JoeKuoD6Init,
                dim15004JoeKuoD6Init,
                dim15005JoeKuoD6Init,
                dim15006JoeKuoD6Init,
                dim15007JoeKuoD6Init,
                dim15008JoeKuoD6Init,
                dim15009JoeKuoD6Init,
                dim15010JoeKuoD6Init,
                dim15011JoeKuoD6Init,
                dim15012JoeKuoD6Init,
                dim15013JoeKuoD6Init,
                dim15014JoeKuoD6Init,
                dim15015JoeKuoD6Init,
                dim15016JoeKuoD6Init,
                dim15017JoeKuoD6Init,
                dim15018JoeKuoD6Init,
                dim15019JoeKuoD6Init,
                dim15020JoeKuoD6Init,
                dim15021JoeKuoD6Init,
                dim15022JoeKuoD6Init,
                dim15023JoeKuoD6Init,
                dim15024JoeKuoD6Init,
                dim15025JoeKuoD6Init,
                dim15026JoeKuoD6Init,
                dim15027JoeKuoD6Init,
                dim15028JoeKuoD6Init,
                dim15029JoeKuoD6Init,
                dim15030JoeKuoD6Init,
                dim15031JoeKuoD6Init,
                dim15032JoeKuoD6Init,
                dim15033JoeKuoD6Init,
                dim15034JoeKuoD6Init,
                dim15035JoeKuoD6Init,
                dim15036JoeKuoD6Init,
                dim15037JoeKuoD6Init,
                dim15038JoeKuoD6Init,
                dim15039JoeKuoD6Init,
                dim15040JoeKuoD6Init,
                dim15041JoeKuoD6Init,
                dim15042JoeKuoD6Init,
                dim15043JoeKuoD6Init,
                dim15044JoeKuoD6Init,
                dim15045JoeKuoD6Init,
                dim15046JoeKuoD6Init,
                dim15047JoeKuoD6Init,
                dim15048JoeKuoD6Init,
                dim15049JoeKuoD6Init,
                dim15050JoeKuoD6Init,
                dim15051JoeKuoD6Init,
                dim15052JoeKuoD6Init,
                dim15053JoeKuoD6Init,
                dim15054JoeKuoD6Init,
                dim15055JoeKuoD6Init,
                dim15056JoeKuoD6Init,
                dim15057JoeKuoD6Init,
                dim15058JoeKuoD6Init,
                dim15059JoeKuoD6Init,
                dim15060JoeKuoD6Init,
                dim15061JoeKuoD6Init,
                dim15062JoeKuoD6Init,
                dim15063JoeKuoD6Init,
                dim15064JoeKuoD6Init,
                dim15065JoeKuoD6Init,
                dim15066JoeKuoD6Init,
                dim15067JoeKuoD6Init,
                dim15068JoeKuoD6Init,
                dim15069JoeKuoD6Init,
                dim15070JoeKuoD6Init,
                dim15071JoeKuoD6Init,
                dim15072JoeKuoD6Init,
                dim15073JoeKuoD6Init,
                dim15074JoeKuoD6Init,
                dim15075JoeKuoD6Init,
                dim15076JoeKuoD6Init,
                dim15077JoeKuoD6Init,
                dim15078JoeKuoD6Init,
                dim15079JoeKuoD6Init,
                dim15080JoeKuoD6Init,
                dim15081JoeKuoD6Init,
                dim15082JoeKuoD6Init,
                dim15083JoeKuoD6Init,
                dim15084JoeKuoD6Init,
                dim15085JoeKuoD6Init,
                dim15086JoeKuoD6Init,
                dim15087JoeKuoD6Init,
                dim15088JoeKuoD6Init,
                dim15089JoeKuoD6Init,
                dim15090JoeKuoD6Init,
                dim15091JoeKuoD6Init,
                dim15092JoeKuoD6Init,
                dim15093JoeKuoD6Init,
                dim15094JoeKuoD6Init,
                dim15095JoeKuoD6Init,
                dim15096JoeKuoD6Init,
                dim15097JoeKuoD6Init,
                dim15098JoeKuoD6Init,
                dim15099JoeKuoD6Init,
                dim15100JoeKuoD6Init,
                dim15101JoeKuoD6Init,
                dim15102JoeKuoD6Init,
                dim15103JoeKuoD6Init,
                dim15104JoeKuoD6Init,
                dim15105JoeKuoD6Init,
                dim15106JoeKuoD6Init,
                dim15107JoeKuoD6Init,
                dim15108JoeKuoD6Init,
                dim15109JoeKuoD6Init,
                dim15110JoeKuoD6Init,
                dim15111JoeKuoD6Init,
                dim15112JoeKuoD6Init,
                dim15113JoeKuoD6Init,
                dim15114JoeKuoD6Init,
                dim15115JoeKuoD6Init,
                dim15116JoeKuoD6Init,
                dim15117JoeKuoD6Init,
                dim15118JoeKuoD6Init,
                dim15119JoeKuoD6Init,
                dim15120JoeKuoD6Init,
                dim15121JoeKuoD6Init,
                dim15122JoeKuoD6Init,
                dim15123JoeKuoD6Init,
                dim15124JoeKuoD6Init,
                dim15125JoeKuoD6Init,
                dim15126JoeKuoD6Init,
                dim15127JoeKuoD6Init,
                dim15128JoeKuoD6Init,
                dim15129JoeKuoD6Init,
                dim15130JoeKuoD6Init,
                dim15131JoeKuoD6Init,
                dim15132JoeKuoD6Init,
                dim15133JoeKuoD6Init,
                dim15134JoeKuoD6Init,
                dim15135JoeKuoD6Init,
                dim15136JoeKuoD6Init,
                dim15137JoeKuoD6Init,
                dim15138JoeKuoD6Init,
                dim15139JoeKuoD6Init,
                dim15140JoeKuoD6Init,
                dim15141JoeKuoD6Init,
                dim15142JoeKuoD6Init,
                dim15143JoeKuoD6Init,
                dim15144JoeKuoD6Init,
                dim15145JoeKuoD6Init,
                dim15146JoeKuoD6Init,
                dim15147JoeKuoD6Init,
                dim15148JoeKuoD6Init,
                dim15149JoeKuoD6Init,
                dim15150JoeKuoD6Init,
                dim15151JoeKuoD6Init,
                dim15152JoeKuoD6Init,
                dim15153JoeKuoD6Init,
                dim15154JoeKuoD6Init,
                dim15155JoeKuoD6Init,
                dim15156JoeKuoD6Init,
                dim15157JoeKuoD6Init,
                dim15158JoeKuoD6Init,
                dim15159JoeKuoD6Init,
                dim15160JoeKuoD6Init,
                dim15161JoeKuoD6Init,
                dim15162JoeKuoD6Init,
                dim15163JoeKuoD6Init,
                dim15164JoeKuoD6Init,
                dim15165JoeKuoD6Init,
                dim15166JoeKuoD6Init,
                dim15167JoeKuoD6Init,
                dim15168JoeKuoD6Init,
                dim15169JoeKuoD6Init,
                dim15170JoeKuoD6Init,
                dim15171JoeKuoD6Init,
                dim15172JoeKuoD6Init,
                dim15173JoeKuoD6Init,
                dim15174JoeKuoD6Init,
                dim15175JoeKuoD6Init,
                dim15176JoeKuoD6Init,
                dim15177JoeKuoD6Init,
                dim15178JoeKuoD6Init,
                dim15179JoeKuoD6Init,
                dim15180JoeKuoD6Init,
                dim15181JoeKuoD6Init,
                dim15182JoeKuoD6Init,
                dim15183JoeKuoD6Init,
                dim15184JoeKuoD6Init,
                dim15185JoeKuoD6Init,
                dim15186JoeKuoD6Init,
                dim15187JoeKuoD6Init,
                dim15188JoeKuoD6Init,
                dim15189JoeKuoD6Init,
                dim15190JoeKuoD6Init,
                dim15191JoeKuoD6Init,
                dim15192JoeKuoD6Init,
                dim15193JoeKuoD6Init,
                dim15194JoeKuoD6Init,
                dim15195JoeKuoD6Init,
                dim15196JoeKuoD6Init,
                dim15197JoeKuoD6Init,
                dim15198JoeKuoD6Init,
                dim15199JoeKuoD6Init,
                dim15200JoeKuoD6Init,
                dim15201JoeKuoD6Init,
                dim15202JoeKuoD6Init,
                dim15203JoeKuoD6Init,
                dim15204JoeKuoD6Init,
                dim15205JoeKuoD6Init,
                dim15206JoeKuoD6Init,
                dim15207JoeKuoD6Init,
                dim15208JoeKuoD6Init,
                dim15209JoeKuoD6Init,
                dim15210JoeKuoD6Init,
                dim15211JoeKuoD6Init,
                dim15212JoeKuoD6Init,
                dim15213JoeKuoD6Init,
                dim15214JoeKuoD6Init,
                dim15215JoeKuoD6Init,
                dim15216JoeKuoD6Init,
                dim15217JoeKuoD6Init,
                dim15218JoeKuoD6Init,
                dim15219JoeKuoD6Init,
                dim15220JoeKuoD6Init,
                dim15221JoeKuoD6Init,
                dim15222JoeKuoD6Init,
                dim15223JoeKuoD6Init,
                dim15224JoeKuoD6Init,
                dim15225JoeKuoD6Init,
                dim15226JoeKuoD6Init,
                dim15227JoeKuoD6Init,
                dim15228JoeKuoD6Init,
                dim15229JoeKuoD6Init,
                dim15230JoeKuoD6Init,
                dim15231JoeKuoD6Init,
                dim15232JoeKuoD6Init,
                dim15233JoeKuoD6Init,
                dim15234JoeKuoD6Init,
                dim15235JoeKuoD6Init,
                dim15236JoeKuoD6Init,
                dim15237JoeKuoD6Init,
                dim15238JoeKuoD6Init,
                dim15239JoeKuoD6Init,
                dim15240JoeKuoD6Init,
                dim15241JoeKuoD6Init,
                dim15242JoeKuoD6Init,
                dim15243JoeKuoD6Init,
                dim15244JoeKuoD6Init,
                dim15245JoeKuoD6Init,
                dim15246JoeKuoD6Init,
                dim15247JoeKuoD6Init,
                dim15248JoeKuoD6Init,
                dim15249JoeKuoD6Init,
                dim15250JoeKuoD6Init,
                dim15251JoeKuoD6Init,
                dim15252JoeKuoD6Init,
                dim15253JoeKuoD6Init,
                dim15254JoeKuoD6Init,
                dim15255JoeKuoD6Init,
                dim15256JoeKuoD6Init,
                dim15257JoeKuoD6Init,
                dim15258JoeKuoD6Init,
                dim15259JoeKuoD6Init,
                dim15260JoeKuoD6Init,
                dim15261JoeKuoD6Init,
                dim15262JoeKuoD6Init,
                dim15263JoeKuoD6Init,
                dim15264JoeKuoD6Init,
                dim15265JoeKuoD6Init,
                dim15266JoeKuoD6Init,
                dim15267JoeKuoD6Init,
                dim15268JoeKuoD6Init,
                dim15269JoeKuoD6Init,
                dim15270JoeKuoD6Init,
                dim15271JoeKuoD6Init,
                dim15272JoeKuoD6Init,
                dim15273JoeKuoD6Init,
                dim15274JoeKuoD6Init,
                dim15275JoeKuoD6Init,
                dim15276JoeKuoD6Init,
                dim15277JoeKuoD6Init,
                dim15278JoeKuoD6Init,
                dim15279JoeKuoD6Init,
                dim15280JoeKuoD6Init,
                dim15281JoeKuoD6Init,
                dim15282JoeKuoD6Init,
                dim15283JoeKuoD6Init,
                dim15284JoeKuoD6Init,
                dim15285JoeKuoD6Init,
                dim15286JoeKuoD6Init,
                dim15287JoeKuoD6Init,
                dim15288JoeKuoD6Init,
                dim15289JoeKuoD6Init,
                dim15290JoeKuoD6Init,
                dim15291JoeKuoD6Init,
                dim15292JoeKuoD6Init,
                dim15293JoeKuoD6Init,
                dim15294JoeKuoD6Init,
                dim15295JoeKuoD6Init,
                dim15296JoeKuoD6Init,
                dim15297JoeKuoD6Init,
                dim15298JoeKuoD6Init,
                dim15299JoeKuoD6Init,
                dim15300JoeKuoD6Init,
                dim15301JoeKuoD6Init,
                dim15302JoeKuoD6Init,
                dim15303JoeKuoD6Init,
                dim15304JoeKuoD6Init,
                dim15305JoeKuoD6Init,
                dim15306JoeKuoD6Init,
                dim15307JoeKuoD6Init,
                dim15308JoeKuoD6Init,
                dim15309JoeKuoD6Init,
                dim15310JoeKuoD6Init,
                dim15311JoeKuoD6Init,
                dim15312JoeKuoD6Init,
                dim15313JoeKuoD6Init,
                dim15314JoeKuoD6Init,
                dim15315JoeKuoD6Init,
                dim15316JoeKuoD6Init,
                dim15317JoeKuoD6Init,
                dim15318JoeKuoD6Init,
                dim15319JoeKuoD6Init,
                dim15320JoeKuoD6Init,
                dim15321JoeKuoD6Init,
                dim15322JoeKuoD6Init,
                dim15323JoeKuoD6Init,
                dim15324JoeKuoD6Init,
                dim15325JoeKuoD6Init,
                dim15326JoeKuoD6Init,
                dim15327JoeKuoD6Init,
                dim15328JoeKuoD6Init,
                dim15329JoeKuoD6Init,
                dim15330JoeKuoD6Init,
                dim15331JoeKuoD6Init,
                dim15332JoeKuoD6Init,
                dim15333JoeKuoD6Init,
                dim15334JoeKuoD6Init,
                dim15335JoeKuoD6Init,
                dim15336JoeKuoD6Init,
                dim15337JoeKuoD6Init,
                dim15338JoeKuoD6Init,
                dim15339JoeKuoD6Init,
                dim15340JoeKuoD6Init,
                dim15341JoeKuoD6Init,
                dim15342JoeKuoD6Init,
                dim15343JoeKuoD6Init,
                dim15344JoeKuoD6Init,
                dim15345JoeKuoD6Init,
                dim15346JoeKuoD6Init,
                dim15347JoeKuoD6Init,
                dim15348JoeKuoD6Init,
                dim15349JoeKuoD6Init,
                dim15350JoeKuoD6Init,
                dim15351JoeKuoD6Init,
                dim15352JoeKuoD6Init,
                dim15353JoeKuoD6Init,
                dim15354JoeKuoD6Init,
                dim15355JoeKuoD6Init,
                dim15356JoeKuoD6Init,
                dim15357JoeKuoD6Init,
                dim15358JoeKuoD6Init,
                dim15359JoeKuoD6Init,
                dim15360JoeKuoD6Init,
                dim15361JoeKuoD6Init,
                dim15362JoeKuoD6Init,
                dim15363JoeKuoD6Init,
                dim15364JoeKuoD6Init,
                dim15365JoeKuoD6Init,
                dim15366JoeKuoD6Init,
                dim15367JoeKuoD6Init,
                dim15368JoeKuoD6Init,
                dim15369JoeKuoD6Init,
                dim15370JoeKuoD6Init,
                dim15371JoeKuoD6Init,
                dim15372JoeKuoD6Init,
                dim15373JoeKuoD6Init,
                dim15374JoeKuoD6Init,
                dim15375JoeKuoD6Init,
                dim15376JoeKuoD6Init,
                dim15377JoeKuoD6Init,
                dim15378JoeKuoD6Init,
                dim15379JoeKuoD6Init,
                dim15380JoeKuoD6Init,
                dim15381JoeKuoD6Init,
                dim15382JoeKuoD6Init,
                dim15383JoeKuoD6Init,
                dim15384JoeKuoD6Init,
                dim15385JoeKuoD6Init,
                dim15386JoeKuoD6Init,
                dim15387JoeKuoD6Init,
                dim15388JoeKuoD6Init,
                dim15389JoeKuoD6Init,
                dim15390JoeKuoD6Init,
                dim15391JoeKuoD6Init,
                dim15392JoeKuoD6Init,
                dim15393JoeKuoD6Init,
                dim15394JoeKuoD6Init,
                dim15395JoeKuoD6Init,
                dim15396JoeKuoD6Init,
                dim15397JoeKuoD6Init,
                dim15398JoeKuoD6Init,
                dim15399JoeKuoD6Init,
                dim15400JoeKuoD6Init,
                dim15401JoeKuoD6Init,
                dim15402JoeKuoD6Init,
                dim15403JoeKuoD6Init,
                dim15404JoeKuoD6Init,
                dim15405JoeKuoD6Init,
                dim15406JoeKuoD6Init,
                dim15407JoeKuoD6Init,
                dim15408JoeKuoD6Init,
                dim15409JoeKuoD6Init,
                dim15410JoeKuoD6Init,
                dim15411JoeKuoD6Init,
                dim15412JoeKuoD6Init,
                dim15413JoeKuoD6Init,
                dim15414JoeKuoD6Init,
                dim15415JoeKuoD6Init,
                dim15416JoeKuoD6Init,
                dim15417JoeKuoD6Init,
                dim15418JoeKuoD6Init,
                dim15419JoeKuoD6Init,
                dim15420JoeKuoD6Init,
                dim15421JoeKuoD6Init,
                dim15422JoeKuoD6Init,
                dim15423JoeKuoD6Init,
                dim15424JoeKuoD6Init,
                dim15425JoeKuoD6Init,
                dim15426JoeKuoD6Init,
                dim15427JoeKuoD6Init,
                dim15428JoeKuoD6Init,
                dim15429JoeKuoD6Init,
                dim15430JoeKuoD6Init,
                dim15431JoeKuoD6Init,
                dim15432JoeKuoD6Init,
                dim15433JoeKuoD6Init,
                dim15434JoeKuoD6Init,
                dim15435JoeKuoD6Init,
                dim15436JoeKuoD6Init,
                dim15437JoeKuoD6Init,
                dim15438JoeKuoD6Init,
                dim15439JoeKuoD6Init,
                dim15440JoeKuoD6Init,
                dim15441JoeKuoD6Init,
                dim15442JoeKuoD6Init,
                dim15443JoeKuoD6Init,
                dim15444JoeKuoD6Init,
                dim15445JoeKuoD6Init,
                dim15446JoeKuoD6Init,
                dim15447JoeKuoD6Init,
                dim15448JoeKuoD6Init,
                dim15449JoeKuoD6Init,
                dim15450JoeKuoD6Init,
                dim15451JoeKuoD6Init,
                dim15452JoeKuoD6Init,
                dim15453JoeKuoD6Init,
                dim15454JoeKuoD6Init,
                dim15455JoeKuoD6Init,
                dim15456JoeKuoD6Init,
                dim15457JoeKuoD6Init,
                dim15458JoeKuoD6Init,
                dim15459JoeKuoD6Init,
                dim15460JoeKuoD6Init,
                dim15461JoeKuoD6Init,
                dim15462JoeKuoD6Init,
                dim15463JoeKuoD6Init,
                dim15464JoeKuoD6Init,
                dim15465JoeKuoD6Init,
                dim15466JoeKuoD6Init,
                dim15467JoeKuoD6Init,
                dim15468JoeKuoD6Init,
                dim15469JoeKuoD6Init,
                dim15470JoeKuoD6Init,
                dim15471JoeKuoD6Init,
                dim15472JoeKuoD6Init,
                dim15473JoeKuoD6Init,
                dim15474JoeKuoD6Init,
                dim15475JoeKuoD6Init,
                dim15476JoeKuoD6Init,
                dim15477JoeKuoD6Init,
                dim15478JoeKuoD6Init,
                dim15479JoeKuoD6Init,
                dim15480JoeKuoD6Init,
                dim15481JoeKuoD6Init,
                dim15482JoeKuoD6Init,
                dim15483JoeKuoD6Init,
                dim15484JoeKuoD6Init,
                dim15485JoeKuoD6Init,
                dim15486JoeKuoD6Init,
                dim15487JoeKuoD6Init,
                dim15488JoeKuoD6Init,
                dim15489JoeKuoD6Init,
                dim15490JoeKuoD6Init,
                dim15491JoeKuoD6Init,
                dim15492JoeKuoD6Init,
                dim15493JoeKuoD6Init,
                dim15494JoeKuoD6Init,
                dim15495JoeKuoD6Init,
                dim15496JoeKuoD6Init,
                dim15497JoeKuoD6Init,
                dim15498JoeKuoD6Init,
                dim15499JoeKuoD6Init,
                dim15500JoeKuoD6Init,
                dim15501JoeKuoD6Init,
                dim15502JoeKuoD6Init,
                dim15503JoeKuoD6Init,
                dim15504JoeKuoD6Init,
                dim15505JoeKuoD6Init,
                dim15506JoeKuoD6Init,
                dim15507JoeKuoD6Init,
                dim15508JoeKuoD6Init,
                dim15509JoeKuoD6Init,
                dim15510JoeKuoD6Init,
                dim15511JoeKuoD6Init,
                dim15512JoeKuoD6Init,
                dim15513JoeKuoD6Init,
                dim15514JoeKuoD6Init,
                dim15515JoeKuoD6Init,
                dim15516JoeKuoD6Init,
                dim15517JoeKuoD6Init,
                dim15518JoeKuoD6Init,
                dim15519JoeKuoD6Init,
                dim15520JoeKuoD6Init,
                dim15521JoeKuoD6Init,
                dim15522JoeKuoD6Init,
                dim15523JoeKuoD6Init,
                dim15524JoeKuoD6Init,
                dim15525JoeKuoD6Init,
                dim15526JoeKuoD6Init,
                dim15527JoeKuoD6Init,
                dim15528JoeKuoD6Init,
                dim15529JoeKuoD6Init,
                dim15530JoeKuoD6Init,
                dim15531JoeKuoD6Init,
                dim15532JoeKuoD6Init,
                dim15533JoeKuoD6Init,
                dim15534JoeKuoD6Init,
                dim15535JoeKuoD6Init,
                dim15536JoeKuoD6Init,
                dim15537JoeKuoD6Init,
                dim15538JoeKuoD6Init,
                dim15539JoeKuoD6Init,
                dim15540JoeKuoD6Init,
                dim15541JoeKuoD6Init,
                dim15542JoeKuoD6Init,
                dim15543JoeKuoD6Init,
                dim15544JoeKuoD6Init,
                dim15545JoeKuoD6Init,
                dim15546JoeKuoD6Init,
                dim15547JoeKuoD6Init,
                dim15548JoeKuoD6Init,
                dim15549JoeKuoD6Init,
                dim15550JoeKuoD6Init,
                dim15551JoeKuoD6Init,
                dim15552JoeKuoD6Init,
                dim15553JoeKuoD6Init,
                dim15554JoeKuoD6Init,
                dim15555JoeKuoD6Init,
                dim15556JoeKuoD6Init,
                dim15557JoeKuoD6Init,
                dim15558JoeKuoD6Init,
                dim15559JoeKuoD6Init,
                dim15560JoeKuoD6Init,
                dim15561JoeKuoD6Init,
                dim15562JoeKuoD6Init,
                dim15563JoeKuoD6Init,
                dim15564JoeKuoD6Init,
                dim15565JoeKuoD6Init,
                dim15566JoeKuoD6Init,
                dim15567JoeKuoD6Init,
                dim15568JoeKuoD6Init,
                dim15569JoeKuoD6Init,
                dim15570JoeKuoD6Init,
                dim15571JoeKuoD6Init,
                dim15572JoeKuoD6Init,
                dim15573JoeKuoD6Init,
                dim15574JoeKuoD6Init,
                dim15575JoeKuoD6Init,
                dim15576JoeKuoD6Init,
                dim15577JoeKuoD6Init,
                dim15578JoeKuoD6Init,
                dim15579JoeKuoD6Init,
                dim15580JoeKuoD6Init,
                dim15581JoeKuoD6Init,
                dim15582JoeKuoD6Init,
                dim15583JoeKuoD6Init,
                dim15584JoeKuoD6Init,
                dim15585JoeKuoD6Init,
                dim15586JoeKuoD6Init,
                dim15587JoeKuoD6Init,
                dim15588JoeKuoD6Init,
                dim15589JoeKuoD6Init,
                dim15590JoeKuoD6Init,
                dim15591JoeKuoD6Init,
                dim15592JoeKuoD6Init,
                dim15593JoeKuoD6Init,
                dim15594JoeKuoD6Init,
                dim15595JoeKuoD6Init,
                dim15596JoeKuoD6Init,
                dim15597JoeKuoD6Init,
                dim15598JoeKuoD6Init,
                dim15599JoeKuoD6Init,
                dim15600JoeKuoD6Init,
                dim15601JoeKuoD6Init,
                dim15602JoeKuoD6Init,
                dim15603JoeKuoD6Init,
                dim15604JoeKuoD6Init,
                dim15605JoeKuoD6Init,
                dim15606JoeKuoD6Init,
                dim15607JoeKuoD6Init,
                dim15608JoeKuoD6Init,
                dim15609JoeKuoD6Init,
                dim15610JoeKuoD6Init,
                dim15611JoeKuoD6Init,
                dim15612JoeKuoD6Init,
                dim15613JoeKuoD6Init,
                dim15614JoeKuoD6Init,
                dim15615JoeKuoD6Init,
                dim15616JoeKuoD6Init,
                dim15617JoeKuoD6Init,
                dim15618JoeKuoD6Init,
                dim15619JoeKuoD6Init,
                dim15620JoeKuoD6Init,
                dim15621JoeKuoD6Init,
                dim15622JoeKuoD6Init,
                dim15623JoeKuoD6Init,
                dim15624JoeKuoD6Init,
                dim15625JoeKuoD6Init,
                dim15626JoeKuoD6Init,
                dim15627JoeKuoD6Init,
                dim15628JoeKuoD6Init,
                dim15629JoeKuoD6Init,
                dim15630JoeKuoD6Init,
                dim15631JoeKuoD6Init,
                dim15632JoeKuoD6Init,
                dim15633JoeKuoD6Init,
                dim15634JoeKuoD6Init,
                dim15635JoeKuoD6Init,
                dim15636JoeKuoD6Init,
                dim15637JoeKuoD6Init,
                dim15638JoeKuoD6Init,
                dim15639JoeKuoD6Init,
                dim15640JoeKuoD6Init,
                dim15641JoeKuoD6Init,
                dim15642JoeKuoD6Init,
                dim15643JoeKuoD6Init,
                dim15644JoeKuoD6Init,
                dim15645JoeKuoD6Init,
                dim15646JoeKuoD6Init,
                dim15647JoeKuoD6Init,
                dim15648JoeKuoD6Init,
                dim15649JoeKuoD6Init,
                dim15650JoeKuoD6Init,
                dim15651JoeKuoD6Init,
                dim15652JoeKuoD6Init,
                dim15653JoeKuoD6Init,
                dim15654JoeKuoD6Init,
                dim15655JoeKuoD6Init,
                dim15656JoeKuoD6Init,
                dim15657JoeKuoD6Init,
                dim15658JoeKuoD6Init,
                dim15659JoeKuoD6Init,
                dim15660JoeKuoD6Init,
                dim15661JoeKuoD6Init,
                dim15662JoeKuoD6Init,
                dim15663JoeKuoD6Init,
                dim15664JoeKuoD6Init,
                dim15665JoeKuoD6Init,
                dim15666JoeKuoD6Init,
                dim15667JoeKuoD6Init,
                dim15668JoeKuoD6Init,
                dim15669JoeKuoD6Init,
                dim15670JoeKuoD6Init,
                dim15671JoeKuoD6Init,
                dim15672JoeKuoD6Init,
                dim15673JoeKuoD6Init,
                dim15674JoeKuoD6Init,
                dim15675JoeKuoD6Init,
                dim15676JoeKuoD6Init,
                dim15677JoeKuoD6Init,
                dim15678JoeKuoD6Init,
                dim15679JoeKuoD6Init,
                dim15680JoeKuoD6Init,
                dim15681JoeKuoD6Init,
                dim15682JoeKuoD6Init,
                dim15683JoeKuoD6Init,
                dim15684JoeKuoD6Init,
                dim15685JoeKuoD6Init,
                dim15686JoeKuoD6Init,
                dim15687JoeKuoD6Init,
                dim15688JoeKuoD6Init,
                dim15689JoeKuoD6Init,
                dim15690JoeKuoD6Init,
                dim15691JoeKuoD6Init,
                dim15692JoeKuoD6Init,
                dim15693JoeKuoD6Init,
                dim15694JoeKuoD6Init,
                dim15695JoeKuoD6Init,
                dim15696JoeKuoD6Init,
                dim15697JoeKuoD6Init,
                dim15698JoeKuoD6Init,
                dim15699JoeKuoD6Init,
                dim15700JoeKuoD6Init,
                dim15701JoeKuoD6Init,
                dim15702JoeKuoD6Init,
                dim15703JoeKuoD6Init,
                dim15704JoeKuoD6Init,
                dim15705JoeKuoD6Init,
                dim15706JoeKuoD6Init,
                dim15707JoeKuoD6Init,
                dim15708JoeKuoD6Init,
                dim15709JoeKuoD6Init,
                dim15710JoeKuoD6Init,
                dim15711JoeKuoD6Init,
                dim15712JoeKuoD6Init,
                dim15713JoeKuoD6Init,
                dim15714JoeKuoD6Init,
                dim15715JoeKuoD6Init,
                dim15716JoeKuoD6Init,
                dim15717JoeKuoD6Init,
                dim15718JoeKuoD6Init,
                dim15719JoeKuoD6Init,
                dim15720JoeKuoD6Init,
                dim15721JoeKuoD6Init,
                dim15722JoeKuoD6Init,
                dim15723JoeKuoD6Init,
                dim15724JoeKuoD6Init,
                dim15725JoeKuoD6Init,
                dim15726JoeKuoD6Init,
                dim15727JoeKuoD6Init,
                dim15728JoeKuoD6Init,
                dim15729JoeKuoD6Init,
                dim15730JoeKuoD6Init,
                dim15731JoeKuoD6Init,
                dim15732JoeKuoD6Init,
                dim15733JoeKuoD6Init,
                dim15734JoeKuoD6Init,
                dim15735JoeKuoD6Init,
                dim15736JoeKuoD6Init,
                dim15737JoeKuoD6Init,
                dim15738JoeKuoD6Init,
                dim15739JoeKuoD6Init,
                dim15740JoeKuoD6Init,
                dim15741JoeKuoD6Init,
                dim15742JoeKuoD6Init,
                dim15743JoeKuoD6Init,
                dim15744JoeKuoD6Init,
                dim15745JoeKuoD6Init,
                dim15746JoeKuoD6Init,
                dim15747JoeKuoD6Init,
                dim15748JoeKuoD6Init,
                dim15749JoeKuoD6Init,
                dim15750JoeKuoD6Init,
                dim15751JoeKuoD6Init,
                dim15752JoeKuoD6Init,
                dim15753JoeKuoD6Init,
                dim15754JoeKuoD6Init,
                dim15755JoeKuoD6Init,
                dim15756JoeKuoD6Init,
                dim15757JoeKuoD6Init,
                dim15758JoeKuoD6Init,
                dim15759JoeKuoD6Init,
                dim15760JoeKuoD6Init,
                dim15761JoeKuoD6Init,
                dim15762JoeKuoD6Init,
                dim15763JoeKuoD6Init,
                dim15764JoeKuoD6Init,
                dim15765JoeKuoD6Init,
                dim15766JoeKuoD6Init,
                dim15767JoeKuoD6Init,
                dim15768JoeKuoD6Init,
                dim15769JoeKuoD6Init,
                dim15770JoeKuoD6Init,
                dim15771JoeKuoD6Init,
                dim15772JoeKuoD6Init,
                dim15773JoeKuoD6Init,
                dim15774JoeKuoD6Init,
                dim15775JoeKuoD6Init,
                dim15776JoeKuoD6Init,
                dim15777JoeKuoD6Init,
                dim15778JoeKuoD6Init,
                dim15779JoeKuoD6Init,
                dim15780JoeKuoD6Init,
                dim15781JoeKuoD6Init,
                dim15782JoeKuoD6Init,
                dim15783JoeKuoD6Init,
                dim15784JoeKuoD6Init,
                dim15785JoeKuoD6Init,
                dim15786JoeKuoD6Init,
                dim15787JoeKuoD6Init,
                dim15788JoeKuoD6Init,
                dim15789JoeKuoD6Init,
                dim15790JoeKuoD6Init,
                dim15791JoeKuoD6Init,
                dim15792JoeKuoD6Init,
                dim15793JoeKuoD6Init,
                dim15794JoeKuoD6Init,
                dim15795JoeKuoD6Init,
                dim15796JoeKuoD6Init,
                dim15797JoeKuoD6Init,
                dim15798JoeKuoD6Init,
                dim15799JoeKuoD6Init,
                dim15800JoeKuoD6Init,
                dim15801JoeKuoD6Init,
                dim15802JoeKuoD6Init,
                dim15803JoeKuoD6Init,
                dim15804JoeKuoD6Init,
                dim15805JoeKuoD6Init,
                dim15806JoeKuoD6Init,
                dim15807JoeKuoD6Init,
                dim15808JoeKuoD6Init,
                dim15809JoeKuoD6Init,
                dim15810JoeKuoD6Init,
                dim15811JoeKuoD6Init,
                dim15812JoeKuoD6Init,
                dim15813JoeKuoD6Init,
                dim15814JoeKuoD6Init,
                dim15815JoeKuoD6Init,
                dim15816JoeKuoD6Init,
                dim15817JoeKuoD6Init,
                dim15818JoeKuoD6Init,
                dim15819JoeKuoD6Init,
                dim15820JoeKuoD6Init,
                dim15821JoeKuoD6Init,
                dim15822JoeKuoD6Init,
                dim15823JoeKuoD6Init,
                dim15824JoeKuoD6Init,
                dim15825JoeKuoD6Init,
                dim15826JoeKuoD6Init,
                dim15827JoeKuoD6Init,
                dim15828JoeKuoD6Init,
                dim15829JoeKuoD6Init,
                dim15830JoeKuoD6Init,
                dim15831JoeKuoD6Init,
                dim15832JoeKuoD6Init,
                dim15833JoeKuoD6Init,
                dim15834JoeKuoD6Init,
                dim15835JoeKuoD6Init,
                dim15836JoeKuoD6Init,
                dim15837JoeKuoD6Init,
                dim15838JoeKuoD6Init,
                dim15839JoeKuoD6Init,
                dim15840JoeKuoD6Init,
                dim15841JoeKuoD6Init,
                dim15842JoeKuoD6Init,
                dim15843JoeKuoD6Init,
                dim15844JoeKuoD6Init,
                dim15845JoeKuoD6Init,
                dim15846JoeKuoD6Init,
                dim15847JoeKuoD6Init,
                dim15848JoeKuoD6Init,
                dim15849JoeKuoD6Init,
                dim15850JoeKuoD6Init,
                dim15851JoeKuoD6Init,
                dim15852JoeKuoD6Init,
                dim15853JoeKuoD6Init,
                dim15854JoeKuoD6Init,
                dim15855JoeKuoD6Init,
                dim15856JoeKuoD6Init,
                dim15857JoeKuoD6Init,
                dim15858JoeKuoD6Init,
                dim15859JoeKuoD6Init,
                dim15860JoeKuoD6Init,
                dim15861JoeKuoD6Init,
                dim15862JoeKuoD6Init,
                dim15863JoeKuoD6Init,
                dim15864JoeKuoD6Init,
                dim15865JoeKuoD6Init,
                dim15866JoeKuoD6Init,
                dim15867JoeKuoD6Init,
                dim15868JoeKuoD6Init,
                dim15869JoeKuoD6Init,
                dim15870JoeKuoD6Init,
                dim15871JoeKuoD6Init,
                dim15872JoeKuoD6Init,
                dim15873JoeKuoD6Init,
                dim15874JoeKuoD6Init,
                dim15875JoeKuoD6Init,
                dim15876JoeKuoD6Init,
                dim15877JoeKuoD6Init,
                dim15878JoeKuoD6Init,
                dim15879JoeKuoD6Init,
                dim15880JoeKuoD6Init,
                dim15881JoeKuoD6Init,
                dim15882JoeKuoD6Init,
                dim15883JoeKuoD6Init,
                dim15884JoeKuoD6Init,
                dim15885JoeKuoD6Init,
                dim15886JoeKuoD6Init,
                dim15887JoeKuoD6Init,
                dim15888JoeKuoD6Init,
                dim15889JoeKuoD6Init,
                dim15890JoeKuoD6Init,
                dim15891JoeKuoD6Init,
                dim15892JoeKuoD6Init,
                dim15893JoeKuoD6Init,
                dim15894JoeKuoD6Init,
                dim15895JoeKuoD6Init,
                dim15896JoeKuoD6Init,
                dim15897JoeKuoD6Init,
                dim15898JoeKuoD6Init,
                dim15899JoeKuoD6Init,
                dim15900JoeKuoD6Init,
                dim15901JoeKuoD6Init,
                dim15902JoeKuoD6Init,
                dim15903JoeKuoD6Init,
                dim15904JoeKuoD6Init,
                dim15905JoeKuoD6Init,
                dim15906JoeKuoD6Init,
                dim15907JoeKuoD6Init,
                dim15908JoeKuoD6Init,
                dim15909JoeKuoD6Init,
                dim15910JoeKuoD6Init,
                dim15911JoeKuoD6Init,
                dim15912JoeKuoD6Init,
                dim15913JoeKuoD6Init,
                dim15914JoeKuoD6Init,
                dim15915JoeKuoD6Init,
                dim15916JoeKuoD6Init,
                dim15917JoeKuoD6Init,
                dim15918JoeKuoD6Init,
                dim15919JoeKuoD6Init,
                dim15920JoeKuoD6Init,
                dim15921JoeKuoD6Init,
                dim15922JoeKuoD6Init,
                dim15923JoeKuoD6Init,
                dim15924JoeKuoD6Init,
                dim15925JoeKuoD6Init,
                dim15926JoeKuoD6Init,
                dim15927JoeKuoD6Init,
                dim15928JoeKuoD6Init,
                dim15929JoeKuoD6Init,
                dim15930JoeKuoD6Init,
                dim15931JoeKuoD6Init,
                dim15932JoeKuoD6Init,
                dim15933JoeKuoD6Init,
                dim15934JoeKuoD6Init,
                dim15935JoeKuoD6Init,
                dim15936JoeKuoD6Init,
                dim15937JoeKuoD6Init,
                dim15938JoeKuoD6Init,
                dim15939JoeKuoD6Init,
                dim15940JoeKuoD6Init,
                dim15941JoeKuoD6Init,
                dim15942JoeKuoD6Init,
                dim15943JoeKuoD6Init,
                dim15944JoeKuoD6Init,
                dim15945JoeKuoD6Init,
                dim15946JoeKuoD6Init,
                dim15947JoeKuoD6Init,
                dim15948JoeKuoD6Init,
                dim15949JoeKuoD6Init,
                dim15950JoeKuoD6Init,
                dim15951JoeKuoD6Init,
                dim15952JoeKuoD6Init,
                dim15953JoeKuoD6Init,
                dim15954JoeKuoD6Init,
                dim15955JoeKuoD6Init,
                dim15956JoeKuoD6Init,
                dim15957JoeKuoD6Init,
                dim15958JoeKuoD6Init,
                dim15959JoeKuoD6Init,
                dim15960JoeKuoD6Init,
                dim15961JoeKuoD6Init,
                dim15962JoeKuoD6Init,
                dim15963JoeKuoD6Init,
                dim15964JoeKuoD6Init,
                dim15965JoeKuoD6Init,
                dim15966JoeKuoD6Init,
                dim15967JoeKuoD6Init,
                dim15968JoeKuoD6Init,
                dim15969JoeKuoD6Init,
                dim15970JoeKuoD6Init,
                dim15971JoeKuoD6Init,
                dim15972JoeKuoD6Init,
                dim15973JoeKuoD6Init,
                dim15974JoeKuoD6Init,
                dim15975JoeKuoD6Init,
                dim15976JoeKuoD6Init,
                dim15977JoeKuoD6Init,
                dim15978JoeKuoD6Init,
                dim15979JoeKuoD6Init,
                dim15980JoeKuoD6Init,
                dim15981JoeKuoD6Init,
                dim15982JoeKuoD6Init,
                dim15983JoeKuoD6Init,
                dim15984JoeKuoD6Init,
                dim15985JoeKuoD6Init,
                dim15986JoeKuoD6Init,
                dim15987JoeKuoD6Init,
                dim15988JoeKuoD6Init,
                dim15989JoeKuoD6Init,
                dim15990JoeKuoD6Init,
                dim15991JoeKuoD6Init,
                dim15992JoeKuoD6Init,
                dim15993JoeKuoD6Init,
                dim15994JoeKuoD6Init,
                dim15995JoeKuoD6Init,
                dim15996JoeKuoD6Init,
                dim15997JoeKuoD6Init,
                dim15998JoeKuoD6Init,
                dim15999JoeKuoD6Init,
                dim16000JoeKuoD6Init,
                dim16001JoeKuoD6Init,
                dim16002JoeKuoD6Init,
                dim16003JoeKuoD6Init,
                dim16004JoeKuoD6Init,
                dim16005JoeKuoD6Init,
                dim16006JoeKuoD6Init,
                dim16007JoeKuoD6Init,
                dim16008JoeKuoD6Init,
                dim16009JoeKuoD6Init,
                dim16010JoeKuoD6Init,
                dim16011JoeKuoD6Init,
                dim16012JoeKuoD6Init,
                dim16013JoeKuoD6Init,
                dim16014JoeKuoD6Init,
                dim16015JoeKuoD6Init,
                dim16016JoeKuoD6Init,
                dim16017JoeKuoD6Init,
                dim16018JoeKuoD6Init,
                dim16019JoeKuoD6Init,
                dim16020JoeKuoD6Init,
                dim16021JoeKuoD6Init,
                dim16022JoeKuoD6Init,
                dim16023JoeKuoD6Init,
                dim16024JoeKuoD6Init,
                dim16025JoeKuoD6Init,
                dim16026JoeKuoD6Init,
                dim16027JoeKuoD6Init,
                dim16028JoeKuoD6Init,
                dim16029JoeKuoD6Init,
                dim16030JoeKuoD6Init,
                dim16031JoeKuoD6Init,
                dim16032JoeKuoD6Init,
                dim16033JoeKuoD6Init,
                dim16034JoeKuoD6Init,
                dim16035JoeKuoD6Init,
                dim16036JoeKuoD6Init,
                dim16037JoeKuoD6Init,
                dim16038JoeKuoD6Init,
                dim16039JoeKuoD6Init,
                dim16040JoeKuoD6Init,
                dim16041JoeKuoD6Init,
                dim16042JoeKuoD6Init,
                dim16043JoeKuoD6Init,
                dim16044JoeKuoD6Init,
                dim16045JoeKuoD6Init,
                dim16046JoeKuoD6Init,
                dim16047JoeKuoD6Init,
                dim16048JoeKuoD6Init,
                dim16049JoeKuoD6Init,
                dim16050JoeKuoD6Init,
                dim16051JoeKuoD6Init,
                dim16052JoeKuoD6Init,
                dim16053JoeKuoD6Init,
                dim16054JoeKuoD6Init,
                dim16055JoeKuoD6Init,
                dim16056JoeKuoD6Init,
                dim16057JoeKuoD6Init,
                dim16058JoeKuoD6Init,
                dim16059JoeKuoD6Init,
                dim16060JoeKuoD6Init,
                dim16061JoeKuoD6Init,
                dim16062JoeKuoD6Init,
                dim16063JoeKuoD6Init,
                dim16064JoeKuoD6Init,
                dim16065JoeKuoD6Init,
                dim16066JoeKuoD6Init,
                dim16067JoeKuoD6Init,
                dim16068JoeKuoD6Init,
                dim16069JoeKuoD6Init,
                dim16070JoeKuoD6Init,
                dim16071JoeKuoD6Init,
                dim16072JoeKuoD6Init,
                dim16073JoeKuoD6Init,
                dim16074JoeKuoD6Init,
                dim16075JoeKuoD6Init,
                dim16076JoeKuoD6Init,
                dim16077JoeKuoD6Init,
                dim16078JoeKuoD6Init,
                dim16079JoeKuoD6Init,
                dim16080JoeKuoD6Init,
                dim16081JoeKuoD6Init,
                dim16082JoeKuoD6Init,
                dim16083JoeKuoD6Init,
                dim16084JoeKuoD6Init,
                dim16085JoeKuoD6Init,
                dim16086JoeKuoD6Init,
                dim16087JoeKuoD6Init,
                dim16088JoeKuoD6Init,
                dim16089JoeKuoD6Init,
                dim16090JoeKuoD6Init,
                dim16091JoeKuoD6Init,
                dim16092JoeKuoD6Init,
                dim16093JoeKuoD6Init,
                dim16094JoeKuoD6Init,
                dim16095JoeKuoD6Init,
                dim16096JoeKuoD6Init,
                dim16097JoeKuoD6Init,
                dim16098JoeKuoD6Init,
                dim16099JoeKuoD6Init,
                dim16100JoeKuoD6Init,
                dim16101JoeKuoD6Init,
                dim16102JoeKuoD6Init,
                dim16103JoeKuoD6Init,
                dim16104JoeKuoD6Init,
                dim16105JoeKuoD6Init,
                dim16106JoeKuoD6Init,
                dim16107JoeKuoD6Init,
                dim16108JoeKuoD6Init,
                dim16109JoeKuoD6Init,
                dim16110JoeKuoD6Init,
                dim16111JoeKuoD6Init,
                dim16112JoeKuoD6Init,
                dim16113JoeKuoD6Init,
                dim16114JoeKuoD6Init,
                dim16115JoeKuoD6Init,
                dim16116JoeKuoD6Init,
                dim16117JoeKuoD6Init,
                dim16118JoeKuoD6Init,
                dim16119JoeKuoD6Init,
                dim16120JoeKuoD6Init,
                dim16121JoeKuoD6Init,
                dim16122JoeKuoD6Init,
                dim16123JoeKuoD6Init,
                dim16124JoeKuoD6Init,
                dim16125JoeKuoD6Init,
                dim16126JoeKuoD6Init,
                dim16127JoeKuoD6Init,
                dim16128JoeKuoD6Init,
                dim16129JoeKuoD6Init,
                dim16130JoeKuoD6Init,
                dim16131JoeKuoD6Init,
                dim16132JoeKuoD6Init,
                dim16133JoeKuoD6Init,
                dim16134JoeKuoD6Init,
                dim16135JoeKuoD6Init,
                dim16136JoeKuoD6Init,
                dim16137JoeKuoD6Init,
                dim16138JoeKuoD6Init,
                dim16139JoeKuoD6Init,
                dim16140JoeKuoD6Init,
                dim16141JoeKuoD6Init,
                dim16142JoeKuoD6Init,
                dim16143JoeKuoD6Init,
                dim16144JoeKuoD6Init,
                dim16145JoeKuoD6Init,
                dim16146JoeKuoD6Init,
                dim16147JoeKuoD6Init,
                dim16148JoeKuoD6Init,
                dim16149JoeKuoD6Init,
                dim16150JoeKuoD6Init,
                dim16151JoeKuoD6Init,
                dim16152JoeKuoD6Init,
                dim16153JoeKuoD6Init,
                dim16154JoeKuoD6Init,
                dim16155JoeKuoD6Init,
                dim16156JoeKuoD6Init,
                dim16157JoeKuoD6Init,
                dim16158JoeKuoD6Init,
                dim16159JoeKuoD6Init,
                dim16160JoeKuoD6Init,
                dim16161JoeKuoD6Init,
                dim16162JoeKuoD6Init,
                dim16163JoeKuoD6Init,
                dim16164JoeKuoD6Init,
                dim16165JoeKuoD6Init,
                dim16166JoeKuoD6Init,
                dim16167JoeKuoD6Init,
                dim16168JoeKuoD6Init,
                dim16169JoeKuoD6Init,
                dim16170JoeKuoD6Init,
                dim16171JoeKuoD6Init,
                dim16172JoeKuoD6Init,
                dim16173JoeKuoD6Init,
                dim16174JoeKuoD6Init,
                dim16175JoeKuoD6Init,
                dim16176JoeKuoD6Init,
                dim16177JoeKuoD6Init,
                dim16178JoeKuoD6Init,
                dim16179JoeKuoD6Init,
                dim16180JoeKuoD6Init,
                dim16181JoeKuoD6Init,
                dim16182JoeKuoD6Init,
                dim16183JoeKuoD6Init,
                dim16184JoeKuoD6Init,
                dim16185JoeKuoD6Init,
                dim16186JoeKuoD6Init,
                dim16187JoeKuoD6Init,
                dim16188JoeKuoD6Init,
                dim16189JoeKuoD6Init,
                dim16190JoeKuoD6Init,
                dim16191JoeKuoD6Init,
                dim16192JoeKuoD6Init,
                dim16193JoeKuoD6Init,
                dim16194JoeKuoD6Init,
                dim16195JoeKuoD6Init,
                dim16196JoeKuoD6Init,
                dim16197JoeKuoD6Init,
                dim16198JoeKuoD6Init,
                dim16199JoeKuoD6Init,
                dim16200JoeKuoD6Init,
                dim16201JoeKuoD6Init,
                dim16202JoeKuoD6Init,
                dim16203JoeKuoD6Init,
                dim16204JoeKuoD6Init,
                dim16205JoeKuoD6Init,
                dim16206JoeKuoD6Init,
                dim16207JoeKuoD6Init,
                dim16208JoeKuoD6Init,
                dim16209JoeKuoD6Init,
                dim16210JoeKuoD6Init,
                dim16211JoeKuoD6Init,
                dim16212JoeKuoD6Init,
                dim16213JoeKuoD6Init,
                dim16214JoeKuoD6Init,
                dim16215JoeKuoD6Init,
                dim16216JoeKuoD6Init,
                dim16217JoeKuoD6Init,
                dim16218JoeKuoD6Init,
                dim16219JoeKuoD6Init,
                dim16220JoeKuoD6Init,
                dim16221JoeKuoD6Init,
                dim16222JoeKuoD6Init,
                dim16223JoeKuoD6Init,
                dim16224JoeKuoD6Init,
                dim16225JoeKuoD6Init,
                dim16226JoeKuoD6Init,
                dim16227JoeKuoD6Init,
                dim16228JoeKuoD6Init,
                dim16229JoeKuoD6Init,
                dim16230JoeKuoD6Init,
                dim16231JoeKuoD6Init,
                dim16232JoeKuoD6Init,
                dim16233JoeKuoD6Init,
                dim16234JoeKuoD6Init,
                dim16235JoeKuoD6Init,
                dim16236JoeKuoD6Init,
                dim16237JoeKuoD6Init,
                dim16238JoeKuoD6Init,
                dim16239JoeKuoD6Init,
                dim16240JoeKuoD6Init,
                dim16241JoeKuoD6Init,
                dim16242JoeKuoD6Init,
                dim16243JoeKuoD6Init,
                dim16244JoeKuoD6Init,
                dim16245JoeKuoD6Init,
                dim16246JoeKuoD6Init,
                dim16247JoeKuoD6Init,
                dim16248JoeKuoD6Init,
                dim16249JoeKuoD6Init,
                dim16250JoeKuoD6Init,
                dim16251JoeKuoD6Init,
                dim16252JoeKuoD6Init,
                dim16253JoeKuoD6Init,
                dim16254JoeKuoD6Init,
                dim16255JoeKuoD6Init,
                dim16256JoeKuoD6Init,
                dim16257JoeKuoD6Init,
                dim16258JoeKuoD6Init,
                dim16259JoeKuoD6Init,
                dim16260JoeKuoD6Init,
                dim16261JoeKuoD6Init,
                dim16262JoeKuoD6Init,
                dim16263JoeKuoD6Init,
                dim16264JoeKuoD6Init,
                dim16265JoeKuoD6Init,
                dim16266JoeKuoD6Init,
                dim16267JoeKuoD6Init,
                dim16268JoeKuoD6Init,
                dim16269JoeKuoD6Init,
                dim16270JoeKuoD6Init,
                dim16271JoeKuoD6Init,
                dim16272JoeKuoD6Init,
                dim16273JoeKuoD6Init,
                dim16274JoeKuoD6Init,
                dim16275JoeKuoD6Init,
                dim16276JoeKuoD6Init,
                dim16277JoeKuoD6Init,
                dim16278JoeKuoD6Init,
                dim16279JoeKuoD6Init,
                dim16280JoeKuoD6Init,
                dim16281JoeKuoD6Init,
                dim16282JoeKuoD6Init,
                dim16283JoeKuoD6Init,
                dim16284JoeKuoD6Init,
                dim16285JoeKuoD6Init,
                dim16286JoeKuoD6Init,
                dim16287JoeKuoD6Init,
                dim16288JoeKuoD6Init,
                dim16289JoeKuoD6Init,
                dim16290JoeKuoD6Init,
                dim16291JoeKuoD6Init,
                dim16292JoeKuoD6Init,
                dim16293JoeKuoD6Init,
                dim16294JoeKuoD6Init,
                dim16295JoeKuoD6Init,
                dim16296JoeKuoD6Init,
                dim16297JoeKuoD6Init,
                dim16298JoeKuoD6Init,
                dim16299JoeKuoD6Init,
                dim16300JoeKuoD6Init,
                dim16301JoeKuoD6Init,
                dim16302JoeKuoD6Init,
                dim16303JoeKuoD6Init,
                dim16304JoeKuoD6Init,
                dim16305JoeKuoD6Init,
                dim16306JoeKuoD6Init,
                dim16307JoeKuoD6Init,
                dim16308JoeKuoD6Init,
                dim16309JoeKuoD6Init,
                dim16310JoeKuoD6Init,
                dim16311JoeKuoD6Init,
                dim16312JoeKuoD6Init,
                dim16313JoeKuoD6Init,
                dim16314JoeKuoD6Init,
                dim16315JoeKuoD6Init,
                dim16316JoeKuoD6Init,
                dim16317JoeKuoD6Init,
                dim16318JoeKuoD6Init,
                dim16319JoeKuoD6Init,
                dim16320JoeKuoD6Init,
                dim16321JoeKuoD6Init,
                dim16322JoeKuoD6Init,
                dim16323JoeKuoD6Init,
                dim16324JoeKuoD6Init,
                dim16325JoeKuoD6Init,
                dim16326JoeKuoD6Init,
                dim16327JoeKuoD6Init,
                dim16328JoeKuoD6Init,
                dim16329JoeKuoD6Init,
                dim16330JoeKuoD6Init,
                dim16331JoeKuoD6Init,
                dim16332JoeKuoD6Init,
                dim16333JoeKuoD6Init,
                dim16334JoeKuoD6Init,
                dim16335JoeKuoD6Init,
                dim16336JoeKuoD6Init,
                dim16337JoeKuoD6Init,
                dim16338JoeKuoD6Init,
                dim16339JoeKuoD6Init,
                dim16340JoeKuoD6Init,
                dim16341JoeKuoD6Init,
                dim16342JoeKuoD6Init,
                dim16343JoeKuoD6Init,
                dim16344JoeKuoD6Init,
                dim16345JoeKuoD6Init,
                dim16346JoeKuoD6Init,
                dim16347JoeKuoD6Init,
                dim16348JoeKuoD6Init,
                dim16349JoeKuoD6Init,
                dim16350JoeKuoD6Init,
                dim16351JoeKuoD6Init,
                dim16352JoeKuoD6Init,
                dim16353JoeKuoD6Init,
                dim16354JoeKuoD6Init,
                dim16355JoeKuoD6Init,
                dim16356JoeKuoD6Init,
                dim16357JoeKuoD6Init,
                dim16358JoeKuoD6Init,
                dim16359JoeKuoD6Init,
                dim16360JoeKuoD6Init,
                dim16361JoeKuoD6Init,
                dim16362JoeKuoD6Init,
                dim16363JoeKuoD6Init,
                dim16364JoeKuoD6Init,
                dim16365JoeKuoD6Init,
                dim16366JoeKuoD6Init,
                dim16367JoeKuoD6Init,
                dim16368JoeKuoD6Init,
                dim16369JoeKuoD6Init,
                dim16370JoeKuoD6Init,
                dim16371JoeKuoD6Init,
                dim16372JoeKuoD6Init,
                dim16373JoeKuoD6Init,
                dim16374JoeKuoD6Init,
                dim16375JoeKuoD6Init,
                dim16376JoeKuoD6Init,
                dim16377JoeKuoD6Init,
                dim16378JoeKuoD6Init,
                dim16379JoeKuoD6Init,
                dim16380JoeKuoD6Init,
                dim16381JoeKuoD6Init,
                dim16382JoeKuoD6Init,
                dim16383JoeKuoD6Init,
                dim16384JoeKuoD6Init,
                dim16385JoeKuoD6Init,
                dim16386JoeKuoD6Init,
                dim16387JoeKuoD6Init,
                dim16388JoeKuoD6Init,
                dim16389JoeKuoD6Init,
                dim16390JoeKuoD6Init,
                dim16391JoeKuoD6Init,
                dim16392JoeKuoD6Init,
                dim16393JoeKuoD6Init,
                dim16394JoeKuoD6Init,
                dim16395JoeKuoD6Init,
                dim16396JoeKuoD6Init,
                dim16397JoeKuoD6Init,
                dim16398JoeKuoD6Init,
                dim16399JoeKuoD6Init,
                dim16400JoeKuoD6Init,
                dim16401JoeKuoD6Init,
                dim16402JoeKuoD6Init,
                dim16403JoeKuoD6Init,
                dim16404JoeKuoD6Init,
                dim16405JoeKuoD6Init,
                dim16406JoeKuoD6Init,
                dim16407JoeKuoD6Init,
                dim16408JoeKuoD6Init,
                dim16409JoeKuoD6Init,
                dim16410JoeKuoD6Init,
                dim16411JoeKuoD6Init,
                dim16412JoeKuoD6Init,
                dim16413JoeKuoD6Init,
                dim16414JoeKuoD6Init,
                dim16415JoeKuoD6Init,
                dim16416JoeKuoD6Init,
                dim16417JoeKuoD6Init,
                dim16418JoeKuoD6Init,
                dim16419JoeKuoD6Init,
                dim16420JoeKuoD6Init,
                dim16421JoeKuoD6Init,
                dim16422JoeKuoD6Init,
                dim16423JoeKuoD6Init,
                dim16424JoeKuoD6Init,
                dim16425JoeKuoD6Init,
                dim16426JoeKuoD6Init,
                dim16427JoeKuoD6Init,
                dim16428JoeKuoD6Init,
                dim16429JoeKuoD6Init,
                dim16430JoeKuoD6Init,
                dim16431JoeKuoD6Init,
                dim16432JoeKuoD6Init,
                dim16433JoeKuoD6Init,
                dim16434JoeKuoD6Init,
                dim16435JoeKuoD6Init,
                dim16436JoeKuoD6Init,
                dim16437JoeKuoD6Init,
                dim16438JoeKuoD6Init,
                dim16439JoeKuoD6Init,
                dim16440JoeKuoD6Init,
                dim16441JoeKuoD6Init,
                dim16442JoeKuoD6Init,
                dim16443JoeKuoD6Init,
                dim16444JoeKuoD6Init,
                dim16445JoeKuoD6Init,
                dim16446JoeKuoD6Init,
                dim16447JoeKuoD6Init,
                dim16448JoeKuoD6Init,
                dim16449JoeKuoD6Init,
                dim16450JoeKuoD6Init,
                dim16451JoeKuoD6Init,
                dim16452JoeKuoD6Init,
                dim16453JoeKuoD6Init,
                dim16454JoeKuoD6Init,
                dim16455JoeKuoD6Init,
                dim16456JoeKuoD6Init,
                dim16457JoeKuoD6Init,
                dim16458JoeKuoD6Init,
                dim16459JoeKuoD6Init,
                dim16460JoeKuoD6Init,
                dim16461JoeKuoD6Init,
                dim16462JoeKuoD6Init,
                dim16463JoeKuoD6Init,
                dim16464JoeKuoD6Init,
                dim16465JoeKuoD6Init,
                dim16466JoeKuoD6Init,
                dim16467JoeKuoD6Init,
                dim16468JoeKuoD6Init,
                dim16469JoeKuoD6Init,
                dim16470JoeKuoD6Init,
                dim16471JoeKuoD6Init,
                dim16472JoeKuoD6Init,
                dim16473JoeKuoD6Init,
                dim16474JoeKuoD6Init,
                dim16475JoeKuoD6Init,
                dim16476JoeKuoD6Init,
                dim16477JoeKuoD6Init,
                dim16478JoeKuoD6Init,
                dim16479JoeKuoD6Init,
                dim16480JoeKuoD6Init,
                dim16481JoeKuoD6Init,
                dim16482JoeKuoD6Init,
                dim16483JoeKuoD6Init,
                dim16484JoeKuoD6Init,
                dim16485JoeKuoD6Init,
                dim16486JoeKuoD6Init,
                dim16487JoeKuoD6Init,
                dim16488JoeKuoD6Init,
                dim16489JoeKuoD6Init,
                dim16490JoeKuoD6Init,
                dim16491JoeKuoD6Init,
                dim16492JoeKuoD6Init,
                dim16493JoeKuoD6Init,
                dim16494JoeKuoD6Init,
                dim16495JoeKuoD6Init,
                dim16496JoeKuoD6Init,
                dim16497JoeKuoD6Init,
                dim16498JoeKuoD6Init,
                dim16499JoeKuoD6Init,
                dim16500JoeKuoD6Init,
                dim16501JoeKuoD6Init,
                dim16502JoeKuoD6Init,
                dim16503JoeKuoD6Init,
                dim16504JoeKuoD6Init,
                dim16505JoeKuoD6Init,
                dim16506JoeKuoD6Init,
                dim16507JoeKuoD6Init,
                dim16508JoeKuoD6Init,
                dim16509JoeKuoD6Init,
                dim16510JoeKuoD6Init,
                dim16511JoeKuoD6Init,
                dim16512JoeKuoD6Init,
                dim16513JoeKuoD6Init,
                dim16514JoeKuoD6Init,
                dim16515JoeKuoD6Init,
                dim16516JoeKuoD6Init,
                dim16517JoeKuoD6Init,
                dim16518JoeKuoD6Init,
                dim16519JoeKuoD6Init,
                dim16520JoeKuoD6Init,
                dim16521JoeKuoD6Init,
                dim16522JoeKuoD6Init,
                dim16523JoeKuoD6Init,
                dim16524JoeKuoD6Init,
                dim16525JoeKuoD6Init,
                dim16526JoeKuoD6Init,
                dim16527JoeKuoD6Init,
                dim16528JoeKuoD6Init,
                dim16529JoeKuoD6Init,
                dim16530JoeKuoD6Init,
                dim16531JoeKuoD6Init,
                dim16532JoeKuoD6Init,
                dim16533JoeKuoD6Init,
                dim16534JoeKuoD6Init,
                dim16535JoeKuoD6Init,
                dim16536JoeKuoD6Init,
                dim16537JoeKuoD6Init,
                dim16538JoeKuoD6Init,
                dim16539JoeKuoD6Init,
                dim16540JoeKuoD6Init,
                dim16541JoeKuoD6Init,
                dim16542JoeKuoD6Init,
                dim16543JoeKuoD6Init,
                dim16544JoeKuoD6Init,
                dim16545JoeKuoD6Init,
                dim16546JoeKuoD6Init,
                dim16547JoeKuoD6Init,
                dim16548JoeKuoD6Init,
                dim16549JoeKuoD6Init,
                dim16550JoeKuoD6Init,
                dim16551JoeKuoD6Init,
                dim16552JoeKuoD6Init,
                dim16553JoeKuoD6Init,
                dim16554JoeKuoD6Init,
                dim16555JoeKuoD6Init,
                dim16556JoeKuoD6Init,
                dim16557JoeKuoD6Init,
                dim16558JoeKuoD6Init,
                dim16559JoeKuoD6Init,
                dim16560JoeKuoD6Init,
                dim16561JoeKuoD6Init,
                dim16562JoeKuoD6Init,
                dim16563JoeKuoD6Init,
                dim16564JoeKuoD6Init,
                dim16565JoeKuoD6Init,
                dim16566JoeKuoD6Init,
                dim16567JoeKuoD6Init,
                dim16568JoeKuoD6Init,
                dim16569JoeKuoD6Init,
                dim16570JoeKuoD6Init,
                dim16571JoeKuoD6Init,
                dim16572JoeKuoD6Init,
                dim16573JoeKuoD6Init,
                dim16574JoeKuoD6Init,
                dim16575JoeKuoD6Init,
                dim16576JoeKuoD6Init,
                dim16577JoeKuoD6Init,
                dim16578JoeKuoD6Init,
                dim16579JoeKuoD6Init,
                dim16580JoeKuoD6Init,
                dim16581JoeKuoD6Init,
                dim16582JoeKuoD6Init,
                dim16583JoeKuoD6Init,
                dim16584JoeKuoD6Init,
                dim16585JoeKuoD6Init,
                dim16586JoeKuoD6Init,
                dim16587JoeKuoD6Init,
                dim16588JoeKuoD6Init,
                dim16589JoeKuoD6Init,
                dim16590JoeKuoD6Init,
                dim16591JoeKuoD6Init,
                dim16592JoeKuoD6Init,
                dim16593JoeKuoD6Init,
                dim16594JoeKuoD6Init,
                dim16595JoeKuoD6Init,
                dim16596JoeKuoD6Init,
                dim16597JoeKuoD6Init,
                dim16598JoeKuoD6Init,
                dim16599JoeKuoD6Init,
                dim16600JoeKuoD6Init,
                dim16601JoeKuoD6Init,
                dim16602JoeKuoD6Init,
                dim16603JoeKuoD6Init,
                dim16604JoeKuoD6Init,
                dim16605JoeKuoD6Init,
                dim16606JoeKuoD6Init,
                dim16607JoeKuoD6Init,
                dim16608JoeKuoD6Init,
                dim16609JoeKuoD6Init,
                dim16610JoeKuoD6Init,
                dim16611JoeKuoD6Init,
                dim16612JoeKuoD6Init,
                dim16613JoeKuoD6Init,
                dim16614JoeKuoD6Init,
                dim16615JoeKuoD6Init,
                dim16616JoeKuoD6Init,
                dim16617JoeKuoD6Init,
                dim16618JoeKuoD6Init,
                dim16619JoeKuoD6Init,
                dim16620JoeKuoD6Init,
                dim16621JoeKuoD6Init,
                dim16622JoeKuoD6Init,
                dim16623JoeKuoD6Init,
                dim16624JoeKuoD6Init,
                dim16625JoeKuoD6Init,
                dim16626JoeKuoD6Init,
                dim16627JoeKuoD6Init,
                dim16628JoeKuoD6Init,
                dim16629JoeKuoD6Init,
                dim16630JoeKuoD6Init,
                dim16631JoeKuoD6Init,
                dim16632JoeKuoD6Init,
                dim16633JoeKuoD6Init,
                dim16634JoeKuoD6Init,
                dim16635JoeKuoD6Init,
                dim16636JoeKuoD6Init,
                dim16637JoeKuoD6Init,
                dim16638JoeKuoD6Init,
                dim16639JoeKuoD6Init,
                dim16640JoeKuoD6Init,
                dim16641JoeKuoD6Init,
                dim16642JoeKuoD6Init,
                dim16643JoeKuoD6Init,
                dim16644JoeKuoD6Init,
                dim16645JoeKuoD6Init,
                dim16646JoeKuoD6Init,
                dim16647JoeKuoD6Init,
                dim16648JoeKuoD6Init,
                dim16649JoeKuoD6Init,
                dim16650JoeKuoD6Init,
                dim16651JoeKuoD6Init,
                dim16652JoeKuoD6Init,
                dim16653JoeKuoD6Init,
                dim16654JoeKuoD6Init,
                dim16655JoeKuoD6Init,
                dim16656JoeKuoD6Init,
                dim16657JoeKuoD6Init,
                dim16658JoeKuoD6Init,
                dim16659JoeKuoD6Init,
                dim16660JoeKuoD6Init,
                dim16661JoeKuoD6Init,
                dim16662JoeKuoD6Init,
                dim16663JoeKuoD6Init,
                dim16664JoeKuoD6Init,
                dim16665JoeKuoD6Init,
                dim16666JoeKuoD6Init,
                dim16667JoeKuoD6Init,
                dim16668JoeKuoD6Init,
                dim16669JoeKuoD6Init,
                dim16670JoeKuoD6Init,
                dim16671JoeKuoD6Init,
                dim16672JoeKuoD6Init,
                dim16673JoeKuoD6Init,
                dim16674JoeKuoD6Init,
                dim16675JoeKuoD6Init,
                dim16676JoeKuoD6Init,
                dim16677JoeKuoD6Init,
                dim16678JoeKuoD6Init,
                dim16679JoeKuoD6Init,
                dim16680JoeKuoD6Init,
                dim16681JoeKuoD6Init,
                dim16682JoeKuoD6Init,
                dim16683JoeKuoD6Init,
                dim16684JoeKuoD6Init,
                dim16685JoeKuoD6Init,
                dim16686JoeKuoD6Init,
                dim16687JoeKuoD6Init,
                dim16688JoeKuoD6Init,
                dim16689JoeKuoD6Init,
                dim16690JoeKuoD6Init,
                dim16691JoeKuoD6Init,
                dim16692JoeKuoD6Init,
                dim16693JoeKuoD6Init,
                dim16694JoeKuoD6Init,
                dim16695JoeKuoD6Init,
                dim16696JoeKuoD6Init,
                dim16697JoeKuoD6Init,
                dim16698JoeKuoD6Init,
                dim16699JoeKuoD6Init,
                dim16700JoeKuoD6Init,
                dim16701JoeKuoD6Init,
                dim16702JoeKuoD6Init,
                dim16703JoeKuoD6Init,
                dim16704JoeKuoD6Init,
                dim16705JoeKuoD6Init,
                dim16706JoeKuoD6Init,
                dim16707JoeKuoD6Init,
                dim16708JoeKuoD6Init,
                dim16709JoeKuoD6Init,
                dim16710JoeKuoD6Init,
                dim16711JoeKuoD6Init,
                dim16712JoeKuoD6Init,
                dim16713JoeKuoD6Init,
                dim16714JoeKuoD6Init,
                dim16715JoeKuoD6Init,
                dim16716JoeKuoD6Init,
                dim16717JoeKuoD6Init,
                dim16718JoeKuoD6Init,
                dim16719JoeKuoD6Init,
                dim16720JoeKuoD6Init,
                dim16721JoeKuoD6Init,
                dim16722JoeKuoD6Init,
                dim16723JoeKuoD6Init,
                dim16724JoeKuoD6Init,
                dim16725JoeKuoD6Init,
                dim16726JoeKuoD6Init,
                dim16727JoeKuoD6Init,
                dim16728JoeKuoD6Init,
                dim16729JoeKuoD6Init,
                dim16730JoeKuoD6Init,
                dim16731JoeKuoD6Init,
                dim16732JoeKuoD6Init,
                dim16733JoeKuoD6Init,
                dim16734JoeKuoD6Init,
                dim16735JoeKuoD6Init,
                dim16736JoeKuoD6Init,
                dim16737JoeKuoD6Init,
                dim16738JoeKuoD6Init,
                dim16739JoeKuoD6Init,
                dim16740JoeKuoD6Init,
                dim16741JoeKuoD6Init,
                dim16742JoeKuoD6Init,
                dim16743JoeKuoD6Init,
                dim16744JoeKuoD6Init,
                dim16745JoeKuoD6Init,
                dim16746JoeKuoD6Init,
                dim16747JoeKuoD6Init,
                dim16748JoeKuoD6Init,
                dim16749JoeKuoD6Init,
                dim16750JoeKuoD6Init,
                dim16751JoeKuoD6Init,
                dim16752JoeKuoD6Init,
                dim16753JoeKuoD6Init,
                dim16754JoeKuoD6Init,
                dim16755JoeKuoD6Init,
                dim16756JoeKuoD6Init,
                dim16757JoeKuoD6Init,
                dim16758JoeKuoD6Init,
                dim16759JoeKuoD6Init,
                dim16760JoeKuoD6Init,
                dim16761JoeKuoD6Init,
                dim16762JoeKuoD6Init,
                dim16763JoeKuoD6Init,
                dim16764JoeKuoD6Init,
                dim16765JoeKuoD6Init,
                dim16766JoeKuoD6Init,
                dim16767JoeKuoD6Init,
                dim16768JoeKuoD6Init,
                dim16769JoeKuoD6Init,
                dim16770JoeKuoD6Init,
                dim16771JoeKuoD6Init,
                dim16772JoeKuoD6Init,
                dim16773JoeKuoD6Init,
                dim16774JoeKuoD6Init,
                dim16775JoeKuoD6Init,
                dim16776JoeKuoD6Init,
                dim16777JoeKuoD6Init,
                dim16778JoeKuoD6Init,
                dim16779JoeKuoD6Init,
                dim16780JoeKuoD6Init,
                dim16781JoeKuoD6Init,
                dim16782JoeKuoD6Init,
                dim16783JoeKuoD6Init,
                dim16784JoeKuoD6Init,
                dim16785JoeKuoD6Init,
                dim16786JoeKuoD6Init,
                dim16787JoeKuoD6Init,
                dim16788JoeKuoD6Init,
                dim16789JoeKuoD6Init,
                dim16790JoeKuoD6Init,
                dim16791JoeKuoD6Init,
                dim16792JoeKuoD6Init,
                dim16793JoeKuoD6Init,
                dim16794JoeKuoD6Init,
                dim16795JoeKuoD6Init,
                dim16796JoeKuoD6Init,
                dim16797JoeKuoD6Init,
                dim16798JoeKuoD6Init,
                dim16799JoeKuoD6Init,
                dim16800JoeKuoD6Init,
                dim16801JoeKuoD6Init,
                dim16802JoeKuoD6Init,
                dim16803JoeKuoD6Init,
                dim16804JoeKuoD6Init,
                dim16805JoeKuoD6Init,
                dim16806JoeKuoD6Init,
                dim16807JoeKuoD6Init,
                dim16808JoeKuoD6Init,
                dim16809JoeKuoD6Init,
                dim16810JoeKuoD6Init,
                dim16811JoeKuoD6Init,
                dim16812JoeKuoD6Init,
                dim16813JoeKuoD6Init,
                dim16814JoeKuoD6Init,
                dim16815JoeKuoD6Init,
                dim16816JoeKuoD6Init,
                dim16817JoeKuoD6Init,
                dim16818JoeKuoD6Init,
                dim16819JoeKuoD6Init,
                dim16820JoeKuoD6Init,
                dim16821JoeKuoD6Init,
                dim16822JoeKuoD6Init,
                dim16823JoeKuoD6Init,
                dim16824JoeKuoD6Init,
                dim16825JoeKuoD6Init,
                dim16826JoeKuoD6Init,
                dim16827JoeKuoD6Init,
                dim16828JoeKuoD6Init,
                dim16829JoeKuoD6Init,
                dim16830JoeKuoD6Init,
                dim16831JoeKuoD6Init,
                dim16832JoeKuoD6Init,
                dim16833JoeKuoD6Init,
                dim16834JoeKuoD6Init,
                dim16835JoeKuoD6Init,
                dim16836JoeKuoD6Init,
                dim16837JoeKuoD6Init,
                dim16838JoeKuoD6Init,
                dim16839JoeKuoD6Init,
                dim16840JoeKuoD6Init,
                dim16841JoeKuoD6Init,
                dim16842JoeKuoD6Init,
                dim16843JoeKuoD6Init,
                dim16844JoeKuoD6Init,
                dim16845JoeKuoD6Init,
                dim16846JoeKuoD6Init,
                dim16847JoeKuoD6Init,
                dim16848JoeKuoD6Init,
                dim16849JoeKuoD6Init,
                dim16850JoeKuoD6Init,
                dim16851JoeKuoD6Init,
                dim16852JoeKuoD6Init,
                dim16853JoeKuoD6Init,
                dim16854JoeKuoD6Init,
                dim16855JoeKuoD6Init,
                dim16856JoeKuoD6Init,
                dim16857JoeKuoD6Init,
                dim16858JoeKuoD6Init,
                dim16859JoeKuoD6Init,
                dim16860JoeKuoD6Init,
                dim16861JoeKuoD6Init,
                dim16862JoeKuoD6Init,
                dim16863JoeKuoD6Init,
                dim16864JoeKuoD6Init,
                dim16865JoeKuoD6Init,
                dim16866JoeKuoD6Init,
                dim16867JoeKuoD6Init,
                dim16868JoeKuoD6Init,
                dim16869JoeKuoD6Init,
                dim16870JoeKuoD6Init,
                dim16871JoeKuoD6Init,
                dim16872JoeKuoD6Init,
                dim16873JoeKuoD6Init,
                dim16874JoeKuoD6Init,
                dim16875JoeKuoD6Init,
                dim16876JoeKuoD6Init,
                dim16877JoeKuoD6Init,
                dim16878JoeKuoD6Init,
                dim16879JoeKuoD6Init,
                dim16880JoeKuoD6Init,
                dim16881JoeKuoD6Init,
                dim16882JoeKuoD6Init,
                dim16883JoeKuoD6Init,
                dim16884JoeKuoD6Init,
                dim16885JoeKuoD6Init,
                dim16886JoeKuoD6Init,
                dim16887JoeKuoD6Init,
                dim16888JoeKuoD6Init,
                dim16889JoeKuoD6Init,
                dim16890JoeKuoD6Init,
                dim16891JoeKuoD6Init,
                dim16892JoeKuoD6Init,
                dim16893JoeKuoD6Init,
                dim16894JoeKuoD6Init,
                dim16895JoeKuoD6Init,
                dim16896JoeKuoD6Init,
                dim16897JoeKuoD6Init,
                dim16898JoeKuoD6Init,
                dim16899JoeKuoD6Init,
                dim16900JoeKuoD6Init,
                dim16901JoeKuoD6Init,
                dim16902JoeKuoD6Init,
                dim16903JoeKuoD6Init,
                dim16904JoeKuoD6Init,
                dim16905JoeKuoD6Init,
                dim16906JoeKuoD6Init,
                dim16907JoeKuoD6Init,
                dim16908JoeKuoD6Init,
                dim16909JoeKuoD6Init,
                dim16910JoeKuoD6Init,
                dim16911JoeKuoD6Init,
                dim16912JoeKuoD6Init,
                dim16913JoeKuoD6Init,
                dim16914JoeKuoD6Init,
                dim16915JoeKuoD6Init,
                dim16916JoeKuoD6Init,
                dim16917JoeKuoD6Init,
                dim16918JoeKuoD6Init,
                dim16919JoeKuoD6Init,
                dim16920JoeKuoD6Init,
                dim16921JoeKuoD6Init,
                dim16922JoeKuoD6Init,
                dim16923JoeKuoD6Init,
                dim16924JoeKuoD6Init,
                dim16925JoeKuoD6Init,
                dim16926JoeKuoD6Init,
                dim16927JoeKuoD6Init,
                dim16928JoeKuoD6Init,
                dim16929JoeKuoD6Init,
                dim16930JoeKuoD6Init,
                dim16931JoeKuoD6Init,
                dim16932JoeKuoD6Init,
                dim16933JoeKuoD6Init,
                dim16934JoeKuoD6Init,
                dim16935JoeKuoD6Init,
                dim16936JoeKuoD6Init,
                dim16937JoeKuoD6Init,
                dim16938JoeKuoD6Init,
                dim16939JoeKuoD6Init,
                dim16940JoeKuoD6Init,
                dim16941JoeKuoD6Init,
                dim16942JoeKuoD6Init,
                dim16943JoeKuoD6Init,
                dim16944JoeKuoD6Init,
                dim16945JoeKuoD6Init,
                dim16946JoeKuoD6Init,
                dim16947JoeKuoD6Init,
                dim16948JoeKuoD6Init,
                dim16949JoeKuoD6Init,
                dim16950JoeKuoD6Init,
                dim16951JoeKuoD6Init,
                dim16952JoeKuoD6Init,
                dim16953JoeKuoD6Init,
                dim16954JoeKuoD6Init,
                dim16955JoeKuoD6Init,
                dim16956JoeKuoD6Init,
                dim16957JoeKuoD6Init,
                dim16958JoeKuoD6Init,
                dim16959JoeKuoD6Init,
                dim16960JoeKuoD6Init,
                dim16961JoeKuoD6Init,
                dim16962JoeKuoD6Init,
                dim16963JoeKuoD6Init,
                dim16964JoeKuoD6Init,
                dim16965JoeKuoD6Init,
                dim16966JoeKuoD6Init,
                dim16967JoeKuoD6Init,
                dim16968JoeKuoD6Init,
                dim16969JoeKuoD6Init,
                dim16970JoeKuoD6Init,
                dim16971JoeKuoD6Init,
                dim16972JoeKuoD6Init,
                dim16973JoeKuoD6Init,
                dim16974JoeKuoD6Init,
                dim16975JoeKuoD6Init,
                dim16976JoeKuoD6Init,
                dim16977JoeKuoD6Init,
                dim16978JoeKuoD6Init,
                dim16979JoeKuoD6Init,
                dim16980JoeKuoD6Init,
                dim16981JoeKuoD6Init,
                dim16982JoeKuoD6Init,
                dim16983JoeKuoD6Init,
                dim16984JoeKuoD6Init,
                dim16985JoeKuoD6Init,
                dim16986JoeKuoD6Init,
                dim16987JoeKuoD6Init,
                dim16988JoeKuoD6Init,
                dim16989JoeKuoD6Init,
                dim16990JoeKuoD6Init,
                dim16991JoeKuoD6Init,
                dim16992JoeKuoD6Init,
                dim16993JoeKuoD6Init,
                dim16994JoeKuoD6Init,
                dim16995JoeKuoD6Init,
                dim16996JoeKuoD6Init,
                dim16997JoeKuoD6Init,
                dim16998JoeKuoD6Init,
                dim16999JoeKuoD6Init,
                dim17000JoeKuoD6Init,
                dim17001JoeKuoD6Init,
                dim17002JoeKuoD6Init,
                dim17003JoeKuoD6Init,
                dim17004JoeKuoD6Init,
                dim17005JoeKuoD6Init,
                dim17006JoeKuoD6Init,
                dim17007JoeKuoD6Init,
                dim17008JoeKuoD6Init,
                dim17009JoeKuoD6Init,
                dim17010JoeKuoD6Init,
                dim17011JoeKuoD6Init,
                dim17012JoeKuoD6Init,
                dim17013JoeKuoD6Init,
                dim17014JoeKuoD6Init,
                dim17015JoeKuoD6Init,
                dim17016JoeKuoD6Init,
                dim17017JoeKuoD6Init,
                dim17018JoeKuoD6Init,
                dim17019JoeKuoD6Init,
                dim17020JoeKuoD6Init,
                dim17021JoeKuoD6Init,
                dim17022JoeKuoD6Init,
                dim17023JoeKuoD6Init,
                dim17024JoeKuoD6Init,
                dim17025JoeKuoD6Init,
                dim17026JoeKuoD6Init,
                dim17027JoeKuoD6Init,
                dim17028JoeKuoD6Init,
                dim17029JoeKuoD6Init,
                dim17030JoeKuoD6Init,
                dim17031JoeKuoD6Init,
                dim17032JoeKuoD6Init,
                dim17033JoeKuoD6Init,
                dim17034JoeKuoD6Init,
                dim17035JoeKuoD6Init,
                dim17036JoeKuoD6Init,
                dim17037JoeKuoD6Init,
                dim17038JoeKuoD6Init,
                dim17039JoeKuoD6Init,
                dim17040JoeKuoD6Init,
                dim17041JoeKuoD6Init,
                dim17042JoeKuoD6Init,
                dim17043JoeKuoD6Init,
                dim17044JoeKuoD6Init,
                dim17045JoeKuoD6Init,
                dim17046JoeKuoD6Init,
                dim17047JoeKuoD6Init,
                dim17048JoeKuoD6Init,
                dim17049JoeKuoD6Init,
                dim17050JoeKuoD6Init,
                dim17051JoeKuoD6Init,
                dim17052JoeKuoD6Init,
                dim17053JoeKuoD6Init,
                dim17054JoeKuoD6Init,
                dim17055JoeKuoD6Init,
                dim17056JoeKuoD6Init,
                dim17057JoeKuoD6Init,
                dim17058JoeKuoD6Init,
                dim17059JoeKuoD6Init,
                dim17060JoeKuoD6Init,
                dim17061JoeKuoD6Init,
                dim17062JoeKuoD6Init,
                dim17063JoeKuoD6Init,
                dim17064JoeKuoD6Init,
                dim17065JoeKuoD6Init,
                dim17066JoeKuoD6Init,
                dim17067JoeKuoD6Init,
                dim17068JoeKuoD6Init,
                dim17069JoeKuoD6Init,
                dim17070JoeKuoD6Init,
                dim17071JoeKuoD6Init,
                dim17072JoeKuoD6Init,
                dim17073JoeKuoD6Init,
                dim17074JoeKuoD6Init,
                dim17075JoeKuoD6Init,
                dim17076JoeKuoD6Init,
                dim17077JoeKuoD6Init,
                dim17078JoeKuoD6Init,
                dim17079JoeKuoD6Init,
                dim17080JoeKuoD6Init,
                dim17081JoeKuoD6Init,
                dim17082JoeKuoD6Init,
                dim17083JoeKuoD6Init,
                dim17084JoeKuoD6Init,
                dim17085JoeKuoD6Init,
                dim17086JoeKuoD6Init,
                dim17087JoeKuoD6Init,
                dim17088JoeKuoD6Init,
                dim17089JoeKuoD6Init,
                dim17090JoeKuoD6Init,
                dim17091JoeKuoD6Init,
                dim17092JoeKuoD6Init,
                dim17093JoeKuoD6Init,
                dim17094JoeKuoD6Init,
                dim17095JoeKuoD6Init,
                dim17096JoeKuoD6Init,
                dim17097JoeKuoD6Init,
                dim17098JoeKuoD6Init,
                dim17099JoeKuoD6Init,
                dim17100JoeKuoD6Init,
                dim17101JoeKuoD6Init,
                dim17102JoeKuoD6Init,
                dim17103JoeKuoD6Init,
                dim17104JoeKuoD6Init,
                dim17105JoeKuoD6Init,
                dim17106JoeKuoD6Init,
                dim17107JoeKuoD6Init,
                dim17108JoeKuoD6Init,
                dim17109JoeKuoD6Init,
                dim17110JoeKuoD6Init,
                dim17111JoeKuoD6Init,
                dim17112JoeKuoD6Init,
                dim17113JoeKuoD6Init,
                dim17114JoeKuoD6Init,
                dim17115JoeKuoD6Init,
                dim17116JoeKuoD6Init,
                dim17117JoeKuoD6Init,
                dim17118JoeKuoD6Init,
                dim17119JoeKuoD6Init,
                dim17120JoeKuoD6Init,
                dim17121JoeKuoD6Init,
                dim17122JoeKuoD6Init,
                dim17123JoeKuoD6Init,
                dim17124JoeKuoD6Init,
                dim17125JoeKuoD6Init,
                dim17126JoeKuoD6Init,
                dim17127JoeKuoD6Init,
                dim17128JoeKuoD6Init,
                dim17129JoeKuoD6Init,
                dim17130JoeKuoD6Init,
                dim17131JoeKuoD6Init,
                dim17132JoeKuoD6Init,
                dim17133JoeKuoD6Init,
                dim17134JoeKuoD6Init,
                dim17135JoeKuoD6Init,
                dim17136JoeKuoD6Init,
                dim17137JoeKuoD6Init,
                dim17138JoeKuoD6Init,
                dim17139JoeKuoD6Init,
                dim17140JoeKuoD6Init,
                dim17141JoeKuoD6Init,
                dim17142JoeKuoD6Init,
                dim17143JoeKuoD6Init,
                dim17144JoeKuoD6Init,
                dim17145JoeKuoD6Init,
                dim17146JoeKuoD6Init,
                dim17147JoeKuoD6Init,
                dim17148JoeKuoD6Init,
                dim17149JoeKuoD6Init,
                dim17150JoeKuoD6Init,
                dim17151JoeKuoD6Init,
                dim17152JoeKuoD6Init,
                dim17153JoeKuoD6Init,
                dim17154JoeKuoD6Init,
                dim17155JoeKuoD6Init,
                dim17156JoeKuoD6Init,
                dim17157JoeKuoD6Init,
                dim17158JoeKuoD6Init,
                dim17159JoeKuoD6Init,
                dim17160JoeKuoD6Init,
                dim17161JoeKuoD6Init,
                dim17162JoeKuoD6Init,
                dim17163JoeKuoD6Init,
                dim17164JoeKuoD6Init,
                dim17165JoeKuoD6Init,
                dim17166JoeKuoD6Init,
                dim17167JoeKuoD6Init,
                dim17168JoeKuoD6Init,
                dim17169JoeKuoD6Init,
                dim17170JoeKuoD6Init,
                dim17171JoeKuoD6Init,
                dim17172JoeKuoD6Init,
                dim17173JoeKuoD6Init,
                dim17174JoeKuoD6Init,
                dim17175JoeKuoD6Init,
                dim17176JoeKuoD6Init,
                dim17177JoeKuoD6Init,
                dim17178JoeKuoD6Init,
                dim17179JoeKuoD6Init,
                dim17180JoeKuoD6Init,
                dim17181JoeKuoD6Init,
                dim17182JoeKuoD6Init,
                dim17183JoeKuoD6Init,
                dim17184JoeKuoD6Init,
                dim17185JoeKuoD6Init,
                dim17186JoeKuoD6Init,
                dim17187JoeKuoD6Init,
                dim17188JoeKuoD6Init,
                dim17189JoeKuoD6Init,
                dim17190JoeKuoD6Init,
                dim17191JoeKuoD6Init,
                dim17192JoeKuoD6Init,
                dim17193JoeKuoD6Init,
                dim17194JoeKuoD6Init,
                dim17195JoeKuoD6Init,
                dim17196JoeKuoD6Init,
                dim17197JoeKuoD6Init,
                dim17198JoeKuoD6Init,
                dim17199JoeKuoD6Init,
                dim17200JoeKuoD6Init,
                dim17201JoeKuoD6Init,
                dim17202JoeKuoD6Init,
                dim17203JoeKuoD6Init,
                dim17204JoeKuoD6Init,
                dim17205JoeKuoD6Init,
                dim17206JoeKuoD6Init,
                dim17207JoeKuoD6Init,
                dim17208JoeKuoD6Init,
                dim17209JoeKuoD6Init,
                dim17210JoeKuoD6Init,
                dim17211JoeKuoD6Init,
                dim17212JoeKuoD6Init,
                dim17213JoeKuoD6Init,
                dim17214JoeKuoD6Init,
                dim17215JoeKuoD6Init,
                dim17216JoeKuoD6Init,
                dim17217JoeKuoD6Init,
                dim17218JoeKuoD6Init,
                dim17219JoeKuoD6Init,
                dim17220JoeKuoD6Init,
                dim17221JoeKuoD6Init,
                dim17222JoeKuoD6Init,
                dim17223JoeKuoD6Init,
                dim17224JoeKuoD6Init,
                dim17225JoeKuoD6Init,
                dim17226JoeKuoD6Init,
                dim17227JoeKuoD6Init,
                dim17228JoeKuoD6Init,
                dim17229JoeKuoD6Init,
                dim17230JoeKuoD6Init,
                dim17231JoeKuoD6Init,
                dim17232JoeKuoD6Init,
                dim17233JoeKuoD6Init,
                dim17234JoeKuoD6Init,
                dim17235JoeKuoD6Init,
                dim17236JoeKuoD6Init,
                dim17237JoeKuoD6Init,
                dim17238JoeKuoD6Init,
                dim17239JoeKuoD6Init,
                dim17240JoeKuoD6Init,
                dim17241JoeKuoD6Init,
                dim17242JoeKuoD6Init,
                dim17243JoeKuoD6Init,
                dim17244JoeKuoD6Init,
                dim17245JoeKuoD6Init,
                dim17246JoeKuoD6Init,
                dim17247JoeKuoD6Init,
                dim17248JoeKuoD6Init,
                dim17249JoeKuoD6Init,
                dim17250JoeKuoD6Init,
                dim17251JoeKuoD6Init,
                dim17252JoeKuoD6Init,
                dim17253JoeKuoD6Init,
                dim17254JoeKuoD6Init,
                dim17255JoeKuoD6Init,
                dim17256JoeKuoD6Init,
                dim17257JoeKuoD6Init,
                dim17258JoeKuoD6Init,
                dim17259JoeKuoD6Init,
                dim17260JoeKuoD6Init,
                dim17261JoeKuoD6Init,
                dim17262JoeKuoD6Init,
                dim17263JoeKuoD6Init,
                dim17264JoeKuoD6Init,
                dim17265JoeKuoD6Init,
                dim17266JoeKuoD6Init,
                dim17267JoeKuoD6Init,
                dim17268JoeKuoD6Init,
                dim17269JoeKuoD6Init,
                dim17270JoeKuoD6Init,
                dim17271JoeKuoD6Init,
                dim17272JoeKuoD6Init,
                dim17273JoeKuoD6Init,
                dim17274JoeKuoD6Init,
                dim17275JoeKuoD6Init,
                dim17276JoeKuoD6Init,
                dim17277JoeKuoD6Init,
                dim17278JoeKuoD6Init,
                dim17279JoeKuoD6Init,
                dim17280JoeKuoD6Init,
                dim17281JoeKuoD6Init,
                dim17282JoeKuoD6Init,
                dim17283JoeKuoD6Init,
                dim17284JoeKuoD6Init,
                dim17285JoeKuoD6Init,
                dim17286JoeKuoD6Init,
                dim17287JoeKuoD6Init,
                dim17288JoeKuoD6Init,
                dim17289JoeKuoD6Init,
                dim17290JoeKuoD6Init,
                dim17291JoeKuoD6Init,
                dim17292JoeKuoD6Init,
                dim17293JoeKuoD6Init,
                dim17294JoeKuoD6Init,
                dim17295JoeKuoD6Init,
                dim17296JoeKuoD6Init,
                dim17297JoeKuoD6Init,
                dim17298JoeKuoD6Init,
                dim17299JoeKuoD6Init,
                dim17300JoeKuoD6Init,
                dim17301JoeKuoD6Init,
                dim17302JoeKuoD6Init,
                dim17303JoeKuoD6Init,
                dim17304JoeKuoD6Init,
                dim17305JoeKuoD6Init,
                dim17306JoeKuoD6Init,
                dim17307JoeKuoD6Init,
                dim17308JoeKuoD6Init,
                dim17309JoeKuoD6Init,
                dim17310JoeKuoD6Init,
                dim17311JoeKuoD6Init,
                dim17312JoeKuoD6Init,
                dim17313JoeKuoD6Init,
                dim17314JoeKuoD6Init,
                dim17315JoeKuoD6Init,
                dim17316JoeKuoD6Init,
                dim17317JoeKuoD6Init,
                dim17318JoeKuoD6Init,
                dim17319JoeKuoD6Init,
                dim17320JoeKuoD6Init,
                dim17321JoeKuoD6Init,
                dim17322JoeKuoD6Init,
                dim17323JoeKuoD6Init,
                dim17324JoeKuoD6Init,
                dim17325JoeKuoD6Init,
                dim17326JoeKuoD6Init,
                dim17327JoeKuoD6Init,
                dim17328JoeKuoD6Init,
                dim17329JoeKuoD6Init,
                dim17330JoeKuoD6Init,
                dim17331JoeKuoD6Init,
                dim17332JoeKuoD6Init,
                dim17333JoeKuoD6Init,
                dim17334JoeKuoD6Init,
                dim17335JoeKuoD6Init,
                dim17336JoeKuoD6Init,
                dim17337JoeKuoD6Init,
                dim17338JoeKuoD6Init,
                dim17339JoeKuoD6Init,
                dim17340JoeKuoD6Init,
                dim17341JoeKuoD6Init,
                dim17342JoeKuoD6Init,
                dim17343JoeKuoD6Init,
                dim17344JoeKuoD6Init,
                dim17345JoeKuoD6Init,
                dim17346JoeKuoD6Init,
                dim17347JoeKuoD6Init,
                dim17348JoeKuoD6Init,
                dim17349JoeKuoD6Init,
                dim17350JoeKuoD6Init,
                dim17351JoeKuoD6Init,
                dim17352JoeKuoD6Init,
                dim17353JoeKuoD6Init,
                dim17354JoeKuoD6Init,
                dim17355JoeKuoD6Init,
                dim17356JoeKuoD6Init,
                dim17357JoeKuoD6Init,
                dim17358JoeKuoD6Init,
                dim17359JoeKuoD6Init,
                dim17360JoeKuoD6Init,
                dim17361JoeKuoD6Init,
                dim17362JoeKuoD6Init,
                dim17363JoeKuoD6Init,
                dim17364JoeKuoD6Init,
                dim17365JoeKuoD6Init,
                dim17366JoeKuoD6Init,
                dim17367JoeKuoD6Init,
                dim17368JoeKuoD6Init,
                dim17369JoeKuoD6Init,
                dim17370JoeKuoD6Init,
                dim17371JoeKuoD6Init,
                dim17372JoeKuoD6Init,
                dim17373JoeKuoD6Init,
                dim17374JoeKuoD6Init,
                dim17375JoeKuoD6Init,
                dim17376JoeKuoD6Init,
                dim17377JoeKuoD6Init,
                dim17378JoeKuoD6Init,
                dim17379JoeKuoD6Init,
                dim17380JoeKuoD6Init,
                dim17381JoeKuoD6Init,
                dim17382JoeKuoD6Init,
                dim17383JoeKuoD6Init,
                dim17384JoeKuoD6Init,
                dim17385JoeKuoD6Init,
                dim17386JoeKuoD6Init,
                dim17387JoeKuoD6Init,
                dim17388JoeKuoD6Init,
                dim17389JoeKuoD6Init,
                dim17390JoeKuoD6Init,
                dim17391JoeKuoD6Init,
                dim17392JoeKuoD6Init,
                dim17393JoeKuoD6Init,
                dim17394JoeKuoD6Init,
                dim17395JoeKuoD6Init,
                dim17396JoeKuoD6Init,
                dim17397JoeKuoD6Init,
                dim17398JoeKuoD6Init,
                dim17399JoeKuoD6Init,
                dim17400JoeKuoD6Init,
                dim17401JoeKuoD6Init,
                dim17402JoeKuoD6Init,
                dim17403JoeKuoD6Init,
                dim17404JoeKuoD6Init,
                dim17405JoeKuoD6Init,
                dim17406JoeKuoD6Init,
                dim17407JoeKuoD6Init,
                dim17408JoeKuoD6Init,
                dim17409JoeKuoD6Init,
                dim17410JoeKuoD6Init,
                dim17411JoeKuoD6Init,
                dim17412JoeKuoD6Init,
                dim17413JoeKuoD6Init,
                dim17414JoeKuoD6Init,
                dim17415JoeKuoD6Init,
                dim17416JoeKuoD6Init,
                dim17417JoeKuoD6Init,
                dim17418JoeKuoD6Init,
                dim17419JoeKuoD6Init,
                dim17420JoeKuoD6Init,
                dim17421JoeKuoD6Init,
                dim17422JoeKuoD6Init,
                dim17423JoeKuoD6Init,
                dim17424JoeKuoD6Init,
                dim17425JoeKuoD6Init,
                dim17426JoeKuoD6Init,
                dim17427JoeKuoD6Init,
                dim17428JoeKuoD6Init,
                dim17429JoeKuoD6Init,
                dim17430JoeKuoD6Init,
                dim17431JoeKuoD6Init,
                dim17432JoeKuoD6Init,
                dim17433JoeKuoD6Init,
                dim17434JoeKuoD6Init,
                dim17435JoeKuoD6Init,
                dim17436JoeKuoD6Init,
                dim17437JoeKuoD6Init,
                dim17438JoeKuoD6Init,
                dim17439JoeKuoD6Init,
                dim17440JoeKuoD6Init,
                dim17441JoeKuoD6Init,
                dim17442JoeKuoD6Init,
                dim17443JoeKuoD6Init,
                dim17444JoeKuoD6Init,
                dim17445JoeKuoD6Init,
                dim17446JoeKuoD6Init,
                dim17447JoeKuoD6Init,
                dim17448JoeKuoD6Init,
                dim17449JoeKuoD6Init,
                dim17450JoeKuoD6Init,
                dim17451JoeKuoD6Init,
                dim17452JoeKuoD6Init,
                dim17453JoeKuoD6Init,
                dim17454JoeKuoD6Init,
                dim17455JoeKuoD6Init,
                dim17456JoeKuoD6Init,
                dim17457JoeKuoD6Init,
                dim17458JoeKuoD6Init,
                dim17459JoeKuoD6Init,
                dim17460JoeKuoD6Init,
                dim17461JoeKuoD6Init,
                dim17462JoeKuoD6Init,
                dim17463JoeKuoD6Init,
                dim17464JoeKuoD6Init,
                dim17465JoeKuoD6Init,
                dim17466JoeKuoD6Init,
                dim17467JoeKuoD6Init,
                dim17468JoeKuoD6Init,
                dim17469JoeKuoD6Init,
                dim17470JoeKuoD6Init,
                dim17471JoeKuoD6Init,
                dim17472JoeKuoD6Init,
                dim17473JoeKuoD6Init,
                dim17474JoeKuoD6Init,
                dim17475JoeKuoD6Init,
                dim17476JoeKuoD6Init,
                dim17477JoeKuoD6Init,
                dim17478JoeKuoD6Init,
                dim17479JoeKuoD6Init,
                dim17480JoeKuoD6Init,
                dim17481JoeKuoD6Init,
                dim17482JoeKuoD6Init,
                dim17483JoeKuoD6Init,
                dim17484JoeKuoD6Init,
                dim17485JoeKuoD6Init,
                dim17486JoeKuoD6Init,
                dim17487JoeKuoD6Init,
                dim17488JoeKuoD6Init,
                dim17489JoeKuoD6Init,
                dim17490JoeKuoD6Init,
                dim17491JoeKuoD6Init,
                dim17492JoeKuoD6Init,
                dim17493JoeKuoD6Init,
                dim17494JoeKuoD6Init,
                dim17495JoeKuoD6Init,
                dim17496JoeKuoD6Init,
                dim17497JoeKuoD6Init,
                dim17498JoeKuoD6Init,
                dim17499JoeKuoD6Init,
                dim17500JoeKuoD6Init,
                dim17501JoeKuoD6Init,
                dim17502JoeKuoD6Init,
                dim17503JoeKuoD6Init,
                dim17504JoeKuoD6Init,
                dim17505JoeKuoD6Init,
                dim17506JoeKuoD6Init,
                dim17507JoeKuoD6Init,
                dim17508JoeKuoD6Init,
                dim17509JoeKuoD6Init,
                dim17510JoeKuoD6Init,
                dim17511JoeKuoD6Init,
                dim17512JoeKuoD6Init,
                dim17513JoeKuoD6Init,
                dim17514JoeKuoD6Init,
                dim17515JoeKuoD6Init,
                dim17516JoeKuoD6Init,
                dim17517JoeKuoD6Init,
                dim17518JoeKuoD6Init,
                dim17519JoeKuoD6Init,
                dim17520JoeKuoD6Init,
                dim17521JoeKuoD6Init,
                dim17522JoeKuoD6Init,
                dim17523JoeKuoD6Init,
                dim17524JoeKuoD6Init,
                dim17525JoeKuoD6Init,
                dim17526JoeKuoD6Init,
                dim17527JoeKuoD6Init,
                dim17528JoeKuoD6Init,
                dim17529JoeKuoD6Init,
                dim17530JoeKuoD6Init,
                dim17531JoeKuoD6Init,
                dim17532JoeKuoD6Init,
                dim17533JoeKuoD6Init,
                dim17534JoeKuoD6Init,
                dim17535JoeKuoD6Init,
                dim17536JoeKuoD6Init,
                dim17537JoeKuoD6Init,
                dim17538JoeKuoD6Init,
                dim17539JoeKuoD6Init,
                dim17540JoeKuoD6Init,
                dim17541JoeKuoD6Init,
                dim17542JoeKuoD6Init,
                dim17543JoeKuoD6Init,
                dim17544JoeKuoD6Init,
                dim17545JoeKuoD6Init,
                dim17546JoeKuoD6Init,
                dim17547JoeKuoD6Init,
                dim17548JoeKuoD6Init,
                dim17549JoeKuoD6Init,
                dim17550JoeKuoD6Init,
                dim17551JoeKuoD6Init,
                dim17552JoeKuoD6Init,
                dim17553JoeKuoD6Init,
                dim17554JoeKuoD6Init,
                dim17555JoeKuoD6Init,
                dim17556JoeKuoD6Init,
                dim17557JoeKuoD6Init,
                dim17558JoeKuoD6Init,
                dim17559JoeKuoD6Init,
                dim17560JoeKuoD6Init,
                dim17561JoeKuoD6Init,
                dim17562JoeKuoD6Init,
                dim17563JoeKuoD6Init,
                dim17564JoeKuoD6Init,
                dim17565JoeKuoD6Init,
                dim17566JoeKuoD6Init,
                dim17567JoeKuoD6Init,
                dim17568JoeKuoD6Init,
                dim17569JoeKuoD6Init,
                dim17570JoeKuoD6Init,
                dim17571JoeKuoD6Init,
                dim17572JoeKuoD6Init,
                dim17573JoeKuoD6Init,
                dim17574JoeKuoD6Init,
                dim17575JoeKuoD6Init,
                dim17576JoeKuoD6Init,
                dim17577JoeKuoD6Init,
                dim17578JoeKuoD6Init,
                dim17579JoeKuoD6Init,
                dim17580JoeKuoD6Init,
                dim17581JoeKuoD6Init,
                dim17582JoeKuoD6Init,
                dim17583JoeKuoD6Init,
                dim17584JoeKuoD6Init,
                dim17585JoeKuoD6Init,
                dim17586JoeKuoD6Init,
                dim17587JoeKuoD6Init,
                dim17588JoeKuoD6Init,
                dim17589JoeKuoD6Init,
                dim17590JoeKuoD6Init,
                dim17591JoeKuoD6Init,
                dim17592JoeKuoD6Init,
                dim17593JoeKuoD6Init,
                dim17594JoeKuoD6Init,
                dim17595JoeKuoD6Init,
                dim17596JoeKuoD6Init,
                dim17597JoeKuoD6Init,
                dim17598JoeKuoD6Init,
                dim17599JoeKuoD6Init,
                dim17600JoeKuoD6Init,
                dim17601JoeKuoD6Init,
                dim17602JoeKuoD6Init,
                dim17603JoeKuoD6Init,
                dim17604JoeKuoD6Init,
                dim17605JoeKuoD6Init,
                dim17606JoeKuoD6Init,
                dim17607JoeKuoD6Init,
                dim17608JoeKuoD6Init,
                dim17609JoeKuoD6Init,
                dim17610JoeKuoD6Init,
                dim17611JoeKuoD6Init,
                dim17612JoeKuoD6Init,
                dim17613JoeKuoD6Init,
                dim17614JoeKuoD6Init,
                dim17615JoeKuoD6Init,
                dim17616JoeKuoD6Init,
                dim17617JoeKuoD6Init,
                dim17618JoeKuoD6Init,
                dim17619JoeKuoD6Init,
                dim17620JoeKuoD6Init,
                dim17621JoeKuoD6Init,
                dim17622JoeKuoD6Init,
                dim17623JoeKuoD6Init,
                dim17624JoeKuoD6Init,
                dim17625JoeKuoD6Init,
                dim17626JoeKuoD6Init,
                dim17627JoeKuoD6Init,
                dim17628JoeKuoD6Init,
                dim17629JoeKuoD6Init,
                dim17630JoeKuoD6Init,
                dim17631JoeKuoD6Init,
                dim17632JoeKuoD6Init,
                dim17633JoeKuoD6Init,
                dim17634JoeKuoD6Init,
                dim17635JoeKuoD6Init,
                dim17636JoeKuoD6Init,
                dim17637JoeKuoD6Init,
                dim17638JoeKuoD6Init,
                dim17639JoeKuoD6Init,
                dim17640JoeKuoD6Init,
                dim17641JoeKuoD6Init,
                dim17642JoeKuoD6Init,
                dim17643JoeKuoD6Init,
                dim17644JoeKuoD6Init,
                dim17645JoeKuoD6Init,
                dim17646JoeKuoD6Init,
                dim17647JoeKuoD6Init,
                dim17648JoeKuoD6Init,
                dim17649JoeKuoD6Init,
                dim17650JoeKuoD6Init,
                dim17651JoeKuoD6Init,
                dim17652JoeKuoD6Init,
                dim17653JoeKuoD6Init,
                dim17654JoeKuoD6Init,
                dim17655JoeKuoD6Init,
                dim17656JoeKuoD6Init,
                dim17657JoeKuoD6Init,
                dim17658JoeKuoD6Init,
                dim17659JoeKuoD6Init,
                dim17660JoeKuoD6Init,
                dim17661JoeKuoD6Init,
                dim17662JoeKuoD6Init,
                dim17663JoeKuoD6Init,
                dim17664JoeKuoD6Init,
                dim17665JoeKuoD6Init,
                dim17666JoeKuoD6Init,
                dim17667JoeKuoD6Init,
                dim17668JoeKuoD6Init,
                dim17669JoeKuoD6Init,
                dim17670JoeKuoD6Init,
                dim17671JoeKuoD6Init,
                dim17672JoeKuoD6Init,
                dim17673JoeKuoD6Init,
                dim17674JoeKuoD6Init,
                dim17675JoeKuoD6Init,
                dim17676JoeKuoD6Init,
                dim17677JoeKuoD6Init,
                dim17678JoeKuoD6Init,
                dim17679JoeKuoD6Init,
                dim17680JoeKuoD6Init,
                dim17681JoeKuoD6Init,
                dim17682JoeKuoD6Init,
                dim17683JoeKuoD6Init,
                dim17684JoeKuoD6Init,
                dim17685JoeKuoD6Init,
                dim17686JoeKuoD6Init,
                dim17687JoeKuoD6Init,
                dim17688JoeKuoD6Init,
                dim17689JoeKuoD6Init,
                dim17690JoeKuoD6Init,
                dim17691JoeKuoD6Init,
                dim17692JoeKuoD6Init,
                dim17693JoeKuoD6Init,
                dim17694JoeKuoD6Init,
                dim17695JoeKuoD6Init,
                dim17696JoeKuoD6Init,
                dim17697JoeKuoD6Init,
                dim17698JoeKuoD6Init,
                dim17699JoeKuoD6Init,
                dim17700JoeKuoD6Init,
                dim17701JoeKuoD6Init,
                dim17702JoeKuoD6Init,
                dim17703JoeKuoD6Init,
                dim17704JoeKuoD6Init,
                dim17705JoeKuoD6Init,
                dim17706JoeKuoD6Init,
                dim17707JoeKuoD6Init,
                dim17708JoeKuoD6Init,
                dim17709JoeKuoD6Init,
                dim17710JoeKuoD6Init,
                dim17711JoeKuoD6Init,
                dim17712JoeKuoD6Init,
                dim17713JoeKuoD6Init,
                dim17714JoeKuoD6Init,
                dim17715JoeKuoD6Init,
                dim17716JoeKuoD6Init,
                dim17717JoeKuoD6Init,
                dim17718JoeKuoD6Init,
                dim17719JoeKuoD6Init,
                dim17720JoeKuoD6Init,
                dim17721JoeKuoD6Init,
                dim17722JoeKuoD6Init,
                dim17723JoeKuoD6Init,
                dim17724JoeKuoD6Init,
                dim17725JoeKuoD6Init,
                dim17726JoeKuoD6Init,
                dim17727JoeKuoD6Init,
                dim17728JoeKuoD6Init,
                dim17729JoeKuoD6Init,
                dim17730JoeKuoD6Init,
                dim17731JoeKuoD6Init,
                dim17732JoeKuoD6Init,
                dim17733JoeKuoD6Init,
                dim17734JoeKuoD6Init,
                dim17735JoeKuoD6Init,
                dim17736JoeKuoD6Init,
                dim17737JoeKuoD6Init,
                dim17738JoeKuoD6Init,
                dim17739JoeKuoD6Init,
                dim17740JoeKuoD6Init,
                dim17741JoeKuoD6Init,
                dim17742JoeKuoD6Init,
                dim17743JoeKuoD6Init,
                dim17744JoeKuoD6Init,
                dim17745JoeKuoD6Init,
                dim17746JoeKuoD6Init,
                dim17747JoeKuoD6Init,
                dim17748JoeKuoD6Init,
                dim17749JoeKuoD6Init,
                dim17750JoeKuoD6Init,
                dim17751JoeKuoD6Init,
                dim17752JoeKuoD6Init,
                dim17753JoeKuoD6Init,
                dim17754JoeKuoD6Init,
                dim17755JoeKuoD6Init,
                dim17756JoeKuoD6Init,
                dim17757JoeKuoD6Init,
                dim17758JoeKuoD6Init,
                dim17759JoeKuoD6Init,
                dim17760JoeKuoD6Init,
                dim17761JoeKuoD6Init,
                dim17762JoeKuoD6Init,
                dim17763JoeKuoD6Init,
                dim17764JoeKuoD6Init,
                dim17765JoeKuoD6Init,
                dim17766JoeKuoD6Init,
                dim17767JoeKuoD6Init,
                dim17768JoeKuoD6Init,
                dim17769JoeKuoD6Init,
                dim17770JoeKuoD6Init,
                dim17771JoeKuoD6Init,
                dim17772JoeKuoD6Init,
                dim17773JoeKuoD6Init,
                dim17774JoeKuoD6Init,
                dim17775JoeKuoD6Init,
                dim17776JoeKuoD6Init,
                dim17777JoeKuoD6Init,
                dim17778JoeKuoD6Init,
                dim17779JoeKuoD6Init,
                dim17780JoeKuoD6Init,
                dim17781JoeKuoD6Init,
                dim17782JoeKuoD6Init,
                dim17783JoeKuoD6Init,
                dim17784JoeKuoD6Init,
                dim17785JoeKuoD6Init,
                dim17786JoeKuoD6Init,
                dim17787JoeKuoD6Init,
                dim17788JoeKuoD6Init,
                dim17789JoeKuoD6Init,
                dim17790JoeKuoD6Init,
                dim17791JoeKuoD6Init,
                dim17792JoeKuoD6Init,
                dim17793JoeKuoD6Init,
                dim17794JoeKuoD6Init,
                dim17795JoeKuoD6Init,
                dim17796JoeKuoD6Init,
                dim17797JoeKuoD6Init,
                dim17798JoeKuoD6Init,
                dim17799JoeKuoD6Init,
                dim17800JoeKuoD6Init,
                dim17801JoeKuoD6Init,
                dim17802JoeKuoD6Init,
                dim17803JoeKuoD6Init,
                dim17804JoeKuoD6Init,
                dim17805JoeKuoD6Init,
                dim17806JoeKuoD6Init,
                dim17807JoeKuoD6Init,
                dim17808JoeKuoD6Init,
                dim17809JoeKuoD6Init,
                dim17810JoeKuoD6Init,
                dim17811JoeKuoD6Init,
                dim17812JoeKuoD6Init,
                dim17813JoeKuoD6Init,
                dim17814JoeKuoD6Init,
                dim17815JoeKuoD6Init,
                dim17816JoeKuoD6Init,
                dim17817JoeKuoD6Init,
                dim17818JoeKuoD6Init,
                dim17819JoeKuoD6Init,
                dim17820JoeKuoD6Init,
                dim17821JoeKuoD6Init,
                dim17822JoeKuoD6Init,
                dim17823JoeKuoD6Init,
                dim17824JoeKuoD6Init,
                dim17825JoeKuoD6Init,
                dim17826JoeKuoD6Init,
                dim17827JoeKuoD6Init,
                dim17828JoeKuoD6Init,
                dim17829JoeKuoD6Init,
                dim17830JoeKuoD6Init,
                dim17831JoeKuoD6Init,
                dim17832JoeKuoD6Init,
                dim17833JoeKuoD6Init,
                dim17834JoeKuoD6Init,
                dim17835JoeKuoD6Init,
                dim17836JoeKuoD6Init,
                dim17837JoeKuoD6Init,
                dim17838JoeKuoD6Init,
                dim17839JoeKuoD6Init,
                dim17840JoeKuoD6Init,
                dim17841JoeKuoD6Init,
                dim17842JoeKuoD6Init,
                dim17843JoeKuoD6Init,
                dim17844JoeKuoD6Init,
                dim17845JoeKuoD6Init,
                dim17846JoeKuoD6Init,
                dim17847JoeKuoD6Init,
                dim17848JoeKuoD6Init,
                dim17849JoeKuoD6Init,
                dim17850JoeKuoD6Init,
                dim17851JoeKuoD6Init,
                dim17852JoeKuoD6Init,
                dim17853JoeKuoD6Init,
                dim17854JoeKuoD6Init,
                dim17855JoeKuoD6Init,
                dim17856JoeKuoD6Init,
                dim17857JoeKuoD6Init,
                dim17858JoeKuoD6Init,
                dim17859JoeKuoD6Init,
                dim17860JoeKuoD6Init,
                dim17861JoeKuoD6Init,
                dim17862JoeKuoD6Init,
                dim17863JoeKuoD6Init,
                dim17864JoeKuoD6Init,
                dim17865JoeKuoD6Init,
                dim17866JoeKuoD6Init,
                dim17867JoeKuoD6Init,
                dim17868JoeKuoD6Init,
                dim17869JoeKuoD6Init,
                dim17870JoeKuoD6Init,
                dim17871JoeKuoD6Init,
                dim17872JoeKuoD6Init,
                dim17873JoeKuoD6Init,
                dim17874JoeKuoD6Init,
                dim17875JoeKuoD6Init,
                dim17876JoeKuoD6Init,
                dim17877JoeKuoD6Init,
                dim17878JoeKuoD6Init,
                dim17879JoeKuoD6Init,
                dim17880JoeKuoD6Init,
                dim17881JoeKuoD6Init,
                dim17882JoeKuoD6Init,
                dim17883JoeKuoD6Init,
                dim17884JoeKuoD6Init,
                dim17885JoeKuoD6Init,
                dim17886JoeKuoD6Init,
                dim17887JoeKuoD6Init,
                dim17888JoeKuoD6Init,
                dim17889JoeKuoD6Init,
                dim17890JoeKuoD6Init,
                dim17891JoeKuoD6Init,
                dim17892JoeKuoD6Init,
                dim17893JoeKuoD6Init,
                dim17894JoeKuoD6Init,
                dim17895JoeKuoD6Init,
                dim17896JoeKuoD6Init,
                dim17897JoeKuoD6Init,
                dim17898JoeKuoD6Init,
                dim17899JoeKuoD6Init,
                dim17900JoeKuoD6Init,
                dim17901JoeKuoD6Init,
                dim17902JoeKuoD6Init,
                dim17903JoeKuoD6Init,
                dim17904JoeKuoD6Init,
                dim17905JoeKuoD6Init,
                dim17906JoeKuoD6Init,
                dim17907JoeKuoD6Init,
                dim17908JoeKuoD6Init,
                dim17909JoeKuoD6Init,
                dim17910JoeKuoD6Init,
                dim17911JoeKuoD6Init,
                dim17912JoeKuoD6Init,
                dim17913JoeKuoD6Init,
                dim17914JoeKuoD6Init,
                dim17915JoeKuoD6Init,
                dim17916JoeKuoD6Init,
                dim17917JoeKuoD6Init,
                dim17918JoeKuoD6Init,
                dim17919JoeKuoD6Init,
                dim17920JoeKuoD6Init,
                dim17921JoeKuoD6Init,
                dim17922JoeKuoD6Init,
                dim17923JoeKuoD6Init,
                dim17924JoeKuoD6Init,
                dim17925JoeKuoD6Init,
                dim17926JoeKuoD6Init,
                dim17927JoeKuoD6Init,
                dim17928JoeKuoD6Init,
                dim17929JoeKuoD6Init,
                dim17930JoeKuoD6Init,
                dim17931JoeKuoD6Init,
                dim17932JoeKuoD6Init,
                dim17933JoeKuoD6Init,
                dim17934JoeKuoD6Init,
                dim17935JoeKuoD6Init,
                dim17936JoeKuoD6Init,
                dim17937JoeKuoD6Init,
                dim17938JoeKuoD6Init,
                dim17939JoeKuoD6Init,
                dim17940JoeKuoD6Init,
                dim17941JoeKuoD6Init,
                dim17942JoeKuoD6Init,
                dim17943JoeKuoD6Init,
                dim17944JoeKuoD6Init,
                dim17945JoeKuoD6Init,
                dim17946JoeKuoD6Init,
                dim17947JoeKuoD6Init,
                dim17948JoeKuoD6Init,
                dim17949JoeKuoD6Init,
                dim17950JoeKuoD6Init,
                dim17951JoeKuoD6Init,
                dim17952JoeKuoD6Init,
                dim17953JoeKuoD6Init,
                dim17954JoeKuoD6Init,
                dim17955JoeKuoD6Init,
                dim17956JoeKuoD6Init,
                dim17957JoeKuoD6Init,
                dim17958JoeKuoD6Init,
                dim17959JoeKuoD6Init,
                dim17960JoeKuoD6Init,
                dim17961JoeKuoD6Init,
                dim17962JoeKuoD6Init,
                dim17963JoeKuoD6Init,
                dim17964JoeKuoD6Init,
                dim17965JoeKuoD6Init,
                dim17966JoeKuoD6Init,
                dim17967JoeKuoD6Init,
                dim17968JoeKuoD6Init,
                dim17969JoeKuoD6Init,
                dim17970JoeKuoD6Init,
                dim17971JoeKuoD6Init,
                dim17972JoeKuoD6Init,
                dim17973JoeKuoD6Init,
                dim17974JoeKuoD6Init,
                dim17975JoeKuoD6Init,
                dim17976JoeKuoD6Init,
                dim17977JoeKuoD6Init,
                dim17978JoeKuoD6Init,
                dim17979JoeKuoD6Init,
                dim17980JoeKuoD6Init,
                dim17981JoeKuoD6Init,
                dim17982JoeKuoD6Init,
                dim17983JoeKuoD6Init,
                dim17984JoeKuoD6Init,
                dim17985JoeKuoD6Init,
                dim17986JoeKuoD6Init,
                dim17987JoeKuoD6Init,
                dim17988JoeKuoD6Init,
                dim17989JoeKuoD6Init,
                dim17990JoeKuoD6Init,
                dim17991JoeKuoD6Init,
                dim17992JoeKuoD6Init,
                dim17993JoeKuoD6Init,
                dim17994JoeKuoD6Init,
                dim17995JoeKuoD6Init,
                dim17996JoeKuoD6Init,
                dim17997JoeKuoD6Init,
                dim17998JoeKuoD6Init,
                dim17999JoeKuoD6Init,
                dim18000JoeKuoD6Init,
                dim18001JoeKuoD6Init,
                dim18002JoeKuoD6Init,
                dim18003JoeKuoD6Init,
                dim18004JoeKuoD6Init,
                dim18005JoeKuoD6Init,
                dim18006JoeKuoD6Init,
                dim18007JoeKuoD6Init,
                dim18008JoeKuoD6Init,
                dim18009JoeKuoD6Init,
                dim18010JoeKuoD6Init,
                dim18011JoeKuoD6Init,
                dim18012JoeKuoD6Init,
                dim18013JoeKuoD6Init,
                dim18014JoeKuoD6Init,
                dim18015JoeKuoD6Init,
                dim18016JoeKuoD6Init,
                dim18017JoeKuoD6Init,
                dim18018JoeKuoD6Init,
                dim18019JoeKuoD6Init,
                dim18020JoeKuoD6Init,
                dim18021JoeKuoD6Init,
                dim18022JoeKuoD6Init,
                dim18023JoeKuoD6Init,
                dim18024JoeKuoD6Init,
                dim18025JoeKuoD6Init,
                dim18026JoeKuoD6Init,
                dim18027JoeKuoD6Init,
                dim18028JoeKuoD6Init,
                dim18029JoeKuoD6Init,
                dim18030JoeKuoD6Init,
                dim18031JoeKuoD6Init,
                dim18032JoeKuoD6Init,
                dim18033JoeKuoD6Init,
                dim18034JoeKuoD6Init,
                dim18035JoeKuoD6Init,
                dim18036JoeKuoD6Init,
                dim18037JoeKuoD6Init,
                dim18038JoeKuoD6Init,
                dim18039JoeKuoD6Init,
                dim18040JoeKuoD6Init,
                dim18041JoeKuoD6Init,
                dim18042JoeKuoD6Init,
                dim18043JoeKuoD6Init,
                dim18044JoeKuoD6Init,
                dim18045JoeKuoD6Init,
                dim18046JoeKuoD6Init,
                dim18047JoeKuoD6Init,
                dim18048JoeKuoD6Init,
                dim18049JoeKuoD6Init,
                dim18050JoeKuoD6Init,
                dim18051JoeKuoD6Init,
                dim18052JoeKuoD6Init,
                dim18053JoeKuoD6Init,
                dim18054JoeKuoD6Init,
                dim18055JoeKuoD6Init,
                dim18056JoeKuoD6Init,
                dim18057JoeKuoD6Init,
                dim18058JoeKuoD6Init,
                dim18059JoeKuoD6Init,
                dim18060JoeKuoD6Init,
                dim18061JoeKuoD6Init,
                dim18062JoeKuoD6Init,
                dim18063JoeKuoD6Init,
                dim18064JoeKuoD6Init,
                dim18065JoeKuoD6Init,
                dim18066JoeKuoD6Init,
                dim18067JoeKuoD6Init,
                dim18068JoeKuoD6Init,
                dim18069JoeKuoD6Init,
                dim18070JoeKuoD6Init,
                dim18071JoeKuoD6Init,
                dim18072JoeKuoD6Init,
                dim18073JoeKuoD6Init,
                dim18074JoeKuoD6Init,
                dim18075JoeKuoD6Init,
                dim18076JoeKuoD6Init,
                dim18077JoeKuoD6Init,
                dim18078JoeKuoD6Init,
                dim18079JoeKuoD6Init,
                dim18080JoeKuoD6Init,
                dim18081JoeKuoD6Init,
                dim18082JoeKuoD6Init,
                dim18083JoeKuoD6Init,
                dim18084JoeKuoD6Init,
                dim18085JoeKuoD6Init,
                dim18086JoeKuoD6Init,
                dim18087JoeKuoD6Init,
                dim18088JoeKuoD6Init,
                dim18089JoeKuoD6Init,
                dim18090JoeKuoD6Init,
                dim18091JoeKuoD6Init,
                dim18092JoeKuoD6Init,
                dim18093JoeKuoD6Init,
                dim18094JoeKuoD6Init,
                dim18095JoeKuoD6Init,
                dim18096JoeKuoD6Init,
                dim18097JoeKuoD6Init,
                dim18098JoeKuoD6Init,
                dim18099JoeKuoD6Init,
                dim18100JoeKuoD6Init,
                dim18101JoeKuoD6Init,
                dim18102JoeKuoD6Init,
                dim18103JoeKuoD6Init,
                dim18104JoeKuoD6Init,
                dim18105JoeKuoD6Init,
                dim18106JoeKuoD6Init,
                dim18107JoeKuoD6Init,
                dim18108JoeKuoD6Init,
                dim18109JoeKuoD6Init,
                dim18110JoeKuoD6Init,
                dim18111JoeKuoD6Init,
                dim18112JoeKuoD6Init,
                dim18113JoeKuoD6Init,
                dim18114JoeKuoD6Init,
                dim18115JoeKuoD6Init,
                dim18116JoeKuoD6Init,
                dim18117JoeKuoD6Init,
                dim18118JoeKuoD6Init,
                dim18119JoeKuoD6Init,
                dim18120JoeKuoD6Init,
                dim18121JoeKuoD6Init,
                dim18122JoeKuoD6Init,
                dim18123JoeKuoD6Init,
                dim18124JoeKuoD6Init,
                dim18125JoeKuoD6Init,
                dim18126JoeKuoD6Init,
                dim18127JoeKuoD6Init,
                dim18128JoeKuoD6Init,
                dim18129JoeKuoD6Init,
                dim18130JoeKuoD6Init,
                dim18131JoeKuoD6Init,
                dim18132JoeKuoD6Init,
                dim18133JoeKuoD6Init,
                dim18134JoeKuoD6Init,
                dim18135JoeKuoD6Init,
                dim18136JoeKuoD6Init,
                dim18137JoeKuoD6Init,
                dim18138JoeKuoD6Init,
                dim18139JoeKuoD6Init,
                dim18140JoeKuoD6Init,
                dim18141JoeKuoD6Init,
                dim18142JoeKuoD6Init,
                dim18143JoeKuoD6Init,
                dim18144JoeKuoD6Init,
                dim18145JoeKuoD6Init,
                dim18146JoeKuoD6Init,
                dim18147JoeKuoD6Init,
                dim18148JoeKuoD6Init,
                dim18149JoeKuoD6Init,
                dim18150JoeKuoD6Init,
                dim18151JoeKuoD6Init,
                dim18152JoeKuoD6Init,
                dim18153JoeKuoD6Init,
                dim18154JoeKuoD6Init,
                dim18155JoeKuoD6Init,
                dim18156JoeKuoD6Init,
                dim18157JoeKuoD6Init,
                dim18158JoeKuoD6Init,
                dim18159JoeKuoD6Init,
                dim18160JoeKuoD6Init,
                dim18161JoeKuoD6Init,
                dim18162JoeKuoD6Init,
                dim18163JoeKuoD6Init,
                dim18164JoeKuoD6Init,
                dim18165JoeKuoD6Init,
                dim18166JoeKuoD6Init,
                dim18167JoeKuoD6Init,
                dim18168JoeKuoD6Init,
                dim18169JoeKuoD6Init,
                dim18170JoeKuoD6Init,
                dim18171JoeKuoD6Init,
                dim18172JoeKuoD6Init,
                dim18173JoeKuoD6Init,
                dim18174JoeKuoD6Init,
                dim18175JoeKuoD6Init,
                dim18176JoeKuoD6Init,
                dim18177JoeKuoD6Init,
                dim18178JoeKuoD6Init,
                dim18179JoeKuoD6Init,
                dim18180JoeKuoD6Init,
                dim18181JoeKuoD6Init,
                dim18182JoeKuoD6Init,
                dim18183JoeKuoD6Init,
                dim18184JoeKuoD6Init,
                dim18185JoeKuoD6Init,
                dim18186JoeKuoD6Init,
                dim18187JoeKuoD6Init,
                dim18188JoeKuoD6Init,
                dim18189JoeKuoD6Init,
                dim18190JoeKuoD6Init,
                dim18191JoeKuoD6Init,
                dim18192JoeKuoD6Init,
                dim18193JoeKuoD6Init,
                dim18194JoeKuoD6Init,
                dim18195JoeKuoD6Init,
                dim18196JoeKuoD6Init,
                dim18197JoeKuoD6Init,
                dim18198JoeKuoD6Init,
                dim18199JoeKuoD6Init,
                dim18200JoeKuoD6Init,
                dim18201JoeKuoD6Init,
                dim18202JoeKuoD6Init,
                dim18203JoeKuoD6Init,
                dim18204JoeKuoD6Init,
                dim18205JoeKuoD6Init,
                dim18206JoeKuoD6Init,
                dim18207JoeKuoD6Init,
                dim18208JoeKuoD6Init,
                dim18209JoeKuoD6Init,
                dim18210JoeKuoD6Init,
                dim18211JoeKuoD6Init,
                dim18212JoeKuoD6Init,
                dim18213JoeKuoD6Init,
                dim18214JoeKuoD6Init,
                dim18215JoeKuoD6Init,
                dim18216JoeKuoD6Init,
                dim18217JoeKuoD6Init,
                dim18218JoeKuoD6Init,
                dim18219JoeKuoD6Init,
                dim18220JoeKuoD6Init,
                dim18221JoeKuoD6Init,
                dim18222JoeKuoD6Init,
                dim18223JoeKuoD6Init,
                dim18224JoeKuoD6Init,
                dim18225JoeKuoD6Init,
                dim18226JoeKuoD6Init,
                dim18227JoeKuoD6Init,
                dim18228JoeKuoD6Init,
                dim18229JoeKuoD6Init,
                dim18230JoeKuoD6Init,
                dim18231JoeKuoD6Init,
                dim18232JoeKuoD6Init,
                dim18233JoeKuoD6Init,
                dim18234JoeKuoD6Init,
                dim18235JoeKuoD6Init,
                dim18236JoeKuoD6Init,
                dim18237JoeKuoD6Init,
                dim18238JoeKuoD6Init,
                dim18239JoeKuoD6Init,
                dim18240JoeKuoD6Init,
                dim18241JoeKuoD6Init,
                dim18242JoeKuoD6Init,
                dim18243JoeKuoD6Init,
                dim18244JoeKuoD6Init,
                dim18245JoeKuoD6Init,
                dim18246JoeKuoD6Init,
                dim18247JoeKuoD6Init,
                dim18248JoeKuoD6Init,
                dim18249JoeKuoD6Init,
                dim18250JoeKuoD6Init,
                dim18251JoeKuoD6Init,
                dim18252JoeKuoD6Init,
                dim18253JoeKuoD6Init,
                dim18254JoeKuoD6Init,
                dim18255JoeKuoD6Init,
                dim18256JoeKuoD6Init,
                dim18257JoeKuoD6Init,
                dim18258JoeKuoD6Init,
                dim18259JoeKuoD6Init,
                dim18260JoeKuoD6Init,
                dim18261JoeKuoD6Init,
                dim18262JoeKuoD6Init,
                dim18263JoeKuoD6Init,
                dim18264JoeKuoD6Init,
                dim18265JoeKuoD6Init,
                dim18266JoeKuoD6Init,
                dim18267JoeKuoD6Init,
                dim18268JoeKuoD6Init,
                dim18269JoeKuoD6Init,
                dim18270JoeKuoD6Init,
                dim18271JoeKuoD6Init,
                dim18272JoeKuoD6Init,
                dim18273JoeKuoD6Init,
                dim18274JoeKuoD6Init,
                dim18275JoeKuoD6Init,
                dim18276JoeKuoD6Init,
                dim18277JoeKuoD6Init,
                dim18278JoeKuoD6Init,
                dim18279JoeKuoD6Init,
                dim18280JoeKuoD6Init,
                dim18281JoeKuoD6Init,
                dim18282JoeKuoD6Init,
                dim18283JoeKuoD6Init,
                dim18284JoeKuoD6Init,
                dim18285JoeKuoD6Init,
                dim18286JoeKuoD6Init,
                dim18287JoeKuoD6Init,
                dim18288JoeKuoD6Init,
                dim18289JoeKuoD6Init,
                dim18290JoeKuoD6Init,
                dim18291JoeKuoD6Init,
                dim18292JoeKuoD6Init,
                dim18293JoeKuoD6Init,
                dim18294JoeKuoD6Init,
                dim18295JoeKuoD6Init,
                dim18296JoeKuoD6Init,
                dim18297JoeKuoD6Init,
                dim18298JoeKuoD6Init,
                dim18299JoeKuoD6Init,
                dim18300JoeKuoD6Init,
                dim18301JoeKuoD6Init,
                dim18302JoeKuoD6Init,
                dim18303JoeKuoD6Init,
                dim18304JoeKuoD6Init,
                dim18305JoeKuoD6Init,
                dim18306JoeKuoD6Init,
                dim18307JoeKuoD6Init,
                dim18308JoeKuoD6Init,
                dim18309JoeKuoD6Init,
                dim18310JoeKuoD6Init,
                dim18311JoeKuoD6Init,
                dim18312JoeKuoD6Init,
                dim18313JoeKuoD6Init,
                dim18314JoeKuoD6Init,
                dim18315JoeKuoD6Init,
                dim18316JoeKuoD6Init,
                dim18317JoeKuoD6Init,
                dim18318JoeKuoD6Init,
                dim18319JoeKuoD6Init,
                dim18320JoeKuoD6Init,
                dim18321JoeKuoD6Init,
                dim18322JoeKuoD6Init,
                dim18323JoeKuoD6Init,
                dim18324JoeKuoD6Init,
                dim18325JoeKuoD6Init,
                dim18326JoeKuoD6Init,
                dim18327JoeKuoD6Init,
                dim18328JoeKuoD6Init,
                dim18329JoeKuoD6Init,
                dim18330JoeKuoD6Init,
                dim18331JoeKuoD6Init,
                dim18332JoeKuoD6Init,
                dim18333JoeKuoD6Init,
                dim18334JoeKuoD6Init,
                dim18335JoeKuoD6Init,
                dim18336JoeKuoD6Init,
                dim18337JoeKuoD6Init,
                dim18338JoeKuoD6Init,
                dim18339JoeKuoD6Init,
                dim18340JoeKuoD6Init,
                dim18341JoeKuoD6Init,
                dim18342JoeKuoD6Init,
                dim18343JoeKuoD6Init,
                dim18344JoeKuoD6Init,
                dim18345JoeKuoD6Init,
                dim18346JoeKuoD6Init,
                dim18347JoeKuoD6Init,
                dim18348JoeKuoD6Init,
                dim18349JoeKuoD6Init,
                dim18350JoeKuoD6Init,
                dim18351JoeKuoD6Init,
                dim18352JoeKuoD6Init,
                dim18353JoeKuoD6Init,
                dim18354JoeKuoD6Init,
                dim18355JoeKuoD6Init,
                dim18356JoeKuoD6Init,
                dim18357JoeKuoD6Init,
                dim18358JoeKuoD6Init,
                dim18359JoeKuoD6Init,
                dim18360JoeKuoD6Init,
                dim18361JoeKuoD6Init,
                dim18362JoeKuoD6Init,
                dim18363JoeKuoD6Init,
                dim18364JoeKuoD6Init,
                dim18365JoeKuoD6Init,
                dim18366JoeKuoD6Init,
                dim18367JoeKuoD6Init,
                dim18368JoeKuoD6Init,
                dim18369JoeKuoD6Init,
                dim18370JoeKuoD6Init,
                dim18371JoeKuoD6Init,
                dim18372JoeKuoD6Init,
                dim18373JoeKuoD6Init,
                dim18374JoeKuoD6Init,
                dim18375JoeKuoD6Init,
                dim18376JoeKuoD6Init,
                dim18377JoeKuoD6Init,
                dim18378JoeKuoD6Init,
                dim18379JoeKuoD6Init,
                dim18380JoeKuoD6Init,
                dim18381JoeKuoD6Init,
                dim18382JoeKuoD6Init,
                dim18383JoeKuoD6Init,
                dim18384JoeKuoD6Init,
                dim18385JoeKuoD6Init,
                dim18386JoeKuoD6Init,
                dim18387JoeKuoD6Init,
                dim18388JoeKuoD6Init,
                dim18389JoeKuoD6Init,
                dim18390JoeKuoD6Init,
                dim18391JoeKuoD6Init,
                dim18392JoeKuoD6Init,
                dim18393JoeKuoD6Init,
                dim18394JoeKuoD6Init,
                dim18395JoeKuoD6Init,
                dim18396JoeKuoD6Init,
                dim18397JoeKuoD6Init,
                dim18398JoeKuoD6Init,
                dim18399JoeKuoD6Init,
                dim18400JoeKuoD6Init,
                dim18401JoeKuoD6Init,
                dim18402JoeKuoD6Init,
                dim18403JoeKuoD6Init,
                dim18404JoeKuoD6Init,
                dim18405JoeKuoD6Init,
                dim18406JoeKuoD6Init,
                dim18407JoeKuoD6Init,
                dim18408JoeKuoD6Init,
                dim18409JoeKuoD6Init,
                dim18410JoeKuoD6Init,
                dim18411JoeKuoD6Init,
                dim18412JoeKuoD6Init,
                dim18413JoeKuoD6Init,
                dim18414JoeKuoD6Init,
                dim18415JoeKuoD6Init,
                dim18416JoeKuoD6Init,
                dim18417JoeKuoD6Init,
                dim18418JoeKuoD6Init,
                dim18419JoeKuoD6Init,
                dim18420JoeKuoD6Init,
                dim18421JoeKuoD6Init,
                dim18422JoeKuoD6Init,
                dim18423JoeKuoD6Init,
                dim18424JoeKuoD6Init,
                dim18425JoeKuoD6Init,
                dim18426JoeKuoD6Init,
                dim18427JoeKuoD6Init,
                dim18428JoeKuoD6Init,
                dim18429JoeKuoD6Init,
                dim18430JoeKuoD6Init,
                dim18431JoeKuoD6Init,
                dim18432JoeKuoD6Init,
                dim18433JoeKuoD6Init,
                dim18434JoeKuoD6Init,
                dim18435JoeKuoD6Init,
                dim18436JoeKuoD6Init,
                dim18437JoeKuoD6Init,
                dim18438JoeKuoD6Init,
                dim18439JoeKuoD6Init,
                dim18440JoeKuoD6Init,
                dim18441JoeKuoD6Init,
                dim18442JoeKuoD6Init,
                dim18443JoeKuoD6Init,
                dim18444JoeKuoD6Init,
                dim18445JoeKuoD6Init,
                dim18446JoeKuoD6Init,
                dim18447JoeKuoD6Init,
                dim18448JoeKuoD6Init,
                dim18449JoeKuoD6Init,
                dim18450JoeKuoD6Init,
                dim18451JoeKuoD6Init,
                dim18452JoeKuoD6Init,
                dim18453JoeKuoD6Init,
                dim18454JoeKuoD6Init,
                dim18455JoeKuoD6Init,
                dim18456JoeKuoD6Init,
                dim18457JoeKuoD6Init,
                dim18458JoeKuoD6Init,
                dim18459JoeKuoD6Init,
                dim18460JoeKuoD6Init,
                dim18461JoeKuoD6Init,
                dim18462JoeKuoD6Init,
                dim18463JoeKuoD6Init,
                dim18464JoeKuoD6Init,
                dim18465JoeKuoD6Init,
                dim18466JoeKuoD6Init,
                dim18467JoeKuoD6Init,
                dim18468JoeKuoD6Init,
                dim18469JoeKuoD6Init,
                dim18470JoeKuoD6Init,
                dim18471JoeKuoD6Init,
                dim18472JoeKuoD6Init,
                dim18473JoeKuoD6Init,
                dim18474JoeKuoD6Init,
                dim18475JoeKuoD6Init,
                dim18476JoeKuoD6Init,
                dim18477JoeKuoD6Init,
                dim18478JoeKuoD6Init,
                dim18479JoeKuoD6Init,
                dim18480JoeKuoD6Init,
                dim18481JoeKuoD6Init,
                dim18482JoeKuoD6Init,
                dim18483JoeKuoD6Init,
                dim18484JoeKuoD6Init,
                dim18485JoeKuoD6Init,
                dim18486JoeKuoD6Init,
                dim18487JoeKuoD6Init,
                dim18488JoeKuoD6Init,
                dim18489JoeKuoD6Init,
                dim18490JoeKuoD6Init,
                dim18491JoeKuoD6Init,
                dim18492JoeKuoD6Init,
                dim18493JoeKuoD6Init,
                dim18494JoeKuoD6Init,
                dim18495JoeKuoD6Init,
                dim18496JoeKuoD6Init,
                dim18497JoeKuoD6Init,
                dim18498JoeKuoD6Init,
                dim18499JoeKuoD6Init,
                dim18500JoeKuoD6Init,
                dim18501JoeKuoD6Init,
                dim18502JoeKuoD6Init,
                dim18503JoeKuoD6Init,
                dim18504JoeKuoD6Init,
                dim18505JoeKuoD6Init,
                dim18506JoeKuoD6Init,
                dim18507JoeKuoD6Init,
                dim18508JoeKuoD6Init,
                dim18509JoeKuoD6Init,
                dim18510JoeKuoD6Init,
                dim18511JoeKuoD6Init,
                dim18512JoeKuoD6Init,
                dim18513JoeKuoD6Init,
                dim18514JoeKuoD6Init,
                dim18515JoeKuoD6Init,
                dim18516JoeKuoD6Init,
                dim18517JoeKuoD6Init,
                dim18518JoeKuoD6Init,
                dim18519JoeKuoD6Init,
                dim18520JoeKuoD6Init,
                dim18521JoeKuoD6Init,
                dim18522JoeKuoD6Init,
                dim18523JoeKuoD6Init,
                dim18524JoeKuoD6Init,
                dim18525JoeKuoD6Init,
                dim18526JoeKuoD6Init,
                dim18527JoeKuoD6Init,
                dim18528JoeKuoD6Init,
                dim18529JoeKuoD6Init,
                dim18530JoeKuoD6Init,
                dim18531JoeKuoD6Init,
                dim18532JoeKuoD6Init,
                dim18533JoeKuoD6Init,
                dim18534JoeKuoD6Init,
                dim18535JoeKuoD6Init,
                dim18536JoeKuoD6Init,
                dim18537JoeKuoD6Init,
                dim18538JoeKuoD6Init,
                dim18539JoeKuoD6Init,
                dim18540JoeKuoD6Init,
                dim18541JoeKuoD6Init,
                dim18542JoeKuoD6Init,
                dim18543JoeKuoD6Init,
                dim18544JoeKuoD6Init,
                dim18545JoeKuoD6Init,
                dim18546JoeKuoD6Init,
                dim18547JoeKuoD6Init,
                dim18548JoeKuoD6Init,
                dim18549JoeKuoD6Init,
                dim18550JoeKuoD6Init,
                dim18551JoeKuoD6Init,
                dim18552JoeKuoD6Init,
                dim18553JoeKuoD6Init,
                dim18554JoeKuoD6Init,
                dim18555JoeKuoD6Init,
                dim18556JoeKuoD6Init,
                dim18557JoeKuoD6Init,
                dim18558JoeKuoD6Init,
                dim18559JoeKuoD6Init,
                dim18560JoeKuoD6Init,
                dim18561JoeKuoD6Init,
                dim18562JoeKuoD6Init,
                dim18563JoeKuoD6Init,
                dim18564JoeKuoD6Init,
                dim18565JoeKuoD6Init,
                dim18566JoeKuoD6Init,
                dim18567JoeKuoD6Init,
                dim18568JoeKuoD6Init,
                dim18569JoeKuoD6Init,
                dim18570JoeKuoD6Init,
                dim18571JoeKuoD6Init,
                dim18572JoeKuoD6Init,
                dim18573JoeKuoD6Init,
                dim18574JoeKuoD6Init,
                dim18575JoeKuoD6Init,
                dim18576JoeKuoD6Init,
                dim18577JoeKuoD6Init,
                dim18578JoeKuoD6Init,
                dim18579JoeKuoD6Init,
                dim18580JoeKuoD6Init,
                dim18581JoeKuoD6Init,
                dim18582JoeKuoD6Init,
                dim18583JoeKuoD6Init,
                dim18584JoeKuoD6Init,
                dim18585JoeKuoD6Init,
                dim18586JoeKuoD6Init,
                dim18587JoeKuoD6Init,
                dim18588JoeKuoD6Init,
                dim18589JoeKuoD6Init,
                dim18590JoeKuoD6Init,
                dim18591JoeKuoD6Init,
                dim18592JoeKuoD6Init,
                dim18593JoeKuoD6Init,
                dim18594JoeKuoD6Init,
                dim18595JoeKuoD6Init,
                dim18596JoeKuoD6Init,
                dim18597JoeKuoD6Init,
                dim18598JoeKuoD6Init,
                dim18599JoeKuoD6Init,
                dim18600JoeKuoD6Init,
                dim18601JoeKuoD6Init,
                dim18602JoeKuoD6Init,
                dim18603JoeKuoD6Init,
                dim18604JoeKuoD6Init,
                dim18605JoeKuoD6Init,
                dim18606JoeKuoD6Init,
                dim18607JoeKuoD6Init,
                dim18608JoeKuoD6Init,
                dim18609JoeKuoD6Init,
                dim18610JoeKuoD6Init,
                dim18611JoeKuoD6Init,
                dim18612JoeKuoD6Init,
                dim18613JoeKuoD6Init,
                dim18614JoeKuoD6Init,
                dim18615JoeKuoD6Init,
                dim18616JoeKuoD6Init,
                dim18617JoeKuoD6Init,
                dim18618JoeKuoD6Init,
                dim18619JoeKuoD6Init,
                dim18620JoeKuoD6Init,
                dim18621JoeKuoD6Init,
                dim18622JoeKuoD6Init,
                dim18623JoeKuoD6Init,
                dim18624JoeKuoD6Init,
                dim18625JoeKuoD6Init,
                dim18626JoeKuoD6Init,
                dim18627JoeKuoD6Init,
                dim18628JoeKuoD6Init,
                dim18629JoeKuoD6Init,
                dim18630JoeKuoD6Init,
                dim18631JoeKuoD6Init,
                dim18632JoeKuoD6Init,
                dim18633JoeKuoD6Init,
                dim18634JoeKuoD6Init,
                dim18635JoeKuoD6Init,
                dim18636JoeKuoD6Init,
                dim18637JoeKuoD6Init,
                dim18638JoeKuoD6Init,
                dim18639JoeKuoD6Init,
                dim18640JoeKuoD6Init,
                dim18641JoeKuoD6Init,
                dim18642JoeKuoD6Init,
                dim18643JoeKuoD6Init,
                dim18644JoeKuoD6Init,
                dim18645JoeKuoD6Init,
                dim18646JoeKuoD6Init,
                dim18647JoeKuoD6Init,
                dim18648JoeKuoD6Init,
                dim18649JoeKuoD6Init,
                dim18650JoeKuoD6Init,
                dim18651JoeKuoD6Init,
                dim18652JoeKuoD6Init,
                dim18653JoeKuoD6Init,
                dim18654JoeKuoD6Init,
                dim18655JoeKuoD6Init,
                dim18656JoeKuoD6Init,
                dim18657JoeKuoD6Init,
                dim18658JoeKuoD6Init,
                dim18659JoeKuoD6Init,
                dim18660JoeKuoD6Init,
                dim18661JoeKuoD6Init,
                dim18662JoeKuoD6Init,
                dim18663JoeKuoD6Init,
                dim18664JoeKuoD6Init,
                dim18665JoeKuoD6Init,
                dim18666JoeKuoD6Init,
                dim18667JoeKuoD6Init,
                dim18668JoeKuoD6Init,
                dim18669JoeKuoD6Init,
                dim18670JoeKuoD6Init,
                dim18671JoeKuoD6Init,
                dim18672JoeKuoD6Init,
                dim18673JoeKuoD6Init,
                dim18674JoeKuoD6Init,
                dim18675JoeKuoD6Init,
                dim18676JoeKuoD6Init,
                dim18677JoeKuoD6Init,
                dim18678JoeKuoD6Init,
                dim18679JoeKuoD6Init,
                dim18680JoeKuoD6Init,
                dim18681JoeKuoD6Init,
                dim18682JoeKuoD6Init,
                dim18683JoeKuoD6Init,
                dim18684JoeKuoD6Init,
                dim18685JoeKuoD6Init,
                dim18686JoeKuoD6Init,
                dim18687JoeKuoD6Init,
                dim18688JoeKuoD6Init,
                dim18689JoeKuoD6Init,
                dim18690JoeKuoD6Init,
                dim18691JoeKuoD6Init,
                dim18692JoeKuoD6Init,
                dim18693JoeKuoD6Init,
                dim18694JoeKuoD6Init,
                dim18695JoeKuoD6Init,
                dim18696JoeKuoD6Init,
                dim18697JoeKuoD6Init,
                dim18698JoeKuoD6Init,
                dim18699JoeKuoD6Init,
                dim18700JoeKuoD6Init,
                dim18701JoeKuoD6Init,
                dim18702JoeKuoD6Init,
                dim18703JoeKuoD6Init,
                dim18704JoeKuoD6Init,
                dim18705JoeKuoD6Init,
                dim18706JoeKuoD6Init,
                dim18707JoeKuoD6Init,
                dim18708JoeKuoD6Init,
                dim18709JoeKuoD6Init,
                dim18710JoeKuoD6Init,
                dim18711JoeKuoD6Init,
                dim18712JoeKuoD6Init,
                dim18713JoeKuoD6Init,
                dim18714JoeKuoD6Init,
                dim18715JoeKuoD6Init,
                dim18716JoeKuoD6Init,
                dim18717JoeKuoD6Init,
                dim18718JoeKuoD6Init,
                dim18719JoeKuoD6Init,
                dim18720JoeKuoD6Init,
                dim18721JoeKuoD6Init,
                dim18722JoeKuoD6Init,
                dim18723JoeKuoD6Init,
                dim18724JoeKuoD6Init,
                dim18725JoeKuoD6Init,
                dim18726JoeKuoD6Init,
                dim18727JoeKuoD6Init,
                dim18728JoeKuoD6Init,
                dim18729JoeKuoD6Init,
                dim18730JoeKuoD6Init,
                dim18731JoeKuoD6Init,
                dim18732JoeKuoD6Init,
                dim18733JoeKuoD6Init,
                dim18734JoeKuoD6Init,
                dim18735JoeKuoD6Init,
                dim18736JoeKuoD6Init,
                dim18737JoeKuoD6Init,
                dim18738JoeKuoD6Init,
                dim18739JoeKuoD6Init,
                dim18740JoeKuoD6Init,
                dim18741JoeKuoD6Init,
                dim18742JoeKuoD6Init,
                dim18743JoeKuoD6Init,
                dim18744JoeKuoD6Init,
                dim18745JoeKuoD6Init,
                dim18746JoeKuoD6Init,
                dim18747JoeKuoD6Init,
                dim18748JoeKuoD6Init,
                dim18749JoeKuoD6Init,
                dim18750JoeKuoD6Init,
                dim18751JoeKuoD6Init,
                dim18752JoeKuoD6Init,
                dim18753JoeKuoD6Init,
                dim18754JoeKuoD6Init,
                dim18755JoeKuoD6Init,
                dim18756JoeKuoD6Init,
                dim18757JoeKuoD6Init,
                dim18758JoeKuoD6Init,
                dim18759JoeKuoD6Init,
                dim18760JoeKuoD6Init,
                dim18761JoeKuoD6Init,
                dim18762JoeKuoD6Init,
                dim18763JoeKuoD6Init,
                dim18764JoeKuoD6Init,
                dim18765JoeKuoD6Init,
                dim18766JoeKuoD6Init,
                dim18767JoeKuoD6Init,
                dim18768JoeKuoD6Init,
                dim18769JoeKuoD6Init,
                dim18770JoeKuoD6Init,
                dim18771JoeKuoD6Init,
                dim18772JoeKuoD6Init,
                dim18773JoeKuoD6Init,
                dim18774JoeKuoD6Init,
                dim18775JoeKuoD6Init,
                dim18776JoeKuoD6Init,
                dim18777JoeKuoD6Init,
                dim18778JoeKuoD6Init,
                dim18779JoeKuoD6Init,
                dim18780JoeKuoD6Init,
                dim18781JoeKuoD6Init,
                dim18782JoeKuoD6Init,
                dim18783JoeKuoD6Init,
                dim18784JoeKuoD6Init,
                dim18785JoeKuoD6Init,
                dim18786JoeKuoD6Init,
                dim18787JoeKuoD6Init,
                dim18788JoeKuoD6Init,
                dim18789JoeKuoD6Init,
                dim18790JoeKuoD6Init,
                dim18791JoeKuoD6Init,
                dim18792JoeKuoD6Init,
                dim18793JoeKuoD6Init,
                dim18794JoeKuoD6Init,
                dim18795JoeKuoD6Init,
                dim18796JoeKuoD6Init,
                dim18797JoeKuoD6Init,
                dim18798JoeKuoD6Init,
                dim18799JoeKuoD6Init,
                dim18800JoeKuoD6Init,
                dim18801JoeKuoD6Init,
                dim18802JoeKuoD6Init,
                dim18803JoeKuoD6Init,
                dim18804JoeKuoD6Init,
                dim18805JoeKuoD6Init,
                dim18806JoeKuoD6Init,
                dim18807JoeKuoD6Init,
                dim18808JoeKuoD6Init,
                dim18809JoeKuoD6Init,
                dim18810JoeKuoD6Init,
                dim18811JoeKuoD6Init,
                dim18812JoeKuoD6Init,
                dim18813JoeKuoD6Init,
                dim18814JoeKuoD6Init,
                dim18815JoeKuoD6Init,
                dim18816JoeKuoD6Init,
                dim18817JoeKuoD6Init,
                dim18818JoeKuoD6Init,
                dim18819JoeKuoD6Init,
                dim18820JoeKuoD6Init,
                dim18821JoeKuoD6Init,
                dim18822JoeKuoD6Init,
                dim18823JoeKuoD6Init,
                dim18824JoeKuoD6Init,
                dim18825JoeKuoD6Init,
                dim18826JoeKuoD6Init,
                dim18827JoeKuoD6Init,
                dim18828JoeKuoD6Init,
                dim18829JoeKuoD6Init,
                dim18830JoeKuoD6Init,
                dim18831JoeKuoD6Init,
                dim18832JoeKuoD6Init,
                dim18833JoeKuoD6Init,
                dim18834JoeKuoD6Init,
                dim18835JoeKuoD6Init,
                dim18836JoeKuoD6Init,
                dim18837JoeKuoD6Init,
                dim18838JoeKuoD6Init,
                dim18839JoeKuoD6Init,
                dim18840JoeKuoD6Init,
                dim18841JoeKuoD6Init,
                dim18842JoeKuoD6Init,
                dim18843JoeKuoD6Init,
                dim18844JoeKuoD6Init,
                dim18845JoeKuoD6Init,
                dim18846JoeKuoD6Init,
                dim18847JoeKuoD6Init,
                dim18848JoeKuoD6Init,
                dim18849JoeKuoD6Init,
                dim18850JoeKuoD6Init,
                dim18851JoeKuoD6Init,
                dim18852JoeKuoD6Init,
                dim18853JoeKuoD6Init,
                dim18854JoeKuoD6Init,
                dim18855JoeKuoD6Init,
                dim18856JoeKuoD6Init,
                dim18857JoeKuoD6Init,
                dim18858JoeKuoD6Init,
                dim18859JoeKuoD6Init,
                dim18860JoeKuoD6Init,
                dim18861JoeKuoD6Init,
                dim18862JoeKuoD6Init,
                dim18863JoeKuoD6Init,
                dim18864JoeKuoD6Init,
                dim18865JoeKuoD6Init,
                dim18866JoeKuoD6Init,
                dim18867JoeKuoD6Init,
                dim18868JoeKuoD6Init,
                dim18869JoeKuoD6Init,
                dim18870JoeKuoD6Init,
                dim18871JoeKuoD6Init,
                dim18872JoeKuoD6Init,
                dim18873JoeKuoD6Init,
                dim18874JoeKuoD6Init,
                dim18875JoeKuoD6Init,
                dim18876JoeKuoD6Init,
                dim18877JoeKuoD6Init,
                dim18878JoeKuoD6Init,
                dim18879JoeKuoD6Init,
                dim18880JoeKuoD6Init,
                dim18881JoeKuoD6Init,
                dim18882JoeKuoD6Init,
                dim18883JoeKuoD6Init,
                dim18884JoeKuoD6Init,
                dim18885JoeKuoD6Init,
                dim18886JoeKuoD6Init,
                dim18887JoeKuoD6Init,
                dim18888JoeKuoD6Init,
                dim18889JoeKuoD6Init,
                dim18890JoeKuoD6Init,
                dim18891JoeKuoD6Init,
                dim18892JoeKuoD6Init,
                dim18893JoeKuoD6Init,
                dim18894JoeKuoD6Init,
                dim18895JoeKuoD6Init,
                dim18896JoeKuoD6Init,
                dim18897JoeKuoD6Init,
                dim18898JoeKuoD6Init,
                dim18899JoeKuoD6Init,
                dim18900JoeKuoD6Init,
                dim18901JoeKuoD6Init,
                dim18902JoeKuoD6Init,
                dim18903JoeKuoD6Init,
                dim18904JoeKuoD6Init,
                dim18905JoeKuoD6Init,
                dim18906JoeKuoD6Init,
                dim18907JoeKuoD6Init,
                dim18908JoeKuoD6Init,
                dim18909JoeKuoD6Init,
                dim18910JoeKuoD6Init,
                dim18911JoeKuoD6Init,
                dim18912JoeKuoD6Init,
                dim18913JoeKuoD6Init,
                dim18914JoeKuoD6Init,
                dim18915JoeKuoD6Init,
                dim18916JoeKuoD6Init,
                dim18917JoeKuoD6Init,
                dim18918JoeKuoD6Init,
                dim18919JoeKuoD6Init,
                dim18920JoeKuoD6Init,
                dim18921JoeKuoD6Init,
                dim18922JoeKuoD6Init,
                dim18923JoeKuoD6Init,
                dim18924JoeKuoD6Init,
                dim18925JoeKuoD6Init,
                dim18926JoeKuoD6Init,
                dim18927JoeKuoD6Init,
                dim18928JoeKuoD6Init,
                dim18929JoeKuoD6Init,
                dim18930JoeKuoD6Init,
                dim18931JoeKuoD6Init,
                dim18932JoeKuoD6Init,
                dim18933JoeKuoD6Init,
                dim18934JoeKuoD6Init,
                dim18935JoeKuoD6Init,
                dim18936JoeKuoD6Init,
                dim18937JoeKuoD6Init,
                dim18938JoeKuoD6Init,
                dim18939JoeKuoD6Init,
                dim18940JoeKuoD6Init,
                dim18941JoeKuoD6Init,
                dim18942JoeKuoD6Init,
                dim18943JoeKuoD6Init,
                dim18944JoeKuoD6Init,
                dim18945JoeKuoD6Init,
                dim18946JoeKuoD6Init,
                dim18947JoeKuoD6Init,
                dim18948JoeKuoD6Init,
                dim18949JoeKuoD6Init,
                dim18950JoeKuoD6Init,
                dim18951JoeKuoD6Init,
                dim18952JoeKuoD6Init,
                dim18953JoeKuoD6Init,
                dim18954JoeKuoD6Init,
                dim18955JoeKuoD6Init,
                dim18956JoeKuoD6Init,
                dim18957JoeKuoD6Init,
                dim18958JoeKuoD6Init,
                dim18959JoeKuoD6Init,
                dim18960JoeKuoD6Init,
                dim18961JoeKuoD6Init,
                dim18962JoeKuoD6Init,
                dim18963JoeKuoD6Init,
                dim18964JoeKuoD6Init,
                dim18965JoeKuoD6Init,
                dim18966JoeKuoD6Init,
                dim18967JoeKuoD6Init,
                dim18968JoeKuoD6Init,
                dim18969JoeKuoD6Init,
                dim18970JoeKuoD6Init,
                dim18971JoeKuoD6Init,
                dim18972JoeKuoD6Init,
                dim18973JoeKuoD6Init,
                dim18974JoeKuoD6Init,
                dim18975JoeKuoD6Init,
                dim18976JoeKuoD6Init,
                dim18977JoeKuoD6Init,
                dim18978JoeKuoD6Init,
                dim18979JoeKuoD6Init,
                dim18980JoeKuoD6Init,
                dim18981JoeKuoD6Init,
                dim18982JoeKuoD6Init,
                dim18983JoeKuoD6Init,
                dim18984JoeKuoD6Init,
                dim18985JoeKuoD6Init,
                dim18986JoeKuoD6Init,
                dim18987JoeKuoD6Init,
                dim18988JoeKuoD6Init,
                dim18989JoeKuoD6Init,
                dim18990JoeKuoD6Init,
                dim18991JoeKuoD6Init,
                dim18992JoeKuoD6Init,
                dim18993JoeKuoD6Init,
                dim18994JoeKuoD6Init,
                dim18995JoeKuoD6Init,
                dim18996JoeKuoD6Init,
                dim18997JoeKuoD6Init,
                dim18998JoeKuoD6Init,
                dim18999JoeKuoD6Init,
                dim19000JoeKuoD6Init,
                dim19001JoeKuoD6Init,
                dim19002JoeKuoD6Init,
                dim19003JoeKuoD6Init,
                dim19004JoeKuoD6Init,
                dim19005JoeKuoD6Init,
                dim19006JoeKuoD6Init,
                dim19007JoeKuoD6Init,
                dim19008JoeKuoD6Init,
                dim19009JoeKuoD6Init,
                dim19010JoeKuoD6Init,
                dim19011JoeKuoD6Init,
                dim19012JoeKuoD6Init,
                dim19013JoeKuoD6Init,
                dim19014JoeKuoD6Init,
                dim19015JoeKuoD6Init,
                dim19016JoeKuoD6Init,
                dim19017JoeKuoD6Init,
                dim19018JoeKuoD6Init,
                dim19019JoeKuoD6Init,
                dim19020JoeKuoD6Init,
                dim19021JoeKuoD6Init,
                dim19022JoeKuoD6Init,
                dim19023JoeKuoD6Init,
                dim19024JoeKuoD6Init,
                dim19025JoeKuoD6Init,
                dim19026JoeKuoD6Init,
                dim19027JoeKuoD6Init,
                dim19028JoeKuoD6Init,
                dim19029JoeKuoD6Init,
                dim19030JoeKuoD6Init,
                dim19031JoeKuoD6Init,
                dim19032JoeKuoD6Init,
                dim19033JoeKuoD6Init,
                dim19034JoeKuoD6Init,
                dim19035JoeKuoD6Init,
                dim19036JoeKuoD6Init,
                dim19037JoeKuoD6Init,
                dim19038JoeKuoD6Init,
                dim19039JoeKuoD6Init,
                dim19040JoeKuoD6Init,
                dim19041JoeKuoD6Init,
                dim19042JoeKuoD6Init,
                dim19043JoeKuoD6Init,
                dim19044JoeKuoD6Init,
                dim19045JoeKuoD6Init,
                dim19046JoeKuoD6Init,
                dim19047JoeKuoD6Init,
                dim19048JoeKuoD6Init,
                dim19049JoeKuoD6Init,
                dim19050JoeKuoD6Init,
                dim19051JoeKuoD6Init,
                dim19052JoeKuoD6Init,
                dim19053JoeKuoD6Init,
                dim19054JoeKuoD6Init,
                dim19055JoeKuoD6Init,
                dim19056JoeKuoD6Init,
                dim19057JoeKuoD6Init,
                dim19058JoeKuoD6Init,
                dim19059JoeKuoD6Init,
                dim19060JoeKuoD6Init,
                dim19061JoeKuoD6Init,
                dim19062JoeKuoD6Init,
                dim19063JoeKuoD6Init,
                dim19064JoeKuoD6Init,
                dim19065JoeKuoD6Init,
                dim19066JoeKuoD6Init,
                dim19067JoeKuoD6Init,
                dim19068JoeKuoD6Init,
                dim19069JoeKuoD6Init,
                dim19070JoeKuoD6Init,
                dim19071JoeKuoD6Init,
                dim19072JoeKuoD6Init,
                dim19073JoeKuoD6Init,
                dim19074JoeKuoD6Init,
                dim19075JoeKuoD6Init,
                dim19076JoeKuoD6Init,
                dim19077JoeKuoD6Init,
                dim19078JoeKuoD6Init,
                dim19079JoeKuoD6Init,
                dim19080JoeKuoD6Init,
                dim19081JoeKuoD6Init,
                dim19082JoeKuoD6Init,
                dim19083JoeKuoD6Init,
                dim19084JoeKuoD6Init,
                dim19085JoeKuoD6Init,
                dim19086JoeKuoD6Init,
                dim19087JoeKuoD6Init,
                dim19088JoeKuoD6Init,
                dim19089JoeKuoD6Init,
                dim19090JoeKuoD6Init,
                dim19091JoeKuoD6Init,
                dim19092JoeKuoD6Init,
                dim19093JoeKuoD6Init,
                dim19094JoeKuoD6Init,
                dim19095JoeKuoD6Init,
                dim19096JoeKuoD6Init,
                dim19097JoeKuoD6Init,
                dim19098JoeKuoD6Init,
                dim19099JoeKuoD6Init,
                dim19100JoeKuoD6Init,
                dim19101JoeKuoD6Init,
                dim19102JoeKuoD6Init,
                dim19103JoeKuoD6Init,
                dim19104JoeKuoD6Init,
                dim19105JoeKuoD6Init,
                dim19106JoeKuoD6Init,
                dim19107JoeKuoD6Init,
                dim19108JoeKuoD6Init,
                dim19109JoeKuoD6Init,
                dim19110JoeKuoD6Init,
                dim19111JoeKuoD6Init,
                dim19112JoeKuoD6Init,
                dim19113JoeKuoD6Init,
                dim19114JoeKuoD6Init,
                dim19115JoeKuoD6Init,
                dim19116JoeKuoD6Init,
                dim19117JoeKuoD6Init,
                dim19118JoeKuoD6Init,
                dim19119JoeKuoD6Init,
                dim19120JoeKuoD6Init,
                dim19121JoeKuoD6Init,
                dim19122JoeKuoD6Init,
                dim19123JoeKuoD6Init,
                dim19124JoeKuoD6Init,
                dim19125JoeKuoD6Init,
                dim19126JoeKuoD6Init,
                dim19127JoeKuoD6Init,
                dim19128JoeKuoD6Init,
                dim19129JoeKuoD6Init,
                dim19130JoeKuoD6Init,
                dim19131JoeKuoD6Init,
                dim19132JoeKuoD6Init,
                dim19133JoeKuoD6Init,
                dim19134JoeKuoD6Init,
                dim19135JoeKuoD6Init,
                dim19136JoeKuoD6Init,
                dim19137JoeKuoD6Init,
                dim19138JoeKuoD6Init,
                dim19139JoeKuoD6Init,
                dim19140JoeKuoD6Init,
                dim19141JoeKuoD6Init,
                dim19142JoeKuoD6Init,
                dim19143JoeKuoD6Init,
                dim19144JoeKuoD6Init,
                dim19145JoeKuoD6Init,
                dim19146JoeKuoD6Init,
                dim19147JoeKuoD6Init,
                dim19148JoeKuoD6Init,
                dim19149JoeKuoD6Init,
                dim19150JoeKuoD6Init,
                dim19151JoeKuoD6Init,
                dim19152JoeKuoD6Init,
                dim19153JoeKuoD6Init,
                dim19154JoeKuoD6Init,
                dim19155JoeKuoD6Init,
                dim19156JoeKuoD6Init,
                dim19157JoeKuoD6Init,
                dim19158JoeKuoD6Init,
                dim19159JoeKuoD6Init,
                dim19160JoeKuoD6Init,
                dim19161JoeKuoD6Init,
                dim19162JoeKuoD6Init,
                dim19163JoeKuoD6Init,
                dim19164JoeKuoD6Init,
                dim19165JoeKuoD6Init,
                dim19166JoeKuoD6Init,
                dim19167JoeKuoD6Init,
                dim19168JoeKuoD6Init,
                dim19169JoeKuoD6Init,
                dim19170JoeKuoD6Init,
                dim19171JoeKuoD6Init,
                dim19172JoeKuoD6Init,
                dim19173JoeKuoD6Init,
                dim19174JoeKuoD6Init,
                dim19175JoeKuoD6Init,
                dim19176JoeKuoD6Init,
                dim19177JoeKuoD6Init,
                dim19178JoeKuoD6Init,
                dim19179JoeKuoD6Init,
                dim19180JoeKuoD6Init,
                dim19181JoeKuoD6Init,
                dim19182JoeKuoD6Init,
                dim19183JoeKuoD6Init,
                dim19184JoeKuoD6Init,
                dim19185JoeKuoD6Init,
                dim19186JoeKuoD6Init,
                dim19187JoeKuoD6Init,
                dim19188JoeKuoD6Init,
                dim19189JoeKuoD6Init,
                dim19190JoeKuoD6Init,
                dim19191JoeKuoD6Init,
                dim19192JoeKuoD6Init,
                dim19193JoeKuoD6Init,
                dim19194JoeKuoD6Init,
                dim19195JoeKuoD6Init,
                dim19196JoeKuoD6Init,
                dim19197JoeKuoD6Init,
                dim19198JoeKuoD6Init,
                dim19199JoeKuoD6Init,
                dim19200JoeKuoD6Init,
                dim19201JoeKuoD6Init,
                dim19202JoeKuoD6Init,
                dim19203JoeKuoD6Init,
                dim19204JoeKuoD6Init,
                dim19205JoeKuoD6Init,
                dim19206JoeKuoD6Init,
                dim19207JoeKuoD6Init,
                dim19208JoeKuoD6Init,
                dim19209JoeKuoD6Init,
                dim19210JoeKuoD6Init,
                dim19211JoeKuoD6Init,
                dim19212JoeKuoD6Init,
                dim19213JoeKuoD6Init,
                dim19214JoeKuoD6Init,
                dim19215JoeKuoD6Init,
                dim19216JoeKuoD6Init,
                dim19217JoeKuoD6Init,
                dim19218JoeKuoD6Init,
                dim19219JoeKuoD6Init,
                dim19220JoeKuoD6Init,
                dim19221JoeKuoD6Init,
                dim19222JoeKuoD6Init,
                dim19223JoeKuoD6Init,
                dim19224JoeKuoD6Init,
                dim19225JoeKuoD6Init,
                dim19226JoeKuoD6Init,
                dim19227JoeKuoD6Init,
                dim19228JoeKuoD6Init,
                dim19229JoeKuoD6Init,
                dim19230JoeKuoD6Init,
                dim19231JoeKuoD6Init,
                dim19232JoeKuoD6Init,
                dim19233JoeKuoD6Init,
                dim19234JoeKuoD6Init,
                dim19235JoeKuoD6Init,
                dim19236JoeKuoD6Init,
                dim19237JoeKuoD6Init,
                dim19238JoeKuoD6Init,
                dim19239JoeKuoD6Init,
                dim19240JoeKuoD6Init,
                dim19241JoeKuoD6Init,
                dim19242JoeKuoD6Init,
                dim19243JoeKuoD6Init,
                dim19244JoeKuoD6Init,
                dim19245JoeKuoD6Init,
                dim19246JoeKuoD6Init,
                dim19247JoeKuoD6Init,
                dim19248JoeKuoD6Init,
                dim19249JoeKuoD6Init,
                dim19250JoeKuoD6Init,
                dim19251JoeKuoD6Init,
                dim19252JoeKuoD6Init,
                dim19253JoeKuoD6Init,
                dim19254JoeKuoD6Init,
                dim19255JoeKuoD6Init,
                dim19256JoeKuoD6Init,
                dim19257JoeKuoD6Init,
                dim19258JoeKuoD6Init,
                dim19259JoeKuoD6Init,
                dim19260JoeKuoD6Init,
                dim19261JoeKuoD6Init,
                dim19262JoeKuoD6Init,
                dim19263JoeKuoD6Init,
                dim19264JoeKuoD6Init,
                dim19265JoeKuoD6Init,
                dim19266JoeKuoD6Init,
                dim19267JoeKuoD6Init,
                dim19268JoeKuoD6Init,
                dim19269JoeKuoD6Init,
                dim19270JoeKuoD6Init,
                dim19271JoeKuoD6Init,
                dim19272JoeKuoD6Init,
                dim19273JoeKuoD6Init,
                dim19274JoeKuoD6Init,
                dim19275JoeKuoD6Init,
                dim19276JoeKuoD6Init,
                dim19277JoeKuoD6Init,
                dim19278JoeKuoD6Init,
                dim19279JoeKuoD6Init,
                dim19280JoeKuoD6Init,
                dim19281JoeKuoD6Init,
                dim19282JoeKuoD6Init,
                dim19283JoeKuoD6Init,
                dim19284JoeKuoD6Init,
                dim19285JoeKuoD6Init,
                dim19286JoeKuoD6Init,
                dim19287JoeKuoD6Init,
                dim19288JoeKuoD6Init,
                dim19289JoeKuoD6Init,
                dim19290JoeKuoD6Init,
                dim19291JoeKuoD6Init,
                dim19292JoeKuoD6Init,
                dim19293JoeKuoD6Init,
                dim19294JoeKuoD6Init,
                dim19295JoeKuoD6Init,
                dim19296JoeKuoD6Init,
                dim19297JoeKuoD6Init,
                dim19298JoeKuoD6Init,
                dim19299JoeKuoD6Init,
                dim19300JoeKuoD6Init,
                dim19301JoeKuoD6Init,
                dim19302JoeKuoD6Init,
                dim19303JoeKuoD6Init,
                dim19304JoeKuoD6Init,
                dim19305JoeKuoD6Init,
                dim19306JoeKuoD6Init,
                dim19307JoeKuoD6Init,
                dim19308JoeKuoD6Init,
                dim19309JoeKuoD6Init,
                dim19310JoeKuoD6Init,
                dim19311JoeKuoD6Init,
                dim19312JoeKuoD6Init,
                dim19313JoeKuoD6Init,
                dim19314JoeKuoD6Init,
                dim19315JoeKuoD6Init,
                dim19316JoeKuoD6Init,
                dim19317JoeKuoD6Init,
                dim19318JoeKuoD6Init,
                dim19319JoeKuoD6Init,
                dim19320JoeKuoD6Init,
                dim19321JoeKuoD6Init,
                dim19322JoeKuoD6Init,
                dim19323JoeKuoD6Init,
                dim19324JoeKuoD6Init,
                dim19325JoeKuoD6Init,
                dim19326JoeKuoD6Init,
                dim19327JoeKuoD6Init,
                dim19328JoeKuoD6Init,
                dim19329JoeKuoD6Init,
                dim19330JoeKuoD6Init,
                dim19331JoeKuoD6Init,
                dim19332JoeKuoD6Init,
                dim19333JoeKuoD6Init,
                dim19334JoeKuoD6Init,
                dim19335JoeKuoD6Init,
                dim19336JoeKuoD6Init,
                dim19337JoeKuoD6Init,
                dim19338JoeKuoD6Init,
                dim19339JoeKuoD6Init,
                dim19340JoeKuoD6Init,
                dim19341JoeKuoD6Init,
                dim19342JoeKuoD6Init,
                dim19343JoeKuoD6Init,
                dim19344JoeKuoD6Init,
                dim19345JoeKuoD6Init,
                dim19346JoeKuoD6Init,
                dim19347JoeKuoD6Init,
                dim19348JoeKuoD6Init,
                dim19349JoeKuoD6Init,
                dim19350JoeKuoD6Init,
                dim19351JoeKuoD6Init,
                dim19352JoeKuoD6Init,
                dim19353JoeKuoD6Init,
                dim19354JoeKuoD6Init,
                dim19355JoeKuoD6Init,
                dim19356JoeKuoD6Init,
                dim19357JoeKuoD6Init,
                dim19358JoeKuoD6Init,
                dim19359JoeKuoD6Init,
                dim19360JoeKuoD6Init,
                dim19361JoeKuoD6Init,
                dim19362JoeKuoD6Init,
                dim19363JoeKuoD6Init,
                dim19364JoeKuoD6Init,
                dim19365JoeKuoD6Init,
                dim19366JoeKuoD6Init,
                dim19367JoeKuoD6Init,
                dim19368JoeKuoD6Init,
                dim19369JoeKuoD6Init,
                dim19370JoeKuoD6Init,
                dim19371JoeKuoD6Init,
                dim19372JoeKuoD6Init,
                dim19373JoeKuoD6Init,
                dim19374JoeKuoD6Init,
                dim19375JoeKuoD6Init,
                dim19376JoeKuoD6Init,
                dim19377JoeKuoD6Init,
                dim19378JoeKuoD6Init,
                dim19379JoeKuoD6Init,
                dim19380JoeKuoD6Init,
                dim19381JoeKuoD6Init,
                dim19382JoeKuoD6Init,
                dim19383JoeKuoD6Init,
                dim19384JoeKuoD6Init,
                dim19385JoeKuoD6Init,
                dim19386JoeKuoD6Init,
                dim19387JoeKuoD6Init,
                dim19388JoeKuoD6Init,
                dim19389JoeKuoD6Init,
                dim19390JoeKuoD6Init,
                dim19391JoeKuoD6Init,
                dim19392JoeKuoD6Init,
                dim19393JoeKuoD6Init,
                dim19394JoeKuoD6Init,
                dim19395JoeKuoD6Init,
                dim19396JoeKuoD6Init,
                dim19397JoeKuoD6Init,
                dim19398JoeKuoD6Init,
                dim19399JoeKuoD6Init,
                dim19400JoeKuoD6Init,
                dim19401JoeKuoD6Init,
                dim19402JoeKuoD6Init,
                dim19403JoeKuoD6Init,
                dim19404JoeKuoD6Init,
                dim19405JoeKuoD6Init,
                dim19406JoeKuoD6Init,
                dim19407JoeKuoD6Init,
                dim19408JoeKuoD6Init,
                dim19409JoeKuoD6Init,
                dim19410JoeKuoD6Init,
                dim19411JoeKuoD6Init,
                dim19412JoeKuoD6Init,
                dim19413JoeKuoD6Init,
                dim19414JoeKuoD6Init,
                dim19415JoeKuoD6Init,
                dim19416JoeKuoD6Init,
                dim19417JoeKuoD6Init,
                dim19418JoeKuoD6Init,
                dim19419JoeKuoD6Init,
                dim19420JoeKuoD6Init,
                dim19421JoeKuoD6Init,
                dim19422JoeKuoD6Init,
                dim19423JoeKuoD6Init,
                dim19424JoeKuoD6Init,
                dim19425JoeKuoD6Init,
                dim19426JoeKuoD6Init,
                dim19427JoeKuoD6Init,
                dim19428JoeKuoD6Init,
                dim19429JoeKuoD6Init,
                dim19430JoeKuoD6Init,
                dim19431JoeKuoD6Init,
                dim19432JoeKuoD6Init,
                dim19433JoeKuoD6Init,
                dim19434JoeKuoD6Init,
                dim19435JoeKuoD6Init,
                dim19436JoeKuoD6Init,
                dim19437JoeKuoD6Init,
                dim19438JoeKuoD6Init,
                dim19439JoeKuoD6Init,
                dim19440JoeKuoD6Init,
                dim19441JoeKuoD6Init,
                dim19442JoeKuoD6Init,
                dim19443JoeKuoD6Init,
                dim19444JoeKuoD6Init,
                dim19445JoeKuoD6Init,
                dim19446JoeKuoD6Init,
                dim19447JoeKuoD6Init,
                dim19448JoeKuoD6Init,
                dim19449JoeKuoD6Init,
                dim19450JoeKuoD6Init,
                dim19451JoeKuoD6Init,
                dim19452JoeKuoD6Init,
                dim19453JoeKuoD6Init,
                dim19454JoeKuoD6Init,
                dim19455JoeKuoD6Init,
                dim19456JoeKuoD6Init,
                dim19457JoeKuoD6Init,
                dim19458JoeKuoD6Init,
                dim19459JoeKuoD6Init,
                dim19460JoeKuoD6Init,
                dim19461JoeKuoD6Init,
                dim19462JoeKuoD6Init,
                dim19463JoeKuoD6Init,
                dim19464JoeKuoD6Init,
                dim19465JoeKuoD6Init,
                dim19466JoeKuoD6Init,
                dim19467JoeKuoD6Init,
                dim19468JoeKuoD6Init,
                dim19469JoeKuoD6Init,
                dim19470JoeKuoD6Init,
                dim19471JoeKuoD6Init,
                dim19472JoeKuoD6Init,
                dim19473JoeKuoD6Init,
                dim19474JoeKuoD6Init,
                dim19475JoeKuoD6Init,
                dim19476JoeKuoD6Init,
                dim19477JoeKuoD6Init,
                dim19478JoeKuoD6Init,
                dim19479JoeKuoD6Init,
                dim19480JoeKuoD6Init,
                dim19481JoeKuoD6Init,
                dim19482JoeKuoD6Init,
                dim19483JoeKuoD6Init,
                dim19484JoeKuoD6Init,
                dim19485JoeKuoD6Init,
                dim19486JoeKuoD6Init,
                dim19487JoeKuoD6Init,
                dim19488JoeKuoD6Init,
                dim19489JoeKuoD6Init,
                dim19490JoeKuoD6Init,
                dim19491JoeKuoD6Init,
                dim19492JoeKuoD6Init,
                dim19493JoeKuoD6Init,
                dim19494JoeKuoD6Init,
                dim19495JoeKuoD6Init,
                dim19496JoeKuoD6Init,
                dim19497JoeKuoD6Init,
                dim19498JoeKuoD6Init,
                dim19499JoeKuoD6Init,
                dim19500JoeKuoD6Init,
                dim19501JoeKuoD6Init,
                dim19502JoeKuoD6Init,
                dim19503JoeKuoD6Init,
                dim19504JoeKuoD6Init,
                dim19505JoeKuoD6Init,
                dim19506JoeKuoD6Init,
                dim19507JoeKuoD6Init,
                dim19508JoeKuoD6Init,
                dim19509JoeKuoD6Init,
                dim19510JoeKuoD6Init,
                dim19511JoeKuoD6Init,
                dim19512JoeKuoD6Init,
                dim19513JoeKuoD6Init,
                dim19514JoeKuoD6Init,
                dim19515JoeKuoD6Init,
                dim19516JoeKuoD6Init,
                dim19517JoeKuoD6Init,
                dim19518JoeKuoD6Init,
                dim19519JoeKuoD6Init,
                dim19520JoeKuoD6Init,
                dim19521JoeKuoD6Init,
                dim19522JoeKuoD6Init,
                dim19523JoeKuoD6Init,
                dim19524JoeKuoD6Init,
                dim19525JoeKuoD6Init,
                dim19526JoeKuoD6Init,
                dim19527JoeKuoD6Init,
                dim19528JoeKuoD6Init,
                dim19529JoeKuoD6Init,
                dim19530JoeKuoD6Init,
                dim19531JoeKuoD6Init,
                dim19532JoeKuoD6Init,
                dim19533JoeKuoD6Init,
                dim19534JoeKuoD6Init,
                dim19535JoeKuoD6Init,
                dim19536JoeKuoD6Init,
                dim19537JoeKuoD6Init,
                dim19538JoeKuoD6Init,
                dim19539JoeKuoD6Init,
                dim19540JoeKuoD6Init,
                dim19541JoeKuoD6Init,
                dim19542JoeKuoD6Init,
                dim19543JoeKuoD6Init,
                dim19544JoeKuoD6Init,
                dim19545JoeKuoD6Init,
                dim19546JoeKuoD6Init,
                dim19547JoeKuoD6Init,
                dim19548JoeKuoD6Init,
                dim19549JoeKuoD6Init,
                dim19550JoeKuoD6Init,
                dim19551JoeKuoD6Init,
                dim19552JoeKuoD6Init,
                dim19553JoeKuoD6Init,
                dim19554JoeKuoD6Init,
                dim19555JoeKuoD6Init,
                dim19556JoeKuoD6Init,
                dim19557JoeKuoD6Init,
                dim19558JoeKuoD6Init,
                dim19559JoeKuoD6Init,
                dim19560JoeKuoD6Init,
                dim19561JoeKuoD6Init,
                dim19562JoeKuoD6Init,
                dim19563JoeKuoD6Init,
                dim19564JoeKuoD6Init,
                dim19565JoeKuoD6Init,
                dim19566JoeKuoD6Init,
                dim19567JoeKuoD6Init,
                dim19568JoeKuoD6Init,
                dim19569JoeKuoD6Init,
                dim19570JoeKuoD6Init,
                dim19571JoeKuoD6Init,
                dim19572JoeKuoD6Init,
                dim19573JoeKuoD6Init,
                dim19574JoeKuoD6Init,
                dim19575JoeKuoD6Init,
                dim19576JoeKuoD6Init,
                dim19577JoeKuoD6Init,
                dim19578JoeKuoD6Init,
                dim19579JoeKuoD6Init,
                dim19580JoeKuoD6Init,
                dim19581JoeKuoD6Init,
                dim19582JoeKuoD6Init,
                dim19583JoeKuoD6Init,
                dim19584JoeKuoD6Init,
                dim19585JoeKuoD6Init,
                dim19586JoeKuoD6Init,
                dim19587JoeKuoD6Init,
                dim19588JoeKuoD6Init,
                dim19589JoeKuoD6Init,
                dim19590JoeKuoD6Init,
                dim19591JoeKuoD6Init,
                dim19592JoeKuoD6Init,
                dim19593JoeKuoD6Init,
                dim19594JoeKuoD6Init,
                dim19595JoeKuoD6Init,
                dim19596JoeKuoD6Init,
                dim19597JoeKuoD6Init,
                dim19598JoeKuoD6Init,
                dim19599JoeKuoD6Init,
                dim19600JoeKuoD6Init,
                dim19601JoeKuoD6Init,
                dim19602JoeKuoD6Init,
                dim19603JoeKuoD6Init,
                dim19604JoeKuoD6Init,
                dim19605JoeKuoD6Init,
                dim19606JoeKuoD6Init,
                dim19607JoeKuoD6Init,
                dim19608JoeKuoD6Init,
                dim19609JoeKuoD6Init,
                dim19610JoeKuoD6Init,
                dim19611JoeKuoD6Init,
                dim19612JoeKuoD6Init,
                dim19613JoeKuoD6Init,
                dim19614JoeKuoD6Init,
                dim19615JoeKuoD6Init,
                dim19616JoeKuoD6Init,
                dim19617JoeKuoD6Init,
                dim19618JoeKuoD6Init,
                dim19619JoeKuoD6Init,
                dim19620JoeKuoD6Init,
                dim19621JoeKuoD6Init,
                dim19622JoeKuoD6Init,
                dim19623JoeKuoD6Init,
                dim19624JoeKuoD6Init,
                dim19625JoeKuoD6Init,
                dim19626JoeKuoD6Init,
                dim19627JoeKuoD6Init,
                dim19628JoeKuoD6Init,
                dim19629JoeKuoD6Init,
                dim19630JoeKuoD6Init,
                dim19631JoeKuoD6Init,
                dim19632JoeKuoD6Init,
                dim19633JoeKuoD6Init,
                dim19634JoeKuoD6Init,
                dim19635JoeKuoD6Init,
                dim19636JoeKuoD6Init,
                dim19637JoeKuoD6Init,
                dim19638JoeKuoD6Init,
                dim19639JoeKuoD6Init,
                dim19640JoeKuoD6Init,
                dim19641JoeKuoD6Init,
                dim19642JoeKuoD6Init,
                dim19643JoeKuoD6Init,
                dim19644JoeKuoD6Init,
                dim19645JoeKuoD6Init,
                dim19646JoeKuoD6Init,
                dim19647JoeKuoD6Init,
                dim19648JoeKuoD6Init,
                dim19649JoeKuoD6Init,
                dim19650JoeKuoD6Init,
                dim19651JoeKuoD6Init,
                dim19652JoeKuoD6Init,
                dim19653JoeKuoD6Init,
                dim19654JoeKuoD6Init,
                dim19655JoeKuoD6Init,
                dim19656JoeKuoD6Init,
                dim19657JoeKuoD6Init,
                dim19658JoeKuoD6Init,
                dim19659JoeKuoD6Init,
                dim19660JoeKuoD6Init,
                dim19661JoeKuoD6Init,
                dim19662JoeKuoD6Init,
                dim19663JoeKuoD6Init,
                dim19664JoeKuoD6Init,
                dim19665JoeKuoD6Init,
                dim19666JoeKuoD6Init,
                dim19667JoeKuoD6Init,
                dim19668JoeKuoD6Init,
                dim19669JoeKuoD6Init,
                dim19670JoeKuoD6Init,
                dim19671JoeKuoD6Init,
                dim19672JoeKuoD6Init,
                dim19673JoeKuoD6Init,
                dim19674JoeKuoD6Init,
                dim19675JoeKuoD6Init,
                dim19676JoeKuoD6Init,
                dim19677JoeKuoD6Init,
                dim19678JoeKuoD6Init,
                dim19679JoeKuoD6Init,
                dim19680JoeKuoD6Init,
                dim19681JoeKuoD6Init,
                dim19682JoeKuoD6Init,
                dim19683JoeKuoD6Init,
                dim19684JoeKuoD6Init,
                dim19685JoeKuoD6Init,
                dim19686JoeKuoD6Init,
                dim19687JoeKuoD6Init,
                dim19688JoeKuoD6Init,
                dim19689JoeKuoD6Init,
                dim19690JoeKuoD6Init,
                dim19691JoeKuoD6Init,
                dim19692JoeKuoD6Init,
                dim19693JoeKuoD6Init,
                dim19694JoeKuoD6Init,
                dim19695JoeKuoD6Init,
                dim19696JoeKuoD6Init,
                dim19697JoeKuoD6Init,
                dim19698JoeKuoD6Init,
                dim19699JoeKuoD6Init,
                dim19700JoeKuoD6Init,
                dim19701JoeKuoD6Init,
                dim19702JoeKuoD6Init,
                dim19703JoeKuoD6Init,
                dim19704JoeKuoD6Init,
                dim19705JoeKuoD6Init,
                dim19706JoeKuoD6Init,
                dim19707JoeKuoD6Init,
                dim19708JoeKuoD6Init,
                dim19709JoeKuoD6Init,
                dim19710JoeKuoD6Init,
                dim19711JoeKuoD6Init,
                dim19712JoeKuoD6Init,
                dim19713JoeKuoD6Init,
                dim19714JoeKuoD6Init,
                dim19715JoeKuoD6Init,
                dim19716JoeKuoD6Init,
                dim19717JoeKuoD6Init,
                dim19718JoeKuoD6Init,
                dim19719JoeKuoD6Init,
                dim19720JoeKuoD6Init,
                dim19721JoeKuoD6Init,
                dim19722JoeKuoD6Init,
                dim19723JoeKuoD6Init,
                dim19724JoeKuoD6Init,
                dim19725JoeKuoD6Init,
                dim19726JoeKuoD6Init,
                dim19727JoeKuoD6Init,
                dim19728JoeKuoD6Init,
                dim19729JoeKuoD6Init,
                dim19730JoeKuoD6Init,
                dim19731JoeKuoD6Init,
                dim19732JoeKuoD6Init,
                dim19733JoeKuoD6Init,
                dim19734JoeKuoD6Init,
                dim19735JoeKuoD6Init,
                dim19736JoeKuoD6Init,
                dim19737JoeKuoD6Init,
                dim19738JoeKuoD6Init,
                dim19739JoeKuoD6Init,
                dim19740JoeKuoD6Init,
                dim19741JoeKuoD6Init,
                dim19742JoeKuoD6Init,
                dim19743JoeKuoD6Init,
                dim19744JoeKuoD6Init,
                dim19745JoeKuoD6Init,
                dim19746JoeKuoD6Init,
                dim19747JoeKuoD6Init,
                dim19748JoeKuoD6Init,
                dim19749JoeKuoD6Init,
                dim19750JoeKuoD6Init,
                dim19751JoeKuoD6Init,
                dim19752JoeKuoD6Init,
                dim19753JoeKuoD6Init,
                dim19754JoeKuoD6Init,
                dim19755JoeKuoD6Init,
                dim19756JoeKuoD6Init,
                dim19757JoeKuoD6Init,
                dim19758JoeKuoD6Init,
                dim19759JoeKuoD6Init,
                dim19760JoeKuoD6Init,
                dim19761JoeKuoD6Init,
                dim19762JoeKuoD6Init,
                dim19763JoeKuoD6Init,
                dim19764JoeKuoD6Init,
                dim19765JoeKuoD6Init,
                dim19766JoeKuoD6Init,
                dim19767JoeKuoD6Init,
                dim19768JoeKuoD6Init,
                dim19769JoeKuoD6Init,
                dim19770JoeKuoD6Init,
                dim19771JoeKuoD6Init,
                dim19772JoeKuoD6Init,
                dim19773JoeKuoD6Init,
                dim19774JoeKuoD6Init,
                dim19775JoeKuoD6Init,
                dim19776JoeKuoD6Init,
                dim19777JoeKuoD6Init,
                dim19778JoeKuoD6Init,
                dim19779JoeKuoD6Init,
                dim19780JoeKuoD6Init,
                dim19781JoeKuoD6Init,
                dim19782JoeKuoD6Init,
                dim19783JoeKuoD6Init,
                dim19784JoeKuoD6Init,
                dim19785JoeKuoD6Init,
                dim19786JoeKuoD6Init,
                dim19787JoeKuoD6Init,
                dim19788JoeKuoD6Init,
                dim19789JoeKuoD6Init,
                dim19790JoeKuoD6Init,
                dim19791JoeKuoD6Init,
                dim19792JoeKuoD6Init,
                dim19793JoeKuoD6Init,
                dim19794JoeKuoD6Init,
                dim19795JoeKuoD6Init,
                dim19796JoeKuoD6Init,
                dim19797JoeKuoD6Init,
                dim19798JoeKuoD6Init,
                dim19799JoeKuoD6Init,
                dim19800JoeKuoD6Init,
                dim19801JoeKuoD6Init,
                dim19802JoeKuoD6Init,
                dim19803JoeKuoD6Init,
                dim19804JoeKuoD6Init,
                dim19805JoeKuoD6Init,
                dim19806JoeKuoD6Init,
                dim19807JoeKuoD6Init,
                dim19808JoeKuoD6Init,
                dim19809JoeKuoD6Init,
                dim19810JoeKuoD6Init,
                dim19811JoeKuoD6Init,
                dim19812JoeKuoD6Init,
                dim19813JoeKuoD6Init,
                dim19814JoeKuoD6Init,
                dim19815JoeKuoD6Init,
                dim19816JoeKuoD6Init,
                dim19817JoeKuoD6Init,
                dim19818JoeKuoD6Init,
                dim19819JoeKuoD6Init,
                dim19820JoeKuoD6Init,
                dim19821JoeKuoD6Init,
                dim19822JoeKuoD6Init,
                dim19823JoeKuoD6Init,
                dim19824JoeKuoD6Init,
                dim19825JoeKuoD6Init,
                dim19826JoeKuoD6Init,
                dim19827JoeKuoD6Init,
                dim19828JoeKuoD6Init,
                dim19829JoeKuoD6Init,
                dim19830JoeKuoD6Init,
                dim19831JoeKuoD6Init,
                dim19832JoeKuoD6Init,
                dim19833JoeKuoD6Init,
                dim19834JoeKuoD6Init,
                dim19835JoeKuoD6Init,
                dim19836JoeKuoD6Init,
                dim19837JoeKuoD6Init,
                dim19838JoeKuoD6Init,
                dim19839JoeKuoD6Init,
                dim19840JoeKuoD6Init,
                dim19841JoeKuoD6Init,
                dim19842JoeKuoD6Init,
                dim19843JoeKuoD6Init,
                dim19844JoeKuoD6Init,
                dim19845JoeKuoD6Init,
                dim19846JoeKuoD6Init,
                dim19847JoeKuoD6Init,
                dim19848JoeKuoD6Init,
                dim19849JoeKuoD6Init,
                dim19850JoeKuoD6Init,
                dim19851JoeKuoD6Init,
                dim19852JoeKuoD6Init,
                dim19853JoeKuoD6Init,
                dim19854JoeKuoD6Init,
                dim19855JoeKuoD6Init,
                dim19856JoeKuoD6Init,
                dim19857JoeKuoD6Init,
                dim19858JoeKuoD6Init,
                dim19859JoeKuoD6Init,
                dim19860JoeKuoD6Init,
                dim19861JoeKuoD6Init,
                dim19862JoeKuoD6Init,
                dim19863JoeKuoD6Init,
                dim19864JoeKuoD6Init,
                dim19865JoeKuoD6Init,
                dim19866JoeKuoD6Init,
                dim19867JoeKuoD6Init,
                dim19868JoeKuoD6Init,
                dim19869JoeKuoD6Init,
                dim19870JoeKuoD6Init,
                dim19871JoeKuoD6Init,
                dim19872JoeKuoD6Init,
                dim19873JoeKuoD6Init,
                dim19874JoeKuoD6Init,
                dim19875JoeKuoD6Init,
                dim19876JoeKuoD6Init,
                dim19877JoeKuoD6Init,
                dim19878JoeKuoD6Init,
                dim19879JoeKuoD6Init,
                dim19880JoeKuoD6Init,
                dim19881JoeKuoD6Init,
                dim19882JoeKuoD6Init,
                dim19883JoeKuoD6Init,
                dim19884JoeKuoD6Init,
                dim19885JoeKuoD6Init,
                dim19886JoeKuoD6Init,
                dim19887JoeKuoD6Init,
                dim19888JoeKuoD6Init,
                dim19889JoeKuoD6Init,
                dim19890JoeKuoD6Init,
                dim19891JoeKuoD6Init,
                dim19892JoeKuoD6Init,
                dim19893JoeKuoD6Init,
                dim19894JoeKuoD6Init,
                dim19895JoeKuoD6Init,
                dim19896JoeKuoD6Init,
                dim19897JoeKuoD6Init,
                dim19898JoeKuoD6Init,
                dim19899JoeKuoD6Init,
                dim19900JoeKuoD6Init,
                dim19901JoeKuoD6Init,
                dim19902JoeKuoD6Init,
                dim19903JoeKuoD6Init,
                dim19904JoeKuoD6Init,
                dim19905JoeKuoD6Init,
                dim19906JoeKuoD6Init,
                dim19907JoeKuoD6Init,
                dim19908JoeKuoD6Init,
                dim19909JoeKuoD6Init,
                dim19910JoeKuoD6Init,
                dim19911JoeKuoD6Init,
                dim19912JoeKuoD6Init,
                dim19913JoeKuoD6Init,
                dim19914JoeKuoD6Init,
                dim19915JoeKuoD6Init,
                dim19916JoeKuoD6Init,
                dim19917JoeKuoD6Init,
                dim19918JoeKuoD6Init,
                dim19919JoeKuoD6Init,
                dim19920JoeKuoD6Init,
                dim19921JoeKuoD6Init,
                dim19922JoeKuoD6Init,
                dim19923JoeKuoD6Init,
                dim19924JoeKuoD6Init,
                dim19925JoeKuoD6Init,
                dim19926JoeKuoD6Init,
                dim19927JoeKuoD6Init,
                dim19928JoeKuoD6Init,
                dim19929JoeKuoD6Init,
                dim19930JoeKuoD6Init,
                dim19931JoeKuoD6Init,
                dim19932JoeKuoD6Init,
                dim19933JoeKuoD6Init,
                dim19934JoeKuoD6Init,
                dim19935JoeKuoD6Init,
                dim19936JoeKuoD6Init,
                dim19937JoeKuoD6Init,
                dim19938JoeKuoD6Init,
                dim19939JoeKuoD6Init,
                dim19940JoeKuoD6Init,
                dim19941JoeKuoD6Init,
                dim19942JoeKuoD6Init,
                dim19943JoeKuoD6Init,
                dim19944JoeKuoD6Init,
                dim19945JoeKuoD6Init,
                dim19946JoeKuoD6Init,
                dim19947JoeKuoD6Init,
                dim19948JoeKuoD6Init,
                dim19949JoeKuoD6Init,
                dim19950JoeKuoD6Init,
                dim19951JoeKuoD6Init,
                dim19952JoeKuoD6Init,
                dim19953JoeKuoD6Init,
                dim19954JoeKuoD6Init,
                dim19955JoeKuoD6Init,
                dim19956JoeKuoD6Init,
                dim19957JoeKuoD6Init,
                dim19958JoeKuoD6Init,
                dim19959JoeKuoD6Init,
                dim19960JoeKuoD6Init,
                dim19961JoeKuoD6Init,
                dim19962JoeKuoD6Init,
                dim19963JoeKuoD6Init,
                dim19964JoeKuoD6Init,
                dim19965JoeKuoD6Init,
                dim19966JoeKuoD6Init,
                dim19967JoeKuoD6Init,
                dim19968JoeKuoD6Init,
                dim19969JoeKuoD6Init,
                dim19970JoeKuoD6Init,
                dim19971JoeKuoD6Init,
                dim19972JoeKuoD6Init,
                dim19973JoeKuoD6Init,
                dim19974JoeKuoD6Init,
                dim19975JoeKuoD6Init,
                dim19976JoeKuoD6Init,
                dim19977JoeKuoD6Init,
                dim19978JoeKuoD6Init,
                dim19979JoeKuoD6Init,
                dim19980JoeKuoD6Init,
                dim19981JoeKuoD6Init,
                dim19982JoeKuoD6Init,
                dim19983JoeKuoD6Init,
                dim19984JoeKuoD6Init,
                dim19985JoeKuoD6Init,
                dim19986JoeKuoD6Init,
                dim19987JoeKuoD6Init,
                dim19988JoeKuoD6Init,
                dim19989JoeKuoD6Init,
                dim19990JoeKuoD6Init,
                dim19991JoeKuoD6Init,
                dim19992JoeKuoD6Init,
                dim19993JoeKuoD6Init,
                dim19994JoeKuoD6Init,
                dim19995JoeKuoD6Init,
                dim19996JoeKuoD6Init,
                dim19997JoeKuoD6Init,
                dim19998JoeKuoD6Init,
                dim19999JoeKuoD6Init,
                dim20000JoeKuoD6Init,
                dim20001JoeKuoD6Init,
                dim20002JoeKuoD6Init,
                dim20003JoeKuoD6Init,
                dim20004JoeKuoD6Init,
                dim20005JoeKuoD6Init,
                dim20006JoeKuoD6Init,
                dim20007JoeKuoD6Init,
                dim20008JoeKuoD6Init,
                dim20009JoeKuoD6Init,
                dim20010JoeKuoD6Init,
                dim20011JoeKuoD6Init,
                dim20012JoeKuoD6Init,
                dim20013JoeKuoD6Init,
                dim20014JoeKuoD6Init,
                dim20015JoeKuoD6Init,
                dim20016JoeKuoD6Init,
                dim20017JoeKuoD6Init,
                dim20018JoeKuoD6Init,
                dim20019JoeKuoD6Init,
                dim20020JoeKuoD6Init,
                dim20021JoeKuoD6Init,
                dim20022JoeKuoD6Init,
                dim20023JoeKuoD6Init,
                dim20024JoeKuoD6Init,
                dim20025JoeKuoD6Init,
                dim20026JoeKuoD6Init,
                dim20027JoeKuoD6Init,
                dim20028JoeKuoD6Init,
                dim20029JoeKuoD6Init,
                dim20030JoeKuoD6Init,
                dim20031JoeKuoD6Init,
                dim20032JoeKuoD6Init,
                dim20033JoeKuoD6Init,
                dim20034JoeKuoD6Init,
                dim20035JoeKuoD6Init,
                dim20036JoeKuoD6Init,
                dim20037JoeKuoD6Init,
                dim20038JoeKuoD6Init,
                dim20039JoeKuoD6Init,
                dim20040JoeKuoD6Init,
                dim20041JoeKuoD6Init,
                dim20042JoeKuoD6Init,
                dim20043JoeKuoD6Init,
                dim20044JoeKuoD6Init,
                dim20045JoeKuoD6Init,
                dim20046JoeKuoD6Init,
                dim20047JoeKuoD6Init,
                dim20048JoeKuoD6Init,
                dim20049JoeKuoD6Init,
                dim20050JoeKuoD6Init,
                dim20051JoeKuoD6Init,
                dim20052JoeKuoD6Init,
                dim20053JoeKuoD6Init,
                dim20054JoeKuoD6Init,
                dim20055JoeKuoD6Init,
                dim20056JoeKuoD6Init,
                dim20057JoeKuoD6Init,
                dim20058JoeKuoD6Init,
                dim20059JoeKuoD6Init,
                dim20060JoeKuoD6Init,
                dim20061JoeKuoD6Init,
                dim20062JoeKuoD6Init,
                dim20063JoeKuoD6Init,
                dim20064JoeKuoD6Init,
                dim20065JoeKuoD6Init,
                dim20066JoeKuoD6Init,
                dim20067JoeKuoD6Init,
                dim20068JoeKuoD6Init,
                dim20069JoeKuoD6Init,
                dim20070JoeKuoD6Init,
                dim20071JoeKuoD6Init,
                dim20072JoeKuoD6Init,
                dim20073JoeKuoD6Init,
                dim20074JoeKuoD6Init,
                dim20075JoeKuoD6Init,
                dim20076JoeKuoD6Init,
                dim20077JoeKuoD6Init,
                dim20078JoeKuoD6Init,
                dim20079JoeKuoD6Init,
                dim20080JoeKuoD6Init,
                dim20081JoeKuoD6Init,
                dim20082JoeKuoD6Init,
                dim20083JoeKuoD6Init,
                dim20084JoeKuoD6Init,
                dim20085JoeKuoD6Init,
                dim20086JoeKuoD6Init,
                dim20087JoeKuoD6Init,
                dim20088JoeKuoD6Init,
                dim20089JoeKuoD6Init,
                dim20090JoeKuoD6Init,
                dim20091JoeKuoD6Init,
                dim20092JoeKuoD6Init,
                dim20093JoeKuoD6Init,
                dim20094JoeKuoD6Init,
                dim20095JoeKuoD6Init,
                dim20096JoeKuoD6Init,
                dim20097JoeKuoD6Init,
                dim20098JoeKuoD6Init,
                dim20099JoeKuoD6Init,
                dim20100JoeKuoD6Init,
                dim20101JoeKuoD6Init,
                dim20102JoeKuoD6Init,
                dim20103JoeKuoD6Init,
                dim20104JoeKuoD6Init,
                dim20105JoeKuoD6Init,
                dim20106JoeKuoD6Init,
                dim20107JoeKuoD6Init,
                dim20108JoeKuoD6Init,
                dim20109JoeKuoD6Init,
                dim20110JoeKuoD6Init,
                dim20111JoeKuoD6Init,
                dim20112JoeKuoD6Init,
                dim20113JoeKuoD6Init,
                dim20114JoeKuoD6Init,
                dim20115JoeKuoD6Init,
                dim20116JoeKuoD6Init,
                dim20117JoeKuoD6Init,
                dim20118JoeKuoD6Init,
                dim20119JoeKuoD6Init,
                dim20120JoeKuoD6Init,
                dim20121JoeKuoD6Init,
                dim20122JoeKuoD6Init,
                dim20123JoeKuoD6Init,
                dim20124JoeKuoD6Init,
                dim20125JoeKuoD6Init,
                dim20126JoeKuoD6Init,
                dim20127JoeKuoD6Init,
                dim20128JoeKuoD6Init,
                dim20129JoeKuoD6Init,
                dim20130JoeKuoD6Init,
                dim20131JoeKuoD6Init,
                dim20132JoeKuoD6Init,
                dim20133JoeKuoD6Init,
                dim20134JoeKuoD6Init,
                dim20135JoeKuoD6Init,
                dim20136JoeKuoD6Init,
                dim20137JoeKuoD6Init,
                dim20138JoeKuoD6Init,
                dim20139JoeKuoD6Init,
                dim20140JoeKuoD6Init,
                dim20141JoeKuoD6Init,
                dim20142JoeKuoD6Init,
                dim20143JoeKuoD6Init,
                dim20144JoeKuoD6Init,
                dim20145JoeKuoD6Init,
                dim20146JoeKuoD6Init,
                dim20147JoeKuoD6Init,
                dim20148JoeKuoD6Init,
                dim20149JoeKuoD6Init,
                dim20150JoeKuoD6Init,
                dim20151JoeKuoD6Init,
                dim20152JoeKuoD6Init,
                dim20153JoeKuoD6Init,
                dim20154JoeKuoD6Init,
                dim20155JoeKuoD6Init,
                dim20156JoeKuoD6Init,
                dim20157JoeKuoD6Init,
                dim20158JoeKuoD6Init,
                dim20159JoeKuoD6Init,
                dim20160JoeKuoD6Init,
                dim20161JoeKuoD6Init,
                dim20162JoeKuoD6Init,
                dim20163JoeKuoD6Init,
                dim20164JoeKuoD6Init,
                dim20165JoeKuoD6Init,
                dim20166JoeKuoD6Init,
                dim20167JoeKuoD6Init,
                dim20168JoeKuoD6Init,
                dim20169JoeKuoD6Init,
                dim20170JoeKuoD6Init,
                dim20171JoeKuoD6Init,
                dim20172JoeKuoD6Init,
                dim20173JoeKuoD6Init,
                dim20174JoeKuoD6Init,
                dim20175JoeKuoD6Init,
                dim20176JoeKuoD6Init,
                dim20177JoeKuoD6Init,
                dim20178JoeKuoD6Init,
                dim20179JoeKuoD6Init,
                dim20180JoeKuoD6Init,
                dim20181JoeKuoD6Init,
                dim20182JoeKuoD6Init,
                dim20183JoeKuoD6Init,
                dim20184JoeKuoD6Init,
                dim20185JoeKuoD6Init,
                dim20186JoeKuoD6Init,
                dim20187JoeKuoD6Init,
                dim20188JoeKuoD6Init,
                dim20189JoeKuoD6Init,
                dim20190JoeKuoD6Init,
                dim20191JoeKuoD6Init,
                dim20192JoeKuoD6Init,
                dim20193JoeKuoD6Init,
                dim20194JoeKuoD6Init,
                dim20195JoeKuoD6Init,
                dim20196JoeKuoD6Init,
                dim20197JoeKuoD6Init,
                dim20198JoeKuoD6Init,
                dim20199JoeKuoD6Init,
                dim20200JoeKuoD6Init,
                dim20201JoeKuoD6Init,
                dim20202JoeKuoD6Init,
                dim20203JoeKuoD6Init,
                dim20204JoeKuoD6Init,
                dim20205JoeKuoD6Init,
                dim20206JoeKuoD6Init,
                dim20207JoeKuoD6Init,
                dim20208JoeKuoD6Init,
                dim20209JoeKuoD6Init,
                dim20210JoeKuoD6Init,
                dim20211JoeKuoD6Init,
                dim20212JoeKuoD6Init,
                dim20213JoeKuoD6Init,
                dim20214JoeKuoD6Init,
                dim20215JoeKuoD6Init,
                dim20216JoeKuoD6Init,
                dim20217JoeKuoD6Init,
                dim20218JoeKuoD6Init,
                dim20219JoeKuoD6Init,
                dim20220JoeKuoD6Init,
                dim20221JoeKuoD6Init,
                dim20222JoeKuoD6Init,
                dim20223JoeKuoD6Init,
                dim20224JoeKuoD6Init,
                dim20225JoeKuoD6Init,
                dim20226JoeKuoD6Init,
                dim20227JoeKuoD6Init,
                dim20228JoeKuoD6Init,
                dim20229JoeKuoD6Init,
                dim20230JoeKuoD6Init,
                dim20231JoeKuoD6Init,
                dim20232JoeKuoD6Init,
                dim20233JoeKuoD6Init,
                dim20234JoeKuoD6Init,
                dim20235JoeKuoD6Init,
                dim20236JoeKuoD6Init,
                dim20237JoeKuoD6Init,
                dim20238JoeKuoD6Init,
                dim20239JoeKuoD6Init,
                dim20240JoeKuoD6Init,
                dim20241JoeKuoD6Init,
                dim20242JoeKuoD6Init,
                dim20243JoeKuoD6Init,
                dim20244JoeKuoD6Init,
                dim20245JoeKuoD6Init,
                dim20246JoeKuoD6Init,
                dim20247JoeKuoD6Init,
                dim20248JoeKuoD6Init,
                dim20249JoeKuoD6Init,
                dim20250JoeKuoD6Init,
                dim20251JoeKuoD6Init,
                dim20252JoeKuoD6Init,
                dim20253JoeKuoD6Init,
                dim20254JoeKuoD6Init,
                dim20255JoeKuoD6Init,
                dim20256JoeKuoD6Init,
                dim20257JoeKuoD6Init,
                dim20258JoeKuoD6Init,
                dim20259JoeKuoD6Init,
                dim20260JoeKuoD6Init,
                dim20261JoeKuoD6Init,
                dim20262JoeKuoD6Init,
                dim20263JoeKuoD6Init,
                dim20264JoeKuoD6Init,
                dim20265JoeKuoD6Init,
                dim20266JoeKuoD6Init,
                dim20267JoeKuoD6Init,
                dim20268JoeKuoD6Init,
                dim20269JoeKuoD6Init,
                dim20270JoeKuoD6Init,
                dim20271JoeKuoD6Init,
                dim20272JoeKuoD6Init,
                dim20273JoeKuoD6Init,
                dim20274JoeKuoD6Init,
                dim20275JoeKuoD6Init,
                dim20276JoeKuoD6Init,
                dim20277JoeKuoD6Init,
                dim20278JoeKuoD6Init,
                dim20279JoeKuoD6Init,
                dim20280JoeKuoD6Init,
                dim20281JoeKuoD6Init,
                dim20282JoeKuoD6Init,
                dim20283JoeKuoD6Init,
                dim20284JoeKuoD6Init,
                dim20285JoeKuoD6Init,
                dim20286JoeKuoD6Init,
                dim20287JoeKuoD6Init,
                dim20288JoeKuoD6Init,
                dim20289JoeKuoD6Init,
                dim20290JoeKuoD6Init,
                dim20291JoeKuoD6Init,
                dim20292JoeKuoD6Init,
                dim20293JoeKuoD6Init,
                dim20294JoeKuoD6Init,
                dim20295JoeKuoD6Init,
                dim20296JoeKuoD6Init,
                dim20297JoeKuoD6Init,
                dim20298JoeKuoD6Init,
                dim20299JoeKuoD6Init,
                dim20300JoeKuoD6Init,
                dim20301JoeKuoD6Init,
                dim20302JoeKuoD6Init,
                dim20303JoeKuoD6Init,
                dim20304JoeKuoD6Init,
                dim20305JoeKuoD6Init,
                dim20306JoeKuoD6Init,
                dim20307JoeKuoD6Init,
                dim20308JoeKuoD6Init,
                dim20309JoeKuoD6Init,
                dim20310JoeKuoD6Init,
                dim20311JoeKuoD6Init,
                dim20312JoeKuoD6Init,
                dim20313JoeKuoD6Init,
                dim20314JoeKuoD6Init,
                dim20315JoeKuoD6Init,
                dim20316JoeKuoD6Init,
                dim20317JoeKuoD6Init,
                dim20318JoeKuoD6Init,
                dim20319JoeKuoD6Init,
                dim20320JoeKuoD6Init,
                dim20321JoeKuoD6Init,
                dim20322JoeKuoD6Init,
                dim20323JoeKuoD6Init,
                dim20324JoeKuoD6Init,
                dim20325JoeKuoD6Init,
                dim20326JoeKuoD6Init,
                dim20327JoeKuoD6Init,
                dim20328JoeKuoD6Init,
                dim20329JoeKuoD6Init,
                dim20330JoeKuoD6Init,
                dim20331JoeKuoD6Init,
                dim20332JoeKuoD6Init,
                dim20333JoeKuoD6Init,
                dim20334JoeKuoD6Init,
                dim20335JoeKuoD6Init,
                dim20336JoeKuoD6Init,
                dim20337JoeKuoD6Init,
                dim20338JoeKuoD6Init,
                dim20339JoeKuoD6Init,
                dim20340JoeKuoD6Init,
                dim20341JoeKuoD6Init,
                dim20342JoeKuoD6Init,
                dim20343JoeKuoD6Init,
                dim20344JoeKuoD6Init,
                dim20345JoeKuoD6Init,
                dim20346JoeKuoD6Init,
                dim20347JoeKuoD6Init,
                dim20348JoeKuoD6Init,
                dim20349JoeKuoD6Init,
                dim20350JoeKuoD6Init,
                dim20351JoeKuoD6Init,
                dim20352JoeKuoD6Init,
                dim20353JoeKuoD6Init,
                dim20354JoeKuoD6Init,
                dim20355JoeKuoD6Init,
                dim20356JoeKuoD6Init,
                dim20357JoeKuoD6Init,
                dim20358JoeKuoD6Init,
                dim20359JoeKuoD6Init,
                dim20360JoeKuoD6Init,
                dim20361JoeKuoD6Init,
                dim20362JoeKuoD6Init,
                dim20363JoeKuoD6Init,
                dim20364JoeKuoD6Init,
                dim20365JoeKuoD6Init,
                dim20366JoeKuoD6Init,
                dim20367JoeKuoD6Init,
                dim20368JoeKuoD6Init,
                dim20369JoeKuoD6Init,
                dim20370JoeKuoD6Init,
                dim20371JoeKuoD6Init,
                dim20372JoeKuoD6Init,
                dim20373JoeKuoD6Init,
                dim20374JoeKuoD6Init,
                dim20375JoeKuoD6Init,
                dim20376JoeKuoD6Init,
                dim20377JoeKuoD6Init,
                dim20378JoeKuoD6Init,
                dim20379JoeKuoD6Init,
                dim20380JoeKuoD6Init,
                dim20381JoeKuoD6Init,
                dim20382JoeKuoD6Init,
                dim20383JoeKuoD6Init,
                dim20384JoeKuoD6Init,
                dim20385JoeKuoD6Init,
                dim20386JoeKuoD6Init,
                dim20387JoeKuoD6Init,
                dim20388JoeKuoD6Init,
                dim20389JoeKuoD6Init,
                dim20390JoeKuoD6Init,
                dim20391JoeKuoD6Init,
                dim20392JoeKuoD6Init,
                dim20393JoeKuoD6Init,
                dim20394JoeKuoD6Init,
                dim20395JoeKuoD6Init,
                dim20396JoeKuoD6Init,
                dim20397JoeKuoD6Init,
                dim20398JoeKuoD6Init,
                dim20399JoeKuoD6Init,
                dim20400JoeKuoD6Init,
                dim20401JoeKuoD6Init,
                dim20402JoeKuoD6Init,
                dim20403JoeKuoD6Init,
                dim20404JoeKuoD6Init,
                dim20405JoeKuoD6Init,
                dim20406JoeKuoD6Init,
                dim20407JoeKuoD6Init,
                dim20408JoeKuoD6Init,
                dim20409JoeKuoD6Init,
                dim20410JoeKuoD6Init,
                dim20411JoeKuoD6Init,
                dim20412JoeKuoD6Init,
                dim20413JoeKuoD6Init,
                dim20414JoeKuoD6Init,
                dim20415JoeKuoD6Init,
                dim20416JoeKuoD6Init,
                dim20417JoeKuoD6Init,
                dim20418JoeKuoD6Init,
                dim20419JoeKuoD6Init,
                dim20420JoeKuoD6Init,
                dim20421JoeKuoD6Init,
                dim20422JoeKuoD6Init,
                dim20423JoeKuoD6Init,
                dim20424JoeKuoD6Init,
                dim20425JoeKuoD6Init,
                dim20426JoeKuoD6Init,
                dim20427JoeKuoD6Init,
                dim20428JoeKuoD6Init,
                dim20429JoeKuoD6Init,
                dim20430JoeKuoD6Init,
                dim20431JoeKuoD6Init,
                dim20432JoeKuoD6Init,
                dim20433JoeKuoD6Init,
                dim20434JoeKuoD6Init,
                dim20435JoeKuoD6Init,
                dim20436JoeKuoD6Init,
                dim20437JoeKuoD6Init,
                dim20438JoeKuoD6Init,
                dim20439JoeKuoD6Init,
                dim20440JoeKuoD6Init,
                dim20441JoeKuoD6Init,
                dim20442JoeKuoD6Init,
                dim20443JoeKuoD6Init,
                dim20444JoeKuoD6Init,
                dim20445JoeKuoD6Init,
                dim20446JoeKuoD6Init,
                dim20447JoeKuoD6Init,
                dim20448JoeKuoD6Init,
                dim20449JoeKuoD6Init,
                dim20450JoeKuoD6Init,
                dim20451JoeKuoD6Init,
                dim20452JoeKuoD6Init,
                dim20453JoeKuoD6Init,
                dim20454JoeKuoD6Init,
                dim20455JoeKuoD6Init,
                dim20456JoeKuoD6Init,
                dim20457JoeKuoD6Init,
                dim20458JoeKuoD6Init,
                dim20459JoeKuoD6Init,
                dim20460JoeKuoD6Init,
                dim20461JoeKuoD6Init,
                dim20462JoeKuoD6Init,
                dim20463JoeKuoD6Init,
                dim20464JoeKuoD6Init,
                dim20465JoeKuoD6Init,
                dim20466JoeKuoD6Init,
                dim20467JoeKuoD6Init,
                dim20468JoeKuoD6Init,
                dim20469JoeKuoD6Init,
                dim20470JoeKuoD6Init,
                dim20471JoeKuoD6Init,
                dim20472JoeKuoD6Init,
                dim20473JoeKuoD6Init,
                dim20474JoeKuoD6Init,
                dim20475JoeKuoD6Init,
                dim20476JoeKuoD6Init,
                dim20477JoeKuoD6Init,
                dim20478JoeKuoD6Init,
                dim20479JoeKuoD6Init,
                dim20480JoeKuoD6Init,
                dim20481JoeKuoD6Init,
                dim20482JoeKuoD6Init,
                dim20483JoeKuoD6Init,
                dim20484JoeKuoD6Init,
                dim20485JoeKuoD6Init,
                dim20486JoeKuoD6Init,
                dim20487JoeKuoD6Init,
                dim20488JoeKuoD6Init,
                dim20489JoeKuoD6Init,
                dim20490JoeKuoD6Init,
                dim20491JoeKuoD6Init,
                dim20492JoeKuoD6Init,
                dim20493JoeKuoD6Init,
                dim20494JoeKuoD6Init,
                dim20495JoeKuoD6Init,
                dim20496JoeKuoD6Init,
                dim20497JoeKuoD6Init,
                dim20498JoeKuoD6Init,
                dim20499JoeKuoD6Init,
                dim20500JoeKuoD6Init,
                dim20501JoeKuoD6Init,
                dim20502JoeKuoD6Init,
                dim20503JoeKuoD6Init,
                dim20504JoeKuoD6Init,
                dim20505JoeKuoD6Init,
                dim20506JoeKuoD6Init,
                dim20507JoeKuoD6Init,
                dim20508JoeKuoD6Init,
                dim20509JoeKuoD6Init,
                dim20510JoeKuoD6Init,
                dim20511JoeKuoD6Init,
                dim20512JoeKuoD6Init,
                dim20513JoeKuoD6Init,
                dim20514JoeKuoD6Init,
                dim20515JoeKuoD6Init,
                dim20516JoeKuoD6Init,
                dim20517JoeKuoD6Init,
                dim20518JoeKuoD6Init,
                dim20519JoeKuoD6Init,
                dim20520JoeKuoD6Init,
                dim20521JoeKuoD6Init,
                dim20522JoeKuoD6Init,
                dim20523JoeKuoD6Init,
                dim20524JoeKuoD6Init,
                dim20525JoeKuoD6Init,
                dim20526JoeKuoD6Init,
                dim20527JoeKuoD6Init,
                dim20528JoeKuoD6Init,
                dim20529JoeKuoD6Init,
                dim20530JoeKuoD6Init,
                dim20531JoeKuoD6Init,
                dim20532JoeKuoD6Init,
                dim20533JoeKuoD6Init,
                dim20534JoeKuoD6Init,
                dim20535JoeKuoD6Init,
                dim20536JoeKuoD6Init,
                dim20537JoeKuoD6Init,
                dim20538JoeKuoD6Init,
                dim20539JoeKuoD6Init,
                dim20540JoeKuoD6Init,
                dim20541JoeKuoD6Init,
                dim20542JoeKuoD6Init,
                dim20543JoeKuoD6Init,
                dim20544JoeKuoD6Init,
                dim20545JoeKuoD6Init,
                dim20546JoeKuoD6Init,
                dim20547JoeKuoD6Init,
                dim20548JoeKuoD6Init,
                dim20549JoeKuoD6Init,
                dim20550JoeKuoD6Init,
                dim20551JoeKuoD6Init,
                dim20552JoeKuoD6Init,
                dim20553JoeKuoD6Init,
                dim20554JoeKuoD6Init,
                dim20555JoeKuoD6Init,
                dim20556JoeKuoD6Init,
                dim20557JoeKuoD6Init,
                dim20558JoeKuoD6Init,
                dim20559JoeKuoD6Init,
                dim20560JoeKuoD6Init,
                dim20561JoeKuoD6Init,
                dim20562JoeKuoD6Init,
                dim20563JoeKuoD6Init,
                dim20564JoeKuoD6Init,
                dim20565JoeKuoD6Init,
                dim20566JoeKuoD6Init,
                dim20567JoeKuoD6Init,
                dim20568JoeKuoD6Init,
                dim20569JoeKuoD6Init,
                dim20570JoeKuoD6Init,
                dim20571JoeKuoD6Init,
                dim20572JoeKuoD6Init,
                dim20573JoeKuoD6Init,
                dim20574JoeKuoD6Init,
                dim20575JoeKuoD6Init,
                dim20576JoeKuoD6Init,
                dim20577JoeKuoD6Init,
                dim20578JoeKuoD6Init,
                dim20579JoeKuoD6Init,
                dim20580JoeKuoD6Init,
                dim20581JoeKuoD6Init,
                dim20582JoeKuoD6Init,
                dim20583JoeKuoD6Init,
                dim20584JoeKuoD6Init,
                dim20585JoeKuoD6Init,
                dim20586JoeKuoD6Init,
                dim20587JoeKuoD6Init,
                dim20588JoeKuoD6Init,
                dim20589JoeKuoD6Init,
                dim20590JoeKuoD6Init,
                dim20591JoeKuoD6Init,
                dim20592JoeKuoD6Init,
                dim20593JoeKuoD6Init,
                dim20594JoeKuoD6Init,
                dim20595JoeKuoD6Init,
                dim20596JoeKuoD6Init,
                dim20597JoeKuoD6Init,
                dim20598JoeKuoD6Init,
                dim20599JoeKuoD6Init,
                dim20600JoeKuoD6Init,
                dim20601JoeKuoD6Init,
                dim20602JoeKuoD6Init,
                dim20603JoeKuoD6Init,
                dim20604JoeKuoD6Init,
                dim20605JoeKuoD6Init,
                dim20606JoeKuoD6Init,
                dim20607JoeKuoD6Init,
                dim20608JoeKuoD6Init,
                dim20609JoeKuoD6Init,
                dim20610JoeKuoD6Init,
                dim20611JoeKuoD6Init,
                dim20612JoeKuoD6Init,
                dim20613JoeKuoD6Init,
                dim20614JoeKuoD6Init,
                dim20615JoeKuoD6Init,
                dim20616JoeKuoD6Init,
                dim20617JoeKuoD6Init,
                dim20618JoeKuoD6Init,
                dim20619JoeKuoD6Init,
                dim20620JoeKuoD6Init,
                dim20621JoeKuoD6Init,
                dim20622JoeKuoD6Init,
                dim20623JoeKuoD6Init,
                dim20624JoeKuoD6Init,
                dim20625JoeKuoD6Init,
                dim20626JoeKuoD6Init,
                dim20627JoeKuoD6Init,
                dim20628JoeKuoD6Init,
                dim20629JoeKuoD6Init,
                dim20630JoeKuoD6Init,
                dim20631JoeKuoD6Init,
                dim20632JoeKuoD6Init,
                dim20633JoeKuoD6Init,
                dim20634JoeKuoD6Init,
                dim20635JoeKuoD6Init,
                dim20636JoeKuoD6Init,
                dim20637JoeKuoD6Init,
                dim20638JoeKuoD6Init,
                dim20639JoeKuoD6Init,
                dim20640JoeKuoD6Init,
                dim20641JoeKuoD6Init,
                dim20642JoeKuoD6Init,
                dim20643JoeKuoD6Init,
                dim20644JoeKuoD6Init,
                dim20645JoeKuoD6Init,
                dim20646JoeKuoD6Init,
                dim20647JoeKuoD6Init,
                dim20648JoeKuoD6Init,
                dim20649JoeKuoD6Init,
                dim20650JoeKuoD6Init,
                dim20651JoeKuoD6Init,
                dim20652JoeKuoD6Init,
                dim20653JoeKuoD6Init,
                dim20654JoeKuoD6Init,
                dim20655JoeKuoD6Init,
                dim20656JoeKuoD6Init,
                dim20657JoeKuoD6Init,
                dim20658JoeKuoD6Init,
                dim20659JoeKuoD6Init,
                dim20660JoeKuoD6Init,
                dim20661JoeKuoD6Init,
                dim20662JoeKuoD6Init,
                dim20663JoeKuoD6Init,
                dim20664JoeKuoD6Init,
                dim20665JoeKuoD6Init,
                dim20666JoeKuoD6Init,
                dim20667JoeKuoD6Init,
                dim20668JoeKuoD6Init,
                dim20669JoeKuoD6Init,
                dim20670JoeKuoD6Init,
                dim20671JoeKuoD6Init,
                dim20672JoeKuoD6Init,
                dim20673JoeKuoD6Init,
                dim20674JoeKuoD6Init,
                dim20675JoeKuoD6Init,
                dim20676JoeKuoD6Init,
                dim20677JoeKuoD6Init,
                dim20678JoeKuoD6Init,
                dim20679JoeKuoD6Init,
                dim20680JoeKuoD6Init,
                dim20681JoeKuoD6Init,
                dim20682JoeKuoD6Init,
                dim20683JoeKuoD6Init,
                dim20684JoeKuoD6Init,
                dim20685JoeKuoD6Init,
                dim20686JoeKuoD6Init,
                dim20687JoeKuoD6Init,
                dim20688JoeKuoD6Init,
                dim20689JoeKuoD6Init,
                dim20690JoeKuoD6Init,
                dim20691JoeKuoD6Init,
                dim20692JoeKuoD6Init,
                dim20693JoeKuoD6Init,
                dim20694JoeKuoD6Init,
                dim20695JoeKuoD6Init,
                dim20696JoeKuoD6Init,
                dim20697JoeKuoD6Init,
                dim20698JoeKuoD6Init,
                dim20699JoeKuoD6Init,
                dim20700JoeKuoD6Init,
                dim20701JoeKuoD6Init,
                dim20702JoeKuoD6Init,
                dim20703JoeKuoD6Init,
                dim20704JoeKuoD6Init,
                dim20705JoeKuoD6Init,
                dim20706JoeKuoD6Init,
                dim20707JoeKuoD6Init,
                dim20708JoeKuoD6Init,
                dim20709JoeKuoD6Init,
                dim20710JoeKuoD6Init,
                dim20711JoeKuoD6Init,
                dim20712JoeKuoD6Init,
                dim20713JoeKuoD6Init,
                dim20714JoeKuoD6Init,
                dim20715JoeKuoD6Init,
                dim20716JoeKuoD6Init,
                dim20717JoeKuoD6Init,
                dim20718JoeKuoD6Init,
                dim20719JoeKuoD6Init,
                dim20720JoeKuoD6Init,
                dim20721JoeKuoD6Init,
                dim20722JoeKuoD6Init,
                dim20723JoeKuoD6Init,
                dim20724JoeKuoD6Init,
                dim20725JoeKuoD6Init,
                dim20726JoeKuoD6Init,
                dim20727JoeKuoD6Init,
                dim20728JoeKuoD6Init,
                dim20729JoeKuoD6Init,
                dim20730JoeKuoD6Init,
                dim20731JoeKuoD6Init,
                dim20732JoeKuoD6Init,
                dim20733JoeKuoD6Init,
                dim20734JoeKuoD6Init,
                dim20735JoeKuoD6Init,
                dim20736JoeKuoD6Init,
                dim20737JoeKuoD6Init,
                dim20738JoeKuoD6Init,
                dim20739JoeKuoD6Init,
                dim20740JoeKuoD6Init,
                dim20741JoeKuoD6Init,
                dim20742JoeKuoD6Init,
                dim20743JoeKuoD6Init,
                dim20744JoeKuoD6Init,
                dim20745JoeKuoD6Init,
                dim20746JoeKuoD6Init,
                dim20747JoeKuoD6Init,
                dim20748JoeKuoD6Init,
                dim20749JoeKuoD6Init,
                dim20750JoeKuoD6Init,
                dim20751JoeKuoD6Init,
                dim20752JoeKuoD6Init,
                dim20753JoeKuoD6Init,
                dim20754JoeKuoD6Init,
                dim20755JoeKuoD6Init,
                dim20756JoeKuoD6Init,
                dim20757JoeKuoD6Init,
                dim20758JoeKuoD6Init,
                dim20759JoeKuoD6Init,
                dim20760JoeKuoD6Init,
                dim20761JoeKuoD6Init,
                dim20762JoeKuoD6Init,
                dim20763JoeKuoD6Init,
                dim20764JoeKuoD6Init,
                dim20765JoeKuoD6Init,
                dim20766JoeKuoD6Init,
                dim20767JoeKuoD6Init,
                dim20768JoeKuoD6Init,
                dim20769JoeKuoD6Init,
                dim20770JoeKuoD6Init,
                dim20771JoeKuoD6Init,
                dim20772JoeKuoD6Init,
                dim20773JoeKuoD6Init,
                dim20774JoeKuoD6Init,
                dim20775JoeKuoD6Init,
                dim20776JoeKuoD6Init,
                dim20777JoeKuoD6Init,
                dim20778JoeKuoD6Init,
                dim20779JoeKuoD6Init,
                dim20780JoeKuoD6Init,
                dim20781JoeKuoD6Init,
                dim20782JoeKuoD6Init,
                dim20783JoeKuoD6Init,
                dim20784JoeKuoD6Init,
                dim20785JoeKuoD6Init,
                dim20786JoeKuoD6Init,
                dim20787JoeKuoD6Init,
                dim20788JoeKuoD6Init,
                dim20789JoeKuoD6Init,
                dim20790JoeKuoD6Init,
                dim20791JoeKuoD6Init,
                dim20792JoeKuoD6Init,
                dim20793JoeKuoD6Init,
                dim20794JoeKuoD6Init,
                dim20795JoeKuoD6Init,
                dim20796JoeKuoD6Init,
                dim20797JoeKuoD6Init,
                dim20798JoeKuoD6Init,
                dim20799JoeKuoD6Init,
                dim20800JoeKuoD6Init,
                dim20801JoeKuoD6Init,
                dim20802JoeKuoD6Init,
                dim20803JoeKuoD6Init,
                dim20804JoeKuoD6Init,
                dim20805JoeKuoD6Init,
                dim20806JoeKuoD6Init,
                dim20807JoeKuoD6Init,
                dim20808JoeKuoD6Init,
                dim20809JoeKuoD6Init,
                dim20810JoeKuoD6Init,
                dim20811JoeKuoD6Init,
                dim20812JoeKuoD6Init,
                dim20813JoeKuoD6Init,
                dim20814JoeKuoD6Init,
                dim20815JoeKuoD6Init,
                dim20816JoeKuoD6Init,
                dim20817JoeKuoD6Init,
                dim20818JoeKuoD6Init,
                dim20819JoeKuoD6Init,
                dim20820JoeKuoD6Init,
                dim20821JoeKuoD6Init,
                dim20822JoeKuoD6Init,
                dim20823JoeKuoD6Init,
                dim20824JoeKuoD6Init,
                dim20825JoeKuoD6Init,
                dim20826JoeKuoD6Init,
                dim20827JoeKuoD6Init,
                dim20828JoeKuoD6Init,
                dim20829JoeKuoD6Init,
                dim20830JoeKuoD6Init,
                dim20831JoeKuoD6Init,
                dim20832JoeKuoD6Init,
                dim20833JoeKuoD6Init,
                dim20834JoeKuoD6Init,
                dim20835JoeKuoD6Init,
                dim20836JoeKuoD6Init,
                dim20837JoeKuoD6Init,
                dim20838JoeKuoD6Init,
                dim20839JoeKuoD6Init,
                dim20840JoeKuoD6Init,
                dim20841JoeKuoD6Init,
                dim20842JoeKuoD6Init,
                dim20843JoeKuoD6Init,
                dim20844JoeKuoD6Init,
                dim20845JoeKuoD6Init,
                dim20846JoeKuoD6Init,
                dim20847JoeKuoD6Init,
                dim20848JoeKuoD6Init,
                dim20849JoeKuoD6Init,
                dim20850JoeKuoD6Init,
                dim20851JoeKuoD6Init,
                dim20852JoeKuoD6Init,
                dim20853JoeKuoD6Init,
                dim20854JoeKuoD6Init,
                dim20855JoeKuoD6Init,
                dim20856JoeKuoD6Init,
                dim20857JoeKuoD6Init,
                dim20858JoeKuoD6Init,
                dim20859JoeKuoD6Init,
                dim20860JoeKuoD6Init,
                dim20861JoeKuoD6Init,
                dim20862JoeKuoD6Init,
                dim20863JoeKuoD6Init,
                dim20864JoeKuoD6Init,
                dim20865JoeKuoD6Init,
                dim20866JoeKuoD6Init,
                dim20867JoeKuoD6Init,
                dim20868JoeKuoD6Init,
                dim20869JoeKuoD6Init,
                dim20870JoeKuoD6Init,
                dim20871JoeKuoD6Init,
                dim20872JoeKuoD6Init,
                dim20873JoeKuoD6Init,
                dim20874JoeKuoD6Init,
                dim20875JoeKuoD6Init,
                dim20876JoeKuoD6Init,
                dim20877JoeKuoD6Init,
                dim20878JoeKuoD6Init,
                dim20879JoeKuoD6Init,
                dim20880JoeKuoD6Init,
                dim20881JoeKuoD6Init,
                dim20882JoeKuoD6Init,
                dim20883JoeKuoD6Init,
                dim20884JoeKuoD6Init,
                dim20885JoeKuoD6Init,
                dim20886JoeKuoD6Init,
                dim20887JoeKuoD6Init,
                dim20888JoeKuoD6Init,
                dim20889JoeKuoD6Init,
                dim20890JoeKuoD6Init,
                dim20891JoeKuoD6Init,
                dim20892JoeKuoD6Init,
                dim20893JoeKuoD6Init,
                dim20894JoeKuoD6Init,
                dim20895JoeKuoD6Init,
                dim20896JoeKuoD6Init,
                dim20897JoeKuoD6Init,
                dim20898JoeKuoD6Init,
                dim20899JoeKuoD6Init,
                dim20900JoeKuoD6Init,
                dim20901JoeKuoD6Init,
                dim20902JoeKuoD6Init,
                dim20903JoeKuoD6Init,
                dim20904JoeKuoD6Init,
                dim20905JoeKuoD6Init,
                dim20906JoeKuoD6Init,
                dim20907JoeKuoD6Init,
                dim20908JoeKuoD6Init,
                dim20909JoeKuoD6Init,
                dim20910JoeKuoD6Init,
                dim20911JoeKuoD6Init,
                dim20912JoeKuoD6Init,
                dim20913JoeKuoD6Init,
                dim20914JoeKuoD6Init,
                dim20915JoeKuoD6Init,
                dim20916JoeKuoD6Init,
                dim20917JoeKuoD6Init,
                dim20918JoeKuoD6Init,
                dim20919JoeKuoD6Init,
                dim20920JoeKuoD6Init,
                dim20921JoeKuoD6Init,
                dim20922JoeKuoD6Init,
                dim20923JoeKuoD6Init,
                dim20924JoeKuoD6Init,
                dim20925JoeKuoD6Init,
                dim20926JoeKuoD6Init,
                dim20927JoeKuoD6Init,
                dim20928JoeKuoD6Init,
                dim20929JoeKuoD6Init,
                dim20930JoeKuoD6Init,
                dim20931JoeKuoD6Init,
                dim20932JoeKuoD6Init,
                dim20933JoeKuoD6Init,
                dim20934JoeKuoD6Init,
                dim20935JoeKuoD6Init,
                dim20936JoeKuoD6Init,
                dim20937JoeKuoD6Init,
                dim20938JoeKuoD6Init,
                dim20939JoeKuoD6Init,
                dim20940JoeKuoD6Init,
                dim20941JoeKuoD6Init,
                dim20942JoeKuoD6Init,
                dim20943JoeKuoD6Init,
                dim20944JoeKuoD6Init,
                dim20945JoeKuoD6Init,
                dim20946JoeKuoD6Init,
                dim20947JoeKuoD6Init,
                dim20948JoeKuoD6Init,
                dim20949JoeKuoD6Init,
                dim20950JoeKuoD6Init,
                dim20951JoeKuoD6Init,
                dim20952JoeKuoD6Init,
                dim20953JoeKuoD6Init,
                dim20954JoeKuoD6Init,
                dim20955JoeKuoD6Init,
                dim20956JoeKuoD6Init,
                dim20957JoeKuoD6Init,
                dim20958JoeKuoD6Init,
                dim20959JoeKuoD6Init,
                dim20960JoeKuoD6Init,
                dim20961JoeKuoD6Init,
                dim20962JoeKuoD6Init,
                dim20963JoeKuoD6Init,
                dim20964JoeKuoD6Init,
                dim20965JoeKuoD6Init,
                dim20966JoeKuoD6Init,
                dim20967JoeKuoD6Init,
                dim20968JoeKuoD6Init,
                dim20969JoeKuoD6Init,
                dim20970JoeKuoD6Init,
                dim20971JoeKuoD6Init,
                dim20972JoeKuoD6Init,
                dim20973JoeKuoD6Init,
                dim20974JoeKuoD6Init,
                dim20975JoeKuoD6Init,
                dim20976JoeKuoD6Init,
                dim20977JoeKuoD6Init,
                dim20978JoeKuoD6Init,
                dim20979JoeKuoD6Init,
                dim20980JoeKuoD6Init,
                dim20981JoeKuoD6Init,
                dim20982JoeKuoD6Init,
                dim20983JoeKuoD6Init,
                dim20984JoeKuoD6Init,
                dim20985JoeKuoD6Init,
                dim20986JoeKuoD6Init,
                dim20987JoeKuoD6Init,
                dim20988JoeKuoD6Init,
                dim20989JoeKuoD6Init,
                dim20990JoeKuoD6Init,
                dim20991JoeKuoD6Init,
                dim20992JoeKuoD6Init,
                dim20993JoeKuoD6Init,
                dim20994JoeKuoD6Init,
                dim20995JoeKuoD6Init,
                dim20996JoeKuoD6Init,
                dim20997JoeKuoD6Init,
                dim20998JoeKuoD6Init,
                dim20999JoeKuoD6Init,
                dim21000JoeKuoD6Init,
                dim21001JoeKuoD6Init,
                dim21002JoeKuoD6Init,
                dim21003JoeKuoD6Init,
                dim21004JoeKuoD6Init,
                dim21005JoeKuoD6Init,
                dim21006JoeKuoD6Init,
                dim21007JoeKuoD6Init,
                dim21008JoeKuoD6Init,
                dim21009JoeKuoD6Init,
                dim21010JoeKuoD6Init,
                dim21011JoeKuoD6Init,
                dim21012JoeKuoD6Init,
                dim21013JoeKuoD6Init,
                dim21014JoeKuoD6Init,
                dim21015JoeKuoD6Init,
                dim21016JoeKuoD6Init,
                dim21017JoeKuoD6Init,
                dim21018JoeKuoD6Init,
                dim21019JoeKuoD6Init,
                dim21020JoeKuoD6Init,
                dim21021JoeKuoD6Init,
                dim21022JoeKuoD6Init,
                dim21023JoeKuoD6Init,
                dim21024JoeKuoD6Init,
                dim21025JoeKuoD6Init,
                dim21026JoeKuoD6Init,
                dim21027JoeKuoD6Init,
                dim21028JoeKuoD6Init,
                dim21029JoeKuoD6Init,
                dim21030JoeKuoD6Init,
                dim21031JoeKuoD6Init,
                dim21032JoeKuoD6Init,
                dim21033JoeKuoD6Init,
                dim21034JoeKuoD6Init,
                dim21035JoeKuoD6Init,
                dim21036JoeKuoD6Init,
                dim21037JoeKuoD6Init,
                dim21038JoeKuoD6Init,
                dim21039JoeKuoD6Init,
                dim21040JoeKuoD6Init,
                dim21041JoeKuoD6Init,
                dim21042JoeKuoD6Init,
                dim21043JoeKuoD6Init,
                dim21044JoeKuoD6Init,
                dim21045JoeKuoD6Init,
                dim21046JoeKuoD6Init,
                dim21047JoeKuoD6Init,
                dim21048JoeKuoD6Init,
                dim21049JoeKuoD6Init,
                dim21050JoeKuoD6Init,
                dim21051JoeKuoD6Init,
                dim21052JoeKuoD6Init,
                dim21053JoeKuoD6Init,
                dim21054JoeKuoD6Init,
                dim21055JoeKuoD6Init,
                dim21056JoeKuoD6Init,
                dim21057JoeKuoD6Init,
                dim21058JoeKuoD6Init,
                dim21059JoeKuoD6Init,
                dim21060JoeKuoD6Init,
                dim21061JoeKuoD6Init,
                dim21062JoeKuoD6Init,
                dim21063JoeKuoD6Init,
                dim21064JoeKuoD6Init,
                dim21065JoeKuoD6Init,
                dim21066JoeKuoD6Init,
                dim21067JoeKuoD6Init,
                dim21068JoeKuoD6Init,
                dim21069JoeKuoD6Init,
                dim21070JoeKuoD6Init,
                dim21071JoeKuoD6Init,
                dim21072JoeKuoD6Init,
                dim21073JoeKuoD6Init,
                dim21074JoeKuoD6Init,
                dim21075JoeKuoD6Init,
                dim21076JoeKuoD6Init,
                dim21077JoeKuoD6Init,
                dim21078JoeKuoD6Init,
                dim21079JoeKuoD6Init,
                dim21080JoeKuoD6Init,
                dim21081JoeKuoD6Init,
                dim21082JoeKuoD6Init,
                dim21083JoeKuoD6Init,
                dim21084JoeKuoD6Init,
                dim21085JoeKuoD6Init,
                dim21086JoeKuoD6Init,
                dim21087JoeKuoD6Init,
                dim21088JoeKuoD6Init,
                dim21089JoeKuoD6Init,
                dim21090JoeKuoD6Init,
                dim21091JoeKuoD6Init,
                dim21092JoeKuoD6Init,
                dim21093JoeKuoD6Init,
                dim21094JoeKuoD6Init,
                dim21095JoeKuoD6Init,
                dim21096JoeKuoD6Init,
                dim21097JoeKuoD6Init,
                dim21098JoeKuoD6Init,
                dim21099JoeKuoD6Init,
                dim21100JoeKuoD6Init,
                dim21101JoeKuoD6Init,
                dim21102JoeKuoD6Init,
                dim21103JoeKuoD6Init,
                dim21104JoeKuoD6Init,
                dim21105JoeKuoD6Init,
                dim21106JoeKuoD6Init,
                dim21107JoeKuoD6Init,
                dim21108JoeKuoD6Init,
                dim21109JoeKuoD6Init,
                dim21110JoeKuoD6Init,
                dim21111JoeKuoD6Init,
                dim21112JoeKuoD6Init,
                dim21113JoeKuoD6Init,
                dim21114JoeKuoD6Init,
                dim21115JoeKuoD6Init,
                dim21116JoeKuoD6Init,
                dim21117JoeKuoD6Init,
                dim21118JoeKuoD6Init,
                dim21119JoeKuoD6Init,
                dim21120JoeKuoD6Init,
                dim21121JoeKuoD6Init,
                dim21122JoeKuoD6Init,
                dim21123JoeKuoD6Init,
                dim21124JoeKuoD6Init,
                dim21125JoeKuoD6Init,
                dim21126JoeKuoD6Init,
                dim21127JoeKuoD6Init,
                dim21128JoeKuoD6Init,
                dim21129JoeKuoD6Init,
                dim21130JoeKuoD6Init,
                dim21131JoeKuoD6Init,
                dim21132JoeKuoD6Init,
                dim21133JoeKuoD6Init,
                dim21134JoeKuoD6Init,
                dim21135JoeKuoD6Init,
                dim21136JoeKuoD6Init,
                dim21137JoeKuoD6Init,
                dim21138JoeKuoD6Init,
                dim21139JoeKuoD6Init,
                dim21140JoeKuoD6Init,
                dim21141JoeKuoD6Init,
                dim21142JoeKuoD6Init,
                dim21143JoeKuoD6Init,
                dim21144JoeKuoD6Init,
                dim21145JoeKuoD6Init,
                dim21146JoeKuoD6Init,
                dim21147JoeKuoD6Init,
                dim21148JoeKuoD6Init,
                dim21149JoeKuoD6Init,
                dim21150JoeKuoD6Init,
                dim21151JoeKuoD6Init,
                dim21152JoeKuoD6Init,
                dim21153JoeKuoD6Init,
                dim21154JoeKuoD6Init,
                dim21155JoeKuoD6Init,
                dim21156JoeKuoD6Init,
                dim21157JoeKuoD6Init,
                dim21158JoeKuoD6Init,
                dim21159JoeKuoD6Init,
                dim21160JoeKuoD6Init,
                dim21161JoeKuoD6Init,
                dim21162JoeKuoD6Init,
                dim21163JoeKuoD6Init,
                dim21164JoeKuoD6Init,
                dim21165JoeKuoD6Init,
                dim21166JoeKuoD6Init,
                dim21167JoeKuoD6Init,
                dim21168JoeKuoD6Init,
                dim21169JoeKuoD6Init,
                dim21170JoeKuoD6Init,
                dim21171JoeKuoD6Init,
                dim21172JoeKuoD6Init,
                dim21173JoeKuoD6Init,
                dim21174JoeKuoD6Init,
                dim21175JoeKuoD6Init,
                dim21176JoeKuoD6Init,
                dim21177JoeKuoD6Init,
                dim21178JoeKuoD6Init,
                dim21179JoeKuoD6Init,
                dim21180JoeKuoD6Init,
                dim21181JoeKuoD6Init,
                dim21182JoeKuoD6Init,
                dim21183JoeKuoD6Init,
                dim21184JoeKuoD6Init,
                dim21185JoeKuoD6Init,
                dim21186JoeKuoD6Init,
                dim21187JoeKuoD6Init,
                dim21188JoeKuoD6Init,
                dim21189JoeKuoD6Init,
                dim21190JoeKuoD6Init,
                dim21191JoeKuoD6Init,
                dim21192JoeKuoD6Init,
                dim21193JoeKuoD6Init,
                dim21194JoeKuoD6Init,
                dim21195JoeKuoD6Init,
                dim21196JoeKuoD6Init,
                dim21197JoeKuoD6Init,
                dim21198JoeKuoD6Init,
                dim21199JoeKuoD6Init,
                dim21200JoeKuoD6Init
            };

            const std::uint32_t dim1JoeKuoD7Init[]  =   {   1   ,0 };
            const std::uint32_t dim2JoeKuoD7Init[]  =   {   1   ,   3   ,0 };
            const std::uint32_t dim3JoeKuoD7Init[]  =   {   1   ,   3   ,   1   ,0 };
            const std::uint32_t dim4JoeKuoD7Init[]  =   {   1   ,   1   ,   1   ,0 };
            const std::uint32_t dim5JoeKuoD7Init[]  =   {   1   ,   1   ,   3   ,   3   ,0 };
            const std::uint32_t dim6JoeKuoD7Init[]  =   {   1   ,   3   ,   5   ,   13  ,0 };
            const std::uint32_t dim7JoeKuoD7Init[]  =   {   1   ,   1   ,   5   ,   5   ,   17  ,0 };
            const std::uint32_t dim8JoeKuoD7Init[]  =   {   1   ,   1   ,   5   ,   5   ,   5   ,0 };
            const std::uint32_t dim9JoeKuoD7Init[]  =   {   1   ,   1   ,   7   ,   11  ,   19  ,0 };
            const std::uint32_t dim10JoeKuoD7Init[] =   {   1   ,   1   ,   5   ,   1   ,   1   ,0 };
            const std::uint32_t dim11JoeKuoD7Init[] =   {   1   ,   1   ,   1   ,   3   ,   11  ,0 };
            const std::uint32_t dim12JoeKuoD7Init[] =   {   1   ,   3   ,   5   ,   5   ,   31  ,0 };
            const std::uint32_t dim13JoeKuoD7Init[] =   {   1   ,   3   ,   3   ,   9   ,   7   ,   49  ,0 };
            const std::uint32_t dim14JoeKuoD7Init[] =   {   1   ,   1   ,   1   ,   15  ,   23  ,   17  ,0 };
            const std::uint32_t dim15JoeKuoD7Init[] =   {   1   ,   3   ,   1   ,   13  ,   27  ,   49  ,0 };
            const std::uint32_t dim16JoeKuoD7Init[] =   {   1   ,   1   ,   1   ,   15  ,   7   ,   5   ,0 };
            const std::uint32_t dim17JoeKuoD7Init[] =   {   1   ,   3   ,   7   ,   7   ,   19  ,   13  ,0 };
            const std::uint32_t dim18JoeKuoD7Init[] =   {   1   ,   1   ,   5   ,   5   ,   19  ,   59  ,0 };
            const std::uint32_t dim19JoeKuoD7Init[] =   {   1   ,   3   ,   7   ,   11  ,   23  ,   7   ,   121 ,0 };
            const std::uint32_t dim20JoeKuoD7Init[] =   {   1   ,   3   ,   5   ,   13  ,   9   ,   19  ,   113 ,0 };
            const std::uint32_t dim21JoeKuoD7Init[] =   {   1   ,   1   ,   7   ,   15  ,   3   ,   53  ,   87  ,0 };
            const std::uint32_t dim22JoeKuoD7Init[] =   {   1   ,   3   ,   7   ,   7   ,   25  ,   33  ,   41  ,0 };
            const std::uint32_t dim23JoeKuoD7Init[] =   {   1   ,   3   ,   1   ,   9   ,   15  ,   47  ,   85  ,0 };
            const std::uint32_t dim24JoeKuoD7Init[] =   {   1   ,   1   ,   7   ,   3   ,   5   ,   25  ,   37  ,0 };
            const std::uint32_t dim25JoeKuoD7Init[] =   {   1   ,   3   ,   7   ,   9   ,   31  ,   11  ,   27  ,0 };
            const std::uint32_t dim26JoeKuoD7Init[] =   {   1   ,   1   ,   7   ,   15  ,   1   ,   17  ,   121 ,0 };
            const std::uint32_t dim27JoeKuoD7Init[] =   {   1   ,   3   ,   7   ,   13  ,   17  ,   49  ,   5   ,0 };
            const std::uint32_t dim28JoeKuoD7Init[] =   {   1   ,   3   ,   5   ,   9   ,   7   ,   9   ,   31  ,0 };
            const std::uint32_t dim29JoeKuoD7Init[] =   {   1   ,   3   ,   1   ,   9   ,   7   ,   29  ,   15  ,0 };
            const std::uint32_t dim30JoeKuoD7Init[] =   {   1   ,   3   ,   1   ,   1   ,   23  ,   43  ,   37  ,0 };
            const std::uint32_t dim31JoeKuoD7Init[] =   {   1   ,   3   ,   7   ,   5   ,   3   ,   43  ,   95  ,0 };
            const std::uint32_t dim32JoeKuoD7Init[] =   {   1   ,   1   ,   7   ,   9   ,   31  ,   25  ,   91  ,0 };
            const std::uint32_t dim33JoeKuoD7Init[] =   {   1   ,   3   ,   1   ,   11  ,   15  ,   17  ,   91  ,0 };
            const std::uint32_t dim34JoeKuoD7Init[] =   {   1   ,   1   ,   1   ,   1   ,   21  ,   29  ,   71  ,0 };
            const std::uint32_t dim35JoeKuoD7Init[] =   {   1   ,   1   ,   5   ,   13  ,   27  ,   3   ,   27  ,0 };
            const std::uint32_t dim36JoeKuoD7Init[] =   {   1   ,   3   ,   1   ,   9   ,   31  ,   25  ,   3   ,0 };
            const std::uint32_t dim37JoeKuoD7Init[] =   {   1   ,   3   ,   3   ,   1   ,   25  ,   23  ,   51  ,   45  ,0 };
            const std::uint32_t dim38JoeKuoD7Init[] =   {   1   ,   1   ,   5   ,   13  ,   9   ,   25  ,   17  ,   227 ,0 };
            const std::uint32_t dim39JoeKuoD7Init[] =   {   1   ,   1   ,   1   ,   1   ,   15  ,   9   ,   91  ,   45  ,0 };
            const std::uint32_t dim40JoeKuoD7Init[] =   {   1   ,   1   ,   7   ,   7   ,   9   ,   35  ,   87  ,   31  ,0 };
            const std::uint32_t dim41JoeKuoD7Init[] =   {   1   ,   1   ,   5   ,   13  ,   29  ,   33  ,   13  ,   119 ,0 };
            const std::uint32_t dim42JoeKuoD7Init[] =   {   1   ,   3   ,   5   ,   3   ,   17  ,   9   ,   73  ,   85  ,0 };
            const std::uint32_t dim43JoeKuoD7Init[] =   {   1   ,   3   ,   7   ,   5   ,   13  ,   33  ,   11  ,   17  ,0 };
            const std::uint32_t dim44JoeKuoD7Init[] =   {   1   ,   1   ,   3   ,   13  ,   29  ,   25  ,   15  ,   75  ,0 };
            const std::uint32_t dim45JoeKuoD7Init[] =   {   1   ,   3   ,   7   ,   9   ,   3   ,   11  ,   11  ,   59  ,0 };
            const std::uint32_t dim46JoeKuoD7Init[] =   {   1   ,   3   ,   1   ,   13  ,   5   ,   27  ,   19  ,   71  ,0 };
            const std::uint32_t dim47JoeKuoD7Init[] =   {   1   ,   1   ,   7   ,   3   ,   13  ,   41  ,   79  ,   137 ,0 };
            const std::uint32_t dim48JoeKuoD7Init[] =   {   1   ,   3   ,   3   ,   7   ,   9   ,   41  ,   89  ,   63  ,0 };
            const std::uint32_t dim49JoeKuoD7Init[] =   {   1   ,   1   ,   1   ,   5   ,   29  ,   57  ,   53  ,   103 ,0 };
            const std::uint32_t dim50JoeKuoD7Init[] =   {   1   ,   1   ,   3   ,   9   ,   3   ,   41  ,   71  ,   119 ,0 };
            const std::uint32_t dim51JoeKuoD7Init[] =   {   1   ,   3   ,   5   ,   5   ,   3   ,   1   ,   39  ,   185 ,0 };
            const std::uint32_t dim52JoeKuoD7Init[] =   {   1   ,   3   ,   3   ,   15  ,   23  ,   3   ,   43  ,   95  ,0 };
            const std::uint32_t dim53JoeKuoD7Init[] =   {   1   ,   1   ,   3   ,   7   ,   1   ,   35  ,   19  ,   19  ,   127 ,0 };
            const std::uint32_t dim54JoeKuoD7Init[] =   {   1   ,   1   ,   3   ,   9   ,   9   ,   31  ,   9   ,   157 ,   105 ,0 };
            const std::uint32_t dim55JoeKuoD7Init[] =   {   1   ,   3   ,   1   ,   1   ,   7   ,   49  ,   13  ,   125 ,   471 ,0 };
            const std::uint32_t dim56JoeKuoD7Init[] =   {   1   ,   3   ,   3   ,   1   ,   17  ,   25  ,   111 ,   73  ,   41  ,0 };
            const std::uint32_t dim57JoeKuoD7Init[] =   {   1   ,   3   ,   5   ,   11  ,   3   ,   61  ,   117 ,   93  ,   325 ,0 };
            const std::uint32_t dim58JoeKuoD7Init[] =   {   1   ,   1   ,   7   ,   15  ,   21  ,   63  ,   103 ,   145 ,   61  ,0 };
            const std::uint32_t dim59JoeKuoD7Init[] =   {   1   ,   3   ,   7   ,   7   ,   27  ,   49  ,   101 ,   227 ,   55  ,0 };
            const std::uint32_t dim60JoeKuoD7Init[] =   {   1   ,   1   ,   7   ,   5   ,   1   ,   1   ,   33  ,   225 ,   501 ,0 };
            const std::uint32_t dim61JoeKuoD7Init[] =   {   1   ,   3   ,   5   ,   5   ,   1   ,   17  ,   113 ,   149 ,   71  ,0 };
            const std::uint32_t dim62JoeKuoD7Init[] =   {   1   ,   1   ,   5   ,   9   ,   27  ,   9   ,   97  ,   7   ,   35  ,0 };
            const std::uint32_t dim63JoeKuoD7Init[] =   {   1   ,   3   ,   1   ,   7   ,   13  ,   39  ,   49  ,   213 ,   483 ,0 };
            const std::uint32_t dim64JoeKuoD7Init[] =   {   1   ,   3   ,   3   ,   11  ,   13  ,   47  ,   43  ,   89  ,   329 ,0 };
            const std::uint32_t dim65JoeKuoD7Init[] =   {   1   ,   3   ,   1   ,   1   ,   19  ,   61  ,   97  ,   205 ,   285 ,0 };
            const std::uint32_t dim66JoeKuoD7Init[] =   {   1   ,   1   ,   3   ,   11  ,   11  ,   3   ,   105 ,   151 ,   469 ,0 };
            const std::uint32_t dim67JoeKuoD7Init[] =   {   1   ,   1   ,   1   ,   1   ,   5   ,   39  ,   89  ,   137 ,   409 ,0 };
            const std::uint32_t dim68JoeKuoD7Init[] =   {   1   ,   1   ,   3   ,   11  ,   23  ,   39  ,   85  ,   251 ,   141 ,0 };
            const std::uint32_t dim69JoeKuoD7Init[] =   {   1   ,   1   ,   3   ,   5   ,   23  ,   23  ,   59  ,   111 ,   19  ,0 };
            const std::uint32_t dim70JoeKuoD7Init[] =   {   1   ,   3   ,   5   ,   9   ,   19  ,   63  ,   1   ,   251 ,   305 ,0 };
            const std::uint32_t dim71JoeKuoD7Init[] =   {   1   ,   3   ,   1   ,   1   ,   3   ,   35  ,   65  ,   153 ,   387 ,0 };
            const std::uint32_t dim72JoeKuoD7Init[] =   {   1   ,   1   ,   5   ,   13  ,   21  ,   45  ,   37  ,   255 ,   295 ,0 };
            const std::uint32_t dim73JoeKuoD7Init[] =   {   1   ,   1   ,   5   ,   1   ,   21  ,   5   ,   39  ,   143 ,   293 ,0 };
            const std::uint32_t dim74JoeKuoD7Init[] =   {   1   ,   1   ,   1   ,   5   ,   21  ,   45  ,   91  ,   211 ,   347 ,0 };
            const std::uint32_t dim75JoeKuoD7Init[] =   {   1   ,   3   ,   5   ,   11  ,   17  ,   21  ,   73  ,   185 ,   259 ,0 };
            const std::uint32_t dim76JoeKuoD7Init[] =   {   1   ,   3   ,   1   ,   11  ,   29  ,   25  ,   85  ,   103 ,   97  ,0 };
            const std::uint32_t dim77JoeKuoD7Init[] =   {   1   ,   3   ,   5   ,   5   ,   27  ,   37  ,   43  ,   243 ,   257 ,0 };
            const std::uint32_t dim78JoeKuoD7Init[] =   {   1   ,   3   ,   5   ,   11  ,   31  ,   63  ,   105 ,   41  ,   229 ,0 };
            const std::uint32_t dim79JoeKuoD7Init[] =   {   1   ,   3   ,   3   ,   15  ,   21  ,   55  ,   29  ,   39  ,   279 ,0 };
            const std::uint32_t dim80JoeKuoD7Init[] =   {   1   ,   3   ,   5   ,   7   ,   1   ,   47  ,   97  ,   15  ,   173 ,0 };
            const std::uint32_t dim81JoeKuoD7Init[] =   {   1   ,   1   ,   5   ,   7   ,   21  ,   55  ,   29  ,   93  ,   97  ,0 };
            const std::uint32_t dim82JoeKuoD7Init[] =   {   1   ,   3   ,   3   ,   3   ,   7   ,   29  ,   27  ,   179 ,   105 ,0 };
            const std::uint32_t dim83JoeKuoD7Init[] =   {   1   ,   1   ,   3   ,   3   ,   1   ,   43  ,   37  ,   221 ,   259 ,0 };
            const std::uint32_t dim84JoeKuoD7Init[] =   {   1   ,   1   ,   7   ,   9   ,   31  ,   25  ,   1   ,   47  ,   71  ,0 };
            const std::uint32_t dim85JoeKuoD7Init[] =   {   1   ,   3   ,   7   ,   7   ,   7   ,   25  ,   37  ,   1   ,   487 ,0 };
            const std::uint32_t dim86JoeKuoD7Init[] =   {   1   ,   3   ,   1   ,   1   ,   31  ,   43  ,   25  ,   117 ,   147 ,0 };
            const std::uint32_t dim87JoeKuoD7Init[] =   {   1   ,   3   ,   7   ,   3   ,   27  ,   7   ,   103 ,   241 ,   173 ,0 };
            const std::uint32_t dim88JoeKuoD7Init[] =   {   1   ,   1   ,   5   ,   1   ,   27  ,   25  ,   91  ,   189 ,   53  ,0 };
            const std::uint32_t dim89JoeKuoD7Init[] =   {   1   ,   1   ,   3   ,   3   ,   29  ,   39  ,   79  ,   125 ,   281 ,0 };
            const std::uint32_t dim90JoeKuoD7Init[] =   {   1   ,   1   ,   5   ,   11  ,   13  ,   57  ,   15  ,   219 ,   407 ,0 };
            const std::uint32_t dim91JoeKuoD7Init[] =   {   1   ,   3   ,   3   ,   5   ,   15  ,   9   ,   65  ,   111 ,   1   ,0 };
            const std::uint32_t dim92JoeKuoD7Init[] =   {   1   ,   1   ,   5   ,   3   ,   31  ,   45  ,   17  ,   227 ,   67  ,0 };
            const std::uint32_t dim93JoeKuoD7Init[] =   {   1   ,   1   ,   3   ,   1   ,   31  ,   59  ,   63  ,   205 ,   27  ,0 };
            const std::uint32_t dim94JoeKuoD7Init[] =   {   1   ,   1   ,   1   ,   9   ,   27  ,   9   ,   49  ,   187 ,   451 ,0 };
            const std::uint32_t dim95JoeKuoD7Init[] =   {   1   ,   1   ,   5   ,   15  ,   11  ,   43  ,   93  ,   49  ,   129 ,0 };
            const std::uint32_t dim96JoeKuoD7Init[] =   {   1   ,   3   ,   7   ,   7   ,   5   ,   63  ,   31  ,   239 ,   11  ,0 };
            const std::uint32_t dim97JoeKuoD7Init[] =   {   1   ,   1   ,   1   ,   11  ,   7   ,   59  ,   37  ,   157 ,   505 ,0 };
            const std::uint32_t dim98JoeKuoD7Init[] =   {   1   ,   3   ,   5   ,   9   ,   3   ,   41  ,   87  ,   229 ,   269 ,0 };
            const std::uint32_t dim99JoeKuoD7Init[] =   {   1   ,   1   ,   5   ,   3   ,   25  ,   11  ,   69  ,   125 ,   35  ,0 };
            const std::uint32_t dim100JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   13  ,   11  ,   53  ,   47  ,   21  ,   79  ,0 };
            const std::uint32_t dim101JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   7   ,   11  ,   23  ,   1   ,   99  ,   417 ,   35  ,0 };
            const std::uint32_t dim102JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   7   ,   7   ,   53  ,   57  ,   229 ,   473 ,   533 ,0 };
            const std::uint32_t dim103JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   9   ,   23  ,   31  ,   87  ,   27  ,   313 ,   853 ,0 };
            const std::uint32_t dim104JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   1   ,   13  ,   43  ,   27  ,   227 ,   231 ,   91  ,0 };
            const std::uint32_t dim105JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   5   ,   11  ,   17  ,   109 ,   29  ,   417 ,   597 ,0 };
            const std::uint32_t dim106JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   7   ,   31  ,   5   ,   23  ,   137 ,   35  ,   583 ,0 };
            const std::uint32_t dim107JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   5   ,   15  ,   23  ,   87  ,   171 ,   171 ,   889 ,0 };
            const std::uint32_t dim108JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   7   ,   17  ,   21  ,   19  ,   233 ,   275 ,   651 ,0 };
            const std::uint32_t dim109JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   5   ,   31  ,   19  ,   127 ,   115 ,   211 ,   715 ,0 };
            const std::uint32_t dim110JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   3   ,   13  ,   5   ,   37  ,   83  ,   123 ,   567 ,0 };
            const std::uint32_t dim111JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   7   ,   3   ,   41  ,   123 ,   61  ,   311 ,   45  ,0 };
            const std::uint32_t dim112JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   5   ,   19  ,   27  ,   1   ,   159 ,   87  ,   155 ,0 };
            const std::uint32_t dim113JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   15  ,   31  ,   17  ,   29  ,   105 ,   293 ,   205 ,0 };
            const std::uint32_t dim114JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   13  ,   15  ,   11  ,   125 ,   241 ,   1   ,   755 ,0 };
            const std::uint32_t dim115JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   7   ,   27  ,   47  ,   59  ,   143 ,   451 ,   1005    ,0 };
            const std::uint32_t dim116JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   11  ,   19  ,   37  ,   49  ,   105 ,   127 ,   683 ,0 };
            const std::uint32_t dim117JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   1   ,   11  ,   31  ,   9   ,   15  ,   355 ,   951 ,0 };
            const std::uint32_t dim118JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   15  ,   5   ,   19  ,   69  ,   51  ,   121 ,   695 ,0 };
            const std::uint32_t dim119JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   9   ,   15  ,   33  ,   125 ,   63  ,   191 ,   773 ,0 };
            const std::uint32_t dim120JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   1   ,   11  ,   13  ,   67  ,   123 ,   143 ,   427 ,0 };
            const std::uint32_t dim121JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   7   ,   17  ,   45  ,   73  ,   209 ,   501 ,   781 ,0 };
            const std::uint32_t dim122JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   5   ,   21  ,   25  ,   31  ,   229 ,   107 ,   447 ,0 };
            const std::uint32_t dim123JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   5   ,   15  ,   39  ,   19  ,   111 ,   221 ,   35  ,0 };
            const std::uint32_t dim124JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   7   ,   7   ,   23  ,   111 ,   201 ,   469 ,   859 ,0 };
            const std::uint32_t dim125JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   9   ,   7   ,   55  ,   1   ,   57  ,   245 ,   865 ,0 };
            const std::uint32_t dim126JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   11  ,   19  ,   17  ,   63  ,   107 ,   423 ,   977 ,0 };
            const std::uint32_t dim127JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   5   ,   23  ,   35  ,   59  ,   143 ,   403 ,   469 ,0 };
            const std::uint32_t dim128JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   9   ,   29  ,   11  ,   11  ,   137 ,   341 ,   669 ,0 };
            const std::uint32_t dim129JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   5   ,   31  ,   29  ,   73  ,   25  ,   21  ,   543 ,0 };
            const std::uint32_t dim130JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   3   ,   17  ,   47  ,   69  ,   103 ,   49  ,   869 ,0 };
            const std::uint32_t dim131JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   9   ,   1   ,   5   ,   69  ,   45  ,   73  ,   533 ,0 };
            const std::uint32_t dim132JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   11  ,   13  ,   11  ,   61  ,   71  ,   397 ,   919 ,0 };
            const std::uint32_t dim133JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   11  ,   1   ,   3   ,   21  ,   127 ,   263 ,   597 ,0 };
            const std::uint32_t dim134JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   9   ,   3   ,   31  ,   41  ,   179 ,   499 ,   313 ,0 };
            const std::uint32_t dim135JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   11  ,   5   ,   43  ,   33  ,   41  ,   53  ,   917 ,0 };
            const std::uint32_t dim136JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   9   ,   1   ,   63  ,   35  ,   139 ,   169 ,   945 ,0 };
            const std::uint32_t dim137JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   3   ,   31  ,   13  ,   51  ,   105 ,   333 ,   703 ,0 };
            const std::uint32_t dim138JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   3   ,   5   ,   5   ,   127 ,   103 ,   465 ,   989 ,0 };
            const std::uint32_t dim139JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   1   ,   31  ,   3   ,   87  ,   41  ,   511 ,   713 ,0 };
            const std::uint32_t dim140JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   1   ,   7   ,   29  ,   19  ,   237 ,   235 ,   531 ,0 };
            const std::uint32_t dim141JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   13  ,   21  ,   11  ,   111 ,   51  ,   461 ,   525 ,0 };
            const std::uint32_t dim142JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   13  ,   27  ,   49  ,   123 ,   241 ,   365 ,   137 ,0 };
            const std::uint32_t dim143JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   13  ,   17  ,   43  ,   43  ,   115 ,   483 ,   291 ,0 };
            const std::uint32_t dim144JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   7   ,   5   ,   17  ,   127 ,   167 ,   371 ,   417 ,0 };
            const std::uint32_t dim145JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   9   ,   11  ,   21  ,   123 ,   29  ,   133 ,   9   ,0 };
            const std::uint32_t dim146JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   7   ,   13  ,   35  ,   99  ,   161 ,   45  ,   347 ,0 };
            const std::uint32_t dim147JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   7   ,   15  ,   21  ,   31  ,   131 ,   441 ,   635 ,0 };
            const std::uint32_t dim148JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   7   ,   21  ,   63  ,   119 ,   175 ,   183 ,   189 ,0 };
            const std::uint32_t dim149JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   3   ,   17  ,   39  ,   21  ,   201 ,   31  ,   747 ,0 };
            const std::uint32_t dim150JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   15  ,   7   ,   23  ,   127 ,   169 ,   341 ,   975 ,0 };
            const std::uint32_t dim151JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   15  ,   27  ,   39  ,   67  ,   111 ,   501 ,   343 ,0 };
            const std::uint32_t dim152JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   15  ,   13  ,   3   ,   99  ,   145 ,   259 ,   579 ,0 };
            const std::uint32_t dim153JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   13  ,   27  ,   45  ,   9   ,   229 ,   139 ,   1015    ,0 };
            const std::uint32_t dim154JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   11  ,   1   ,   61  ,   35  ,   77  ,   423 ,   987 ,0 };
            const std::uint32_t dim155JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   11  ,   13  ,   53  ,   99  ,   165 ,   329 ,   191 ,0 };
            const std::uint32_t dim156JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   11  ,   13  ,   31  ,   15  ,   237 ,   359 ,   337 ,0 };
            const std::uint32_t dim157JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   1   ,   1   ,   15  ,   35  ,   175 ,   347 ,   485 ,0 };
            const std::uint32_t dim158JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   9   ,   3   ,   15  ,   63  ,   19  ,   123 ,   633 ,0 };
            const std::uint32_t dim159JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   3   ,   9   ,   5   ,   51  ,   123 ,   239 ,   829 ,0 };
            const std::uint32_t dim160JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   15  ,   27  ,   49  ,   1   ,   177 ,   433 ,   237 ,0 };
            const std::uint32_t dim161JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   1   ,   25  ,   1   ,   71  ,   187 ,   3   ,   455 ,   1559    ,0 };
            const std::uint32_t dim162JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   5   ,   17  ,   53  ,   71  ,   115 ,   87  ,   811 ,   1559    ,0 };
            const std::uint32_t dim163JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   9   ,   3   ,   5   ,   93  ,   233 ,   413 ,   105 ,   335 ,0 };
            const std::uint32_t dim164JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   5   ,   13  ,   33  ,   45  ,   45  ,   255 ,   691 ,   1827    ,0 };
            const std::uint32_t dim165JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   7   ,   3   ,   51  ,   57  ,   119 ,   355 ,   151 ,   297 ,0 };
            const std::uint32_t dim166JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   13  ,   17  ,   11  ,   19  ,   5   ,   369 ,   661 ,   877 ,0 };
            const std::uint32_t dim167JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   3   ,   3   ,   61  ,   15  ,   207 ,   161 ,   811 ,   1585    ,0 };
            const std::uint32_t dim168JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   9   ,   11  ,   63  ,   105 ,   45  ,   209 ,   605 ,   835 ,0 };
            const std::uint32_t dim169JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   7   ,   11  ,   47  ,   35  ,   73  ,   303 ,   809 ,   1813    ,0 };
            const std::uint32_t dim170JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   1   ,   9   ,   35  ,   69  ,   219 ,   5   ,   281 ,   1263    ,0 };
            const std::uint32_t dim171JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   1   ,   9   ,   25  ,   85  ,   159 ,   415 ,   471 ,   345 ,0 };
            const std::uint32_t dim172JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   11  ,   11  ,   61  ,   43  ,   109 ,   327 ,   865 ,   1635    ,0 };
            const std::uint32_t dim173JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   13  ,   21  ,   39  ,   123 ,   211 ,   355 ,   91  ,   1481    ,0 };
            const std::uint32_t dim174JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   15  ,   17  ,   39  ,   69  ,   149 ,   133 ,   779 ,   575 ,0 };
            const std::uint32_t dim175JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   9   ,   15  ,   49  ,   7   ,   183 ,   25  ,   823 ,   971 ,0 };
            const std::uint32_t dim176JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   7   ,   31  ,   63  ,   9   ,   187 ,   211 ,   473 ,   485 ,0 };
            const std::uint32_t dim177JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   11  ,   9   ,   1   ,   35  ,   177 ,   435 ,   307 ,   1493    ,0 };
            const std::uint32_t dim178JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   3   ,   27  ,   51  ,   91  ,   63  ,   511 ,   179 ,   251 ,0 };
            const std::uint32_t dim179JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   11  ,   27  ,   49  ,   125 ,   111 ,   283 ,   577 ,   397 ,0 };
            const std::uint32_t dim180JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   15  ,   11  ,   7   ,   19  ,   85  ,   111 ,   629 ,   435 ,0 };
            const std::uint32_t dim181JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   9   ,   7   ,   11  ,   127 ,   25  ,   139 ,   271 ,   263 ,0 };
            const std::uint32_t dim182JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   15  ,   21  ,   25  ,   55  ,   129 ,   211 ,   755 ,   1695    ,0 };
            const std::uint32_t dim183JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   15  ,   13  ,   23  ,   107 ,   241 ,   231 ,   319 ,   385 ,0 };
            const std::uint32_t dim184JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   11  ,   31  ,   31  ,   97  ,   141 ,   93  ,   759 ,   1199    ,0 };
            const std::uint32_t dim185JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   9   ,   25  ,   15  ,   63  ,   79  ,   321 ,   53  ,   1877    ,0 };
            const std::uint32_t dim186JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   5   ,   11  ,   59  ,   113 ,   77  ,   75  ,   453 ,   1617    ,0 };
            const std::uint32_t dim187JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   15  ,   19  ,   33  ,   65  ,   141 ,   109 ,   211 ,   213 ,0 };
            const std::uint32_t dim188JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   13  ,   17  ,   1   ,   123 ,   1   ,   305 ,   271 ,   1835    ,0 };
            const std::uint32_t dim189JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   7   ,   9   ,   61  ,   83  ,   75  ,   355 ,   595 ,   773 ,0 };
            const std::uint32_t dim190JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   13  ,   31  ,   53  ,   97  ,   193 ,   95  ,   933 ,   535 ,0 };
            const std::uint32_t dim191JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   11  ,   21  ,   47  ,   95  ,   31  ,   399 ,   115 ,   265 ,0 };
            const std::uint32_t dim192JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   3   ,   19  ,   43  ,   97  ,   29  ,   259 ,   671 ,   1789    ,0 };
            const std::uint32_t dim193JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   7   ,   11  ,   3   ,   1   ,   167 ,   73  ,   21  ,   587 ,0 };
            const std::uint32_t dim194JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   1   ,   7   ,   29  ,   113 ,   243 ,   389 ,   605 ,   1267    ,0 };
            const std::uint32_t dim195JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   1   ,   19  ,   17  ,   43  ,   89  ,   467 ,   501 ,   137 ,0 };
            const std::uint32_t dim196JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   7   ,   13  ,   41  ,   97  ,   123 ,   153 ,   603 ,   1469    ,0 };
            const std::uint32_t dim197JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   3   ,   25  ,   29  ,   45  ,   231 ,   489 ,   305 ,   1071    ,0 };
            const std::uint32_t dim198JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   3   ,   31  ,   51  ,   59  ,   113 ,   309 ,   923 ,   1171    ,0 };
            const std::uint32_t dim199JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   11  ,   7   ,   41  ,   55  ,   207 ,   181 ,   565 ,   913 ,0 };
            const std::uint32_t dim200JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   9   ,   9   ,   45  ,   25  ,   49  ,   135 ,   777 ,   593 ,0 };
            const std::uint32_t dim201JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   3   ,   31  ,   3   ,   51  ,   253 ,   369 ,   853 ,   1985    ,0 };
            const std::uint32_t dim202JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   3   ,   25  ,   7   ,   89  ,   193 ,   153 ,   835 ,   341 ,0 };
            const std::uint32_t dim203JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   15  ,   29  ,   51  ,   1   ,   159 ,   77  ,   423 ,   1319    ,0 };
            const std::uint32_t dim204JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   11  ,   31  ,   51  ,   93  ,   249 ,   321 ,   841 ,   619 ,0 };
            const std::uint32_t dim205JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   7   ,   17  ,   11  ,   99  ,   45  ,   407 ,   123 ,   1363    ,0 };
            const std::uint32_t dim206JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   5   ,   13  ,   39  ,   65  ,   195 ,   55  ,   991 ,   1105    ,0 };
            const std::uint32_t dim207JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   11  ,   13  ,   11  ,   79  ,   239 ,   93  ,   683 ,   1459    ,0 };
            const std::uint32_t dim208JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   11  ,   23  ,   5   ,   29  ,   73  ,   197 ,   17  ,   953 ,0 };
            const std::uint32_t dim209JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   3   ,   27  ,   13  ,   109 ,   193 ,   447 ,   271 ,   429 ,0 };
            const std::uint32_t dim210JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   15  ,   17  ,   41  ,   45  ,   205 ,   235 ,   1015    ,   1129    ,0 };
            const std::uint32_t dim211JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   7   ,   5   ,   33  ,   121 ,   23  ,   265 ,   199 ,   525 ,0 };
            const std::uint32_t dim212JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   5   ,   19  ,   35  ,   17  ,   177 ,   351 ,   935 ,   1769    ,0 };
            const std::uint32_t dim213JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   5   ,   1   ,   39  ,   71  ,   89  ,   27  ,   695 ,   289 ,0 };
            const std::uint32_t dim214JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   5   ,   27  ,   9   ,   27  ,   239 ,   83  ,   349 ,   1989    ,0 };
            const std::uint32_t dim215JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   11  ,   13  ,   63  ,   99  ,   177 ,   91  ,   899 ,   987 ,0 };
            const std::uint32_t dim216JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   1   ,   5   ,   23  ,   85  ,   61  ,   307 ,   491 ,   663 ,0 };
            const std::uint32_t dim217JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   7   ,   19  ,   27  ,   127 ,   205 ,   489 ,   857 ,   1077    ,0 };
            const std::uint32_t dim218JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   1   ,   1   ,   45  ,   43  ,   93  ,   445 ,   391 ,   1703    ,0 };
            const std::uint32_t dim219JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   9   ,   31  ,   55  ,   85  ,   103 ,   439 ,   123 ,   3   ,0 };
            const std::uint32_t dim220JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   15  ,   9   ,   51  ,   51  ,   213 ,   119 ,   245 ,   417 ,0 };
            const std::uint32_t dim221JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   1   ,   31  ,   49  ,   49  ,   227 ,   279 ,   891 ,   69  ,0 };
            const std::uint32_t dim222JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   13  ,   7   ,   49  ,   19  ,   147 ,   69  ,   451 ,   669 ,0 };
            const std::uint32_t dim223JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   9   ,   27  ,   27  ,   67  ,   131 ,   191 ,   497 ,   1189    ,0 };
            const std::uint32_t dim224JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   1   ,   13  ,   49  ,   93  ,   1   ,   161 ,   725 ,   709 ,0 };
            const std::uint32_t dim225JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   1   ,   13  ,   49  ,   67  ,   37  ,   153 ,   31  ,   409 ,0 };
            const std::uint32_t dim226JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   7   ,   19  ,   55  ,   103 ,   111 ,   381 ,   209 ,   271 ,0 };
            const std::uint32_t dim227JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   13  ,   17  ,   29  ,   15  ,   155 ,   81  ,   737 ,   565 ,0 };
            const std::uint32_t dim228JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   11  ,   29  ,   17  ,   119 ,   247 ,   189 ,   897 ,   1385    ,0 };
            const std::uint32_t dim229JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   13  ,   15  ,   51  ,   71  ,   85  ,   211 ,   839 ,   1085    ,0 };
            const std::uint32_t dim230JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   9   ,   15  ,   37  ,   93  ,   155 ,   357 ,   475 ,   175 ,0 };
            const std::uint32_t dim231JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   7   ,   1   ,   31  ,   125 ,   181 ,   339 ,   275 ,   301 ,0 };
            const std::uint32_t dim232JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   7   ,   27  ,   33  ,   3   ,   125 ,   153 ,   343 ,   577 ,0 };
            const std::uint32_t dim233JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   1   ,   17  ,   17  ,   51  ,   87  ,   409 ,   845 ,   1857    ,0 };
            const std::uint32_t dim234JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   11  ,   5   ,   47  ,   101 ,   45  ,   425 ,   721 ,   1303    ,0 };
            const std::uint32_t dim235JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   15  ,   9   ,   57  ,   15  ,   7   ,   479 ,   611 ,   1837    ,0 };
            const std::uint32_t dim236JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   13  ,   21  ,   57  ,   89  ,   145 ,   401 ,   1007    ,   753 ,0 };
            const std::uint32_t dim237JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   15  ,   19  ,   63  ,   5   ,   243 ,   111 ,   999 ,   435 ,0 };
            const std::uint32_t dim238JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   13  ,   31  ,   27  ,   27  ,   217 ,   71  ,   145 ,   695 ,0 };
            const std::uint32_t dim239JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   7   ,   11  ,   61  ,   113 ,   145 ,   481 ,   487 ,   1609    ,0 };
            const std::uint32_t dim240JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   13  ,   7   ,   51  ,   55  ,   1   ,   307 ,   219 ,   475 ,0 };
            const std::uint32_t dim241JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   5   ,   21  ,   27  ,   77  ,   193 ,   263 ,   37  ,   1421    ,0 };
            const std::uint32_t dim242JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   11  ,   5   ,   23  ,   101 ,   85  ,   41  ,   179 ,   1311    ,0 };
            const std::uint32_t dim243JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   9   ,   27  ,   5   ,   49  ,   227 ,   317 ,   695 ,   581 ,0 };
            const std::uint32_t dim244JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   15  ,   9   ,   23  ,   119 ,   145 ,   231 ,   15  ,   1349    ,0 };
            const std::uint32_t dim245JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   5   ,   1   ,   17  ,   37  ,   247 ,   261 ,   993 ,   173 ,0 };
            const std::uint32_t dim246JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   15  ,   31  ,   19  ,   23  ,   189 ,   353 ,   445 ,   1145    ,0 };
            const std::uint32_t dim247JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   11  ,   9   ,   1   ,   65  ,   211 ,   119 ,   531 ,   1389    ,0 };
            const std::uint32_t dim248JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   1   ,   31  ,   49  ,   31  ,   239 ,   131 ,   159 ,   55  ,0 };
            const std::uint32_t dim249JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   7   ,   3   ,   13  ,   85  ,   89  ,   459 ,   293 ,   1621    ,0 };
            const std::uint32_t dim250JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   7   ,   23  ,   55  ,   79  ,   61  ,   499 ,   915 ,   1641    ,0 };
            const std::uint32_t dim251JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   7   ,   17  ,   47  ,   69  ,   91  ,   157 ,   171 ,   1827    ,0 };
            const std::uint32_t dim252JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   5   ,   29  ,   55  ,   105 ,   31  ,   467 ,   3   ,   241 ,0 };
            const std::uint32_t dim253JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   11  ,   19  ,   27  ,   87  ,   199 ,   295 ,   949 ,   323 ,0 };
            const std::uint32_t dim254JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   1   ,   25  ,   59  ,   125 ,   33  ,   35  ,   75  ,   603 ,0 };
            const std::uint32_t dim255JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   5   ,   25  ,   63  ,   19  ,   87  ,   475 ,   711 ,   1549    ,0 };
            const std::uint32_t dim256JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   7   ,   11  ,   35  ,   29  ,   193 ,   27  ,   757 ,   133 ,0 };
            const std::uint32_t dim257JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   13  ,   9   ,   29  ,   21  ,   229 ,   137 ,   111 ,   1827    ,0 };
            const std::uint32_t dim258JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   7   ,   7   ,   5   ,   35  ,   217 ,   511 ,   309 ,   2013    ,0 };
            const std::uint32_t dim259JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   1   ,   3   ,   25  ,   99  ,   187 ,   141 ,   599 ,   223 ,0 };
            const std::uint32_t dim260JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   9   ,   23  ,   9   ,   3   ,   223 ,   357 ,   261 ,   393 ,0 };
            const std::uint32_t dim261JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   9   ,   3   ,   47  ,   73  ,   75  ,   153 ,   249 ,   149 ,0 };
            const std::uint32_t dim262JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   13  ,   5   ,   31  ,   25  ,   77  ,   501 ,   221 ,   941 ,0 };
            const std::uint32_t dim263JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   1   ,   21  ,   41  ,   107 ,   95  ,   245 ,   35  ,   1843    ,0 };
            const std::uint32_t dim264JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   3   ,   19  ,   59  ,   95  ,   51  ,   211 ,   647 ,   61  ,0 };
            const std::uint32_t dim265JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   15  ,   31  ,   9   ,   91  ,   191 ,   395 ,   161 ,   601 ,0 };
            const std::uint32_t dim266JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   7   ,   25  ,   11  ,   45  ,   147 ,   457 ,   457 ,   1331    ,0 };
            const std::uint32_t dim267JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   15  ,   31  ,   13  ,   49  ,   87  ,   481 ,   155 ,   745 ,0 };
            const std::uint32_t dim268JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   11  ,   17  ,   31  ,   93  ,   39  ,   195 ,   957 ,   877 ,0 };
            const std::uint32_t dim269JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   1   ,   1   ,   9   ,   1   ,   175 ,   63  ,   715 ,   887 ,0 };
            const std::uint32_t dim270JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   3   ,   11  ,   55  ,   15  ,   221 ,   103 ,   169 ,   1961    ,0 };
            const std::uint32_t dim271JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   15  ,   21  ,   41  ,   87  ,   141 ,   233 ,   879 ,   1869    ,0 };
            const std::uint32_t dim272JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   13  ,   13  ,   15  ,   127 ,   29  ,   103 ,   533 ,   925 ,0 };
            const std::uint32_t dim273JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   5   ,   23  ,   59  ,   1   ,   93  ,   97  ,   979 ,   1123    ,0 };
            const std::uint32_t dim274JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   7   ,   31  ,   29  ,   55  ,   185 ,   27  ,   759 ,   1037    ,0 };
            const std::uint32_t dim275JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   9   ,   9   ,   21  ,   95  ,   111 ,   291 ,   331 ,   889 ,0 };
            const std::uint32_t dim276JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   3   ,   15  ,   17  ,   113 ,   21  ,   97  ,   653 ,   769 ,0 };
            const std::uint32_t dim277JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   9   ,   19  ,   9   ,   67  ,   43  ,   9   ,   7   ,   1751    ,0 };
            const std::uint32_t dim278JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   9   ,   29  ,   15  ,   103 ,   69  ,   249 ,   465 ,   1747    ,0 };
            const std::uint32_t dim279JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   15  ,   17  ,   13  ,   81  ,   149 ,   253 ,   993 ,   25  ,0 };
            const std::uint32_t dim280JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   7   ,   27  ,   19  ,   63  ,   95  ,   165 ,   641 ,   1141    ,0 };
            const std::uint32_t dim281JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   1   ,   13  ,   39  ,   101 ,   131 ,   359 ,   825 ,   41  ,0 };
            const std::uint32_t dim282JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   7   ,   31  ,   31  ,   43  ,   83  ,   147 ,   427 ,   2031    ,0 };
            const std::uint32_t dim283JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   9   ,   27  ,   33  ,   109 ,   45  ,   123 ,   121 ,   485 ,0 };
            const std::uint32_t dim284JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   9   ,   27  ,   35  ,   13  ,   161 ,   363 ,   651 ,   1865    ,0 };
            const std::uint32_t dim285JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   11  ,   11  ,   45  ,   11  ,   127 ,   19  ,   459 ,   605 ,0 };
            const std::uint32_t dim286JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   15  ,   13  ,   37  ,   105 ,   159 ,   61  ,   157 ,   157 ,0 };
            const std::uint32_t dim287JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   15  ,   5   ,   39  ,   121 ,   85  ,   383 ,   579 ,   2001    ,0 };
            const std::uint32_t dim288JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   13  ,   13  ,   7   ,   101 ,   213 ,   455 ,   961 ,   1327    ,0 };
            const std::uint32_t dim289JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   13  ,   31  ,   39  ,   49  ,   33  ,   267 ,   783 ,   67  ,0 };
            const std::uint32_t dim290JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   9   ,   31  ,   43  ,   45  ,   85  ,   1   ,   187 ,   899 ,0 };
            const std::uint32_t dim291JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   1   ,   23  ,   11  ,   93  ,   227 ,   41  ,   1013    ,   1689    ,0 };
            const std::uint32_t dim292JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   15  ,   17  ,   31  ,   33  ,   67  ,   79  ,   113 ,   803 ,0 };
            const std::uint32_t dim293JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   9   ,   13  ,   53  ,   27  ,   203 ,   143 ,   469 ,   1435    ,0 };
            const std::uint32_t dim294JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   1   ,   19  ,   1   ,   119 ,   37  ,   135 ,   797 ,   1935    ,0 };
            const std::uint32_t dim295JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   11  ,   29  ,   29  ,   111 ,   79  ,   81  ,   973 ,   899 ,0 };
            const std::uint32_t dim296JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   1   ,   21  ,   3   ,   83  ,   43  ,   95  ,   445 ,   1529    ,0 };
            const std::uint32_t dim297JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   9   ,   11  ,   5   ,   27  ,   67  ,   101 ,   395 ,   195 ,0 };
            const std::uint32_t dim298JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   3   ,   29  ,   13  ,   41  ,   219 ,   157 ,   325 ,   955 ,0 };
            const std::uint32_t dim299JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   13  ,   27  ,   29  ,   113 ,   209 ,   323 ,   747 ,   759 ,0 };
            const std::uint32_t dim300JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   13  ,   1   ,   57  ,   113 ,   133 ,   363 ,   57  ,   715 ,0 };
            const std::uint32_t dim301JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   3   ,   25  ,   43  ,   123 ,   27  ,   483 ,   1023    ,   739 ,0 };
            const std::uint32_t dim302JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   13  ,   27  ,   43  ,   117 ,   217 ,   55  ,   977 ,   487 ,0 };
            const std::uint32_t dim303JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   3   ,   25  ,   31  ,   95  ,   67  ,   7   ,   19  ,   321 ,0 };
            const std::uint32_t dim304JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   3   ,   25  ,   7   ,   17  ,   123 ,   487 ,   709 ,   971 ,0 };
            const std::uint32_t dim305JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   11  ,   15  ,   9   ,   127 ,   129 ,   35  ,   123 ,   1217    ,0 };
            const std::uint32_t dim306JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   5   ,   17  ,   63  ,   67  ,   137 ,   253 ,   691 ,   447 ,0 };
            const std::uint32_t dim307JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   1   ,   27  ,   53  ,   25  ,   205 ,   75  ,   827 ,   1609    ,0 };
            const std::uint32_t dim308JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   13  ,   3   ,   49  ,   59  ,   207 ,   357 ,   269 ,   309 ,0 };
            const std::uint32_t dim309JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   5   ,   25  ,   57  ,   9   ,   117 ,   359 ,   9   ,   405 ,0 };
            const std::uint32_t dim310JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   15  ,   15  ,   21  ,   53  ,   163 ,   91  ,   35  ,   277 ,0 };
            const std::uint32_t dim311JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   1   ,   23  ,   5   ,   69  ,   83  ,   11  ,   161 ,   141 ,0 };
            const std::uint32_t dim312JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   13  ,   13  ,   25  ,   15  ,   209 ,   385 ,   389 ,   817 ,0 };
            const std::uint32_t dim313JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   13  ,   11  ,   11  ,   17  ,   191 ,   327 ,   731 ,   973 ,0 };
            const std::uint32_t dim314JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   15  ,   1   ,   63  ,   55  ,   51  ,   379 ,   359 ,   305 ,0 };
            const std::uint32_t dim315JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   11  ,   17  ,   19  ,   81  ,   123 ,   335 ,   391 ,   647 ,0 };
            const std::uint32_t dim316JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   13  ,   27  ,   15  ,   53  ,   243 ,   115 ,   733 ,   1095    ,0 };
            const std::uint32_t dim317JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   3   ,   5   ,   47  ,   111 ,   153 ,   479 ,   133 ,   723 ,0 };
            const std::uint32_t dim318JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   1   ,   15  ,   47  ,   85  ,   27  ,   449 ,   673 ,   931 ,0 };
            const std::uint32_t dim319JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   5   ,   23  ,   23  ,   15  ,   21  ,   113 ,   1003    ,   1077    ,0 };
            const std::uint32_t dim320JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   9   ,   27  ,   55  ,   29  ,   95  ,   21  ,   29  ,   1409    ,0 };
            const std::uint32_t dim321JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   5   ,   19  ,   53  ,   5   ,   135 ,   219 ,   607 ,   151 ,0 };
            const std::uint32_t dim322JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   1   ,   29  ,   31  ,   83  ,   103 ,   493 ,   227 ,   423 ,0 };
            const std::uint32_t dim323JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   13  ,   23  ,   3   ,   111 ,   147 ,   333 ,   159 ,   983 ,0 };
            const std::uint32_t dim324JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   7   ,   13  ,   1   ,   45  ,   57  ,   111 ,   459 ,   1503    ,0 };
            const std::uint32_t dim325JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   9   ,   9   ,   21  ,   27  ,   155 ,   377 ,   617 ,   1429    ,0 };
            const std::uint32_t dim326JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   15  ,   3   ,   7   ,   113 ,   11  ,   349 ,   961 ,   749 ,0 };
            const std::uint32_t dim327JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   15  ,   31  ,   13  ,   51  ,   63  ,   315 ,   691 ,   1351    ,0 };
            const std::uint32_t dim328JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   1   ,   21  ,   51  ,   5   ,   53  ,   215 ,   199 ,   891 ,0 };
            const std::uint32_t dim329JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   1   ,   23  ,   19  ,   37  ,   29  ,   263 ,   341 ,   453 ,0 };
            const std::uint32_t dim330JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   1   ,   13  ,   37  ,   113 ,   121 ,   483 ,   879 ,   1749    ,0 };
            const std::uint32_t dim331JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   7   ,   13  ,   41  ,   19  ,   69  ,   323 ,   547 ,   297 ,0 };
            const std::uint32_t dim332JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   9   ,   23  ,   13  ,   21  ,   179 ,   377 ,   217 ,   559 ,0 };
            const std::uint32_t dim333JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   15  ,   15  ,   5   ,   17  ,   41  ,   3   ,   391 ,   1241    ,0 };
            const std::uint32_t dim334JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   15  ,   31  ,   57  ,   97  ,   57  ,   183 ,   415 ,   917 ,0 };
            const std::uint32_t dim335JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   9   ,   17  ,   31  ,   121 ,   15  ,   425 ,   9   ,   655 ,0 };
            const std::uint32_t dim336JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   15  ,   3   ,   55  ,   53  ,   73  ,   463 ,   887 ,   1999    ,0 };
            const std::uint32_t dim337JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   7   ,   3   ,   25  ,   17  ,   5   ,   55  ,   833 ,   1899    ,   4077    ,0 };
            const std::uint32_t dim338JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   11  ,   23  ,   47  ,   67  ,   45  ,   9   ,   41  ,   835 ,   373 ,0 };
            const std::uint32_t dim339JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   11  ,   5   ,   55  ,   25  ,   137 ,   11  ,   119 ,   967 ,   3969    ,0 };
            const std::uint32_t dim340JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   13  ,   3   ,   5   ,   17  ,   11  ,   259 ,   7   ,   1587    ,   3919    ,0 };
            const std::uint32_t dim341JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   3   ,   29  ,   57  ,   113 ,   207 ,   187 ,   173 ,   575 ,   935 ,0 };
            const std::uint32_t dim342JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   9   ,   25  ,   31  ,   89  ,   29  ,   345 ,   753 ,   1675    ,   85  ,0 };
            const std::uint32_t dim343JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   1   ,   9   ,   41  ,   91  ,   245 ,   63  ,   995 ,   1751    ,   2881    ,0 };
            const std::uint32_t dim344JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   3   ,   21  ,   63  ,   121 ,   237 ,   243 ,   815 ,   1507    ,   265 ,0 };
            const std::uint32_t dim345JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   1   ,   23  ,   27  ,   121 ,   215 ,   381 ,   317 ,   669 ,   357 ,0 };
            const std::uint32_t dim346JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   3   ,   1   ,   45  ,   87  ,   19  ,   43  ,   915 ,   1083    ,   3259    ,0 };
            const std::uint32_t dim347JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   5   ,   15  ,   31  ,   15  ,   229 ,   489 ,   897 ,   791 ,   3019    ,0 };
            const std::uint32_t dim348JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   5   ,   25  ,   19  ,   89  ,   211 ,   413 ,   839 ,   2029    ,   1785    ,0 };
            const std::uint32_t dim349JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   1   ,   19  ,   29  ,   67  ,   11  ,   483 ,   303 ,   469 ,   795 ,0 };
            const std::uint32_t dim350JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   5   ,   19  ,   15  ,   81  ,   147 ,   337 ,   641 ,   1863    ,   2497    ,0 };
            const std::uint32_t dim351JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   5   ,   17  ,   43  ,   83  ,   173 ,   307 ,   397 ,   1231    ,   2275    ,0 };
            const std::uint32_t dim352JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   9   ,   27  ,   49  ,   61  ,   29  ,   169 ,   811 ,   171 ,   1373    ,0 };
            const std::uint32_t dim353JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   1   ,   13  ,   63  ,   11  ,   197 ,   145 ,   987 ,   1709    ,   895 ,0 };
            const std::uint32_t dim354JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   3   ,   15  ,   3   ,   5   ,   213 ,   155 ,   271 ,   867 ,   1665    ,0 };
            const std::uint32_t dim355JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   1   ,   23  ,   51  ,   99  ,   49  ,   83  ,   159 ,   1589    ,   3961    ,0 };
            const std::uint32_t dim356JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   9   ,   21  ,   13  ,   1   ,   91  ,   187 ,   615 ,   293 ,   3791    ,0 };
            const std::uint32_t dim357JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   5   ,   19  ,   43  ,   107 ,   235 ,   339 ,   65  ,   579 ,   2529    ,0 };
            const std::uint32_t dim358JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   1   ,   17  ,   39  ,   63  ,   67  ,   289 ,   593 ,   959 ,   1503    ,0 };
            const std::uint32_t dim359JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   11  ,   3   ,   15  ,   87  ,   153 ,   487 ,   537 ,   849 ,   385 ,0 };
            const std::uint32_t dim360JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   3   ,   5   ,   11  ,   99  ,   239 ,   241 ,   251 ,   793 ,   3677    ,0 };
            const std::uint32_t dim361JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   7   ,   13  ,   21  ,   111 ,   113 ,   69  ,   861 ,   1455    ,   3655    ,0 };
            const std::uint32_t dim362JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   11  ,   9   ,   21  ,   33  ,   29  ,   505 ,   81  ,   713 ,   2545    ,0 };
            const std::uint32_t dim363JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   11  ,   5   ,   29  ,   83  ,   73  ,   377 ,   611 ,   1099    ,   3225    ,0 };
            const std::uint32_t dim364JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   3   ,   25  ,   53  ,   75  ,   75  ,   235 ,   877 ,   609 ,   1535    ,0 };
            const std::uint32_t dim365JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   1   ,   29  ,   45  ,   27  ,   13  ,   437 ,   317 ,   581 ,   1179    ,0 };
            const std::uint32_t dim366JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   1   ,   3   ,   25  ,   127 ,   157 ,   443 ,   229 ,   277 ,   4059    ,0 };
            const std::uint32_t dim367JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   13  ,   17  ,   61  ,   31  ,   1   ,   483 ,   915 ,   1085    ,   1497    ,0 };
            const std::uint32_t dim368JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   11  ,   13  ,   57  ,   5   ,   49  ,   181 ,   881 ,   765 ,   1767    ,0 };
            const std::uint32_t dim369JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   1   ,   29  ,   17  ,   91  ,   95  ,   319 ,   339 ,   187 ,   2427    ,0 };
            const std::uint32_t dim370JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   5   ,   1   ,   17  ,   33  ,   181 ,   165 ,   237 ,   815 ,   3387    ,0 };
            const std::uint32_t dim371JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   1   ,   5   ,   17  ,   81  ,   193 ,   61  ,   411 ,   457 ,   2367    ,0 };
            const std::uint32_t dim372JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   7   ,   23  ,   17  ,   73  ,   185 ,   269 ,   1017    ,   299 ,   1879    ,0 };
            const std::uint32_t dim373JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   11  ,   7   ,   33  ,   75  ,   57  ,   275 ,   355 ,   1157    ,   2297    ,0 };
            const std::uint32_t dim374JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   7   ,   13  ,   7   ,   69  ,   25  ,   411 ,   319 ,   1385    ,   2081    ,0 };
            const std::uint32_t dim375JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   15  ,   27  ,   55  ,   35  ,   51  ,   71  ,   759 ,   1071    ,   51  ,0 };
            const std::uint32_t dim376JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   7   ,   29  ,   3   ,   25  ,   19  ,   123 ,   717 ,   1071    ,   257 ,0 };
            const std::uint32_t dim377JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   1   ,   7   ,   37  ,   51  ,   175 ,   19  ,   511 ,   469 ,   3757    ,0 };
            const std::uint32_t dim378JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   5   ,   19  ,   45  ,   107 ,   207 ,   369 ,   479 ,   853 ,   195 ,0 };
            const std::uint32_t dim379JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   9   ,   11  ,   11  ,   89  ,   115 ,   149 ,   789 ,   523 ,   2949    ,0 };
            const std::uint32_t dim380JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   11  ,   15  ,   53  ,   123 ,   167 ,   471 ,   355 ,   1515    ,   2291    ,0 };
            const std::uint32_t dim381JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   1   ,   23  ,   1   ,   5   ,   21  ,   315 ,   45  ,   1901    ,   3351    ,0 };
            const std::uint32_t dim382JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   5   ,   3   ,   49  ,   31  ,   89  ,   11  ,   777 ,   1003    ,   389 ,0 };
            const std::uint32_t dim383JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   3   ,   23  ,   3   ,   55  ,   213 ,   333 ,   257 ,   309 ,   4079    ,0 };
            const std::uint32_t dim384JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   7   ,   9   ,   29  ,   103 ,   41  ,   161 ,   253 ,   681 ,   1971    ,0 };
            const std::uint32_t dim385JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   13  ,   13  ,   33  ,   71  ,   121 ,   325 ,   423 ,   1485    ,   3205    ,0 };
            const std::uint32_t dim386JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   7   ,   9   ,   55  ,   69  ,   201 ,   111 ,   561 ,   1733    ,   1881    ,0 };
            const std::uint32_t dim387JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   7   ,   9   ,   41  ,   31  ,   113 ,   79  ,   193 ,   757 ,   329 ,0 };
            const std::uint32_t dim388JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   5   ,   3   ,   23  ,   27  ,   99  ,   179 ,   7   ,   1087    ,   27  ,0 };
            const std::uint32_t dim389JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   7   ,   13  ,   23  ,   9   ,   61  ,   157 ,   641 ,   299 ,   2077    ,0 };
            const std::uint32_t dim390JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   5   ,   29  ,   59  ,   63  ,   67  ,   493 ,   119 ,   959 ,   2683    ,0 };
            const std::uint32_t dim391JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   1   ,   19  ,   25  ,   117 ,   161 ,   249 ,   545 ,   997 ,   17  ,0 };
            const std::uint32_t dim392JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   5   ,   5   ,   31  ,   107 ,   181 ,   191 ,   913 ,   1911    ,   2329    ,0 };
            const std::uint32_t dim393JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   13  ,   31  ,   11  ,   109 ,   229 ,   159 ,   235 ,   975 ,   717 ,0 };
            const std::uint32_t dim394JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   3   ,   5   ,   7   ,   117 ,   233 ,   83  ,   31  ,   1641    ,   251 ,0 };
            const std::uint32_t dim395JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   1   ,   3   ,   45  ,   53  ,   179 ,   113 ,   353 ,   1805    ,   1097    ,0 };
            const std::uint32_t dim396JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   5   ,   17  ,   15  ,   83  ,   177 ,   399 ,   831 ,   231 ,   2307    ,0 };
            const std::uint32_t dim397JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   15  ,   19  ,   37  ,   19  ,   119 ,   243 ,   703 ,   1813    ,   2415    ,0 };
            const std::uint32_t dim398JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   9   ,   19  ,   25  ,   119 ,   123 ,   235 ,   817 ,   871 ,   763 ,0 };
            const std::uint32_t dim399JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   3   ,   7   ,   49  ,   97  ,   207 ,   297 ,   283 ,   467 ,   1843    ,0 };
            const std::uint32_t dim400JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   1   ,   21  ,   25  ,   103 ,   227 ,   239 ,   683 ,   797 ,   1763    ,0 };
            const std::uint32_t dim401JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   11  ,   27  ,   27  ,   127 ,   185 ,   137 ,   449 ,   1549    ,   3561    ,0 };
            const std::uint32_t dim402JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   5   ,   3   ,   45  ,   113 ,   35  ,   427 ,   847 ,   1761    ,   1721    ,0 };
            const std::uint32_t dim403JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   7   ,   25  ,   63  ,   33  ,   197 ,   183 ,   803 ,   963 ,   2179    ,0 };
            const std::uint32_t dim404JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   9   ,   19  ,   1   ,   3   ,   229 ,   225 ,   479 ,   593 ,   597 ,0 };
            const std::uint32_t dim405JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   5   ,   19  ,   35  ,   105 ,   245 ,   1   ,   249 ,   217 ,   2917    ,0 };
            const std::uint32_t dim406JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   1   ,   11  ,   3   ,   59  ,   51  ,   249 ,   135 ,   419 ,   3411    ,0 };
            const std::uint32_t dim407JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   15  ,   27  ,   45  ,   51  ,   15  ,   17  ,   473 ,   557 ,   2679    ,0 };
            const std::uint32_t dim408JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   11  ,   31  ,   43  ,   45  ,   163 ,   289 ,   723 ,   337 ,   2817    ,0 };
            const std::uint32_t dim409JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   11  ,   11  ,   51  ,   73  ,   101 ,   217 ,   255 ,   1547    ,   925 ,0 };
            const std::uint32_t dim410JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   5   ,   7   ,   53  ,   5   ,   163 ,   323 ,   757 ,   1443    ,   2703    ,0 };
            const std::uint32_t dim411JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   15  ,   19  ,   35  ,   23  ,   129 ,   199 ,   303 ,   1801    ,   1999    ,0 };
            const std::uint32_t dim412JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   15  ,   23  ,   37  ,   25  ,   61  ,   307 ,   901 ,   1117    ,   1301    ,0 };
            const std::uint32_t dim413JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   11  ,   15  ,   59  ,   71  ,   163 ,   93  ,   471 ,   341 ,   1825    ,0 };
            const std::uint32_t dim414JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   11  ,   27  ,   63  ,   73  ,   209 ,   453 ,   49  ,   1161    ,   1399    ,0 };
            const std::uint32_t dim415JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   3   ,   9   ,   5   ,   101 ,   47  ,   225 ,   451 ,   2005    ,   223 ,0 };
            const std::uint32_t dim416JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   3   ,   25  ,   43  ,   33  ,   171 ,   413 ,   371 ,   1133    ,   1057    ,0 };
            const std::uint32_t dim417JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   9   ,   5   ,   35  ,   39  ,   219 ,   319 ,   301 ,   1475    ,   3155    ,0 };
            const std::uint32_t dim418JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   15  ,   17  ,   39  ,   123 ,   165 ,   337 ,   17  ,   679 ,   3155    ,0 };
            const std::uint32_t dim419JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   3   ,   29  ,   33  ,   13  ,   165 ,   57  ,   723 ,   1201    ,   3523    ,0 };
            const std::uint32_t dim420JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   9   ,   25  ,   23  ,   67  ,   139 ,   321 ,   555 ,   723 ,   1017    ,0 };
            const std::uint32_t dim421JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   9   ,   17  ,   59  ,   25  ,   29  ,   473 ,   473 ,   1425    ,   965 ,0 };
            const std::uint32_t dim422JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   3   ,   13  ,   53  ,   29  ,   239 ,   321 ,   455 ,   1539    ,   1279    ,0 };
            const std::uint32_t dim423JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   3   ,   3   ,   37  ,   127 ,   149 ,   205 ,   313 ,   827 ,   1713    ,0 };
            const std::uint32_t dim424JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   5   ,   11  ,   41  ,   25  ,   73  ,   279 ,   539 ,   1761    ,   2565    ,0 };
            const std::uint32_t dim425JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   9   ,   21  ,   7   ,   75  ,   209 ,   83  ,   885 ,   821 ,   3887    ,0 };
            const std::uint32_t dim426JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   1   ,   21  ,   1   ,   13  ,   245 ,   291 ,   615 ,   1747    ,   1477    ,0 };
            const std::uint32_t dim427JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   1   ,   1   ,   11  ,   107 ,   105 ,   19  ,   263 ,   1497    ,   2311    ,0 };
            const std::uint32_t dim428JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   5   ,   15  ,   15  ,   105 ,   171 ,   143 ,   879 ,   1611    ,   277 ,0 };
            const std::uint32_t dim429JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   15  ,   15  ,   51  ,   15  ,   15  ,   25  ,   309 ,   1531    ,   977 ,0 };
            const std::uint32_t dim430JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   11  ,   29  ,   63  ,   65  ,   209 ,   155 ,   975 ,   107 ,   611 ,0 };
            const std::uint32_t dim431JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   15  ,   11  ,   55  ,   21  ,   149 ,   291 ,   221 ,   449 ,   133 ,0 };
            const std::uint32_t dim432JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   13  ,   3   ,   59  ,   41  ,   167 ,   37  ,   951 ,   1561    ,   2087    ,0 };
            const std::uint32_t dim433JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   15  ,   31  ,   59  ,   97  ,   49  ,   319 ,   935 ,   1419    ,   3215    ,0 };
            const std::uint32_t dim434JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   1   ,   27  ,   17  ,   91  ,   91  ,   327 ,   395 ,   1553    ,   201 ,0 };
            const std::uint32_t dim435JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   7   ,   5   ,   59  ,   51  ,   77  ,   207 ,   697 ,   521 ,   635 ,0 };
            const std::uint32_t dim436JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   5   ,   5   ,   37  ,   95  ,   91  ,   399 ,   151 ,   1795    ,   905 ,0 };
            const std::uint32_t dim437JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   5   ,   19  ,   29  ,   49  ,   55  ,   377 ,   793 ,   1429    ,   3393    ,0 };
            const std::uint32_t dim438JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   9   ,   9   ,   43  ,   127 ,   203 ,   355 ,   951 ,   711 ,   563 ,0 };
            const std::uint32_t dim439JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   13  ,   23  ,   21  ,   123 ,   41  ,   465 ,   33  ,   855 ,   1685    ,0 };
            const std::uint32_t dim440JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   7   ,   7   ,   11  ,   65  ,   195 ,   235 ,   823 ,   23  ,   2723    ,0 };
            const std::uint32_t dim441JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   7   ,   9   ,   41  ,   93  ,   109 ,   475 ,   587 ,   27  ,   1061    ,0 };
            const std::uint32_t dim442JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   13  ,   5   ,   45  ,   29  ,   87  ,   75  ,   853 ,   2023    ,   795 ,0 };
            const std::uint32_t dim443JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   3   ,   3   ,   7   ,   59  ,   235 ,   139 ,   457 ,   1855    ,   3739    ,0 };
            const std::uint32_t dim444JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   11  ,   23  ,   57  ,   25  ,   11  ,   473 ,   699 ,   887 ,   805 ,0 };
            const std::uint32_t dim445JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   1   ,   27  ,   3   ,   23  ,   115 ,   499 ,   287 ,   531 ,   1115    ,0 };
            const std::uint32_t dim446JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   15  ,   7   ,   7   ,   33  ,   83  ,   29  ,   477 ,   727 ,   3037    ,0 };
            const std::uint32_t dim447JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   9   ,   27  ,   43  ,   113 ,   203 ,   413 ,   649 ,   869 ,   3351    ,0 };
            const std::uint32_t dim448JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   9   ,   27  ,   15  ,   105 ,   167 ,   431 ,   87  ,   931 ,   4017    ,0 };
            const std::uint32_t dim449JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   1   ,   15  ,   23  ,   85  ,   145 ,   349 ,   291 ,   1137    ,   605 ,0 };
            const std::uint32_t dim450JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   15  ,   31  ,   53  ,   127 ,   25  ,   15  ,   277 ,   575 ,   1327    ,0 };
            const std::uint32_t dim451JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   15  ,   17  ,   29  ,   125 ,   251 ,   469 ,   15  ,   1803    ,   237 ,0 };
            const std::uint32_t dim452JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   13  ,   9   ,   21  ,   23  ,   111 ,   103 ,   861 ,   1137    ,   3843    ,0 };
            const std::uint32_t dim453JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   5   ,   29  ,   49  ,   101 ,   237 ,   187 ,   825 ,   137 ,   957 ,0 };
            const std::uint32_t dim454JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   13  ,   13  ,   9   ,   101 ,   171 ,   15  ,   245 ,   107 ,   2179    ,0 };
            const std::uint32_t dim455JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   11  ,   21  ,   33  ,   51  ,   211 ,   113 ,   569 ,   295 ,   3593    ,0 };
            const std::uint32_t dim456JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   5   ,   9   ,   5   ,   119 ,   159 ,   211 ,   121 ,   1547    ,   2267    ,0 };
            const std::uint32_t dim457JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   9   ,   7   ,   19  ,   53  ,   39  ,   271 ,   437 ,   765 ,   1511    ,0 };
            const std::uint32_t dim458JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   9   ,   3   ,   5   ,   119 ,   83  ,   161 ,   275 ,   1443    ,   465 ,0 };
            const std::uint32_t dim459JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   1   ,   27  ,   61  ,   103 ,   207 ,   249 ,   479 ,   651 ,   1793    ,0 };
            const std::uint32_t dim460JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   9   ,   11  ,   53  ,   43  ,   41  ,   271 ,   859 ,   25  ,   1401    ,0 };
            const std::uint32_t dim461JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   5   ,   9   ,   39  ,   87  ,   21  ,   425 ,   561 ,   861 ,   2801    ,0 };
            const std::uint32_t dim462JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   1   ,   1   ,   25  ,   21  ,   199 ,   315 ,   355 ,   429 ,   3093    ,0 };
            const std::uint32_t dim463JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   9   ,   11  ,   63  ,   123 ,   253 ,   483 ,   781 ,   1685    ,   977 ,0 };
            const std::uint32_t dim464JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   15  ,   17  ,   57  ,   19  ,   251 ,   173 ,   519 ,   1523    ,   749 ,0 };
            const std::uint32_t dim465JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   11  ,   23  ,   5   ,   119 ,   7   ,   327 ,   507 ,   1777    ,   951 ,0 };
            const std::uint32_t dim466JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   5   ,   1   ,   37  ,   41  ,   99  ,   273 ,   241 ,   293 ,   2289    ,0 };
            const std::uint32_t dim467JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   9   ,   3   ,   51  ,   65  ,   115 ,   159 ,   341 ,   1603    ,   3769    ,0 };
            const std::uint32_t dim468JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   3   ,   15  ,   61  ,   105 ,   103 ,   113 ,   435 ,   415 ,   161 ,0 };
            const std::uint32_t dim469JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   7   ,   9   ,   9   ,   17  ,   13  ,   135 ,   923 ,   951 ,   3603    ,0 };
            const std::uint32_t dim470JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   13  ,   9   ,   31  ,   25  ,   175 ,   449 ,   541 ,   745 ,   2771    ,0 };
            const std::uint32_t dim471JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   9   ,   5   ,   5   ,   61  ,   17  ,   357 ,   623 ,   873 ,   975 ,0 };
            const std::uint32_t dim472JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   9   ,   9   ,   31  ,   11  ,   225 ,   81  ,   965 ,   1837    ,   1975    ,0 };
            const std::uint32_t dim473JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   1   ,   3   ,   57  ,   69  ,   169 ,   11  ,   633 ,   885 ,   535 ,0 };
            const std::uint32_t dim474JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   9   ,   21  ,   63  ,   73  ,   233 ,   151 ,   519 ,   1319    ,   1485    ,0 };
            const std::uint32_t dim475JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   11  ,   23  ,   5   ,   51  ,   115 ,   501 ,   627 ,   1875    ,   3003    ,0 };
            const std::uint32_t dim476JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   1   ,   9   ,   3   ,   91  ,   177 ,   305 ,   897 ,   317 ,   3231    ,0 };
            const std::uint32_t dim477JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   3   ,   9   ,   13  ,   121 ,   93  ,   303 ,   551 ,   1087    ,   905 ,0 };
            const std::uint32_t dim478JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   7   ,   1   ,   63  ,   123 ,   177 ,   87  ,   489 ,   1247    ,   1831    ,0 };
            const std::uint32_t dim479JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   5   ,   25  ,   61  ,   1   ,   225 ,   247 ,   991 ,   231 ,   657 ,0 };
            const std::uint32_t dim480JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   5   ,   19  ,   23  ,   113 ,   101 ,   427 ,   327 ,   1859    ,   3115    ,0 };
            const std::uint32_t dim481JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   13  ,   11  ,   5   ,   125 ,   133 ,   131 ,   441 ,   1277    ,   2583    ,   7133    ,0 };
            const std::uint32_t dim482JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   3   ,   29  ,   45  ,   21  ,   45  ,   477 ,   135 ,   13  ,   2531    ,   7657    ,0 };
            const std::uint32_t dim483JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   9   ,   19  ,   3   ,   47  ,   37  ,   491 ,   237 ,   1493    ,   4053    ,   6025    ,0 };
            const std::uint32_t dim484JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   7   ,   15  ,   51  ,   23  ,   181 ,   63  ,   755 ,   761 ,   3215    ,   3547    ,0 };
            const std::uint32_t dim485JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   5   ,   11  ,   3   ,   27  ,   187 ,   221 ,   305 ,   1941    ,   1443    ,   5161    ,0 };
            const std::uint32_t dim486JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   13  ,   13  ,   53  ,   63  ,   19  ,   5   ,   273 ,   1305    ,   919 ,   3335    ,0 };
            const std::uint32_t dim487JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   5   ,   15  ,   19  ,   85  ,   35  ,   41  ,   117 ,   1269    ,   289 ,   7433    ,0 };
            const std::uint32_t dim488JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   9   ,   27  ,   49  ,   119 ,   101 ,   57  ,   267 ,   1225    ,   3779    ,   3357    ,0 };
            const std::uint32_t dim489JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   11  ,   5   ,   1   ,   9   ,   251 ,   411 ,   19  ,   763 ,   1297    ,   5309    ,0 };
            const std::uint32_t dim490JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   13  ,   31  ,   55  ,   67  ,   63  ,   23  ,   1021    ,   199 ,   2885    ,   1777    ,0 };
            const std::uint32_t dim491JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   9   ,   29  ,   27  ,   123 ,   191 ,   125 ,   295 ,   891 ,   3507    ,   2895    ,0 };
            const std::uint32_t dim492JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   7   ,   15  ,   41  ,   35  ,   119 ,   343 ,   603 ,   819 ,   41  ,   8131    ,0 };
            const std::uint32_t dim493JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   9   ,   21  ,   61  ,   43  ,   199 ,   359 ,   607 ,   623 ,   1579    ,   7899    ,0 };
            const std::uint32_t dim494JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   15  ,   25  ,   59  ,   47  ,   47  ,   365 ,   125 ,   921 ,   3081    ,   2081    ,0 };
            const std::uint32_t dim495JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   1   ,   23  ,   23  ,   111 ,   53  ,   395 ,   945 ,   59  ,   3345    ,   1671    ,0 };
            const std::uint32_t dim496JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   15  ,   15  ,   57  ,   31  ,   15  ,   235 ,   247 ,   1645    ,   3085    ,   4381    ,0 };
            const std::uint32_t dim497JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   11  ,   23  ,   21  ,   9   ,   89  ,   61  ,   347 ,   1423    ,   3613    ,   697 ,0 };
            const std::uint32_t dim498JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   13  ,   21  ,   37  ,   5   ,   159 ,   409 ,   131 ,   559 ,   3505    ,   6631    ,0 };
            const std::uint32_t dim499JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   11  ,   23  ,   51  ,   97  ,   247 ,   137 ,   183 ,   1775    ,   2169    ,   2869    ,0 };
            const std::uint32_t dim500JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   7   ,   29  ,   53  ,   109 ,   75  ,   327 ,   755 ,   825 ,   329 ,   5795    ,0 };
            const std::uint32_t dim501JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   5   ,   17  ,   63  ,   109 ,   199 ,   215 ,   869 ,   2009    ,   1153    ,   1233    ,0 };
            const std::uint32_t dim502JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   15  ,   15  ,   37  ,   63  ,   93  ,   151 ,   621 ,   1749    ,   2211    ,   5437    ,0 };
            const std::uint32_t dim503JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   15  ,   13  ,   63  ,   57  ,   17  ,   323 ,   271 ,   1451    ,   459 ,   1187    ,0 };
            const std::uint32_t dim504JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   5   ,   31  ,   47  ,   15  ,   83  ,   389 ,   857 ,   505 ,   635 ,   7341    ,0 };
            const std::uint32_t dim505JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   3   ,   19  ,   7   ,   83  ,   17  ,   51  ,   947 ,   1193    ,   163 ,   3895    ,0 };
            const std::uint32_t dim506JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   1   ,   23  ,   5   ,   115 ,   113 ,   445 ,   703 ,   747 ,   963 ,   7483    ,0 };
            const std::uint32_t dim507JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   5   ,   27  ,   31  ,   41  ,   221 ,   313 ,   317 ,   517 ,   3901    ,   3937    ,0 };
            const std::uint32_t dim508JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   11  ,   29  ,   41  ,   23  ,   249 ,   169 ,   51  ,   1783    ,   2493    ,   6109    ,0 };
            const std::uint32_t dim509JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   13  ,   23  ,   23  ,   85  ,   71  ,   321 ,   623 ,   207 ,   3027    ,   319 ,0 };
            const std::uint32_t dim510JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   3   ,   3   ,   19  ,   63  ,   233 ,   377 ,   509 ,   1969    ,   67  ,   5059    ,0 };
            const std::uint32_t dim511JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   7   ,   13  ,   27  ,   39  ,   67  ,   483 ,   587 ,   1581    ,   177 ,   5213    ,0 };
            const std::uint32_t dim512JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   1   ,   23  ,   55  ,   3   ,   177 ,   97  ,   551 ,   1733    ,   1943    ,   6607    ,0 };
            const std::uint32_t dim513JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   5   ,   5   ,   9   ,   39  ,   189 ,   473 ,   5   ,   19  ,   2793    ,   6937    ,0 };
            const std::uint32_t dim514JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   13  ,   31  ,   35  ,   105 ,   19  ,   279 ,   749 ,   523 ,   1503    ,   6231    ,0 };
            const std::uint32_t dim515JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   9   ,   11  ,   59  ,   89  ,   153 ,   155 ,   219 ,   549 ,   2263    ,   8101    ,0 };
            const std::uint32_t dim516JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   13  ,   29  ,   9   ,   9   ,   61  ,   43  ,   165 ,   1395    ,   91  ,   2871    ,0 };
            const std::uint32_t dim517JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   1   ,   27  ,   63  ,   63  ,   97  ,   47  ,   969 ,   991 ,   111 ,   2267    ,0 };
            const std::uint32_t dim518JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   7   ,   5   ,   13  ,   51  ,   195 ,   369 ,   551 ,   961 ,   1123    ,   7001    ,0 };
            const std::uint32_t dim519JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   7   ,   27  ,   57  ,   49  ,   51  ,   321 ,   187 ,   1869    ,   1181    ,   6333    ,0 };
            const std::uint32_t dim520JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   3   ,   25  ,   63  ,   15  ,   165 ,   175 ,   401 ,   1659    ,   2345    ,   683 ,0 };
            const std::uint32_t dim521JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   1   ,   9   ,   41  ,   121 ,   123 ,   49  ,   303 ,   229 ,   2799    ,   3247    ,0 };
            const std::uint32_t dim522JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   15  ,   29  ,   11  ,   113 ,   137 ,   221 ,   859 ,   1601    ,   215 ,   6257    ,0 };
            const std::uint32_t dim523JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   9   ,   9   ,   21  ,   91  ,   179 ,   369 ,   389 ,   1737    ,   1235    ,   3033    ,0 };
            const std::uint32_t dim524JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   7   ,   21  ,   53  ,   85  ,   217 ,   505 ,   299 ,   1505    ,   3289    ,   3811    ,0 };
            const std::uint32_t dim525JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   15  ,   25  ,   25  ,   109 ,   229 ,   511 ,   733 ,   1047    ,   3295    ,   307 ,0 };
            const std::uint32_t dim526JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   15  ,   29  ,   25  ,   21  ,   201 ,   353 ,   97  ,   231 ,   3791    ,   3019    ,0 };
            const std::uint32_t dim527JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   5   ,   1   ,   7   ,   75  ,   57  ,   501 ,   217 ,   1647    ,   1539    ,   2961    ,0 };
            const std::uint32_t dim528JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   5   ,   21  ,   13  ,   123 ,   153 ,   83  ,   253 ,   19  ,   2469    ,   5239    ,0 };
            const std::uint32_t dim529JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   3   ,   31  ,   13  ,   103 ,   107 ,   91  ,   3   ,   1795    ,   3587    ,   3345    ,0 };
            const std::uint32_t dim530JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   13  ,   1   ,   47  ,   71  ,   61  ,   335 ,   347 ,   753 ,   3685    ,   3895    ,0 };
            const std::uint32_t dim531JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   11  ,   25  ,   53  ,   73  ,   65  ,   203 ,   923 ,   661 ,   1349    ,   8089    ,0 };
            const std::uint32_t dim532JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   5   ,   11  ,   23  ,   93  ,   149 ,   367 ,   577 ,   1095    ,   993 ,   5279    ,0 };
            const std::uint32_t dim533JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   7   ,   11  ,   33  ,   23  ,   117 ,   457 ,   1023    ,   1789    ,   3103    ,   2979    ,0 };
            const std::uint32_t dim534JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   11  ,   3   ,   3   ,   3   ,   177 ,   9   ,   11  ,   1753    ,   3291    ,   7617    ,0 };
            const std::uint32_t dim535JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   7   ,   1   ,   27  ,   105 ,   199 ,   465 ,   505 ,   427 ,   2605    ,   7215    ,0 };
            const std::uint32_t dim536JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   1   ,   19  ,   23  ,   21  ,   167 ,   205 ,   561 ,   175 ,   677 ,   117 ,0 };
            const std::uint32_t dim537JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   7   ,   31  ,   23  ,   83  ,   219 ,   391 ,   101 ,   1433    ,   3973    ,   4217    ,0 };
            const std::uint32_t dim538JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   3   ,   9   ,   41  ,   21  ,   189 ,   437 ,   187 ,   1973    ,   445 ,   7439    ,0 };
            const std::uint32_t dim539JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   7   ,   21  ,   3   ,   53  ,   9   ,   295 ,   331 ,   2029    ,   3063    ,   6095    ,0 };
            const std::uint32_t dim540JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   7   ,   19  ,   9   ,   119 ,   247 ,   371 ,   635 ,   1411    ,   419 ,   3297    ,0 };
            const std::uint32_t dim541JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   1   ,   3   ,   31  ,   113 ,   235 ,   57  ,   923 ,   2033    ,   1523    ,   6381    ,0 };
            const std::uint32_t dim542JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   3   ,   17  ,   51  ,   115 ,   215 ,   271 ,   411 ,   573 ,   1761    ,   1793    ,0 };
            const std::uint32_t dim543JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   11  ,   5   ,   15  ,   69  ,   193 ,   107 ,   577 ,   909 ,   1997    ,   4503    ,0 };
            const std::uint32_t dim544JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   3   ,   1   ,   3   ,   17  ,   227 ,   381 ,   931 ,   1933    ,   807 ,   3295    ,0 };
            const std::uint32_t dim545JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   15  ,   15  ,   23  ,   15  ,   183 ,   247 ,   167 ,   193 ,   1643    ,   4139    ,0 };
            const std::uint32_t dim546JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   13  ,   31  ,   39  ,   13  ,   213 ,   45  ,   643 ,   515 ,   1167    ,   6991    ,0 };
            const std::uint32_t dim547JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   9   ,   15  ,   7   ,   5   ,   223 ,   53  ,   413 ,   403 ,   3003    ,   4135    ,0 };
            const std::uint32_t dim548JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   5   ,   25  ,   25  ,   31  ,   209 ,   113 ,   971 ,   629 ,   189 ,   2309    ,0 };
            const std::uint32_t dim549JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   3   ,   23  ,   29  ,   37  ,   39  ,   73  ,   797 ,   589 ,   1351    ,   4495    ,0 };
            const std::uint32_t dim550JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   13  ,   31  ,   25  ,   15  ,   147 ,   351 ,   541 ,   493 ,   1361    ,   3151    ,0 };
            const std::uint32_t dim551JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   9   ,   31  ,   45  ,   43  ,   125 ,   503 ,   987 ,   1485    ,   521 ,   957 ,0 };
            const std::uint32_t dim552JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   5   ,   1   ,   51  ,   7   ,   189 ,   111 ,   735 ,   993 ,   2313    ,   7027    ,0 };
            const std::uint32_t dim553JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   1   ,   5   ,   11  ,   123 ,   241 ,   325 ,   337 ,   1369    ,   3515    ,   8077    ,0 };
            const std::uint32_t dim554JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   13  ,   9   ,   57  ,   89  ,   89  ,   439 ,   803 ,   545 ,   1097    ,   2443    ,0 };
            const std::uint32_t dim555JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   7   ,   1   ,   31  ,   23  ,   121 ,   19  ,   469 ,   887 ,   3925    ,   6591    ,0 };
            const std::uint32_t dim556JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   7   ,   11  ,   39  ,   95  ,   65  ,   39  ,   407 ,   1187    ,   2803    ,   643 ,0 };
            const std::uint32_t dim557JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   3   ,   23  ,   43  ,   97  ,   39  ,   463 ,   929 ,   469 ,   255 ,   7219    ,0 };
            const std::uint32_t dim558JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   5   ,   21  ,   47  ,   99  ,   117 ,   233 ,   921 ,   801 ,   1105    ,   2993    ,0 };
            const std::uint32_t dim559JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   5   ,   7   ,   1   ,   33  ,   61  ,   389 ,   969 ,   389 ,   2081    ,   4215    ,0 };
            const std::uint32_t dim560JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   7   ,   15  ,   5   ,   103 ,   115 ,   59  ,   699 ,   1287    ,   3023    ,   7599    ,0 };
            const std::uint32_t dim561JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   15  ,   23  ,   49  ,   19  ,   85  ,   219 ,   837 ,   15  ,   1213    ,   1011    ,0 };
            const std::uint32_t dim562JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   3   ,   9   ,   19  ,   55  ,   247 ,   97  ,   125 ,   1377    ,   3107    ,   1787    ,0 };
            const std::uint32_t dim563JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   7   ,   31  ,   13  ,   35  ,   53  ,   269 ,   603 ,   729 ,   1827    ,   1083    ,0 };
            const std::uint32_t dim564JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   11  ,   7   ,   55  ,   81  ,   61  ,   3   ,   119 ,   995 ,   1721    ,   3205    ,0 };
            const std::uint32_t dim565JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   13  ,   11  ,   57  ,   81  ,   63  ,   271 ,   1001    ,   1901    ,   471 ,   2217    ,0 };
            const std::uint32_t dim566JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   1   ,   1   ,   47  ,   79  ,   175 ,   145 ,   615 ,   1393    ,   137 ,   589 ,0 };
            const std::uint32_t dim567JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   11  ,   25  ,   47  ,   93  ,   81  ,   157 ,   913 ,   1117    ,   819 ,   8079    ,0 };
            const std::uint32_t dim568JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   1   ,   23  ,   51  ,   85  ,   101 ,   41  ,   115 ,   303 ,   1721    ,   6515    ,0 };
            const std::uint32_t dim569JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   13  ,   23  ,   31  ,   1   ,   31  ,   63  ,   595 ,   611 ,   3153    ,   7865    ,0 };
            const std::uint32_t dim570JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   9   ,   17  ,   35  ,   53  ,   53  ,   421 ,   537 ,   557 ,   2735    ,   7813    ,0 };
            const std::uint32_t dim571JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   11  ,   7   ,   17  ,   105 ,   1   ,   201 ,   45  ,   1517    ,   3303    ,   3287    ,0 };
            const std::uint32_t dim572JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   15  ,   15  ,   63  ,   45  ,   129 ,   81  ,   901 ,   1735    ,   3551    ,   2885    ,0 };
            const std::uint32_t dim573JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   15  ,   21  ,   9   ,   63  ,   133 ,   245 ,   807 ,   1425    ,   961 ,   7425    ,0 };
            const std::uint32_t dim574JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   15  ,   27  ,   25  ,   41  ,   93  ,   253 ,   345 ,   875 ,   1663    ,   5713    ,0 };
            const std::uint32_t dim575JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   1   ,   9   ,   61  ,   117 ,   183 ,   381 ,   739 ,   1739    ,   3285    ,   747 ,0 };
            const std::uint32_t dim576JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   15  ,   7   ,   49  ,   39  ,   233 ,   465 ,   511 ,   1853    ,   637 ,   6823    ,0 };
            const std::uint32_t dim577JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   15  ,   29  ,   19  ,   1   ,   71  ,   109 ,   959 ,   1575    ,   3225    ,   3951    ,0 };
            const std::uint32_t dim578JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   7   ,   3   ,   21  ,   23  ,   25  ,   423 ,   507 ,   617 ,   2175    ,   7331    ,0 };
            const std::uint32_t dim579JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   5   ,   31  ,   19  ,   111 ,   139 ,   217 ,   301 ,   1845    ,   1789    ,   5935    ,0 };
            const std::uint32_t dim580JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   11  ,   19  ,   63  ,   53  ,   47  ,   493 ,   181 ,   709 ,   3601    ,   6163    ,0 };
            const std::uint32_t dim581JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   9   ,   7   ,   57  ,   57  ,   89  ,   25  ,   757 ,   1959    ,   285 ,   2121    ,0 };
            const std::uint32_t dim582JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   13  ,   13  ,   23  ,   25  ,   61  ,   481 ,   473 ,   1933    ,   1861    ,   881 ,0 };
            const std::uint32_t dim583JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   15  ,   11  ,   27  ,   53  ,   243 ,   439 ,   221 ,   1281    ,   1129    ,   6685    ,0 };
            const std::uint32_t dim584JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   7   ,   11  ,   55  ,   11  ,   99  ,   153 ,   517 ,   985 ,   3533    ,   1363    ,0 };
            const std::uint32_t dim585JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   3   ,   11  ,   7   ,   95  ,   193 ,   161 ,   183 ,   1417    ,   187 ,   4787    ,0 };
            const std::uint32_t dim586JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   13  ,   13  ,   21  ,   1   ,   183 ,   257 ,   393 ,   831 ,   2149    ,   2219    ,0 };
            const std::uint32_t dim587JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   9   ,   1   ,   19  ,   9   ,   95  ,   65  ,   57  ,   1999    ,   125 ,   2181    ,0 };
            const std::uint32_t dim588JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   11  ,   3   ,   29  ,   57  ,   249 ,   93  ,   143 ,   1163    ,   2635    ,   837 ,0 };
            const std::uint32_t dim589JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   3   ,   19  ,   3   ,   61  ,   151 ,   115 ,   601 ,   1085    ,   2505    ,   4171    ,0 };
            const std::uint32_t dim590JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   11  ,   19  ,   35  ,   89  ,   117 ,   5   ,   197 ,   1763    ,   415 ,   5455    ,0 };
            const std::uint32_t dim591JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   13  ,   1   ,   41  ,   77  ,   127 ,   93  ,   785 ,   269 ,   915 ,   5723    ,0 };
            const std::uint32_t dim592JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   5   ,   25  ,   39  ,   77  ,   77  ,   499 ,   931 ,   1707    ,   3401    ,   5707    ,0 };
            const std::uint32_t dim593JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   13  ,   7   ,   41  ,   99  ,   3   ,   463 ,   433 ,   651 ,   4079    ,   409 ,0 };
            const std::uint32_t dim594JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   3   ,   25  ,   25  ,   51  ,   211 ,   269 ,   867 ,   1403    ,   517 ,   4371    ,0 };
            const std::uint32_t dim595JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   15  ,   23  ,   53  ,   53  ,   41  ,   269 ,   571 ,   525 ,   2309    ,   431 ,0 };
            const std::uint32_t dim596JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   5   ,   19  ,   25  ,   125 ,   133 ,   249 ,   555 ,   781 ,   2853    ,   2185    ,0 };
            const std::uint32_t dim597JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   13  ,   27  ,   59  ,   47  ,   67  ,   197 ,   865 ,   101 ,   2291    ,   6219    ,0 };
            const std::uint32_t dim598JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   7   ,   5   ,   43  ,   95  ,   209 ,   407 ,   821 ,   215 ,   2371    ,   5059    ,0 };
            const std::uint32_t dim599JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   1   ,   7   ,   25  ,   75  ,   239 ,   327 ,   969 ,   575 ,   2519    ,   3515    ,0 };
            const std::uint32_t dim600JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   3   ,   3   ,   13  ,   105 ,   1   ,   319 ,   549 ,   1003    ,   3441    ,   185 ,0 };
            const std::uint32_t dim601JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   9   ,   29  ,   17  ,   75  ,   95  ,   407 ,   199 ,   1609    ,   3537    ,   7293    ,0 };
            const std::uint32_t dim602JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   7   ,   15  ,   27  ,   39  ,   175 ,   431 ,   905 ,   925 ,   3277    ,   8029    ,0 };
            const std::uint32_t dim603JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   3   ,   3   ,   19  ,   73  ,   87  ,   107 ,   605 ,   45  ,   3267    ,   3033    ,0 };
            const std::uint32_t dim604JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   1   ,   31  ,   9   ,   73  ,   151 ,   71  ,   929 ,   1995    ,   739 ,   1483    ,0 };
            const std::uint32_t dim605JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   3   ,   7   ,   55  ,   27  ,   177 ,   225 ,   333 ,   663 ,   4065    ,   2559    ,0 };
            const std::uint32_t dim606JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   5   ,   21  ,   61  ,   121 ,   159 ,   269 ,   267 ,   1307    ,   1213    ,   5057    ,0 };
            const std::uint32_t dim607JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   15  ,   3   ,   35  ,   29  ,   243 ,   199 ,   695 ,   1225    ,   3437    ,   7451    ,0 };
            const std::uint32_t dim608JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   9   ,   15  ,   23  ,   15  ,   43  ,   383 ,   95  ,   239 ,   945 ,   5339    ,0 };
            const std::uint32_t dim609JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   9   ,   23  ,   11  ,   81  ,   93  ,   493 ,   435 ,   1291    ,   873 ,   5101    ,0 };
            const std::uint32_t dim610JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   7   ,   23  ,   11  ,   89  ,   95  ,   203 ,   533 ,   583 ,   981 ,   2029    ,0 };
            const std::uint32_t dim611JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   3   ,   27  ,   57  ,   59  ,   161 ,   361 ,   511 ,   1723    ,   1893    ,   4113    ,0 };
            const std::uint32_t dim612JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   15  ,   27  ,   5   ,   7   ,   213 ,   509 ,   483 ,   1645    ,   3487    ,   2927    ,0 };
            const std::uint32_t dim613JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   13  ,   17  ,   47  ,   87  ,   25  ,   331 ,   793 ,   1467    ,   875 ,   7147    ,0 };
            const std::uint32_t dim614JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   1   ,   29  ,   51  ,   21  ,   223 ,   289 ,   461 ,   1153    ,   579 ,   2621    ,0 };
            const std::uint32_t dim615JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   5   ,   9   ,   9   ,   69  ,   21  ,   257 ,   679 ,   1031    ,   809 ,   1633    ,0 };
            const std::uint32_t dim616JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   13  ,   3   ,   59  ,   27  ,   193 ,   507 ,   407 ,   831 ,   1921    ,   4411    ,0 };
            const std::uint32_t dim617JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   9   ,   19  ,   61  ,   77  ,   163 ,   103 ,   35  ,   803 ,   2327    ,   7349    ,0 };
            const std::uint32_t dim618JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   1   ,   5   ,   19  ,   49  ,   79  ,   469 ,   595 ,   625 ,   333 ,   4861    ,0 };
            const std::uint32_t dim619JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   13  ,   9   ,   17  ,   97  ,   229 ,   263 ,   63  ,   1907    ,   2493    ,   1001    ,0 };
            const std::uint32_t dim620JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   11  ,   25  ,   23  ,   111 ,   51  ,   7   ,   551 ,   1669    ,   2495    ,   3409    ,0 };
            const std::uint32_t dim621JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   13  ,   5   ,   39  ,   115 ,   179 ,   473 ,   179 ,   2047    ,   467 ,   5797    ,0 };
            const std::uint32_t dim622JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   9   ,   21  ,   3   ,   9   ,   245 ,   29  ,   457 ,   101 ,   253 ,   5757    ,0 };
            const std::uint32_t dim623JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   5   ,   1   ,   11  ,   123 ,   29  ,   43  ,   259 ,   1387    ,   2973    ,   2509    ,0 };
            const std::uint32_t dim624JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   9   ,   15  ,   35  ,   85  ,   165 ,   91  ,   793 ,   1963    ,   595 ,   1721    ,0 };
            const std::uint32_t dim625JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   11  ,   29  ,   29  ,   79  ,   33  ,   439 ,   635 ,   1639    ,   803 ,   847 ,0 };
            const std::uint32_t dim626JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   5   ,   29  ,   9   ,   121 ,   239 ,   33  ,   535 ,   1957    ,   1459    ,   7997    ,0 };
            const std::uint32_t dim627JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   9   ,   7   ,   15  ,   11  ,   91  ,   495 ,   939 ,   1597    ,   4011    ,   97  ,0 };
            const std::uint32_t dim628JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   7   ,   27  ,   1   ,   115 ,   29  ,   345 ,   665 ,   1433    ,   3291    ,   1431    ,0 };
            const std::uint32_t dim629JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   11  ,   21  ,   27  ,   127 ,   55  ,   401 ,   787 ,   405 ,   715 ,   5385    ,0 };
            const std::uint32_t dim630JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   7   ,   7   ,   59  ,   109 ,   221 ,   179 ,   217 ,   1045    ,   1979    ,   4003    ,0 };
            const std::uint32_t dim631JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   9   ,   17  ,   57  ,   73  ,   219 ,   369 ,   235 ,   43  ,   65  ,   919 ,0 };
            const std::uint32_t dim632JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   13  ,   19  ,   29  ,   73  ,   7   ,   405 ,   691 ,   1007    ,   341 ,   7153    ,0 };
            const std::uint32_t dim633JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   9   ,   1   ,   17  ,   67  ,   101 ,   33  ,   851 ,   1227    ,   41  ,   8057    ,0 };
            const std::uint32_t dim634JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   15  ,   21  ,   37  ,   43  ,   161 ,   63  ,   27  ,   855 ,   3983    ,   7661    ,0 };
            const std::uint32_t dim635JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   3   ,   25  ,   11  ,   85  ,   127 ,   309 ,   979 ,   1071    ,   3485    ,   3513    ,0 };
            const std::uint32_t dim636JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   1   ,   21  ,   51  ,   37  ,   87  ,   71  ,   923 ,   1983    ,   1013    ,   4677    ,0 };
            const std::uint32_t dim637JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   3   ,   29  ,   13  ,   93  ,   193 ,   207 ,   229 ,   185 ,   2109    ,   8085    ,0 };
            const std::uint32_t dim638JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   5   ,   15  ,   43  ,   101 ,   27  ,   185 ,   541 ,   1371    ,   1487    ,   11  ,0 };
            const std::uint32_t dim639JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   7   ,   11  ,   35  ,   83  ,   163 ,   3   ,   391 ,   343 ,   2931    ,   1183    ,0 };
            const std::uint32_t dim640JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   7   ,   5   ,   1   ,   109 ,   195 ,   389 ,   679 ,   571 ,   121 ,   2669    ,0 };
            const std::uint32_t dim641JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   13  ,   11  ,   11  ,   47  ,   105 ,   389 ,   661 ,   113 ,   2849    ,   2861    ,0 };
            const std::uint32_t dim642JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   7   ,   27  ,   3   ,   33  ,   105 ,   81  ,   817 ,   691 ,   1017    ,   4477    ,0 };
            const std::uint32_t dim643JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   15  ,   19  ,   63  ,   11  ,   179 ,   473 ,   695 ,   1033    ,   363 ,   1479    ,0 };
            const std::uint32_t dim644JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   5   ,   23  ,   33  ,   121 ,   101 ,   349 ,   599 ,   1821    ,   3975    ,   263 ,0 };
            const std::uint32_t dim645JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   11  ,   21  ,   1   ,   115 ,   123 ,   367 ,   497 ,   609 ,   1473    ,   515 ,0 };
            const std::uint32_t dim646JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   5   ,   13  ,   49  ,   63  ,   63  ,   137 ,   39  ,   1281    ,   1289    ,   6687    ,0 };
            const std::uint32_t dim647JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   3   ,   9   ,   49  ,   11  ,   205 ,   451 ,   163 ,   125 ,   2639    ,   1921    ,0 };
            const std::uint32_t dim648JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   5   ,   5   ,   29  ,   67  ,   33  ,   169 ,   133 ,   599 ,   2559    ,   6495    ,0 };
            const std::uint32_t dim649JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   13  ,   21  ,   47  ,   119 ,   39  ,   389 ,   695 ,   717 ,   1003    ,   4107    ,0 };
            const std::uint32_t dim650JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   7   ,   23  ,   49  ,   113 ,   245 ,   485 ,   291 ,   1431    ,   3577    ,   1787    ,0 };
            const std::uint32_t dim651JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   11  ,   27  ,   59  ,   127 ,   205 ,   177 ,   73  ,   935 ,   2041    ,   6899    ,0 };
            const std::uint32_t dim652JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   13  ,   27  ,   41  ,   115 ,   121 ,   239 ,   939 ,   1963    ,   2045    ,   2457    ,0 };
            const std::uint32_t dim653JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   11  ,   23  ,   51  ,   13  ,   177 ,   51  ,   145 ,   651 ,   3817    ,   2399    ,0 };
            const std::uint32_t dim654JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   3   ,   11  ,   35  ,   119 ,   251 ,   303 ,   673 ,   1475    ,   1415    ,   3809    ,0 };
            const std::uint32_t dim655JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   3   ,   31  ,   25  ,   117 ,   87  ,   19  ,   491 ,   1681    ,   2291    ,   3559    ,0 };
            const std::uint32_t dim656JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   15  ,   25  ,   13  ,   83  ,   243 ,   499 ,   77  ,   1809    ,   81  ,   4211    ,0 };
            const std::uint32_t dim657JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   3   ,   27  ,   7   ,   119 ,   141 ,   305 ,   323 ,   1679    ,   1143    ,   2277    ,0 };
            const std::uint32_t dim658JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   7   ,   27  ,   31  ,   31  ,   219 ,   55  ,   437 ,   1113    ,   2801    ,   1409    ,0 };
            const std::uint32_t dim659JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   7   ,   25  ,   51  ,   77  ,   255 ,   211 ,   265 ,   1597    ,   3883    ,   5913    ,0 };
            const std::uint32_t dim660JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   1   ,   23  ,   55  ,   21  ,   243 ,   329 ,   221 ,   901 ,   1363    ,   1449    ,0 };
            const std::uint32_t dim661JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   3   ,   7   ,   53  ,   63  ,   143 ,   503 ,   295 ,   135 ,   4037    ,   6363    ,0 };
            const std::uint32_t dim662JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   7   ,   7   ,   35  ,   7   ,   19  ,   437 ,   361 ,   807 ,   277 ,   6335    ,0 };
            const std::uint32_t dim663JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   5   ,   5   ,   53  ,   121 ,   219 ,   447 ,   453 ,   1001    ,   339 ,   3959    ,0 };
            const std::uint32_t dim664JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   13  ,   27  ,   29  ,   107 ,   255 ,   385 ,   539 ,   1787    ,   3091    ,   6319    ,0 };
            const std::uint32_t dim665JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   5   ,   1   ,   57  ,   15  ,   93  ,   331 ,   155 ,   107 ,   3295    ,   7081    ,0 };
            const std::uint32_t dim666JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   15  ,   1   ,   35  ,   57  ,   249 ,   171 ,   309 ,   1413    ,   2677    ,   1593    ,0 };
            const std::uint32_t dim667JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   7   ,   27  ,   51  ,   107 ,   233 ,   163 ,   317 ,   1815    ,   2443    ,   3431    ,0 };
            const std::uint32_t dim668JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   5   ,   13  ,   31  ,   119 ,   25  ,   339 ,   671 ,   1143    ,   2317    ,   1963    ,0 };
            const std::uint32_t dim669JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   11  ,   15  ,   39  ,   15  ,   135 ,   183 ,   445 ,   1607    ,   2397    ,   7609    ,0 };
            const std::uint32_t dim670JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   7   ,   13  ,   61  ,   29  ,   5   ,   309 ,   1009    ,   1241    ,   3471    ,   4505    ,0 };
            const std::uint32_t dim671JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   9   ,   7   ,   39  ,   13  ,   67  ,   421 ,   169 ,   1751    ,   2939    ,   3315    ,0 };
            const std::uint32_t dim672JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   9   ,   5   ,   35  ,   91  ,   59  ,   195 ,   621 ,   449 ,   2245    ,   3379    ,0 };
            const std::uint32_t dim673JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   9   ,   27  ,   23  ,   87  ,   181 ,   171 ,   37  ,   1137    ,   597 ,   7443    ,0 };
            const std::uint32_t dim674JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   13  ,   15  ,   41  ,   109 ,   81  ,   149 ,   709 ,   1537    ,   2349    ,   3999    ,0 };
            const std::uint32_t dim675JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   3   ,   9   ,   27  ,   93  ,   211 ,   239 ,   391 ,   411 ,   1329    ,   4213    ,0 };
            const std::uint32_t dim676JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   15  ,   9   ,   33  ,   19  ,   105 ,   89  ,   181 ,   157 ,   461 ,   6505    ,0 };
            const std::uint32_t dim677JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   15  ,   15  ,   3   ,   113 ,   79  ,   49  ,   463 ,   299 ,   1621    ,   2719    ,0 };
            const std::uint32_t dim678JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   13  ,   23  ,   13  ,   57  ,   161 ,   347 ,   483 ,   1521    ,   3611    ,   4111    ,0 };
            const std::uint32_t dim679JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   13  ,   15  ,   21  ,   79  ,   145 ,   329 ,   649 ,   1809    ,   1925    ,   7157    ,0 };
            const std::uint32_t dim680JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   1   ,   29  ,   5   ,   35  ,   229 ,   375 ,   789 ,   481 ,   1863    ,   6467    ,0 };
            const std::uint32_t dim681JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   15  ,   1   ,   19  ,   39  ,   3   ,   327 ,   721 ,   1763    ,   963 ,   4397    ,0 };
            const std::uint32_t dim682JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   3   ,   3   ,   51  ,   97  ,   1   ,   109 ,   337 ,   535 ,   2795    ,   1155    ,0 };
            const std::uint32_t dim683JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   13  ,   5   ,   55  ,   91  ,   147 ,   395 ,   141 ,   947 ,   2647    ,   1193    ,0 };
            const std::uint32_t dim684JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   11  ,   31  ,   49  ,   71  ,   175 ,   231 ,   81  ,   155 ,   3257    ,   173 ,0 };
            const std::uint32_t dim685JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   13  ,   15  ,   27  ,   71  ,   43  ,   267 ,   611 ,   2041    ,   1127    ,   3905    ,0 };
            const std::uint32_t dim686JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   15  ,   3   ,   63  ,   25  ,   129 ,   409 ,   837 ,   1601    ,   2387    ,   5063    ,0 };
            const std::uint32_t dim687JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   7   ,   19  ,   63  ,   27  ,   141 ,   423 ,   751 ,   669 ,   1945    ,   3015    ,0 };
            const std::uint32_t dim688JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   11  ,   15  ,   59  ,   103 ,   123 ,   49  ,   71  ,   929 ,   3495    ,   3591    ,0 };
            const std::uint32_t dim689JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   5   ,   9   ,   17  ,   49  ,   3   ,   67  ,   63  ,   1645    ,   585 ,   83  ,0 };
            const std::uint32_t dim690JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   3   ,   25  ,   7   ,   103 ,   109 ,   241 ,   501 ,   2043    ,   139 ,   3865    ,0 };
            const std::uint32_t dim691JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   5   ,   19  ,   41  ,   35  ,   223 ,   351 ,   853 ,   961 ,   2963    ,   3315    ,0 };
            const std::uint32_t dim692JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   11  ,   9   ,   61  ,   103 ,   95  ,   393 ,   131 ,   611 ,   177 ,   635 ,0 };
            const std::uint32_t dim693JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   9   ,   15  ,   27  ,   107 ,   35  ,   211 ,   299 ,   923 ,   2629    ,   2585    ,0 };
            const std::uint32_t dim694JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   3   ,   9   ,   57  ,   89  ,   161 ,   323 ,   123 ,   1969    ,   3545    ,   5149    ,0 };
            const std::uint32_t dim695JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   9   ,   25  ,   15  ,   39  ,   7   ,   81  ,   503 ,   1549    ,   227 ,   7267    ,0 };
            const std::uint32_t dim696JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   1   ,   29  ,   41  ,   77  ,   131 ,   181 ,   555 ,   1165    ,   563 ,   5197    ,0 };
            const std::uint32_t dim697JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   11  ,   15  ,   11  ,   69  ,   183 ,   113 ,   651 ,   1265    ,   1741    ,   8025    ,0 };
            const std::uint32_t dim698JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   13  ,   15  ,   61  ,   113 ,   181 ,   305 ,   669 ,   1903    ,   575 ,   6561    ,0 };
            const std::uint32_t dim699JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   1   ,   27  ,   63  ,   103 ,   21  ,   387 ,   803 ,   1611    ,   1793    ,   1011    ,0 };
            const std::uint32_t dim700JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   9   ,   19  ,   41  ,   61  ,   153 ,   387 ,   509 ,   1771    ,   1715    ,   4643    ,0 };
            const std::uint32_t dim701JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   9   ,   9   ,   23  ,   99  ,   157 ,   185 ,   457 ,   1485    ,   3153    ,   6361    ,0 };
            const std::uint32_t dim702JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   9   ,   15  ,   3   ,   71  ,   95  ,   353 ,   549 ,   1269    ,   3451    ,   403 ,0 };
            const std::uint32_t dim703JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   5   ,   17  ,   45  ,   49  ,   249 ,   185 ,   367 ,   1499    ,   2921    ,   7485    ,0 };
            const std::uint32_t dim704JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   13  ,   1   ,   61  ,   57  ,   95  ,   213 ,   333 ,   603 ,   697 ,   6737    ,0 };
            const std::uint32_t dim705JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   7   ,   31  ,   37  ,   45  ,   71  ,   339 ,   629 ,   1181    ,   979 ,   1473    ,0 };
            const std::uint32_t dim706JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   5   ,   7   ,   5   ,   9   ,   139 ,   89  ,   683 ,   569 ,   1887    ,   2173    ,0 };
            const std::uint32_t dim707JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   11  ,   19  ,   7   ,   33  ,   65  ,   299 ,   791 ,   1281    ,   3793    ,   7019    ,0 };
            const std::uint32_t dim708JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   7   ,   5   ,   45  ,   11  ,   247 ,   335 ,   199 ,   17  ,   2829    ,   2811    ,0 };
            const std::uint32_t dim709JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   7   ,   9   ,   37  ,   17  ,   37  ,   385 ,   81  ,   1455    ,   1921    ,   6957    ,0 };
            const std::uint32_t dim710JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   1   ,   23  ,   53  ,   13  ,   7   ,   475 ,   167 ,   1573    ,   2235    ,   4097    ,0 };
            const std::uint32_t dim711JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   9   ,   23  ,   53  ,   107 ,   63  ,   457 ,   723 ,   53  ,   3025    ,   3153    ,0 };
            const std::uint32_t dim712JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   5   ,   21  ,   39  ,   1   ,   123 ,   293 ,   275 ,   1441    ,   2897    ,   4645    ,0 };
            const std::uint32_t dim713JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   7   ,   21  ,   5   ,   93  ,   63  ,   427 ,   47  ,   559 ,   2383    ,   4137    ,0 };
            const std::uint32_t dim714JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   1   ,   13  ,   39  ,   81  ,   63  ,   353 ,   937 ,   679 ,   79  ,   3319    ,0 };
            const std::uint32_t dim715JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   3   ,   19  ,   3   ,   57  ,   207 ,   115 ,   439 ,   835 ,   389 ,   4413    ,0 };
            const std::uint32_t dim716JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   7   ,   21  ,   57  ,   81  ,   137 ,   265 ,   845 ,   843 ,   3083    ,   4453    ,0 };
            const std::uint32_t dim717JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   13  ,   13  ,   29  ,   77  ,   181 ,   483 ,   871 ,   1739    ,   3859    ,   5005    ,0 };
            const std::uint32_t dim718JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   13  ,   9   ,   45  ,   73  ,   73  ,   427 ,   783 ,   617 ,   1771    ,   5953    ,0 };
            const std::uint32_t dim719JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   13  ,   31  ,   39  ,   83  ,   17  ,   275 ,   419 ,   1405    ,   3189    ,   7751    ,0 };
            const std::uint32_t dim720JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   13  ,   15  ,   17  ,   15  ,   67  ,   455 ,   477 ,   1911    ,   2225    ,   4095    ,0 };
            const std::uint32_t dim721JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   1   ,   5   ,   39  ,   73  ,   205 ,   331 ,   819 ,   1499    ,   1243    ,   7369    ,0 };
            const std::uint32_t dim722JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   1   ,   1   ,   49  ,   11  ,   167 ,   489 ,   169 ,   1683    ,   2999    ,   4371    ,0 };
            const std::uint32_t dim723JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   9   ,   13  ,   7   ,   29  ,   105 ,   155 ,   85  ,   1311    ,   617 ,   1793    ,0 };
            const std::uint32_t dim724JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   5   ,   13  ,   3   ,   71  ,   27  ,   83  ,   145 ,   89  ,   691 ,   1081    ,0 };
            const std::uint32_t dim725JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   1   ,   9   ,   43  ,   23  ,   63  ,   43  ,   263 ,   1849    ,   1963    ,   1043    ,0 };
            const std::uint32_t dim726JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   1   ,   25  ,   15  ,   17  ,   211 ,   453 ,   385 ,   349 ,   789 ,   787 ,0 };
            const std::uint32_t dim727JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   11  ,   1   ,   63  ,   83  ,   63  ,   317 ,   841 ,   1779    ,   669 ,   253 ,0 };
            const std::uint32_t dim728JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   5   ,   7   ,   49  ,   67  ,   69  ,   167 ,   29  ,   217 ,   1759    ,   6167    ,0 };
            const std::uint32_t dim729JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   1   ,   15  ,   63  ,   43  ,   3   ,   183 ,   577 ,   1301    ,   1479    ,   4189    ,0 };
            const std::uint32_t dim730JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   13  ,   29  ,   57  ,   103 ,   253 ,   45  ,   661 ,   1593    ,   1993    ,   523 ,0 };
            const std::uint32_t dim731JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   15  ,   25  ,   17  ,   11  ,   71  ,   213 ,   287 ,   627 ,   2699    ,   4909    ,0 };
            const std::uint32_t dim732JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   9   ,   11  ,   53  ,   117 ,   59  ,   225 ,   469 ,   109 ,   583 ,   4677    ,0 };
            const std::uint32_t dim733JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   15  ,   27  ,   41  ,   109 ,   37  ,   153 ,   885 ,   1339    ,   2783    ,   7833    ,0 };
            const std::uint32_t dim734JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   7   ,   5   ,   47  ,   5   ,   233 ,   507 ,   953 ,   1359    ,   2505    ,   6943    ,0 };
            const std::uint32_t dim735JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   5   ,   11  ,   21  ,   33  ,   207 ,   17  ,   621 ,   1943    ,   597 ,   3993    ,0 };
            const std::uint32_t dim736JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   3   ,   13  ,   55  ,   11  ,   247 ,   321 ,   533 ,   715 ,   2941    ,   6435    ,0 };
            const std::uint32_t dim737JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   15  ,   19  ,   3   ,   59  ,   1   ,   473 ,   17  ,   691 ,   747 ,   3917    ,0 };
            const std::uint32_t dim738JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   1   ,   25  ,   49  ,   11  ,   185 ,   185 ,   821 ,   1857    ,   3927    ,   2641    ,0 };
            const std::uint32_t dim739JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   11  ,   27  ,   31  ,   47  ,   33  ,   63  ,   935 ,   1709    ,   1495    ,   3869    ,0 };
            const std::uint32_t dim740JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   3   ,   23  ,   35  ,   73  ,   171 ,   207 ,   535 ,   751 ,   3693    ,   3015    ,0 };
            const std::uint32_t dim741JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   9   ,   11  ,   9   ,   101 ,   183 ,   83  ,   507 ,   15  ,   3993    ,   3631    ,0 };
            const std::uint32_t dim742JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   1   ,   5   ,   13  ,   41  ,   239 ,   355 ,   463 ,   997 ,   1163    ,   651 ,0 };
            const std::uint32_t dim743JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   11  ,   19  ,   25  ,   21  ,   233 ,   315 ,   1009    ,   1433    ,   2281    ,   4685    ,0 };
            const std::uint32_t dim744JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   5   ,   17  ,   11  ,   31  ,   47  ,   47  ,   873 ,   1957    ,   2307    ,   1757    ,0 };
            const std::uint32_t dim745JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   15  ,   1   ,   43  ,   93  ,   27  ,   315 ,   357 ,   787 ,   3843    ,   4615    ,0 };
            const std::uint32_t dim746JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   13  ,   13  ,   41  ,   67  ,   137 ,   241 ,   707 ,   1207    ,   1923    ,   2753    ,0 };
            const std::uint32_t dim747JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   3   ,   1   ,   15  ,   21  ,   175 ,   21  ,   917 ,   625 ,   543 ,   7235    ,0 };
            const std::uint32_t dim748JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   15  ,   3   ,   49  ,   97  ,   195 ,   443 ,   689 ,   1393    ,   2385    ,   4111    ,0 };
            const std::uint32_t dim749JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   3   ,   19  ,   53  ,   55  ,   243 ,   491 ,   213 ,   1371    ,   3867    ,   5323    ,0 };
            const std::uint32_t dim750JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   1   ,   9   ,   47  ,   7   ,   169 ,   151 ,   53  ,   1481    ,   3689    ,   2539    ,0 };
            const std::uint32_t dim751JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   9   ,   31  ,   7   ,   49  ,   27  ,   57  ,   769 ,   687 ,   1007    ,   3619    ,0 };
            const std::uint32_t dim752JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   9   ,   1   ,   49  ,   29  ,   153 ,   273 ,   965 ,   719 ,   4023    ,   1755    ,0 };
            const std::uint32_t dim753JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   1   ,   23  ,   29  ,   85  ,   179 ,   137 ,   237 ,   1639    ,   3759    ,   5533    ,0 };
            const std::uint32_t dim754JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   3   ,   7   ,   3   ,   1   ,   107 ,   259 ,   827 ,   799 ,   2677    ,   1677    ,0 };
            const std::uint32_t dim755JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   5   ,   9   ,   51  ,   89  ,   255 ,   97  ,   419 ,   703 ,   3903    ,   833 ,0 };
            const std::uint32_t dim756JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   3   ,   21  ,   27  ,   115 ,   75  ,   329 ,   747 ,   1949    ,   1309    ,   3611    ,0 };
            const std::uint32_t dim757JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   3   ,   13  ,   3   ,   21  ,   5   ,   337 ,   757 ,   1765    ,   667 ,   5607    ,0 };
            const std::uint32_t dim758JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   1   ,   19  ,   29  ,   113 ,   7   ,   51  ,   283 ,   1987    ,   3939    ,   583 ,0 };
            const std::uint32_t dim759JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   3   ,   23  ,   13  ,   9   ,   187 ,   251 ,   899 ,   85  ,   701 ,   2597    ,0 };
            const std::uint32_t dim760JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   7   ,   1   ,   15  ,   83  ,   183 ,   471 ,   533 ,   1119    ,   3157    ,   827 ,0 };
            const std::uint32_t dim761JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   11  ,   27  ,   49  ,   117 ,   57  ,   337 ,   603 ,   1247    ,   3957    ,   1739    ,0 };
            const std::uint32_t dim762JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   9   ,   29  ,   23  ,   123 ,   215 ,   479 ,   459 ,   361 ,   305 ,   237 ,0 };
            const std::uint32_t dim763JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   11  ,   1   ,   27  ,   103 ,   241 ,   493 ,   441 ,   1171    ,   3625    ,   3369    ,0 };
            const std::uint32_t dim764JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   9   ,   15  ,   59  ,   13  ,   225 ,   485 ,   493 ,   97  ,   2705    ,   7077    ,0 };
            const std::uint32_t dim765JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   1   ,   5   ,   27  ,   85  ,   135 ,   451 ,   745 ,   613 ,   1443    ,   6047    ,0 };
            const std::uint32_t dim766JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   7   ,   5   ,   41  ,   57  ,   167 ,   105 ,   721 ,   365 ,   833 ,   4485    ,0 };
            const std::uint32_t dim767JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   1   ,   19  ,   13  ,   119 ,   161 ,   475 ,   935 ,   1707    ,   2971    ,   6797    ,0 };
            const std::uint32_t dim768JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   15  ,   19  ,   59  ,   23  ,   29  ,   339 ,   671 ,   2027    ,   545 ,   6197    ,0 };
            const std::uint32_t dim769JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   3   ,   7   ,   41  ,   3   ,   169 ,   479 ,   567 ,   865 ,   2481    ,   3979    ,0 };
            const std::uint32_t dim770JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   13  ,   25  ,   23  ,   59  ,   175 ,   17  ,   291 ,   1283    ,   1405    ,   4939    ,0 };
            const std::uint32_t dim771JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   13  ,   13  ,   21  ,   127 ,   75  ,   275 ,   549 ,   971 ,   2019    ,   199 ,0 };
            const std::uint32_t dim772JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   3   ,   9   ,   61  ,   47  ,   23  ,   51  ,   589 ,   73  ,   265 ,   7315    ,0 };
            const std::uint32_t dim773JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   1   ,   3   ,   21  ,   15  ,   33  ,   443 ,   831 ,   375 ,   3045    ,   4215    ,0 };
            const std::uint32_t dim774JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   1   ,   27  ,   47  ,   123 ,   9   ,   131 ,   487 ,   393 ,   2959    ,   1509    ,0 };
            const std::uint32_t dim775JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   9   ,   15  ,   49  ,   61  ,   77  ,   65  ,   411 ,   293 ,   3827    ,   5723    ,0 };
            const std::uint32_t dim776JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   9   ,   17  ,   33  ,   97  ,   207 ,   227 ,   679 ,   1157    ,   1237    ,   2203    ,0 };
            const std::uint32_t dim777JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   1   ,   31  ,   31  ,   23  ,   59  ,   363 ,   225 ,   827 ,   2757    ,   1979    ,0 };
            const std::uint32_t dim778JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   11  ,   13  ,   31  ,   19  ,   27  ,   225 ,   901 ,   727 ,   2491    ,   3075    ,0 };
            const std::uint32_t dim779JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   9   ,   17  ,   9   ,   63  ,   117 ,   331 ,   887 ,   407 ,   111 ,   125 ,0 };
            const std::uint32_t dim780JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   13  ,   5   ,   25  ,   37  ,   61  ,   241 ,   15  ,   559 ,   1981    ,   3585    ,0 };
            const std::uint32_t dim781JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   9   ,   13  ,   57  ,   9   ,   189 ,   135 ,   485 ,   105 ,   327 ,   7233    ,0 };
            const std::uint32_t dim782JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   11  ,   11  ,   37  ,   13  ,   139 ,   93  ,   233 ,   1171    ,   165 ,   4151    ,0 };
            const std::uint32_t dim783JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   9   ,   7   ,   61  ,   81  ,   243 ,   111 ,   681 ,   859 ,   2163    ,   7019    ,0 };
            const std::uint32_t dim784JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   5   ,   31  ,   57  ,   85  ,   105 ,   323 ,   729 ,   131 ,   2055    ,   1893    ,0 };
            const std::uint32_t dim785JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   15  ,   17  ,   55  ,   35  ,   211 ,   341 ,   281 ,   613 ,   697 ,   6479    ,0 };
            const std::uint32_t dim786JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   1   ,   9   ,   35  ,   107 ,   47  ,   243 ,   917 ,   683 ,   1333    ,   7797    ,0 };
            const std::uint32_t dim787JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   7   ,   31  ,   15  ,   9   ,   11  ,   109 ,   509 ,   973 ,   3817    ,   2877    ,0 };
            const std::uint32_t dim788JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   15  ,   31  ,   21  ,   43  ,   79  ,   367 ,   201 ,   549 ,   1335    ,   7231    ,0 };
            const std::uint32_t dim789JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   5   ,   23  ,   21  ,   63  ,   207 ,   333 ,   395 ,   925 ,   705 ,   8143    ,0 };
            const std::uint32_t dim790JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   5   ,   13  ,   23  ,   93  ,   123 ,   317 ,   511 ,   867 ,   1791    ,   5621    ,0 };
            const std::uint32_t dim791JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   3   ,   1   ,   1   ,   61  ,   133 ,   23  ,   885 ,   1281    ,   3115    ,   2717    ,0 };
            const std::uint32_t dim792JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   13  ,   5   ,   3   ,   59  ,   59  ,   453 ,   787 ,   1933    ,   2813    ,   6405    ,0 };
            const std::uint32_t dim793JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   9   ,   7   ,   39  ,   85  ,   65  ,   33  ,   85  ,   1597    ,   17  ,   3779    ,0 };
            const std::uint32_t dim794JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   1   ,   3   ,   33  ,   85  ,   129 ,   249 ,   845 ,   1481    ,   3249    ,   7207    ,0 };
            const std::uint32_t dim795JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   3   ,   9   ,   5   ,   51  ,   79  ,   241 ,   173 ,   567 ,   3047    ,   6779    ,0 };
            const std::uint32_t dim796JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   1   ,   1   ,   49  ,   29  ,   243 ,   95  ,   609 ,   1887    ,   407 ,   7875    ,0 };
            const std::uint32_t dim797JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   15  ,   29  ,   55  ,   69  ,   171 ,   337 ,   701 ,   1255    ,   1889    ,   3365    ,0 };
            const std::uint32_t dim798JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   5   ,   11  ,   27  ,   3   ,   167 ,   325 ,   397 ,   545 ,   2097    ,   1323    ,0 };
            const std::uint32_t dim799JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   11  ,   7   ,   3   ,   17  ,   47  ,   227 ,   573 ,   713 ,   975 ,   5991    ,0 };
            const std::uint32_t dim800JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   15  ,   7   ,   55  ,   71  ,   41  ,   195 ,   227 ,   821 ,   3209    ,   1363    ,0 };
            const std::uint32_t dim801JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   9   ,   7   ,   49  ,   105 ,   5   ,   441 ,   629 ,   201 ,   2951    ,   5757    ,0 };
            const std::uint32_t dim802JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   7   ,   13  ,   5   ,   5   ,   31  ,   355 ,   107 ,   1937    ,   3553    ,   697 ,0 };
            const std::uint32_t dim803JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   7   ,   23  ,   59  ,   109 ,   185 ,   289 ,   257 ,   1055    ,   3221    ,   6445    ,0 };
            const std::uint32_t dim804JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   7   ,   3   ,   27  ,   61  ,   85  ,   383 ,   93  ,   639 ,   1113    ,   1511    ,0 };
            const std::uint32_t dim805JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   7   ,   17  ,   29  ,   31  ,   255 ,   57  ,   557 ,   721 ,   4015    ,   7587    ,0 };
            const std::uint32_t dim806JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   9   ,   23  ,   15  ,   89  ,   85  ,   201 ,   177 ,   571 ,   2691    ,   4521    ,0 };
            const std::uint32_t dim807JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   9   ,   9   ,   25  ,   91  ,   75  ,   405 ,   13  ,   587 ,   2299    ,   7879    ,0 };
            const std::uint32_t dim808JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   15  ,   3   ,   59  ,   109 ,   175 ,   411 ,   309 ,   787 ,   2979    ,   5385    ,0 };
            const std::uint32_t dim809JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   1   ,   9   ,   21  ,   109 ,   109 ,   179 ,   955 ,   423 ,   3637    ,   3283    ,0 };
            const std::uint32_t dim810JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   1   ,   7   ,   51  ,   31  ,   83  ,   273 ,   545 ,   1063    ,   1463    ,   1857    ,0 };
            const std::uint32_t dim811JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   9   ,   1   ,   51  ,   49  ,   241 ,   365 ,   423 ,   1299    ,   3533    ,   1771    ,0 };
            const std::uint32_t dim812JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   15  ,   25  ,   21  ,   95  ,   221 ,   65  ,   335 ,   697 ,   759 ,   4331    ,0 };
            const std::uint32_t dim813JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   11  ,   15  ,   53  ,   17  ,   7   ,   461 ,   543 ,   233 ,   3993    ,   725 ,0 };
            const std::uint32_t dim814JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   1   ,   13  ,   3   ,   53  ,   213 ,   5   ,   709 ,   883 ,   3261    ,   855 ,0 };
            const std::uint32_t dim815JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   13  ,   1   ,   33  ,   61  ,   255 ,   385 ,   793 ,   525 ,   929 ,   4263    ,0 };
            const std::uint32_t dim816JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   11  ,   1   ,   33  ,   97  ,   235 ,   427 ,   1021    ,   1683    ,   2821    ,   1347    ,0 };
            const std::uint32_t dim817JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   9   ,   15  ,   7   ,   39  ,   163 ,   13  ,   535 ,   1259    ,   653 ,   7359    ,0 };
            const std::uint32_t dim818JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   15  ,   31  ,   27  ,   19  ,   255 ,   341 ,   509 ,   1775    ,   1493    ,   6977    ,0 };
            const std::uint32_t dim819JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   15  ,   3   ,   23  ,   53  ,   221 ,   271 ,   729 ,   1013    ,   101 ,   2837    ,0 };
            const std::uint32_t dim820JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   3   ,   19  ,   63  ,   83  ,   149 ,   385 ,   813 ,   1783    ,   4021    ,   3645    ,0 };
            const std::uint32_t dim821JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   7   ,   11  ,   57  ,   121 ,   97  ,   479 ,   33  ,   579 ,   1009    ,   1821    ,0 };
            const std::uint32_t dim822JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   15  ,   5   ,   25  ,   69  ,   159 ,   441 ,   661 ,   151 ,   103 ,   2659    ,0 };
            const std::uint32_t dim823JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   7   ,   11  ,   7   ,   15  ,   159 ,   19  ,   457 ,   1873    ,   3017    ,   3927    ,0 };
            const std::uint32_t dim824JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   11  ,   9   ,   43  ,   73  ,   187 ,   107 ,   603 ,   387 ,   3713    ,   853 ,0 };
            const std::uint32_t dim825JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   15  ,   29  ,   55  ,   87  ,   247 ,   283 ,   11  ,   927 ,   3313    ,   5147    ,0 };
            const std::uint32_t dim826JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   5   ,   27  ,   25  ,   1   ,   123 ,   19  ,   237 ,   1171    ,   1731    ,   7079    ,0 };
            const std::uint32_t dim827JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   7   ,   29  ,   43  ,   15  ,   91  ,   61  ,   329 ,   1343    ,   1349    ,   471 ,0 };
            const std::uint32_t dim828JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   11  ,   11  ,   7   ,   25  ,   143 ,   277 ,   791 ,   775 ,   3711    ,   7115    ,0 };
            const std::uint32_t dim829JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   5   ,   29  ,   27  ,   53  ,   241 ,   399 ,   165 ,   1347    ,   1661    ,   4495    ,0 };
            const std::uint32_t dim830JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   3   ,   21  ,   7   ,   73  ,   61  ,   155 ,   635 ,   1095    ,   3295    ,   7109    ,0 };
            const std::uint32_t dim831JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   11  ,   5   ,   39  ,   11  ,   167 ,   317 ,   317 ,   161 ,   2141    ,   1327    ,0 };
            const std::uint32_t dim832JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   7   ,   23  ,   45  ,   59  ,   13  ,   107 ,   47  ,   2001    ,   1491    ,   4463    ,0 };
            const std::uint32_t dim833JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   15  ,   27  ,   63  ,   41  ,   143 ,   503 ,   711 ,   277 ,   2523    ,   6331    ,0 };
            const std::uint32_t dim834JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   15  ,   13  ,   49  ,   121 ,   107 ,   145 ,   769 ,   699 ,   3793    ,   2333    ,0 };
            const std::uint32_t dim835JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   11  ,   17  ,   7   ,   57  ,   139 ,   17  ,   433 ,   1053    ,   1279    ,   833 ,0 };
            const std::uint32_t dim836JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   3   ,   21  ,   19  ,   61  ,   229 ,   271 ,   831 ,   495 ,   1663    ,   2109    ,0 };
            const std::uint32_t dim837JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   11  ,   17  ,   27  ,   23  ,   153 ,   151 ,   309 ,   1935    ,   3993    ,   4149    ,0 };
            const std::uint32_t dim838JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   1   ,   11  ,   29  ,   33  ,   77  ,   357 ,   543 ,   217 ,   893 ,   2989    ,0 };
            const std::uint32_t dim839JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   13  ,   21  ,   25  ,   121 ,   211 ,   491 ,   983 ,   1395    ,   2879    ,   1173    ,0 };
            const std::uint32_t dim840JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   11  ,   31  ,   61  ,   45  ,   125 ,   21  ,   175 ,   1869    ,   403 ,   579 ,0 };
            const std::uint32_t dim841JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   11  ,   27  ,   5   ,   47  ,   211 ,   149 ,   753 ,   301 ,   933 ,   3339    ,0 };
            const std::uint32_t dim842JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   15  ,   7   ,   57  ,   105 ,   243 ,   27  ,   629 ,   337 ,   1917    ,   2653    ,0 };
            const std::uint32_t dim843JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   1   ,   27  ,   27  ,   45  ,   39  ,   249 ,   167 ,   2031    ,   3427    ,   6051    ,0 };
            const std::uint32_t dim844JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   5   ,   9   ,   13  ,   55  ,   167 ,   473 ,   371 ,   677 ,   2171    ,   1859    ,0 };
            const std::uint32_t dim845JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   13  ,   21  ,   49  ,   25  ,   193 ,   507 ,   531 ,   1639    ,   3181    ,   2763    ,0 };
            const std::uint32_t dim846JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   11  ,   15  ,   3   ,   115 ,   163 ,   63  ,   383 ,   835 ,   2507    ,   5525    ,0 };
            const std::uint32_t dim847JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   1   ,   1   ,   63  ,   59  ,   75  ,   293 ,   609 ,   59  ,   1729    ,   4909    ,0 };
            const std::uint32_t dim848JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   15  ,   11  ,   57  ,   59  ,   109 ,   465 ,   285 ,   1973    ,   505 ,   4447    ,0 };
            const std::uint32_t dim849JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   13  ,   11  ,   63  ,   87  ,   149 ,   185 ,   493 ,   831 ,   2927    ,   11  ,0 };
            const std::uint32_t dim850JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   3   ,   3   ,   19  ,   111 ,   199 ,   371 ,   411 ,   659 ,   1191    ,   6279    ,0 };
            const std::uint32_t dim851JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   9   ,   21  ,   57  ,   73  ,   189 ,   307 ,   515 ,   1797    ,   2073    ,   1085    ,0 };
            const std::uint32_t dim852JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   9   ,   23  ,   21  ,   21  ,   23  ,   487 ,   715 ,   449 ,   2157    ,   5063    ,0 };
            const std::uint32_t dim853JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   11  ,   27  ,   27  ,   121 ,   61  ,   281 ,   805 ,   55  ,   2111    ,   2193    ,0 };
            const std::uint32_t dim854JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   3   ,   5   ,   45  ,   23  ,   71  ,   369 ,   875 ,   1185    ,   1611    ,   2009    ,0 };
            const std::uint32_t dim855JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   15  ,   17  ,   59  ,   17  ,   99  ,   403 ,   103 ,   847 ,   849 ,   569 ,0 };
            const std::uint32_t dim856JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   7   ,   7   ,   13  ,   47  ,   125 ,   35  ,   615 ,   281 ,   1443    ,   1199    ,0 };
            const std::uint32_t dim857JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   15  ,   13  ,   63  ,   73  ,   191 ,   137 ,   257 ,   1609    ,   409 ,   5135    ,0 };
            const std::uint32_t dim858JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   11  ,   13  ,   57  ,   63  ,   189 ,   367 ,   7   ,   1261    ,   211 ,   2223    ,0 };
            const std::uint32_t dim859JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   3   ,   31  ,   21  ,   117 ,   135 ,   231 ,   981 ,   857 ,   3737    ,   1631    ,0 };
            const std::uint32_t dim860JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   5   ,   11  ,   13  ,   55  ,   193 ,   99  ,   969 ,   1093    ,   1575    ,   2367    ,0 };
            const std::uint32_t dim861JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   9   ,   9   ,   45  ,   81  ,   139 ,   479 ,   561 ,   1983    ,   3117    ,   2539    ,0 };
            const std::uint32_t dim862JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   11  ,   19  ,   37  ,   107 ,   125 ,   415 ,   653 ,   517 ,   2191    ,   415 ,0 };
            const std::uint32_t dim863JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   9   ,   13  ,   41  ,   59  ,   193 ,   205 ,   485 ,   1439    ,   1333    ,   2519    ,0 };
            const std::uint32_t dim864JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   13  ,   9   ,   41  ,   95  ,   141 ,   21  ,   953 ,   1453    ,   3585    ,   2521    ,0 };
            const std::uint32_t dim865JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   11  ,   25  ,   21  ,   43  ,   221 ,   201 ,   761 ,   1457    ,   1597    ,   2147    ,0 };
            const std::uint32_t dim866JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   9   ,   27  ,   63  ,   35  ,   229 ,   147 ,   293 ,   699 ,   673 ,   4779    ,0 };
            const std::uint32_t dim867JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   13  ,   15  ,   57  ,   57  ,   197 ,   23  ,   925 ,   1433    ,   681 ,   1721    ,0 };
            const std::uint32_t dim868JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   11  ,   17  ,   25  ,   127 ,   195 ,   487 ,   679 ,   1529    ,   453 ,   3955    ,0 };
            const std::uint32_t dim869JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   1   ,   29  ,   17  ,   49  ,   13  ,   299 ,   305 ,   11  ,   3913    ,   1633    ,0 };
            const std::uint32_t dim870JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   3   ,   15  ,   15  ,   79  ,   233 ,   183 ,   515 ,   773 ,   1761    ,   5439    ,0 };
            const std::uint32_t dim871JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   7   ,   23  ,   43  ,   3   ,   59  ,   37  ,   985 ,   1957    ,   2373    ,   7823    ,0 };
            const std::uint32_t dim872JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   5   ,   21  ,   59  ,   47  ,   205 ,   69  ,   435 ,   1567    ,   2661    ,   3589    ,0 };
            const std::uint32_t dim873JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   1   ,   7   ,   29  ,   15  ,   61  ,   197 ,   339 ,   1955    ,   2815    ,   4343    ,0 };
            const std::uint32_t dim874JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   5   ,   13  ,   33  ,   109 ,   33  ,   475 ,   219 ,   1707    ,   3747    ,   7359    ,0 };
            const std::uint32_t dim875JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   3   ,   21  ,   15  ,   53  ,   29  ,   493 ,   729 ,   1847    ,   1387    ,   1221    ,0 };
            const std::uint32_t dim876JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   11  ,   19  ,   27  ,   107 ,   29  ,   217 ,   19  ,   337 ,   2621    ,   1199    ,0 };
            const std::uint32_t dim877JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   11  ,   11  ,   39  ,   111 ,   195 ,   373 ,   239 ,   355 ,   359 ,   1187    ,0 };
            const std::uint32_t dim878JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   15  ,   29  ,   63  ,   13  ,   235 ,   413 ,   67  ,   1437    ,   3227    ,   5067    ,0 };
            const std::uint32_t dim879JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   3   ,   29  ,   35  ,   11  ,   189 ,   15  ,   181 ,   1807    ,   1711    ,   3317    ,0 };
            const std::uint32_t dim880JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   5   ,   25  ,   21  ,   93  ,   101 ,   65  ,   495 ,   375 ,   2873    ,   5253    ,0 };
            const std::uint32_t dim881JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   3   ,   19  ,   47  ,   13  ,   229 ,   3   ,   377 ,   1769    ,   673 ,   5713    ,0 };
            const std::uint32_t dim882JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   15  ,   11  ,   19  ,   25  ,   249 ,   95  ,   777 ,   1763    ,   2607    ,   6439    ,0 };
            const std::uint32_t dim883JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   1   ,   31  ,   47  ,   101 ,   155 ,   139 ,   201 ,   1687    ,   1503    ,   4783    ,0 };
            const std::uint32_t dim884JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   13  ,   27  ,   11  ,   53  ,   199 ,   305 ,   481 ,   1071    ,   143 ,   3667    ,0 };
            const std::uint32_t dim885JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   11  ,   15  ,   29  ,   95  ,   201 ,   271 ,   607 ,   511 ,   4029    ,   4269    ,0 };
            const std::uint32_t dim886JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   3   ,   29  ,   13  ,   99  ,   161 ,   55  ,   997 ,   1123    ,   3107    ,   4255    ,0 };
            const std::uint32_t dim887JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   11  ,   13  ,   5   ,   121 ,   253 ,   315 ,   465 ,   851 ,   3147    ,   5415    ,0 };
            const std::uint32_t dim888JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   13  ,   29  ,   15  ,   39  ,   7   ,   439 ,   787 ,   895 ,   1859    ,   5139    ,0 };
            const std::uint32_t dim889JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   9   ,   29  ,   37  ,   61  ,   61  ,   321 ,   307 ,   1741    ,   3143    ,   1977    ,0 };
            const std::uint32_t dim890JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   5   ,   19  ,   5   ,   105 ,   89  ,   189 ,   723 ,   407 ,   2557    ,   3817    ,0 };
            const std::uint32_t dim891JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   7   ,   15  ,   9   ,   93  ,   15  ,   461 ,   337 ,   1157    ,   531 ,   797 ,0 };
            const std::uint32_t dim892JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   1   ,   15  ,   33  ,   49  ,   87  ,   185 ,   581 ,   1449    ,   735 ,   4891    ,0 };
            const std::uint32_t dim893JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   7   ,   31  ,   49  ,   125 ,   99  ,   237 ,   655 ,   825 ,   2769    ,   4589    ,0 };
            const std::uint32_t dim894JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   15  ,   1   ,   51  ,   97  ,   205 ,   15  ,   47  ,   1453    ,   3399    ,   5539    ,0 };
            const std::uint32_t dim895JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   13  ,   29  ,   43  ,   105 ,   39  ,   329 ,   719 ,   563 ,   3817    ,   2901    ,0 };
            const std::uint32_t dim896JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   5   ,   25  ,   19  ,   7   ,   209 ,   89  ,   455 ,   2019    ,   1481    ,   7409    ,0 };
            const std::uint32_t dim897JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   1   ,   25  ,   47  ,   53  ,   115 ,   263 ,   547 ,   565 ,   3495    ,   3759    ,0 };
            const std::uint32_t dim898JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   15  ,   25  ,   47  ,   121 ,   193 ,   99  ,   45  ,   1251    ,   1221    ,   6425    ,0 };
            const std::uint32_t dim899JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   9   ,   3   ,   47  ,   91  ,   231 ,   189 ,   39  ,   1811    ,   3215    ,   6593    ,0 };
            const std::uint32_t dim900JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   5   ,   3   ,   57  ,   67  ,   63  ,   23  ,   627 ,   2045    ,   2377    ,   3805    ,0 };
            const std::uint32_t dim901JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   13  ,   7   ,   47  ,   29  ,   99  ,   481 ,   923 ,   119 ,   1911    ,   5187    ,0 };
            const std::uint32_t dim902JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   7   ,   1   ,   57  ,   7   ,   197 ,   451 ,   531 ,   29  ,   1851    ,   7069    ,0 };
            const std::uint32_t dim903JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   5   ,   31  ,   43  ,   3   ,   207 ,   67  ,   279 ,   37  ,   2381    ,   5997    ,0 };
            const std::uint32_t dim904JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   7   ,   23  ,   57  ,   91  ,   109 ,   165 ,   549 ,   837 ,   3135    ,   2251    ,0 };
            const std::uint32_t dim905JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   1   ,   3   ,   41  ,   67  ,   127 ,   273 ,   385 ,   995 ,   3263    ,   5211    ,0 };
            const std::uint32_t dim906JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   9   ,   21  ,   9   ,   101 ,   105 ,   43  ,   291 ,   1909    ,   1641    ,   7965    ,0 };
            const std::uint32_t dim907JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   11  ,   19  ,   21  ,   117 ,   141 ,   197 ,   83  ,   203 ,   393 ,   7995    ,0 };
            const std::uint32_t dim908JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   13  ,   11  ,   33  ,   21  ,   207 ,   421 ,   91  ,   1233    ,   1239    ,   5683    ,0 };
            const std::uint32_t dim909JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   15  ,   5   ,   1   ,   127 ,   119 ,   349 ,   953 ,   1297    ,   1805    ,   2385    ,0 };
            const std::uint32_t dim910JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   1   ,   19  ,   17  ,   17  ,   37  ,   217 ,   857 ,   859 ,   53  ,   2091    ,0 };
            const std::uint32_t dim911JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   15  ,   27  ,   37  ,   69  ,   121 ,   101 ,   1011    ,   1859    ,   3297    ,   5755    ,0 };
            const std::uint32_t dim912JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   13  ,   21  ,   13  ,   107 ,   105 ,   17  ,   743 ,   1849    ,   3169    ,   5901    ,0 };
            const std::uint32_t dim913JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   13  ,   31  ,   37  ,   125 ,   83  ,   127 ,   687 ,   1593    ,   1257    ,   4729    ,0 };
            const std::uint32_t dim914JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   3   ,   23  ,   21  ,   51  ,   157 ,   469 ,   349 ,   213 ,   1303    ,   123 ,0 };
            const std::uint32_t dim915JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   15  ,   17  ,   23  ,   45  ,   157 ,   313 ,   241 ,   361 ,   3967    ,   3635    ,0 };
            const std::uint32_t dim916JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   7   ,   25  ,   41  ,   65  ,   25  ,   97  ,   787 ,   951 ,   2471    ,   4621    ,0 };
            const std::uint32_t dim917JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   3   ,   31  ,   29  ,   75  ,   173 ,   55  ,   613 ,   283 ,   195 ,   5009    ,0 };
            const std::uint32_t dim918JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   3   ,   9   ,   47  ,   115 ,   149 ,   501 ,   199 ,   1957    ,   785 ,   3391    ,0 };
            const std::uint32_t dim919JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   11  ,   31  ,   57  ,   71  ,   191 ,   333 ,   157 ,   809 ,   3039    ,   7471    ,0 };
            const std::uint32_t dim920JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   9   ,   19  ,   17  ,   103 ,   243 ,   411 ,   449 ,   1495    ,   3843    ,   5361    ,0 };
            const std::uint32_t dim921JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   1   ,   11  ,   13  ,   99  ,   229 ,   365 ,   909 ,   87  ,   3669    ,   6609    ,0 };
            const std::uint32_t dim922JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   15  ,   7   ,   61  ,   95  ,   95  ,   147 ,   959 ,   971 ,   649 ,   5047    ,0 };
            const std::uint32_t dim923JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   15  ,   15  ,   37  ,   113 ,   29  ,   373 ,   379 ,   151 ,   2741    ,   1259    ,0 };
            const std::uint32_t dim924JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   7   ,   1   ,   7   ,   91  ,   61  ,   213 ,   131 ,   1607    ,   3957    ,   4197    ,0 };
            const std::uint32_t dim925JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   15  ,   11  ,   41  ,   79  ,   25  ,   267 ,   511 ,   111 ,   1779    ,   351 ,0 };
            const std::uint32_t dim926JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   5   ,   17  ,   9   ,   29  ,   117 ,   207 ,   655 ,   221 ,   3567    ,   6069    ,0 };
            const std::uint32_t dim927JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   13  ,   31  ,   47  ,   3   ,   51  ,   451 ,   675 ,   91  ,   1529    ,   5729    ,0 };
            const std::uint32_t dim928JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   15  ,   27  ,   37  ,   27  ,   189 ,   183 ,   619 ,   509 ,   2421    ,   5903    ,0 };
            const std::uint32_t dim929JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   7   ,   1   ,   31  ,   79  ,   233 ,   41  ,   949 ,   1313    ,   3807    ,   171 ,0 };
            const std::uint32_t dim930JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   5   ,   31  ,   39  ,   29  ,   43  ,   309 ,   11  ,   1041    ,   1893    ,   4443    ,0 };
            const std::uint32_t dim931JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   11  ,   13  ,   51  ,   5   ,   199 ,   51  ,   563 ,   819 ,   3467    ,   7003    ,0 };
            const std::uint32_t dim932JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   15  ,   19  ,   27  ,   1   ,   3   ,   393 ,   901 ,   1603    ,   1949    ,   7119    ,0 };
            const std::uint32_t dim933JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   3   ,   13  ,   39  ,   35  ,   53  ,   437 ,   263 ,   783 ,   1669    ,   7271    ,0 };
            const std::uint32_t dim934JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   11  ,   23  ,   11  ,   17  ,   187 ,   303 ,   833 ,   805 ,   3395    ,   181 ,0 };
            const std::uint32_t dim935JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   9   ,   15  ,   23  ,   113 ,   37  ,   131 ,   89  ,   923 ,   2265    ,   1621    ,0 };
            const std::uint32_t dim936JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   5   ,   3   ,   35  ,   53  ,   139 ,   21  ,   547 ,   1765    ,   3993    ,   2617    ,0 };
            const std::uint32_t dim937JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   1   ,   3   ,   35  ,   17  ,   185 ,   291 ,   973 ,   1267    ,   301 ,   7443    ,0 };
            const std::uint32_t dim938JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   1   ,   5   ,   45  ,   107 ,   209 ,   345 ,   821 ,   173 ,   1777    ,   4215    ,0 };
            const std::uint32_t dim939JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   3   ,   13  ,   11  ,   17  ,   5   ,   445 ,   411 ,   825 ,   3031    ,   4295    ,0 };
            const std::uint32_t dim940JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   1   ,   15  ,   45  ,   57  ,   243 ,   263 ,   167 ,   1889    ,   2901    ,   2315    ,0 };
            const std::uint32_t dim941JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   13  ,   27  ,   37  ,   27  ,   39  ,   89  ,   571 ,   775 ,   269 ,   2633    ,0 };
            const std::uint32_t dim942JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   15  ,   5   ,   41  ,   59  ,   89  ,   475 ,   745 ,   431 ,   489 ,   2121    ,0 };
            const std::uint32_t dim943JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   11  ,   3   ,   53  ,   65  ,   107 ,   475 ,   529 ,   169 ,   2555    ,   5189    ,0 };
            const std::uint32_t dim944JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   7   ,   27  ,   7   ,   55  ,   11  ,   493 ,   687 ,   365 ,   3105    ,   8067    ,0 };
            const std::uint32_t dim945JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   7   ,   13  ,   7   ,   101 ,   139 ,   387 ,   289 ,   1157    ,   785 ,   1457    ,0 };
            const std::uint32_t dim946JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   7   ,   1   ,   23  ,   81  ,   147 ,   509 ,   241 ,   1507    ,   3947    ,   795 ,0 };
            const std::uint32_t dim947JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   3   ,   3   ,   3   ,   39  ,   205 ,   67  ,   409 ,   1463    ,   2503    ,   7003    ,0 };
            const std::uint32_t dim948JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   7   ,   13  ,   3   ,   49  ,   157 ,   271 ,   813 ,   1793    ,   2059    ,   7233    ,0 };
            const std::uint32_t dim949JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   11  ,   17  ,   7   ,   35  ,   251 ,   91  ,   725 ,   157 ,   2503    ,   7007    ,0 };
            const std::uint32_t dim950JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   7   ,   31  ,   59  ,   115 ,   1   ,   421 ,   181 ,   809 ,   1739    ,   5641    ,0 };
            const std::uint32_t dim951JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   1   ,   3   ,   53  ,   29  ,   37  ,   181 ,   187 ,   11  ,   1829    ,   5031    ,0 };
            const std::uint32_t dim952JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   3   ,   5   ,   49  ,   11  ,   69  ,   109 ,   11  ,   1825    ,   2119    ,   4697    ,0 };
            const std::uint32_t dim953JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   7   ,   7   ,   31  ,   115 ,   197 ,   39  ,   177 ,   1263    ,   1173    ,   3845    ,0 };
            const std::uint32_t dim954JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   1   ,   15  ,   61  ,   49  ,   3   ,   141 ,   599 ,   809 ,   2827    ,   6349    ,0 };
            const std::uint32_t dim955JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   9   ,   23  ,   29  ,   121 ,   175 ,   507 ,   273 ,   1945    ,   2991    ,   885 ,0 };
            const std::uint32_t dim956JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   1   ,   3   ,   55  ,   125 ,   37  ,   57  ,   901 ,   85  ,   3319    ,   3477    ,0 };
            const std::uint32_t dim957JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   15  ,   3   ,   27  ,   69  ,   143 ,   431 ,   47  ,   603 ,   1321    ,   5053    ,0 };
            const std::uint32_t dim958JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   3   ,   3   ,   37  ,   65  ,   163 ,   391 ,   509 ,   87  ,   747 ,   4301    ,0 };
            const std::uint32_t dim959JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   9   ,   5   ,   53  ,   75  ,   179 ,   389 ,   97  ,   373 ,   963 ,   3647    ,0 };
            const std::uint32_t dim960JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   5   ,   13  ,   21  ,   49  ,   211 ,   5   ,   469 ,   1807    ,   891 ,   1543    ,0 };
            const std::uint32_t dim961JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   9   ,   13  ,   29  ,   39  ,   55  ,   39  ,   667 ,   1967    ,   1887    ,   2619    ,0 };
            const std::uint32_t dim962JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   9   ,   25  ,   47  ,   1   ,   221 ,   421 ,   175 ,   461 ,   1931    ,   3525    ,0 };
            const std::uint32_t dim963JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   9   ,   11  ,   35  ,   23  ,   121 ,   493 ,   675 ,   857 ,   2989    ,   4863    ,0 };
            const std::uint32_t dim964JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   9   ,   5   ,   39  ,   121 ,   9   ,   249 ,   507 ,   1637    ,   2991    ,   4545    ,0 };
            const std::uint32_t dim965JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   9   ,   5   ,   9   ,   27  ,   135 ,   299 ,   713 ,   1385    ,   729 ,   29  ,0 };
            const std::uint32_t dim966JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   11  ,   3   ,   3   ,   67  ,   17  ,   163 ,   535 ,   1731    ,   1401    ,   4495    ,0 };
            const std::uint32_t dim967JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   5   ,   31  ,   29  ,   81  ,   251 ,   471 ,   461 ,   1151    ,   1037    ,   4069    ,0 };
            const std::uint32_t dim968JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   5   ,   11  ,   29  ,   13  ,   157 ,   329 ,   237 ,   691 ,   1895    ,   653 ,0 };
            const std::uint32_t dim969JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   13  ,   23  ,   23  ,   57  ,   149 ,   111 ,   607 ,   1835    ,   3129    ,   1827    ,0 };
            const std::uint32_t dim970JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   5   ,   11  ,   11  ,   95  ,   143 ,   495 ,   805 ,   1163    ,   1853    ,   1017    ,0 };
            const std::uint32_t dim971JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   9   ,   15  ,   19  ,   89  ,   143 ,   305 ,   121 ,   1217    ,   807 ,   5003    ,0 };
            const std::uint32_t dim972JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   13  ,   27  ,   39  ,   117 ,   65  ,   473 ,   191 ,   1863    ,   3533    ,   243 ,0 };
            const std::uint32_t dim973JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   9   ,   31  ,   5   ,   91  ,   245 ,   175 ,   635 ,   257 ,   1197    ,   5965    ,0 };
            const std::uint32_t dim974JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   1   ,   9   ,   13  ,   37  ,   19  ,   177 ,   949 ,   49  ,   3855    ,   5105    ,0 };
            const std::uint32_t dim975JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   3   ,   1   ,   41  ,   33  ,   65  ,   295 ,   917 ,   503 ,   2665    ,   1485    ,0 };
            const std::uint32_t dim976JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   5   ,   3   ,   25  ,   11  ,   9   ,   439 ,   293 ,   1919    ,   693 ,   5797    ,0 };
            const std::uint32_t dim977JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   15  ,   17  ,   51  ,   7   ,   17  ,   153 ,   105 ,   807 ,   1029    ,   4649    ,0 };
            const std::uint32_t dim978JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   11  ,   27  ,   25  ,   37  ,   49  ,   481 ,   599 ,   655 ,   1497    ,   6455    ,0 };
            const std::uint32_t dim979JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   5   ,   25  ,   23  ,   127 ,   203 ,   381 ,   61  ,   1651    ,   3535    ,   6345    ,0 };
            const std::uint32_t dim980JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   5   ,   27  ,   13  ,   93  ,   151 ,   421 ,   713 ,   305 ,   3541    ,   6741    ,0 };
            const std::uint32_t dim981JoeKuoD7Init[]    =   {   1   ,   1   ,   5   ,   5   ,   3   ,   1   ,   93  ,   55  ,   65  ,   437 ,   1283    ,   55  ,   861 ,0 };
            const std::uint32_t dim982JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   9   ,   27  ,   59  ,   15  ,   195 ,   303 ,   705 ,   143 ,   1423    ,   6793    ,0 };
            const std::uint32_t dim983JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   13  ,   3   ,   21  ,   81  ,   89  ,   325 ,   103 ,   573 ,   1891    ,   3023    ,0 };
            const std::uint32_t dim984JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   7   ,   15  ,   47  ,   23  ,   139 ,   437 ,   701 ,   1453    ,   1419    ,   1487    ,0 };
            const std::uint32_t dim985JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   1   ,   13  ,   35  ,   49  ,   127 ,   335 ,   185 ,   393 ,   2239    ,   2039    ,0 };
            const std::uint32_t dim986JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   5   ,   29  ,   3   ,   83  ,   179 ,   487 ,   381 ,   1477    ,   1849    ,   7593    ,0 };
            const std::uint32_t dim987JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   3   ,   15  ,   61  ,   75  ,   115 ,   487 ,   237 ,   615 ,   1011    ,   4725    ,0 };
            const std::uint32_t dim988JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   5   ,   25  ,   39  ,   105 ,   81  ,   401 ,   939 ,   343 ,   3281    ,   3907    ,0 };
            const std::uint32_t dim989JoeKuoD7Init[]    =   {   1   ,   3   ,   5   ,   9   ,   31  ,   31  ,   43  ,   131 ,   275 ,   575 ,   727 ,   3035    ,   363 ,0 };
            const std::uint32_t dim990JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   11  ,   31  ,   9   ,   27  ,   145 ,   99  ,   261 ,   1927    ,   2619    ,   5853    ,0 };
            const std::uint32_t dim991JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   5   ,   25  ,   33  ,   85  ,   77  ,   435 ,   453 ,   1115    ,   1025    ,   2477    ,0 };
            const std::uint32_t dim992JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   13  ,   19  ,   55  ,   85  ,   155 ,   455 ,   385 ,   1033    ,   3789    ,   709 ,0 };
            const std::uint32_t dim993JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   11  ,   31  ,   47  ,   61  ,   45  ,   247 ,   557 ,   929 ,   1579    ,   3927    ,0 };
            const std::uint32_t dim994JoeKuoD7Init[]    =   {   1   ,   1   ,   3   ,   7   ,   13  ,   41  ,   121 ,   249 ,   393 ,   527 ,   1807    ,   2493    ,   67  ,0 };
            const std::uint32_t dim995JoeKuoD7Init[]    =   {   1   ,   3   ,   7   ,   13  ,   3   ,   17  ,   9   ,   215 ,   181 ,   841 ,   1381    ,   1573    ,   1531    ,0 };
            const std::uint32_t dim996JoeKuoD7Init[]    =   {   1   ,   1   ,   7   ,   3   ,   21  ,   39  ,   119 ,   89  ,   267 ,   395 ,   1263    ,   3927    ,   5419    ,0 };
            const std::uint32_t dim997JoeKuoD7Init[]    =   {   1   ,   1   ,   1   ,   5   ,   17  ,   21  ,   35  ,   217 ,   165 ,   837 ,   1093    ,   1347    ,   6361    ,0 };
            const std::uint32_t dim998JoeKuoD7Init[]    =   {   1   ,   3   ,   3   ,   9   ,   9   ,   1   ,   59  ,   31  ,   41  ,   229 ,   925 ,   2703    ,   6597    ,0 };
            const std::uint32_t dim999JoeKuoD7Init[]    =   {   1   ,   3   ,   1   ,   9   ,   13  ,   21  ,   35  ,   159 ,   329 ,   981 ,   955 ,   1871    ,   3571    ,0 };
            const std::uint32_t dim1000JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   11  ,   31  ,   47  ,   121 ,   201 ,   339 ,   1021    ,   1413    ,   1405    ,   1261    ,0 };
            const std::uint32_t dim1001JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   11  ,   15  ,   23  ,   115 ,   247 ,   333 ,   757 ,   369 ,   3839    ,   5217    ,0 };
            const std::uint32_t dim1002JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   15  ,   1   ,   37  ,   47  ,   67  ,   461 ,   333 ,   837 ,   2831    ,   2293    ,0 };
            const std::uint32_t dim1003JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   11  ,   31  ,   29  ,   75  ,   9   ,   287 ,   17  ,   1771    ,   3523    ,   7321    ,0 };
            const std::uint32_t dim1004JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   5   ,   29  ,   47  ,   37  ,   25  ,   497 ,   455 ,   1929    ,   2711    ,   777 ,0 };
            const std::uint32_t dim1005JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   15  ,   17  ,   21  ,   121 ,   205 ,   133 ,   139 ,   1343    ,   2181    ,   6281    ,0 };
            const std::uint32_t dim1006JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   3   ,   17  ,   59  ,   93  ,   105 ,   359 ,   27  ,   1515    ,   115 ,   7585    ,0 };
            const std::uint32_t dim1007JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   3   ,   25  ,   43  ,   71  ,   71  ,   315 ,   137 ,   1245    ,   1751    ,   1589    ,0 };
            const std::uint32_t dim1008JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   1   ,   23  ,   51  ,   61  ,   247 ,   317 ,   125 ,   859 ,   3807    ,   1175    ,0 };
            const std::uint32_t dim1009JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   9   ,   31  ,   33  ,   25  ,   41  ,   21  ,   1001    ,   63  ,   2105    ,   1929    ,0 };
            const std::uint32_t dim1010JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   15  ,   29  ,   61  ,   59  ,   173 ,   265 ,   661 ,   115 ,   3127    ,   4431    ,0 };
            const std::uint32_t dim1011JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   15  ,   7   ,   63  ,   55  ,   253 ,   131 ,   425 ,   735 ,   2917    ,   5311    ,0 };
            const std::uint32_t dim1012JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   3   ,   9   ,   7   ,   81  ,   39  ,   261 ,   633 ,   485 ,   2091    ,   3763    ,0 };
            const std::uint32_t dim1013JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   11  ,   27  ,   19  ,   99  ,   99  ,   27  ,   225 ,   1007    ,   1089    ,   921 ,0 };
            const std::uint32_t dim1014JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   13  ,   21  ,   7   ,   85  ,   105 ,   379 ,   223 ,   955 ,   3533    ,   3879    ,0 };
            const std::uint32_t dim1015JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   9   ,   13  ,   45  ,   55  ,   57  ,   315 ,   255 ,   141 ,   3255    ,   5185    ,0 };
            const std::uint32_t dim1016JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   15  ,   9   ,   27  ,   53  ,   15  ,   25  ,   547 ,   1573    ,   1387    ,   7243    ,0 };
            const std::uint32_t dim1017JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   15  ,   19  ,   17  ,   77  ,   253 ,   105 ,   1009    ,   1331    ,   2773    ,   7563    ,0 };
            const std::uint32_t dim1018JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   5   ,   3   ,   19  ,   103 ,   63  ,   491 ,   709 ,   1299    ,   1245    ,   3879    ,0 };
            const std::uint32_t dim1019JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   1   ,   13  ,   43  ,   37  ,   41  ,   167 ,   349 ,   1821    ,   2741    ,   3025    ,0 };
            const std::uint32_t dim1020JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   5   ,   29  ,   39  ,   25  ,   221 ,   259 ,   939 ,   471 ,   2547    ,   7119    ,0 };
            const std::uint32_t dim1021JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   3   ,   25  ,   59  ,   53  ,   105 ,   39  ,   737 ,   987 ,   2961    ,   7703    ,0 };
            const std::uint32_t dim1022JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   3   ,   29  ,   11  ,   109 ,   233 ,   221 ,   515 ,   1463    ,   1233    ,   7591    ,0 };
            const std::uint32_t dim1023JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   3   ,   17  ,   17  ,   113 ,   91  ,   253 ,   547 ,   1203    ,   2327    ,   6933    ,0 };
            const std::uint32_t dim1024JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   11  ,   25  ,   3   ,   17  ,   27  ,   239 ,   723 ,   1751    ,   3907    ,   1199    ,0 };
            const std::uint32_t dim1025JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   15  ,   13  ,   35  ,   93  ,   9   ,   501 ,   949 ,   659 ,   1863    ,   5319    ,0 };
            const std::uint32_t dim1026JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   1   ,   1   ,   55  ,   99  ,   73  ,   185 ,   299 ,   181 ,   4005    ,   7239    ,0 };
            const std::uint32_t dim1027JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   5   ,   13  ,   57  ,   21  ,   41  ,   461 ,   445 ,   199 ,   689 ,   2005    ,0 };
            const std::uint32_t dim1028JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   9   ,   11  ,   39  ,   45  ,   157 ,   295 ,   907 ,   1839    ,   3313    ,   6397    ,0 };
            const std::uint32_t dim1029JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   15  ,   21  ,   49  ,   39  ,   147 ,   325 ,   437 ,   1773    ,   2533    ,   8183    ,0 };
            const std::uint32_t dim1030JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   11  ,   11  ,   45  ,   9   ,   149 ,   439 ,   403 ,   1717    ,   3141    ,   7259    ,0 };
            const std::uint32_t dim1031JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   3   ,   13  ,   41  ,   79  ,   93  ,   123 ,   135 ,   541 ,   1133    ,   4389    ,0 };
            const std::uint32_t dim1032JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   11  ,   17  ,   45  ,   3   ,   49  ,   117 ,   193 ,   1737    ,   2995    ,   6821    ,0 };
            const std::uint32_t dim1033JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   9   ,   19  ,   53  ,   77  ,   119 ,   83  ,   161 ,   1029    ,   95  ,   7065    ,0 };
            const std::uint32_t dim1034JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   5   ,   19  ,   33  ,   13  ,   85  ,   63  ,   1011    ,   1857    ,   2657    ,   7513    ,0 };
            const std::uint32_t dim1035JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   13  ,   15  ,   31  ,   121 ,   75  ,   343 ,   915 ,   1571    ,   1291    ,   965 ,0 };
            const std::uint32_t dim1036JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   15  ,   17  ,   27  ,   31  ,   183 ,   79  ,   219 ,   341 ,   2491    ,   7329    ,0 };
            const std::uint32_t dim1037JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   15  ,   5   ,   5   ,   53  ,   151 ,   149 ,   471 ,   413 ,   967 ,   4207    ,0 };
            const std::uint32_t dim1038JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   15  ,   21  ,   17  ,   97  ,   107 ,   51  ,   533 ,   1195    ,   1495    ,   3843    ,0 };
            const std::uint32_t dim1039JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   7   ,   3   ,   5   ,   109 ,   19  ,   401 ,   179 ,   1595    ,   3147    ,   3847    ,0 };
            const std::uint32_t dim1040JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   9   ,   11  ,   49  ,   9   ,   245 ,   417 ,   933 ,   627 ,   551 ,   3643    ,0 };
            const std::uint32_t dim1041JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   11  ,   5   ,   33  ,   101 ,   247 ,   57  ,   597 ,   377 ,   7   ,   7117    ,0 };
            const std::uint32_t dim1042JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   11  ,   7   ,   47  ,   113 ,   29  ,   503 ,   385 ,   743 ,   563 ,   4775    ,0 };
            const std::uint32_t dim1043JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   15  ,   7   ,   63  ,   57  ,   171 ,   77  ,   663 ,   1113    ,   1901    ,   5361    ,0 };
            const std::uint32_t dim1044JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   11  ,   1   ,   1   ,   39  ,   83  ,   497 ,   725 ,   1105    ,   863 ,   113 ,0 };
            const std::uint32_t dim1045JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   1   ,   1   ,   23  ,   95  ,   137 ,   447 ,   593 ,   561 ,   1665    ,   7565    ,0 };
            const std::uint32_t dim1046JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   5   ,   19  ,   15  ,   25  ,   185 ,   33  ,   747 ,   641 ,   3205    ,   1373    ,0 };
            const std::uint32_t dim1047JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   1   ,   15  ,   17  ,   65  ,   77  ,   1   ,   689 ,   1751    ,   1885    ,   3873    ,0 };
            const std::uint32_t dim1048JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   15  ,   23  ,   23  ,   9   ,   97  ,   129 ,   185 ,   1527    ,   3721    ,   5161    ,0 };
            const std::uint32_t dim1049JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   5   ,   23  ,   33  ,   33  ,   131 ,   99  ,   929 ,   1077    ,   3129    ,   8153    ,0 };
            const std::uint32_t dim1050JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   1   ,   1   ,   37  ,   69  ,   155 ,   69  ,   121 ,   395 ,   717 ,   841 ,0 };
            const std::uint32_t dim1051JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   7   ,   17  ,   63  ,   101 ,   109 ,   323 ,   559 ,   427 ,   2279    ,   5345    ,0 };
            const std::uint32_t dim1052JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   1   ,   9   ,   27  ,   77  ,   19  ,   375 ,   313 ,   855 ,   65  ,   1359    ,0 };
            const std::uint32_t dim1053JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   5   ,   23  ,   11  ,   5   ,   57  ,   69  ,   267 ,   895 ,   1279    ,   5083    ,0 };
            const std::uint32_t dim1054JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   9   ,   17  ,   5   ,   13  ,   27  ,   299 ,   279 ,   389 ,   3161    ,   4633    ,0 };
            const std::uint32_t dim1055JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   1   ,   19  ,   47  ,   31  ,   93  ,   503 ,   473 ,   1501    ,   617 ,   1621    ,0 };
            const std::uint32_t dim1056JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   15  ,   17  ,   31  ,   35  ,   75  ,   41  ,   113 ,   149 ,   861 ,   5845    ,0 };
            const std::uint32_t dim1057JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   1   ,   7   ,   21  ,   31  ,   77  ,   307 ,   709 ,   531 ,   1133    ,   5887    ,0 };
            const std::uint32_t dim1058JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   7   ,   25  ,   37  ,   23  ,   233 ,   339 ,   705 ,   123 ,   79  ,   3827    ,0 };
            const std::uint32_t dim1059JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   9   ,   15  ,   61  ,   13  ,   215 ,   175 ,   999 ,   1147    ,   523 ,   7831    ,0 };
            const std::uint32_t dim1060JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   7   ,   15  ,   31  ,   117 ,   41  ,   43  ,   851 ,   1657    ,   669 ,   7243    ,0 };
            const std::uint32_t dim1061JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   1   ,   29  ,   47  ,   29  ,   179 ,   151 ,   833 ,   1911    ,   3031    ,   3835    ,0 };
            const std::uint32_t dim1062JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   13  ,   27  ,   41  ,   127 ,   203 ,   381 ,   395 ,   201 ,   1713    ,   4781    ,0 };
            const std::uint32_t dim1063JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   7   ,   11  ,   11  ,   127 ,   13  ,   257 ,   1   ,   1285    ,   2829    ,   8077    ,0 };
            const std::uint32_t dim1064JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   5   ,   15  ,   1   ,   35  ,   105 ,   183 ,   543 ,   1865    ,   675 ,   7747    ,0 };
            const std::uint32_t dim1065JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   1   ,   15  ,   47  ,   111 ,   147 ,   373 ,   445 ,   1273    ,   1989    ,   2057    ,0 };
            const std::uint32_t dim1066JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   9   ,   5   ,   31  ,   63  ,   127 ,   33  ,   323 ,   477 ,   213 ,   8137    ,0 };
            const std::uint32_t dim1067JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   9   ,   13  ,   1   ,   9   ,   135 ,   113 ,   395 ,   127 ,   3561    ,   5903    ,0 };
            const std::uint32_t dim1068JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   15  ,   1   ,   31  ,   85  ,   181 ,   49  ,   585 ,   1515    ,   2105    ,   541 ,0 };
            const std::uint32_t dim1069JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   15  ,   9   ,   1   ,   121 ,   31  ,   221 ,   445 ,   735 ,   1107    ,   4073    ,0 };
            const std::uint32_t dim1070JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   15  ,   3   ,   13  ,   13  ,   247 ,   509 ,   199 ,   1575    ,   2721    ,   2303    ,0 };
            const std::uint32_t dim1071JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   7   ,   25  ,   17  ,   63  ,   59  ,   409 ,   69  ,   1947    ,   427 ,   5357    ,0 };
            const std::uint32_t dim1072JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   3   ,   13  ,   5   ,   99  ,   161 ,   163 ,   437 ,   1467    ,   2215    ,   3321    ,0 };
            const std::uint32_t dim1073JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   3   ,   15  ,   55  ,   101 ,   207 ,   75  ,   601 ,   1327    ,   3901    ,   5773    ,0 };
            const std::uint32_t dim1074JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   3   ,   13  ,   45  ,   115 ,   119 ,   431 ,   5   ,   563 ,   3255    ,   5077    ,0 };
            const std::uint32_t dim1075JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   3   ,   21  ,   51  ,   41  ,   3   ,   375 ,   203 ,   1117    ,   3921    ,   387 ,0 };
            const std::uint32_t dim1076JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   7   ,   9   ,   5   ,   15  ,   133 ,   179 ,   37  ,   1593    ,   193 ,   4975    ,0 };
            const std::uint32_t dim1077JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   7   ,   31  ,   37  ,   89  ,   1   ,   241 ,   445 ,   381 ,   3283    ,   3851    ,0 };
            const std::uint32_t dim1078JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   1   ,   5   ,   45  ,   21  ,   123 ,   377 ,   83  ,   2029    ,   1913    ,   659 ,0 };
            const std::uint32_t dim1079JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   3   ,   5   ,   5   ,   35  ,   85  ,   173 ,   397 ,   1695    ,   3517    ,   175 ,0 };
            const std::uint32_t dim1080JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   13  ,   25  ,   51  ,   93  ,   177 ,   371 ,   507 ,   1777    ,   3335    ,   5953    ,0 };
            const std::uint32_t dim1081JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   15  ,   13  ,   41  ,   103 ,   105 ,   303 ,   401 ,   1339    ,   21  ,   5723    ,0 };
            const std::uint32_t dim1082JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   15  ,   7   ,   57  ,   63  ,   79  ,   35  ,   363 ,   831 ,   3911    ,   5777    ,0 };
            const std::uint32_t dim1083JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   11  ,   13  ,   15  ,   127 ,   141 ,   231 ,   619 ,   835 ,   691 ,   525 ,0 };
            const std::uint32_t dim1084JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   5   ,   7   ,   33  ,   81  ,   83  ,   497 ,   459 ,   493 ,   725 ,   2137    ,0 };
            const std::uint32_t dim1085JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   5   ,   25  ,   7   ,   77  ,   163 ,   47  ,   445 ,   629 ,   463 ,   3597    ,0 };
            const std::uint32_t dim1086JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   11  ,   19  ,   13  ,   67  ,   117 ,   351 ,   169 ,   1905    ,   3105    ,   93  ,0 };
            const std::uint32_t dim1087JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   13  ,   17  ,   17  ,   67  ,   135 ,   111 ,   649 ,   495 ,   425 ,   1621    ,0 };
            const std::uint32_t dim1088JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   1   ,   19  ,   59  ,   11  ,   227 ,   137 ,   525 ,   1751    ,   915 ,   4397    ,0 };
            const std::uint32_t dim1089JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   3   ,   15  ,   53  ,   87  ,   153 ,   69  ,   867 ,   833 ,   2363    ,   4363    ,0 };
            const std::uint32_t dim1090JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   13  ,   13  ,   19  ,   35  ,   103 ,   441 ,   23  ,   1049    ,   2469    ,   6595    ,0 };
            const std::uint32_t dim1091JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   7   ,   23  ,   55  ,   57  ,   25  ,   3   ,   157 ,   523 ,   1029    ,   4177    ,0 };
            const std::uint32_t dim1092JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   5   ,   9   ,   13  ,   1   ,   109 ,   219 ,   703 ,   237 ,   435 ,   2607    ,0 };
            const std::uint32_t dim1093JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   13  ,   21  ,   23  ,   5   ,   109 ,   467 ,   197 ,   1467    ,   3625    ,   4997    ,0 };
            const std::uint32_t dim1094JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   3   ,   25  ,   53  ,   119 ,   163 ,   117 ,   721 ,   1017    ,   2499    ,   4139    ,0 };
            const std::uint32_t dim1095JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   9   ,   9   ,   13  ,   33  ,   5   ,   263 ,   21  ,   1393    ,   3181    ,   4785    ,0 };
            const std::uint32_t dim1096JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   13  ,   15  ,   5   ,   57  ,   233 ,   99  ,   305 ,   745 ,   2327    ,   2259    ,0 };
            const std::uint32_t dim1097JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   3   ,   15  ,   39  ,   99  ,   115 ,   395 ,   99  ,   947 ,   3171    ,   711 ,0 };
            const std::uint32_t dim1098JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   13  ,   17  ,   33  ,   29  ,   37  ,   399 ,   479 ,   1083    ,   285 ,   6897    ,0 };
            const std::uint32_t dim1099JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   5   ,   7   ,   1   ,   9   ,   239 ,   479 ,   265 ,   1129    ,   3615    ,   4865    ,0 };
            const std::uint32_t dim1100JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   15  ,   31  ,   45  ,   7   ,   179 ,   467 ,   675 ,   1257    ,   1729    ,   7879    ,0 };
            const std::uint32_t dim1101JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   13  ,   5   ,   23  ,   11  ,   219 ,   503 ,   613 ,   1383    ,   1733    ,   3269    ,0 };
            const std::uint32_t dim1102JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   13  ,   25  ,   5   ,   81  ,   205 ,   389 ,   925 ,   735 ,   2981    ,   4271    ,0 };
            const std::uint32_t dim1103JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   7   ,   19  ,   47  ,   107 ,   15  ,   87  ,   889 ,   725 ,   1123    ,   2883    ,0 };
            const std::uint32_t dim1104JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   13  ,   31  ,   9   ,   45  ,   129 ,   353 ,   919 ,   1529    ,   827 ,   3645    ,0 };
            const std::uint32_t dim1105JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   5   ,   13  ,   45  ,   17  ,   219 ,   23  ,   873 ,   1127    ,   1757    ,   1103    ,0 };
            const std::uint32_t dim1106JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   11  ,   31  ,   45  ,   33  ,   215 ,   107 ,   941 ,   1785    ,   4039    ,   3393    ,0 };
            const std::uint32_t dim1107JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   7   ,   15  ,   61  ,   107 ,   189 ,   31  ,   457 ,   881 ,   1449    ,   7351    ,0 };
            const std::uint32_t dim1108JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   15  ,   13  ,   63  ,   95  ,   27  ,   3   ,   771 ,   363 ,   2569    ,   2195    ,0 };
            const std::uint32_t dim1109JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   9   ,   15  ,   11  ,   5   ,   193 ,   439 ,   745 ,   1705    ,   1249    ,   7319    ,0 };
            const std::uint32_t dim1110JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   11  ,   29  ,   19  ,   111 ,   73  ,   149 ,   707 ,   1337    ,   1417    ,   761 ,0 };
            const std::uint32_t dim1111JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   9   ,   17  ,   7   ,   127 ,   113 ,   353 ,   575 ,   1979    ,   3589    ,   3221    ,   1801    ,0 };
            const std::uint32_t dim1112JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   13  ,   29  ,   21  ,   31  ,   135 ,   45  ,   571 ,   229 ,   791 ,   2017    ,   1023    ,0 };
            const std::uint32_t dim1113JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   1   ,   3   ,   37  ,   29  ,   233 ,   379 ,   579 ,   1895    ,   2359    ,   5511    ,   15901   ,0 };
            const std::uint32_t dim1114JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   3   ,   11  ,   63  ,   83  ,   219 ,   275 ,   441 ,   581 ,   3735    ,   6845    ,   12669   ,0 };
            const std::uint32_t dim1115JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   9   ,   3   ,   5   ,   87  ,   143 ,   207 ,   211 ,   1123    ,   443 ,   3139    ,   15123   ,0 };
            const std::uint32_t dim1116JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   11  ,   11  ,   21  ,   69  ,   69  ,   307 ,   935 ,   1353    ,   163 ,   1535    ,   4821    ,0 };
            const std::uint32_t dim1117JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   13  ,   11  ,   47  ,   41  ,   107 ,   463 ,   1003    ,   457 ,   1019    ,   1699    ,   4425    ,0 };
            const std::uint32_t dim1118JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   7   ,   9   ,   5   ,   99  ,   95  ,   207 ,   697 ,   9   ,   771 ,   6895    ,   9157    ,0 };
            const std::uint32_t dim1119JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   11  ,   13  ,   5   ,   15  ,   107 ,   3   ,   319 ,   1187    ,   3357    ,   295 ,   2863    ,0 };
            const std::uint32_t dim1120JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   1   ,   13  ,   23  ,   89  ,   149 ,   337 ,   435 ,   633 ,   885 ,   1361    ,   3795    ,0 };
            const std::uint32_t dim1121JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   13  ,   1   ,   9   ,   63  ,   203 ,   377 ,   305 ,   1471    ,   3193    ,   5507    ,   2219    ,0 };
            const std::uint32_t dim1122JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   9   ,   9   ,   9   ,   63  ,   31  ,   35  ,   551 ,   1379    ,   135 ,   4949    ,   10345   ,0 };
            const std::uint32_t dim1123JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   3   ,   7   ,   61  ,   121 ,   27  ,   127 ,   901 ,   1935    ,   1347    ,   3179    ,   13785   ,0 };
            const std::uint32_t dim1124JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   11  ,   13  ,   17  ,   57  ,   73  ,   219 ,   73  ,   335 ,   3705    ,   591 ,   3547    ,0 };
            const std::uint32_t dim1125JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   7   ,   13  ,   7   ,   127 ,   153 ,   503 ,   99  ,   187 ,   1697    ,   3497    ,   11913   ,0 };
            const std::uint32_t dim1126JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   5   ,   3   ,   21  ,   99  ,   125 ,   87  ,   889 ,   1471    ,   625 ,   2671    ,   11729   ,0 };
            const std::uint32_t dim1127JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   7   ,   9   ,   55  ,   127 ,   201 ,   383 ,   769 ,   769 ,   3907    ,   7087    ,   1933    ,0 };
            const std::uint32_t dim1128JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   5   ,   9   ,   47  ,   5   ,   29  ,   155 ,   327 ,   1413    ,   2761    ,   7699    ,   9129    ,0 };
            const std::uint32_t dim1129JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   15  ,   9   ,   11  ,   7   ,   91  ,   71  ,   563 ,   535 ,   3387    ,   4769    ,   4875    ,0 };
            const std::uint32_t dim1130JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   11  ,   17  ,   47  ,   29  ,   201 ,   299 ,   947 ,   39  ,   583 ,   1723    ,   877 ,0 };
            const std::uint32_t dim1131JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   5   ,   27  ,   49  ,   105 ,   31  ,   91  ,   39  ,   1355    ,   2729    ,   6965    ,   14081   ,0 };
            const std::uint32_t dim1132JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   7   ,   17  ,   63  ,   65  ,   229 ,   497 ,   431 ,   1167    ,   1299    ,   4641    ,   10975   ,0 };
            const std::uint32_t dim1133JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   9   ,   17  ,   3   ,   101 ,   191 ,   187 ,   87  ,   1229    ,   369 ,   2633    ,   13765   ,0 };
            const std::uint32_t dim1134JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   7   ,   29  ,   7   ,   57  ,   17  ,   319 ,   839 ,   799 ,   151 ,   431 ,   9513    ,0 };
            const std::uint32_t dim1135JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   11  ,   25  ,   47  ,   15  ,   29  ,   71  ,   617 ,   697 ,   2633    ,   1787    ,   10343   ,0 };
            const std::uint32_t dim1136JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   3   ,   13  ,   1   ,   41  ,   211 ,   265 ,   501 ,   1619    ,   3781    ,   4091    ,   7785    ,0 };
            const std::uint32_t dim1137JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   9   ,   11  ,   37  ,   69  ,   45  ,   107 ,   69  ,   1227    ,   311 ,   187 ,   10379   ,0 };
            const std::uint32_t dim1138JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   1   ,   31  ,   37  ,   85  ,   135 ,   283 ,   869 ,   1159    ,   3971    ,   6339    ,   5511    ,0 };
            const std::uint32_t dim1139JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   3   ,   19  ,   43  ,   75  ,   59  ,   365 ,   763 ,   323 ,   3513    ,   437 ,   2371    ,0 };
            const std::uint32_t dim1140JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   13  ,   31  ,   39  ,   81  ,   199 ,   43  ,   863 ,   1563    ,   2811    ,   4551    ,   7469    ,0 };
            const std::uint32_t dim1141JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   5   ,   17  ,   59  ,   17  ,   9   ,   53  ,   527 ,   1689    ,   2365    ,   7673    ,   14581   ,0 };
            const std::uint32_t dim1142JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   5   ,   5   ,   5   ,   59  ,   21  ,   303 ,   43  ,   1379    ,   3297    ,   3053    ,   11115   ,0 };
            const std::uint32_t dim1143JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   15  ,   3   ,   33  ,   5   ,   253 ,   409 ,   321 ,   1487    ,   2083    ,   405 ,   15075   ,0 };
            const std::uint32_t dim1144JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   15  ,   11  ,   53  ,   99  ,   151 ,   33  ,   675 ,   1781    ,   1475    ,   2193    ,   6073    ,0 };
            const std::uint32_t dim1145JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   13  ,   27  ,   49  ,   83  ,   15  ,   335 ,   35  ,   1999    ,   237 ,   7359    ,   12173   ,0 };
            const std::uint32_t dim1146JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   15  ,   15  ,   61  ,   85  ,   243 ,   347 ,   745 ,   637 ,   1057    ,   5475    ,   15039   ,0 };
            const std::uint32_t dim1147JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   7   ,   1   ,   1   ,   31  ,   197 ,   499 ,   741 ,   191 ,   3799    ,   5485    ,   10129   ,0 };
            const std::uint32_t dim1148JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   5   ,   29  ,   15  ,   15  ,   185 ,   55  ,   685 ,   329 ,   605 ,   3365    ,   10203   ,0 };
            const std::uint32_t dim1149JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   13  ,   5   ,   1   ,   1   ,   169 ,   349 ,   591 ,   1961    ,   2989    ,   131 ,   2647    ,0 };
            const std::uint32_t dim1150JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   9   ,   17  ,   49  ,   95  ,   7   ,   57  ,   881 ,   1065    ,   3759    ,   5851    ,   7439    ,0 };
            const std::uint32_t dim1151JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   5   ,   27  ,   49  ,   65  ,   1   ,   177 ,   477 ,   453 ,   1823    ,   7615    ,   1285    ,0 };
            const std::uint32_t dim1152JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   9   ,   23  ,   25  ,   17  ,   149 ,   85  ,   373 ,   1585    ,   1227    ,   6127    ,   6003    ,0 };
            const std::uint32_t dim1153JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   13  ,   15  ,   61  ,   41  ,   141 ,   507 ,   391 ,   587 ,   2819    ,   3311    ,   853 ,0 };
            const std::uint32_t dim1154JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   13  ,   13  ,   23  ,   67  ,   171 ,   381 ,   285 ,   619 ,   457 ,   2751    ,   435 ,0 };
            const std::uint32_t dim1155JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   15  ,   13  ,   9   ,   21  ,   197 ,   385 ,   511 ,   1683    ,   2965    ,   1367    ,   7523    ,0 };
            const std::uint32_t dim1156JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   1   ,   23  ,   13  ,   21  ,   55  ,   415 ,   503 ,   1765    ,   1745    ,   5329    ,   4665    ,0 };
            const std::uint32_t dim1157JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   1   ,   21  ,   51  ,   49  ,   31  ,   195 ,   243 ,   1825    ,   2831    ,   467 ,   6527    ,0 };
            const std::uint32_t dim1158JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   3   ,   31  ,   37  ,   41  ,   139 ,   63  ,   517 ,   717 ,   415 ,   1137    ,   1855    ,0 };
            const std::uint32_t dim1159JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   15  ,   1   ,   45  ,   39  ,   9   ,   441 ,   809 ,   801 ,   3133    ,   2283    ,   8947    ,0 };
            const std::uint32_t dim1160JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   13  ,   13  ,   47  ,   55  ,   115 ,   155 ,   347 ,   1597    ,   415 ,   271 ,   4543    ,0 };
            const std::uint32_t dim1161JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   1   ,   1   ,   45  ,   5   ,   239 ,   187 ,   293 ,   59  ,   1319    ,   3839    ,   9945    ,0 };
            const std::uint32_t dim1162JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   15  ,   1   ,   41  ,   13  ,   19  ,   455 ,   881 ,   451 ,   1795    ,   239 ,   2695    ,0 };
            const std::uint32_t dim1163JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   9   ,   5   ,   25  ,   3   ,   19  ,   189 ,   377 ,   1017    ,   2501    ,   2707    ,   15333   ,0 };
            const std::uint32_t dim1164JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   5   ,   29  ,   57  ,   45  ,   35  ,   297 ,   663 ,   359 ,   2597    ,   7223    ,   6265    ,0 };
            const std::uint32_t dim1165JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   7   ,   1   ,   47  ,   125 ,   209 ,   65  ,   129 ,   211 ,   2535    ,   3617    ,   16229   ,0 };
            const std::uint32_t dim1166JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   11  ,   19  ,   29  ,   39  ,   177 ,   39  ,   807 ,   975 ,   835 ,   5509    ,   791 ,0 };
            const std::uint32_t dim1167JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   13  ,   31  ,   49  ,   69  ,   169 ,   433 ,   833 ,   1743    ,   3187    ,   8111    ,   15475   ,0 };
            const std::uint32_t dim1168JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   7   ,   31  ,   9   ,   27  ,   73  ,   335 ,   363 ,   1707    ,   1227    ,   6459    ,   12513   ,0 };
            const std::uint32_t dim1169JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   1   ,   1   ,   47  ,   109 ,   115 ,   429 ,   551 ,   1805    ,   3235    ,   579 ,   10039   ,0 };
            const std::uint32_t dim1170JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   7   ,   17  ,   61  ,   61  ,   1   ,   35  ,   917 ,   1513    ,   2141    ,   3939    ,   15755   ,0 };
            const std::uint32_t dim1171JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   1   ,   3   ,   27  ,   7   ,   219 ,   473 ,   875 ,   711 ,   703 ,   129 ,   16359   ,0 };
            const std::uint32_t dim1172JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   3   ,   27  ,   33  ,   97  ,   137 ,   19  ,   893 ,   233 ,   2605    ,   13  ,   875 ,0 };
            const std::uint32_t dim1173JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   11  ,   31  ,   43  ,   77  ,   225 ,   403 ,   861 ,   141 ,   2121    ,   707 ,   15753   ,0 };
            const std::uint32_t dim1174JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   3   ,   17  ,   33  ,   29  ,   103 ,   381 ,   179 ,   735 ,   2939    ,   7213    ,   12679   ,0 };
            const std::uint32_t dim1175JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   7   ,   5   ,   41  ,   43  ,   215 ,   239 ,   19  ,   625 ,   579 ,   5157    ,   12457   ,0 };
            const std::uint32_t dim1176JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   7   ,   15  ,   29  ,   93  ,   37  ,   241 ,   141 ,   1035    ,   3283    ,   193 ,   9873    ,0 };
            const std::uint32_t dim1177JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   13  ,   23  ,   11  ,   113 ,   153 ,   271 ,   515 ,   197 ,   3723    ,   1827    ,   11941   ,0 };
            const std::uint32_t dim1178JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   1   ,   29  ,   13  ,   45  ,   23  ,   421 ,   957 ,   1819    ,   1287    ,   5615    ,   4253    ,0 };
            const std::uint32_t dim1179JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   3   ,   11  ,   55  ,   47  ,   211 ,   85  ,   481 ,   1199    ,   3225    ,   5233    ,   4295    ,0 };
            const std::uint32_t dim1180JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   13  ,   11  ,   51  ,   93  ,   139 ,   271 ,   929 ,   863 ,   3227    ,   3075    ,   3587    ,0 };
            const std::uint32_t dim1181JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   11  ,   19  ,   59  ,   9   ,   221 ,   275 ,   171 ,   1703    ,   1495    ,   523 ,   5993    ,0 };
            const std::uint32_t dim1182JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   13  ,   15  ,   11  ,   21  ,   147 ,   291 ,   639 ,   1411    ,   33  ,   6845    ,   1431    ,0 };
            const std::uint32_t dim1183JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   1   ,   11  ,   11  ,   39  ,   195 ,   261 ,   19  ,   1803    ,   2869    ,   4507    ,   1131    ,0 };
            const std::uint32_t dim1184JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   11  ,   15  ,   27  ,   125 ,   5   ,   309 ,   569 ,   361 ,   4061    ,   2559    ,   1631    ,0 };
            const std::uint32_t dim1185JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   7   ,   23  ,   57  ,   37  ,   175 ,   35  ,   753 ,   755 ,   519 ,   5617    ,   1419    ,0 };
            const std::uint32_t dim1186JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   11  ,   21  ,   9   ,   107 ,   37  ,   121 ,   767 ,   1005    ,   2609    ,   2531    ,   14811   ,0 };
            const std::uint32_t dim1187JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   7   ,   3   ,   9   ,   91  ,   203 ,   219 ,   523 ,   319 ,   3021    ,   3465    ,   15579   ,0 };
            const std::uint32_t dim1188JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   1   ,   3   ,   29  ,   97  ,   249 ,   429 ,   665 ,   283 ,   595 ,   1527    ,   4559    ,0 };
            const std::uint32_t dim1189JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   15  ,   19  ,   23  ,   9   ,   169 ,   427 ,   171 ,   897 ,   3099    ,   7339    ,   13237   ,0 };
            const std::uint32_t dim1190JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   13  ,   11  ,   25  ,   11  ,   123 ,   229 ,   197 ,   1395    ,   2999    ,   3591    ,   5017    ,0 };
            const std::uint32_t dim1191JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   15  ,   3   ,   11  ,   49  ,   5   ,   217 ,   575 ,   445 ,   1381    ,   4407    ,   9777    ,0 };
            const std::uint32_t dim1192JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   13  ,   23  ,   43  ,   55  ,   19  ,   129 ,   925 ,   1623    ,   4037    ,   2535    ,   871 ,0 };
            const std::uint32_t dim1193JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   15  ,   3   ,   7   ,   29  ,   109 ,   251 ,   627 ,   1751    ,   3613    ,   5741    ,   7859    ,0 };
            const std::uint32_t dim1194JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   3   ,   23  ,   61  ,   115 ,   127 ,   157 ,   725 ,   1321    ,   1143    ,   3737    ,   12559   ,0 };
            const std::uint32_t dim1195JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   11  ,   25  ,   41  ,   117 ,   217 ,   389 ,   839 ,   1029    ,   547 ,   6149    ,   8335    ,0 };
            const std::uint32_t dim1196JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   1   ,   29  ,   61  ,   101 ,   81  ,   137 ,   547 ,   1989    ,   3907    ,   4855    ,   15949   ,0 };
            const std::uint32_t dim1197JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   3   ,   5   ,   9   ,   15  ,   33  ,   415 ,   725 ,   1183    ,   4091    ,   411 ,   4541    ,0 };
            const std::uint32_t dim1198JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   7   ,   31  ,   61  ,   53  ,   205 ,   157 ,   861 ,   989 ,   3265    ,   2943    ,   12941   ,0 };
            const std::uint32_t dim1199JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   11  ,   11  ,   13  ,   89  ,   39  ,   241 ,   153 ,   439 ,   2087    ,   5161    ,   5705    ,0 };
            const std::uint32_t dim1200JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   11  ,   15  ,   49  ,   39  ,   101 ,   1   ,   793 ,   1429    ,   2109    ,   1233    ,   3717    ,0 };
            const std::uint32_t dim1201JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   9   ,   29  ,   59  ,   45  ,   111 ,   157 ,   421 ,   853 ,   273 ,   1595    ,   1799    ,0 };
            const std::uint32_t dim1202JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   11  ,   3   ,   45  ,   31  ,   89  ,   475 ,   887 ,   563 ,   3985    ,   3011    ,   6903    ,0 };
            const std::uint32_t dim1203JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   15  ,   25  ,   13  ,   69  ,   3   ,   249 ,   435 ,   1333    ,   4079    ,   2259    ,   1971    ,0 };
            const std::uint32_t dim1204JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   11  ,   9   ,   51  ,   7   ,   203 ,   231 ,   155 ,   375 ,   2079    ,   6821    ,   12973   ,0 };
            const std::uint32_t dim1205JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   9   ,   5   ,   23  ,   115 ,   1   ,   307 ,   553 ,   1005    ,   2113    ,   6443    ,   8545    ,0 };
            const std::uint32_t dim1206JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   11  ,   7   ,   49  ,   49  ,   255 ,   73  ,   373 ,   413 ,   2997    ,   1403    ,   9501    ,0 };
            const std::uint32_t dim1207JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   15  ,   11  ,   31  ,   29  ,   43  ,   341 ,   119 ,   1209    ,   1471    ,   5785    ,   9809    ,0 };
            const std::uint32_t dim1208JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   15  ,   3   ,   35  ,   75  ,   187 ,   421 ,   911 ,   169 ,   1427    ,   7243    ,   10511   ,0 };
            const std::uint32_t dim1209JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   9   ,   3   ,   25  ,   21  ,   137 ,   437 ,   737 ,   1373    ,   3417    ,   2951    ,   7623    ,0 };
            const std::uint32_t dim1210JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   15  ,   27  ,   19  ,   97  ,   237 ,   341 ,   679 ,   473 ,   2775    ,   7195    ,   8093    ,0 };
            const std::uint32_t dim1211JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   3   ,   7   ,   45  ,   19  ,   109 ,   499 ,   883 ,   1473    ,   1907    ,   7229    ,   8063    ,0 };
            const std::uint32_t dim1212JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   1   ,   5   ,   49  ,   65  ,   213 ,   49  ,   941 ,   833 ,   3859    ,   3423    ,   5723    ,0 };
            const std::uint32_t dim1213JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   1   ,   27  ,   43  ,   53  ,   21  ,   379 ,   139 ,   1811    ,   133 ,   3641    ,   3021    ,0 };
            const std::uint32_t dim1214JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   9   ,   31  ,   49  ,   13  ,   17  ,   99  ,   773 ,   1127    ,   1237    ,   3593    ,   13233   ,0 };
            const std::uint32_t dim1215JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   9   ,   13  ,   21  ,   117 ,   29  ,   105 ,   671 ,   1423    ,   2449    ,   1979    ,   3717    ,0 };
            const std::uint32_t dim1216JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   13  ,   17  ,   55  ,   37  ,   45  ,   163 ,   475 ,   665 ,   115 ,   2175    ,   10065   ,0 };
            const std::uint32_t dim1217JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   9   ,   7   ,   31  ,   67  ,   215 ,   153 ,   981 ,   569 ,   2911    ,   6111    ,   12189   ,0 };
            const std::uint32_t dim1218JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   11  ,   19  ,   19  ,   101 ,   27  ,   131 ,   153 ,   505 ,   2897    ,   4573    ,   13713   ,0 };
            const std::uint32_t dim1219JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   9   ,   15  ,   21  ,   99  ,   187 ,   155 ,   135 ,   1421    ,   1421    ,   843 ,   3271    ,0 };
            const std::uint32_t dim1220JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   5   ,   1   ,   9   ,   17  ,   243 ,   111 ,   223 ,   1343    ,   3765    ,   2439    ,   717 ,0 };
            const std::uint32_t dim1221JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   3   ,   21  ,   9   ,   83  ,   191 ,   45  ,   813 ,   1047    ,   1483    ,   209 ,   2895    ,0 };
            const std::uint32_t dim1222JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   11  ,   29  ,   41  ,   119 ,   11  ,   245 ,   145 ,   969 ,   3017    ,   6403    ,   11387   ,0 };
            const std::uint32_t dim1223JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   13  ,   1   ,   19  ,   107 ,   35  ,   49  ,   381 ,   225 ,   595 ,   7145    ,   697 ,0 };
            const std::uint32_t dim1224JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   11  ,   5   ,   15  ,   37  ,   31  ,   117 ,   649 ,   1263    ,   1045    ,   3749    ,   16177   ,0 };
            const std::uint32_t dim1225JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   3   ,   7   ,   7   ,   91  ,   45  ,   395 ,   403 ,   1953    ,   743 ,   2207    ,   12887   ,0 };
            const std::uint32_t dim1226JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   11  ,   13  ,   31  ,   67  ,   7   ,   279 ,   389 ,   775 ,   301 ,   87  ,   6705    ,0 };
            const std::uint32_t dim1227JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   5   ,   27  ,   7   ,   85  ,   183 ,   325 ,   103 ,   1943    ,   2421    ,   4399    ,   7339    ,0 };
            const std::uint32_t dim1228JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   7   ,   21  ,   13  ,   69  ,   1   ,   289 ,   727 ,   1587    ,   3033    ,   2921    ,   12035   ,0 };
            const std::uint32_t dim1229JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   11  ,   31  ,   35  ,   103 ,   239 ,   89  ,   983 ,   433 ,   3027    ,   3089    ,   14439   ,0 };
            const std::uint32_t dim1230JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   9   ,   11  ,   9   ,   107 ,   207 ,   87  ,   563 ,   129 ,   2647    ,   3163    ,   11327   ,0 };
            const std::uint32_t dim1231JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   11  ,   9   ,   35  ,   115 ,   189 ,   293 ,   637 ,   213 ,   1111    ,   331 ,   10115   ,0 };
            const std::uint32_t dim1232JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   7   ,   21  ,   59  ,   127 ,   145 ,   157 ,   431 ,   295 ,   4055    ,   6207    ,   5353    ,0 };
            const std::uint32_t dim1233JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   5   ,   9   ,   53  ,   13  ,   249 ,   275 ,   841 ,   987 ,   3243    ,   7229    ,   6215    ,0 };
            const std::uint32_t dim1234JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   9   ,   11  ,   5   ,   47  ,   247 ,   57  ,   799 ,   1787    ,   2667    ,   3615    ,   4343    ,0 };
            const std::uint32_t dim1235JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   11  ,   31  ,   37  ,   73  ,   77  ,   181 ,   591 ,   445 ,   3081    ,   5337    ,   14259   ,0 };
            const std::uint32_t dim1236JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   11  ,   11  ,   49  ,   59  ,   229 ,   159 ,   139 ,   1435    ,   313 ,   7995    ,   5623    ,0 };
            const std::uint32_t dim1237JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   13  ,   17  ,   39  ,   53  ,   39  ,   413 ,   451 ,   2029    ,   1549    ,   485 ,   1311    ,0 };
            const std::uint32_t dim1238JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   11  ,   15  ,   57  ,   9   ,   245 ,   397 ,   587 ,   1733    ,   459 ,   2127    ,   16085   ,0 };
            const std::uint32_t dim1239JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   3   ,   17  ,   5   ,   17  ,   231 ,   439 ,   355 ,   1899    ,   1613    ,   1529    ,   12557   ,0 };
            const std::uint32_t dim1240JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   1   ,   5   ,   55  ,   113 ,   209 ,   441 ,   813 ,   1025    ,   191 ,   853 ,   2039    ,0 };
            const std::uint32_t dim1241JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   11  ,   9   ,   47  ,   89  ,   137 ,   187 ,   457 ,   1169    ,   3607    ,   3799    ,   15121   ,0 };
            const std::uint32_t dim1242JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   15  ,   15  ,   27  ,   93  ,   211 ,   137 ,   809 ,   1723    ,   1865    ,   6291    ,   13209   ,0 };
            const std::uint32_t dim1243JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   15  ,   5   ,   15  ,   67  ,   55  ,   445 ,   781 ,   829 ,   3237    ,   4031    ,   5147    ,0 };
            const std::uint32_t dim1244JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   3   ,   17  ,   59  ,   65  ,   35  ,   103 ,   515 ,   1409    ,   395 ,   711 ,   11773   ,0 };
            const std::uint32_t dim1245JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   11  ,   29  ,   5   ,   21  ,   117 ,   269 ,   963 ,   337 ,   3149    ,   2569    ,   9881    ,0 };
            const std::uint32_t dim1246JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   7   ,   1   ,   57  ,   61  ,   185 ,   431 ,   977 ,   661 ,   1285    ,   2607    ,   13465   ,0 };
            const std::uint32_t dim1247JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   5   ,   25  ,   35  ,   61  ,   227 ,   437 ,   75  ,   1677    ,   3337    ,   4601    ,   10447   ,0 };
            const std::uint32_t dim1248JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   1   ,   29  ,   29  ,   5   ,   163 ,   237 ,   217 ,   97  ,   1607    ,   911 ,   6195    ,0 };
            const std::uint32_t dim1249JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   3   ,   17  ,   7   ,   101 ,   31  ,   323 ,   191 ,   871 ,   1691    ,   3535    ,   8935    ,0 };
            const std::uint32_t dim1250JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   3   ,   11  ,   47  ,   117 ,   179 ,   25  ,   735 ,   989 ,   1623    ,   5321    ,   12603   ,0 };
            const std::uint32_t dim1251JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   11  ,   1   ,   55  ,   121 ,   221 ,   383 ,   969 ,   777 ,   3419    ,   2621    ,   1651    ,0 };
            const std::uint32_t dim1252JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   7   ,   21  ,   9   ,   95  ,   239 ,   221 ,   577 ,   1479    ,   1649    ,   6765    ,   5601    ,0 };
            const std::uint32_t dim1253JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   15  ,   29  ,   43  ,   49  ,   71  ,   255 ,   1011    ,   115 ,   1859    ,   7369    ,   16233   ,0 };
            const std::uint32_t dim1254JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   1   ,   13  ,   9   ,   21  ,   193 ,   255 ,   315 ,   1295    ,   1413    ,   6851    ,   4395    ,0 };
            const std::uint32_t dim1255JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   13  ,   21  ,   11  ,   75  ,   87  ,   453 ,   39  ,   503 ,   2937    ,   5089    ,   14211   ,0 };
            const std::uint32_t dim1256JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   13  ,   1   ,   17  ,   121 ,   153 ,   89  ,   113 ,   1969    ,   65  ,   4907    ,   10165   ,0 };
            const std::uint32_t dim1257JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   1   ,   17  ,   49  ,   75  ,   25  ,   147 ,   357 ,   617 ,   3245    ,   7313    ,   753 ,0 };
            const std::uint32_t dim1258JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   15  ,   25  ,   3   ,   71  ,   97  ,   463 ,   515 ,   989 ,   69  ,   687 ,   15151   ,0 };
            const std::uint32_t dim1259JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   3   ,   25  ,   61  ,   95  ,   219 ,   429 ,   143 ,   565 ,   463 ,   4165    ,   2619    ,0 };
            const std::uint32_t dim1260JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   13  ,   3   ,   45  ,   11  ,   59  ,   237 ,   387 ,   109 ,   253 ,   651 ,   13061   ,0 };
            const std::uint32_t dim1261JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   1   ,   25  ,   41  ,   111 ,   179 ,   321 ,   139 ,   453 ,   1061    ,   6395    ,   6391    ,0 };
            const std::uint32_t dim1262JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   1   ,   5   ,   11  ,   73  ,   131 ,   469 ,   839 ,   459 ,   2237    ,   2481    ,   10087   ,0 };
            const std::uint32_t dim1263JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   3   ,   13  ,   55  ,   75  ,   111 ,   411 ,   1007    ,   1303    ,   1613    ,   2449    ,   11337   ,0 };
            const std::uint32_t dim1264JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   1   ,   11  ,   39  ,   3   ,   193 ,   113 ,   927 ,   1345    ,   2747    ,   4951    ,   10543   ,0 };
            const std::uint32_t dim1265JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   15  ,   23  ,   39  ,   47  ,   115 ,   129 ,   51  ,   921 ,   1021    ,   6907    ,   8139    ,0 };
            const std::uint32_t dim1266JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   7   ,   31  ,   13  ,   75  ,   79  ,   331 ,   773 ,   1147    ,   335 ,   1729    ,   4015    ,0 };
            const std::uint32_t dim1267JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   7   ,   1   ,   47  ,   15  ,   183 ,   243 ,   525 ,   1515    ,   3209    ,   6597    ,   1895    ,0 };
            const std::uint32_t dim1268JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   3   ,   7   ,   59  ,   115 ,   223 ,   161 ,   181 ,   533 ,   1085    ,   3405    ,   2565    ,0 };
            const std::uint32_t dim1269JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   1   ,   9   ,   23  ,   57  ,   135 ,   113 ,   57  ,   143 ,   2949    ,   2703    ,   1813    ,0 };
            const std::uint32_t dim1270JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   9   ,   25  ,   43  ,   103 ,   7   ,   167 ,   393 ,   1515    ,   2871    ,   5167    ,   9943    ,0 };
            const std::uint32_t dim1271JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   1   ,   25  ,   1   ,   61  ,   49  ,   137 ,   157 ,   693 ,   3615    ,   1655    ,   14975   ,0 };
            const std::uint32_t dim1272JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   11  ,   21  ,   41  ,   89  ,   7   ,   171 ,   49  ,   1021    ,   3227    ,   3989    ,   11739   ,0 };
            const std::uint32_t dim1273JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   5   ,   31  ,   49  ,   13  ,   109 ,   435 ,   99  ,   1435    ,   709 ,   4085    ,   1233    ,0 };
            const std::uint32_t dim1274JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   1   ,   1   ,   55  ,   5   ,   107 ,   435 ,   663 ,   441 ,   3503    ,   5313    ,   159 ,0 };
            const std::uint32_t dim1275JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   13  ,   19  ,   57  ,   17  ,   13  ,   25  ,   1021    ,   2005    ,   3445    ,   4263    ,   3185    ,0 };
            const std::uint32_t dim1276JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   7   ,   5   ,   5   ,   37  ,   99  ,   237 ,   563 ,   483 ,   1991    ,   7217    ,   5433    ,0 };
            const std::uint32_t dim1277JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   9   ,   13  ,   13  ,   123 ,   51  ,   31  ,   957 ,   1125    ,   2125    ,   2157    ,   11437   ,0 };
            const std::uint32_t dim1278JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   11  ,   5   ,   59  ,   53  ,   193 ,   337 ,   5   ,   1037    ,   1573    ,   1147    ,   7055    ,0 };
            const std::uint32_t dim1279JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   9   ,   27  ,   47  ,   53  ,   121 ,   421 ,   551 ,   23  ,   1603    ,   1815    ,   2741    ,0 };
            const std::uint32_t dim1280JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   13  ,   27  ,   7   ,   79  ,   255 ,   209 ,   441 ,   1761    ,   1755    ,   7077    ,   3581    ,0 };
            const std::uint32_t dim1281JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   13  ,   3   ,   43  ,   113 ,   227 ,   43  ,   387 ,   1255    ,   1117    ,   6849    ,   11715   ,0 };
            const std::uint32_t dim1282JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   13  ,   15  ,   19  ,   59  ,   159 ,   265 ,   283 ,   615 ,   3745    ,   539 ,   15195   ,0 };
            const std::uint32_t dim1283JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   3   ,   7   ,   21  ,   29  ,   135 ,   203 ,   887 ,   549 ,   85  ,   8093    ,   12527   ,0 };
            const std::uint32_t dim1284JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   11  ,   5   ,   35  ,   41  ,   61  ,   273 ,   187 ,   1655    ,   2449    ,   2173    ,   14737   ,0 };
            const std::uint32_t dim1285JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   9   ,   29  ,   49  ,   11  ,   33  ,   477 ,   671 ,   1455    ,   2577    ,   5239    ,   5025    ,0 };
            const std::uint32_t dim1286JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   5   ,   23  ,   15  ,   67  ,   73  ,   73  ,   45  ,   1727    ,   645 ,   2623    ,   10859   ,0 };
            const std::uint32_t dim1287JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   15  ,   29  ,   37  ,   45  ,   183 ,   97  ,   297 ,   593 ,   833 ,   5833    ,   4777    ,0 };
            const std::uint32_t dim1288JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   5   ,   27  ,   21  ,   5   ,   253 ,   243 ,   993 ,   1701    ,   1695    ,   4037    ,   1891    ,0 };
            const std::uint32_t dim1289JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   1   ,   17  ,   37  ,   123 ,   21  ,   95  ,   533 ,   111 ,   2605    ,   7011    ,   7957    ,0 };
            const std::uint32_t dim1290JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   1   ,   5   ,   43  ,   11  ,   143 ,   457 ,   607 ,   469 ,   1479    ,   6181    ,   7579    ,0 };
            const std::uint32_t dim1291JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   15  ,   5   ,   59  ,   105 ,   111 ,   47  ,   53  ,   215 ,   1601    ,   8057    ,   4233    ,0 };
            const std::uint32_t dim1292JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   15  ,   7   ,   5   ,   17  ,   157 ,   47  ,   541 ,   1487    ,   2623    ,   1705    ,   5565    ,0 };
            const std::uint32_t dim1293JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   7   ,   21  ,   27  ,   63  ,   117 ,   323 ,   379 ,   1407    ,   4043    ,   3763    ,   10367   ,0 };
            const std::uint32_t dim1294JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   7   ,   27  ,   11  ,   35  ,   81  ,   447 ,   279 ,   811 ,   1355    ,   4185    ,   8281    ,0 };
            const std::uint32_t dim1295JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   15  ,   19  ,   41  ,   111 ,   225 ,   133 ,   79  ,   347 ,   3595    ,   7863    ,   5239    ,0 };
            const std::uint32_t dim1296JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   5   ,   17  ,   41  ,   77  ,   125 ,   221 ,   93  ,   551 ,   1263    ,   1973    ,   12081   ,0 };
            const std::uint32_t dim1297JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   3   ,   17  ,   55  ,   9   ,   149 ,   203 ,   217 ,   1235    ,   1905    ,   6139    ,   7223    ,0 };
            const std::uint32_t dim1298JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   9   ,   1   ,   3   ,   17  ,   5   ,   157 ,   739 ,   691 ,   1471    ,   709 ,   1355    ,0 };
            const std::uint32_t dim1299JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   9   ,   3   ,   13  ,   87  ,   153 ,   49  ,   391 ,   47  ,   1703    ,   1913    ,   12885   ,0 };
            const std::uint32_t dim1300JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   3   ,   19  ,   49  ,   91  ,   47  ,   263 ,   287 ,   1885    ,   3137    ,   3709    ,   8895    ,0 };
            const std::uint32_t dim1301JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   5   ,   19  ,   55  ,   59  ,   63  ,   229 ,   705 ,   1791    ,   1789    ,   4083    ,   11827   ,0 };
            const std::uint32_t dim1302JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   13  ,   21  ,   31  ,   127 ,   143 ,   57  ,   933 ,   125 ,   813 ,   6121    ,   5883    ,0 };
            const std::uint32_t dim1303JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   7   ,   7   ,   45  ,   39  ,   137 ,   219 ,   249 ,   791 ,   751 ,   4877    ,   6935    ,0 };
            const std::uint32_t dim1304JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   5   ,   31  ,   21  ,   11  ,   191 ,   399 ,   339 ,   815 ,   2459    ,   7621    ,   1279    ,0 };
            const std::uint32_t dim1305JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   13  ,   11  ,   49  ,   111 ,   101 ,   367 ,   645 ,   99  ,   1759    ,   2275    ,   8289    ,0 };
            const std::uint32_t dim1306JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   9   ,   15  ,   23  ,   17  ,   93  ,   339 ,   705 ,   1487    ,   3325    ,   6585    ,   13281   ,0 };
            const std::uint32_t dim1307JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   1   ,   17  ,   25  ,   69  ,   115 ,   339 ,   241 ,   777 ,   1585    ,   2565    ,   14843   ,0 };
            const std::uint32_t dim1308JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   7   ,   5   ,   45  ,   99  ,   161 ,   505 ,   511 ,   591 ,   2109    ,   5885    ,   12547   ,0 };
            const std::uint32_t dim1309JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   11  ,   13  ,   45  ,   87  ,   105 ,   387 ,   339 ,   1079    ,   705 ,   2385    ,   9375    ,0 };
            const std::uint32_t dim1310JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   1   ,   5   ,   19  ,   111 ,   155 ,   147 ,   897 ,   1879    ,   243 ,   3745    ,   2309    ,0 };
            const std::uint32_t dim1311JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   1   ,   1   ,   1   ,   123 ,   153 ,   409 ,   101 ,   105 ,   1713    ,   5161    ,   8915    ,0 };
            const std::uint32_t dim1312JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   11  ,   17  ,   5   ,   53  ,   145 ,   243 ,   811 ,   1413    ,   3735    ,   6857    ,   1151    ,0 };
            const std::uint32_t dim1313JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   13  ,   9   ,   35  ,   127 ,   245 ,   479 ,   691 ,   281 ,   845 ,   4017    ,   14011   ,0 };
            const std::uint32_t dim1314JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   15  ,   3   ,   27  ,   11  ,   231 ,   47  ,   1023    ,   1785    ,   4039    ,   137 ,   3429    ,0 };
            const std::uint32_t dim1315JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   5   ,   19  ,   45  ,   7   ,   251 ,   191 ,   387 ,   1853    ,   3851    ,   6237    ,   6475    ,0 };
            const std::uint32_t dim1316JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   15  ,   27  ,   19  ,   71  ,   13  ,   65  ,   679 ,   281 ,   2141    ,   1211    ,   4063    ,0 };
            const std::uint32_t dim1317JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   15  ,   7   ,   31  ,   73  ,   103 ,   393 ,   177 ,   1929    ,   809 ,   3389    ,   5673    ,0 };
            const std::uint32_t dim1318JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   7   ,   1   ,   45  ,   35  ,   247 ,   485 ,   25  ,   1079    ,   4019    ,   6101    ,   4715    ,0 };
            const std::uint32_t dim1319JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   7   ,   27  ,   13  ,   121 ,   177 ,   377 ,   585 ,   1503    ,   1249    ,   715 ,   309 ,0 };
            const std::uint32_t dim1320JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   7   ,   23  ,   19  ,   37  ,   19  ,   243 ,   261 ,   139 ,   1261    ,   3775    ,   10299   ,0 };
            const std::uint32_t dim1321JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   11  ,   23  ,   1   ,   123 ,   225 ,   497 ,   131 ,   1863    ,   4061    ,   1247    ,   12511   ,0 };
            const std::uint32_t dim1322JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   15  ,   5   ,   25  ,   59  ,   213 ,   157 ,   697 ,   671 ,   1431    ,   2891    ,   6881    ,0 };
            const std::uint32_t dim1323JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   9   ,   1   ,   33  ,   67  ,   121 ,   165 ,   867 ,   393 ,   1439    ,   1255    ,   11839   ,0 };
            const std::uint32_t dim1324JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   11  ,   23  ,   43  ,   11  ,   23  ,   507 ,   585 ,   277 ,   1077    ,   2697    ,   4901    ,0 };
            const std::uint32_t dim1325JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   15  ,   17  ,   35  ,   75  ,   177 ,   373 ,   113 ,   401 ,   1999    ,   1595    ,   10635   ,0 };
            const std::uint32_t dim1326JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   11  ,   31  ,   49  ,   65  ,   225 ,   217 ,   783 ,   787 ,   1421    ,   5701    ,   2185    ,0 };
            const std::uint32_t dim1327JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   15  ,   13  ,   45  ,   111 ,   23  ,   89  ,   263 ,   699 ,   4037    ,   6937    ,   6265    ,0 };
            const std::uint32_t dim1328JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   1   ,   15  ,   51  ,   49  ,   9   ,   221 ,   85  ,   1983    ,   2865    ,   2841    ,   3105    ,0 };
            const std::uint32_t dim1329JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   9   ,   5   ,   35  ,   75  ,   213 ,   177 ,   131 ,   1227    ,   4069    ,   5035    ,   4371    ,0 };
            const std::uint32_t dim1330JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   5   ,   1   ,   33  ,   75  ,   125 ,   5   ,   283 ,   667 ,   1521    ,   3267    ,   9641    ,0 };
            const std::uint32_t dim1331JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   11  ,   11  ,   49  ,   75  ,   125 ,   349 ,   887 ,   269 ,   2295    ,   4049    ,   1217    ,0 };
            const std::uint32_t dim1332JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   13  ,   17  ,   23  ,   19  ,   141 ,   213 ,   33  ,   475 ,   2543    ,   3617    ,   5791    ,0 };
            const std::uint32_t dim1333JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   11  ,   3   ,   39  ,   95  ,   139 ,   277 ,   109 ,   601 ,   2011    ,   2459    ,   5915    ,0 };
            const std::uint32_t dim1334JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   5   ,   27  ,   61  ,   35  ,   221 ,   329 ,   411 ,   1811    ,   3397    ,   1545    ,   10615   ,0 };
            const std::uint32_t dim1335JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   3   ,   3   ,   55  ,   71  ,   187 ,   371 ,   223 ,   1711    ,   3279    ,   5541    ,   4203    ,0 };
            const std::uint32_t dim1336JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   3   ,   27  ,   61  ,   23  ,   143 ,   475 ,   693 ,   1717    ,   353 ,   4381    ,   11355   ,0 };
            const std::uint32_t dim1337JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   13  ,   9   ,   23  ,   109 ,   11  ,   483 ,   1005    ,   1709    ,   2883    ,   5021    ,   10079   ,0 };
            const std::uint32_t dim1338JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   9   ,   25  ,   19  ,   79  ,   169 ,   433 ,   177 ,   1071    ,   3413    ,   2071    ,   3565    ,0 };
            const std::uint32_t dim1339JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   7   ,   7   ,   47  ,   105 ,   225 ,   153 ,   949 ,   9   ,   2383    ,   3947    ,   2711    ,0 };
            const std::uint32_t dim1340JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   9   ,   1   ,   17  ,   87  ,   159 ,   107 ,   41  ,   1459    ,   2133    ,   6261    ,   15637   ,0 };
            const std::uint32_t dim1341JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   3   ,   1   ,   7   ,   45  ,   255 ,   377 ,   811 ,   1911    ,   2727    ,   7223    ,   3825    ,0 };
            const std::uint32_t dim1342JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   13  ,   13  ,   13  ,   5   ,   59  ,   421 ,   585 ,   1651    ,   55  ,   2877    ,   11643   ,0 };
            const std::uint32_t dim1343JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   11  ,   15  ,   57  ,   1   ,   173 ,   189 ,   485 ,   1881    ,   3449    ,   1831    ,   2501    ,0 };
            const std::uint32_t dim1344JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   7   ,   21  ,   29  ,   49  ,   255 ,   313 ,   137 ,   51  ,   2281    ,   973 ,   16053   ,0 };
            const std::uint32_t dim1345JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   11  ,   23  ,   61  ,   99  ,   77  ,   399 ,   649 ,   1567    ,   1701    ,   4747    ,   1301    ,0 };
            const std::uint32_t dim1346JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   3   ,   11  ,   57  ,   45  ,   169 ,   247 ,   73  ,   1685    ,   341 ,   6791    ,   2833    ,0 };
            const std::uint32_t dim1347JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   13  ,   9   ,   5   ,   17  ,   209 ,   329 ,   379 ,   1787    ,   737 ,   7271    ,   7357    ,0 };
            const std::uint32_t dim1348JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   9   ,   13  ,   7   ,   97  ,   165 ,   99  ,   599 ,   471 ,   2945    ,   3125    ,   10413   ,0 };
            const std::uint32_t dim1349JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   11  ,   31  ,   29  ,   45  ,   3   ,   457 ,   673 ,   589 ,   2521    ,   5655    ,   13973   ,0 };
            const std::uint32_t dim1350JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   1   ,   15  ,   15  ,   61  ,   77  ,   321 ,   317 ,   993 ,   1101    ,   5885    ,   5105    ,0 };
            const std::uint32_t dim1351JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   5   ,   7   ,   45  ,   111 ,   129 ,   407 ,   117 ,   93  ,   2399    ,   1049    ,   12435   ,0 };
            const std::uint32_t dim1352JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   3   ,   11  ,   29  ,   103 ,   189 ,   29  ,   899 ,   1141    ,   1799    ,   4439    ,   2907    ,0 };
            const std::uint32_t dim1353JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   5   ,   3   ,   39  ,   25  ,   255 ,   97  ,   1015    ,   727 ,   377 ,   8015    ,   12617   ,0 };
            const std::uint32_t dim1354JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   11  ,   29  ,   23  ,   103 ,   51  ,   95  ,   333 ,   171 ,   3019    ,   1373    ,   13379   ,0 };
            const std::uint32_t dim1355JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   9   ,   21  ,   49  ,   57  ,   157 ,   337 ,   141 ,   307 ,   2333    ,   1857    ,   8739    ,0 };
            const std::uint32_t dim1356JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   11  ,   9   ,   35  ,   33  ,   93  ,   211 ,   969 ,   1093    ,   4053    ,   1313    ,   12771   ,0 };
            const std::uint32_t dim1357JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   9   ,   27  ,   7   ,   77  ,   65  ,   425 ,   603 ,   261 ,   2321    ,   579 ,   1249    ,0 };
            const std::uint32_t dim1358JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   13  ,   29  ,   39  ,   21  ,   243 ,   115 ,   201 ,   749 ,   3049    ,   3113    ,   1485    ,0 };
            const std::uint32_t dim1359JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   15  ,   23  ,   53  ,   27  ,   189 ,   193 ,   281 ,   149 ,   2205    ,   6149    ,   2669    ,0 };
            const std::uint32_t dim1360JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   13  ,   9   ,   13  ,   65  ,   37  ,   161 ,   59  ,   1691    ,   435 ,   6077    ,   14827   ,0 };
            const std::uint32_t dim1361JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   15  ,   5   ,   35  ,   41  ,   239 ,   177 ,   265 ,   389 ,   1829    ,   1229    ,   14351   ,0 };
            const std::uint32_t dim1362JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   3   ,   7   ,   27  ,   61  ,   107 ,   171 ,   411 ,   685 ,   455 ,   5175    ,   4981    ,0 };
            const std::uint32_t dim1363JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   7   ,   13  ,   23  ,   107 ,   63  ,   71  ,   755 ,   535 ,   1819    ,   1545    ,   2075    ,0 };
            const std::uint32_t dim1364JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   15  ,   1   ,   27  ,   61  ,   247 ,   333 ,   549 ,   981 ,   3201    ,   919 ,   1505    ,0 };
            const std::uint32_t dim1365JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   5   ,   29  ,   27  ,   93  ,   147 ,   105 ,   83  ,   209 ,   61  ,   3045    ,   4639    ,0 };
            const std::uint32_t dim1366JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   7   ,   25  ,   35  ,   77  ,   59  ,   157 ,   993 ,   325 ,   3085    ,   671 ,   3573    ,0 };
            const std::uint32_t dim1367JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   15  ,   15  ,   45  ,   31  ,   93  ,   367 ,   747 ,   969 ,   3443    ,   3825    ,   2997    ,0 };
            const std::uint32_t dim1368JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   5   ,   27  ,   21  ,   23  ,   63  ,   271 ,   515 ,   261 ,   1947    ,   6257    ,   12861   ,0 };
            const std::uint32_t dim1369JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   7   ,   27  ,   51  ,   31  ,   229 ,   225 ,   283 ,   947 ,   759 ,   5431    ,   2161    ,0 };
            const std::uint32_t dim1370JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   13  ,   7   ,   39  ,   5   ,   223 ,   55  ,   999 ,   697 ,   3383    ,   1605    ,   15315   ,0 };
            const std::uint32_t dim1371JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   3   ,   29  ,   13  ,   103 ,   215 ,   73  ,   715 ,   1117    ,   3399    ,   1867    ,   8049    ,0 };
            const std::uint32_t dim1372JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   3   ,   1   ,   33  ,   121 ,   135 ,   105 ,   335 ,   105 ,   815 ,   1601    ,   15785   ,0 };
            const std::uint32_t dim1373JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   13  ,   13  ,   27  ,   39  ,   119 ,   271 ,   75  ,   1531    ,   649 ,   8035    ,   5533    ,0 };
            const std::uint32_t dim1374JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   3   ,   9   ,   47  ,   109 ,   85  ,   135 ,   553 ,   1091    ,   3077    ,   5527    ,   15225   ,0 };
            const std::uint32_t dim1375JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   5   ,   31  ,   11  ,   127 ,   197 ,   257 ,   281 ,   1939    ,   3711    ,   2871    ,   11953   ,0 };
            const std::uint32_t dim1376JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   15  ,   21  ,   51  ,   57  ,   159 ,   445 ,   521 ,   27  ,   1313    ,   6031    ,   2891    ,0 };
            const std::uint32_t dim1377JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   15  ,   21  ,   57  ,   53  ,   29  ,   39  ,   547 ,   1995    ,   3605    ,   3899    ,   1199    ,0 };
            const std::uint32_t dim1378JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   3   ,   1   ,   59  ,   69  ,   21  ,   383 ,   743 ,   87  ,   3369    ,   2309    ,   9651    ,0 };
            const std::uint32_t dim1379JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   13  ,   3   ,   9   ,   41  ,   77  ,   201 ,   331 ,   1007    ,   1503    ,   5771    ,   567 ,0 };
            const std::uint32_t dim1380JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   15  ,   19  ,   19  ,   61  ,   221 ,   257 ,   903 ,   83  ,   1923    ,   6453    ,   11275   ,0 };
            const std::uint32_t dim1381JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   13  ,   21  ,   21  ,   101 ,   109 ,   419 ,   409 ,   125 ,   3337    ,   5763    ,   4945    ,0 };
            const std::uint32_t dim1382JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   11  ,   27  ,   21  ,   39  ,   63  ,   475 ,   285 ,   917 ,   4017    ,   1491    ,   9479    ,0 };
            const std::uint32_t dim1383JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   1   ,   23  ,   59  ,   119 ,   89  ,   309 ,   567 ,   1781    ,   2369    ,   4311    ,   16033   ,0 };
            const std::uint32_t dim1384JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   3   ,   13  ,   51  ,   69  ,   71  ,   89  ,   1013    ,   329 ,   69  ,   1107    ,   14509   ,0 };
            const std::uint32_t dim1385JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   7   ,   23  ,   39  ,   9   ,   137 ,   65  ,   83  ,   1001    ,   271 ,   2127    ,   9715    ,0 };
            const std::uint32_t dim1386JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   9   ,   13  ,   1   ,   67  ,   233 ,   333 ,   365 ,   1717    ,   77  ,   7173    ,   1271    ,0 };
            const std::uint32_t dim1387JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   7   ,   15  ,   3   ,   115 ,   237 ,   467 ,   827 ,   389 ,   1901    ,   6767    ,   7809    ,0 };
            const std::uint32_t dim1388JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   15  ,   23  ,   27  ,   117 ,   99  ,   49  ,   863 ,   1775    ,   1729    ,   8069    ,   9917    ,0 };
            const std::uint32_t dim1389JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   11  ,   23  ,   47  ,   75  ,   91  ,   47  ,   99  ,   1187    ,   1911    ,   2453    ,   5055    ,0 };
            const std::uint32_t dim1390JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   11  ,   15  ,   51  ,   43  ,   133 ,   175 ,   647 ,   1053    ,   439 ,   1933    ,   7339    ,0 };
            const std::uint32_t dim1391JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   13  ,   5   ,   37  ,   105 ,   243 ,   467 ,   255 ,   715 ,   1023    ,   4331    ,   8943    ,0 };
            const std::uint32_t dim1392JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   15  ,   15  ,   55  ,   59  ,   111 ,   351 ,   345 ,   1517    ,   3009    ,   4149    ,   8511    ,0 };
            const std::uint32_t dim1393JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   5   ,   3   ,   55  ,   123 ,   61  ,   405 ,   719 ,   245 ,   2745    ,   7471    ,   2205    ,0 };
            const std::uint32_t dim1394JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   9   ,   19  ,   25  ,   43  ,   105 ,   215 ,   117 ,   563 ,   513 ,   4609    ,   13307   ,0 };
            const std::uint32_t dim1395JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   5   ,   21  ,   27  ,   107 ,   131 ,   329 ,   519 ,   369 ,   2523    ,   4099    ,   13943   ,0 };
            const std::uint32_t dim1396JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   13  ,   27  ,   15  ,   25  ,   63  ,   5   ,   513 ,   1641    ,   3955    ,   4233    ,   12263   ,0 };
            const std::uint32_t dim1397JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   5   ,   3   ,   51  ,   49  ,   49  ,   197 ,   919 ,   281 ,   3713    ,   2179    ,   4573    ,0 };
            const std::uint32_t dim1398JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   5   ,   25  ,   15  ,   49  ,   159 ,   53  ,   609 ,   573 ,   1533    ,   4589    ,   10593   ,0 };
            const std::uint32_t dim1399JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   15  ,   7   ,   21  ,   61  ,   129 ,   53  ,   95  ,   1107    ,   57  ,   2559    ,   11977   ,0 };
            const std::uint32_t dim1400JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   5   ,   5   ,   5   ,   75  ,   153 ,   359 ,   345 ,   1739    ,   2047    ,   6355    ,   5801    ,0 };
            const std::uint32_t dim1401JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   13  ,   17  ,   5   ,   39  ,   209 ,   399 ,   127 ,   1215    ,   2377    ,   7707    ,   5191    ,0 };
            const std::uint32_t dim1402JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   3   ,   25  ,   31  ,   33  ,   93  ,   1   ,   229 ,   1379    ,   1587    ,   2245    ,   16041   ,0 };
            const std::uint32_t dim1403JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   13  ,   25  ,   51  ,   5   ,   1   ,   237 ,   471 ,   637 ,   3205    ,   4629    ,   15929   ,0 };
            const std::uint32_t dim1404JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   11  ,   27  ,   57  ,   45  ,   141 ,   167 ,   949 ,   1839    ,   289 ,   2637    ,   2041    ,0 };
            const std::uint32_t dim1405JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   7   ,   9   ,   57  ,   69  ,   93  ,   301 ,   805 ,   1265    ,   3415    ,   2395    ,   2949    ,0 };
            const std::uint32_t dim1406JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   15  ,   9   ,   61  ,   17  ,   185 ,   201 ,   743 ,   1903    ,   1161    ,   1693    ,   15125   ,0 };
            const std::uint32_t dim1407JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   3   ,   21  ,   47  ,   125 ,   117 ,   213 ,   761 ,   1357    ,   2455    ,   7065    ,   7335    ,0 };
            const std::uint32_t dim1408JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   7   ,   23  ,   15  ,   39  ,   17  ,   373 ,   777 ,   761 ,   3853    ,   3607    ,   2119    ,0 };
            const std::uint32_t dim1409JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   1   ,   31  ,   9   ,   45  ,   109 ,   209 ,   797 ,   777 ,   2381    ,   5047    ,   12453   ,0 };
            const std::uint32_t dim1410JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   1   ,   1   ,   9   ,   13  ,   171 ,   223 ,   987 ,   1815    ,   1953    ,   4439    ,   3973    ,0 };
            const std::uint32_t dim1411JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   9   ,   19  ,   11  ,   37  ,   87  ,   117 ,   399 ,   705 ,   2839    ,   3699    ,   13249   ,0 };
            const std::uint32_t dim1412JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   1   ,   21  ,   45  ,   25  ,   41  ,   133 ,   721 ,   289 ,   727 ,   7835    ,   9811    ,0 };
            const std::uint32_t dim1413JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   9   ,   23  ,   7   ,   75  ,   233 ,   113 ,   945 ,   1447    ,   4031    ,   6791    ,   6285    ,0 };
            const std::uint32_t dim1414JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   9   ,   3   ,   1   ,   127 ,   139 ,   391 ,   745 ,   807 ,   3229    ,   1809    ,   7587    ,0 };
            const std::uint32_t dim1415JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   3   ,   29  ,   47  ,   99  ,   115 ,   37  ,   487 ,   1897    ,   2433    ,   4925    ,   9747    ,0 };
            const std::uint32_t dim1416JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   15  ,   23  ,   25  ,   95  ,   165 ,   257 ,   67  ,   1445    ,   4055    ,   3761    ,   10411   ,0 };
            const std::uint32_t dim1417JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   11  ,   5   ,   27  ,   77  ,   197 ,   9   ,   679 ,   1259    ,   3289    ,   621 ,   2733    ,0 };
            const std::uint32_t dim1418JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   9   ,   27  ,   51  ,   57  ,   189 ,   511 ,   633 ,   431 ,   43  ,   2613    ,   5863    ,0 };
            const std::uint32_t dim1419JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   11  ,   29  ,   53  ,   79  ,   237 ,   15  ,   377 ,   45  ,   347 ,   5733    ,   3531    ,0 };
            const std::uint32_t dim1420JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   1   ,   25  ,   7   ,   87  ,   211 ,   429 ,   745 ,   673 ,   3967    ,   2059    ,   785 ,0 };
            const std::uint32_t dim1421JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   5   ,   21  ,   31  ,   7   ,   43  ,   381 ,   635 ,   35  ,   1247    ,   8061    ,   3907    ,0 };
            const std::uint32_t dim1422JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   9   ,   11  ,   39  ,   79  ,   9   ,   395 ,   611 ,   1087    ,   2837    ,   6979    ,   7651    ,0 };
            const std::uint32_t dim1423JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   13  ,   11  ,   37  ,   35  ,   61  ,   373 ,   1001    ,   1849    ,   2169    ,   903 ,   10993   ,0 };
            const std::uint32_t dim1424JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   3   ,   29  ,   3   ,   43  ,   155 ,   403 ,   597 ,   1437    ,   4031    ,   7169    ,   15333   ,0 };
            const std::uint32_t dim1425JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   1   ,   17  ,   29  ,   57  ,   245 ,   505 ,   915 ,   933 ,   1313    ,   7295    ,   12105   ,0 };
            const std::uint32_t dim1426JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   9   ,   29  ,   13  ,   49  ,   89  ,   377 ,   131 ,   31  ,   1869    ,   1717    ,   7679    ,0 };
            const std::uint32_t dim1427JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   7   ,   27  ,   43  ,   1   ,   107 ,   167 ,   851 ,   743 ,   2837    ,   6705    ,   2913    ,0 };
            const std::uint32_t dim1428JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   13  ,   5   ,   27  ,   77  ,   91  ,   305 ,   941 ,   1293    ,   2343    ,   5397    ,   6487    ,0 };
            const std::uint32_t dim1429JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   5   ,   11  ,   29  ,   25  ,   233 ,   391 ,   221 ,   1285    ,   3995    ,   2713    ,   9125    ,0 };
            const std::uint32_t dim1430JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   3   ,   11  ,   47  ,   77  ,   31  ,   233 ,   775 ,   1399    ,   1519    ,   3427    ,   10027   ,0 };
            const std::uint32_t dim1431JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   3   ,   5   ,   7   ,   37  ,   111 ,   265 ,   541 ,   77  ,   3327    ,   8115    ,   5541    ,0 };
            const std::uint32_t dim1432JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   5   ,   25  ,   27  ,   91  ,   185 ,   447 ,   225 ,   615 ,   2141    ,   2813    ,   9509    ,0 };
            const std::uint32_t dim1433JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   5   ,   15  ,   21  ,   107 ,   61  ,   259 ,   651 ,   1401    ,   3733    ,   6255    ,   5995    ,0 };
            const std::uint32_t dim1434JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   11  ,   21  ,   5   ,   121 ,   229 ,   497 ,   267 ,   1077    ,   3835    ,   4619    ,   8791    ,0 };
            const std::uint32_t dim1435JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   3   ,   19  ,   59  ,   85  ,   115 ,   19  ,   69  ,   1937    ,   711 ,   7911    ,   2615    ,0 };
            const std::uint32_t dim1436JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   11  ,   1   ,   9   ,   117 ,   229 ,   307 ,   355 ,   1635    ,   863 ,   4931    ,   5997    ,0 };
            const std::uint32_t dim1437JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   11  ,   21  ,   17  ,   119 ,   163 ,   297 ,   641 ,   291 ,   2287    ,   4611    ,   4419    ,0 };
            const std::uint32_t dim1438JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   7   ,   13  ,   59  ,   53  ,   17  ,   321 ,   263 ,   1929    ,   3277    ,   6209    ,   2649    ,0 };
            const std::uint32_t dim1439JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   13  ,   3   ,   35  ,   35  ,   249 ,   359 ,   479 ,   1067    ,   2507    ,   4809    ,   7427    ,0 };
            const std::uint32_t dim1440JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   1   ,   27  ,   57  ,   101 ,   47  ,   383 ,   937 ,   969 ,   307 ,   7617    ,   9579    ,0 };
            const std::uint32_t dim1441JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   13  ,   27  ,   61  ,   39  ,   177 ,   413 ,   435 ,   1529    ,   2773    ,   2267    ,   12597   ,0 };
            const std::uint32_t dim1442JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   5   ,   25  ,   61  ,   57  ,   175 ,   407 ,   341 ,   1979    ,   2237    ,   3557    ,   6841    ,0 };
            const std::uint32_t dim1443JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   5   ,   11  ,   23  ,   97  ,   247 ,   187 ,   555 ,   1603    ,   1871    ,   7427    ,   10605   ,0 };
            const std::uint32_t dim1444JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   15  ,   7   ,   21  ,   23  ,   165 ,   235 ,   937 ,   739 ,   2579    ,   6621    ,   12661   ,0 };
            const std::uint32_t dim1445JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   1   ,   13  ,   47  ,   103 ,   107 ,   87  ,   941 ,   563 ,   1007    ,   7483    ,   11721   ,0 };
            const std::uint32_t dim1446JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   15  ,   29  ,   63  ,   55  ,   215 ,   95  ,   991 ,   1017    ,   921 ,   8113    ,   11747   ,0 };
            const std::uint32_t dim1447JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   15  ,   3   ,   25  ,   79  ,   5   ,   401 ,   473 ,   125 ,   2135    ,   6443    ,   10773   ,0 };
            const std::uint32_t dim1448JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   9   ,   31  ,   21  ,   71  ,   185 ,   75  ,   43  ,   1131    ,   3885    ,   3879    ,   2695    ,0 };
            const std::uint32_t dim1449JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   13  ,   13  ,   41  ,   117 ,   109 ,   429 ,   473 ,   35  ,   123 ,   5545    ,   7015    ,0 };
            const std::uint32_t dim1450JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   13  ,   21  ,   57  ,   55  ,   241 ,   107 ,   689 ,   707 ,   45  ,   8175    ,   15185   ,0 };
            const std::uint32_t dim1451JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   7   ,   25  ,   5   ,   123 ,   173 ,   57  ,   517 ,   1605    ,   2355    ,   411 ,   14485   ,0 };
            const std::uint32_t dim1452JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   13  ,   11  ,   17  ,   95  ,   129 ,   9   ,   1013    ,   1683    ,   461 ,   697 ,   8089    ,0 };
            const std::uint32_t dim1453JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   3   ,   19  ,   49  ,   49  ,   247 ,   371 ,   175 ,   1803    ,   119 ,   365 ,   10281   ,0 };
            const std::uint32_t dim1454JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   15  ,   13  ,   57  ,   93  ,   245 ,   469 ,   933 ,   225 ,   2645    ,   6325    ,   9545    ,0 };
            const std::uint32_t dim1455JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   9   ,   11  ,   37  ,   1   ,   203 ,   227 ,   809 ,   2035    ,   99  ,   2693    ,   13591   ,0 };
            const std::uint32_t dim1456JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   3   ,   29  ,   7   ,   71  ,   7   ,   295 ,   203 ,   401 ,   461 ,   5351    ,   8223    ,0 };
            const std::uint32_t dim1457JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   1   ,   25  ,   31  ,   57  ,   35  ,   131 ,   411 ,   945 ,   1441    ,   4487    ,   2659    ,0 };
            const std::uint32_t dim1458JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   15  ,   15  ,   19  ,   89  ,   253 ,   141 ,   549 ,   751 ,   1267    ,   717 ,   7185    ,0 };
            const std::uint32_t dim1459JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   13  ,   1   ,   15  ,   61  ,   19  ,   331 ,   347 ,   1019    ,   1913    ,   6233    ,   8913    ,0 };
            const std::uint32_t dim1460JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   15  ,   7   ,   25  ,   59  ,   75  ,   455 ,   411 ,   325 ,   553 ,   5861    ,   915 ,0 };
            const std::uint32_t dim1461JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   5   ,   31  ,   49  ,   91  ,   107 ,   279 ,   405 ,   517 ,   55  ,   2121    ,   6971    ,0 };
            const std::uint32_t dim1462JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   7   ,   5   ,   39  ,   29  ,   205 ,   33  ,   827 ,   1593    ,   3503    ,   5461    ,   16147   ,0 };
            const std::uint32_t dim1463JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   13  ,   11  ,   13  ,   83  ,   99  ,   369 ,   283 ,   873 ,   1247    ,   6159    ,   15495   ,0 };
            const std::uint32_t dim1464JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   15  ,   25  ,   61  ,   71  ,   63  ,   333 ,   183 ,   1317    ,   3467    ,   5483    ,   11591   ,0 };
            const std::uint32_t dim1465JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   15  ,   27  ,   23  ,   1   ,   173 ,   407 ,   525 ,   1841    ,   347 ,   6103    ,   6449    ,0 };
            const std::uint32_t dim1466JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   3   ,   9   ,   45  ,   39  ,   215 ,   329 ,   457 ,   1341    ,   3037    ,   1631    ,   15335   ,0 };
            const std::uint32_t dim1467JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   3   ,   13  ,   53  ,   65  ,   177 ,   105 ,   21  ,   685 ,   3111    ,   7487    ,   1463    ,0 };
            const std::uint32_t dim1468JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   5   ,   5   ,   31  ,   69  ,   65  ,   381 ,   375 ,   221 ,   477 ,   3311    ,   12103   ,0 };
            const std::uint32_t dim1469JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   9   ,   25  ,   59  ,   57  ,   221 ,   293 ,   237 ,   429 ,   503 ,   6539    ,   14773   ,0 };
            const std::uint32_t dim1470JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   13  ,   9   ,   3   ,   47  ,   21  ,   115 ,   321 ,   389 ,   1631    ,   2715    ,   6607    ,0 };
            const std::uint32_t dim1471JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   15  ,   7   ,   31  ,   105 ,   5   ,   449 ,   195 ,   65  ,   3895    ,   7093    ,   3229    ,0 };
            const std::uint32_t dim1472JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   1   ,   1   ,   55  ,   119 ,   5   ,   39  ,   143 ,   905 ,   2813    ,   1723    ,   3705    ,0 };
            const std::uint32_t dim1473JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   3   ,   23  ,   47  ,   61  ,   239 ,   369 ,   485 ,   1857    ,   2105    ,   2681    ,   13723   ,0 };
            const std::uint32_t dim1474JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   5   ,   19  ,   5   ,   43  ,   155 ,   445 ,   597 ,   1201    ,   1625    ,   5273    ,   13569   ,0 };
            const std::uint32_t dim1475JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   9   ,   3   ,   63  ,   35  ,   103 ,   67  ,   259 ,   493 ,   2847    ,   1149    ,   8367    ,0 };
            const std::uint32_t dim1476JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   11  ,   19  ,   35  ,   15  ,   245 ,   59  ,   65  ,   75  ,   1297    ,   1637    ,   9081    ,0 };
            const std::uint32_t dim1477JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   11  ,   3   ,   23  ,   73  ,   163 ,   323 ,   857 ,   441 ,   399 ,   5447    ,   16365   ,0 };
            const std::uint32_t dim1478JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   7   ,   31  ,   55  ,   125 ,   255 ,   173 ,   203 ,   1537    ,   475 ,   2955    ,   12461   ,0 };
            const std::uint32_t dim1479JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   9   ,   27  ,   37  ,   69  ,   183 ,   319 ,   435 ,   807 ,   557 ,   7093    ,   2935    ,0 };
            const std::uint32_t dim1480JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   5   ,   23  ,   53  ,   105 ,   211 ,   49  ,   815 ,   97  ,   915 ,   7607    ,   8847    ,0 };
            const std::uint32_t dim1481JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   13  ,   13  ,   49  ,   43  ,   203 ,   293 ,   771 ,   1021    ,   535 ,   4655    ,   14727   ,0 };
            const std::uint32_t dim1482JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   5   ,   13  ,   49  ,   89  ,   75  ,   227 ,   821 ,   7   ,   2539    ,   7627    ,   6301    ,0 };
            const std::uint32_t dim1483JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   9   ,   5   ,   11  ,   35  ,   71  ,   187 ,   739 ,   1191    ,   2255    ,   2131    ,   13649   ,0 };
            const std::uint32_t dim1484JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   5   ,   5   ,   37  ,   105 ,   29  ,   453 ,   251 ,   1111    ,   2345    ,   6297    ,   14701   ,0 };
            const std::uint32_t dim1485JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   7   ,   31  ,   21  ,   5   ,   33  ,   245 ,   1007    ,   1981    ,   3775    ,   8169    ,   955 ,0 };
            const std::uint32_t dim1486JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   11  ,   11  ,   51  ,   45  ,   35  ,   351 ,   479 ,   1307    ,   3009    ,   7285    ,   5261    ,0 };
            const std::uint32_t dim1487JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   13  ,   5   ,   13  ,   119 ,   41  ,   175 ,   995 ,   1461    ,   2739    ,   7281    ,   7533    ,0 };
            const std::uint32_t dim1488JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   9   ,   7   ,   5   ,   7   ,   153 ,   233 ,   209 ,   1235    ,   3457    ,   3113    ,   13215   ,0 };
            const std::uint32_t dim1489JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   15  ,   9   ,   29  ,   41  ,   103 ,   389 ,   541 ,   1697    ,   893 ,   6507    ,   10805   ,0 };
            const std::uint32_t dim1490JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   3   ,   19  ,   11  ,   73  ,   73  ,   439 ,   985 ,   1215    ,   1481    ,   617 ,   5343    ,0 };
            const std::uint32_t dim1491JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   11  ,   7   ,   15  ,   81  ,   203 ,   41  ,   789 ,   283 ,   691 ,   3495    ,   12143   ,0 };
            const std::uint32_t dim1492JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   9   ,   21  ,   61  ,   101 ,   185 ,   193 ,   159 ,   13  ,   2571    ,   545 ,   3043    ,0 };
            const std::uint32_t dim1493JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   1   ,   11  ,   29  ,   107 ,   179 ,   69  ,   899 ,   1275    ,   1647    ,   1061    ,   12283   ,0 };
            const std::uint32_t dim1494JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   7   ,   15  ,   43  ,   3   ,   207 ,   75  ,   669 ,   1239    ,   1339    ,   571 ,   5483    ,0 };
            const std::uint32_t dim1495JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   1   ,   7   ,   23  ,   49  ,   183 ,   305 ,   309 ,   657 ,   1951    ,   6377    ,   4165    ,0 };
            const std::uint32_t dim1496JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   3   ,   5   ,   21  ,   51  ,   177 ,   101 ,   95  ,   1331    ,   357 ,   6777    ,   13199   ,0 };
            const std::uint32_t dim1497JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   3   ,   31  ,   3   ,   11  ,   179 ,   95  ,   219 ,   395 ,   603 ,   7397    ,   12045   ,0 };
            const std::uint32_t dim1498JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   1   ,   21  ,   35  ,   79  ,   255 ,   443 ,   123 ,   551 ,   1113    ,   8133    ,   11621   ,0 };
            const std::uint32_t dim1499JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   1   ,   11  ,   7   ,   125 ,   133 ,   429 ,   81  ,   91  ,   1135    ,   5165    ,   14953   ,0 };
            const std::uint32_t dim1500JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   9   ,   25  ,   17  ,   103 ,   39  ,   167 ,   459 ,   703 ,   759 ,   1771    ,   723 ,0 };
            const std::uint32_t dim1501JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   5   ,   7   ,   21  ,   113 ,   121 ,   97  ,   231 ,   59  ,   1679    ,   1409    ,   5045    ,0 };
            const std::uint32_t dim1502JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   9   ,   19  ,   17  ,   117 ,   225 ,   163 ,   183 ,   89  ,   2251    ,   4777    ,   14553   ,0 };
            const std::uint32_t dim1503JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   7   ,   7   ,   61  ,   25  ,   211 ,   65  ,   273 ,   1427    ,   585 ,   5907    ,   1031    ,0 };
            const std::uint32_t dim1504JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   3   ,   25  ,   27  ,   69  ,   113 ,   29  ,   67  ,   2025    ,   37  ,   7357    ,   14879   ,0 };
            const std::uint32_t dim1505JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   11  ,   23  ,   59  ,   107 ,   179 ,   187 ,   989 ,   1043    ,   409 ,   489 ,   3289    ,0 };
            const std::uint32_t dim1506JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   7   ,   5   ,   39  ,   79  ,   23  ,   443 ,   701 ,   789 ,   1723    ,   7595    ,   8003    ,0 };
            const std::uint32_t dim1507JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   11  ,   13  ,   25  ,   29  ,   167 ,   143 ,   735 ,   1623    ,   2005    ,   3731    ,   1413    ,0 };
            const std::uint32_t dim1508JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   13  ,   23  ,   19  ,   3   ,   143 ,   69  ,   331 ,   71  ,   3233    ,   4187    ,   13927   ,0 };
            const std::uint32_t dim1509JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   5   ,   23  ,   21  ,   121 ,   47  ,   291 ,   883 ,   43  ,   419 ,   297 ,   8385    ,0 };
            const std::uint32_t dim1510JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   5   ,   19  ,   63  ,   57  ,   127 ,   59  ,   539 ,   207 ,   3805    ,   4741    ,   12519   ,0 };
            const std::uint32_t dim1511JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   5   ,   5   ,   23  ,   117 ,   45  ,   501 ,   903 ,   1241    ,   3853    ,   989 ,   7997    ,0 };
            const std::uint32_t dim1512JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   5   ,   11  ,   27  ,   17  ,   21  ,   373 ,   755 ,   1149    ,   3443    ,   3489    ,   11701   ,0 };
            const std::uint32_t dim1513JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   7   ,   7   ,   55  ,   75  ,   29  ,   241 ,   707 ,   555 ,   1683    ,   1311    ,   14769   ,0 };
            const std::uint32_t dim1514JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   13  ,   19  ,   55  ,   87  ,   145 ,   27  ,   935 ,   519 ,   1083    ,   1115    ,   10963   ,0 };
            const std::uint32_t dim1515JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   13  ,   5   ,   11  ,   25  ,   215 ,   483 ,   817 ,   101 ,   981 ,   5125    ,   15257   ,0 };
            const std::uint32_t dim1516JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   11  ,   21  ,   59  ,   93  ,   55  ,   447 ,   5   ,   1225    ,   827 ,   1539    ,   4035    ,0 };
            const std::uint32_t dim1517JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   13  ,   3   ,   53  ,   5   ,   39  ,   475 ,   475 ,   905 ,   355 ,   6319    ,   415 ,0 };
            const std::uint32_t dim1518JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   9   ,   21  ,   49  ,   69  ,   109 ,   3   ,   441 ,   1533    ,   2359    ,   4025    ,   15949   ,0 };
            const std::uint32_t dim1519JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   13  ,   3   ,   59  ,   67  ,   147 ,   151 ,   27  ,   1039    ,   2331    ,   2839    ,   15939   ,0 };
            const std::uint32_t dim1520JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   9   ,   7   ,   17  ,   13  ,   153 ,   415 ,   147 ,   181 ,   3441    ,   7997    ,   3175    ,0 };
            const std::uint32_t dim1521JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   13  ,   9   ,   61  ,   123 ,   177 ,   497 ,   989 ,   525 ,   1819    ,   5963    ,   2051    ,0 };
            const std::uint32_t dim1522JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   1   ,   11  ,   13  ,   17  ,   147 ,   57  ,   367 ,   477 ,   1009    ,   4613    ,   16357   ,0 };
            const std::uint32_t dim1523JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   9   ,   27  ,   27  ,   29  ,   61  ,   499 ,   191 ,   43  ,   1109    ,   5805    ,   12799   ,0 };
            const std::uint32_t dim1524JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   9   ,   11  ,   61  ,   57  ,   139 ,   173 ,   725 ,   1879    ,   1861    ,   7123    ,   9505    ,0 };
            const std::uint32_t dim1525JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   5   ,   11  ,   1   ,   93  ,   179 ,   3   ,   893 ,   1917    ,   2293    ,   5105    ,   12093   ,0 };
            const std::uint32_t dim1526JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   9   ,   31  ,   45  ,   107 ,   19  ,   285 ,   81  ,   339 ,   3051    ,   1369    ,   10841   ,0 };
            const std::uint32_t dim1527JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   9   ,   27  ,   49  ,   19  ,   29  ,   155 ,   389 ,   1287    ,   3   ,   2311    ,   7561    ,0 };
            const std::uint32_t dim1528JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   9   ,   9   ,   1   ,   45  ,   171 ,   245 ,   897 ,   1881    ,   2683    ,   4185    ,   14049   ,0 };
            const std::uint32_t dim1529JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   15  ,   19  ,   37  ,   19  ,   227 ,   133 ,   573 ,   1897    ,   1231    ,   1649    ,   8481    ,0 };
            const std::uint32_t dim1530JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   15  ,   5   ,   19  ,   27  ,   85  ,   281 ,   471 ,   3   ,   2149    ,   4785    ,   12391   ,0 };
            const std::uint32_t dim1531JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   3   ,   17  ,   5   ,   127 ,   37  ,   299 ,   467 ,   1523    ,   3421    ,   4119    ,   11151   ,0 };
            const std::uint32_t dim1532JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   13  ,   11  ,   5   ,   15  ,   137 ,   459 ,   553 ,   785 ,   1149    ,   6107    ,   321 ,0 };
            const std::uint32_t dim1533JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   3   ,   7   ,   19  ,   85  ,   133 ,   7   ,   753 ,   65  ,   3341    ,   5859    ,   3829    ,0 };
            const std::uint32_t dim1534JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   11  ,   19  ,   13  ,   17  ,   191 ,   121 ,   895 ,   761 ,   2431    ,   5887    ,   10961   ,0 };
            const std::uint32_t dim1535JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   7   ,   1   ,   63  ,   47  ,   43  ,   119 ,   311 ,   935 ,   2299    ,   1509    ,   4821    ,0 };
            const std::uint32_t dim1536JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   7   ,   27  ,   51  ,   93  ,   195 ,   397 ,   155 ,   471 ,   2547    ,   8007    ,   15575   ,0 };
            const std::uint32_t dim1537JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   5   ,   25  ,   13  ,   125 ,   239 ,   93  ,   983 ,   293 ,   1317    ,   115 ,   6417    ,0 };
            const std::uint32_t dim1538JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   3   ,   9   ,   61  ,   93  ,   15  ,   495 ,   295 ,   1391    ,   2833    ,   45  ,   9039    ,0 };
            const std::uint32_t dim1539JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   9   ,   11  ,   31  ,   125 ,   5   ,   65  ,   173 ,   1189    ,   2363    ,   6603    ,   15891   ,0 };
            const std::uint32_t dim1540JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   5   ,   5   ,   63  ,   53  ,   35  ,   311 ,   935 ,   1591    ,   309 ,   7829    ,   1495    ,0 };
            const std::uint32_t dim1541JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   5   ,   29  ,   21  ,   121 ,   199 ,   153 ,   933 ,   1577    ,   1681    ,   1883    ,   7697    ,0 };
            const std::uint32_t dim1542JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   11  ,   19  ,   23  ,   111 ,   113 ,   73  ,   99  ,   1385    ,   591 ,   6977    ,   11995   ,0 };
            const std::uint32_t dim1543JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   13  ,   27  ,   11  ,   23  ,   79  ,   429 ,   505 ,   1693    ,   919 ,   3699    ,   3815    ,0 };
            const std::uint32_t dim1544JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   9   ,   7   ,   23  ,   29  ,   197 ,   465 ,   267 ,   915 ,   1455    ,   2155    ,   15105   ,0 };
            const std::uint32_t dim1545JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   9   ,   17  ,   3   ,   7   ,   73  ,   417 ,   841 ,   1123    ,   3425    ,   4691    ,   14703   ,0 };
            const std::uint32_t dim1546JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   15  ,   15  ,   7   ,   75  ,   85  ,   441 ,   5   ,   1593    ,   43  ,   1207    ,   12117   ,0 };
            const std::uint32_t dim1547JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   7   ,   21  ,   45  ,   93  ,   133 ,   31  ,   249 ,   701 ,   97  ,   1033    ,   15359   ,0 };
            const std::uint32_t dim1548JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   7   ,   3   ,   5   ,   9   ,   21  ,   339 ,   661 ,   1841    ,   2209    ,   5869    ,   10291   ,0 };
            const std::uint32_t dim1549JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   11  ,   13  ,   3   ,   67  ,   135 ,   69  ,   117 ,   43  ,   2885    ,   5719    ,   427 ,0 };
            const std::uint32_t dim1550JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   9   ,   15  ,   55  ,   45  ,   85  ,   423 ,   351 ,   169 ,   2693    ,   3063    ,   13471   ,0 };
            const std::uint32_t dim1551JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   7   ,   21  ,   17  ,   51  ,   59  ,   251 ,   697 ,   787 ,   3331    ,   7567    ,   15413   ,0 };
            const std::uint32_t dim1552JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   7   ,   29  ,   29  ,   113 ,   37  ,   347 ,   21  ,   223 ,   427 ,   4163    ,   6773    ,0 };
            const std::uint32_t dim1553JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   9   ,   25  ,   55  ,   89  ,   101 ,   327 ,   483 ,   1197    ,   1377    ,   3367    ,   15363   ,0 };
            const std::uint32_t dim1554JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   5   ,   15  ,   37  ,   87  ,   131 ,   279 ,   981 ,   623 ,   105 ,   3537    ,   6021    ,0 };
            const std::uint32_t dim1555JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   13  ,   19  ,   27  ,   49  ,   187 ,   249 ,   17  ,   1499    ,   3559    ,   1691    ,   525 ,0 };
            const std::uint32_t dim1556JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   11  ,   25  ,   55  ,   7   ,   145 ,   335 ,   975 ,   1007    ,   1853    ,   2509    ,   12895   ,0 };
            const std::uint32_t dim1557JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   15  ,   31  ,   29  ,   43  ,   91  ,   51  ,   543 ,   251 ,   3137    ,   1449    ,   2465    ,0 };
            const std::uint32_t dim1558JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   1   ,   25  ,   33  ,   107 ,   117 ,   439 ,   851 ,   1853    ,   1309    ,   7329    ,   6953    ,0 };
            const std::uint32_t dim1559JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   9   ,   13  ,   13  ,   105 ,   113 ,   161 ,   307 ,   939 ,   579 ,   6945    ,   3275    ,0 };
            const std::uint32_t dim1560JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   3   ,   19  ,   61  ,   85  ,   247 ,   31  ,   781 ,   599 ,   1731    ,   7907    ,   10855   ,0 };
            const std::uint32_t dim1561JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   15  ,   23  ,   13  ,   111 ,   197 ,   399 ,   273 ,   1339    ,   717 ,   6365    ,   11211   ,0 };
            const std::uint32_t dim1562JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   1   ,   7   ,   37  ,   83  ,   217 ,   351 ,   325 ,   787 ,   2735    ,   6797    ,   649 ,0 };
            const std::uint32_t dim1563JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   5   ,   25  ,   9   ,   29  ,   3   ,   305 ,   773 ,   933 ,   4091    ,   7515    ,   13513   ,0 };
            const std::uint32_t dim1564JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   7   ,   5   ,   9   ,   53  ,   79  ,   509 ,   101 ,   187 ,   4087    ,   5473    ,   8581    ,0 };
            const std::uint32_t dim1565JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   3   ,   9   ,   7   ,   59  ,   235 ,   219 ,   85  ,   1275    ,   329 ,   3661    ,   2135    ,0 };
            const std::uint32_t dim1566JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   15  ,   7   ,   43  ,   39  ,   153 ,   59  ,   91  ,   755 ,   827 ,   2399    ,   5395    ,0 };
            const std::uint32_t dim1567JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   3   ,   11  ,   29  ,   75  ,   195 ,   249 ,   789 ,   489 ,   1297    ,   1465    ,   449 ,0 };
            const std::uint32_t dim1568JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   13  ,   29  ,   13  ,   61  ,   111 ,   85  ,   335 ,   1835    ,   4025    ,   3433    ,   12839   ,0 };
            const std::uint32_t dim1569JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   1   ,   9   ,   45  ,   13  ,   179 ,   145 ,   161 ,   459 ,   3011    ,   7809    ,   11047   ,0 };
            const std::uint32_t dim1570JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   15  ,   27  ,   1   ,   81  ,   241 ,   89  ,   159 ,   681 ,   3525    ,   4487    ,   9129    ,0 };
            const std::uint32_t dim1571JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   15  ,   7   ,   1   ,   15  ,   103 ,   81  ,   59  ,   1953    ,   3729    ,   6451    ,   15051   ,0 };
            const std::uint32_t dim1572JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   1   ,   29  ,   7   ,   77  ,   77  ,   279 ,   1007    ,   1315    ,   1149    ,   301 ,   14183   ,0 };
            const std::uint32_t dim1573JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   11  ,   1   ,   1   ,   85  ,   23  ,   27  ,   211 ,   2023    ,   591 ,   2949    ,   10741   ,0 };
            const std::uint32_t dim1574JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   11  ,   31  ,   63  ,   49  ,   87  ,   291 ,   701 ,   531 ,   287 ,   6117    ,   16303   ,0 };
            const std::uint32_t dim1575JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   9   ,   27  ,   19  ,   19  ,   143 ,   95  ,   65  ,   1027    ,   2765    ,   2483    ,   14347   ,0 };
            const std::uint32_t dim1576JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   9   ,   3   ,   31  ,   31  ,   243 ,   45  ,   195 ,   1997    ,   3361    ,   7151    ,   12021   ,0 };
            const std::uint32_t dim1577JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   9   ,   11  ,   43  ,   83  ,   1   ,   389 ,   843 ,   1635    ,   3405    ,   2497    ,   4473    ,0 };
            const std::uint32_t dim1578JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   5   ,   15  ,   9   ,   65  ,   187 ,   107 ,   271 ,   1049    ,   1657    ,   1831    ,   12291   ,0 };
            const std::uint32_t dim1579JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   3   ,   29  ,   17  ,   107 ,   17  ,   253 ,   399 ,   481 ,   83  ,   3905    ,   5817    ,0 };
            const std::uint32_t dim1580JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   5   ,   21  ,   1   ,   93  ,   189 ,   451 ,   183 ,   1489    ,   379 ,   4673    ,   9323    ,0 };
            const std::uint32_t dim1581JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   9   ,   19  ,   25  ,   105 ,   97  ,   505 ,   569 ,   773 ,   3155    ,   3275    ,   11389   ,0 };
            const std::uint32_t dim1582JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   11  ,   29  ,   25  ,   87  ,   205 ,   321 ,   187 ,   239 ,   2217    ,   1063    ,   13323   ,0 };
            const std::uint32_t dim1583JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   13  ,   19  ,   47  ,   17  ,   243 ,   103 ,   515 ,   1049    ,   2119    ,   2185    ,   3137    ,0 };
            const std::uint32_t dim1584JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   15  ,   17  ,   19  ,   45  ,   191 ,   257 ,   453 ,   779 ,   3759    ,   6825    ,   5711    ,0 };
            const std::uint32_t dim1585JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   15  ,   15  ,   41  ,   41  ,   181 ,   185 ,   91  ,   375 ,   2825    ,   3841    ,   14179   ,0 };
            const std::uint32_t dim1586JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   13  ,   23  ,   11  ,   93  ,   117 ,   135 ,   333 ,   1985    ,   3355    ,   2119    ,   10511   ,0 };
            const std::uint32_t dim1587JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   15  ,   5   ,   59  ,   17  ,   141 ,   291 ,   897 ,   657 ,   2805    ,   4423    ,   559 ,0 };
            const std::uint32_t dim1588JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   1   ,   19  ,   55  ,   33  ,   77  ,   321 ,   989 ,   1713    ,   1553    ,   5541    ,   12995   ,0 };
            const std::uint32_t dim1589JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   5   ,   11  ,   9   ,   69  ,   123 ,   223 ,   201 ,   1505    ,   1119    ,   381 ,   12361   ,0 };
            const std::uint32_t dim1590JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   7   ,   13  ,   13  ,   15  ,   107 ,   143 ,   925 ,   1741    ,   3697    ,   5379    ,   10661   ,0 };
            const std::uint32_t dim1591JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   1   ,   25  ,   43  ,   47  ,   209 ,   57  ,   1015    ,   1721    ,   1707    ,   3675    ,   2651    ,0 };
            const std::uint32_t dim1592JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   3   ,   21  ,   27  ,   101 ,   41  ,   309 ,   585 ,   159 ,   2029    ,   5307    ,   5919    ,0 };
            const std::uint32_t dim1593JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   7   ,   13  ,   53  ,   43  ,   71  ,   259 ,   331 ,   1317    ,   3367    ,   2593    ,   4667    ,0 };
            const std::uint32_t dim1594JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   13  ,   1   ,   31  ,   115 ,   159 ,   203 ,   39  ,   19  ,   1939    ,   2601    ,   14819   ,0 };
            const std::uint32_t dim1595JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   9   ,   1   ,   33  ,   101 ,   145 ,   401 ,   655 ,   543 ,   2063    ,   425 ,   6397    ,0 };
            const std::uint32_t dim1596JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   1   ,   1   ,   13  ,   15  ,   19  ,   347 ,   679 ,   107 ,   933 ,   8097    ,   16213   ,0 };
            const std::uint32_t dim1597JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   5   ,   9   ,   47  ,   15  ,   95  ,   191 ,   887 ,   69  ,   3775    ,   7839    ,   767 ,0 };
            const std::uint32_t dim1598JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   13  ,   17  ,   37  ,   43  ,   241 ,   401 ,   273 ,   1819    ,   2437    ,   2027    ,   5763    ,0 };
            const std::uint32_t dim1599JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   11  ,   25  ,   49  ,   31  ,   17  ,   153 ,   771 ,   1151    ,   1575    ,   1719    ,   12567   ,0 };
            const std::uint32_t dim1600JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   9   ,   19  ,   31  ,   33  ,   227 ,   15  ,   645 ,   1499    ,   967 ,   6459    ,   975 ,0 };
            const std::uint32_t dim1601JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   1   ,   5   ,   23  ,   31  ,   105 ,   47  ,   761 ,   1911    ,   3889    ,   67  ,   5543    ,0 };
            const std::uint32_t dim1602JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   3   ,   15  ,   1   ,   7   ,   119 ,   247 ,   759 ,   1277    ,   1233    ,   1055    ,   15651   ,0 };
            const std::uint32_t dim1603JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   1   ,   15  ,   33  ,   117 ,   189 ,   93  ,   511 ,   1709    ,   3329    ,   619 ,   3561    ,0 };
            const std::uint32_t dim1604JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   9   ,   21  ,   39  ,   35  ,   59  ,   121 ,   149 ,   2015    ,   1127    ,   8035    ,   8197    ,0 };
            const std::uint32_t dim1605JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   9   ,   25  ,   3   ,   43  ,   189 ,   257 ,   343 ,   607 ,   285 ,   6003    ,   1119    ,0 };
            const std::uint32_t dim1606JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   11  ,   7   ,   41  ,   53  ,   193 ,   343 ,   353 ,   1743    ,   1877    ,   2207    ,   10765   ,0 };
            const std::uint32_t dim1607JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   1   ,   3   ,   59  ,   117 ,   15  ,   199 ,   639 ,   1597    ,   3833    ,   7167    ,   9437    ,0 };
            const std::uint32_t dim1608JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   13  ,   15  ,   49  ,   79  ,   19  ,   131 ,   1021    ,   1881    ,   1113    ,   6191    ,   7549    ,0 };
            const std::uint32_t dim1609JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   5   ,   29  ,   57  ,   69  ,   181 ,   167 ,   179 ,   317 ,   4069    ,   3885    ,   2641    ,0 };
            const std::uint32_t dim1610JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   7   ,   1   ,   15  ,   13  ,   69  ,   425 ,   491 ,   327 ,   1387    ,   5333    ,   14555   ,0 };
            const std::uint32_t dim1611JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   3   ,   3   ,   33  ,   99  ,   169 ,   245 ,   155 ,   1843    ,   2435    ,   2853    ,   8871    ,0 };
            const std::uint32_t dim1612JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   11  ,   27  ,   37  ,   107 ,   163 ,   399 ,   933 ,   1867    ,   3321    ,   2737    ,   4941    ,0 };
            const std::uint32_t dim1613JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   11  ,   27  ,   25  ,   31  ,   193 ,   219 ,   21  ,   1811    ,   2515    ,   1027    ,   10337   ,0 };
            const std::uint32_t dim1614JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   1   ,   13  ,   23  ,   75  ,   175 ,   265 ,   71  ,   597 ,   521 ,   5343    ,   5615    ,0 };
            const std::uint32_t dim1615JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   11  ,   27  ,   13  ,   23  ,   187 ,   281 ,   593 ,   1559    ,   1355    ,   637 ,   15835   ,0 };
            const std::uint32_t dim1616JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   15  ,   25  ,   7   ,   29  ,   1   ,   403 ,   175 ,   401 ,   3521    ,   1077    ,   8699    ,0 };
            const std::uint32_t dim1617JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   5   ,   31  ,   27  ,   79  ,   135 ,   439 ,   935 ,   783 ,   2981    ,   3747    ,   10697   ,0 };
            const std::uint32_t dim1618JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   3   ,   25  ,   1   ,   119 ,   53  ,   107 ,   841 ,   909 ,   265 ,   3845    ,   8613    ,0 };
            const std::uint32_t dim1619JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   7   ,   13  ,   53  ,   3   ,   159 ,   453 ,   711 ,   399 ,   3267    ,   1245    ,   8747    ,0 };
            const std::uint32_t dim1620JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   9   ,   15  ,   59  ,   99  ,   255 ,   331 ,   241 ,   1389    ,   3885    ,   7497    ,   13169   ,0 };
            const std::uint32_t dim1621JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   9   ,   11  ,   23  ,   49  ,   77  ,   239 ,   341 ,   453 ,   763 ,   3241    ,   13097   ,0 };
            const std::uint32_t dim1622JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   15  ,   21  ,   15  ,   65  ,   221 ,   167 ,   17  ,   1621    ,   4043    ,   1643    ,   13481   ,0 };
            const std::uint32_t dim1623JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   9   ,   1   ,   35  ,   125 ,   157 ,   437 ,   49  ,   1145    ,   861 ,   4323    ,   11839   ,0 };
            const std::uint32_t dim1624JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   5   ,   27  ,   27  ,   125 ,   61  ,   401 ,   251 ,   1171    ,   2409    ,   63  ,   11279   ,0 };
            const std::uint32_t dim1625JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   5   ,   27  ,   57  ,   39  ,   37  ,   337 ,   999 ,   549 ,   2071    ,   5547    ,   315 ,0 };
            const std::uint32_t dim1626JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   15  ,   29  ,   29  ,   119 ,   89  ,   325 ,   665 ,   783 ,   1683    ,   6185    ,   4301    ,0 };
            const std::uint32_t dim1627JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   7   ,   7   ,   25  ,   111 ,   99  ,   411 ,   549 ,   949 ,   735 ,   6881    ,   4681    ,0 };
            const std::uint32_t dim1628JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   15  ,   21  ,   3   ,   117 ,   83  ,   473 ,   595 ,   1061    ,   3905    ,   4985    ,   6149    ,0 };
            const std::uint32_t dim1629JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   1   ,   17  ,   13  ,   27  ,   101 ,   95  ,   773 ,   1095    ,   2813    ,   6253    ,   2817    ,0 };
            const std::uint32_t dim1630JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   9   ,   1   ,   9   ,   91  ,   43  ,   153 ,   627 ,   49  ,   1109    ,   1395    ,   2971    ,0 };
            const std::uint32_t dim1631JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   11  ,   25  ,   57  ,   1   ,   141 ,   227 ,   161 ,   3   ,   2509    ,   2675    ,   14093   ,0 };
            const std::uint32_t dim1632JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   7   ,   27  ,   35  ,   85  ,   103 ,   321 ,   331 ,   351 ,   2831    ,   911 ,   13259   ,0 };
            const std::uint32_t dim1633JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   9   ,   29  ,   59  ,   57  ,   199 ,   27  ,   303 ,   1001    ,   1393    ,   3345    ,   11169   ,0 };
            const std::uint32_t dim1634JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   15  ,   11  ,   37  ,   83  ,   127 ,   79  ,   683 ,   669 ,   1793    ,   2271    ,   1643    ,0 };
            const std::uint32_t dim1635JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   5   ,   9   ,   45  ,   65  ,   143 ,   489 ,   91  ,   1819    ,   2679    ,   4003    ,   13961   ,0 };
            const std::uint32_t dim1636JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   1   ,   5   ,   9   ,   127 ,   61  ,   209 ,   597 ,   463 ,   961 ,   1739    ,   13955   ,0 };
            const std::uint32_t dim1637JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   11  ,   29  ,   13  ,   73  ,   61  ,   233 ,   891 ,   1477    ,   501 ,   7781    ,   15911   ,0 };
            const std::uint32_t dim1638JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   3   ,   23  ,   23  ,   99  ,   227 ,   385 ,   503 ,   405 ,   3825    ,   535 ,   5997    ,0 };
            const std::uint32_t dim1639JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   7   ,   11  ,   31  ,   105 ,   103 ,   383 ,   897 ,   1049    ,   2757    ,   7687    ,   13175   ,0 };
            const std::uint32_t dim1640JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   15  ,   7   ,   55  ,   43  ,   205 ,   451 ,   195 ,   1973    ,   1963    ,   5791    ,   14413   ,0 };
            const std::uint32_t dim1641JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   13  ,   7   ,   5   ,   35  ,   215 ,   415 ,   221 ,   1245    ,   399 ,   1471    ,   9559    ,0 };
            const std::uint32_t dim1642JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   13  ,   3   ,   27  ,   119 ,   245 ,   291 ,   633 ,   641 ,   779 ,   533 ,   12031   ,0 };
            const std::uint32_t dim1643JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   11  ,   21  ,   41  ,   83  ,   93  ,   91  ,   671 ,   1579    ,   3375    ,   7109    ,   12321   ,0 };
            const std::uint32_t dim1644JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   1   ,   27  ,   47  ,   19  ,   161 ,   103 ,   455 ,   2027    ,   1461    ,   633 ,   5815    ,0 };
            const std::uint32_t dim1645JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   11  ,   25  ,   11  ,   115 ,   95  ,   15  ,   979 ,   89  ,   2489    ,   255 ,   13683   ,0 };
            const std::uint32_t dim1646JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   5   ,   31  ,   55  ,   85  ,   223 ,   231 ,   9   ,   493 ,   3117    ,   3431    ,   12139   ,0 };
            const std::uint32_t dim1647JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   13  ,   1   ,   59  ,   5   ,   33  ,   111 ,   711 ,   1111    ,   3337    ,   6595    ,   15149   ,0 };
            const std::uint32_t dim1648JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   5   ,   27  ,   9   ,   85  ,   243 ,   141 ,   155 ,   2007    ,   673 ,   3613    ,   9837    ,0 };
            const std::uint32_t dim1649JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   13  ,   17  ,   53  ,   105 ,   125 ,   295 ,   467 ,   29  ,   1501    ,   2841    ,   1531    ,0 };
            const std::uint32_t dim1650JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   1   ,   15  ,   35  ,   95  ,   73  ,   273 ,   5   ,   515 ,   185 ,   5845    ,   15793   ,0 };
            const std::uint32_t dim1651JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   15  ,   1   ,   9   ,   117 ,   229 ,   219 ,   723 ,   1641    ,   2639    ,   5711    ,   10337   ,0 };
            const std::uint32_t dim1652JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   1   ,   9   ,   47  ,   13  ,   179 ,   353 ,   167 ,   1255    ,   4053    ,   1279    ,   6181    ,0 };
            const std::uint32_t dim1653JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   11  ,   3   ,   29  ,   47  ,   63  ,   127 ,   355 ,   1459    ,   441 ,   6849    ,   12995   ,0 };
            const std::uint32_t dim1654JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   5   ,   15  ,   27  ,   99  ,   11  ,   63  ,   405 ,   1025    ,   2047    ,   7239    ,   13019   ,0 };
            const std::uint32_t dim1655JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   15  ,   31  ,   1   ,   17  ,   109 ,   7   ,   251 ,   517 ,   2923    ,   2967    ,   15609   ,0 };
            const std::uint32_t dim1656JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   5   ,   5   ,   9   ,   89  ,   77  ,   77  ,   619 ,   793 ,   195 ,   3507    ,   4203    ,0 };
            const std::uint32_t dim1657JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   1   ,   29  ,   47  ,   83  ,   117 ,   387 ,   601 ,   35  ,   1327    ,   6381    ,   7673    ,0 };
            const std::uint32_t dim1658JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   3   ,   21  ,   7   ,   33  ,   41  ,   161 ,   53  ,   1635    ,   787 ,   6197    ,   4841    ,0 };
            const std::uint32_t dim1659JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   11  ,   5   ,   33  ,   29  ,   43  ,   289 ,   805 ,   109 ,   2099    ,   7851    ,   809 ,0 };
            const std::uint32_t dim1660JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   7   ,   7   ,   39  ,   79  ,   147 ,   129 ,   307 ,   93  ,   3349    ,   7329    ,   14213   ,0 };
            const std::uint32_t dim1661JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   13  ,   27  ,   59  ,   35  ,   235 ,   413 ,   631 ,   1201    ,   1317    ,   5489    ,   13277   ,0 };
            const std::uint32_t dim1662JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   7   ,   27  ,   57  ,   57  ,   83  ,   273 ,   973 ,   767 ,   3993    ,   5337    ,   15679   ,0 };
            const std::uint32_t dim1663JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   11  ,   29  ,   49  ,   63  ,   211 ,   253 ,   947 ,   21  ,   1993    ,   6775    ,   1551    ,0 };
            const std::uint32_t dim1664JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   15  ,   27  ,   17  ,   37  ,   81  ,   83  ,   991 ,   1509    ,   1931    ,   7389    ,   6053    ,0 };
            const std::uint32_t dim1665JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   15  ,   19  ,   23  ,   53  ,   225 ,   131 ,   935 ,   333 ,   577 ,   7893    ,   13339   ,0 };
            const std::uint32_t dim1666JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   1   ,   27  ,   41  ,   97  ,   131 ,   135 ,   857 ,   89  ,   2285    ,   223 ,   15595   ,0 };
            const std::uint32_t dim1667JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   13  ,   13  ,   29  ,   47  ,   179 ,   63  ,   261 ,   1409    ,   3921    ,   653 ,   12425   ,0 };
            const std::uint32_t dim1668JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   7   ,   15  ,   53  ,   121 ,   7   ,   287 ,   251 ,   579 ,   1415    ,   453 ,   15615   ,0 };
            const std::uint32_t dim1669JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   5   ,   3   ,   9   ,   41  ,   105 ,   505 ,   37  ,   665 ,   3323    ,   3613    ,   4533    ,0 };
            const std::uint32_t dim1670JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   1   ,   5   ,   57  ,   53  ,   107 ,   279 ,   169 ,   1797    ,   3395    ,   7325    ,   5825    ,0 };
            const std::uint32_t dim1671JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   13  ,   19  ,   23  ,   33  ,   145 ,   15  ,   459 ,   711 ,   2883    ,   2879    ,   7437    ,0 };
            const std::uint32_t dim1672JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   1   ,   23  ,   17  ,   81  ,   233 ,   85  ,   435 ,   169 ,   287 ,   5913    ,   11063   ,0 };
            const std::uint32_t dim1673JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   9   ,   23  ,   5   ,   7   ,   9   ,   393 ,   243 ,   1301    ,   365 ,   7529    ,   13875   ,0 };
            const std::uint32_t dim1674JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   1   ,   9   ,   43  ,   127 ,   81  ,   49  ,   783 ,   1079    ,   4059    ,   5829    ,   7873    ,0 };
            const std::uint32_t dim1675JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   7   ,   29  ,   49  ,   123 ,   81  ,   73  ,   137 ,   895 ,   791 ,   6801    ,   1209    ,0 };
            const std::uint32_t dim1676JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   13  ,   7   ,   63  ,   93  ,   177 ,   263 ,   373 ,   39  ,   1713    ,   6793    ,   215 ,0 };
            const std::uint32_t dim1677JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   9   ,   31  ,   19  ,   105 ,   187 ,   55  ,   715 ,   505 ,   2597    ,   2923    ,   16351   ,0 };
            const std::uint32_t dim1678JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   15  ,   9   ,   29  ,   113 ,   41  ,   83  ,   667 ,   605 ,   1033    ,   1525    ,   2781    ,0 };
            const std::uint32_t dim1679JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   5   ,   29  ,   27  ,   123 ,   159 ,   3   ,   659 ,   1757    ,   3603    ,   6419    ,   10125   ,0 };
            const std::uint32_t dim1680JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   3   ,   17  ,   19  ,   1   ,   19  ,   459 ,   833 ,   1149    ,   413 ,   1835    ,   12449   ,0 };
            const std::uint32_t dim1681JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   15  ,   27  ,   13  ,   109 ,   233 ,   341 ,   943 ,   173 ,   2491    ,   445 ,   5669    ,0 };
            const std::uint32_t dim1682JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   13  ,   17  ,   37  ,   53  ,   79  ,   107 ,   263 ,   353 ,   1193    ,   4445    ,   13969   ,0 };
            const std::uint32_t dim1683JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   7   ,   17  ,   55  ,   49  ,   53  ,   9   ,   831 ,   1551    ,   1105    ,   7797    ,   10667   ,0 };
            const std::uint32_t dim1684JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   13  ,   23  ,   9   ,   77  ,   85  ,   297 ,   875 ,   1339    ,   3019    ,   7211    ,   363 ,0 };
            const std::uint32_t dim1685JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   3   ,   13  ,   11  ,   13  ,   239 ,   235 ,   299 ,   1433    ,   3913    ,   6793    ,   8471    ,0 };
            const std::uint32_t dim1686JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   15  ,   15  ,   43  ,   109 ,   33  ,   221 ,   543 ,   1067    ,   559 ,   2541    ,   5601    ,0 };
            const std::uint32_t dim1687JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   11  ,   15  ,   51  ,   77  ,   125 ,   195 ,   435 ,   1769    ,   1047    ,   2509    ,   11143   ,0 };
            const std::uint32_t dim1688JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   13  ,   19  ,   43  ,   31  ,   115 ,   357 ,   197 ,   119 ,   1709    ,   1851    ,   5625    ,0 };
            const std::uint32_t dim1689JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   15  ,   25  ,   19  ,   127 ,   165 ,   241 ,   255 ,   1737    ,   4053    ,   5987    ,   2573    ,0 };
            const std::uint32_t dim1690JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   1   ,   5   ,   5   ,   21  ,   203 ,   379 ,   147 ,   1793    ,   461 ,   4863    ,   14659   ,0 };
            const std::uint32_t dim1691JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   13  ,   15  ,   41  ,   125 ,   191 ,   471 ,   863 ,   485 ,   1029    ,   6375    ,   7825    ,0 };
            const std::uint32_t dim1692JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   1   ,   13  ,   47  ,   53  ,   221 ,   351 ,   621 ,   1025    ,   3729    ,   367 ,   16091   ,0 };
            const std::uint32_t dim1693JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   11  ,   1   ,   47  ,   11  ,   91  ,   485 ,   601 ,   235 ,   241 ,   6631    ,   3159    ,0 };
            const std::uint32_t dim1694JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   11  ,   9   ,   59  ,   41  ,   121 ,   87  ,   969 ,   667 ,   3845    ,   3317    ,   14095   ,0 };
            const std::uint32_t dim1695JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   9   ,   17  ,   43  ,   95  ,   111 ,   253 ,   497 ,   1263    ,   1323    ,   2669    ,   11567   ,0 };
            const std::uint32_t dim1696JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   5   ,   17  ,   45  ,   15  ,   231 ,   7   ,   125 ,   67  ,   27  ,   5397    ,   15347   ,0 };
            const std::uint32_t dim1697JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   13  ,   15  ,   59  ,   119 ,   203 ,   89  ,   987 ,   337 ,   3313    ,   5533    ,   13157   ,0 };
            const std::uint32_t dim1698JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   5   ,   31  ,   21  ,   11  ,   79  ,   485 ,   431 ,   1333    ,   3111    ,   2081    ,   4327    ,0 };
            const std::uint32_t dim1699JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   7   ,   1   ,   19  ,   111 ,   127 ,   23  ,   597 ,   1049    ,   2337    ,   6891    ,   7421    ,0 };
            const std::uint32_t dim1700JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   7   ,   23  ,   3   ,   121 ,   171 ,   41  ,   3   ,   147 ,   397 ,   5413    ,   15457   ,0 };
            const std::uint32_t dim1701JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   9   ,   11  ,   9   ,   107 ,   55  ,   303 ,   285 ,   599 ,   2507    ,   699 ,   8593    ,0 };
            const std::uint32_t dim1702JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   3   ,   19  ,   61  ,   9   ,   33  ,   385 ,   761 ,   1185    ,   1163    ,   2251    ,   8497    ,0 };
            const std::uint32_t dim1703JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   3   ,   5   ,   35  ,   31  ,   19  ,   173 ,   425 ,   833 ,   119 ,   6691    ,   11103   ,0 };
            const std::uint32_t dim1704JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   3   ,   11  ,   15  ,   105 ,   239 ,   21  ,   477 ,   1303    ,   3437    ,   5511    ,   2469    ,0 };
            const std::uint32_t dim1705JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   5   ,   13  ,   11  ,   49  ,   81  ,   505 ,   527 ,   1799    ,   403 ,   6849    ,   4551    ,0 };
            const std::uint32_t dim1706JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   1   ,   5   ,   1   ,   21  ,   83  ,   273 ,   477 ,   1281    ,   3173    ,   2065    ,   1559    ,0 };
            const std::uint32_t dim1707JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   5   ,   19  ,   43  ,   33  ,   191 ,   411 ,   879 ,   83  ,   2653    ,   1271    ,   10557   ,0 };
            const std::uint32_t dim1708JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   1   ,   25  ,   27  ,   81  ,   81  ,   23  ,   575 ,   787 ,   1715    ,   7983    ,   14397   ,0 };
            const std::uint32_t dim1709JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   11  ,   27  ,   57  ,   31  ,   139 ,   65  ,   445 ,   1993    ,   3693    ,   2627    ,   941 ,0 };
            const std::uint32_t dim1710JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   9   ,   5   ,   55  ,   23  ,   235 ,   103 ,   451 ,   1299    ,   3901    ,   2705    ,   12485   ,0 };
            const std::uint32_t dim1711JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   11  ,   9   ,   57  ,   57  ,   129 ,   269 ,   841 ,   1859    ,   1149    ,   531 ,   11977   ,0 };
            const std::uint32_t dim1712JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   7   ,   17  ,   11  ,   9   ,   89  ,   205 ,   3   ,   437 ,   475 ,   313 ,   7593    ,0 };
            const std::uint32_t dim1713JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   13  ,   9   ,   37  ,   9   ,   109 ,   453 ,   965 ,   1259    ,   2713    ,   7301    ,   15453   ,0 };
            const std::uint32_t dim1714JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   7   ,   25  ,   57  ,   53  ,   149 ,   291 ,   45  ,   783 ,   2327    ,   7439    ,   6567    ,0 };
            const std::uint32_t dim1715JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   13  ,   5   ,   17  ,   65  ,   15  ,   279 ,   435 ,   1015    ,   3157    ,   1411    ,   3259    ,0 };
            const std::uint32_t dim1716JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   1   ,   27  ,   9   ,   119 ,   11  ,   159 ,   829 ,   1499    ,   3797    ,   3059    ,   675 ,0 };
            const std::uint32_t dim1717JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   7   ,   27  ,   5   ,   65  ,   141 ,   403 ,   431 ,   645 ,   3547    ,   7779    ,   12565   ,0 };
            const std::uint32_t dim1718JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   15  ,   7   ,   11  ,   3   ,   53  ,   479 ,   841 ,   541 ,   2041    ,   631 ,   13969   ,0 };
            const std::uint32_t dim1719JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   9   ,   19  ,   29  ,   15  ,   137 ,   317 ,   929 ,   509 ,   2231    ,   6273    ,   305 ,0 };
            const std::uint32_t dim1720JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   1   ,   19  ,   43  ,   99  ,   221 ,   429 ,   293 ,   133 ,   3233    ,   5097    ,   7521    ,0 };
            const std::uint32_t dim1721JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   7   ,   5   ,   19  ,   11  ,   253 ,   375 ,   33  ,   941 ,   573 ,   1855    ,   13119   ,0 };
            const std::uint32_t dim1722JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   5   ,   27  ,   59  ,   61  ,   195 ,   197 ,   635 ,   889 ,   777 ,   2559    ,   3013    ,0 };
            const std::uint32_t dim1723JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   7   ,   21  ,   45  ,   95  ,   61  ,   253 ,   239 ,   585 ,   75  ,   3737    ,   2199    ,0 };
            const std::uint32_t dim1724JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   5   ,   1   ,   17  ,   61  ,   21  ,   485 ,   199 ,   7   ,   431 ,   1117    ,   2039    ,0 };
            const std::uint32_t dim1725JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   7   ,   13  ,   23  ,   53  ,   211 ,   319 ,   47  ,   299 ,   2681    ,   6913    ,   5265    ,0 };
            const std::uint32_t dim1726JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   1   ,   21  ,   49  ,   1   ,   197 ,   413 ,   475 ,   79  ,   3761    ,   6379    ,   10689   ,0 };
            const std::uint32_t dim1727JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   11  ,   15  ,   37  ,   51  ,   81  ,   319 ,   985 ,   129 ,   3105    ,   1321    ,   9749    ,0 };
            const std::uint32_t dim1728JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   13  ,   23  ,   31  ,   61  ,   49  ,   497 ,   987 ,   1401    ,   2609    ,   307 ,   4839    ,0 };
            const std::uint32_t dim1729JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   7   ,   11  ,   25  ,   9   ,   97  ,   337 ,   535 ,   543 ,   145 ,   241 ,   1481    ,0 };
            const std::uint32_t dim1730JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   11  ,   17  ,   55  ,   81  ,   161 ,   367 ,   825 ,   879 ,   301 ,   13  ,   7089    ,0 };
            const std::uint32_t dim1731JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   3   ,   13  ,   11  ,   43  ,   237 ,   485 ,   3   ,   1191    ,   223 ,   767 ,   10297   ,0 };
            const std::uint32_t dim1732JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   13  ,   21  ,   21  ,   93  ,   241 ,   119 ,   647 ,   921 ,   2847    ,   6889    ,   7055    ,0 };
            const std::uint32_t dim1733JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   5   ,   5   ,   29  ,   3   ,   225 ,   307 ,   257 ,   1961    ,   2455    ,   2239    ,   3405    ,0 };
            const std::uint32_t dim1734JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   11  ,   15  ,   33  ,   17  ,   179 ,   469 ,   5   ,   1577    ,   3539    ,   7123    ,   16093   ,0 };
            const std::uint32_t dim1735JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   7   ,   27  ,   43  ,   45  ,   115 ,   507 ,   657 ,   1531    ,   2221    ,   3175    ,   1877    ,0 };
            const std::uint32_t dim1736JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   1   ,   11  ,   25  ,   49  ,   155 ,   441 ,   703 ,   813 ,   1143    ,   219 ,   12675   ,0 };
            const std::uint32_t dim1737JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   3   ,   15  ,   55  ,   15  ,   83  ,   333 ,   573 ,   1527    ,   3421    ,   6225    ,   3115    ,0 };
            const std::uint32_t dim1738JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   1   ,   27  ,   3   ,   117 ,   149 ,   35  ,   587 ,   1123    ,   3037    ,   8083    ,   113 ,0 };
            const std::uint32_t dim1739JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   5   ,   1   ,   23  ,   79  ,   99  ,   287 ,   505 ,   807 ,   4003    ,   4551    ,   2093    ,0 };
            const std::uint32_t dim1740JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   9   ,   29  ,   5   ,   59  ,   111 ,   401 ,   179 ,   1263    ,   749 ,   689 ,   8905    ,0 };
            const std::uint32_t dim1741JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   3   ,   17  ,   41  ,   81  ,   191 ,   313 ,   343 ,   809 ,   83  ,   405 ,   10665   ,0 };
            const std::uint32_t dim1742JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   9   ,   7   ,   19  ,   59  ,   157 ,   169 ,   273 ,   935 ,   1435    ,   4725    ,   14049   ,0 };
            const std::uint32_t dim1743JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   7   ,   11  ,   41  ,   61  ,   47  ,   43  ,   13  ,   783 ,   3685    ,   6417    ,   7859    ,0 };
            const std::uint32_t dim1744JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   3   ,   13  ,   37  ,   127 ,   107 ,   439 ,   855 ,   1969    ,   1257    ,   1459    ,   3617    ,0 };
            const std::uint32_t dim1745JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   1   ,   5   ,   7   ,   41  ,   77  ,   175 ,   679 ,   353 ,   2899    ,   1513    ,   9241    ,0 };
            const std::uint32_t dim1746JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   1   ,   31  ,   41  ,   75  ,   217 ,   131 ,   261 ,   1659    ,   509 ,   3327    ,   14651   ,0 };
            const std::uint32_t dim1747JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   15  ,   15  ,   1   ,   111 ,   131 ,   19  ,   123 ,   701 ,   2633    ,   5125    ,   15109   ,0 };
            const std::uint32_t dim1748JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   3   ,   15  ,   51  ,   19  ,   133 ,   41  ,   561 ,   869 ,   447 ,   1421    ,   8659    ,0 };
            const std::uint32_t dim1749JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   9   ,   15  ,   47  ,   103 ,   5   ,   23  ,   97  ,   1413    ,   3307    ,   407 ,   6943    ,0 };
            const std::uint32_t dim1750JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   15  ,   19  ,   37  ,   113 ,   217 ,   451 ,   733 ,   1407    ,   2805    ,   6121    ,   12471   ,0 };
            const std::uint32_t dim1751JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   13  ,   7   ,   53  ,   1   ,   159 ,   503 ,   603 ,   1523    ,   2327    ,   909 ,   3685    ,0 };
            const std::uint32_t dim1752JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   13  ,   11  ,   47  ,   79  ,   69  ,   459 ,   761 ,   1181    ,   3369    ,   7983    ,   8561    ,0 };
            const std::uint32_t dim1753JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   9   ,   3   ,   51  ,   69  ,   93  ,   375 ,   451 ,   1181    ,   1353    ,   939 ,   629 ,0 };
            const std::uint32_t dim1754JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   9   ,   29  ,   57  ,   89  ,   145 ,   477 ,   17  ,   55  ,   2073    ,   1805    ,   5389    ,0 };
            const std::uint32_t dim1755JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   7   ,   1   ,   59  ,   85  ,   69  ,   369 ,   191 ,   1419    ,   1331    ,   7451    ,   8769    ,0 };
            const std::uint32_t dim1756JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   11  ,   11  ,   49  ,   31  ,   249 ,   285 ,   29  ,   633 ,   3387    ,   1197    ,   6363    ,0 };
            const std::uint32_t dim1757JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   7   ,   15  ,   33  ,   3   ,   253 ,   247 ,   573 ,   2029    ,   3419    ,   8037    ,   2889    ,0 };
            const std::uint32_t dim1758JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   1   ,   23  ,   31  ,   35  ,   113 ,   221 ,   659 ,   755 ,   2777    ,   3709    ,   7511    ,0 };
            const std::uint32_t dim1759JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   7   ,   7   ,   29  ,   113 ,   81  ,   203 ,   711 ,   1427    ,   2233    ,   6049    ,   11417   ,0 };
            const std::uint32_t dim1760JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   1   ,   19  ,   55  ,   107 ,   87  ,   383 ,   25  ,   935 ,   1287    ,   1867    ,   2133    ,0 };
            const std::uint32_t dim1761JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   11  ,   9   ,   45  ,   15  ,   171 ,   293 ,   533 ,   1393    ,   759 ,   3009    ,   7879    ,0 };
            const std::uint32_t dim1762JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   1   ,   1   ,   59  ,   51  ,   15  ,   471 ,   377 ,   1031    ,   3427    ,   6447    ,   10465   ,0 };
            const std::uint32_t dim1763JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   15  ,   7   ,   15  ,   3   ,   1   ,   359 ,   331 ,   1295    ,   2777    ,   373 ,   4043    ,0 };
            const std::uint32_t dim1764JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   9   ,   21  ,   41  ,   123 ,   61  ,   225 ,   305 ,   149 ,   2041    ,   7569    ,   14055   ,0 };
            const std::uint32_t dim1765JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   3   ,   27  ,   15  ,   79  ,   47  ,   463 ,   327 ,   1231    ,   171 ,   4931    ,   7549    ,0 };
            const std::uint32_t dim1766JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   15  ,   27  ,   11  ,   35  ,   179 ,   205 ,   579 ,   1297    ,   3149    ,   1253    ,   3067    ,0 };
            const std::uint32_t dim1767JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   5   ,   15  ,   41  ,   17  ,   69  ,   369 ,   57  ,   779 ,   3055    ,   7799    ,   10755   ,0 };
            const std::uint32_t dim1768JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   11  ,   1   ,   11  ,   121 ,   177 ,   297 ,   933 ,   1319    ,   3123    ,   1233    ,   15521   ,0 };
            const std::uint32_t dim1769JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   7   ,   27  ,   59  ,   17  ,   155 ,   17  ,   109 ,   1623    ,   3527    ,   6227    ,   14295   ,0 };
            const std::uint32_t dim1770JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   13  ,   27  ,   19  ,   47  ,   35  ,   403 ,   647 ,   1257    ,   1661    ,   7011    ,   11981   ,0 };
            const std::uint32_t dim1771JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   13  ,   27  ,   47  ,   73  ,   53  ,   355 ,   857 ,   1091    ,   3165    ,   2729    ,   7685    ,0 };
            const std::uint32_t dim1772JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   9   ,   7   ,   55  ,   53  ,   183 ,   109 ,   655 ,   1143    ,   975 ,   2809    ,   2709    ,0 };
            const std::uint32_t dim1773JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   9   ,   11  ,   5   ,   121 ,   63  ,   221 ,   247 ,   1649    ,   709 ,   5215    ,   12159   ,0 };
            const std::uint32_t dim1774JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   5   ,   5   ,   37  ,   83  ,   89  ,   475 ,   513 ,   563 ,   1965    ,   2335    ,   7921    ,0 };
            const std::uint32_t dim1775JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   3   ,   15  ,   23  ,   79  ,   79  ,   499 ,   343 ,   917 ,   3495    ,   7685    ,   5939    ,0 };
            const std::uint32_t dim1776JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   13  ,   5   ,   59  ,   87  ,   7   ,   469 ,   979 ,   683 ,   3397    ,   3787    ,   5063    ,0 };
            const std::uint32_t dim1777JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   5   ,   1   ,   27  ,   73  ,   85  ,   427 ,   619 ,   989 ,   2323    ,   4069    ,   13721   ,0 };
            const std::uint32_t dim1778JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   3   ,   3   ,   39  ,   55  ,   153 ,   293 ,   483 ,   235 ,   2041    ,   549 ,   15519   ,0 };
            const std::uint32_t dim1779JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   9   ,   17  ,   13  ,   61  ,   227 ,   435 ,   383 ,   513 ,   1169    ,   3335    ,   11257   ,0 };
            const std::uint32_t dim1780JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   7   ,   1   ,   47  ,   61  ,   117 ,   483 ,   979 ,   163 ,   2621    ,   1701    ,   13331   ,0 };
            const std::uint32_t dim1781JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   1   ,   17  ,   49  ,   115 ,   235 ,   511 ,   681 ,   1493    ,   137 ,   539 ,   5429    ,0 };
            const std::uint32_t dim1782JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   13  ,   13  ,   61  ,   3   ,   1   ,   291 ,   101 ,   363 ,   1677    ,   2133    ,   3629    ,0 };
            const std::uint32_t dim1783JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   3   ,   1   ,   11  ,   83  ,   127 ,   291 ,   599 ,   819 ,   2637    ,   1197    ,   7435    ,0 };
            const std::uint32_t dim1784JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   1   ,   1   ,   23  ,   115 ,   47  ,   403 ,   377 ,   833 ,   3241    ,   6843    ,   10279   ,0 };
            const std::uint32_t dim1785JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   15  ,   7   ,   51  ,   81  ,   215 ,   43  ,   445 ,   203 ,   3375    ,   6479    ,   3745    ,0 };
            const std::uint32_t dim1786JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   5   ,   7   ,   13  ,   25  ,   43  ,   233 ,   725 ,   267 ,   1875    ,   6481    ,   9685    ,0 };
            const std::uint32_t dim1787JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   7   ,   23  ,   9   ,   37  ,   1   ,   51  ,   861 ,   1509    ,   11  ,   8119    ,   9171    ,0 };
            const std::uint32_t dim1788JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   9   ,   17  ,   41  ,   69  ,   51  ,   445 ,   727 ,   159 ,   3317    ,   4951    ,   7519    ,0 };
            const std::uint32_t dim1789JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   13  ,   11  ,   3   ,   9   ,   211 ,   453 ,   957 ,   1499    ,   953 ,   403 ,   10715   ,0 };
            const std::uint32_t dim1790JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   7   ,   19  ,   1   ,   13  ,   255 ,   351 ,   325 ,   1055    ,   3719    ,   2343    ,   12693   ,0 };
            const std::uint32_t dim1791JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   3   ,   25  ,   29  ,   77  ,   185 ,   421 ,   33  ,   911 ,   2791    ,   4865    ,   4591    ,0 };
            const std::uint32_t dim1792JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   1   ,   5   ,   53  ,   77  ,   25  ,   359 ,   69  ,   169 ,   225 ,   237 ,   2059    ,0 };
            const std::uint32_t dim1793JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   3   ,   25  ,   63  ,   21  ,   111 ,   83  ,   21  ,   1513    ,   565 ,   1097    ,   7331    ,0 };
            const std::uint32_t dim1794JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   15  ,   23  ,   33  ,   127 ,   221 ,   121 ,   95  ,   909 ,   1207    ,   2957    ,   3367    ,0 };
            const std::uint32_t dim1795JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   15  ,   11  ,   49  ,   35  ,   147 ,   265 ,   517 ,   2011    ,   3585    ,   3877    ,   2907    ,0 };
            const std::uint32_t dim1796JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   1   ,   11  ,   37  ,   53  ,   47  ,   35  ,   323 ,   1283    ,   399 ,   7785    ,   8341    ,0 };
            const std::uint32_t dim1797JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   15  ,   5   ,   51  ,   83  ,   255 ,   231 ,   141 ,   1005    ,   3681    ,   3155    ,   11815   ,0 };
            const std::uint32_t dim1798JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   7   ,   3   ,   15  ,   75  ,   81  ,   23  ,   137 ,   897 ,   2439    ,   5277    ,   6377    ,0 };
            const std::uint32_t dim1799JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   1   ,   3   ,   11  ,   69  ,   231 ,   483 ,   797 ,   133 ,   497 ,   3973    ,   14993   ,0 };
            const std::uint32_t dim1800JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   15  ,   23  ,   17  ,   89  ,   207 ,   111 ,   157 ,   1689    ,   3165    ,   7147    ,   15265   ,0 };
            const std::uint32_t dim1801JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   5   ,   9   ,   31  ,   45  ,   131 ,   423 ,   53  ,   1723    ,   2009    ,   485 ,   15329   ,0 };
            const std::uint32_t dim1802JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   3   ,   25  ,   5   ,   97  ,   81  ,   431 ,   701 ,   1799    ,   3595    ,   3147    ,   8919    ,0 };
            const std::uint32_t dim1803JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   3   ,   3   ,   37  ,   3   ,   219 ,   291 ,   553 ,   1879    ,   15  ,   3357    ,   8479    ,0 };
            const std::uint32_t dim1804JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   3   ,   3   ,   21  ,   55  ,   253 ,   49  ,   191 ,   951 ,   13  ,   5163    ,   12243   ,0 };
            const std::uint32_t dim1805JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   1   ,   29  ,   39  ,   93  ,   123 ,   133 ,   465 ,   1665    ,   2023    ,   6773    ,   10521   ,0 };
            const std::uint32_t dim1806JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   15  ,   15  ,   15  ,   107 ,   209 ,   103 ,   59  ,   33  ,   1927    ,   6517    ,   8479    ,0 };
            const std::uint32_t dim1807JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   15  ,   3   ,   37  ,   19  ,   3   ,   43  ,   193 ,   1907    ,   2579    ,   7415    ,   9165    ,0 };
            const std::uint32_t dim1808JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   11  ,   29  ,   63  ,   47  ,   79  ,   227 ,   569 ,   67  ,   4015    ,   1275    ,   11963   ,0 };
            const std::uint32_t dim1809JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   1   ,   1   ,   33  ,   103 ,   111 ,   129 ,   189 ,   837 ,   3741    ,   699 ,   14433   ,0 };
            const std::uint32_t dim1810JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   11  ,   19  ,   15  ,   43  ,   35  ,   367 ,   535 ,   913 ,   2109    ,   1397    ,   12199   ,0 };
            const std::uint32_t dim1811JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   15  ,   27  ,   15  ,   41  ,   59  ,   429 ,   423 ,   377 ,   905 ,   7403    ,   6175    ,0 };
            const std::uint32_t dim1812JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   5   ,   27  ,   55  ,   49  ,   247 ,   353 ,   773 ,   707 ,   2501    ,   7567    ,   1821    ,0 };
            const std::uint32_t dim1813JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   15  ,   5   ,   11  ,   31  ,   49  ,   331 ,   1017    ,   909 ,   967 ,   5557    ,   7279    ,0 };
            const std::uint32_t dim1814JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   5   ,   13  ,   55  ,   127 ,   111 ,   193 ,   77  ,   1353    ,   349 ,   5785    ,   16325   ,0 };
            const std::uint32_t dim1815JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   11  ,   23  ,   61  ,   83  ,   79  ,   409 ,   877 ,   1625    ,   705 ,   6159    ,   1701    ,0 };
            const std::uint32_t dim1816JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   1   ,   29  ,   39  ,   69  ,   221 ,   29  ,   83  ,   21  ,   3525    ,   7387    ,   9249    ,0 };
            const std::uint32_t dim1817JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   3   ,   13  ,   57  ,   63  ,   159 ,   25  ,   151 ,   1749    ,   3191    ,   4805    ,   6003    ,0 };
            const std::uint32_t dim1818JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   15  ,   11  ,   49  ,   71  ,   241 ,   421 ,   859 ,   1923    ,   539 ,   1721    ,   2903    ,0 };
            const std::uint32_t dim1819JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   1   ,   15  ,   33  ,   123 ,   133 ,   323 ,   173 ,   271 ,   2641    ,   2649    ,   5485    ,0 };
            const std::uint32_t dim1820JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   13  ,   13  ,   31  ,   39  ,   147 ,   313 ,   497 ,   2019    ,   3269    ,   2671    ,   6599    ,0 };
            const std::uint32_t dim1821JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   9   ,   13  ,   37  ,   111 ,   87  ,   3   ,   417 ,   923 ,   1833    ,   5383    ,   12045   ,0 };
            const std::uint32_t dim1822JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   13  ,   25  ,   27  ,   91  ,   121 ,   151 ,   407 ,   899 ,   469 ,   6647    ,   2799    ,0 };
            const std::uint32_t dim1823JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   7   ,   19  ,   39  ,   29  ,   43  ,   195 ,   439 ,   1065    ,   2035    ,   749 ,   14013   ,0 };
            const std::uint32_t dim1824JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   13  ,   21  ,   1   ,   69  ,   223 ,   83  ,   457 ,   1589    ,   1199    ,   7635    ,   1987    ,0 };
            const std::uint32_t dim1825JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   13  ,   5   ,   21  ,   35  ,   169 ,   71  ,   855 ,   497 ,   1119    ,   6681    ,   3905    ,0 };
            const std::uint32_t dim1826JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   13  ,   25  ,   55  ,   109 ,   113 ,   41  ,   461 ,   185 ,   3677    ,   1807    ,   13773   ,0 };
            const std::uint32_t dim1827JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   5   ,   15  ,   61  ,   91  ,   219 ,   365 ,   399 ,   505 ,   1207    ,   2237    ,   9267    ,0 };
            const std::uint32_t dim1828JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   3   ,   7   ,   1   ,   29  ,   151 ,   215 ,   587 ,   1499    ,   355 ,   5121    ,   14963   ,0 };
            const std::uint32_t dim1829JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   1   ,   3   ,   23  ,   127 ,   189 ,   139 ,   987 ,   1291    ,   3583    ,   2881    ,   1927    ,0 };
            const std::uint32_t dim1830JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   11  ,   19  ,   51  ,   25  ,   179 ,   35  ,   517 ,   1531    ,   3657    ,   7025    ,   7079    ,0 };
            const std::uint32_t dim1831JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   7   ,   23  ,   51  ,   35  ,   157 ,   113 ,   993 ,   265 ,   1119    ,   2639    ,   14475   ,0 };
            const std::uint32_t dim1832JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   1   ,   23  ,   19  ,   111 ,   83  ,   413 ,   205 ,   87  ,   2389    ,   7593    ,   9189    ,0 };
            const std::uint32_t dim1833JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   11  ,   25  ,   25  ,   39  ,   59  ,   419 ,   477 ,   1189    ,   807 ,   7679    ,   9867    ,0 };
            const std::uint32_t dim1834JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   1   ,   9   ,   59  ,   99  ,   183 ,   493 ,   811 ,   441 ,   1039    ,   1099    ,   10229   ,0 };
            const std::uint32_t dim1835JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   9   ,   31  ,   27  ,   51  ,   179 ,   277 ,   549 ,   153 ,   1785    ,   5227    ,   13695   ,0 };
            const std::uint32_t dim1836JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   11  ,   29  ,   43  ,   9   ,   205 ,   499 ,   55  ,   745 ,   2217    ,   793 ,   14517   ,0 };
            const std::uint32_t dim1837JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   7   ,   29  ,   47  ,   15  ,   153 ,   73  ,   971 ,   149 ,   2579    ,   1699    ,   14849   ,0 };
            const std::uint32_t dim1838JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   7   ,   31  ,   33  ,   61  ,   103 ,   503 ,   531 ,   2033    ,   2415    ,   4151    ,   4937    ,0 };
            const std::uint32_t dim1839JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   15  ,   15  ,   53  ,   27  ,   67  ,   351 ,   273 ,   637 ,   4085    ,   3445    ,   2085    ,0 };
            const std::uint32_t dim1840JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   15  ,   7   ,   57  ,   121 ,   23  ,   73  ,   765 ,   1949    ,   67  ,   8061    ,   11167   ,0 };
            const std::uint32_t dim1841JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   1   ,   25  ,   7   ,   107 ,   13  ,   409 ,   115 ,   1451    ,   1215    ,   39  ,   11577   ,0 };
            const std::uint32_t dim1842JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   15  ,   3   ,   15  ,   71  ,   1   ,   337 ,   929 ,   1435    ,   2847    ,   3257    ,   12233   ,0 };
            const std::uint32_t dim1843JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   11  ,   31  ,   37  ,   61  ,   243 ,   255 ,   79  ,   1735    ,   3769    ,   4893    ,   15103   ,0 };
            const std::uint32_t dim1844JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   11  ,   5   ,   63  ,   49  ,   197 ,   301 ,   883 ,   951 ,   2357    ,   7501    ,   15499   ,0 };
            const std::uint32_t dim1845JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   3   ,   13  ,   53  ,   71  ,   235 ,   183 ,   951 ,   845 ,   3361    ,   4757    ,   7745    ,0 };
            const std::uint32_t dim1846JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   3   ,   25  ,   61  ,   119 ,   3   ,   487 ,   503 ,   179 ,   2085    ,   4093    ,   1339    ,0 };
            const std::uint32_t dim1847JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   3   ,   21  ,   15  ,   113 ,   175 ,   61  ,   789 ,   1369    ,   109 ,   5963    ,   9401    ,0 };
            const std::uint32_t dim1848JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   5   ,   21  ,   35  ,   103 ,   33  ,   147 ,   561 ,   1033    ,   1497    ,   309 ,   12505   ,0 };
            const std::uint32_t dim1849JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   13  ,   25  ,   17  ,   29  ,   101 ,   103 ,   719 ,   329 ,   1317    ,   4487    ,   9115    ,0 };
            const std::uint32_t dim1850JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   13  ,   5   ,   61  ,   25  ,   79  ,   161 ,   673 ,   47  ,   2485    ,   7711    ,   4959    ,0 };
            const std::uint32_t dim1851JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   13  ,   19  ,   13  ,   1   ,   27  ,   443 ,   369 ,   669 ,   2555    ,   3003    ,   5117    ,0 };
            const std::uint32_t dim1852JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   5   ,   21  ,   29  ,   65  ,   211 ,   343 ,   717 ,   949 ,   1987    ,   6571    ,   11299   ,0 };
            const std::uint32_t dim1853JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   9   ,   19  ,   7   ,   115 ,   119 ,   369 ,   247 ,   1165    ,   4033    ,   861 ,   5667    ,0 };
            const std::uint32_t dim1854JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   3   ,   3   ,   53  ,   15  ,   219 ,   223 ,   873 ,   1145    ,   2781    ,   3297    ,   10551   ,0 };
            const std::uint32_t dim1855JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   15  ,   5   ,   61  ,   15  ,   121 ,   201 ,   89  ,   647 ,   3079    ,   1505    ,   10003   ,0 };
            const std::uint32_t dim1856JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   13  ,   17  ,   55  ,   27  ,   215 ,   67  ,   461 ,   1955    ,   765 ,   483 ,   11695   ,0 };
            const std::uint32_t dim1857JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   1   ,   1   ,   21  ,   59  ,   19  ,   339 ,   157 ,   2019    ,   971 ,   1797    ,   5237    ,0 };
            const std::uint32_t dim1858JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   9   ,   15  ,   1   ,   67  ,   119 ,   63  ,   59  ,   1107    ,   2201    ,   5499    ,   3757    ,0 };
            const std::uint32_t dim1859JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   13  ,   29  ,   59  ,   73  ,   89  ,   469 ,   335 ,   53  ,   315 ,   4371    ,   6417    ,0 };
            const std::uint32_t dim1860JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   3   ,   21  ,   7   ,   11  ,   205 ,   485 ,   695 ,   1959    ,   2407    ,   5423    ,   15359   ,0 };
            const std::uint32_t dim1861JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   1   ,   1   ,   43  ,   61  ,   103 ,   65  ,   747 ,   695 ,   3855    ,   7765    ,   13299   ,0 };
            const std::uint32_t dim1862JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   11  ,   9   ,   11  ,   47  ,   59  ,   287 ,   363 ,   1677    ,   613 ,   4181    ,   16221   ,0 };
            const std::uint32_t dim1863JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   3   ,   9   ,   43  ,   1   ,   107 ,   291 ,   493 ,   571 ,   2329    ,   2707    ,   13683   ,0 };
            const std::uint32_t dim1864JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   1   ,   13  ,   27  ,   29  ,   159 ,   357 ,   187 ,   613 ,   1803    ,   5563    ,   14913   ,0 };
            const std::uint32_t dim1865JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   13  ,   1   ,   5   ,   69  ,   69  ,   17  ,   527 ,   1019    ,   2565    ,   1383    ,   3695    ,0 };
            const std::uint32_t dim1866JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   3   ,   9   ,   21  ,   9   ,   151 ,   145 ,   891 ,   1961    ,   257 ,   5885    ,   5201    ,0 };
            const std::uint32_t dim1867JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   15  ,   9   ,   7   ,   31  ,   3   ,   115 ,   697 ,   369 ,   1531    ,   3581    ,   5681    ,   27421   ,0 };
            const std::uint32_t dim1868JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   9   ,   13  ,   33  ,   19  ,   191 ,   433 ,   651 ,   2023    ,   373 ,   4665    ,   15147   ,   28277   ,0 };
            const std::uint32_t dim1869JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   7   ,   27  ,   3   ,   15  ,   57  ,   137 ,   903 ,   355 ,   503 ,   3   ,   13015   ,   32415   ,0 };
            const std::uint32_t dim1870JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   1   ,   13  ,   57  ,   69  ,   55  ,   75  ,   633 ,   1271    ,   189 ,   4279    ,   1293    ,   5719    ,0 };
            const std::uint32_t dim1871JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   15  ,   27  ,   9   ,   13  ,   185 ,   211 ,   593 ,   723 ,   3725    ,   5165    ,   15375   ,   1055    ,0 };
            const std::uint32_t dim1872JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   13  ,   21  ,   11  ,   67  ,   11  ,   279 ,   503 ,   1839    ,   3509    ,   1285    ,   5251    ,   27835   ,0 };
            const std::uint32_t dim1873JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   15  ,   5   ,   45  ,   35  ,   145 ,   383 ,   227 ,   327 ,   2419    ,   5207    ,   15897   ,   20869   ,0 };
            const std::uint32_t dim1874JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   11  ,   31  ,   25  ,   69  ,   169 ,   363 ,   819 ,   1855    ,   61  ,   5613    ,   11835   ,   24761   ,0 };
            const std::uint32_t dim1875JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   9   ,   15  ,   41  ,   123 ,   61  ,   359 ,   29  ,   369 ,   1167    ,   489 ,   12947   ,   14765   ,0 };
            const std::uint32_t dim1876JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   5   ,   7   ,   33  ,   115 ,   193 ,   427 ,   123 ,   1795    ,   3153    ,   2771    ,   6761    ,   719 ,0 };
            const std::uint32_t dim1877JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   13  ,   31  ,   39  ,   5   ,   179 ,   181 ,   787 ,   1891    ,   2287    ,   2085    ,   15081   ,   2035    ,0 };
            const std::uint32_t dim1878JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   15  ,   1   ,   47  ,   15  ,   235 ,   431 ,   687 ,   1787    ,   225 ,   7749    ,   1179    ,   29243   ,0 };
            const std::uint32_t dim1879JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   13  ,   19  ,   53  ,   119 ,   131 ,   417 ,   505 ,   1179    ,   2291    ,   4795    ,   10475   ,   6307    ,0 };
            const std::uint32_t dim1880JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   13  ,   15  ,   43  ,   73  ,   3   ,   193 ,   5   ,   1843    ,   1617    ,   7557    ,   4165    ,   4089    ,0 };
            const std::uint32_t dim1881JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   5   ,   3   ,   35  ,   121 ,   183 ,   197 ,   605 ,   1775    ,   1647    ,   4929    ,   365 ,   43  ,0 };
            const std::uint32_t dim1882JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   7   ,   13  ,   31  ,   69  ,   157 ,   309 ,   99  ,   705 ,   1705    ,   2093    ,   13055   ,   6727    ,0 };
            const std::uint32_t dim1883JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   3   ,   29  ,   41  ,   109 ,   129 ,   223 ,   755 ,   595 ,   1931    ,   3967    ,   8249    ,   9439    ,0 };
            const std::uint32_t dim1884JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   1   ,   21  ,   45  ,   101 ,   229 ,   343 ,   455 ,   125 ,   1335    ,   749 ,   3967    ,   22777   ,0 };
            const std::uint32_t dim1885JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   13  ,   31  ,   49  ,   125 ,   199 ,   37  ,   685 ,   1171    ,   1793    ,   1057    ,   10041   ,   12693   ,0 };
            const std::uint32_t dim1886JoeKuoD7Init[]   =   {   1   ,   3   ,   7   ,   5   ,   19  ,   33  ,   35  ,   115 ,   269 ,   151 ,   731 ,   1803    ,   5241    ,   3667    ,   25371   ,0 };
            const std::uint32_t dim1887JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   3   ,   7   ,   27  ,   25  ,   249 ,   275 ,   331 ,   1579    ,   2911    ,   5859    ,   9893    ,   27807   ,0 };
            const std::uint32_t dim1888JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   7   ,   21  ,   41  ,   81  ,   239 ,   141 ,   861 ,   827 ,   1261    ,   6873    ,   6413    ,   19313   ,0 };
            const std::uint32_t dim1889JoeKuoD7Init[]   =   {   1   ,   1   ,   7   ,   1   ,   9   ,   51  ,   39  ,   123 ,   145 ,   929 ,   1101    ,   2505    ,   6493    ,   95  ,   17247   ,0 };
            const std::uint32_t dim1890JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   5   ,   11  ,   3   ,   47  ,   167 ,   5   ,   229 ,   1603    ,   3541    ,   5505    ,   1221    ,   899 ,0 };
            const std::uint32_t dim1891JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   9   ,   5   ,   17  ,   7   ,   21  ,   499 ,   597 ,   1775    ,   3187    ,   831 ,   10995   ,   7721    ,0 };
            const std::uint32_t dim1892JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   15  ,   27  ,   25  ,   7   ,   205 ,   341 ,   965 ,   519 ,   2907    ,   373 ,   5827    ,   14243   ,0 };
            const std::uint32_t dim1893JoeKuoD7Init[]   =   {   1   ,   3   ,   1   ,   3   ,   19  ,   27  ,   13  ,   207 ,   287 ,   983 ,   575 ,   891 ,   3869    ,   11213   ,   11377   ,0 };
            const std::uint32_t dim1894JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   9   ,   1   ,   5   ,   53  ,   7   ,   507 ,   505 ,   133 ,   3567    ,   6601    ,   7985    ,   10461   ,0 };
            const std::uint32_t dim1895JoeKuoD7Init[]   =   {   1   ,   1   ,   3   ,   9   ,   15  ,   9   ,   87  ,   231 ,   39  ,   701 ,   625 ,   2783    ,   6163    ,   6945    ,   4521    ,0 };
            const std::uint32_t dim1896JoeKuoD7Init[]   =   {   1   ,   3   ,   5   ,   7   ,   25  ,   39  ,   63  ,   215 ,   89  ,   775 ,   283 ,   2919    ,   151 ,   7233    ,   32163   ,0 };
            const std::uint32_t dim1897JoeKuoD7Init[]   =   {   1   ,   3   ,   3   ,   13  ,   31  ,   31  ,   55  ,   125 ,   433 ,   77  ,   1123    ,   3151    ,   6421    ,   6343    ,   14893   ,0 };
            const std::uint32_t dim1898JoeKuoD7Init[]   =   {   1   ,   1   ,   5   ,   9   ,   17  ,   55  ,   63  ,   31  ,   331 ,   945 ,   1953    ,   4093    ,   6875    ,   3519    ,   23329   ,0 };
            const std::uint32_t dim1899JoeKuoD7Init[]   =   {   1   ,   1   ,   1   ,   3   ,   23  ,   17  ,   17  ,   39  ,   173 ,   1013    ,   527 ,   2563    ,   3623    ,   10049   ,   10919   ,0 };

            const std::uint32_t * const JoeKuoD7initializers[1899]
            =
            {
                dim1JoeKuoD7Init,
                dim2JoeKuoD7Init,
                dim3JoeKuoD7Init,
                dim4JoeKuoD7Init,
                dim5JoeKuoD7Init,
                dim6JoeKuoD7Init,
                dim7JoeKuoD7Init,
                dim8JoeKuoD7Init,
                dim9JoeKuoD7Init,
                dim10JoeKuoD7Init,
                dim11JoeKuoD7Init,
                dim12JoeKuoD7Init,
                dim13JoeKuoD7Init,
                dim14JoeKuoD7Init,
                dim15JoeKuoD7Init,
                dim16JoeKuoD7Init,
                dim17JoeKuoD7Init,
                dim18JoeKuoD7Init,
                dim19JoeKuoD7Init,
                dim20JoeKuoD7Init,
                dim21JoeKuoD7Init,
                dim22JoeKuoD7Init,
                dim23JoeKuoD7Init,
                dim24JoeKuoD7Init,
                dim25JoeKuoD7Init,
                dim26JoeKuoD7Init,
                dim27JoeKuoD7Init,
                dim28JoeKuoD7Init,
                dim29JoeKuoD7Init,
                dim30JoeKuoD7Init,
                dim31JoeKuoD7Init,
                dim32JoeKuoD7Init,
                dim33JoeKuoD7Init,
                dim34JoeKuoD7Init,
                dim35JoeKuoD7Init,
                dim36JoeKuoD7Init,
                dim37JoeKuoD7Init,
                dim38JoeKuoD7Init,
                dim39JoeKuoD7Init,
                dim40JoeKuoD7Init,
                dim41JoeKuoD7Init,
                dim42JoeKuoD7Init,
                dim43JoeKuoD7Init,
                dim44JoeKuoD7Init,
                dim45JoeKuoD7Init,
                dim46JoeKuoD7Init,
                dim47JoeKuoD7Init,
                dim48JoeKuoD7Init,
                dim49JoeKuoD7Init,
                dim50JoeKuoD7Init,
                dim51JoeKuoD7Init,
                dim52JoeKuoD7Init,
                dim53JoeKuoD7Init,
                dim54JoeKuoD7Init,
                dim55JoeKuoD7Init,
                dim56JoeKuoD7Init,
                dim57JoeKuoD7Init,
                dim58JoeKuoD7Init,
                dim59JoeKuoD7Init,
                dim60JoeKuoD7Init,
                dim61JoeKuoD7Init,
                dim62JoeKuoD7Init,
                dim63JoeKuoD7Init,
                dim64JoeKuoD7Init,
                dim65JoeKuoD7Init,
                dim66JoeKuoD7Init,
                dim67JoeKuoD7Init,
                dim68JoeKuoD7Init,
                dim69JoeKuoD7Init,
                dim70JoeKuoD7Init,
                dim71JoeKuoD7Init,
                dim72JoeKuoD7Init,
                dim73JoeKuoD7Init,
                dim74JoeKuoD7Init,
                dim75JoeKuoD7Init,
                dim76JoeKuoD7Init,
                dim77JoeKuoD7Init,
                dim78JoeKuoD7Init,
                dim79JoeKuoD7Init,
                dim80JoeKuoD7Init,
                dim81JoeKuoD7Init,
                dim82JoeKuoD7Init,
                dim83JoeKuoD7Init,
                dim84JoeKuoD7Init,
                dim85JoeKuoD7Init,
                dim86JoeKuoD7Init,
                dim87JoeKuoD7Init,
                dim88JoeKuoD7Init,
                dim89JoeKuoD7Init,
                dim90JoeKuoD7Init,
                dim91JoeKuoD7Init,
                dim92JoeKuoD7Init,
                dim93JoeKuoD7Init,
                dim94JoeKuoD7Init,
                dim95JoeKuoD7Init,
                dim96JoeKuoD7Init,
                dim97JoeKuoD7Init,
                dim98JoeKuoD7Init,
                dim99JoeKuoD7Init,
                dim100JoeKuoD7Init,
                dim101JoeKuoD7Init,
                dim102JoeKuoD7Init,
                dim103JoeKuoD7Init,
                dim104JoeKuoD7Init,
                dim105JoeKuoD7Init,
                dim106JoeKuoD7Init,
                dim107JoeKuoD7Init,
                dim108JoeKuoD7Init,
                dim109JoeKuoD7Init,
                dim110JoeKuoD7Init,
                dim111JoeKuoD7Init,
                dim112JoeKuoD7Init,
                dim113JoeKuoD7Init,
                dim114JoeKuoD7Init,
                dim115JoeKuoD7Init,
                dim116JoeKuoD7Init,
                dim117JoeKuoD7Init,
                dim118JoeKuoD7Init,
                dim119JoeKuoD7Init,
                dim120JoeKuoD7Init,
                dim121JoeKuoD7Init,
                dim122JoeKuoD7Init,
                dim123JoeKuoD7Init,
                dim124JoeKuoD7Init,
                dim125JoeKuoD7Init,
                dim126JoeKuoD7Init,
                dim127JoeKuoD7Init,
                dim128JoeKuoD7Init,
                dim129JoeKuoD7Init,
                dim130JoeKuoD7Init,
                dim131JoeKuoD7Init,
                dim132JoeKuoD7Init,
                dim133JoeKuoD7Init,
                dim134JoeKuoD7Init,
                dim135JoeKuoD7Init,
                dim136JoeKuoD7Init,
                dim137JoeKuoD7Init,
                dim138JoeKuoD7Init,
                dim139JoeKuoD7Init,
                dim140JoeKuoD7Init,
                dim141JoeKuoD7Init,
                dim142JoeKuoD7Init,
                dim143JoeKuoD7Init,
                dim144JoeKuoD7Init,
                dim145JoeKuoD7Init,
                dim146JoeKuoD7Init,
                dim147JoeKuoD7Init,
                dim148JoeKuoD7Init,
                dim149JoeKuoD7Init,
                dim150JoeKuoD7Init,
                dim151JoeKuoD7Init,
                dim152JoeKuoD7Init,
                dim153JoeKuoD7Init,
                dim154JoeKuoD7Init,
                dim155JoeKuoD7Init,
                dim156JoeKuoD7Init,
                dim157JoeKuoD7Init,
                dim158JoeKuoD7Init,
                dim159JoeKuoD7Init,
                dim160JoeKuoD7Init,
                dim161JoeKuoD7Init,
                dim162JoeKuoD7Init,
                dim163JoeKuoD7Init,
                dim164JoeKuoD7Init,
                dim165JoeKuoD7Init,
                dim166JoeKuoD7Init,
                dim167JoeKuoD7Init,
                dim168JoeKuoD7Init,
                dim169JoeKuoD7Init,
                dim170JoeKuoD7Init,
                dim171JoeKuoD7Init,
                dim172JoeKuoD7Init,
                dim173JoeKuoD7Init,
                dim174JoeKuoD7Init,
                dim175JoeKuoD7Init,
                dim176JoeKuoD7Init,
                dim177JoeKuoD7Init,
                dim178JoeKuoD7Init,
                dim179JoeKuoD7Init,
                dim180JoeKuoD7Init,
                dim181JoeKuoD7Init,
                dim182JoeKuoD7Init,
                dim183JoeKuoD7Init,
                dim184JoeKuoD7Init,
                dim185JoeKuoD7Init,
                dim186JoeKuoD7Init,
                dim187JoeKuoD7Init,
                dim188JoeKuoD7Init,
                dim189JoeKuoD7Init,
                dim190JoeKuoD7Init,
                dim191JoeKuoD7Init,
                dim192JoeKuoD7Init,
                dim193JoeKuoD7Init,
                dim194JoeKuoD7Init,
                dim195JoeKuoD7Init,
                dim196JoeKuoD7Init,
                dim197JoeKuoD7Init,
                dim198JoeKuoD7Init,
                dim199JoeKuoD7Init,
                dim200JoeKuoD7Init,
                dim201JoeKuoD7Init,
                dim202JoeKuoD7Init,
                dim203JoeKuoD7Init,
                dim204JoeKuoD7Init,
                dim205JoeKuoD7Init,
                dim206JoeKuoD7Init,
                dim207JoeKuoD7Init,
                dim208JoeKuoD7Init,
                dim209JoeKuoD7Init,
                dim210JoeKuoD7Init,
                dim211JoeKuoD7Init,
                dim212JoeKuoD7Init,
                dim213JoeKuoD7Init,
                dim214JoeKuoD7Init,
                dim215JoeKuoD7Init,
                dim216JoeKuoD7Init,
                dim217JoeKuoD7Init,
                dim218JoeKuoD7Init,
                dim219JoeKuoD7Init,
                dim220JoeKuoD7Init,
                dim221JoeKuoD7Init,
                dim222JoeKuoD7Init,
                dim223JoeKuoD7Init,
                dim224JoeKuoD7Init,
                dim225JoeKuoD7Init,
                dim226JoeKuoD7Init,
                dim227JoeKuoD7Init,
                dim228JoeKuoD7Init,
                dim229JoeKuoD7Init,
                dim230JoeKuoD7Init,
                dim231JoeKuoD7Init,
                dim232JoeKuoD7Init,
                dim233JoeKuoD7Init,
                dim234JoeKuoD7Init,
                dim235JoeKuoD7Init,
                dim236JoeKuoD7Init,
                dim237JoeKuoD7Init,
                dim238JoeKuoD7Init,
                dim239JoeKuoD7Init,
                dim240JoeKuoD7Init,
                dim241JoeKuoD7Init,
                dim242JoeKuoD7Init,
                dim243JoeKuoD7Init,
                dim244JoeKuoD7Init,
                dim245JoeKuoD7Init,
                dim246JoeKuoD7Init,
                dim247JoeKuoD7Init,
                dim248JoeKuoD7Init,
                dim249JoeKuoD7Init,
                dim250JoeKuoD7Init,
                dim251JoeKuoD7Init,
                dim252JoeKuoD7Init,
                dim253JoeKuoD7Init,
                dim254JoeKuoD7Init,
                dim255JoeKuoD7Init,
                dim256JoeKuoD7Init,
                dim257JoeKuoD7Init,
                dim258JoeKuoD7Init,
                dim259JoeKuoD7Init,
                dim260JoeKuoD7Init,
                dim261JoeKuoD7Init,
                dim262JoeKuoD7Init,
                dim263JoeKuoD7Init,
                dim264JoeKuoD7Init,
                dim265JoeKuoD7Init,
                dim266JoeKuoD7Init,
                dim267JoeKuoD7Init,
                dim268JoeKuoD7Init,
                dim269JoeKuoD7Init,
                dim270JoeKuoD7Init,
                dim271JoeKuoD7Init,
                dim272JoeKuoD7Init,
                dim273JoeKuoD7Init,
                dim274JoeKuoD7Init,
                dim275JoeKuoD7Init,
                dim276JoeKuoD7Init,
                dim277JoeKuoD7Init,
                dim278JoeKuoD7Init,
                dim279JoeKuoD7Init,
                dim280JoeKuoD7Init,
                dim281JoeKuoD7Init,
                dim282JoeKuoD7Init,
                dim283JoeKuoD7Init,
                dim284JoeKuoD7Init,
                dim285JoeKuoD7Init,
                dim286JoeKuoD7Init,
                dim287JoeKuoD7Init,
                dim288JoeKuoD7Init,
                dim289JoeKuoD7Init,
                dim290JoeKuoD7Init,
                dim291JoeKuoD7Init,
                dim292JoeKuoD7Init,
                dim293JoeKuoD7Init,
                dim294JoeKuoD7Init,
                dim295JoeKuoD7Init,
                dim296JoeKuoD7Init,
                dim297JoeKuoD7Init,
                dim298JoeKuoD7Init,
                dim299JoeKuoD7Init,
                dim300JoeKuoD7Init,
                dim301JoeKuoD7Init,
                dim302JoeKuoD7Init,
                dim303JoeKuoD7Init,
                dim304JoeKuoD7Init,
                dim305JoeKuoD7Init,
                dim306JoeKuoD7Init,
                dim307JoeKuoD7Init,
                dim308JoeKuoD7Init,
                dim309JoeKuoD7Init,
                dim310JoeKuoD7Init,
                dim311JoeKuoD7Init,
                dim312JoeKuoD7Init,
                dim313JoeKuoD7Init,
                dim314JoeKuoD7Init,
                dim315JoeKuoD7Init,
                dim316JoeKuoD7Init,
                dim317JoeKuoD7Init,
                dim318JoeKuoD7Init,
                dim319JoeKuoD7Init,
                dim320JoeKuoD7Init,
                dim321JoeKuoD7Init,
                dim322JoeKuoD7Init,
                dim323JoeKuoD7Init,
                dim324JoeKuoD7Init,
                dim325JoeKuoD7Init,
                dim326JoeKuoD7Init,
                dim327JoeKuoD7Init,
                dim328JoeKuoD7Init,
                dim329JoeKuoD7Init,
                dim330JoeKuoD7Init,
                dim331JoeKuoD7Init,
                dim332JoeKuoD7Init,
                dim333JoeKuoD7Init,
                dim334JoeKuoD7Init,
                dim335JoeKuoD7Init,
                dim336JoeKuoD7Init,
                dim337JoeKuoD7Init,
                dim338JoeKuoD7Init,
                dim339JoeKuoD7Init,
                dim340JoeKuoD7Init,
                dim341JoeKuoD7Init,
                dim342JoeKuoD7Init,
                dim343JoeKuoD7Init,
                dim344JoeKuoD7Init,
                dim345JoeKuoD7Init,
                dim346JoeKuoD7Init,
                dim347JoeKuoD7Init,
                dim348JoeKuoD7Init,
                dim349JoeKuoD7Init,
                dim350JoeKuoD7Init,
                dim351JoeKuoD7Init,
                dim352JoeKuoD7Init,
                dim353JoeKuoD7Init,
                dim354JoeKuoD7Init,
                dim355JoeKuoD7Init,
                dim356JoeKuoD7Init,
                dim357JoeKuoD7Init,
                dim358JoeKuoD7Init,
                dim359JoeKuoD7Init,
                dim360JoeKuoD7Init,
                dim361JoeKuoD7Init,
                dim362JoeKuoD7Init,
                dim363JoeKuoD7Init,
                dim364JoeKuoD7Init,
                dim365JoeKuoD7Init,
                dim366JoeKuoD7Init,
                dim367JoeKuoD7Init,
                dim368JoeKuoD7Init,
                dim369JoeKuoD7Init,
                dim370JoeKuoD7Init,
                dim371JoeKuoD7Init,
                dim372JoeKuoD7Init,
                dim373JoeKuoD7Init,
                dim374JoeKuoD7Init,
                dim375JoeKuoD7Init,
                dim376JoeKuoD7Init,
                dim377JoeKuoD7Init,
                dim378JoeKuoD7Init,
                dim379JoeKuoD7Init,
                dim380JoeKuoD7Init,
                dim381JoeKuoD7Init,
                dim382JoeKuoD7Init,
                dim383JoeKuoD7Init,
                dim384JoeKuoD7Init,
                dim385JoeKuoD7Init,
                dim386JoeKuoD7Init,
                dim387JoeKuoD7Init,
                dim388JoeKuoD7Init,
                dim389JoeKuoD7Init,
                dim390JoeKuoD7Init,
                dim391JoeKuoD7Init,
                dim392JoeKuoD7Init,
                dim393JoeKuoD7Init,
                dim394JoeKuoD7Init,
                dim395JoeKuoD7Init,
                dim396JoeKuoD7Init,
                dim397JoeKuoD7Init,
                dim398JoeKuoD7Init,
                dim399JoeKuoD7Init,
                dim400JoeKuoD7Init,
                dim401JoeKuoD7Init,
                dim402JoeKuoD7Init,
                dim403JoeKuoD7Init,
                dim404JoeKuoD7Init,
                dim405JoeKuoD7Init,
                dim406JoeKuoD7Init,
                dim407JoeKuoD7Init,
                dim408JoeKuoD7Init,
                dim409JoeKuoD7Init,
                dim410JoeKuoD7Init,
                dim411JoeKuoD7Init,
                dim412JoeKuoD7Init,
                dim413JoeKuoD7Init,
                dim414JoeKuoD7Init,
                dim415JoeKuoD7Init,
                dim416JoeKuoD7Init,
                dim417JoeKuoD7Init,
                dim418JoeKuoD7Init,
                dim419JoeKuoD7Init,
                dim420JoeKuoD7Init,
                dim421JoeKuoD7Init,
                dim422JoeKuoD7Init,
                dim423JoeKuoD7Init,
                dim424JoeKuoD7Init,
                dim425JoeKuoD7Init,
                dim426JoeKuoD7Init,
                dim427JoeKuoD7Init,
                dim428JoeKuoD7Init,
                dim429JoeKuoD7Init,
                dim430JoeKuoD7Init,
                dim431JoeKuoD7Init,
                dim432JoeKuoD7Init,
                dim433JoeKuoD7Init,
                dim434JoeKuoD7Init,
                dim435JoeKuoD7Init,
                dim436JoeKuoD7Init,
                dim437JoeKuoD7Init,
                dim438JoeKuoD7Init,
                dim439JoeKuoD7Init,
                dim440JoeKuoD7Init,
                dim441JoeKuoD7Init,
                dim442JoeKuoD7Init,
                dim443JoeKuoD7Init,
                dim444JoeKuoD7Init,
                dim445JoeKuoD7Init,
                dim446JoeKuoD7Init,
                dim447JoeKuoD7Init,
                dim448JoeKuoD7Init,
                dim449JoeKuoD7Init,
                dim450JoeKuoD7Init,
                dim451JoeKuoD7Init,
                dim452JoeKuoD7Init,
                dim453JoeKuoD7Init,
                dim454JoeKuoD7Init,
                dim455JoeKuoD7Init,
                dim456JoeKuoD7Init,
                dim457JoeKuoD7Init,
                dim458JoeKuoD7Init,
                dim459JoeKuoD7Init,
                dim460JoeKuoD7Init,
                dim461JoeKuoD7Init,
                dim462JoeKuoD7Init,
                dim463JoeKuoD7Init,
                dim464JoeKuoD7Init,
                dim465JoeKuoD7Init,
                dim466JoeKuoD7Init,
                dim467JoeKuoD7Init,
                dim468JoeKuoD7Init,
                dim469JoeKuoD7Init,
                dim470JoeKuoD7Init,
                dim471JoeKuoD7Init,
                dim472JoeKuoD7Init,
                dim473JoeKuoD7Init,
                dim474JoeKuoD7Init,
                dim475JoeKuoD7Init,
                dim476JoeKuoD7Init,
                dim477JoeKuoD7Init,
                dim478JoeKuoD7Init,
                dim479JoeKuoD7Init,
                dim480JoeKuoD7Init,
                dim481JoeKuoD7Init,
                dim482JoeKuoD7Init,
                dim483JoeKuoD7Init,
                dim484JoeKuoD7Init,
                dim485JoeKuoD7Init,
                dim486JoeKuoD7Init,
                dim487JoeKuoD7Init,
                dim488JoeKuoD7Init,
                dim489JoeKuoD7Init,
                dim490JoeKuoD7Init,
                dim491JoeKuoD7Init,
                dim492JoeKuoD7Init,
                dim493JoeKuoD7Init,
                dim494JoeKuoD7Init,
                dim495JoeKuoD7Init,
                dim496JoeKuoD7Init,
                dim497JoeKuoD7Init,
                dim498JoeKuoD7Init,
                dim499JoeKuoD7Init,
                dim500JoeKuoD7Init,
                dim501JoeKuoD7Init,
                dim502JoeKuoD7Init,
                dim503JoeKuoD7Init,
                dim504JoeKuoD7Init,
                dim505JoeKuoD7Init,
                dim506JoeKuoD7Init,
                dim507JoeKuoD7Init,
                dim508JoeKuoD7Init,
                dim509JoeKuoD7Init,
                dim510JoeKuoD7Init,
                dim511JoeKuoD7Init,
                dim512JoeKuoD7Init,
                dim513JoeKuoD7Init,
                dim514JoeKuoD7Init,
                dim515JoeKuoD7Init,
                dim516JoeKuoD7Init,
                dim517JoeKuoD7Init,
                dim518JoeKuoD7Init,
                dim519JoeKuoD7Init,
                dim520JoeKuoD7Init,
                dim521JoeKuoD7Init,
                dim522JoeKuoD7Init,
                dim523JoeKuoD7Init,
                dim524JoeKuoD7Init,
                dim525JoeKuoD7Init,
                dim526JoeKuoD7Init,
                dim527JoeKuoD7Init,
                dim528JoeKuoD7Init,
                dim529JoeKuoD7Init,
                dim530JoeKuoD7Init,
                dim531JoeKuoD7Init,
                dim532JoeKuoD7Init,
                dim533JoeKuoD7Init,
                dim534JoeKuoD7Init,
                dim535JoeKuoD7Init,
                dim536JoeKuoD7Init,
                dim537JoeKuoD7Init,
                dim538JoeKuoD7Init,
                dim539JoeKuoD7Init,
                dim540JoeKuoD7Init,
                dim541JoeKuoD7Init,
                dim542JoeKuoD7Init,
                dim543JoeKuoD7Init,
                dim544JoeKuoD7Init,
                dim545JoeKuoD7Init,
                dim546JoeKuoD7Init,
                dim547JoeKuoD7Init,
                dim548JoeKuoD7Init,
                dim549JoeKuoD7Init,
                dim550JoeKuoD7Init,
                dim551JoeKuoD7Init,
                dim552JoeKuoD7Init,
                dim553JoeKuoD7Init,
                dim554JoeKuoD7Init,
                dim555JoeKuoD7Init,
                dim556JoeKuoD7Init,
                dim557JoeKuoD7Init,
                dim558JoeKuoD7Init,
                dim559JoeKuoD7Init,
                dim560JoeKuoD7Init,
                dim561JoeKuoD7Init,
                dim562JoeKuoD7Init,
                dim563JoeKuoD7Init,
                dim564JoeKuoD7Init,
                dim565JoeKuoD7Init,
                dim566JoeKuoD7Init,
                dim567JoeKuoD7Init,
                dim568JoeKuoD7Init,
                dim569JoeKuoD7Init,
                dim570JoeKuoD7Init,
                dim571JoeKuoD7Init,
                dim572JoeKuoD7Init,
                dim573JoeKuoD7Init,
                dim574JoeKuoD7Init,
                dim575JoeKuoD7Init,
                dim576JoeKuoD7Init,
                dim577JoeKuoD7Init,
                dim578JoeKuoD7Init,
                dim579JoeKuoD7Init,
                dim580JoeKuoD7Init,
                dim581JoeKuoD7Init,
                dim582JoeKuoD7Init,
                dim583JoeKuoD7Init,
                dim584JoeKuoD7Init,
                dim585JoeKuoD7Init,
                dim586JoeKuoD7Init,
                dim587JoeKuoD7Init,
                dim588JoeKuoD7Init,
                dim589JoeKuoD7Init,
                dim590JoeKuoD7Init,
                dim591JoeKuoD7Init,
                dim592JoeKuoD7Init,
                dim593JoeKuoD7Init,
                dim594JoeKuoD7Init,
                dim595JoeKuoD7Init,
                dim596JoeKuoD7Init,
                dim597JoeKuoD7Init,
                dim598JoeKuoD7Init,
                dim599JoeKuoD7Init,
                dim600JoeKuoD7Init,
                dim601JoeKuoD7Init,
                dim602JoeKuoD7Init,
                dim603JoeKuoD7Init,
                dim604JoeKuoD7Init,
                dim605JoeKuoD7Init,
                dim606JoeKuoD7Init,
                dim607JoeKuoD7Init,
                dim608JoeKuoD7Init,
                dim609JoeKuoD7Init,
                dim610JoeKuoD7Init,
                dim611JoeKuoD7Init,
                dim612JoeKuoD7Init,
                dim613JoeKuoD7Init,
                dim614JoeKuoD7Init,
                dim615JoeKuoD7Init,
                dim616JoeKuoD7Init,
                dim617JoeKuoD7Init,
                dim618JoeKuoD7Init,
                dim619JoeKuoD7Init,
                dim620JoeKuoD7Init,
                dim621JoeKuoD7Init,
                dim622JoeKuoD7Init,
                dim623JoeKuoD7Init,
                dim624JoeKuoD7Init,
                dim625JoeKuoD7Init,
                dim626JoeKuoD7Init,
                dim627JoeKuoD7Init,
                dim628JoeKuoD7Init,
                dim629JoeKuoD7Init,
                dim630JoeKuoD7Init,
                dim631JoeKuoD7Init,
                dim632JoeKuoD7Init,
                dim633JoeKuoD7Init,
                dim634JoeKuoD7Init,
                dim635JoeKuoD7Init,
                dim636JoeKuoD7Init,
                dim637JoeKuoD7Init,
                dim638JoeKuoD7Init,
                dim639JoeKuoD7Init,
                dim640JoeKuoD7Init,
                dim641JoeKuoD7Init,
                dim642JoeKuoD7Init,
                dim643JoeKuoD7Init,
                dim644JoeKuoD7Init,
                dim645JoeKuoD7Init,
                dim646JoeKuoD7Init,
                dim647JoeKuoD7Init,
                dim648JoeKuoD7Init,
                dim649JoeKuoD7Init,
                dim650JoeKuoD7Init,
                dim651JoeKuoD7Init,
                dim652JoeKuoD7Init,
                dim653JoeKuoD7Init,
                dim654JoeKuoD7Init,
                dim655JoeKuoD7Init,
                dim656JoeKuoD7Init,
                dim657JoeKuoD7Init,
                dim658JoeKuoD7Init,
                dim659JoeKuoD7Init,
                dim660JoeKuoD7Init,
                dim661JoeKuoD7Init,
                dim662JoeKuoD7Init,
                dim663JoeKuoD7Init,
                dim664JoeKuoD7Init,
                dim665JoeKuoD7Init,
                dim666JoeKuoD7Init,
                dim667JoeKuoD7Init,
                dim668JoeKuoD7Init,
                dim669JoeKuoD7Init,
                dim670JoeKuoD7Init,
                dim671JoeKuoD7Init,
                dim672JoeKuoD7Init,
                dim673JoeKuoD7Init,
                dim674JoeKuoD7Init,
                dim675JoeKuoD7Init,
                dim676JoeKuoD7Init,
                dim677JoeKuoD7Init,
                dim678JoeKuoD7Init,
                dim679JoeKuoD7Init,
                dim680JoeKuoD7Init,
                dim681JoeKuoD7Init,
                dim682JoeKuoD7Init,
                dim683JoeKuoD7Init,
                dim684JoeKuoD7Init,
                dim685JoeKuoD7Init,
                dim686JoeKuoD7Init,
                dim687JoeKuoD7Init,
                dim688JoeKuoD7Init,
                dim689JoeKuoD7Init,
                dim690JoeKuoD7Init,
                dim691JoeKuoD7Init,
                dim692JoeKuoD7Init,
                dim693JoeKuoD7Init,
                dim694JoeKuoD7Init,
                dim695JoeKuoD7Init,
                dim696JoeKuoD7Init,
                dim697JoeKuoD7Init,
                dim698JoeKuoD7Init,
                dim699JoeKuoD7Init,
                dim700JoeKuoD7Init,
                dim701JoeKuoD7Init,
                dim702JoeKuoD7Init,
                dim703JoeKuoD7Init,
                dim704JoeKuoD7Init,
                dim705JoeKuoD7Init,
                dim706JoeKuoD7Init,
                dim707JoeKuoD7Init,
                dim708JoeKuoD7Init,
                dim709JoeKuoD7Init,
                dim710JoeKuoD7Init,
                dim711JoeKuoD7Init,
                dim712JoeKuoD7Init,
                dim713JoeKuoD7Init,
                dim714JoeKuoD7Init,
                dim715JoeKuoD7Init,
                dim716JoeKuoD7Init,
                dim717JoeKuoD7Init,
                dim718JoeKuoD7Init,
                dim719JoeKuoD7Init,
                dim720JoeKuoD7Init,
                dim721JoeKuoD7Init,
                dim722JoeKuoD7Init,
                dim723JoeKuoD7Init,
                dim724JoeKuoD7Init,
                dim725JoeKuoD7Init,
                dim726JoeKuoD7Init,
                dim727JoeKuoD7Init,
                dim728JoeKuoD7Init,
                dim729JoeKuoD7Init,
                dim730JoeKuoD7Init,
                dim731JoeKuoD7Init,
                dim732JoeKuoD7Init,
                dim733JoeKuoD7Init,
                dim734JoeKuoD7Init,
                dim735JoeKuoD7Init,
                dim736JoeKuoD7Init,
                dim737JoeKuoD7Init,
                dim738JoeKuoD7Init,
                dim739JoeKuoD7Init,
                dim740JoeKuoD7Init,
                dim741JoeKuoD7Init,
                dim742JoeKuoD7Init,
                dim743JoeKuoD7Init,
                dim744JoeKuoD7Init,
                dim745JoeKuoD7Init,
                dim746JoeKuoD7Init,
                dim747JoeKuoD7Init,
                dim748JoeKuoD7Init,
                dim749JoeKuoD7Init,
                dim750JoeKuoD7Init,
                dim751JoeKuoD7Init,
                dim752JoeKuoD7Init,
                dim753JoeKuoD7Init,
                dim754JoeKuoD7Init,
                dim755JoeKuoD7Init,
                dim756JoeKuoD7Init,
                dim757JoeKuoD7Init,
                dim758JoeKuoD7Init,
                dim759JoeKuoD7Init,
                dim760JoeKuoD7Init,
                dim761JoeKuoD7Init,
                dim762JoeKuoD7Init,
                dim763JoeKuoD7Init,
                dim764JoeKuoD7Init,
                dim765JoeKuoD7Init,
                dim766JoeKuoD7Init,
                dim767JoeKuoD7Init,
                dim768JoeKuoD7Init,
                dim769JoeKuoD7Init,
                dim770JoeKuoD7Init,
                dim771JoeKuoD7Init,
                dim772JoeKuoD7Init,
                dim773JoeKuoD7Init,
                dim774JoeKuoD7Init,
                dim775JoeKuoD7Init,
                dim776JoeKuoD7Init,
                dim777JoeKuoD7Init,
                dim778JoeKuoD7Init,
                dim779JoeKuoD7Init,
                dim780JoeKuoD7Init,
                dim781JoeKuoD7Init,
                dim782JoeKuoD7Init,
                dim783JoeKuoD7Init,
                dim784JoeKuoD7Init,
                dim785JoeKuoD7Init,
                dim786JoeKuoD7Init,
                dim787JoeKuoD7Init,
                dim788JoeKuoD7Init,
                dim789JoeKuoD7Init,
                dim790JoeKuoD7Init,
                dim791JoeKuoD7Init,
                dim792JoeKuoD7Init,
                dim793JoeKuoD7Init,
                dim794JoeKuoD7Init,
                dim795JoeKuoD7Init,
                dim796JoeKuoD7Init,
                dim797JoeKuoD7Init,
                dim798JoeKuoD7Init,
                dim799JoeKuoD7Init,
                dim800JoeKuoD7Init,
                dim801JoeKuoD7Init,
                dim802JoeKuoD7Init,
                dim803JoeKuoD7Init,
                dim804JoeKuoD7Init,
                dim805JoeKuoD7Init,
                dim806JoeKuoD7Init,
                dim807JoeKuoD7Init,
                dim808JoeKuoD7Init,
                dim809JoeKuoD7Init,
                dim810JoeKuoD7Init,
                dim811JoeKuoD7Init,
                dim812JoeKuoD7Init,
                dim813JoeKuoD7Init,
                dim814JoeKuoD7Init,
                dim815JoeKuoD7Init,
                dim816JoeKuoD7Init,
                dim817JoeKuoD7Init,
                dim818JoeKuoD7Init,
                dim819JoeKuoD7Init,
                dim820JoeKuoD7Init,
                dim821JoeKuoD7Init,
                dim822JoeKuoD7Init,
                dim823JoeKuoD7Init,
                dim824JoeKuoD7Init,
                dim825JoeKuoD7Init,
                dim826JoeKuoD7Init,
                dim827JoeKuoD7Init,
                dim828JoeKuoD7Init,
                dim829JoeKuoD7Init,
                dim830JoeKuoD7Init,
                dim831JoeKuoD7Init,
                dim832JoeKuoD7Init,
                dim833JoeKuoD7Init,
                dim834JoeKuoD7Init,
                dim835JoeKuoD7Init,
                dim836JoeKuoD7Init,
                dim837JoeKuoD7Init,
                dim838JoeKuoD7Init,
                dim839JoeKuoD7Init,
                dim840JoeKuoD7Init,
                dim841JoeKuoD7Init,
                dim842JoeKuoD7Init,
                dim843JoeKuoD7Init,
                dim844JoeKuoD7Init,
                dim845JoeKuoD7Init,
                dim846JoeKuoD7Init,
                dim847JoeKuoD7Init,
                dim848JoeKuoD7Init,
                dim849JoeKuoD7Init,
                dim850JoeKuoD7Init,
                dim851JoeKuoD7Init,
                dim852JoeKuoD7Init,
                dim853JoeKuoD7Init,
                dim854JoeKuoD7Init,
                dim855JoeKuoD7Init,
                dim856JoeKuoD7Init,
                dim857JoeKuoD7Init,
                dim858JoeKuoD7Init,
                dim859JoeKuoD7Init,
                dim860JoeKuoD7Init,
                dim861JoeKuoD7Init,
                dim862JoeKuoD7Init,
                dim863JoeKuoD7Init,
                dim864JoeKuoD7Init,
                dim865JoeKuoD7Init,
                dim866JoeKuoD7Init,
                dim867JoeKuoD7Init,
                dim868JoeKuoD7Init,
                dim869JoeKuoD7Init,
                dim870JoeKuoD7Init,
                dim871JoeKuoD7Init,
                dim872JoeKuoD7Init,
                dim873JoeKuoD7Init,
                dim874JoeKuoD7Init,
                dim875JoeKuoD7Init,
                dim876JoeKuoD7Init,
                dim877JoeKuoD7Init,
                dim878JoeKuoD7Init,
                dim879JoeKuoD7Init,
                dim880JoeKuoD7Init,
                dim881JoeKuoD7Init,
                dim882JoeKuoD7Init,
                dim883JoeKuoD7Init,
                dim884JoeKuoD7Init,
                dim885JoeKuoD7Init,
                dim886JoeKuoD7Init,
                dim887JoeKuoD7Init,
                dim888JoeKuoD7Init,
                dim889JoeKuoD7Init,
                dim890JoeKuoD7Init,
                dim891JoeKuoD7Init,
                dim892JoeKuoD7Init,
                dim893JoeKuoD7Init,
                dim894JoeKuoD7Init,
                dim895JoeKuoD7Init,
                dim896JoeKuoD7Init,
                dim897JoeKuoD7Init,
                dim898JoeKuoD7Init,
                dim899JoeKuoD7Init,
                dim900JoeKuoD7Init,
                dim901JoeKuoD7Init,
                dim902JoeKuoD7Init,
                dim903JoeKuoD7Init,
                dim904JoeKuoD7Init,
                dim905JoeKuoD7Init,
                dim906JoeKuoD7Init,
                dim907JoeKuoD7Init,
                dim908JoeKuoD7Init,
                dim909JoeKuoD7Init,
                dim910JoeKuoD7Init,
                dim911JoeKuoD7Init,
                dim912JoeKuoD7Init,
                dim913JoeKuoD7Init,
                dim914JoeKuoD7Init,
                dim915JoeKuoD7Init,
                dim916JoeKuoD7Init,
                dim917JoeKuoD7Init,
                dim918JoeKuoD7Init,
                dim919JoeKuoD7Init,
                dim920JoeKuoD7Init,
                dim921JoeKuoD7Init,
                dim922JoeKuoD7Init,
                dim923JoeKuoD7Init,
                dim924JoeKuoD7Init,
                dim925JoeKuoD7Init,
                dim926JoeKuoD7Init,
                dim927JoeKuoD7Init,
                dim928JoeKuoD7Init,
                dim929JoeKuoD7Init,
                dim930JoeKuoD7Init,
                dim931JoeKuoD7Init,
                dim932JoeKuoD7Init,
                dim933JoeKuoD7Init,
                dim934JoeKuoD7Init,
                dim935JoeKuoD7Init,
                dim936JoeKuoD7Init,
                dim937JoeKuoD7Init,
                dim938JoeKuoD7Init,
                dim939JoeKuoD7Init,
                dim940JoeKuoD7Init,
                dim941JoeKuoD7Init,
                dim942JoeKuoD7Init,
                dim943JoeKuoD7Init,
                dim944JoeKuoD7Init,
                dim945JoeKuoD7Init,
                dim946JoeKuoD7Init,
                dim947JoeKuoD7Init,
                dim948JoeKuoD7Init,
                dim949JoeKuoD7Init,
                dim950JoeKuoD7Init,
                dim951JoeKuoD7Init,
                dim952JoeKuoD7Init,
                dim953JoeKuoD7Init,
                dim954JoeKuoD7Init,
                dim955JoeKuoD7Init,
                dim956JoeKuoD7Init,
                dim957JoeKuoD7Init,
                dim958JoeKuoD7Init,
                dim959JoeKuoD7Init,
                dim960JoeKuoD7Init,
                dim961JoeKuoD7Init,
                dim962JoeKuoD7Init,
                dim963JoeKuoD7Init,
                dim964JoeKuoD7Init,
                dim965JoeKuoD7Init,
                dim966JoeKuoD7Init,
                dim967JoeKuoD7Init,
                dim968JoeKuoD7Init,
                dim969JoeKuoD7Init,
                dim970JoeKuoD7Init,
                dim971JoeKuoD7Init,
                dim972JoeKuoD7Init,
                dim973JoeKuoD7Init,
                dim974JoeKuoD7Init,
                dim975JoeKuoD7Init,
                dim976JoeKuoD7Init,
                dim977JoeKuoD7Init,
                dim978JoeKuoD7Init,
                dim979JoeKuoD7Init,
                dim980JoeKuoD7Init,
                dim981JoeKuoD7Init,
                dim982JoeKuoD7Init,
                dim983JoeKuoD7Init,
                dim984JoeKuoD7Init,
                dim985JoeKuoD7Init,
                dim986JoeKuoD7Init,
                dim987JoeKuoD7Init,
                dim988JoeKuoD7Init,
                dim989JoeKuoD7Init,
                dim990JoeKuoD7Init,
                dim991JoeKuoD7Init,
                dim992JoeKuoD7Init,
                dim993JoeKuoD7Init,
                dim994JoeKuoD7Init,
                dim995JoeKuoD7Init,
                dim996JoeKuoD7Init,
                dim997JoeKuoD7Init,
                dim998JoeKuoD7Init,
                dim999JoeKuoD7Init,
                dim1000JoeKuoD7Init,
                dim1001JoeKuoD7Init,
                dim1002JoeKuoD7Init,
                dim1003JoeKuoD7Init,
                dim1004JoeKuoD7Init,
                dim1005JoeKuoD7Init,
                dim1006JoeKuoD7Init,
                dim1007JoeKuoD7Init,
                dim1008JoeKuoD7Init,
                dim1009JoeKuoD7Init,
                dim1010JoeKuoD7Init,
                dim1011JoeKuoD7Init,
                dim1012JoeKuoD7Init,
                dim1013JoeKuoD7Init,
                dim1014JoeKuoD7Init,
                dim1015JoeKuoD7Init,
                dim1016JoeKuoD7Init,
                dim1017JoeKuoD7Init,
                dim1018JoeKuoD7Init,
                dim1019JoeKuoD7Init,
                dim1020JoeKuoD7Init,
                dim1021JoeKuoD7Init,
                dim1022JoeKuoD7Init,
                dim1023JoeKuoD7Init,
                dim1024JoeKuoD7Init,
                dim1025JoeKuoD7Init,
                dim1026JoeKuoD7Init,
                dim1027JoeKuoD7Init,
                dim1028JoeKuoD7Init,
                dim1029JoeKuoD7Init,
                dim1030JoeKuoD7Init,
                dim1031JoeKuoD7Init,
                dim1032JoeKuoD7Init,
                dim1033JoeKuoD7Init,
                dim1034JoeKuoD7Init,
                dim1035JoeKuoD7Init,
                dim1036JoeKuoD7Init,
                dim1037JoeKuoD7Init,
                dim1038JoeKuoD7Init,
                dim1039JoeKuoD7Init,
                dim1040JoeKuoD7Init,
                dim1041JoeKuoD7Init,
                dim1042JoeKuoD7Init,
                dim1043JoeKuoD7Init,
                dim1044JoeKuoD7Init,
                dim1045JoeKuoD7Init,
                dim1046JoeKuoD7Init,
                dim1047JoeKuoD7Init,
                dim1048JoeKuoD7Init,
                dim1049JoeKuoD7Init,
                dim1050JoeKuoD7Init,
                dim1051JoeKuoD7Init,
                dim1052JoeKuoD7Init,
                dim1053JoeKuoD7Init,
                dim1054JoeKuoD7Init,
                dim1055JoeKuoD7Init,
                dim1056JoeKuoD7Init,
                dim1057JoeKuoD7Init,
                dim1058JoeKuoD7Init,
                dim1059JoeKuoD7Init,
                dim1060JoeKuoD7Init,
                dim1061JoeKuoD7Init,
                dim1062JoeKuoD7Init,
                dim1063JoeKuoD7Init,
                dim1064JoeKuoD7Init,
                dim1065JoeKuoD7Init,
                dim1066JoeKuoD7Init,
                dim1067JoeKuoD7Init,
                dim1068JoeKuoD7Init,
                dim1069JoeKuoD7Init,
                dim1070JoeKuoD7Init,
                dim1071JoeKuoD7Init,
                dim1072JoeKuoD7Init,
                dim1073JoeKuoD7Init,
                dim1074JoeKuoD7Init,
                dim1075JoeKuoD7Init,
                dim1076JoeKuoD7Init,
                dim1077JoeKuoD7Init,
                dim1078JoeKuoD7Init,
                dim1079JoeKuoD7Init,
                dim1080JoeKuoD7Init,
                dim1081JoeKuoD7Init,
                dim1082JoeKuoD7Init,
                dim1083JoeKuoD7Init,
                dim1084JoeKuoD7Init,
                dim1085JoeKuoD7Init,
                dim1086JoeKuoD7Init,
                dim1087JoeKuoD7Init,
                dim1088JoeKuoD7Init,
                dim1089JoeKuoD7Init,
                dim1090JoeKuoD7Init,
                dim1091JoeKuoD7Init,
                dim1092JoeKuoD7Init,
                dim1093JoeKuoD7Init,
                dim1094JoeKuoD7Init,
                dim1095JoeKuoD7Init,
                dim1096JoeKuoD7Init,
                dim1097JoeKuoD7Init,
                dim1098JoeKuoD7Init,
                dim1099JoeKuoD7Init,
                dim1100JoeKuoD7Init,
                dim1101JoeKuoD7Init,
                dim1102JoeKuoD7Init,
                dim1103JoeKuoD7Init,
                dim1104JoeKuoD7Init,
                dim1105JoeKuoD7Init,
                dim1106JoeKuoD7Init,
                dim1107JoeKuoD7Init,
                dim1108JoeKuoD7Init,
                dim1109JoeKuoD7Init,
                dim1110JoeKuoD7Init,
                dim1111JoeKuoD7Init,
                dim1112JoeKuoD7Init,
                dim1113JoeKuoD7Init,
                dim1114JoeKuoD7Init,
                dim1115JoeKuoD7Init,
                dim1116JoeKuoD7Init,
                dim1117JoeKuoD7Init,
                dim1118JoeKuoD7Init,
                dim1119JoeKuoD7Init,
                dim1120JoeKuoD7Init,
                dim1121JoeKuoD7Init,
                dim1122JoeKuoD7Init,
                dim1123JoeKuoD7Init,
                dim1124JoeKuoD7Init,
                dim1125JoeKuoD7Init,
                dim1126JoeKuoD7Init,
                dim1127JoeKuoD7Init,
                dim1128JoeKuoD7Init,
                dim1129JoeKuoD7Init,
                dim1130JoeKuoD7Init,
                dim1131JoeKuoD7Init,
                dim1132JoeKuoD7Init,
                dim1133JoeKuoD7Init,
                dim1134JoeKuoD7Init,
                dim1135JoeKuoD7Init,
                dim1136JoeKuoD7Init,
                dim1137JoeKuoD7Init,
                dim1138JoeKuoD7Init,
                dim1139JoeKuoD7Init,
                dim1140JoeKuoD7Init,
                dim1141JoeKuoD7Init,
                dim1142JoeKuoD7Init,
                dim1143JoeKuoD7Init,
                dim1144JoeKuoD7Init,
                dim1145JoeKuoD7Init,
                dim1146JoeKuoD7Init,
                dim1147JoeKuoD7Init,
                dim1148JoeKuoD7Init,
                dim1149JoeKuoD7Init,
                dim1150JoeKuoD7Init,
                dim1151JoeKuoD7Init,
                dim1152JoeKuoD7Init,
                dim1153JoeKuoD7Init,
                dim1154JoeKuoD7Init,
                dim1155JoeKuoD7Init,
                dim1156JoeKuoD7Init,
                dim1157JoeKuoD7Init,
                dim1158JoeKuoD7Init,
                dim1159JoeKuoD7Init,
                dim1160JoeKuoD7Init,
                dim1161JoeKuoD7Init,
                dim1162JoeKuoD7Init,
                dim1163JoeKuoD7Init,
                dim1164JoeKuoD7Init,
                dim1165JoeKuoD7Init,
                dim1166JoeKuoD7Init,
                dim1167JoeKuoD7Init,
                dim1168JoeKuoD7Init,
                dim1169JoeKuoD7Init,
                dim1170JoeKuoD7Init,
                dim1171JoeKuoD7Init,
                dim1172JoeKuoD7Init,
                dim1173JoeKuoD7Init,
                dim1174JoeKuoD7Init,
                dim1175JoeKuoD7Init,
                dim1176JoeKuoD7Init,
                dim1177JoeKuoD7Init,
                dim1178JoeKuoD7Init,
                dim1179JoeKuoD7Init,
                dim1180JoeKuoD7Init,
                dim1181JoeKuoD7Init,
                dim1182JoeKuoD7Init,
                dim1183JoeKuoD7Init,
                dim1184JoeKuoD7Init,
                dim1185JoeKuoD7Init,
                dim1186JoeKuoD7Init,
                dim1187JoeKuoD7Init,
                dim1188JoeKuoD7Init,
                dim1189JoeKuoD7Init,
                dim1190JoeKuoD7Init,
                dim1191JoeKuoD7Init,
                dim1192JoeKuoD7Init,
                dim1193JoeKuoD7Init,
                dim1194JoeKuoD7Init,
                dim1195JoeKuoD7Init,
                dim1196JoeKuoD7Init,
                dim1197JoeKuoD7Init,
                dim1198JoeKuoD7Init,
                dim1199JoeKuoD7Init,
                dim1200JoeKuoD7Init,
                dim1201JoeKuoD7Init,
                dim1202JoeKuoD7Init,
                dim1203JoeKuoD7Init,
                dim1204JoeKuoD7Init,
                dim1205JoeKuoD7Init,
                dim1206JoeKuoD7Init,
                dim1207JoeKuoD7Init,
                dim1208JoeKuoD7Init,
                dim1209JoeKuoD7Init,
                dim1210JoeKuoD7Init,
                dim1211JoeKuoD7Init,
                dim1212JoeKuoD7Init,
                dim1213JoeKuoD7Init,
                dim1214JoeKuoD7Init,
                dim1215JoeKuoD7Init,
                dim1216JoeKuoD7Init,
                dim1217JoeKuoD7Init,
                dim1218JoeKuoD7Init,
                dim1219JoeKuoD7Init,
                dim1220JoeKuoD7Init,
                dim1221JoeKuoD7Init,
                dim1222JoeKuoD7Init,
                dim1223JoeKuoD7Init,
                dim1224JoeKuoD7Init,
                dim1225JoeKuoD7Init,
                dim1226JoeKuoD7Init,
                dim1227JoeKuoD7Init,
                dim1228JoeKuoD7Init,
                dim1229JoeKuoD7Init,
                dim1230JoeKuoD7Init,
                dim1231JoeKuoD7Init,
                dim1232JoeKuoD7Init,
                dim1233JoeKuoD7Init,
                dim1234JoeKuoD7Init,
                dim1235JoeKuoD7Init,
                dim1236JoeKuoD7Init,
                dim1237JoeKuoD7Init,
                dim1238JoeKuoD7Init,
                dim1239JoeKuoD7Init,
                dim1240JoeKuoD7Init,
                dim1241JoeKuoD7Init,
                dim1242JoeKuoD7Init,
                dim1243JoeKuoD7Init,
                dim1244JoeKuoD7Init,
                dim1245JoeKuoD7Init,
                dim1246JoeKuoD7Init,
                dim1247JoeKuoD7Init,
                dim1248JoeKuoD7Init,
                dim1249JoeKuoD7Init,
                dim1250JoeKuoD7Init,
                dim1251JoeKuoD7Init,
                dim1252JoeKuoD7Init,
                dim1253JoeKuoD7Init,
                dim1254JoeKuoD7Init,
                dim1255JoeKuoD7Init,
                dim1256JoeKuoD7Init,
                dim1257JoeKuoD7Init,
                dim1258JoeKuoD7Init,
                dim1259JoeKuoD7Init,
                dim1260JoeKuoD7Init,
                dim1261JoeKuoD7Init,
                dim1262JoeKuoD7Init,
                dim1263JoeKuoD7Init,
                dim1264JoeKuoD7Init,
                dim1265JoeKuoD7Init,
                dim1266JoeKuoD7Init,
                dim1267JoeKuoD7Init,
                dim1268JoeKuoD7Init,
                dim1269JoeKuoD7Init,
                dim1270JoeKuoD7Init,
                dim1271JoeKuoD7Init,
                dim1272JoeKuoD7Init,
                dim1273JoeKuoD7Init,
                dim1274JoeKuoD7Init,
                dim1275JoeKuoD7Init,
                dim1276JoeKuoD7Init,
                dim1277JoeKuoD7Init,
                dim1278JoeKuoD7Init,
                dim1279JoeKuoD7Init,
                dim1280JoeKuoD7Init,
                dim1281JoeKuoD7Init,
                dim1282JoeKuoD7Init,
                dim1283JoeKuoD7Init,
                dim1284JoeKuoD7Init,
                dim1285JoeKuoD7Init,
                dim1286JoeKuoD7Init,
                dim1287JoeKuoD7Init,
                dim1288JoeKuoD7Init,
                dim1289JoeKuoD7Init,
                dim1290JoeKuoD7Init,
                dim1291JoeKuoD7Init,
                dim1292JoeKuoD7Init,
                dim1293JoeKuoD7Init,
                dim1294JoeKuoD7Init,
                dim1295JoeKuoD7Init,
                dim1296JoeKuoD7Init,
                dim1297JoeKuoD7Init,
                dim1298JoeKuoD7Init,
                dim1299JoeKuoD7Init,
                dim1300JoeKuoD7Init,
                dim1301JoeKuoD7Init,
                dim1302JoeKuoD7Init,
                dim1303JoeKuoD7Init,
                dim1304JoeKuoD7Init,
                dim1305JoeKuoD7Init,
                dim1306JoeKuoD7Init,
                dim1307JoeKuoD7Init,
                dim1308JoeKuoD7Init,
                dim1309JoeKuoD7Init,
                dim1310JoeKuoD7Init,
                dim1311JoeKuoD7Init,
                dim1312JoeKuoD7Init,
                dim1313JoeKuoD7Init,
                dim1314JoeKuoD7Init,
                dim1315JoeKuoD7Init,
                dim1316JoeKuoD7Init,
                dim1317JoeKuoD7Init,
                dim1318JoeKuoD7Init,
                dim1319JoeKuoD7Init,
                dim1320JoeKuoD7Init,
                dim1321JoeKuoD7Init,
                dim1322JoeKuoD7Init,
                dim1323JoeKuoD7Init,
                dim1324JoeKuoD7Init,
                dim1325JoeKuoD7Init,
                dim1326JoeKuoD7Init,
                dim1327JoeKuoD7Init,
                dim1328JoeKuoD7Init,
                dim1329JoeKuoD7Init,
                dim1330JoeKuoD7Init,
                dim1331JoeKuoD7Init,
                dim1332JoeKuoD7Init,
                dim1333JoeKuoD7Init,
                dim1334JoeKuoD7Init,
                dim1335JoeKuoD7Init,
                dim1336JoeKuoD7Init,
                dim1337JoeKuoD7Init,
                dim1338JoeKuoD7Init,
                dim1339JoeKuoD7Init,
                dim1340JoeKuoD7Init,
                dim1341JoeKuoD7Init,
                dim1342JoeKuoD7Init,
                dim1343JoeKuoD7Init,
                dim1344JoeKuoD7Init,
                dim1345JoeKuoD7Init,
                dim1346JoeKuoD7Init,
                dim1347JoeKuoD7Init,
                dim1348JoeKuoD7Init,
                dim1349JoeKuoD7Init,
                dim1350JoeKuoD7Init,
                dim1351JoeKuoD7Init,
                dim1352JoeKuoD7Init,
                dim1353JoeKuoD7Init,
                dim1354JoeKuoD7Init,
                dim1355JoeKuoD7Init,
                dim1356JoeKuoD7Init,
                dim1357JoeKuoD7Init,
                dim1358JoeKuoD7Init,
                dim1359JoeKuoD7Init,
                dim1360JoeKuoD7Init,
                dim1361JoeKuoD7Init,
                dim1362JoeKuoD7Init,
                dim1363JoeKuoD7Init,
                dim1364JoeKuoD7Init,
                dim1365JoeKuoD7Init,
                dim1366JoeKuoD7Init,
                dim1367JoeKuoD7Init,
                dim1368JoeKuoD7Init,
                dim1369JoeKuoD7Init,
                dim1370JoeKuoD7Init,
                dim1371JoeKuoD7Init,
                dim1372JoeKuoD7Init,
                dim1373JoeKuoD7Init,
                dim1374JoeKuoD7Init,
                dim1375JoeKuoD7Init,
                dim1376JoeKuoD7Init,
                dim1377JoeKuoD7Init,
                dim1378JoeKuoD7Init,
                dim1379JoeKuoD7Init,
                dim1380JoeKuoD7Init,
                dim1381JoeKuoD7Init,
                dim1382JoeKuoD7Init,
                dim1383JoeKuoD7Init,
                dim1384JoeKuoD7Init,
                dim1385JoeKuoD7Init,
                dim1386JoeKuoD7Init,
                dim1387JoeKuoD7Init,
                dim1388JoeKuoD7Init,
                dim1389JoeKuoD7Init,
                dim1390JoeKuoD7Init,
                dim1391JoeKuoD7Init,
                dim1392JoeKuoD7Init,
                dim1393JoeKuoD7Init,
                dim1394JoeKuoD7Init,
                dim1395JoeKuoD7Init,
                dim1396JoeKuoD7Init,
                dim1397JoeKuoD7Init,
                dim1398JoeKuoD7Init,
                dim1399JoeKuoD7Init,
                dim1400JoeKuoD7Init,
                dim1401JoeKuoD7Init,
                dim1402JoeKuoD7Init,
                dim1403JoeKuoD7Init,
                dim1404JoeKuoD7Init,
                dim1405JoeKuoD7Init,
                dim1406JoeKuoD7Init,
                dim1407JoeKuoD7Init,
                dim1408JoeKuoD7Init,
                dim1409JoeKuoD7Init,
                dim1410JoeKuoD7Init,
                dim1411JoeKuoD7Init,
                dim1412JoeKuoD7Init,
                dim1413JoeKuoD7Init,
                dim1414JoeKuoD7Init,
                dim1415JoeKuoD7Init,
                dim1416JoeKuoD7Init,
                dim1417JoeKuoD7Init,
                dim1418JoeKuoD7Init,
                dim1419JoeKuoD7Init,
                dim1420JoeKuoD7Init,
                dim1421JoeKuoD7Init,
                dim1422JoeKuoD7Init,
                dim1423JoeKuoD7Init,
                dim1424JoeKuoD7Init,
                dim1425JoeKuoD7Init,
                dim1426JoeKuoD7Init,
                dim1427JoeKuoD7Init,
                dim1428JoeKuoD7Init,
                dim1429JoeKuoD7Init,
                dim1430JoeKuoD7Init,
                dim1431JoeKuoD7Init,
                dim1432JoeKuoD7Init,
                dim1433JoeKuoD7Init,
                dim1434JoeKuoD7Init,
                dim1435JoeKuoD7Init,
                dim1436JoeKuoD7Init,
                dim1437JoeKuoD7Init,
                dim1438JoeKuoD7Init,
                dim1439JoeKuoD7Init,
                dim1440JoeKuoD7Init,
                dim1441JoeKuoD7Init,
                dim1442JoeKuoD7Init,
                dim1443JoeKuoD7Init,
                dim1444JoeKuoD7Init,
                dim1445JoeKuoD7Init,
                dim1446JoeKuoD7Init,
                dim1447JoeKuoD7Init,
                dim1448JoeKuoD7Init,
                dim1449JoeKuoD7Init,
                dim1450JoeKuoD7Init,
                dim1451JoeKuoD7Init,
                dim1452JoeKuoD7Init,
                dim1453JoeKuoD7Init,
                dim1454JoeKuoD7Init,
                dim1455JoeKuoD7Init,
                dim1456JoeKuoD7Init,
                dim1457JoeKuoD7Init,
                dim1458JoeKuoD7Init,
                dim1459JoeKuoD7Init,
                dim1460JoeKuoD7Init,
                dim1461JoeKuoD7Init,
                dim1462JoeKuoD7Init,
                dim1463JoeKuoD7Init,
                dim1464JoeKuoD7Init,
                dim1465JoeKuoD7Init,
                dim1466JoeKuoD7Init,
                dim1467JoeKuoD7Init,
                dim1468JoeKuoD7Init,
                dim1469JoeKuoD7Init,
                dim1470JoeKuoD7Init,
                dim1471JoeKuoD7Init,
                dim1472JoeKuoD7Init,
                dim1473JoeKuoD7Init,
                dim1474JoeKuoD7Init,
                dim1475JoeKuoD7Init,
                dim1476JoeKuoD7Init,
                dim1477JoeKuoD7Init,
                dim1478JoeKuoD7Init,
                dim1479JoeKuoD7Init,
                dim1480JoeKuoD7Init,
                dim1481JoeKuoD7Init,
                dim1482JoeKuoD7Init,
                dim1483JoeKuoD7Init,
                dim1484JoeKuoD7Init,
                dim1485JoeKuoD7Init,
                dim1486JoeKuoD7Init,
                dim1487JoeKuoD7Init,
                dim1488JoeKuoD7Init,
                dim1489JoeKuoD7Init,
                dim1490JoeKuoD7Init,
                dim1491JoeKuoD7Init,
                dim1492JoeKuoD7Init,
                dim1493JoeKuoD7Init,
                dim1494JoeKuoD7Init,
                dim1495JoeKuoD7Init,
                dim1496JoeKuoD7Init,
                dim1497JoeKuoD7Init,
                dim1498JoeKuoD7Init,
                dim1499JoeKuoD7Init,
                dim1500JoeKuoD7Init,
                dim1501JoeKuoD7Init,
                dim1502JoeKuoD7Init,
                dim1503JoeKuoD7Init,
                dim1504JoeKuoD7Init,
                dim1505JoeKuoD7Init,
                dim1506JoeKuoD7Init,
                dim1507JoeKuoD7Init,
                dim1508JoeKuoD7Init,
                dim1509JoeKuoD7Init,
                dim1510JoeKuoD7Init,
                dim1511JoeKuoD7Init,
                dim1512JoeKuoD7Init,
                dim1513JoeKuoD7Init,
                dim1514JoeKuoD7Init,
                dim1515JoeKuoD7Init,
                dim1516JoeKuoD7Init,
                dim1517JoeKuoD7Init,
                dim1518JoeKuoD7Init,
                dim1519JoeKuoD7Init,
                dim1520JoeKuoD7Init,
                dim1521JoeKuoD7Init,
                dim1522JoeKuoD7Init,
                dim1523JoeKuoD7Init,
                dim1524JoeKuoD7Init,
                dim1525JoeKuoD7Init,
                dim1526JoeKuoD7Init,
                dim1527JoeKuoD7Init,
                dim1528JoeKuoD7Init,
                dim1529JoeKuoD7Init,
                dim1530JoeKuoD7Init,
                dim1531JoeKuoD7Init,
                dim1532JoeKuoD7Init,
                dim1533JoeKuoD7Init,
                dim1534JoeKuoD7Init,
                dim1535JoeKuoD7Init,
                dim1536JoeKuoD7Init,
                dim1537JoeKuoD7Init,
                dim1538JoeKuoD7Init,
                dim1539JoeKuoD7Init,
                dim1540JoeKuoD7Init,
                dim1541JoeKuoD7Init,
                dim1542JoeKuoD7Init,
                dim1543JoeKuoD7Init,
                dim1544JoeKuoD7Init,
                dim1545JoeKuoD7Init,
                dim1546JoeKuoD7Init,
                dim1547JoeKuoD7Init,
                dim1548JoeKuoD7Init,
                dim1549JoeKuoD7Init,
                dim1550JoeKuoD7Init,
                dim1551JoeKuoD7Init,
                dim1552JoeKuoD7Init,
                dim1553JoeKuoD7Init,
                dim1554JoeKuoD7Init,
                dim1555JoeKuoD7Init,
                dim1556JoeKuoD7Init,
                dim1557JoeKuoD7Init,
                dim1558JoeKuoD7Init,
                dim1559JoeKuoD7Init,
                dim1560JoeKuoD7Init,
                dim1561JoeKuoD7Init,
                dim1562JoeKuoD7Init,
                dim1563JoeKuoD7Init,
                dim1564JoeKuoD7Init,
                dim1565JoeKuoD7Init,
                dim1566JoeKuoD7Init,
                dim1567JoeKuoD7Init,
                dim1568JoeKuoD7Init,
                dim1569JoeKuoD7Init,
                dim1570JoeKuoD7Init,
                dim1571JoeKuoD7Init,
                dim1572JoeKuoD7Init,
                dim1573JoeKuoD7Init,
                dim1574JoeKuoD7Init,
                dim1575JoeKuoD7Init,
                dim1576JoeKuoD7Init,
                dim1577JoeKuoD7Init,
                dim1578JoeKuoD7Init,
                dim1579JoeKuoD7Init,
                dim1580JoeKuoD7Init,
                dim1581JoeKuoD7Init,
                dim1582JoeKuoD7Init,
                dim1583JoeKuoD7Init,
                dim1584JoeKuoD7Init,
                dim1585JoeKuoD7Init,
                dim1586JoeKuoD7Init,
                dim1587JoeKuoD7Init,
                dim1588JoeKuoD7Init,
                dim1589JoeKuoD7Init,
                dim1590JoeKuoD7Init,
                dim1591JoeKuoD7Init,
                dim1592JoeKuoD7Init,
                dim1593JoeKuoD7Init,
                dim1594JoeKuoD7Init,
                dim1595JoeKuoD7Init,
                dim1596JoeKuoD7Init,
                dim1597JoeKuoD7Init,
                dim1598JoeKuoD7Init,
                dim1599JoeKuoD7Init,
                dim1600JoeKuoD7Init,
                dim1601JoeKuoD7Init,
                dim1602JoeKuoD7Init,
                dim1603JoeKuoD7Init,
                dim1604JoeKuoD7Init,
                dim1605JoeKuoD7Init,
                dim1606JoeKuoD7Init,
                dim1607JoeKuoD7Init,
                dim1608JoeKuoD7Init,
                dim1609JoeKuoD7Init,
                dim1610JoeKuoD7Init,
                dim1611JoeKuoD7Init,
                dim1612JoeKuoD7Init,
                dim1613JoeKuoD7Init,
                dim1614JoeKuoD7Init,
                dim1615JoeKuoD7Init,
                dim1616JoeKuoD7Init,
                dim1617JoeKuoD7Init,
                dim1618JoeKuoD7Init,
                dim1619JoeKuoD7Init,
                dim1620JoeKuoD7Init,
                dim1621JoeKuoD7Init,
                dim1622JoeKuoD7Init,
                dim1623JoeKuoD7Init,
                dim1624JoeKuoD7Init,
                dim1625JoeKuoD7Init,
                dim1626JoeKuoD7Init,
                dim1627JoeKuoD7Init,
                dim1628JoeKuoD7Init,
                dim1629JoeKuoD7Init,
                dim1630JoeKuoD7Init,
                dim1631JoeKuoD7Init,
                dim1632JoeKuoD7Init,
                dim1633JoeKuoD7Init,
                dim1634JoeKuoD7Init,
                dim1635JoeKuoD7Init,
                dim1636JoeKuoD7Init,
                dim1637JoeKuoD7Init,
                dim1638JoeKuoD7Init,
                dim1639JoeKuoD7Init,
                dim1640JoeKuoD7Init,
                dim1641JoeKuoD7Init,
                dim1642JoeKuoD7Init,
                dim1643JoeKuoD7Init,
                dim1644JoeKuoD7Init,
                dim1645JoeKuoD7Init,
                dim1646JoeKuoD7Init,
                dim1647JoeKuoD7Init,
                dim1648JoeKuoD7Init,
                dim1649JoeKuoD7Init,
                dim1650JoeKuoD7Init,
                dim1651JoeKuoD7Init,
                dim1652JoeKuoD7Init,
                dim1653JoeKuoD7Init,
                dim1654JoeKuoD7Init,
                dim1655JoeKuoD7Init,
                dim1656JoeKuoD7Init,
                dim1657JoeKuoD7Init,
                dim1658JoeKuoD7Init,
                dim1659JoeKuoD7Init,
                dim1660JoeKuoD7Init,
                dim1661JoeKuoD7Init,
                dim1662JoeKuoD7Init,
                dim1663JoeKuoD7Init,
                dim1664JoeKuoD7Init,
                dim1665JoeKuoD7Init,
                dim1666JoeKuoD7Init,
                dim1667JoeKuoD7Init,
                dim1668JoeKuoD7Init,
                dim1669JoeKuoD7Init,
                dim1670JoeKuoD7Init,
                dim1671JoeKuoD7Init,
                dim1672JoeKuoD7Init,
                dim1673JoeKuoD7Init,
                dim1674JoeKuoD7Init,
                dim1675JoeKuoD7Init,
                dim1676JoeKuoD7Init,
                dim1677JoeKuoD7Init,
                dim1678JoeKuoD7Init,
                dim1679JoeKuoD7Init,
                dim1680JoeKuoD7Init,
                dim1681JoeKuoD7Init,
                dim1682JoeKuoD7Init,
                dim1683JoeKuoD7Init,
                dim1684JoeKuoD7Init,
                dim1685JoeKuoD7Init,
                dim1686JoeKuoD7Init,
                dim1687JoeKuoD7Init,
                dim1688JoeKuoD7Init,
                dim1689JoeKuoD7Init,
                dim1690JoeKuoD7Init,
                dim1691JoeKuoD7Init,
                dim1692JoeKuoD7Init,
                dim1693JoeKuoD7Init,
                dim1694JoeKuoD7Init,
                dim1695JoeKuoD7Init,
                dim1696JoeKuoD7Init,
                dim1697JoeKuoD7Init,
                dim1698JoeKuoD7Init,
                dim1699JoeKuoD7Init,
                dim1700JoeKuoD7Init,
                dim1701JoeKuoD7Init,
                dim1702JoeKuoD7Init,
                dim1703JoeKuoD7Init,
                dim1704JoeKuoD7Init,
                dim1705JoeKuoD7Init,
                dim1706JoeKuoD7Init,
                dim1707JoeKuoD7Init,
                dim1708JoeKuoD7Init,
                dim1709JoeKuoD7Init,
                dim1710JoeKuoD7Init,
                dim1711JoeKuoD7Init,
                dim1712JoeKuoD7Init,
                dim1713JoeKuoD7Init,
                dim1714JoeKuoD7Init,
                dim1715JoeKuoD7Init,
                dim1716JoeKuoD7Init,
                dim1717JoeKuoD7Init,
                dim1718JoeKuoD7Init,
                dim1719JoeKuoD7Init,
                dim1720JoeKuoD7Init,
                dim1721JoeKuoD7Init,
                dim1722JoeKuoD7Init,
                dim1723JoeKuoD7Init,
                dim1724JoeKuoD7Init,
                dim1725JoeKuoD7Init,
                dim1726JoeKuoD7Init,
                dim1727JoeKuoD7Init,
                dim1728JoeKuoD7Init,
                dim1729JoeKuoD7Init,
                dim1730JoeKuoD7Init,
                dim1731JoeKuoD7Init,
                dim1732JoeKuoD7Init,
                dim1733JoeKuoD7Init,
                dim1734JoeKuoD7Init,
                dim1735JoeKuoD7Init,
                dim1736JoeKuoD7Init,
                dim1737JoeKuoD7Init,
                dim1738JoeKuoD7Init,
                dim1739JoeKuoD7Init,
                dim1740JoeKuoD7Init,
                dim1741JoeKuoD7Init,
                dim1742JoeKuoD7Init,
                dim1743JoeKuoD7Init,
                dim1744JoeKuoD7Init,
                dim1745JoeKuoD7Init,
                dim1746JoeKuoD7Init,
                dim1747JoeKuoD7Init,
                dim1748JoeKuoD7Init,
                dim1749JoeKuoD7Init,
                dim1750JoeKuoD7Init,
                dim1751JoeKuoD7Init,
                dim1752JoeKuoD7Init,
                dim1753JoeKuoD7Init,
                dim1754JoeKuoD7Init,
                dim1755JoeKuoD7Init,
                dim1756JoeKuoD7Init,
                dim1757JoeKuoD7Init,
                dim1758JoeKuoD7Init,
                dim1759JoeKuoD7Init,
                dim1760JoeKuoD7Init,
                dim1761JoeKuoD7Init,
                dim1762JoeKuoD7Init,
                dim1763JoeKuoD7Init,
                dim1764JoeKuoD7Init,
                dim1765JoeKuoD7Init,
                dim1766JoeKuoD7Init,
                dim1767JoeKuoD7Init,
                dim1768JoeKuoD7Init,
                dim1769JoeKuoD7Init,
                dim1770JoeKuoD7Init,
                dim1771JoeKuoD7Init,
                dim1772JoeKuoD7Init,
                dim1773JoeKuoD7Init,
                dim1774JoeKuoD7Init,
                dim1775JoeKuoD7Init,
                dim1776JoeKuoD7Init,
                dim1777JoeKuoD7Init,
                dim1778JoeKuoD7Init,
                dim1779JoeKuoD7Init,
                dim1780JoeKuoD7Init,
                dim1781JoeKuoD7Init,
                dim1782JoeKuoD7Init,
                dim1783JoeKuoD7Init,
                dim1784JoeKuoD7Init,
                dim1785JoeKuoD7Init,
                dim1786JoeKuoD7Init,
                dim1787JoeKuoD7Init,
                dim1788JoeKuoD7Init,
                dim1789JoeKuoD7Init,
                dim1790JoeKuoD7Init,
                dim1791JoeKuoD7Init,
                dim1792JoeKuoD7Init,
                dim1793JoeKuoD7Init,
                dim1794JoeKuoD7Init,
                dim1795JoeKuoD7Init,
                dim1796JoeKuoD7Init,
                dim1797JoeKuoD7Init,
                dim1798JoeKuoD7Init,
                dim1799JoeKuoD7Init,
                dim1800JoeKuoD7Init,
                dim1801JoeKuoD7Init,
                dim1802JoeKuoD7Init,
                dim1803JoeKuoD7Init,
                dim1804JoeKuoD7Init,
                dim1805JoeKuoD7Init,
                dim1806JoeKuoD7Init,
                dim1807JoeKuoD7Init,
                dim1808JoeKuoD7Init,
                dim1809JoeKuoD7Init,
                dim1810JoeKuoD7Init,
                dim1811JoeKuoD7Init,
                dim1812JoeKuoD7Init,
                dim1813JoeKuoD7Init,
                dim1814JoeKuoD7Init,
                dim1815JoeKuoD7Init,
                dim1816JoeKuoD7Init,
                dim1817JoeKuoD7Init,
                dim1818JoeKuoD7Init,
                dim1819JoeKuoD7Init,
                dim1820JoeKuoD7Init,
                dim1821JoeKuoD7Init,
                dim1822JoeKuoD7Init,
                dim1823JoeKuoD7Init,
                dim1824JoeKuoD7Init,
                dim1825JoeKuoD7Init,
                dim1826JoeKuoD7Init,
                dim1827JoeKuoD7Init,
                dim1828JoeKuoD7Init,
                dim1829JoeKuoD7Init,
                dim1830JoeKuoD7Init,
                dim1831JoeKuoD7Init,
                dim1832JoeKuoD7Init,
                dim1833JoeKuoD7Init,
                dim1834JoeKuoD7Init,
                dim1835JoeKuoD7Init,
                dim1836JoeKuoD7Init,
                dim1837JoeKuoD7Init,
                dim1838JoeKuoD7Init,
                dim1839JoeKuoD7Init,
                dim1840JoeKuoD7Init,
                dim1841JoeKuoD7Init,
                dim1842JoeKuoD7Init,
                dim1843JoeKuoD7Init,
                dim1844JoeKuoD7Init,
                dim1845JoeKuoD7Init,
                dim1846JoeKuoD7Init,
                dim1847JoeKuoD7Init,
                dim1848JoeKuoD7Init,
                dim1849JoeKuoD7Init,
                dim1850JoeKuoD7Init,
                dim1851JoeKuoD7Init,
                dim1852JoeKuoD7Init,
                dim1853JoeKuoD7Init,
                dim1854JoeKuoD7Init,
                dim1855JoeKuoD7Init,
                dim1856JoeKuoD7Init,
                dim1857JoeKuoD7Init,
                dim1858JoeKuoD7Init,
                dim1859JoeKuoD7Init,
                dim1860JoeKuoD7Init,
                dim1861JoeKuoD7Init,
                dim1862JoeKuoD7Init,
                dim1863JoeKuoD7Init,
                dim1864JoeKuoD7Init,
                dim1865JoeKuoD7Init,
                dim1866JoeKuoD7Init,
                dim1867JoeKuoD7Init,
                dim1868JoeKuoD7Init,
                dim1869JoeKuoD7Init,
                dim1870JoeKuoD7Init,
                dim1871JoeKuoD7Init,
                dim1872JoeKuoD7Init,
                dim1873JoeKuoD7Init,
                dim1874JoeKuoD7Init,
                dim1875JoeKuoD7Init,
                dim1876JoeKuoD7Init,
                dim1877JoeKuoD7Init,
                dim1878JoeKuoD7Init,
                dim1879JoeKuoD7Init,
                dim1880JoeKuoD7Init,
                dim1881JoeKuoD7Init,
                dim1882JoeKuoD7Init,
                dim1883JoeKuoD7Init,
                dim1884JoeKuoD7Init,
                dim1885JoeKuoD7Init,
                dim1886JoeKuoD7Init,
                dim1887JoeKuoD7Init,
                dim1888JoeKuoD7Init,
                dim1889JoeKuoD7Init,
                dim1890JoeKuoD7Init,
                dim1891JoeKuoD7Init,
                dim1892JoeKuoD7Init,
                dim1893JoeKuoD7Init,
                dim1894JoeKuoD7Init,
                dim1895JoeKuoD7Init,
                dim1896JoeKuoD7Init,
                dim1897JoeKuoD7Init,
                dim1898JoeKuoD7Init,
                dim1899JoeKuoD7Init
            };

            const std::uint32_t dim1JoeKuoD5Init[]  =   {   1   ,0 };
            const std::uint32_t dim2JoeKuoD5Init[]  =   {   1   ,   3   ,0 };
            const std::uint32_t dim3JoeKuoD5Init[]  =   {   1   ,   3   ,   1   ,0 };
            const std::uint32_t dim4JoeKuoD5Init[]  =   {   1   ,   1   ,   1   ,0 };
            const std::uint32_t dim5JoeKuoD5Init[]  =   {   1   ,   1   ,   3   ,   3   ,0 };
            const std::uint32_t dim6JoeKuoD5Init[]  =   {   1   ,   3   ,   5   ,   13  ,0 };
            const std::uint32_t dim7JoeKuoD5Init[]  =   {   1   ,   1   ,   5   ,   5   ,   17  ,0 };
            const std::uint32_t dim8JoeKuoD5Init[]  =   {   1   ,   1   ,   5   ,   5   ,   5   ,0 };
            const std::uint32_t dim9JoeKuoD5Init[]  =   {   1   ,   1   ,   7   ,   11  ,   19  ,0 };
            const std::uint32_t dim10JoeKuoD5Init[] =   {   1   ,   1   ,   5   ,   1   ,   1   ,0 };
            const std::uint32_t dim11JoeKuoD5Init[] =   {   1   ,   3   ,   7   ,   1   ,   19  ,0 };
            const std::uint32_t dim12JoeKuoD5Init[] =   {   1   ,   3   ,   3   ,   5   ,   7   ,0 };
            const std::uint32_t dim13JoeKuoD5Init[] =   {   1   ,   3   ,   3   ,   13  ,   9   ,   53  ,0 };
            const std::uint32_t dim14JoeKuoD5Init[] =   {   1   ,   1   ,   5   ,   11  ,   1   ,   1   ,0 };
            const std::uint32_t dim15JoeKuoD5Init[] =   {   1   ,   1   ,   3   ,   7   ,   21  ,   51  ,0 };
            const std::uint32_t dim16JoeKuoD5Init[] =   {   1   ,   1   ,   1   ,   15  ,   1   ,   5   ,0 };
            const std::uint32_t dim17JoeKuoD5Init[] =   {   1   ,   3   ,   1   ,   9   ,   9   ,   1   ,0 };
            const std::uint32_t dim18JoeKuoD5Init[] =   {   1   ,   1   ,   5   ,   5   ,   17  ,   61  ,0 };
            const std::uint32_t dim19JoeKuoD5Init[] =   {   1   ,   3   ,   1   ,   15  ,   29  ,   57  ,   87  ,0 };
            const std::uint32_t dim20JoeKuoD5Init[] =   {   1   ,   3   ,   5   ,   15  ,   3   ,   11  ,   17  ,0 };
            const std::uint32_t dim21JoeKuoD5Init[] =   {   1   ,   3   ,   3   ,   7   ,   5   ,   17  ,   65  ,0 };
            const std::uint32_t dim22JoeKuoD5Init[] =   {   1   ,   3   ,   5   ,   1   ,   25  ,   29  ,   49  ,0 };
            const std::uint32_t dim23JoeKuoD5Init[] =   {   1   ,   1   ,   3   ,   7   ,   15  ,   39  ,   119 ,0 };
            const std::uint32_t dim24JoeKuoD5Init[] =   {   1   ,   3   ,   3   ,   5   ,   19  ,   51  ,   61  ,0 };
            const std::uint32_t dim25JoeKuoD5Init[] =   {   1   ,   1   ,   5   ,   15  ,   11  ,   47  ,   15  ,0 };
            const std::uint32_t dim26JoeKuoD5Init[] =   {   1   ,   1   ,   7   ,   3   ,   29  ,   51  ,   51  ,0 };
            const std::uint32_t dim27JoeKuoD5Init[] =   {   1   ,   1   ,   3   ,   15  ,   19  ,   17  ,   13  ,0 };
            const std::uint32_t dim28JoeKuoD5Init[] =   {   1   ,   3   ,   7   ,   3   ,   17  ,   9   ,   93  ,0 };
            const std::uint32_t dim29JoeKuoD5Init[] =   {   1   ,   3   ,   7   ,   5   ,   7   ,   29  ,   111 ,0 };
            const std::uint32_t dim30JoeKuoD5Init[] =   {   1   ,   1   ,   7   ,   9   ,   25  ,   19  ,   105 ,0 };
            const std::uint32_t dim31JoeKuoD5Init[] =   {   1   ,   1   ,   1   ,   11  ,   21  ,   35  ,   107 ,0 };
            const std::uint32_t dim32JoeKuoD5Init[] =   {   1   ,   1   ,   5   ,   11  ,   19  ,   53  ,   25  ,0 };
            const std::uint32_t dim33JoeKuoD5Init[] =   {   1   ,   3   ,   1   ,   3   ,   27  ,   29  ,   31  ,0 };
            const std::uint32_t dim34JoeKuoD5Init[] =   {   1   ,   1   ,   5   ,   13  ,   27  ,   19  ,   61  ,0 };
            const std::uint32_t dim35JoeKuoD5Init[] =   {   1   ,   3   ,   1   ,   3   ,   25  ,   33  ,   105 ,0 };
            const std::uint32_t dim36JoeKuoD5Init[] =   {   1   ,   3   ,   7   ,   11  ,   27  ,   55  ,   1   ,0 };
            const std::uint32_t dim37JoeKuoD5Init[] =   {   1   ,   1   ,   7   ,   1   ,   9   ,   45  ,   97  ,   63  ,0 };
            const std::uint32_t dim38JoeKuoD5Init[] =   {   1   ,   1   ,   7   ,   9   ,   3   ,   17  ,   85  ,   213 ,0 };
            const std::uint32_t dim39JoeKuoD5Init[] =   {   1   ,   1   ,   1   ,   3   ,   31  ,   35  ,   93  ,   35  ,0 };
            const std::uint32_t dim40JoeKuoD5Init[] =   {   1   ,   3   ,   5   ,   9   ,   1   ,   63  ,   117 ,   35  ,0 };
            const std::uint32_t dim41JoeKuoD5Init[] =   {   1   ,   3   ,   1   ,   9   ,   21  ,   3   ,   53  ,   29  ,0 };
            const std::uint32_t dim42JoeKuoD5Init[] =   {   1   ,   3   ,   1   ,   9   ,   29  ,   33  ,   43  ,   181 ,0 };
            const std::uint32_t dim43JoeKuoD5Init[] =   {   1   ,   3   ,   7   ,   3   ,   21  ,   45  ,   121 ,   141 ,0 };
            const std::uint32_t dim44JoeKuoD5Init[] =   {   1   ,   1   ,   1   ,   13  ,   5   ,   49  ,   45  ,   77  ,0 };
            const std::uint32_t dim45JoeKuoD5Init[] =   {   1   ,   1   ,   3   ,   3   ,   1   ,   47  ,   37  ,   151 ,0 };
            const std::uint32_t dim46JoeKuoD5Init[] =   {   1   ,   3   ,   7   ,   5   ,   9   ,   51  ,   61  ,   95  ,0 };
            const std::uint32_t dim47JoeKuoD5Init[] =   {   1   ,   1   ,   1   ,   7   ,   31  ,   23  ,   81  ,   105 ,0 };
            const std::uint32_t dim48JoeKuoD5Init[] =   {   1   ,   3   ,   5   ,   15  ,   15  ,   9   ,   115 ,   55  ,0 };
            const std::uint32_t dim49JoeKuoD5Init[] =   {   1   ,   3   ,   3   ,   13  ,   15  ,   1   ,   87  ,   11  ,0 };
            const std::uint32_t dim50JoeKuoD5Init[] =   {   1   ,   3   ,   5   ,   1   ,   5   ,   9   ,   29  ,   241 ,0 };
            const std::uint32_t dim51JoeKuoD5Init[] =   {   1   ,   1   ,   1   ,   9   ,   19  ,   5   ,   115 ,   191 ,0 };
            const std::uint32_t dim52JoeKuoD5Init[] =   {   1   ,   1   ,   1   ,   15  ,   1   ,   57  ,   107 ,   49  ,0 };
            const std::uint32_t dim53JoeKuoD5Init[] =   {   1   ,   1   ,   7   ,   7   ,   23  ,   21  ,   71  ,   187 ,   207 ,0 };
            const std::uint32_t dim54JoeKuoD5Init[] =   {   1   ,   3   ,   3   ,   5   ,   11  ,   35  ,   101 ,   7   ,   501 ,0 };
            const std::uint32_t dim55JoeKuoD5Init[] =   {   1   ,   3   ,   5   ,   15  ,   29  ,   5   ,   61  ,   205 ,   301 ,0 };
            const std::uint32_t dim56JoeKuoD5Init[] =   {   1   ,   1   ,   7   ,   13  ,   7   ,   39  ,   127 ,   243 ,   307 ,0 };
            const std::uint32_t dim57JoeKuoD5Init[] =   {   1   ,   3   ,   7   ,   13  ,   29  ,   9   ,   93  ,   187 ,   429 ,0 };
            const std::uint32_t dim58JoeKuoD5Init[] =   {   1   ,   3   ,   3   ,   11  ,   15  ,   35  ,   85  ,   159 ,   223 ,0 };
            const std::uint32_t dim59JoeKuoD5Init[] =   {   1   ,   1   ,   3   ,   1   ,   13  ,   3   ,   111 ,   17  ,   411 ,0 };
            const std::uint32_t dim60JoeKuoD5Init[] =   {   1   ,   1   ,   1   ,   7   ,   31  ,   21  ,   103 ,   175 ,   97  ,0 };
            const std::uint32_t dim61JoeKuoD5Init[] =   {   1   ,   1   ,   1   ,   15  ,   11  ,   21  ,   63  ,   45  ,   29  ,0 };
            const std::uint32_t dim62JoeKuoD5Init[] =   {   1   ,   3   ,   5   ,   3   ,   13  ,   45  ,   53  ,   191 ,   455 ,0 };
            const std::uint32_t dim63JoeKuoD5Init[] =   {   1   ,   3   ,   3   ,   13  ,   11  ,   37  ,   65  ,   45  ,   371 ,0 };
            const std::uint32_t dim64JoeKuoD5Init[] =   {   1   ,   1   ,   1   ,   15  ,   23  ,   9   ,   123 ,   97  ,   497 ,0 };
            const std::uint32_t dim65JoeKuoD5Init[] =   {   1   ,   1   ,   7   ,   7   ,   5   ,   13  ,   33  ,   169 ,   411 ,0 };
            const std::uint32_t dim66JoeKuoD5Init[] =   {   1   ,   1   ,   3   ,   13  ,   29  ,   61  ,   67  ,   1   ,   167 ,0 };
            const std::uint32_t dim67JoeKuoD5Init[] =   {   1   ,   1   ,   7   ,   3   ,   11  ,   21  ,   25  ,   87  ,   507 ,0 };
            const std::uint32_t dim68JoeKuoD5Init[] =   {   1   ,   3   ,   1   ,   9   ,   31  ,   37  ,   3   ,   89  ,   113 ,0 };
            const std::uint32_t dim69JoeKuoD5Init[] =   {   1   ,   1   ,   5   ,   11  ,   5   ,   11  ,   83  ,   85  ,   421 ,0 };
            const std::uint32_t dim70JoeKuoD5Init[] =   {   1   ,   3   ,   5   ,   7   ,   23  ,   9   ,   111 ,   135 ,   337 ,0 };
            const std::uint32_t dim71JoeKuoD5Init[] =   {   1   ,   3   ,   5   ,   15  ,   3   ,   39  ,   81  ,   249 ,   363 ,0 };
            const std::uint32_t dim72JoeKuoD5Init[] =   {   1   ,   1   ,   7   ,   15  ,   9   ,   49  ,   79  ,   103 ,   19  ,0 };
            const std::uint32_t dim73JoeKuoD5Init[] =   {   1   ,   3   ,   1   ,   1   ,   17  ,   31  ,   45  ,   205 ,   381 ,0 };
            const std::uint32_t dim74JoeKuoD5Init[] =   {   1   ,   1   ,   1   ,   1   ,   11  ,   45  ,   89  ,   1   ,   365 ,0 };
            const std::uint32_t dim75JoeKuoD5Init[] =   {   1   ,   1   ,   1   ,   15  ,   7   ,   63  ,   55  ,   185 ,   373 ,0 };
            const std::uint32_t dim76JoeKuoD5Init[] =   {   1   ,   1   ,   1   ,   3   ,   17  ,   19  ,   23  ,   7   ,   265 ,0 };
            const std::uint32_t dim77JoeKuoD5Init[] =   {   1   ,   1   ,   3   ,   15  ,   13  ,   31  ,   53  ,   235 ,   309 ,0 };
            const std::uint32_t dim78JoeKuoD5Init[] =   {   1   ,   3   ,   1   ,   5   ,   1   ,   63  ,   73  ,   155 ,   33  ,0 };
            const std::uint32_t dim79JoeKuoD5Init[] =   {   1   ,   1   ,   1   ,   15  ,   19  ,   57  ,   21  ,   45  ,   203 ,0 };
            const std::uint32_t dim80JoeKuoD5Init[] =   {   1   ,   3   ,   5   ,   9   ,   13  ,   27  ,   55  ,   215 ,   181 ,0 };
            const std::uint32_t dim81JoeKuoD5Init[] =   {   1   ,   1   ,   7   ,   3   ,   11  ,   39  ,   55  ,   219 ,   401 ,0 };
            const std::uint32_t dim82JoeKuoD5Init[] =   {   1   ,   1   ,   1   ,   7   ,   9   ,   13  ,   3   ,   181 ,   395 ,0 };
            const std::uint32_t dim83JoeKuoD5Init[] =   {   1   ,   3   ,   1   ,   15  ,   13  ,   19  ,   23  ,   145 ,   97  ,0 };
            const std::uint32_t dim84JoeKuoD5Init[] =   {   1   ,   1   ,   1   ,   15  ,   23  ,   15  ,   55  ,   3   ,   243 ,0 };
            const std::uint32_t dim85JoeKuoD5Init[] =   {   1   ,   1   ,   3   ,   15  ,   15  ,   5   ,   115 ,   169 ,   415 ,0 };
            const std::uint32_t dim86JoeKuoD5Init[] =   {   1   ,   1   ,   7   ,   15  ,   31  ,   15  ,   119 ,   89  ,   37  ,0 };
            const std::uint32_t dim87JoeKuoD5Init[] =   {   1   ,   1   ,   5   ,   3   ,   25  ,   23  ,   23  ,   133 ,   467 ,0 };
            const std::uint32_t dim88JoeKuoD5Init[] =   {   1   ,   3   ,   5   ,   15  ,   11  ,   7   ,   73  ,   209 ,   331 ,0 };
            const std::uint32_t dim89JoeKuoD5Init[] =   {   1   ,   3   ,   7   ,   11  ,   29  ,   51  ,   119 ,   105 ,   63  ,0 };
            const std::uint32_t dim90JoeKuoD5Init[] =   {   1   ,   1   ,   5   ,   9   ,   19  ,   21  ,   53  ,   211 ,   231 ,0 };
            const std::uint32_t dim91JoeKuoD5Init[] =   {   1   ,   3   ,   5   ,   1   ,   7   ,   23  ,   27  ,   67  ,   445 ,0 };
            const std::uint32_t dim92JoeKuoD5Init[] =   {   1   ,   1   ,   5   ,   15  ,   21  ,   53  ,   117 ,   229 ,   13  ,0 };
            const std::uint32_t dim93JoeKuoD5Init[] =   {   1   ,   3   ,   5   ,   11  ,   19  ,   55  ,   53  ,   13  ,   349 ,0 };
            const std::uint32_t dim94JoeKuoD5Init[] =   {   1   ,   3   ,   1   ,   9   ,   19  ,   25  ,   79  ,   55  ,   355 ,0 };
            const std::uint32_t dim95JoeKuoD5Init[] =   {   1   ,   3   ,   3   ,   5   ,   31  ,   27  ,   105 ,   63  ,   21  ,0 };
            const std::uint32_t dim96JoeKuoD5Init[] =   {   1   ,   3   ,   3   ,   15  ,   13  ,   37  ,   39  ,   13  ,   459 ,0 };
            const std::uint32_t dim97JoeKuoD5Init[] =   {   1   ,   1   ,   1   ,   7   ,   25  ,   61  ,   93  ,   195 ,   441 ,0 };
            const std::uint32_t dim98JoeKuoD5Init[] =   {   1   ,   3   ,   3   ,   3   ,   7   ,   35  ,   55  ,   103 ,   159 ,0 };
            const std::uint32_t dim99JoeKuoD5Init[] =   {   1   ,   1   ,   7   ,   11  ,   7   ,   33  ,   49  ,   113 ,   331 ,0 };
            const std::uint32_t dim100JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   1   ,   1   ,   31  ,   35  ,   63  ,   465 ,0 };
            const std::uint32_t dim101JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   1   ,   13  ,   43  ,   83  ,   177 ,   461 ,   747 ,0 };
            const std::uint32_t dim102JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   3   ,   21  ,   5   ,   19  ,   135 ,   483 ,   181 ,0 };
            const std::uint32_t dim103JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   9   ,   25  ,   3   ,   37  ,   147 ,   483 ,   743 ,0 };
            const std::uint32_t dim104JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   3   ,   1   ,   1   ,   101 ,   163 ,   165 ,   957 ,0 };
            const std::uint32_t dim105JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   1   ,   15  ,   41  ,   117 ,   7   ,   71  ,   357 ,0 };
            const std::uint32_t dim106JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   9   ,   27  ,   11  ,   55  ,   5   ,   11  ,   863 ,0 };
            const std::uint32_t dim107JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   1   ,   27  ,   43  ,   51  ,   211 ,   265 ,   403 ,0 };
            const std::uint32_t dim108JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   3   ,   31  ,   35  ,   61  ,   43  ,   223 ,   441 ,0 };
            const std::uint32_t dim109JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   7   ,   19  ,   61  ,   59  ,   63  ,   401 ,   767 ,0 };
            const std::uint32_t dim110JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   9   ,   23  ,   39  ,   83  ,   249 ,   129 ,   843 ,0 };
            const std::uint32_t dim111JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   13  ,   1   ,   49  ,   61  ,   115 ,   289 ,   85  ,0 };
            const std::uint32_t dim112JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   13  ,   7   ,   17  ,   35  ,   95  ,   235 ,   49  ,0 };
            const std::uint32_t dim113JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   11  ,   9   ,   9   ,   91  ,   141 ,   305 ,   955 ,0 };
            const std::uint32_t dim114JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   11  ,   17  ,   3   ,   77  ,   95  ,   507 ,   627 ,0 };
            const std::uint32_t dim115JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   1   ,   31  ,   43  ,   31  ,   217 ,   67  ,   853 ,0 };
            const std::uint32_t dim116JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   15  ,   17  ,   33  ,   31  ,   91  ,   465 ,   209 ,0 };
            const std::uint32_t dim117JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   7   ,   31  ,   41  ,   101 ,   95  ,   431 ,   203 ,0 };
            const std::uint32_t dim118JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   1   ,   23  ,   45  ,   123 ,   111 ,   457 ,   655 ,0 };
            const std::uint32_t dim119JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   5   ,   9   ,   27  ,   37  ,   195 ,   11  ,   99  ,0 };
            const std::uint32_t dim120JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   9   ,   7   ,   39  ,   81  ,   171 ,   97  ,   775 ,0 };
            const std::uint32_t dim121JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   3   ,   3   ,   27  ,   93  ,   149 ,   321 ,   537 ,0 };
            const std::uint32_t dim122JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   3   ,   13  ,   3   ,   59  ,   137 ,   505 ,   395 ,0 };
            const std::uint32_t dim123JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   11  ,   15  ,   53  ,   77  ,   235 ,   439 ,   829 ,0 };
            const std::uint32_t dim124JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   1   ,   25  ,   61  ,   65  ,   53  ,   207 ,   891 ,0 };
            const std::uint32_t dim125JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   15  ,   29  ,   39  ,   67  ,   203 ,   495 ,   795 ,0 };
            const std::uint32_t dim126JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   1   ,   15  ,   17  ,   119 ,   83  ,   411 ,   1015    ,0 };
            const std::uint32_t dim127JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   1   ,   13  ,   37  ,   69  ,   147 ,   141 ,   229 ,0 };
            const std::uint32_t dim128JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   1   ,   11  ,   31  ,   73  ,   99  ,   133 ,   45  ,0 };
            const std::uint32_t dim129JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   11  ,   31  ,   49  ,   51  ,   45  ,   27  ,   415 ,0 };
            const std::uint32_t dim130JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   11  ,   23  ,   19  ,   85  ,   17  ,   41  ,   625 ,0 };
            const std::uint32_t dim131JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   9   ,   3   ,   37  ,   9   ,   57  ,   59  ,   383 ,0 };
            const std::uint32_t dim132JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   3   ,   19  ,   53  ,   11  ,   215 ,   391 ,   51  ,0 };
            const std::uint32_t dim133JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   15  ,   17  ,   1   ,   53  ,   89  ,   291 ,   91  ,0 };
            const std::uint32_t dim134JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   1   ,   5   ,   33  ,   69  ,   29  ,   281 ,   13  ,0 };
            const std::uint32_t dim135JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   15  ,   21  ,   61  ,   61  ,   69  ,   395 ,   785 ,0 };
            const std::uint32_t dim136JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   7   ,   25  ,   51  ,   27  ,   11  ,   375 ,   865 ,0 };
            const std::uint32_t dim137JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   1   ,   11  ,   47  ,   45  ,   85  ,   507 ,   11  ,0 };
            const std::uint32_t dim138JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   5   ,   17  ,   53  ,   101 ,   57  ,   213 ,   795 ,0 };
            const std::uint32_t dim139JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   7   ,   15  ,   19  ,   117 ,   213 ,   397 ,   343 ,0 };
            const std::uint32_t dim140JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   7   ,   9   ,   19  ,   27  ,   23  ,   205 ,   707 ,0 };
            const std::uint32_t dim141JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   13  ,   11  ,   51  ,   1   ,   3   ,   63  ,   483 ,0 };
            const std::uint32_t dim142JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   13  ,   27  ,   49  ,   97  ,   247 ,   273 ,   785 ,0 };
            const std::uint32_t dim143JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   15  ,   31  ,   3   ,   43  ,   199 ,   81  ,   317 ,0 };
            const std::uint32_t dim144JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   15  ,   17  ,   3   ,   101 ,   13  ,   131 ,   631 ,0 };
            const std::uint32_t dim145JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   1   ,   25  ,   23  ,   17  ,   145 ,   247 ,   889 ,0 };
            const std::uint32_t dim146JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   7   ,   17  ,   5   ,   11  ,   133 ,   19  ,   507 ,0 };
            const std::uint32_t dim147JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   7   ,   31  ,   53  ,   39  ,   107 ,   183 ,   335 ,0 };
            const std::uint32_t dim148JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   15  ,   3   ,   19  ,   39  ,   155 ,   477 ,   833 ,0 };
            const std::uint32_t dim149JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   9   ,   31  ,   7   ,   5   ,   5   ,   399 ,   831 ,0 };
            const std::uint32_t dim150JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   1   ,   19  ,   37  ,   89  ,   243 ,   131 ,   901 ,0 };
            const std::uint32_t dim151JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   13  ,   23  ,   3   ,   127 ,   213 ,   97  ,   325 ,0 };
            const std::uint32_t dim152JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   9   ,   23  ,   27  ,   7   ,   161 ,   307 ,   451 ,0 };
            const std::uint32_t dim153JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   1   ,   5   ,   25  ,   23  ,   103 ,   59  ,   431 ,0 };
            const std::uint32_t dim154JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   7   ,   3   ,   43  ,   121 ,   117 ,   33  ,   231 ,0 };
            const std::uint32_t dim155JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   7   ,   11  ,   61  ,   73  ,   231 ,   225 ,   97  ,0 };
            const std::uint32_t dim156JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   11  ,   1   ,   9   ,   61  ,   3   ,   407 ,   425 ,0 };
            const std::uint32_t dim157JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   7   ,   1   ,   25  ,   95  ,   161 ,   387 ,   379 ,0 };
            const std::uint32_t dim158JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   1   ,   15  ,   53  ,   55  ,   107 ,   425 ,   629 ,0 };
            const std::uint32_t dim159JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   11  ,   31  ,   59  ,   97  ,   99  ,   339 ,   417 ,0 };
            const std::uint32_t dim160JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   9   ,   9   ,   5   ,   7   ,   157 ,   401 ,   155 ,0 };
            const std::uint32_t dim161JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   7   ,   31  ,   15  ,   37  ,   253 ,   93  ,   149 ,   1255    ,0 };
            const std::uint32_t dim162JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   9   ,   11  ,   61  ,   65  ,   71  ,   53  ,   929 ,   1153    ,0 };
            const std::uint32_t dim163JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   15  ,   13  ,   25  ,   93  ,   55  ,   55  ,   923 ,   601 ,0 };
            const std::uint32_t dim164JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   7   ,   21  ,   43  ,   71  ,   115 ,   253 ,   953 ,   1455    ,0 };
            const std::uint32_t dim165JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   7   ,   3   ,   31  ,   115 ,   213 ,   39  ,   589 ,   1029    ,0 };
            const std::uint32_t dim166JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   1   ,   7   ,   59  ,   31  ,   87  ,   233 ,   75  ,   365 ,0 };
            const std::uint32_t dim167JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   15  ,   13  ,   27  ,   55  ,   117 ,   327 ,   465 ,   1735    ,0 };
            const std::uint32_t dim168JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   9   ,   25  ,   9   ,   125 ,   247 ,   81  ,   437 ,   483 ,0 };
            const std::uint32_t dim169JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   15  ,   27  ,   39  ,   27  ,   57  ,   45  ,   263 ,   281 ,0 };
            const std::uint32_t dim170JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   5   ,   29  ,   5   ,   73  ,   231 ,   97  ,   773 ,   1349    ,0 };
            const std::uint32_t dim171JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   5   ,   25  ,   27  ,   81  ,   87  ,   91  ,   169 ,   235 ,0 };
            const std::uint32_t dim172JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   11  ,   19  ,   61  ,   17  ,   175 ,   253 ,   673 ,   175 ,0 };
            const std::uint32_t dim173JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   7   ,   17  ,   43  ,   65  ,   245 ,   125 ,   137 ,   1475    ,0 };
            const std::uint32_t dim174JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   5   ,   15  ,   57  ,   39  ,   151 ,   197 ,   529 ,   393 ,0 };
            const std::uint32_t dim175JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   3   ,   29  ,   41  ,   93  ,   47  ,   375 ,   729 ,   709 ,0 };
            const std::uint32_t dim176JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   9   ,   13  ,   35  ,   49  ,   197 ,   107 ,   381 ,   1531    ,0 };
            const std::uint32_t dim177JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   9   ,   15  ,   35  ,   105 ,   105 ,   259 ,   201 ,   317 ,0 };
            const std::uint32_t dim178JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   15  ,   13  ,   23  ,   89  ,   203 ,   335 ,   1003    ,   107 ,0 };
            const std::uint32_t dim179JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   15  ,   25  ,   25  ,   7   ,   145 ,   213 ,   845 ,   949 ,0 };
            const std::uint32_t dim180JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   1   ,   23  ,   11  ,   101 ,   59  ,   57  ,   261 ,   1627    ,0 };
            const std::uint32_t dim181JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   11  ,   23  ,   63  ,   43  ,   137 ,   49  ,   249 ,   1369    ,0 };
            const std::uint32_t dim182JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   13  ,   25  ,   3   ,   81  ,   157 ,   511 ,   725 ,   2027    ,0 };
            const std::uint32_t dim183JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   7   ,   5   ,   37  ,   33  ,   7   ,   287 ,   307 ,   147 ,0 };
            const std::uint32_t dim184JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   5   ,   27  ,   19  ,   93  ,   173 ,   145 ,   821 ,   139 ,0 };
            const std::uint32_t dim185JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   15  ,   23  ,   61  ,   123 ,   85  ,   375 ,   699 ,   229 ,0 };
            const std::uint32_t dim186JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   3   ,   25  ,   21  ,   127 ,   53  ,   247 ,   1005    ,   831 ,0 };
            const std::uint32_t dim187JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   7   ,   25  ,   39  ,   27  ,   247 ,   319 ,   659 ,   1453    ,0 };
            const std::uint32_t dim188JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   11  ,   31  ,   45  ,   67  ,   195 ,   11  ,   481 ,   83  ,0 };
            const std::uint32_t dim189JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   13  ,   27  ,   61  ,   5   ,   173 ,   353 ,   733 ,   1189    ,0 };
            const std::uint32_t dim190JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   7   ,   23  ,   49  ,   119 ,   145 ,   285 ,   873 ,   641 ,0 };
            const std::uint32_t dim191JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   9   ,   1   ,   17  ,   119 ,   121 ,   203 ,   483 ,   1601    ,0 };
            const std::uint32_t dim192JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   11  ,   21  ,   35  ,   121 ,   11  ,   213 ,   93  ,   77  ,0 };
            const std::uint32_t dim193JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   7   ,   7   ,   5   ,   27  ,   153 ,   223 ,   831 ,   679 ,0 };
            const std::uint32_t dim194JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   5   ,   1   ,   39  ,   39  ,   233 ,   483 ,   667 ,   1367    ,0 };
            const std::uint32_t dim195JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   13  ,   19  ,   51  ,   21  ,   209 ,   381 ,   787 ,   1451    ,0 };
            const std::uint32_t dim196JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   3   ,   15  ,   9   ,   29  ,   225 ,   225 ,   389 ,   1075    ,0 };
            const std::uint32_t dim197JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   5   ,   13  ,   57  ,   55  ,   229 ,   279 ,   1019    ,   1491    ,0 };
            const std::uint32_t dim198JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   9   ,   19  ,   19  ,   35  ,   15  ,   335 ,   685 ,   1987    ,0 };
            const std::uint32_t dim199JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   11  ,   1   ,   5   ,   3   ,   29  ,   19  ,   363 ,   247 ,0 };
            const std::uint32_t dim200JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   11  ,   13  ,   17  ,   17  ,   253 ,   365 ,   397 ,   1643    ,0 };
            const std::uint32_t dim201JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   15  ,   25  ,   23  ,   81  ,   243 ,   343 ,   441 ,   1675    ,0 };
            const std::uint32_t dim202JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   11  ,   15  ,   51  ,   23  ,   213 ,   235 ,   997 ,   1205    ,0 };
            const std::uint32_t dim203JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   7   ,   5   ,   39  ,   99  ,   165 ,   331 ,   795 ,   803 ,0 };
            const std::uint32_t dim204JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   13  ,   31  ,   63  ,   109 ,   171 ,   151 ,   269 ,   581 ,0 };
            const std::uint32_t dim205JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   7   ,   25  ,   13  ,   41  ,   75  ,   411 ,   425 ,   267 ,0 };
            const std::uint32_t dim206JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   7   ,   1   ,   31  ,   49  ,   113 ,   473 ,   677 ,   395 ,0 };
            const std::uint32_t dim207JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   5   ,   23  ,   43  ,   111 ,   171 ,   489 ,   949 ,   1681    ,0 };
            const std::uint32_t dim208JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   5   ,   5   ,   37  ,   67  ,   23  ,   115 ,   909 ,   853 ,0 };
            const std::uint32_t dim209JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   3   ,   27  ,   35  ,   63  ,   45  ,   481 ,   571 ,   793 ,0 };
            const std::uint32_t dim210JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   15  ,   11  ,   45  ,   53  ,   225 ,   147 ,   935 ,   1189    ,0 };
            const std::uint32_t dim211JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   5   ,   15  ,   17  ,   77  ,   59  ,   169 ,   831 ,   163 ,0 };
            const std::uint32_t dim212JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   15  ,   7   ,   29  ,   85  ,   19  ,   313 ,   35  ,   401 ,0 };
            const std::uint32_t dim213JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   13  ,   3   ,   1   ,   45  ,   139 ,   17  ,   847 ,   1309    ,0 };
            const std::uint32_t dim214JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   3   ,   25  ,   1   ,   117 ,   185 ,   291 ,   251 ,   1049    ,0 };
            const std::uint32_t dim215JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   1   ,   27  ,   63  ,   33  ,   161 ,   181 ,   79  ,   667 ,0 };
            const std::uint32_t dim216JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   11  ,   9   ,   63  ,   91  ,   207 ,   329 ,   3   ,   1155    ,0 };
            const std::uint32_t dim217JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   5   ,   3   ,   59  ,   39  ,   37  ,   231 ,   993 ,   1147    ,0 };
            const std::uint32_t dim218JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   3   ,   7   ,   41  ,   85  ,   223 ,   407 ,   403 ,   573 ,0 };
            const std::uint32_t dim219JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   3   ,   15  ,   51  ,   1   ,   191 ,   123 ,   103 ,   1201    ,0 };
            const std::uint32_t dim220JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   3   ,   31  ,   9   ,   83  ,   231 ,   419 ,   109 ,   1455    ,0 };
            const std::uint32_t dim221JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   11  ,   13  ,   39  ,   89  ,   9   ,   237 ,   185 ,   1113    ,0 };
            const std::uint32_t dim222JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   9   ,   1   ,   43  ,   121 ,   241 ,   165 ,   263 ,   1205    ,0 };
            const std::uint32_t dim223JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   3   ,   21  ,   3   ,   61  ,   219 ,   49  ,   733 ,   25  ,0 };
            const std::uint32_t dim224JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   7   ,   31  ,   27  ,   121 ,   61  ,   447 ,   401 ,   529 ,0 };
            const std::uint32_t dim225JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   11  ,   27  ,   47  ,   85  ,   5   ,   305 ,   763 ,   1255    ,0 };
            const std::uint32_t dim226JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   9   ,   13  ,   41  ,   9   ,   51  ,   195 ,   103 ,   983 ,0 };
            const std::uint32_t dim227JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   15  ,   1   ,   27  ,   65  ,   91  ,   61  ,   591 ,   2039    ,0 };
            const std::uint32_t dim228JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   1   ,   15  ,   19  ,   107 ,   197 ,   121 ,   879 ,   771 ,0 };
            const std::uint32_t dim229JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   7   ,   19  ,   53  ,   9   ,   3   ,   67  ,   893 ,   1817    ,0 };
            const std::uint32_t dim230JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   9   ,   11  ,   63  ,   53  ,   247 ,   65  ,   681 ,   1721    ,0 };
            const std::uint32_t dim231JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   3   ,   25  ,   47  ,   91  ,   55  ,   471 ,   731 ,   939 ,0 };
            const std::uint32_t dim232JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   9   ,   7   ,   45  ,   121 ,   69  ,   423 ,   599 ,   2027    ,0 };
            const std::uint32_t dim233JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   11  ,   23  ,   7   ,   43  ,   179 ,   511 ,   571 ,   1707    ,0 };
            const std::uint32_t dim234JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   9   ,   17  ,   11  ,   69  ,   13  ,   303 ,   299 ,   653 ,0 };
            const std::uint32_t dim235JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   7   ,   7   ,   29  ,   69  ,   237 ,   237 ,   425 ,   1413    ,0 };
            const std::uint32_t dim236JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   3   ,   19  ,   31  ,   55  ,   55  ,   225 ,   943 ,   1027    ,0 };
            const std::uint32_t dim237JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   7   ,   25  ,   9   ,   9   ,   29  ,   485 ,   885 ,   1229    ,0 };
            const std::uint32_t dim238JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   9   ,   7   ,   11  ,   73  ,   151 ,   17  ,   669 ,   773 ,0 };
            const std::uint32_t dim239JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   13  ,   25  ,   13  ,   51  ,   53  ,   411 ,   555 ,   795 ,0 };
            const std::uint32_t dim240JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   9   ,   21  ,   33  ,   7   ,   113 ,   325 ,   593 ,   1647    ,0 };
            const std::uint32_t dim241JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   15  ,   3   ,   13  ,   83  ,   205 ,   153 ,   7   ,   1181    ,0 };
            const std::uint32_t dim242JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   5   ,   1   ,   55  ,   91  ,   17  ,   383 ,   453 ,   1749    ,0 };
            const std::uint32_t dim243JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   1   ,   5   ,   13  ,   91  ,   19  ,   241 ,   569 ,   291 ,0 };
            const std::uint32_t dim244JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   9   ,   13  ,   19  ,   109 ,   195 ,   17  ,   203 ,   473 ,0 };
            const std::uint32_t dim245JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   11  ,   17  ,   17  ,   43  ,   201 ,   297 ,   159 ,   685 ,0 };
            const std::uint32_t dim246JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   15  ,   15  ,   33  ,   91  ,   53  ,   337 ,   237 ,   1063    ,0 };
            const std::uint32_t dim247JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   9   ,   13  ,   15  ,   59  ,   115 ,   457 ,   169 ,   29  ,0 };
            const std::uint32_t dim248JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   7   ,   21  ,   51  ,   41  ,   49  ,   467 ,   171 ,   301 ,0 };
            const std::uint32_t dim249JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   5   ,   19  ,   57  ,   27  ,   57  ,   119 ,   183 ,   1519    ,0 };
            const std::uint32_t dim250JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   9   ,   19  ,   21  ,   117 ,   35  ,   43  ,   829 ,   1817    ,0 };
            const std::uint32_t dim251JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   7   ,   9   ,   27  ,   127 ,   233 ,   229 ,   467 ,   2033    ,0 };
            const std::uint32_t dim252JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   1   ,   7   ,   21  ,   113 ,   23  ,   15  ,   43  ,   375 ,0 };
            const std::uint32_t dim253JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   3   ,   11  ,   21  ,   13  ,   87  ,   57  ,   805 ,   1529    ,0 };
            const std::uint32_t dim254JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   15  ,   3   ,   39  ,   115 ,   179 ,   199 ,   907 ,   1487    ,0 };
            const std::uint32_t dim255JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   1   ,   17  ,   17  ,   83  ,   23  ,   421 ,   813 ,   29  ,0 };
            const std::uint32_t dim256JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   3   ,   29  ,   39  ,   81  ,   69  ,   339 ,   495 ,   281 ,0 };
            const std::uint32_t dim257JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   5   ,   27  ,   39  ,   9   ,   233 ,   19  ,   663 ,   57  ,0 };
            const std::uint32_t dim258JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   15  ,   17  ,   7   ,   17  ,   39  ,   299 ,   97  ,   1329    ,0 };
            const std::uint32_t dim259JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   7   ,   9   ,   27  ,   5   ,   245 ,   477 ,   591 ,   1021    ,0 };
            const std::uint32_t dim260JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   13  ,   9   ,   37  ,   19  ,   141 ,   201 ,   57  ,   1117    ,0 };
            const std::uint32_t dim261JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   1   ,   7   ,   27  ,   33  ,   235 ,   247 ,   701 ,   1293    ,0 };
            const std::uint32_t dim262JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   3   ,   17  ,   25  ,   81  ,   213 ,   457 ,   877 ,   741 ,0 };
            const std::uint32_t dim263JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   13  ,   15  ,   47  ,   113 ,   29  ,   111 ,   913 ,   1695    ,0 };
            const std::uint32_t dim264JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   3   ,   5   ,   53  ,   119 ,   215 ,   163 ,   933 ,   1447    ,0 };
            const std::uint32_t dim265JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   7   ,   15  ,   27  ,   111 ,   19  ,   231 ,   287 ,   1439    ,0 };
            const std::uint32_t dim266JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   5   ,   27  ,   29  ,   35  ,   109 ,   249 ,   989 ,   1837    ,0 };
            const std::uint32_t dim267JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   9   ,   29  ,   35  ,   51  ,   241 ,   509 ,   163 ,   831 ,0 };
            const std::uint32_t dim268JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   9   ,   7   ,   59  ,   43  ,   111 ,   119 ,   639 ,   899 ,0 };
            const std::uint32_t dim269JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   3   ,   15  ,   47  ,   95  ,   219 ,   377 ,   899 ,   535 ,0 };
            const std::uint32_t dim270JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   11  ,   3   ,   19  ,   115 ,   59  ,   143 ,   13  ,   701 ,0 };
            const std::uint32_t dim271JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   11  ,   5   ,   17  ,   17  ,   91  ,   223 ,   923 ,   1299    ,0 };
            const std::uint32_t dim272JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   15  ,   21  ,   21  ,   85  ,   127 ,   253 ,   271 ,   725 ,0 };
            const std::uint32_t dim273JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   15  ,   9   ,   11  ,   113 ,   67  ,   509 ,   697 ,   1163    ,0 };
            const std::uint32_t dim274JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   11  ,   13  ,   53  ,   15  ,   221 ,   253 ,   219 ,   1839    ,0 };
            const std::uint32_t dim275JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   3   ,   31  ,   63  ,   85  ,   171 ,   345 ,   243 ,   711 ,0 };
            const std::uint32_t dim276JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   1   ,   25  ,   13  ,   65  ,   91  ,   441 ,   609 ,   1751    ,0 };
            const std::uint32_t dim277JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   5   ,   23  ,   1   ,   15  ,   83  ,   115 ,   367 ,   735 ,0 };
            const std::uint32_t dim278JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   3   ,   11  ,   15  ,   41  ,   1   ,   437 ,   231 ,   1529    ,0 };
            const std::uint32_t dim279JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   3   ,   29  ,   11  ,   89  ,   133 ,   473 ,   811 ,   87  ,0 };
            const std::uint32_t dim280JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   1   ,   15  ,   39  ,   97  ,   197 ,   475 ,   105 ,   527 ,0 };
            const std::uint32_t dim281JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   1   ,   9   ,   17  ,   21  ,   167 ,   255 ,   341 ,   765 ,0 };
            const std::uint32_t dim282JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   7   ,   23  ,   47  ,   121 ,   219 ,   343 ,   169 ,   1147    ,0 };
            const std::uint32_t dim283JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   7   ,   3   ,   57  ,   27  ,   147 ,   383 ,   157 ,   1851    ,0 };
            const std::uint32_t dim284JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   1   ,   25  ,   17  ,   35  ,   123 ,   371 ,   281 ,   881 ,0 };
            const std::uint32_t dim285JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   7   ,   11  ,   11  ,   21  ,   5   ,   53  ,   155 ,   1811    ,0 };
            const std::uint32_t dim286JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   15  ,   31  ,   27  ,   117 ,   169 ,   389 ,   651 ,   1513    ,0 };
            const std::uint32_t dim287JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   5   ,   31  ,   15  ,   103 ,   59  ,   73  ,   575 ,   1597    ,0 };
            const std::uint32_t dim288JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   9   ,   15  ,   5   ,   17  ,   183 ,   471 ,   561 ,   607 ,0 };
            const std::uint32_t dim289JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   5   ,   9   ,   39  ,   25  ,   87  ,   171 ,   559 ,   481 ,0 };
            const std::uint32_t dim290JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   5   ,   17  ,   61  ,   101 ,   255 ,   147 ,   481 ,   661 ,0 };
            const std::uint32_t dim291JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   1   ,   17  ,   9   ,   119 ,   31  ,   177 ,   475 ,   1243    ,0 };
            const std::uint32_t dim292JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   13  ,   27  ,   45  ,   111 ,   229 ,   201 ,   927 ,   339 ,0 };
            const std::uint32_t dim293JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   15  ,   9   ,   25  ,   23  ,   91  ,   453 ,   861 ,   1919    ,0 };
            const std::uint32_t dim294JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   3   ,   7   ,   57  ,   93  ,   75  ,   223 ,   63  ,   7   ,0 };
            const std::uint32_t dim295JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   13  ,   7   ,   29  ,   71  ,   197 ,   405 ,   401 ,   585 ,0 };
            const std::uint32_t dim296JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   13  ,   11  ,   11  ,   7   ,   157 ,   1   ,   105 ,   473 ,0 };
            const std::uint32_t dim297JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   1   ,   29  ,   3   ,   127 ,   243 ,   93  ,   123 ,   1041    ,0 };
            const std::uint32_t dim298JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   9   ,   25  ,   55  ,   13  ,   243 ,   37  ,   565 ,   1167    ,0 };
            const std::uint32_t dim299JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   15  ,   31  ,   29  ,   75  ,   61  ,   43  ,   159 ,   443 ,0 };
            const std::uint32_t dim300JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   9   ,   15  ,   63  ,   43  ,   251 ,   97  ,   141 ,   791 ,0 };
            const std::uint32_t dim301JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   3   ,   27  ,   43  ,   17  ,   49  ,   109 ,   777 ,   1999    ,0 };
            const std::uint32_t dim302JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   1   ,   25  ,   5   ,   15  ,   145 ,   75  ,   855 ,   771 ,0 };
            const std::uint32_t dim303JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   13  ,   7   ,   27  ,   3   ,   221 ,   451 ,   533 ,   1059    ,0 };
            const std::uint32_t dim304JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   13  ,   11  ,   61  ,   53  ,   33  ,   217 ,   967 ,   177 ,0 };
            const std::uint32_t dim305JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   7   ,   1   ,   7   ,   85  ,   105 ,   417 ,   87  ,   417 ,0 };
            const std::uint32_t dim306JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   3   ,   13  ,   59  ,   11  ,   219 ,   363 ,   481 ,   893 ,0 };
            const std::uint32_t dim307JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   11  ,   27  ,   23  ,   85  ,   239 ,   343 ,   43  ,   1597    ,0 };
            const std::uint32_t dim308JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   3   ,   29  ,   5   ,   127 ,   49  ,   223 ,   797 ,   2003    ,0 };
            const std::uint32_t dim309JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   9   ,   29  ,   61  ,   21  ,   191 ,   157 ,   355 ,   2033    ,0 };
            const std::uint32_t dim310JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   5   ,   5   ,   49  ,   53  ,   207 ,   121 ,   451 ,   319 ,0 };
            const std::uint32_t dim311JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   11  ,   9   ,   7   ,   111 ,   153 ,   151 ,   395 ,   1389    ,0 };
            const std::uint32_t dim312JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   11  ,   25  ,   45  ,   113 ,   99  ,   263 ,   561 ,   1181    ,0 };
            const std::uint32_t dim313JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   1   ,   13  ,   27  ,   77  ,   1   ,   109 ,   741 ,   59  ,0 };
            const std::uint32_t dim314JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   1   ,   15  ,   57  ,   43  ,   7   ,   507 ,   885 ,   747 ,0 };
            const std::uint32_t dim315JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   5   ,   25  ,   7   ,   45  ,   147 ,   375 ,   975 ,   619 ,0 };
            const std::uint32_t dim316JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   11  ,   13  ,   11  ,   107 ,   81  ,   199 ,   11  ,   1267    ,0 };
            const std::uint32_t dim317JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   3   ,   15  ,   11  ,   113 ,   61  ,   425 ,   43  ,   1889    ,0 };
            const std::uint32_t dim318JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   7   ,   29  ,   11  ,   123 ,   237 ,   173 ,   249 ,   1091    ,0 };
            const std::uint32_t dim319JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   15  ,   29  ,   13  ,   21  ,   159 ,   149 ,   379 ,   1665    ,0 };
            const std::uint32_t dim320JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   15  ,   13  ,   53  ,   23  ,   47  ,   115 ,   183 ,   577 ,0 };
            const std::uint32_t dim321JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   9   ,   11  ,   49  ,   77  ,   81  ,   193 ,   133 ,   489 ,0 };
            const std::uint32_t dim322JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   15  ,   7   ,   27  ,   53  ,   187 ,   347 ,   211 ,   233 ,0 };
            const std::uint32_t dim323JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   9   ,   15  ,   17  ,   45  ,   75  ,   449 ,   971 ,   1123    ,0 };
            const std::uint32_t dim324JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   11  ,   25  ,   21  ,   109 ,   71  ,   439 ,   439 ,   1397    ,0 };
            const std::uint32_t dim325JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   7   ,   9   ,   47  ,   117 ,   117 ,   165 ,   531 ,   271 ,0 };
            const std::uint32_t dim326JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   9   ,   11  ,   5   ,   31  ,   199 ,   159 ,   87  ,   1729    ,0 };
            const std::uint32_t dim327JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   5   ,   27  ,   29  ,   17  ,   237 ,   175 ,   881 ,   989 ,0 };
            const std::uint32_t dim328JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   13  ,   25  ,   63  ,   19  ,   159 ,   409 ,   247 ,   683 ,0 };
            const std::uint32_t dim329JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   15  ,   15  ,   39  ,   101 ,   129 ,   253 ,   487 ,   719 ,0 };
            const std::uint32_t dim330JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   1   ,   7   ,   13  ,   107 ,   249 ,   331 ,   553 ,   1199    ,0 };
            const std::uint32_t dim331JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   1   ,   5   ,   51  ,   81  ,   37  ,   349 ,   561 ,   295 ,0 };
            const std::uint32_t dim332JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   5   ,   27  ,   61  ,   49  ,   89  ,   379 ,   67  ,   1063    ,0 };
            const std::uint32_t dim333JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   9   ,   15  ,   37  ,   119 ,   141 ,   81  ,   341 ,   2003    ,0 };
            const std::uint32_t dim334JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   13  ,   29  ,   31  ,   29  ,   143 ,   463 ,   399 ,   1345    ,0 };
            const std::uint32_t dim335JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   3   ,   29  ,   35  ,   29  ,   233 ,   499 ,   503 ,   903 ,0 };
            const std::uint32_t dim336JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   13  ,   29  ,   23  ,   127 ,   185 ,   77  ,   555 ,   1311    ,0 };
            const std::uint32_t dim337JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   11  ,   23  ,   3   ,   111 ,   159 ,   503 ,   889 ,   1043    ,   1153    ,0 };
            const std::uint32_t dim338JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   1   ,   13  ,   41  ,   109 ,   133 ,   81  ,   525 ,   2027    ,   3059    ,0 };
            const std::uint32_t dim339JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   11  ,   29  ,   53  ,   111 ,   129 ,   399 ,   479 ,   467 ,   363 ,0 };
            const std::uint32_t dim340JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   3   ,   5   ,   7   ,   9   ,   21  ,   391 ,   851 ,   575 ,   1317    ,0 };
            const std::uint32_t dim341JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   5   ,   19  ,   59  ,   91  ,   133 ,   403 ,   71  ,   1895    ,   3029    ,0 };
            const std::uint32_t dim342JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   11  ,   21  ,   29  ,   113 ,   109 ,   463 ,   251 ,   393 ,   3169    ,0 };
            const std::uint32_t dim343JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   11  ,   25  ,   3   ,   47  ,   195 ,   223 ,   1003    ,   947 ,   121 ,0 };
            const std::uint32_t dim344JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   9   ,   31  ,   61  ,   63  ,   31  ,   49  ,   907 ,   389 ,   3713    ,0 };
            const std::uint32_t dim345JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   13  ,   13  ,   19  ,   55  ,   87  ,   489 ,   665 ,   945 ,   2081    ,0 };
            const std::uint32_t dim346JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   7   ,   23  ,   5   ,   39  ,   19  ,   355 ,   399 ,   929 ,   3077    ,0 };
            const std::uint32_t dim347JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   11  ,   7   ,   59  ,   43  ,   69  ,   285 ,   753 ,   75  ,   2261    ,0 };
            const std::uint32_t dim348JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   3   ,   27  ,   45  ,   29  ,   181 ,   347 ,   863 ,   1421    ,   2077    ,0 };
            const std::uint32_t dim349JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   3   ,   7   ,   27  ,   77  ,   67  ,   399 ,   919 ,   917 ,   1465    ,0 };
            const std::uint32_t dim350JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   5   ,   11  ,   41  ,   17  ,   65  ,   495 ,   643 ,   1641    ,   323 ,0 };
            const std::uint32_t dim351JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   1   ,   9   ,   37  ,   107 ,   171 ,   189 ,   405 ,   2005    ,   2811    ,0 };
            const std::uint32_t dim352JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   11  ,   3   ,   63  ,   51  ,   27  ,   479 ,   571 ,   575 ,   2859    ,0 };
            const std::uint32_t dim353JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   9   ,   29  ,   23  ,   89  ,   7   ,   265 ,   41  ,   481 ,   2177    ,0 };
            const std::uint32_t dim354JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   7   ,   29  ,   15  ,   79  ,   217 ,   411 ,   867 ,   49  ,   469 ,0 };
            const std::uint32_t dim355JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   3   ,   3   ,   27  ,   69  ,   177 ,   291 ,   965 ,   637 ,   3629    ,0 };
            const std::uint32_t dim356JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   13  ,   11  ,   45  ,   83  ,   63  ,   275 ,   851 ,   779 ,   2615    ,0 };
            const std::uint32_t dim357JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   13  ,   1   ,   27  ,   89  ,   153 ,   355 ,   811 ,   515 ,   1541    ,0 };
            const std::uint32_t dim358JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   13  ,   1   ,   21  ,   75  ,   5   ,   255 ,   813 ,   1347    ,   2301    ,0 };
            const std::uint32_t dim359JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   15  ,   9   ,   49  ,   3   ,   203 ,   505 ,   591 ,   713 ,   2893    ,0 };
            const std::uint32_t dim360JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   3   ,   1   ,   51  ,   11  ,   161 ,   41  ,   17  ,   435 ,   3045    ,0 };
            const std::uint32_t dim361JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   9   ,   15  ,   23  ,   115 ,   73  ,   343 ,   985 ,   1559    ,   1615    ,0 };
            const std::uint32_t dim362JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   5   ,   9   ,   43  ,   17  ,   187 ,   311 ,   749 ,   1841    ,   609 ,0 };
            const std::uint32_t dim363JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   15  ,   13  ,   3   ,   113 ,   83  ,   287 ,   931 ,   399 ,   2143    ,0 };
            const std::uint32_t dim364JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   13  ,   17  ,   11  ,   99  ,   235 ,   313 ,   293 ,   2005    ,   2557    ,0 };
            const std::uint32_t dim365JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   13  ,   7   ,   57  ,   79  ,   225 ,   415 ,   749 ,   1243    ,   1303    ,0 };
            const std::uint32_t dim366JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   5   ,   21  ,   37  ,   55  ,   53  ,   389 ,   141 ,   1231    ,   1639    ,0 };
            const std::uint32_t dim367JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   13  ,   15  ,   37  ,   83  ,   219 ,   471 ,   751 ,   1241    ,   269 ,0 };
            const std::uint32_t dim368JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   11  ,   7   ,   51  ,   37  ,   81  ,   97  ,   857 ,   1431    ,   883 ,0 };
            const std::uint32_t dim369JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   7   ,   27  ,   31  ,   29  ,   223 ,   439 ,   25  ,   379 ,   3721    ,0 };
            const std::uint32_t dim370JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   7   ,   13  ,   11  ,   55  ,   127 ,   493 ,   493 ,   143 ,   1595    ,0 };
            const std::uint32_t dim371JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   15  ,   27  ,   55  ,   93  ,   91  ,   49  ,   931 ,   99  ,   1887    ,0 };
            const std::uint32_t dim372JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   1   ,   13  ,   11  ,   81  ,   175 ,   171 ,   203 ,   679 ,   239 ,0 };
            const std::uint32_t dim373JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   9   ,   19  ,   35  ,   79  ,   51  ,   163 ,   571 ,   363 ,   3903    ,0 };
            const std::uint32_t dim374JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   5   ,   3   ,   11  ,   99  ,   57  ,   479 ,   571 ,   487 ,   2141    ,0 };
            const std::uint32_t dim375JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   13  ,   1   ,   3   ,   123 ,   191 ,   349 ,   523 ,   53  ,   2991    ,0 };
            const std::uint32_t dim376JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   5   ,   17  ,   1   ,   5   ,   131 ,   279 ,   717 ,   1725    ,   35  ,0 };
            const std::uint32_t dim377JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   1   ,   9   ,   43  ,   29  ,   9   ,   487 ,   349 ,   457 ,   2551    ,0 };
            const std::uint32_t dim378JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   5   ,   7   ,   55  ,   75  ,   245 ,   249 ,   623 ,   1681    ,   2345    ,0 };
            const std::uint32_t dim379JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   11  ,   15  ,   35  ,   111 ,   185 ,   269 ,   913 ,   1899    ,   4059    ,0 };
            const std::uint32_t dim380JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   3   ,   1   ,   51  ,   43  ,   159 ,   273 ,   329 ,   863 ,   831 ,0 };
            const std::uint32_t dim381JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   15  ,   31  ,   35  ,   23  ,   135 ,   223 ,   333 ,   1265    ,   1183    ,0 };
            const std::uint32_t dim382JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   9   ,   9   ,   21  ,   93  ,   33  ,   341 ,   649 ,   1707    ,   1995    ,0 };
            const std::uint32_t dim383JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   5   ,   9   ,   9   ,   9   ,   175 ,   331 ,   709 ,   927 ,   423 ,0 };
            const std::uint32_t dim384JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   1   ,   5   ,   41  ,   31  ,   105 ,   223 ,   17  ,   1485    ,   2133    ,0 };
            const std::uint32_t dim385JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   11  ,   23  ,   7   ,   95  ,   87  ,   303 ,   817 ,   1019    ,   3335    ,0 };
            const std::uint32_t dim386JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   1   ,   21  ,   3   ,   7   ,   133 ,   23  ,   235 ,   1311    ,   531 ,0 };
            const std::uint32_t dim387JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   15  ,   25  ,   35  ,   69  ,   251 ,   37  ,   5   ,   1147    ,   2593    ,0 };
            const std::uint32_t dim388JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   9   ,   21  ,   55  ,   27  ,   129 ,   239 ,   887 ,   1759    ,   3211    ,0 };
            const std::uint32_t dim389JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   15  ,   3   ,   41  ,   13  ,   141 ,   339 ,   921 ,   1081    ,   4047    ,0 };
            const std::uint32_t dim390JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   5   ,   1   ,   49  ,   51  ,   91  ,   357 ,   259 ,   547 ,   189 ,0 };
            const std::uint32_t dim391JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   13  ,   15  ,   29  ,   43  ,   165 ,   213 ,   59  ,   429 ,   1831    ,0 };
            const std::uint32_t dim392JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   9   ,   25  ,   11  ,   37  ,   67  ,   5   ,   77  ,   915 ,   3865    ,0 };
            const std::uint32_t dim393JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   9   ,   31  ,   63  ,   61  ,   209 ,   283 ,   223 ,   1253    ,   2137    ,0 };
            const std::uint32_t dim394JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   11  ,   13  ,   45  ,   65  ,   105 ,   419 ,   909 ,   1943    ,   2201    ,0 };
            const std::uint32_t dim395JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   7   ,   9   ,   27  ,   21  ,   233 ,   37  ,   23  ,   921 ,   969 ,0 };
            const std::uint32_t dim396JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   3   ,   31  ,   55  ,   39  ,   127 ,   455 ,   397 ,   65  ,   2381    ,0 };
            const std::uint32_t dim397JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   3   ,   27  ,   57  ,   39  ,   137 ,   263 ,   519 ,   427 ,   3289    ,0 };
            const std::uint32_t dim398JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   5   ,   9   ,   29  ,   21  ,   99  ,   21  ,   807 ,   1871    ,   2875    ,0 };
            const std::uint32_t dim399JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   15  ,   27  ,   59  ,   3   ,   15  ,   189 ,   681 ,   305 ,   2969    ,0 };
            const std::uint32_t dim400JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   13  ,   25  ,   43  ,   111 ,   179 ,   281 ,   377 ,   1885    ,   815 ,0 };
            const std::uint32_t dim401JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   1   ,   15  ,   13  ,   17  ,   99  ,   53  ,   269 ,   1199    ,   1771    ,0 };
            const std::uint32_t dim402JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   7   ,   7   ,   59  ,   115 ,   209 ,   327 ,   913 ,   715 ,   279 ,0 };
            const std::uint32_t dim403JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   5   ,   11  ,   29  ,   81  ,   69  ,   191 ,   453 ,   379 ,   1379    ,0 };
            const std::uint32_t dim404JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   13  ,   1   ,   29  ,   85  ,   181 ,   281 ,   463 ,   137 ,   2779    ,0 };
            const std::uint32_t dim405JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   7   ,   25  ,   39  ,   45  ,   241 ,   87  ,   11  ,   511 ,   1919    ,0 };
            const std::uint32_t dim406JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   13  ,   21  ,   17  ,   57  ,   249 ,   91  ,   165 ,   1867    ,   615 ,0 };
            const std::uint32_t dim407JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   3   ,   29  ,   47  ,   79  ,   83  ,   3   ,   765 ,   1803    ,   2741    ,0 };
            const std::uint32_t dim408JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   15  ,   29  ,   41  ,   23  ,   9   ,   205 ,   657 ,   721 ,   2877    ,0 };
            const std::uint32_t dim409JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   5   ,   31  ,   21  ,   71  ,   217 ,   19  ,   589 ,   281 ,   719 ,0 };
            const std::uint32_t dim410JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   9   ,   11  ,   37  ,   3   ,   159 ,   41  ,   823 ,   1519    ,   3395    ,0 };
            const std::uint32_t dim411JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   3   ,   7   ,   51  ,   49  ,   193 ,   37  ,   981 ,   687 ,   3219    ,0 };
            const std::uint32_t dim412JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   15  ,   3   ,   27  ,   79  ,   195 ,   155 ,   613 ,   1933    ,   2083    ,0 };
            const std::uint32_t dim413JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   11  ,   13  ,   39  ,   75  ,   109 ,   395 ,   809 ,   545 ,   499 ,0 };
            const std::uint32_t dim414JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   11  ,   1   ,   63  ,   47  ,   77  ,   455 ,   617 ,   739 ,   2885    ,0 };
            const std::uint32_t dim415JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   9   ,   23  ,   59  ,   117 ,   47  ,   379 ,   349 ,   1967    ,   1895    ,0 };
            const std::uint32_t dim416JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   15  ,   1   ,   3   ,   7   ,   7   ,   105 ,   703 ,   1777    ,   113 ,0 };
            const std::uint32_t dim417JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   7   ,   7   ,   25  ,   69  ,   123 ,   257 ,   513 ,   41  ,   2689    ,0 };
            const std::uint32_t dim418JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   15  ,   7   ,   9   ,   11  ,   67  ,   27  ,   283 ,   1139    ,   1961    ,0 };
            const std::uint32_t dim419JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   13  ,   3   ,   5   ,   53  ,   251 ,   139 ,   913 ,   267 ,   1931    ,0 };
            const std::uint32_t dim420JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   13  ,   3   ,   11  ,   79  ,   211 ,   27  ,   551 ,   339 ,   3383    ,0 };
            const std::uint32_t dim421JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   1   ,   9   ,   47  ,   111 ,   47  ,   399 ,   353 ,   1707    ,   603 ,0 };
            const std::uint32_t dim422JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   15  ,   1   ,   43  ,   17  ,   19  ,   335 ,   713 ,   645 ,   3227    ,0 };
            const std::uint32_t dim423JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   9   ,   5   ,   27  ,   17  ,   209 ,   363 ,   821 ,   1365    ,   143 ,0 };
            const std::uint32_t dim424JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   7   ,   29  ,   11  ,   47  ,   253 ,   421 ,   599 ,   465 ,   2413    ,0 };
            const std::uint32_t dim425JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   9   ,   17  ,   39  ,   5   ,   47  ,   315 ,   645 ,   713 ,   4023    ,0 };
            const std::uint32_t dim426JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   9   ,   9   ,   3   ,   11  ,   45  ,   9   ,   831 ,   1513    ,   2655    ,0 };
            const std::uint32_t dim427JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   3   ,   29  ,   55  ,   113 ,   181 ,   281 ,   329 ,   193 ,   2969    ,0 };
            const std::uint32_t dim428JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   7   ,   9   ,   15  ,   29  ,   77  ,   11  ,   627 ,   1191    ,   3589    ,0 };
            const std::uint32_t dim429JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   3   ,   27  ,   53  ,   83  ,   13  ,   409 ,   931 ,   1581    ,   371 ,0 };
            const std::uint32_t dim430JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   3   ,   11  ,   7   ,   89  ,   143 ,   369 ,   519 ,   947 ,   2047    ,0 };
            const std::uint32_t dim431JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   11  ,   27  ,   59  ,   27  ,   75  ,   199 ,   965 ,   1669    ,   1713    ,0 };
            const std::uint32_t dim432JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   1   ,   23  ,   63  ,   91  ,   159 ,   193 ,   355 ,   653 ,   2659    ,0 };
            const std::uint32_t dim433JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   11  ,   23  ,   37  ,   15  ,   73  ,   457 ,   789 ,   1207    ,   2573    ,0 };
            const std::uint32_t dim434JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   7   ,   13  ,   23  ,   71  ,   171 ,   479 ,   183 ,   1285    ,   1649    ,0 };
            const std::uint32_t dim435JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   1   ,   19  ,   13  ,   89  ,   5   ,   319 ,   15  ,   857 ,   3175    ,0 };
            const std::uint32_t dim436JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   7   ,   29  ,   7   ,   1   ,   249 ,   191 ,   237 ,   683 ,   1261    ,0 };
            const std::uint32_t dim437JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   7   ,   17  ,   53  ,   99  ,   119 ,   35  ,   63  ,   1845    ,   2681    ,0 };
            const std::uint32_t dim438JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   7   ,   23  ,   53  ,   39  ,   157 ,   323 ,   537 ,   1989    ,   1233    ,0 };
            const std::uint32_t dim439JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   7   ,   25  ,   19  ,   9   ,   67  ,   315 ,   499 ,   919 ,   2299    ,0 };
            const std::uint32_t dim440JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   9   ,   21  ,   49  ,   109 ,   185 ,   403 ,   179 ,   1967    ,   1185    ,0 };
            const std::uint32_t dim441JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   1   ,   27  ,   53  ,   33  ,   203 ,   179 ,   515 ,   1867    ,   1775    ,0 };
            const std::uint32_t dim442JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   15  ,   19  ,   25  ,   23  ,   77  ,   51  ,   467 ,   143 ,   1585    ,0 };
            const std::uint32_t dim443JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   15  ,   19  ,   35  ,   41  ,   97  ,   407 ,   319 ,   1175    ,   241 ,0 };
            const std::uint32_t dim444JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   3   ,   29  ,   51  ,   41  ,   91  ,   223 ,   671 ,   729 ,   2009    ,0 };
            const std::uint32_t dim445JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   7   ,   7   ,   55  ,   125 ,   75  ,   425 ,   699 ,   1837    ,   1515    ,0 };
            const std::uint32_t dim446JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   1   ,   27  ,   59  ,   59  ,   235 ,   43  ,   77  ,   1433    ,   3689    ,0 };
            const std::uint32_t dim447JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   9   ,   19  ,   59  ,   69  ,   85  ,   199 ,   173 ,   1947    ,   1383    ,0 };
            const std::uint32_t dim448JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   13  ,   29  ,   47  ,   121 ,   131 ,   45  ,   341 ,   85  ,   257 ,0 };
            const std::uint32_t dim449JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   1   ,   17  ,   17  ,   113 ,   103 ,   407 ,   815 ,   225 ,   2267    ,0 };
            const std::uint32_t dim450JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   3   ,   23  ,   19  ,   65  ,   173 ,   475 ,   527 ,   271 ,   261 ,0 };
            const std::uint32_t dim451JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   9   ,   23  ,   51  ,   5   ,   75  ,   403 ,   277 ,   1897    ,   353 ,0 };
            const std::uint32_t dim452JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   3   ,   31  ,   49  ,   73  ,   93  ,   55  ,   99  ,   403 ,   659 ,0 };
            const std::uint32_t dim453JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   11  ,   29  ,   17  ,   57  ,   141 ,   209 ,   907 ,   431 ,   2265    ,0 };
            const std::uint32_t dim454JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   15  ,   25  ,   55  ,   105 ,   61  ,   273 ,   201 ,   23  ,   1211    ,0 };
            const std::uint32_t dim455JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   5   ,   3   ,   63  ,   41  ,   121 ,   161 ,   713 ,   1885    ,   225 ,0 };
            const std::uint32_t dim456JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   11  ,   11  ,   53  ,   63  ,   175 ,   439 ,   1   ,   953 ,   481 ,0 };
            const std::uint32_t dim457JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   7   ,   1   ,   27  ,   65  ,   189 ,   223 ,   659 ,   413 ,   3677    ,0 };
            const std::uint32_t dim458JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   5   ,   17  ,   9   ,   51  ,   39  ,   307 ,   811 ,   941 ,   2297    ,0 };
            const std::uint32_t dim459JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   3   ,   1   ,   41  ,   77  ,   237 ,   47  ,   533 ,   1783    ,   1385    ,0 };
            const std::uint32_t dim460JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   13  ,   19  ,   39  ,   31  ,   249 ,   449 ,   639 ,   1789    ,   3479    ,0 };
            const std::uint32_t dim461JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   11  ,   9   ,   9   ,   9   ,   19  ,   481 ,   411 ,   1669    ,   863 ,0 };
            const std::uint32_t dim462JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   7   ,   15  ,   15  ,   89  ,   161 ,   171 ,   377 ,   2031    ,   389 ,0 };
            const std::uint32_t dim463JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   5   ,   7   ,   49  ,   83  ,   81  ,   181 ,   395 ,   1197    ,   2455    ,0 };
            const std::uint32_t dim464JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   9   ,   15  ,   25  ,   21  ,   35  ,   287 ,   369 ,   693 ,   1753    ,0 };
            const std::uint32_t dim465JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   7   ,   5   ,   19  ,   41  ,   241 ,   459 ,   427 ,   631 ,   1109    ,0 };
            const std::uint32_t dim466JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   3   ,   23  ,   13  ,   115 ,   55  ,   145 ,   933 ,   1985    ,   753 ,0 };
            const std::uint32_t dim467JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   5   ,   19  ,   15  ,   73  ,   67  ,   335 ,   583 ,   315 ,   1559    ,0 };
            const std::uint32_t dim468JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   5   ,   23  ,   41  ,   65  ,   155 ,   171 ,   1017    ,   1283    ,   1989    ,0 };
            const std::uint32_t dim469JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   13  ,   23  ,   53  ,   75  ,   91  ,   253 ,   41  ,   101 ,   1943    ,0 };
            const std::uint32_t dim470JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   13  ,   25  ,   13  ,   5   ,   71  ,   437 ,   553 ,   701 ,   805 ,0 };
            const std::uint32_t dim471JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   5   ,   3   ,   3   ,   61  ,   255 ,   409 ,   753 ,   1265    ,   2739    ,0 };
            const std::uint32_t dim472JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   11  ,   25  ,   33  ,   69  ,   41  ,   367 ,   133 ,   809 ,   1421    ,0 };
            const std::uint32_t dim473JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   9   ,   3   ,   59  ,   15  ,   229 ,   313 ,   667 ,   45  ,   1485    ,0 };
            const std::uint32_t dim474JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   11  ,   3   ,   45  ,   73  ,   245 ,   47  ,   489 ,   1715    ,   3167    ,0 };
            const std::uint32_t dim475JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   15  ,   23  ,   23  ,   107 ,   1   ,   171 ,   993 ,   1617    ,   3665    ,0 };
            const std::uint32_t dim476JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   5   ,   5   ,   41  ,   9   ,   221 ,   91  ,   611 ,   639 ,   3709    ,0 };
            const std::uint32_t dim477JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   1   ,   17  ,   31  ,   55  ,   23  ,   75  ,   501 ,   1605    ,   2361    ,0 };
            const std::uint32_t dim478JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   11  ,   19  ,   27  ,   37  ,   111 ,   393 ,   75  ,   523 ,   2079    ,0 };
            const std::uint32_t dim479JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   1   ,   13  ,   17  ,   103 ,   177 ,   331 ,   431 ,   419 ,   2781    ,0 };
            const std::uint32_t dim480JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   1   ,   31  ,   57  ,   9   ,   87  ,   111 ,   761 ,   1259    ,   3645    ,0 };
            const std::uint32_t dim481JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   1   ,   29  ,   39  ,   117 ,   207 ,   25  ,   263 ,   1875    ,   3325    ,   1773    ,0 };
            const std::uint32_t dim482JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   11  ,   21  ,   55  ,   105 ,   43  ,   155 ,   933 ,   585 ,   1617    ,   1705    ,0 };
            const std::uint32_t dim483JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   5   ,   29  ,   37  ,   67  ,   165 ,   229 ,   517 ,   71  ,   3927    ,   1131    ,0 };
            const std::uint32_t dim484JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   3   ,   1   ,   15  ,   7   ,   139 ,   431 ,   599 ,   101 ,   1167    ,   55  ,0 };
            const std::uint32_t dim485JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   3   ,   5   ,   31  ,   15  ,   99  ,   375 ,   491 ,   293 ,   2521    ,   1599    ,0 };
            const std::uint32_t dim486JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   13  ,   29  ,   59  ,   99  ,   155 ,   295 ,   21  ,   1459    ,   2263    ,   1997    ,0 };
            const std::uint32_t dim487JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   5   ,   29  ,   61  ,   103 ,   151 ,   37  ,   431 ,   1893    ,   2835    ,   6509    ,0 };
            const std::uint32_t dim488JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   7   ,   17  ,   15  ,   1   ,   163 ,   481 ,   547 ,   701 ,   2957    ,   7071    ,0 };
            const std::uint32_t dim489JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   5   ,   29  ,   41  ,   51  ,   223 ,   133 ,   49  ,   753 ,   3769    ,   8139    ,0 };
            const std::uint32_t dim490JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   1   ,   23  ,   23  ,   21  ,   107 ,   9   ,   445 ,   215 ,   857 ,   7913    ,0 };
            const std::uint32_t dim491JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   5   ,   17  ,   13  ,   11  ,   111 ,   419 ,   433 ,   1289    ,   2855    ,   2157    ,0 };
            const std::uint32_t dim492JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   11  ,   31  ,   3   ,   97  ,   223 ,   143 ,   117 ,   563 ,   2179    ,   1053    ,0 };
            const std::uint32_t dim493JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   13  ,   7   ,   25  ,   115 ,   151 ,   181 ,   999 ,   1027    ,   795 ,   679 ,0 };
            const std::uint32_t dim494JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   15  ,   31  ,   23  ,   85  ,   125 ,   135 ,   1001    ,   909 ,   339 ,   5693    ,0 };
            const std::uint32_t dim495JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   3   ,   29  ,   17  ,   105 ,   239 ,   467 ,   875 ,   1135    ,   1859    ,   6399    ,0 };
            const std::uint32_t dim496JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   13  ,   19  ,   59  ,   99  ,   29  ,   177 ,   879 ,   1817    ,   3747    ,   1855    ,0 };
            const std::uint32_t dim497JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   1   ,   23  ,   5   ,   29  ,   53  ,   111 ,   341 ,   1713    ,   2285    ,   7033    ,0 };
            const std::uint32_t dim498JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   5   ,   7   ,   55  ,   67  ,   173 ,   273 ,   881 ,   1405    ,   1663    ,   2135    ,0 };
            const std::uint32_t dim499JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   9   ,   1   ,   39  ,   11  ,   63  ,   107 ,   905 ,   629 ,   1773    ,   1059    ,0 };
            const std::uint32_t dim500JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   15  ,   29  ,   51  ,   111 ,   189 ,   337 ,   505 ,   453 ,   1549    ,   3697    ,0 };
            const std::uint32_t dim501JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   9   ,   23  ,   57  ,   21  ,   61  ,   161 ,   695 ,   1097    ,   809 ,   5737    ,0 };
            const std::uint32_t dim502JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   15  ,   15  ,   55  ,   93  ,   65  ,   101 ,   521 ,   1273    ,   1949    ,   7325    ,0 };
            const std::uint32_t dim503JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   3   ,   23  ,   31  ,   37  ,   51  ,   205 ,   261 ,   647 ,   1905    ,   4407    ,0 };
            const std::uint32_t dim504JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   3   ,   3   ,   9   ,   91  ,   51  ,   271 ,   623 ,   1611    ,   563 ,   4687    ,0 };
            const std::uint32_t dim505JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   3   ,   11  ,   61  ,   95  ,   215 ,   347 ,   171 ,   519 ,   2331    ,   2189    ,0 };
            const std::uint32_t dim506JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   1   ,   25  ,   13  ,   87  ,   159 ,   87  ,   915 ,   463 ,   1345    ,   5901    ,0 };
            const std::uint32_t dim507JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   11  ,   31  ,   21  ,   81  ,   75  ,   153 ,   337 ,   2025    ,   233 ,   4999    ,0 };
            const std::uint32_t dim508JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   11  ,   23  ,   25  ,   81  ,   149 ,   225 ,   799 ,   159 ,   799 ,   687 ,0 };
            const std::uint32_t dim509JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   5   ,   23  ,   55  ,   67  ,   47  ,   375 ,   657 ,   877 ,   1505    ,   1757    ,0 };
            const std::uint32_t dim510JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   9   ,   17  ,   7   ,   123 ,   71  ,   203 ,   457 ,   201 ,   9   ,   6671    ,0 };
            const std::uint32_t dim511JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   3   ,   1   ,   55  ,   7   ,   133 ,   65  ,   891 ,   1705    ,   389 ,   4601    ,0 };
            const std::uint32_t dim512JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   3   ,   21  ,   59  ,   101 ,   105 ,   241 ,   231 ,   363 ,   4029    ,   1279    ,0 };
            const std::uint32_t dim513JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   11  ,   31  ,   61  ,   115 ,   219 ,   249 ,   575 ,   201 ,   547 ,   5315    ,0 };
            const std::uint32_t dim514JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   11  ,   11  ,   3   ,   75  ,   219 ,   183 ,   771 ,   725 ,   2175    ,   4077    ,0 };
            const std::uint32_t dim515JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   13  ,   1   ,   37  ,   1   ,   165 ,   431 ,   423 ,   2021    ,   475 ,   5151    ,0 };
            const std::uint32_t dim516JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   7   ,   15  ,   59  ,   25  ,   133 ,   377 ,   747 ,   23  ,   1195    ,   3303    ,0 };
            const std::uint32_t dim517JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   15  ,   23  ,   63  ,   121 ,   159 ,   403 ,   143 ,   187 ,   1481    ,   4755    ,0 };
            const std::uint32_t dim518JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   13  ,   21  ,   29  ,   55  ,   165 ,   483 ,   495 ,   579 ,   1197    ,   4841    ,0 };
            const std::uint32_t dim519JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   3   ,   27  ,   7   ,   111 ,   57  ,   353 ,   1023    ,   1593    ,   1447    ,   5819    ,0 };
            const std::uint32_t dim520JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   3   ,   13  ,   37  ,   115 ,   65  ,   23  ,   707 ,   603 ,   1805    ,   6011    ,0 };
            const std::uint32_t dim521JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   15  ,   9   ,   47  ,   87  ,   195 ,   125 ,   515 ,   1885    ,   89  ,   1377    ,0 };
            const std::uint32_t dim522JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   11  ,   1   ,   25  ,   11  ,   73  ,   183 ,   897 ,   981 ,   275 ,   331 ,0 };
            const std::uint32_t dim523JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   15  ,   13  ,   53  ,   125 ,   37  ,   145 ,   763 ,   1991    ,   1971    ,   4385    ,0 };
            const std::uint32_t dim524JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   1   ,   29  ,   53  ,   69  ,   97  ,   415 ,   151 ,   1389    ,   2867    ,   3085    ,0 };
            const std::uint32_t dim525JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   7   ,   21  ,   51  ,   77  ,   115 ,   81  ,   197 ,   91  ,   3417    ,   2357    ,0 };
            const std::uint32_t dim526JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   11  ,   31  ,   31  ,   21  ,   21  ,   93  ,   221 ,   1401    ,   3253    ,   6875    ,0 };
            const std::uint32_t dim527JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   9   ,   11  ,   17  ,   87  ,   75  ,   333 ,   871 ,   1679    ,   2943    ,   4803    ,0 };
            const std::uint32_t dim528JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   11  ,   11  ,   61  ,   67  ,   141 ,   79  ,   757 ,   965 ,   1999    ,   6363    ,0 };
            const std::uint32_t dim529JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   5   ,   27  ,   13  ,   109 ,   137 ,   235 ,   1007    ,   1307    ,   341 ,   3957    ,0 };
            const std::uint32_t dim530JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   9   ,   15  ,   37  ,   47  ,   247 ,   295 ,   867 ,   1433    ,   553 ,   5365    ,0 };
            const std::uint32_t dim531JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   3   ,   13  ,   29  ,   77  ,   155 ,   423 ,   823 ,   1117    ,   3939    ,   1423    ,0 };
            const std::uint32_t dim532JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   9   ,   17  ,   27  ,   47  ,   73  ,   79  ,   329 ,   1473    ,   3241    ,   697 ,0 };
            const std::uint32_t dim533JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   9   ,   23  ,   5   ,   47  ,   89  ,   427 ,   893 ,   2031    ,   3415    ,   6367    ,0 };
            const std::uint32_t dim534JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   1   ,   17  ,   47  ,   31  ,   113 ,   461 ,   417 ,   2017    ,   41  ,   2417    ,0 };
            const std::uint32_t dim535JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   5   ,   11  ,   35  ,   119 ,   95  ,   389 ,   31  ,   871 ,   563 ,   7547    ,0 };
            const std::uint32_t dim536JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   9   ,   3   ,   49  ,   63  ,   237 ,   511 ,   619 ,   589 ,   3571    ,   1883    ,0 };
            const std::uint32_t dim537JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   1   ,   1   ,   29  ,   17  ,   117 ,   173 ,   399 ,   443 ,   2625    ,   2009    ,0 };
            const std::uint32_t dim538JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   9   ,   23  ,   47  ,   5   ,   167 ,   413 ,   513 ,   509 ,   853 ,   3509    ,0 };
            const std::uint32_t dim539JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   5   ,   13  ,   15  ,   33  ,   165 ,   21  ,   163 ,   1613    ,   3387    ,   645 ,0 };
            const std::uint32_t dim540JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   3   ,   7   ,   33  ,   59  ,   25  ,   65  ,   243 ,   1253    ,   1893    ,   1637    ,0 };
            const std::uint32_t dim541JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   15  ,   21  ,   63  ,   51  ,   167 ,   131 ,   171 ,   651 ,   295 ,   5775    ,0 };
            const std::uint32_t dim542JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   9   ,   7   ,   23  ,   31  ,   171 ,   85  ,   859 ,   1691    ,   2757    ,   1351    ,0 };
            const std::uint32_t dim543JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   3   ,   31  ,   7   ,   25  ,   69  ,   183 ,   417 ,   39  ,   2671    ,   5197    ,0 };
            const std::uint32_t dim544JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   9   ,   17  ,   21  ,   57  ,   145 ,   23  ,   933 ,   2031    ,   65  ,   4583    ,0 };
            const std::uint32_t dim545JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   5   ,   1   ,   59  ,   117 ,   191 ,   197 ,   627 ,   659 ,   2873    ,   3865    ,0 };
            const std::uint32_t dim546JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   15  ,   23  ,   51  ,   45  ,   47  ,   147 ,   779 ,   1619    ,   1017    ,   3769    ,0 };
            const std::uint32_t dim547JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   3   ,   9   ,   1   ,   75  ,   151 ,   117 ,   483 ,   1499    ,   2143    ,   5873    ,0 };
            const std::uint32_t dim548JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   1   ,   13  ,   31  ,   105 ,   115 ,   199 ,   111 ,   1403    ,   1833    ,   7923    ,0 };
            const std::uint32_t dim549JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   7   ,   29  ,   53  ,   121 ,   149 ,   419 ,   107 ,   1299    ,   1925    ,   4409    ,0 };
            const std::uint32_t dim550JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   11  ,   21  ,   25  ,   63  ,   97  ,   145 ,   71  ,   1693    ,   465 ,   5607    ,0 };
            const std::uint32_t dim551JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   15  ,   25  ,   43  ,   77  ,   177 ,   53  ,   495 ,   1983    ,   4083    ,   2107    ,0 };
            const std::uint32_t dim552JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   11  ,   7   ,   51  ,   109 ,   29  ,   171 ,   847 ,   673 ,   2929    ,   3887    ,0 };
            const std::uint32_t dim553JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   9   ,   31  ,   47  ,   63  ,   225 ,   371 ,   453 ,   1075    ,   2293    ,   3323    ,0 };
            const std::uint32_t dim554JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   9   ,   31  ,   29  ,   67  ,   227 ,   135 ,   369 ,   481 ,   187 ,   3237    ,0 };
            const std::uint32_t dim555JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   7   ,   1   ,   29  ,   49  ,   157 ,   99  ,   741 ,   279 ,   1963    ,   7881    ,0 };
            const std::uint32_t dim556JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   13  ,   17  ,   49  ,   33  ,   73  ,   103 ,   941 ,   209 ,   1329    ,   3   ,0 };
            const std::uint32_t dim557JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   1   ,   17  ,   41  ,   53  ,   57  ,   163 ,   761 ,   1855    ,   3423    ,   5317    ,0 };
            const std::uint32_t dim558JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   1   ,   11  ,   13  ,   59  ,   37  ,   351 ,   561 ,   1213    ,   2355    ,   8095    ,0 };
            const std::uint32_t dim559JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   3   ,   3   ,   31  ,   47  ,   237 ,   101 ,   167 ,   1623    ,   645 ,   4787    ,0 };
            const std::uint32_t dim560JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   9   ,   21  ,   33  ,   55  ,   15  ,   433 ,   129 ,   279 ,   2131    ,   2943    ,0 };
            const std::uint32_t dim561JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   13  ,   9   ,   55  ,   71  ,   151 ,   273 ,   901 ,   427 ,   3749    ,   8163    ,0 };
            const std::uint32_t dim562JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   13  ,   13  ,   63  ,   11  ,   63  ,   477 ,   743 ,   1391    ,   2045    ,   6985    ,0 };
            const std::uint32_t dim563JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   11  ,   31  ,   25  ,   93  ,   217 ,   39  ,   263 ,   1411    ,   3   ,   7313    ,0 };
            const std::uint32_t dim564JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   1   ,   21  ,   13  ,   3   ,   255 ,   107 ,   851 ,   1281    ,   959 ,   3955    ,0 };
            const std::uint32_t dim565JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   9   ,   19  ,   55  ,   53  ,   201 ,   199 ,   361 ,   805 ,   579 ,   1459    ,0 };
            const std::uint32_t dim566JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   15  ,   9   ,   59  ,   109 ,   245 ,   29  ,   21  ,   137 ,   717 ,   607 ,0 };
            const std::uint32_t dim567JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   11  ,   15  ,   23  ,   49  ,   3   ,   195 ,   185 ,   85  ,   3885    ,   5859    ,0 };
            const std::uint32_t dim568JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   3   ,   13  ,   21  ,   7   ,   65  ,   185 ,   541 ,   305 ,   79  ,   3125    ,0 };
            const std::uint32_t dim569JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   3   ,   7   ,   59  ,   11  ,   125 ,   127 ,   283 ,   943 ,   3545    ,   1617    ,0 };
            const std::uint32_t dim570JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   3   ,   19  ,   39  ,   73  ,   167 ,   431 ,   147 ,   3   ,   1099    ,   6311    ,0 };
            const std::uint32_t dim571JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   13  ,   29  ,   57  ,   109 ,   169 ,   49  ,   457 ,   469 ,   3093    ,   7505    ,0 };
            const std::uint32_t dim572JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   1   ,   15  ,   29  ,   69  ,   133 ,   423 ,   737 ,   673 ,   2529    ,   2065    ,0 };
            const std::uint32_t dim573JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   7   ,   21  ,   47  ,   15  ,   175 ,   17  ,   419 ,   1917    ,   1183    ,   429 ,0 };
            const std::uint32_t dim574JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   9   ,   31  ,   43  ,   19  ,   63  ,   395 ,   331 ,   385 ,   3879    ,   3233    ,0 };
            const std::uint32_t dim575JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   9   ,   5   ,   11  ,   101 ,   65  ,   315 ,   805 ,   719 ,   641 ,   343 ,0 };
            const std::uint32_t dim576JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   1   ,   15  ,   5   ,   17  ,   115 ,   503 ,   395 ,   531 ,   1201    ,   7225    ,0 };
            const std::uint32_t dim577JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   7   ,   3   ,   35  ,   29  ,   1   ,   297 ,   421 ,   1365    ,   1491    ,   7973    ,0 };
            const std::uint32_t dim578JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   13  ,   1   ,   59  ,   79  ,   13  ,   337 ,   717 ,   1229    ,   2587    ,   5659    ,0 };
            const std::uint32_t dim579JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   9   ,   21  ,   15  ,   27  ,   19  ,   195 ,   27  ,   267 ,   381 ,   1969    ,0 };
            const std::uint32_t dim580JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   7   ,   25  ,   63  ,   119 ,   155 ,   243 ,   229 ,   897 ,   629 ,   7515    ,0 };
            const std::uint32_t dim581JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   1   ,   13  ,   37  ,   35  ,   31  ,   485 ,   729 ,   123 ,   1645    ,   457 ,0 };
            const std::uint32_t dim582JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   11  ,   17  ,   15  ,   47  ,   149 ,   311 ,   189 ,   1925    ,   9   ,   7639    ,0 };
            const std::uint32_t dim583JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   3   ,   1   ,   1   ,   127 ,   197 ,   109 ,   49  ,   265 ,   3643    ,   3629    ,0 };
            const std::uint32_t dim584JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   15  ,   21  ,   49  ,   71  ,   187 ,   189 ,   631 ,   1449    ,   775 ,   5973    ,0 };
            const std::uint32_t dim585JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   5   ,   27  ,   15  ,   17  ,   137 ,   393 ,   807 ,   1189    ,   2731    ,   6337    ,0 };
            const std::uint32_t dim586JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   11  ,   3   ,   43  ,   3   ,   77  ,   487 ,   539 ,   1781    ,   3261    ,   2775    ,0 };
            const std::uint32_t dim587JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   13  ,   29  ,   31  ,   83  ,   225 ,   159 ,   971 ,   1899    ,   1035    ,   5383    ,0 };
            const std::uint32_t dim588JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   7   ,   27  ,   1   ,   15  ,   141 ,   485 ,   639 ,   1895    ,   3129    ,   4489    ,0 };
            const std::uint32_t dim589JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   5   ,   9   ,   17  ,   21  ,   231 ,   363 ,   637 ,   1851    ,   3675    ,   5371    ,0 };
            const std::uint32_t dim590JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   11  ,   9   ,   17  ,   91  ,   243 ,   51  ,   565 ,   491 ,   3333    ,   3329    ,0 };
            const std::uint32_t dim591JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   3   ,   13  ,   9   ,   19  ,   227 ,   353 ,   111 ,   1805    ,   3917    ,   6849    ,0 };
            const std::uint32_t dim592JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   1   ,   29  ,   31  ,   27  ,   57  ,   421 ,   155 ,   1385    ,   999 ,   1581    ,0 };
            const std::uint32_t dim593JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   7   ,   1   ,   55  ,   35  ,   35  ,   311 ,   357 ,   1569    ,   2693    ,   2251    ,0 };
            const std::uint32_t dim594JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   9   ,   27  ,   41  ,   111 ,   119 ,   265 ,   165 ,   1999    ,   2067    ,   7801    ,0 };
            const std::uint32_t dim595JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   15  ,   31  ,   55  ,   31  ,   39  ,   305 ,   581 ,   373 ,   2523    ,   2153    ,0 };
            const std::uint32_t dim596JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   7   ,   9   ,   19  ,   115 ,   41  ,   261 ,   209 ,   897 ,   409 ,   5201    ,0 };
            const std::uint32_t dim597JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   13  ,   3   ,   15  ,   95  ,   143 ,   407 ,   719 ,   1763    ,   1763    ,   1173    ,0 };
            const std::uint32_t dim598JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   11  ,   17  ,   13  ,   69  ,   17  ,   293 ,   815 ,   1361    ,   259 ,   6751    ,0 };
            const std::uint32_t dim599JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   15  ,   11  ,   53  ,   13  ,   195 ,   153 ,   445 ,   1873    ,   1159    ,   4739    ,0 };
            const std::uint32_t dim600JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   7   ,   3   ,   25  ,   57  ,   229 ,   269 ,   299 ,   1687    ,   2707    ,   7049    ,0 };
            const std::uint32_t dim601JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   1   ,   5   ,   23  ,   89  ,   171 ,   207 ,   523 ,   2031    ,   2513    ,   2475    ,0 };
            const std::uint32_t dim602JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   7   ,   25  ,   57  ,   125 ,   109 ,   203 ,   671 ,   781 ,   295 ,   4001    ,0 };
            const std::uint32_t dim603JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   3   ,   17  ,   37  ,   51  ,   169 ,   441 ,   797 ,   871 ,   3267    ,   5695    ,0 };
            const std::uint32_t dim604JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   5   ,   17  ,   25  ,   97  ,   41  ,   377 ,   643 ,   1463    ,   141 ,   3961    ,0 };
            const std::uint32_t dim605JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   1   ,   17  ,   35  ,   111 ,   91  ,   253 ,   237 ,   1491    ,   2839    ,   2265    ,0 };
            const std::uint32_t dim606JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   13  ,   23  ,   7   ,   47  ,   61  ,   263 ,   591 ,   1365    ,   2371    ,   4209    ,0 };
            const std::uint32_t dim607JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   5   ,   7   ,   51  ,   117 ,   161 ,   383 ,   303 ,   1765    ,   3105    ,   3961    ,0 };
            const std::uint32_t dim608JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   11  ,   11  ,   55  ,   111 ,   55  ,   417 ,   713 ,   305 ,   1781    ,   5283    ,0 };
            const std::uint32_t dim609JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   11  ,   25  ,   51  ,   17  ,   215 ,   335 ,   47  ,   1789    ,   2049    ,   5349    ,0 };
            const std::uint32_t dim610JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   3   ,   1   ,   9   ,   71  ,   105 ,   397 ,   517 ,   1093    ,   765 ,   5301    ,0 };
            const std::uint32_t dim611JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   9   ,   31  ,   41  ,   95  ,   153 ,   383 ,   91  ,   1649    ,   3059    ,   6135    ,0 };
            const std::uint32_t dim612JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   11  ,   19  ,   51  ,   67  ,   119 ,   507 ,   179 ,   571 ,   2767    ,   5517    ,0 };
            const std::uint32_t dim613JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   9   ,   13  ,   19  ,   35  ,   249 ,   39  ,   425 ,   233 ,   1635    ,   5915    ,0 };
            const std::uint32_t dim614JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   11  ,   17  ,   15  ,   43  ,   29  ,   351 ,   25  ,   1879    ,   3941    ,   189 ,0 };
            const std::uint32_t dim615JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   5   ,   13  ,   55  ,   9   ,   7   ,   91  ,   951 ,   1681    ,   2723    ,   4349    ,0 };
            const std::uint32_t dim616JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   9   ,   27  ,   31  ,   49  ,   33  ,   287 ,   629 ,   851 ,   1353    ,   6391    ,0 };
            const std::uint32_t dim617JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   7   ,   19  ,   27  ,   45  ,   209 ,   257 ,   141 ,   1771    ,   931 ,   7839    ,0 };
            const std::uint32_t dim618JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   1   ,   9   ,   47  ,   87  ,   71  ,   183 ,   249 ,   311 ,   1989    ,   1753    ,0 };
            const std::uint32_t dim619JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   5   ,   7   ,   35  ,   45  ,   199 ,   207 ,   203 ,   831 ,   2643    ,   1155    ,0 };
            const std::uint32_t dim620JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   11  ,   5   ,   11  ,   27  ,   187 ,   405 ,   747 ,   261 ,   1279    ,   6153    ,0 };
            const std::uint32_t dim621JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   9   ,   7   ,   43  ,   23  ,   117 ,   421 ,   775 ,   1657    ,   1071    ,   4551    ,0 };
            const std::uint32_t dim622JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   9   ,   1   ,   51  ,   5   ,   27  ,   121 ,   459 ,   1251    ,   901 ,   2301    ,0 };
            const std::uint32_t dim623JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   11  ,   15  ,   47  ,   107 ,   93  ,   79  ,   719 ,   571 ,   65  ,   7589    ,0 };
            const std::uint32_t dim624JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   3   ,   19  ,   33  ,   103 ,   253 ,   469 ,   109 ,   913 ,   2251    ,   4737    ,0 };
            const std::uint32_t dim625JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   5   ,   23  ,   29  ,   89  ,   79  ,   253 ,   513 ,   723 ,   3823    ,   5769    ,0 };
            const std::uint32_t dim626JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   1   ,   27  ,   3   ,   103 ,   171 ,   353 ,   673 ,   1147    ,   529 ,   4737    ,0 };
            const std::uint32_t dim627JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   7   ,   27  ,   5   ,   103 ,   61  ,   101 ,   759 ,   443 ,   2003    ,   5537    ,0 };
            const std::uint32_t dim628JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   5   ,   11  ,   15  ,   109 ,   119 ,   473 ,   585 ,   1759    ,   319 ,   5461    ,0 };
            const std::uint32_t dim629JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   9   ,   19  ,   61  ,   5   ,   255 ,   171 ,   843 ,   823 ,   2713    ,   5313    ,0 };
            const std::uint32_t dim630JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   3   ,   9   ,   11  ,   57  ,   3   ,   365 ,   471 ,   1179    ,   1999    ,   3333    ,0 };
            const std::uint32_t dim631JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   9   ,   1   ,   3   ,   3   ,   195 ,   441 ,   193 ,   1905    ,   1753    ,   1839    ,0 };
            const std::uint32_t dim632JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   3   ,   1   ,   49  ,   99  ,   85  ,   175 ,   603 ,   1569    ,   2201    ,   1979    ,0 };
            const std::uint32_t dim633JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   5   ,   27  ,   37  ,   61  ,   137 ,   219 ,   469 ,   973 ,   1979    ,   1135    ,0 };
            const std::uint32_t dim634JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   13  ,   3   ,   59  ,   11  ,   203 ,   415 ,   513 ,   1469    ,   1655    ,   5913    ,0 };
            const std::uint32_t dim635JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   7   ,   21  ,   23  ,   87  ,   83  ,   21  ,   351 ,   899 ,   1633    ,   6589    ,0 };
            const std::uint32_t dim636JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   5   ,   5   ,   63  ,   45  ,   201 ,   193 ,   27  ,   1365    ,   1197    ,   1729    ,0 };
            const std::uint32_t dim637JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   5   ,   1   ,   35  ,   59  ,   157 ,   295 ,   359 ,   383 ,   3191    ,   7019    ,0 };
            const std::uint32_t dim638JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   13  ,   3   ,   23  ,   17  ,   149 ,   59  ,   115 ,   1101    ,   1879    ,   4243    ,0 };
            const std::uint32_t dim639JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   5   ,   3   ,   21  ,   71  ,   31  ,   85  ,   93  ,   1691    ,   379 ,   7901    ,0 };
            const std::uint32_t dim640JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   13  ,   15  ,   7   ,   29  ,   59  ,   191 ,   817 ,   439 ,   453 ,   5073    ,0 };
            const std::uint32_t dim641JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   9   ,   29  ,   7   ,   119 ,   35  ,   393 ,   9   ,   509 ,   3907    ,   7031    ,0 };
            const std::uint32_t dim642JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   3   ,   29  ,   51  ,   19  ,   127 ,   399 ,   309 ,   117 ,   3491    ,   5417    ,0 };
            const std::uint32_t dim643JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   5   ,   31  ,   33  ,   17  ,   119 ,   365 ,   301 ,   527 ,   3341    ,   779 ,0 };
            const std::uint32_t dim644JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   1   ,   29  ,   41  ,   43  ,   85  ,   133 ,   191 ,   229 ,   3407    ,   3147    ,0 };
            const std::uint32_t dim645JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   3   ,   7   ,   9   ,   49  ,   121 ,   193 ,   569 ,   467 ,   999 ,   6813    ,0 };
            const std::uint32_t dim646JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   13  ,   7   ,   23  ,   121 ,   43  ,   173 ,   761 ,   525 ,   3221    ,   5435    ,0 };
            const std::uint32_t dim647JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   3   ,   15  ,   43  ,   47  ,   149 ,   227 ,   357 ,   1219    ,   4087    ,   1215    ,0 };
            const std::uint32_t dim648JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   15  ,   1   ,   33  ,   81  ,   195 ,   201 ,   307 ,   1081    ,   3201    ,   4293    ,0 };
            const std::uint32_t dim649JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   11  ,   11  ,   1   ,   125 ,   119 ,   105 ,   783 ,   117 ,   3465    ,   5713    ,0 };
            const std::uint32_t dim650JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   1   ,   1   ,   51  ,   17  ,   141 ,   107 ,   875 ,   1135    ,   1213    ,   7113    ,0 };
            const std::uint32_t dim651JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   1   ,   7   ,   41  ,   63  ,   91  ,   465 ,   893 ,   1663    ,   2717    ,   6313    ,0 };
            const std::uint32_t dim652JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   15  ,   23  ,   43  ,   77  ,   49  ,   131 ,   953 ,   1591    ,   869 ,   3779    ,0 };
            const std::uint32_t dim653JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   15  ,   5   ,   9   ,   41  ,   183 ,   403 ,   775 ,   1163    ,   2963    ,   861 ,0 };
            const std::uint32_t dim654JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   11  ,   27  ,   19  ,   51  ,   139 ,   87  ,   315 ,   831 ,   2587    ,   4847    ,0 };
            const std::uint32_t dim655JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   13  ,   23  ,   23  ,   117 ,   189 ,   405 ,   735 ,   681 ,   457 ,   337 ,0 };
            const std::uint32_t dim656JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   5   ,   13  ,   21  ,   25  ,   207 ,   179 ,   715 ,   629 ,   593 ,   6351    ,0 };
            const std::uint32_t dim657JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   3   ,   25  ,   13  ,   31  ,   245 ,   147 ,   953 ,   1061    ,   3749    ,   6927    ,0 };
            const std::uint32_t dim658JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   9   ,   29  ,   27  ,   57  ,   5   ,   345 ,   471 ,   599 ,   3677    ,   1801    ,0 };
            const std::uint32_t dim659JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   5   ,   21  ,   47  ,   27  ,   21  ,   473 ,   881 ,   1973    ,   995 ,   6513    ,0 };
            const std::uint32_t dim660JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   7   ,   23  ,   1   ,   19  ,   197 ,   43  ,   955 ,   1503    ,   2825    ,   7241    ,0 };
            const std::uint32_t dim661JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   13  ,   5   ,   51  ,   51  ,   33  ,   349 ,   835 ,   1367    ,   1913    ,   1963    ,0 };
            const std::uint32_t dim662JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   5   ,   19  ,   63  ,   9   ,   145 ,   335 ,   843 ,   655 ,   1049    ,   3421    ,0 };
            const std::uint32_t dim663JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   1   ,   1   ,   33  ,   1   ,   9   ,   35  ,   833 ,   629 ,   3453    ,   6341    ,0 };
            const std::uint32_t dim664JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   11  ,   3   ,   55  ,   119 ,   87  ,   441 ,   43  ,   169 ,   761 ,   753 ,0 };
            const std::uint32_t dim665JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   5   ,   17  ,   11  ,   87  ,   165 ,   421 ,   1005    ,   1227    ,   3381    ,   1005    ,0 };
            const std::uint32_t dim666JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   13  ,   17  ,   19  ,   63  ,   71  ,   251 ,   355 ,   1127    ,   2575    ,   1193    ,0 };
            const std::uint32_t dim667JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   13  ,   9   ,   23  ,   71  ,   173 ,   421 ,   179 ,   1899    ,   2507    ,   8083    ,0 };
            const std::uint32_t dim668JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   15  ,   1   ,   13  ,   81  ,   169 ,   85  ,   957 ,   1109    ,   2767    ,   447 ,0 };
            const std::uint32_t dim669JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   15  ,   19  ,   41  ,   61  ,   247 ,   325 ,   273 ,   469 ,   1859    ,   6869    ,0 };
            const std::uint32_t dim670JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   9   ,   15  ,   3   ,   3   ,   119 ,   377 ,   579 ,   1155    ,   325 ,   143 ,0 };
            const std::uint32_t dim671JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   11  ,   31  ,   1   ,   43  ,   135 ,   375 ,   383 ,   1497    ,   2759    ,   43  ,0 };
            const std::uint32_t dim672JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   5   ,   1   ,   63  ,   75  ,   179 ,   447 ,   113 ,   1037    ,   631 ,   4969    ,0 };
            const std::uint32_t dim673JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   13  ,   13  ,   61  ,   63  ,   229 ,   85  ,   223 ,   153 ,   3987    ,   4685    ,0 };
            const std::uint32_t dim674JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   13  ,   17  ,   33  ,   17  ,   247 ,   399 ,   559 ,   369 ,   1525    ,   4923    ,0 };
            const std::uint32_t dim675JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   13  ,   1   ,   63  ,   69  ,   167 ,   407 ,   191 ,   499 ,   1697    ,   3267    ,0 };
            const std::uint32_t dim676JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   9   ,   31  ,   15  ,   97  ,   183 ,   165 ,   271 ,   1465    ,   931 ,   4061    ,0 };
            const std::uint32_t dim677JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   1   ,   31  ,   7   ,   121 ,   37  ,   429 ,   375 ,   1539    ,   1383    ,   7317    ,0 };
            const std::uint32_t dim678JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   9   ,   13  ,   41  ,   49  ,   205 ,   233 ,   847 ,   187 ,   359 ,   2341    ,0 };
            const std::uint32_t dim679JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   5   ,   25  ,   5   ,   57  ,   119 ,   79  ,   131 ,   1707    ,   1601    ,   1657    ,0 };
            const std::uint32_t dim680JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   9   ,   21  ,   11  ,   89  ,   149 ,   369 ,   401 ,   623 ,   3001    ,   85  ,0 };
            const std::uint32_t dim681JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   15  ,   31  ,   9   ,   109 ,   33  ,   31  ,   93  ,   2035    ,   3785    ,   5893    ,0 };
            const std::uint32_t dim682JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   3   ,   31  ,   57  ,   15  ,   161 ,   333 ,   559 ,   1487    ,   1037    ,   1055    ,0 };
            const std::uint32_t dim683JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   13  ,   7   ,   9   ,   7   ,   109 ,   151 ,   629 ,   295 ,   105 ,   1121    ,0 };
            const std::uint32_t dim684JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   3   ,   7   ,   25  ,   49  ,   5   ,   95  ,   321 ,   303 ,   2571    ,   6967    ,0 };
            const std::uint32_t dim685JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   3   ,   27  ,   13  ,   65  ,   27  ,   507 ,   847 ,   155 ,   3183    ,   5985    ,0 };
            const std::uint32_t dim686JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   9   ,   17  ,   29  ,   69  ,   23  ,   181 ,   855 ,   1659    ,   889 ,   1273    ,0 };
            const std::uint32_t dim687JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   5   ,   19  ,   41  ,   109 ,   97  ,   373 ,   591 ,   1715    ,   3927    ,   3101    ,0 };
            const std::uint32_t dim688JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   3   ,   9   ,   9   ,   75  ,   63  ,   1   ,   39  ,   941 ,   3677    ,   7253    ,0 };
            const std::uint32_t dim689JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   11  ,   27  ,   37  ,   25  ,   33  ,   213 ,   917 ,   2037    ,   145 ,   4395    ,0 };
            const std::uint32_t dim690JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   11  ,   23  ,   21  ,   15  ,   195 ,   87  ,   699 ,   1475    ,   429 ,   1641    ,0 };
            const std::uint32_t dim691JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   1   ,   1   ,   51  ,   117 ,   13  ,   369 ,   711 ,   625 ,   3171    ,   1867    ,0 };
            const std::uint32_t dim692JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   15  ,   23  ,   11  ,   47  ,   177 ,   511 ,   709 ,   255 ,   2355    ,   71  ,0 };
            const std::uint32_t dim693JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   9   ,   7   ,   21  ,   21  ,   35  ,   303 ,   105 ,   525 ,   589 ,   5449    ,0 };
            const std::uint32_t dim694JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   7   ,   21  ,   27  ,   71  ,   177 ,   205 ,   143 ,   385 ,   2949    ,   8169    ,0 };
            const std::uint32_t dim695JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   9   ,   19  ,   39  ,   79  ,   241 ,   103 ,   489 ,   1399    ,   2781    ,   5533    ,0 };
            const std::uint32_t dim696JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   5   ,   23  ,   9   ,   121 ,   51  ,   145 ,   927 ,   1457    ,   1891    ,   7475    ,0 };
            const std::uint32_t dim697JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   1   ,   7   ,   23  ,   67  ,   145 ,   161 ,   63  ,   569 ,   395 ,   6719    ,0 };
            const std::uint32_t dim698JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   11  ,   5   ,   31  ,   13  ,   9   ,   135 ,   367 ,   1591    ,   1963    ,   7249    ,0 };
            const std::uint32_t dim699JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   13  ,   7   ,   47  ,   119 ,   195 ,   439 ,   619 ,   551 ,   1955    ,   6913    ,0 };
            const std::uint32_t dim700JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   1   ,   29  ,   57  ,   43  ,   213 ,   113 ,   339 ,   1943    ,   183 ,   3063    ,0 };
            const std::uint32_t dim701JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   11  ,   1   ,   3   ,   57  ,   149 ,   495 ,   547 ,   603 ,   907 ,   1349    ,0 };
            const std::uint32_t dim702JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   7   ,   7   ,   31  ,   87  ,   49  ,   239 ,   827 ,   1451    ,   3171    ,   287 ,0 };
            const std::uint32_t dim703JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   15  ,   11  ,   41  ,   29  ,   233 ,   101 ,   573 ,   737 ,   3813    ,   7739    ,0 };
            const std::uint32_t dim704JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   9   ,   19  ,   13  ,   57  ,   177 ,   259 ,   595 ,   263 ,   2851    ,   5771    ,0 };
            const std::uint32_t dim705JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   13  ,   13  ,   5   ,   27  ,   133 ,   17  ,   725 ,   417 ,   2277    ,   5649    ,0 };
            const std::uint32_t dim706JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   13  ,   25  ,   57  ,   35  ,   229 ,   253 ,   761 ,   275 ,   2519    ,   7061    ,0 };
            const std::uint32_t dim707JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   13  ,   9   ,   31  ,   61  ,   181 ,   129 ,   259 ,   1569    ,   817 ,   4665    ,0 };
            const std::uint32_t dim708JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   5   ,   23  ,   3   ,   69  ,   161 ,   429 ,   143 ,   455 ,   905 ,   3337    ,0 };
            const std::uint32_t dim709JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   3   ,   21  ,   33  ,   81  ,   187 ,   481 ,   481 ,   1947    ,   3563    ,   4797    ,0 };
            const std::uint32_t dim710JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   7   ,   15  ,   35  ,   23  ,   187 ,   455 ,   535 ,   85  ,   1067    ,   1793    ,0 };
            const std::uint32_t dim711JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   3   ,   11  ,   17  ,   89  ,   255 ,   443 ,   791 ,   1617    ,   2979    ,   1357    ,0 };
            const std::uint32_t dim712JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   15  ,   17  ,   49  ,   1   ,   233 ,   3   ,   587 ,   1203    ,   3185    ,   1173    ,0 };
            const std::uint32_t dim713JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   9   ,   5   ,   53  ,   37  ,   13  ,   47  ,   1011    ,   1589    ,   1073    ,   5445    ,0 };
            const std::uint32_t dim714JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   1   ,   15  ,   43  ,   85  ,   167 ,   347 ,   935 ,   1681    ,   261 ,   3623    ,0 };
            const std::uint32_t dim715JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   3   ,   3   ,   31  ,   121 ,   241 ,   129 ,   555 ,   1737    ,   3557    ,   6515    ,0 };
            const std::uint32_t dim716JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   15  ,   25  ,   7   ,   125 ,   105 ,   13  ,   927 ,   1929    ,   3869    ,   7429    ,0 };
            const std::uint32_t dim717JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   1   ,   31  ,   47  ,   3   ,   29  ,   149 ,   827 ,   771 ,   2113    ,   1607    ,0 };
            const std::uint32_t dim718JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   1   ,   17  ,   17  ,   65  ,   247 ,   109 ,   613 ,   1975    ,   2393    ,   6057    ,0 };
            const std::uint32_t dim719JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   7   ,   9   ,   43  ,   41  ,   119 ,   335 ,   533 ,   1053    ,   1343    ,   6529    ,0 };
            const std::uint32_t dim720JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   1   ,   31  ,   59  ,   85  ,   247 ,   485 ,   811 ,   749 ,   89  ,   6677    ,0 };
            const std::uint32_t dim721JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   13  ,   7   ,   47  ,   77  ,   193 ,   25  ,   27  ,   639 ,   109 ,   6455    ,0 };
            const std::uint32_t dim722JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   1   ,   15  ,   63  ,   17  ,   81  ,   425 ,   403 ,   1537    ,   3205    ,   6237    ,0 };
            const std::uint32_t dim723JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   9   ,   21  ,   29  ,   105 ,   135 ,   407 ,   119 ,   793 ,   559 ,   973 ,0 };
            const std::uint32_t dim724JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   15  ,   1   ,   31  ,   45  ,   97  ,   511 ,   463 ,   1923    ,   2487    ,   1311    ,0 };
            const std::uint32_t dim725JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   11  ,   13  ,   53  ,   91  ,   149 ,   441 ,   841 ,   1121    ,   3305    ,   975 ,0 };
            const std::uint32_t dim726JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   15  ,   5   ,   55  ,   81  ,   181 ,   333 ,   63  ,   1157    ,   2831    ,   6231    ,0 };
            const std::uint32_t dim727JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   15  ,   29  ,   21  ,   69  ,   87  ,   41  ,   623 ,   475 ,   723 ,   5693    ,0 };
            const std::uint32_t dim728JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   5   ,   23  ,   19  ,   15  ,   25  ,   269 ,   79  ,   1699    ,   691 ,   525 ,0 };
            const std::uint32_t dim729JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   1   ,   29  ,   23  ,   85  ,   5   ,   431 ,   649 ,   1187    ,   3503    ,   105 ,0 };
            const std::uint32_t dim730JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   1   ,   27  ,   59  ,   1   ,   81  ,   351 ,   383 ,   1167    ,   3747    ,   5935    ,0 };
            const std::uint32_t dim731JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   13  ,   21  ,   49  ,   93  ,   5   ,   471 ,   231 ,   1469    ,   1089    ,   5059    ,0 };
            const std::uint32_t dim732JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   11  ,   31  ,   61  ,   117 ,   161 ,   307 ,   621 ,   1713    ,   1325    ,   283 ,0 };
            const std::uint32_t dim733JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   7   ,   21  ,   35  ,   7   ,   79  ,   157 ,   723 ,   57  ,   25  ,   2789    ,0 };
            const std::uint32_t dim734JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   13  ,   9   ,   47  ,   97  ,   1   ,   257 ,   941 ,   553 ,   3811    ,   3775    ,0 };
            const std::uint32_t dim735JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   13  ,   19  ,   5   ,   73  ,   233 ,   289 ,   241 ,   175 ,   2831    ,   4613    ,0 };
            const std::uint32_t dim736JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   9   ,   11  ,   61  ,   1   ,   245 ,   223 ,   641 ,   77  ,   1811    ,   3459    ,0 };
            const std::uint32_t dim737JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   1   ,   21  ,   41  ,   9   ,   175 ,   377 ,   331 ,   1615    ,   325 ,   5413    ,0 };
            const std::uint32_t dim738JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   3   ,   23  ,   57  ,   99  ,   161 ,   127 ,   47  ,   1923    ,   165 ,   2123    ,0 };
            const std::uint32_t dim739JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   15  ,   11  ,   15  ,   77  ,   15  ,   323 ,   919 ,   1001    ,   377 ,   6095    ,0 };
            const std::uint32_t dim740JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   7   ,   25  ,   47  ,   5   ,   25  ,   197 ,   811 ,   179 ,   215 ,   5393    ,0 };
            const std::uint32_t dim741JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   11  ,   29  ,   37  ,   7   ,   125 ,   3   ,   7   ,   1881    ,   3823    ,   2117    ,0 };
            const std::uint32_t dim742JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   3   ,   9   ,   61  ,   97  ,   233 ,   233 ,   603 ,   511 ,   17  ,   2081    ,0 };
            const std::uint32_t dim743JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   9   ,   15  ,   35  ,   73  ,   199 ,   113 ,   575 ,   537 ,   883 ,   6897    ,0 };
            const std::uint32_t dim744JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   9   ,   17  ,   63  ,   7   ,   181 ,   261 ,   719 ,   591 ,   2575    ,   1065    ,0 };
            const std::uint32_t dim745JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   1   ,   13  ,   15  ,   1   ,   207 ,   385 ,   277 ,   547 ,   1069    ,   6421    ,0 };
            const std::uint32_t dim746JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   3   ,   5   ,   3   ,   43  ,   213 ,   509 ,   969 ,   1799    ,   3519    ,   7759    ,0 };
            const std::uint32_t dim747JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   15  ,   29  ,   51  ,   87  ,   63  ,   257 ,   1001    ,   741 ,   1747    ,   975 ,0 };
            const std::uint32_t dim748JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   15  ,   5   ,   27  ,   7   ,   27  ,   493 ,   817 ,   319 ,   1435    ,   3243    ,0 };
            const std::uint32_t dim749JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   15  ,   5   ,   9   ,   113 ,   153 ,   397 ,   63  ,   2037    ,   3319    ,   6355    ,0 };
            const std::uint32_t dim750JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   1   ,   29  ,   9   ,   97  ,   171 ,   113 ,   729 ,   1939    ,   2741    ,   4699    ,0 };
            const std::uint32_t dim751JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   11  ,   29  ,   3   ,   49  ,   183 ,   69  ,   313 ,   153 ,   2757    ,   3353    ,0 };
            const std::uint32_t dim752JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   7   ,   5   ,   39  ,   65  ,   65  ,   405 ,   301 ,   849 ,   1211    ,   3627    ,0 };
            const std::uint32_t dim753JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   13  ,   19  ,   11  ,   81  ,   181 ,   471 ,   669 ,   139 ,   4019    ,   4057    ,0 };
            const std::uint32_t dim754JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   13  ,   3   ,   31  ,   125 ,   229 ,   181 ,   913 ,   2035    ,   2081    ,   6573    ,0 };
            const std::uint32_t dim755JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   5   ,   13  ,   25  ,   37  ,   209 ,   255 ,   761 ,   1485    ,   2833    ,   6617    ,0 };
            const std::uint32_t dim756JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   7   ,   29  ,   17  ,   55  ,   59  ,   337 ,   953 ,   775 ,   3865    ,   5671    ,0 };
            const std::uint32_t dim757JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   13  ,   15  ,   37  ,   109 ,   93  ,   303 ,   57  ,   1727    ,   615 ,   3337    ,0 };
            const std::uint32_t dim758JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   13  ,   31  ,   57  ,   119 ,   57  ,   295 ,   707 ,   1409    ,   3769    ,   6359    ,0 };
            const std::uint32_t dim759JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   5   ,   31  ,   25  ,   35  ,   191 ,   27  ,   463 ,   875 ,   129 ,   3829    ,0 };
            const std::uint32_t dim760JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   13  ,   19  ,   29  ,   95  ,   227 ,   487 ,   519 ,   289 ,   965 ,   2121    ,0 };
            const std::uint32_t dim761JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   5   ,   21  ,   37  ,   7   ,   43  ,   213 ,   673 ,   25  ,   1911    ,   7229    ,0 };
            const std::uint32_t dim762JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   5   ,   9   ,   55  ,   115 ,   155 ,   119 ,   49  ,   653 ,   3425    ,   299 ,0 };
            const std::uint32_t dim763JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   11  ,   7   ,   55  ,   65  ,   21  ,   93  ,   295 ,   1097    ,   145 ,   3401    ,0 };
            const std::uint32_t dim764JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   3   ,   1   ,   19  ,   109 ,   247 ,   499 ,   391 ,   309 ,   59  ,   695 ,0 };
            const std::uint32_t dim765JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   5   ,   9   ,   37  ,   113 ,   233 ,   57  ,   955 ,   437 ,   775 ,   2673    ,0 };
            const std::uint32_t dim766JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   3   ,   5   ,   27  ,   57  ,   53  ,   149 ,   929 ,   41  ,   1473    ,   4751    ,0 };
            const std::uint32_t dim767JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   11  ,   5   ,   3   ,   107 ,   57  ,   3   ,   727 ,   2001    ,   3463    ,   4753    ,0 };
            const std::uint32_t dim768JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   11  ,   3   ,   37  ,   111 ,   97  ,   225 ,   809 ,   135 ,   2049    ,   2373    ,0 };
            const std::uint32_t dim769JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   15  ,   3   ,   37  ,   57  ,   153 ,   175 ,   851 ,   137 ,   495 ,   4423    ,0 };
            const std::uint32_t dim770JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   7   ,   25  ,   31  ,   53  ,   51  ,   421 ,   33  ,   1241    ,   2157    ,   867 ,0 };
            const std::uint32_t dim771JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   13  ,   3   ,   33  ,   15  ,   77  ,   73  ,   51  ,   1131    ,   3387    ,   7935    ,0 };
            const std::uint32_t dim772JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   9   ,   11  ,   25  ,   27  ,   235 ,   341 ,   133 ,   261 ,   2087    ,   4079    ,0 };
            const std::uint32_t dim773JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   13  ,   11  ,   63  ,   33  ,   99  ,   65  ,   485 ,   561 ,   2269    ,   8143    ,0 };
            const std::uint32_t dim774JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   5   ,   13  ,   25  ,   53  ,   65  ,   59  ,   861 ,   1705    ,   627 ,   1097    ,0 };
            const std::uint32_t dim775JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   3   ,   25  ,   15  ,   67  ,   187 ,   161 ,   747 ,   947 ,   4029    ,   7547    ,0 };
            const std::uint32_t dim776JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   5   ,   7   ,   27  ,   119 ,   239 ,   197 ,   165 ,   457 ,   1927    ,   6195    ,0 };
            const std::uint32_t dim777JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   7   ,   27  ,   21  ,   23  ,   93  ,   319 ,   551 ,   1317    ,   69  ,   6735    ,0 };
            const std::uint32_t dim778JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   11  ,   25  ,   45  ,   23  ,   127 ,   327 ,   949 ,   1451    ,   2245    ,   6705    ,0 };
            const std::uint32_t dim779JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   15  ,   19  ,   23  ,   69  ,   113 ,   53  ,   215 ,   1505    ,   1255    ,   5063    ,0 };
            const std::uint32_t dim780JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   9   ,   7   ,   19  ,   39  ,   135 ,   437 ,   251 ,   1947    ,   2219    ,   4015    ,0 };
            const std::uint32_t dim781JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   3   ,   23  ,   39  ,   91  ,   111 ,   395 ,   545 ,   179 ,   937 ,   2531    ,0 };
            const std::uint32_t dim782JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   11  ,   1   ,   53  ,   113 ,   137 ,   131 ,   461 ,   151 ,   1617    ,   6399    ,0 };
            const std::uint32_t dim783JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   3   ,   13  ,   3   ,   75  ,   31  ,   175 ,   773 ,   1293    ,   625 ,   6563    ,0 };
            const std::uint32_t dim784JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   15  ,   9   ,   51  ,   87  ,   223 ,   405 ,   751 ,   1053    ,   1431    ,   4701    ,0 };
            const std::uint32_t dim785JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   13  ,   21  ,   21  ,   111 ,   145 ,   311 ,   733 ,   635 ,   1369    ,   297 ,0 };
            const std::uint32_t dim786JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   7   ,   25  ,   5   ,   23  ,   201 ,   179 ,   593 ,   1531    ,   1197    ,   3525    ,0 };
            const std::uint32_t dim787JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   13  ,   7   ,   17  ,   19  ,   247 ,   401 ,   15  ,   93  ,   245 ,   5987    ,0 };
            const std::uint32_t dim788JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   11  ,   7   ,   45  ,   119 ,   99  ,   197 ,   163 ,   637 ,   3143    ,   1775    ,0 };
            const std::uint32_t dim789JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   3   ,   17  ,   7   ,   35  ,   121 ,   155 ,   925 ,   1001    ,   2941    ,   107 ,0 };
            const std::uint32_t dim790JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   15  ,   15  ,   3   ,   89  ,   205 ,   171 ,   279 ,   763 ,   2343    ,   7825    ,0 };
            const std::uint32_t dim791JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   15  ,   15  ,   3   ,   113 ,   135 ,   159 ,   217 ,   139 ,   167 ,   589 ,0 };
            const std::uint32_t dim792JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   1   ,   31  ,   59  ,   89  ,   3   ,   261 ,   953 ,   1527    ,   447 ,   1211    ,0 };
            const std::uint32_t dim793JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   9   ,   31  ,   39  ,   93  ,   171 ,   497 ,   657 ,   809 ,   2905    ,   2399    ,0 };
            const std::uint32_t dim794JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   15  ,   27  ,   19  ,   25  ,   179 ,   293 ,   829 ,   1197    ,   3077    ,   6631    ,0 };
            const std::uint32_t dim795JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   7   ,   31  ,   55  ,   53  ,   177 ,   157 ,   619 ,   197 ,   3675    ,   4691    ,0 };
            const std::uint32_t dim796JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   5   ,   7   ,   33  ,   85  ,   59  ,   435 ,   653 ,   1363    ,   731 ,   3923    ,0 };
            const std::uint32_t dim797JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   3   ,   15  ,   35  ,   15  ,   217 ,   333 ,   717 ,   143 ,   4071    ,   4769    ,0 };
            const std::uint32_t dim798JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   7   ,   23  ,   31  ,   65  ,   77  ,   261 ,   389 ,   1733    ,   4077    ,   3387    ,0 };
            const std::uint32_t dim799JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   9   ,   21  ,   45  ,   21  ,   103 ,   163 ,   237 ,   1447    ,   141 ,   3995    ,0 };
            const std::uint32_t dim800JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   3   ,   27  ,   35  ,   61  ,   149 ,   359 ,   131 ,   1309    ,   3283    ,   5905    ,0 };
            const std::uint32_t dim801JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   15  ,   9   ,   15  ,   99  ,   43  ,   115 ,   871 ,   419 ,   2787    ,   7741    ,0 };
            const std::uint32_t dim802JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   5   ,   1   ,   45  ,   31  ,   87  ,   165 ,   103 ,   2041    ,   1529    ,   5721    ,0 };
            const std::uint32_t dim803JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   15  ,   3   ,   11  ,   107 ,   9   ,   367 ,   401 ,   1571    ,   2657    ,   4745    ,0 };
            const std::uint32_t dim804JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   13  ,   31  ,   51  ,   35  ,   53  ,   131 ,   441 ,   1421    ,   2367    ,   7713    ,0 };
            const std::uint32_t dim805JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   5   ,   21  ,   49  ,   109 ,   117 ,   263 ,   827 ,   1975    ,   2639    ,   1249    ,0 };
            const std::uint32_t dim806JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   13  ,   7   ,   3   ,   87  ,   185 ,   493 ,   721 ,   1363    ,   2201    ,   1067    ,0 };
            const std::uint32_t dim807JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   5   ,   13  ,   41  ,   113 ,   105 ,   111 ,   65  ,   705 ,   4079    ,   2461    ,0 };
            const std::uint32_t dim808JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   13  ,   9   ,   1   ,   75  ,   103 ,   181 ,   587 ,   1531    ,   461 ,   6551    ,0 };
            const std::uint32_t dim809JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   11  ,   13  ,   43  ,   19  ,   131 ,   233 ,   209 ,   175 ,   625 ,   985 ,0 };
            const std::uint32_t dim810JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   11  ,   23  ,   1   ,   87  ,   233 ,   355 ,   765 ,   869 ,   2569    ,   5919    ,0 };
            const std::uint32_t dim811JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   5   ,   13  ,   27  ,   41  ,   127 ,   105 ,   299 ,   189 ,   3801    ,   4677    ,0 };
            const std::uint32_t dim812JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   13  ,   21  ,   49  ,   111 ,   95  ,   27  ,   433 ,   1715    ,   1167    ,   4943    ,0 };
            const std::uint32_t dim813JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   11  ,   5   ,   17  ,   93  ,   91  ,   79  ,   355 ,   111 ,   1159    ,   4629    ,0 };
            const std::uint32_t dim814JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   1   ,   29  ,   43  ,   107 ,   91  ,   111 ,   813 ,   537 ,   97  ,   5337    ,0 };
            const std::uint32_t dim815JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   5   ,   27  ,   1   ,   69  ,   181 ,   247 ,   51  ,   409 ,   1965    ,   4709    ,0 };
            const std::uint32_t dim816JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   1   ,   7   ,   53  ,   119 ,   109 ,   331 ,   189 ,   761 ,   385 ,   5227    ,0 };
            const std::uint32_t dim817JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   15  ,   5   ,   61  ,   57  ,   3   ,   157 ,   737 ,   1605    ,   3701    ,   1069    ,0 };
            const std::uint32_t dim818JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   1   ,   17  ,   27  ,   89  ,   235 ,   53  ,   521 ,   1975    ,   1383    ,   467 ,0 };
            const std::uint32_t dim819JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   7   ,   25  ,   25  ,   39  ,   149 ,   157 ,   385 ,   1651    ,   105 ,   1487    ,0 };
            const std::uint32_t dim820JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   7   ,   15  ,   43  ,   37  ,   167 ,   303 ,   655 ,   331 ,   1595    ,   5405    ,0 };
            const std::uint32_t dim821JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   9   ,   13  ,   29  ,   13  ,   163 ,   405 ,   903 ,   1277    ,   985 ,   1479    ,0 };
            const std::uint32_t dim822JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   13  ,   1   ,   7   ,   61  ,   9   ,   163 ,   67  ,   209 ,   1923    ,   6587    ,0 };
            const std::uint32_t dim823JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   15  ,   13  ,   3   ,   99  ,   177 ,   507 ,   1017    ,   1565    ,   757 ,   5829    ,0 };
            const std::uint32_t dim824JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   11  ,   7   ,   49  ,   51  ,   71  ,   177 ,   1015    ,   1321    ,   187 ,   875 ,0 };
            const std::uint32_t dim825JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   1   ,   29  ,   49  ,   111 ,   143 ,   99  ,   297 ,   659 ,   3147    ,   7531    ,0 };
            const std::uint32_t dim826JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   3   ,   15  ,   21  ,   11  ,   229 ,   249 ,   185 ,   147 ,   173 ,   7895    ,0 };
            const std::uint32_t dim827JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   1   ,   17  ,   23  ,   123 ,   157 ,   373 ,   501 ,   411 ,   2487    ,   4873    ,0 };
            const std::uint32_t dim828JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   11  ,   21  ,   61  ,   83  ,   65  ,   345 ,   105 ,   1533    ,   981 ,   1635    ,0 };
            const std::uint32_t dim829JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   1   ,   15  ,   15  ,   19  ,   119 ,   59  ,   1003    ,   1595    ,   2871    ,   627 ,0 };
            const std::uint32_t dim830JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   3   ,   7   ,   47  ,   43  ,   3   ,   359 ,   175 ,   1149    ,   213 ,   79  ,0 };
            const std::uint32_t dim831JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   1   ,   5   ,   19  ,   7   ,   93  ,   335 ,   809 ,   1867    ,   1359    ,   1017    ,0 };
            const std::uint32_t dim832JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   11  ,   31  ,   25  ,   75  ,   139 ,   125 ,   479 ,   101 ,   3969    ,   1173    ,0 };
            const std::uint32_t dim833JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   3   ,   5   ,   17  ,   33  ,   145 ,   57  ,   31  ,   1033    ,   3975    ,   5561    ,0 };
            const std::uint32_t dim834JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   3   ,   31  ,   37  ,   47  ,   149 ,   341 ,   663 ,   303 ,   3395    ,   4327    ,0 };
            const std::uint32_t dim835JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   1   ,   31  ,   31  ,   37  ,   207 ,   189 ,   435 ,   347 ,   2791    ,   2203    ,0 };
            const std::uint32_t dim836JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   5   ,   3   ,   61  ,   71  ,   199 ,   207 ,   261 ,   27  ,   2281    ,   6215    ,0 };
            const std::uint32_t dim837JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   13  ,   19  ,   61  ,   51  ,   99  ,   279 ,   535 ,   473 ,   2233    ,   5637    ,0 };
            const std::uint32_t dim838JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   15  ,   7   ,   51  ,   25  ,   159 ,   63  ,   611 ,   1015    ,   3561    ,   5763    ,0 };
            const std::uint32_t dim839JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   7   ,   9   ,   13  ,   101 ,   13  ,   203 ,   733 ,   1657    ,   919 ,   7857    ,0 };
            const std::uint32_t dim840JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   9   ,   5   ,   7   ,   105 ,   137 ,   321 ,   817 ,   467 ,   4043    ,   603 ,0 };
            const std::uint32_t dim841JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   9   ,   5   ,   7   ,   105 ,   93  ,   295 ,   617 ,   713 ,   3075    ,   1839    ,0 };
            const std::uint32_t dim842JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   5   ,   11  ,   17  ,   89  ,   229 ,   417 ,   53  ,   693 ,   2101    ,   1293    ,0 };
            const std::uint32_t dim843JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   5   ,   3   ,   57  ,   95  ,   175 ,   161 ,   291 ,   219 ,   3101    ,   3387    ,0 };
            const std::uint32_t dim844JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   3   ,   25  ,   53  ,   89  ,   7   ,   9   ,   863 ,   675 ,   1011    ,   1753    ,0 };
            const std::uint32_t dim845JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   15  ,   13  ,   41  ,   57  ,   141 ,   109 ,   541 ,   387 ,   3805    ,   2219    ,0 };
            const std::uint32_t dim846JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   11  ,   19  ,   45  ,   45  ,   63  ,   283 ,   277 ,   1503    ,   3909    ,   4825    ,0 };
            const std::uint32_t dim847JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   13  ,   11  ,   27  ,   33  ,   245 ,   335 ,   785 ,   1651    ,   2503    ,   7247    ,0 };
            const std::uint32_t dim848JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   5   ,   19  ,   3   ,   29  ,   9   ,   259 ,   1023    ,   71  ,   3659    ,   3615    ,0 };
            const std::uint32_t dim849JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   9   ,   29  ,   41  ,   59  ,   137 ,   139 ,   193 ,   267 ,   3293    ,   4769    ,0 };
            const std::uint32_t dim850JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   5   ,   21  ,   29  ,   107 ,   227 ,   107 ,   929 ,   1009    ,   2013    ,   2791    ,0 };
            const std::uint32_t dim851JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   7   ,   25  ,   61  ,   105 ,   159 ,   125 ,   873 ,   293 ,   1475    ,   1745    ,0 };
            const std::uint32_t dim852JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   5   ,   13  ,   11  ,   63  ,   109 ,   329 ,   847 ,   521 ,   3045    ,   2673    ,0 };
            const std::uint32_t dim853JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   1   ,   21  ,   1   ,   15  ,   161 ,   369 ,   339 ,   417 ,   3165    ,   5047    ,0 };
            const std::uint32_t dim854JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   9   ,   31  ,   61  ,   109 ,   25  ,   491 ,   969 ,   1369    ,   403 ,   835 ,0 };
            const std::uint32_t dim855JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   9   ,   29  ,   29  ,   27  ,   55  ,   395 ,   979 ,   27  ,   3091    ,   2383    ,0 };
            const std::uint32_t dim856JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   1   ,   25  ,   17  ,   73  ,   117 ,   55  ,   381 ,   641 ,   2549    ,   7049    ,0 };
            const std::uint32_t dim857JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   11  ,   17  ,   5   ,   97  ,   89  ,   187 ,   973 ,   1343    ,   3777    ,   3549    ,0 };
            const std::uint32_t dim858JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   1   ,   9   ,   51  ,   49  ,   169 ,   135 ,   827 ,   1941    ,   3421    ,   2351    ,0 };
            const std::uint32_t dim859JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   11  ,   25  ,   59  ,   9   ,   63  ,   259 ,   551 ,   983 ,   2743    ,   3439    ,0 };
            const std::uint32_t dim860JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   5   ,   1   ,   55  ,   19  ,   35  ,   39  ,   629 ,   1601    ,   773 ,   3697    ,0 };
            const std::uint32_t dim861JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   7   ,   17  ,   59  ,   55  ,   201 ,   467 ,   945 ,   707 ,   2197    ,   6907    ,0 };
            const std::uint32_t dim862JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   15  ,   11  ,   9   ,   1   ,   87  ,   299 ,   509 ,   117 ,   3249    ,   3811    ,0 };
            const std::uint32_t dim863JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   7   ,   23  ,   35  ,   43  ,   129 ,   357 ,   501 ,   837 ,   305 ,   7967    ,0 };
            const std::uint32_t dim864JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   1   ,   23  ,   45  ,   85  ,   245 ,   157 ,   193 ,   215 ,   1021    ,   5115    ,0 };
            const std::uint32_t dim865JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   9   ,   5   ,   47  ,   125 ,   27  ,   295 ,   407 ,   1601    ,   859 ,   1203    ,0 };
            const std::uint32_t dim866JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   7   ,   21  ,   3   ,   23  ,   141 ,   75  ,   841 ,   199 ,   2719    ,   2131    ,0 };
            const std::uint32_t dim867JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   1   ,   3   ,   7   ,   35  ,   227 ,   275 ,   37  ,   523 ,   2849    ,   4363    ,0 };
            const std::uint32_t dim868JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   9   ,   5   ,   39  ,   95  ,   77  ,   201 ,   891 ,   339 ,   375 ,   7115    ,0 };
            const std::uint32_t dim869JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   3   ,   3   ,   57  ,   57  ,   49  ,   305 ,   141 ,   1149    ,   3909    ,   6981    ,0 };
            const std::uint32_t dim870JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   7   ,   19  ,   17  ,   53  ,   31  ,   233 ,   317 ,   1541    ,   235 ,   1831    ,0 };
            const std::uint32_t dim871JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   5   ,   7   ,   63  ,   125 ,   169 ,   141 ,   399 ,   277 ,   1417    ,   7989    ,0 };
            const std::uint32_t dim872JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   1   ,   17  ,   61  ,   89  ,   11  ,   411 ,   505 ,   1191    ,   2651    ,   1175    ,0 };
            const std::uint32_t dim873JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   1   ,   11  ,   41  ,   39  ,   69  ,   279 ,   229 ,   1247    ,   1001    ,   7163    ,0 };
            const std::uint32_t dim874JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   5   ,   13  ,   29  ,   115 ,   51  ,   79  ,   57  ,   315 ,   173 ,   5875    ,0 };
            const std::uint32_t dim875JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   5   ,   1   ,   43  ,   121 ,   5   ,   99  ,   451 ,   1121    ,   425 ,   4581    ,0 };
            const std::uint32_t dim876JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   5   ,   19  ,   5   ,   101 ,   33  ,   19  ,   5   ,   1325    ,   3527    ,   1733    ,0 };
            const std::uint32_t dim877JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   7   ,   15  ,   35  ,   91  ,   141 ,   127 ,   1005    ,   459 ,   3707    ,   6551    ,0 };
            const std::uint32_t dim878JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   11  ,   15  ,   27  ,   31  ,   49  ,   153 ,   337 ,   1235    ,   2063    ,   211 ,0 };
            const std::uint32_t dim879JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   3   ,   25  ,   45  ,   17  ,   233 ,   161 ,   559 ,   1687    ,   3833    ,   5451    ,0 };
            const std::uint32_t dim880JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   13  ,   23  ,   39  ,   127 ,   183 ,   379 ,   655 ,   129 ,   37  ,   2283    ,0 };
            const std::uint32_t dim881JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   13  ,   23  ,   33  ,   35  ,   111 ,   491 ,   343 ,   1771    ,   509 ,   937 ,0 };
            const std::uint32_t dim882JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   3   ,   19  ,   59  ,   59  ,   79  ,   327 ,   911 ,   1103    ,   2695    ,   3673    ,0 };
            const std::uint32_t dim883JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   5   ,   11  ,   23  ,   43  ,   31  ,   455 ,   843 ,   1515    ,   3059    ,   505 ,0 };
            const std::uint32_t dim884JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   7   ,   15  ,   1   ,   63  ,   35  ,   327 ,   801 ,   237 ,   1137    ,   3447    ,0 };
            const std::uint32_t dim885JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   1   ,   7   ,   35  ,   105 ,   113 ,   281 ,   153 ,   461 ,   3165    ,   659 ,0 };
            const std::uint32_t dim886JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   13  ,   29  ,   5   ,   119 ,   45  ,   313 ,   713 ,   1989    ,   99  ,   883 ,0 };
            const std::uint32_t dim887JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   15  ,   17  ,   43  ,   115 ,   201 ,   51  ,   947 ,   1271    ,   2465    ,   5319    ,0 };
            const std::uint32_t dim888JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   11  ,   25  ,   39  ,   49  ,   103 ,   99  ,   469 ,   1777    ,   33  ,   7115    ,0 };
            const std::uint32_t dim889JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   1   ,   17  ,   43  ,   53  ,   97  ,   473 ,   231 ,   1035    ,   19  ,   995 ,0 };
            const std::uint32_t dim890JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   1   ,   5   ,   1   ,   89  ,   255 ,   201 ,   945 ,   2017    ,   3181    ,   3961    ,0 };
            const std::uint32_t dim891JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   7   ,   9   ,   9   ,   45  ,   91  ,   451 ,   671 ,   613 ,   4051    ,   1233    ,0 };
            const std::uint32_t dim892JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   11  ,   27  ,   49  ,   37  ,   151 ,   59  ,   489 ,   341 ,   507 ,   5839    ,0 };
            const std::uint32_t dim893JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   3   ,   1   ,   41  ,   11  ,   165 ,   509 ,   615 ,   793 ,   2741    ,   7269    ,0 };
            const std::uint32_t dim894JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   13  ,   11  ,   33  ,   115 ,   87  ,   131 ,   653 ,   995 ,   1903    ,   4449    ,0 };
            const std::uint32_t dim895JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   11  ,   27  ,   41  ,   49  ,   211 ,   229 ,   797 ,   469 ,   839 ,   5047    ,0 };
            const std::uint32_t dim896JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   3   ,   9   ,   43  ,   57  ,   13  ,   77  ,   623 ,   245 ,   2349    ,   3611    ,0 };
            const std::uint32_t dim897JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   11  ,   23  ,   31  ,   101 ,   3   ,   355 ,   739 ,   1287    ,   3973    ,   6923    ,0 };
            const std::uint32_t dim898JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   5   ,   17  ,   61  ,   83  ,   75  ,   329 ,   849 ,   645 ,   3125    ,   8159    ,0 };
            const std::uint32_t dim899JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   11  ,   15  ,   31  ,   91  ,   149 ,   195 ,   585 ,   1415    ,   119 ,   6737    ,0 };
            const std::uint32_t dim900JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   13  ,   7   ,   3   ,   41  ,   25  ,   481 ,   175 ,   1147    ,   153 ,   6483    ,0 };
            const std::uint32_t dim901JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   1   ,   29  ,   59  ,   11  ,   225 ,   275 ,   299 ,   1083    ,   401 ,   6809    ,0 };
            const std::uint32_t dim902JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   11  ,   7   ,   19  ,   119 ,   145 ,   299 ,   273 ,   1571    ,   627 ,   6597    ,0 };
            const std::uint32_t dim903JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   13  ,   17  ,   7   ,   63  ,   19  ,   141 ,   359 ,   879 ,   2741    ,   3139    ,0 };
            const std::uint32_t dim904JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   15  ,   9   ,   19  ,   45  ,   127 ,   511 ,   767 ,   47  ,   2389    ,   7691    ,0 };
            const std::uint32_t dim905JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   15  ,   11  ,   53  ,   15  ,   207 ,   31  ,   215 ,   183 ,   2745    ,   4703    ,0 };
            const std::uint32_t dim906JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   7   ,   13  ,   43  ,   13  ,   65  ,   165 ,   157 ,   1139    ,   2417    ,   547 ,0 };
            const std::uint32_t dim907JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   7   ,   29  ,   29  ,   45  ,   165 ,   401 ,   327 ,   119 ,   1449    ,   1281    ,0 };
            const std::uint32_t dim908JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   11  ,   27  ,   25  ,   35  ,   5   ,   447 ,   205 ,   1487    ,   4089    ,   4929    ,0 };
            const std::uint32_t dim909JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   13  ,   3   ,   45  ,   73  ,   19  ,   349 ,   657 ,   771 ,   1029    ,   5047    ,0 };
            const std::uint32_t dim910JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   7   ,   29  ,   63  ,   23  ,   69  ,   425 ,   997 ,   9   ,   2365    ,   3279    ,0 };
            const std::uint32_t dim911JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   1   ,   7   ,   31  ,   47  ,   205 ,   29  ,   851 ,   1735    ,   1641    ,   2623    ,0 };
            const std::uint32_t dim912JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   11  ,   25  ,   33  ,   73  ,   109 ,   183 ,   357 ,   1585    ,   3323    ,   4993    ,0 };
            const std::uint32_t dim913JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   15  ,   13  ,   53  ,   43  ,   61  ,   137 ,   127 ,   1769    ,   2107    ,   4025    ,0 };
            const std::uint32_t dim914JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   7   ,   25  ,   59  ,   93  ,   57  ,   391 ,   155 ,   1367    ,   4093    ,   625 ,0 };
            const std::uint32_t dim915JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   1   ,   25  ,   27  ,   53  ,   217 ,   75  ,   961 ,   371 ,   1281    ,   6553    ,0 };
            const std::uint32_t dim916JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   5   ,   19  ,   5   ,   89  ,   87  ,   377 ,   199 ,   1533    ,   2219    ,   2705    ,0 };
            const std::uint32_t dim917JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   7   ,   15  ,   1   ,   61  ,   143 ,   137 ,   379 ,   1443    ,   355 ,   971 ,0 };
            const std::uint32_t dim918JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   11  ,   17  ,   57  ,   85  ,   225 ,   37  ,   345 ,   1509    ,   597 ,   5731    ,0 };
            const std::uint32_t dim919JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   11  ,   29  ,   55  ,   69  ,   27  ,   155 ,   481 ,   925 ,   3391    ,   5277    ,0 };
            const std::uint32_t dim920JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   9   ,   15  ,   19  ,   25  ,   5   ,   109 ,   83  ,   635 ,   3073    ,   3531    ,0 };
            const std::uint32_t dim921JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   15  ,   23  ,   5   ,   13  ,   7   ,   19  ,   625 ,   1481    ,   1827    ,   3991    ,0 };
            const std::uint32_t dim922JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   9   ,   7   ,   35  ,   123 ,   161 ,   303 ,   423 ,   25  ,   2467    ,   3411    ,0 };
            const std::uint32_t dim923JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   1   ,   9   ,   47  ,   27  ,   159 ,   249 ,   573 ,   1987    ,   3449    ,   7639    ,0 };
            const std::uint32_t dim924JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   5   ,   19  ,   59  ,   7   ,   209 ,   27  ,   495 ,   1491    ,   3217    ,   1321    ,0 };
            const std::uint32_t dim925JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   11  ,   17  ,   11  ,   109 ,   87  ,   315 ,   917 ,   1105    ,   215 ,   1295    ,0 };
            const std::uint32_t dim926JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   9   ,   25  ,   11  ,   77  ,   81  ,   453 ,   871 ,   1541    ,   141 ,   1625    ,0 };
            const std::uint32_t dim927JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   3   ,   1   ,   37  ,   11  ,   149 ,   45  ,   213 ,   975 ,   2557    ,   4263    ,0 };
            const std::uint32_t dim928JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   13  ,   17  ,   55  ,   59  ,   33  ,   39  ,   285 ,   1767    ,   3687    ,   7087    ,0 };
            const std::uint32_t dim929JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   7   ,   27  ,   9   ,   103 ,   191 ,   405 ,   25  ,   595 ,   1765    ,   5695    ,0 };
            const std::uint32_t dim930JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   7   ,   31  ,   27  ,   29  ,   195 ,   355 ,   199 ,   1297    ,   3195    ,   683 ,0 };
            const std::uint32_t dim931JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   1   ,   21  ,   3   ,   19  ,   227 ,   325 ,   279 ,   1593    ,   613 ,   7527    ,0 };
            const std::uint32_t dim932JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   15  ,   27  ,   17  ,   91  ,   179 ,   385 ,   133 ,   823 ,   3731    ,   2957    ,0 };
            const std::uint32_t dim933JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   7   ,   13  ,   9   ,   1   ,   137 ,   347 ,   67  ,   287 ,   1403    ,   5233    ,0 };
            const std::uint32_t dim934JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   7   ,   17  ,   15  ,   25  ,   95  ,   225 ,   469 ,   1585    ,   2513    ,   1489    ,0 };
            const std::uint32_t dim935JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   13  ,   31  ,   33  ,   81  ,   121 ,   435 ,   971 ,   877 ,   1603    ,   373 ,0 };
            const std::uint32_t dim936JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   9   ,   7   ,   31  ,   29  ,   27  ,   135 ,   181 ,   549 ,   1901    ,   813 ,0 };
            const std::uint32_t dim937JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   3   ,   3   ,   5   ,   11  ,   229 ,   255 ,   981 ,   1843    ,   2785    ,   2573    ,0 };
            const std::uint32_t dim938JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   13  ,   25  ,   29  ,   13  ,   87  ,   361 ,   431 ,   969 ,   1893    ,   5257    ,0 };
            const std::uint32_t dim939JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   3   ,   21  ,   53  ,   99  ,   243 ,   313 ,   681 ,   655 ,   2733    ,   4329    ,0 };
            const std::uint32_t dim940JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   7   ,   13  ,   3   ,   107 ,   61  ,   285 ,   687 ,   213 ,   551 ,   5039    ,0 };
            const std::uint32_t dim941JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   3   ,   9   ,   47  ,   99  ,   239 ,   313 ,   975 ,   1403    ,   3641    ,   1951    ,0 };
            const std::uint32_t dim942JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   3   ,   19  ,   43  ,   77  ,   139 ,   357 ,   973 ,   977 ,   369 ,   2775    ,0 };
            const std::uint32_t dim943JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   15  ,   23  ,   43  ,   109 ,   91  ,   321 ,   1   ,   1917    ,   3341    ,   1441    ,0 };
            const std::uint32_t dim944JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   9   ,   7   ,   19  ,   61  ,   255 ,   25  ,   729 ,   479 ,   837 ,   13  ,0 };
            const std::uint32_t dim945JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   9   ,   27  ,   29  ,   123 ,   101 ,   349 ,   443 ,   1759    ,   3   ,   4685    ,0 };
            const std::uint32_t dim946JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   1   ,   29  ,   47  ,   33  ,   183 ,   223 ,   927 ,   1341    ,   797 ,   8007    ,0 };
            const std::uint32_t dim947JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   15  ,   27  ,   33  ,   71  ,   195 ,   57  ,   897 ,   1337    ,   3455    ,   5201    ,0 };
            const std::uint32_t dim948JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   7   ,   31  ,   55  ,   121 ,   49  ,   343 ,   501 ,   1511    ,   113 ,   1549    ,0 };
            const std::uint32_t dim949JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   3   ,   9   ,   61  ,   19  ,   215 ,   323 ,   427 ,   1777    ,   685 ,   63  ,0 };
            const std::uint32_t dim950JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   15  ,   17  ,   23  ,   33  ,   129 ,   257 ,   527 ,   825 ,   3611    ,   2123    ,0 };
            const std::uint32_t dim951JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   1   ,   5   ,   45  ,   79  ,   9   ,   211 ,   493 ,   1095    ,   3031    ,   4093    ,0 };
            const std::uint32_t dim952JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   9   ,   21  ,   29  ,   29  ,   247 ,   489 ,   735 ,   11  ,   1723    ,   4459    ,0 };
            const std::uint32_t dim953JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   5   ,   21  ,   41  ,   59  ,   65  ,   151 ,   113 ,   851 ,   1213    ,   6367    ,0 };
            const std::uint32_t dim954JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   5   ,   9   ,   17  ,   85  ,   207 ,   219 ,   45  ,   85  ,   2433    ,   2219    ,0 };
            const std::uint32_t dim955JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   5   ,   7   ,   9   ,   39  ,   201 ,   369 ,   369 ,   113 ,   2667    ,   5137    ,0 };
            const std::uint32_t dim956JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   3   ,   27  ,   59  ,   127 ,   189 ,   289 ,   683 ,   1285    ,   2713    ,   7037    ,0 };
            const std::uint32_t dim957JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   3   ,   5   ,   19  ,   51  ,   23  ,   139 ,   379 ,   651 ,   19  ,   7705    ,0 };
            const std::uint32_t dim958JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   11  ,   31  ,   23  ,   11  ,   37  ,   161 ,   679 ,   1581    ,   217 ,   7973    ,0 };
            const std::uint32_t dim959JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   5   ,   9   ,   49  ,   23  ,   177 ,   475 ,   261 ,   403 ,   1415    ,   2299    ,0 };
            const std::uint32_t dim960JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   15  ,   19  ,   35  ,   117 ,   223 ,   159 ,   805 ,   1039    ,   1359    ,   6635    ,0 };
            const std::uint32_t dim961JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   15  ,   19  ,   1   ,   121 ,   223 ,   123 ,   161 ,   1631    ,   1161    ,   6997    ,0 };
            const std::uint32_t dim962JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   15  ,   5   ,   31  ,   41  ,   133 ,   121 ,   523 ,   1941    ,   2583    ,   6231    ,0 };
            const std::uint32_t dim963JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   15  ,   7   ,   31  ,   95  ,   49  ,   501 ,   737 ,   363 ,   2879    ,   6561    ,0 };
            const std::uint32_t dim964JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   11  ,   31  ,   47  ,   61  ,   17  ,   399 ,   3   ,   605 ,   907 ,   4605    ,0 };
            const std::uint32_t dim965JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   1   ,   23  ,   61  ,   47  ,   93  ,   25  ,   643 ,   881 ,   3559    ,   5251    ,0 };
            const std::uint32_t dim966JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   5   ,   27  ,   63  ,   1   ,   147 ,   425 ,   639 ,   1229    ,   3131    ,   5833    ,0 };
            const std::uint32_t dim967JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   15  ,   31  ,   31  ,   57  ,   121 ,   183 ,   39  ,   1067    ,   1915    ,   7321    ,0 };
            const std::uint32_t dim968JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   9   ,   21  ,   25  ,   125 ,   29  ,   53  ,   433 ,   189 ,   3465    ,   3847    ,0 };
            const std::uint32_t dim969JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   1   ,   11  ,   13  ,   99  ,   229 ,   365 ,   909 ,   87  ,   3669    ,   6609    ,0 };
            const std::uint32_t dim970JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   1   ,   29  ,   3   ,   43  ,   13  ,   19  ,   897 ,   1269    ,   1091    ,   3207    ,0 };
            const std::uint32_t dim971JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   13  ,   11  ,   33  ,   69  ,   251 ,   337 ,   235 ,   523 ,   2053    ,   3655    ,0 };
            const std::uint32_t dim972JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   15  ,   1   ,   11  ,   75  ,   169 ,   507 ,   391 ,   1009    ,   3165    ,   3691    ,0 };
            const std::uint32_t dim973JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   13  ,   3   ,   39  ,   119 ,   193 ,   169 ,   661 ,   813 ,   143 ,   7825    ,0 };
            const std::uint32_t dim974JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   11  ,   13  ,   33  ,   91  ,   209 ,   469 ,   141 ,   391 ,   1037    ,   6591    ,0 };
            const std::uint32_t dim975JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   7   ,   17  ,   45  ,   39  ,   19  ,   449 ,   691 ,   187 ,   2739    ,   7671    ,0 };
            const std::uint32_t dim976JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   15  ,   13  ,   57  ,   7   ,   75  ,   435 ,   287 ,   1479    ,   2143    ,   6501    ,0 };
            const std::uint32_t dim977JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   11  ,   11  ,   29  ,   111 ,   223 ,   505 ,   139 ,   1587    ,   3769    ,   5839    ,0 };
            const std::uint32_t dim978JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   7   ,   5   ,   61  ,   7   ,   209 ,   461 ,   37  ,   1771    ,   3683    ,   4283    ,0 };
            const std::uint32_t dim979JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   9   ,   1   ,   5   ,   123 ,   69  ,   75  ,   451 ,   963 ,   3273    ,   2785    ,0 };
            const std::uint32_t dim980JoeKuoD5Init[]    =   {   1   ,   1   ,   1   ,   3   ,   7   ,   17  ,   87  ,   63  ,   505 ,   863 ,   1955    ,   3253    ,   463 ,0 };
            const std::uint32_t dim981JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   15  ,   15  ,   55  ,   127 ,   213 ,   277 ,   829 ,   165 ,   2885    ,   6693    ,0 };
            const std::uint32_t dim982JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   1   ,   9   ,   35  ,   5   ,   233 ,   329 ,   827 ,   531 ,   1435    ,   899 ,0 };
            const std::uint32_t dim983JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   11  ,   15  ,   25  ,   19  ,   233 ,   375 ,   327 ,   241 ,   3519    ,   4511    ,0 };
            const std::uint32_t dim984JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   11  ,   1   ,   1   ,   117 ,   29  ,   185 ,   529 ,   873 ,   1769    ,   6857    ,0 };
            const std::uint32_t dim985JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   11  ,   1   ,   31  ,   125 ,   27  ,   77  ,   295 ,   43  ,   205 ,   3349    ,0 };
            const std::uint32_t dim986JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   13  ,   1   ,   59  ,   11  ,   195 ,   483 ,   391 ,   381 ,   1251    ,   205 ,0 };
            const std::uint32_t dim987JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   1   ,   5   ,   51  ,   33  ,   159 ,   143 ,   213 ,   573 ,   1329    ,   2327    ,0 };
            const std::uint32_t dim988JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   15  ,   25  ,   5   ,   11  ,   203 ,   217 ,   397 ,   819 ,   949 ,   3987    ,0 };
            const std::uint32_t dim989JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   13  ,   17  ,   1   ,   29  ,   219 ,   161 ,   437 ,   685 ,   2743    ,   7509    ,0 };
            const std::uint32_t dim990JoeKuoD5Init[]    =   {   1   ,   1   ,   3   ,   13  ,   3   ,   31  ,   29  ,   51  ,   41  ,   217 ,   997 ,   2581    ,   4273    ,0 };
            const std::uint32_t dim991JoeKuoD5Init[]    =   {   1   ,   1   ,   7   ,   5   ,   31  ,   33  ,   45  ,   113 ,   463 ,   537 ,   237 ,   1501    ,   315 ,0 };
            const std::uint32_t dim992JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   5   ,   13  ,   3   ,   49  ,   155 ,   175 ,   655 ,   1995    ,   2131    ,   6105    ,0 };
            const std::uint32_t dim993JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   15  ,   23  ,   3   ,   17  ,   165 ,   67  ,   137 ,   337 ,   3805    ,   257 ,0 };
            const std::uint32_t dim994JoeKuoD5Init[]    =   {   1   ,   1   ,   5   ,   13  ,   31  ,   11  ,   39  ,   111 ,   79  ,   585 ,   1911    ,   2395    ,   6239    ,0 };
            const std::uint32_t dim995JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   13  ,   5   ,   13  ,   61  ,   87  ,   309 ,   571 ,   321 ,   2485    ,   807 ,0 };
            const std::uint32_t dim996JoeKuoD5Init[]    =   {   1   ,   3   ,   5   ,   13  ,   31  ,   21  ,   9   ,   177 ,   9   ,   395 ,   351 ,   529 ,   4977    ,0 };
            const std::uint32_t dim997JoeKuoD5Init[]    =   {   1   ,   3   ,   1   ,   5   ,   5   ,   41  ,   95  ,   145 ,   319 ,   339 ,   1559    ,   203 ,   2883    ,0 };
            const std::uint32_t dim998JoeKuoD5Init[]    =   {   1   ,   3   ,   3   ,   7   ,   9   ,   13  ,   121 ,   111 ,   107 ,   421 ,   1763    ,   2671    ,   259 ,0 };
            const std::uint32_t dim999JoeKuoD5Init[]    =   {   1   ,   3   ,   7   ,   13  ,   25  ,   47  ,   71  ,   249 ,   119 ,   83  ,   1651    ,   2715    ,   4819    ,0 };
            const std::uint32_t dim1000JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   3   ,   5   ,   59  ,   99  ,   139 ,   435 ,   653 ,   153 ,   3605    ,   753 ,0 };
            const std::uint32_t dim1001JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   13  ,   19  ,   13  ,   3   ,   17  ,   215 ,   1017    ,   1685    ,   3795    ,   2363    ,0 };
            const std::uint32_t dim1002JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   11  ,   15  ,   13  ,   97  ,   145 ,   383 ,   39  ,   667 ,   1217    ,   1473    ,0 };
            const std::uint32_t dim1003JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   3   ,   11  ,   25  ,   107 ,   149 ,   11  ,   835 ,   1013    ,   1587    ,   1485    ,0 };
            const std::uint32_t dim1004JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   7   ,   15  ,   33  ,   15  ,   251 ,   473 ,   723 ,   959 ,   3991    ,   7145    ,0 };
            const std::uint32_t dim1005JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   13  ,   1   ,   49  ,   73  ,   195 ,   139 ,   893 ,   1677    ,   707 ,   667 ,0 };
            const std::uint32_t dim1006JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   11  ,   23  ,   3   ,   79  ,   255 ,   371 ,   885 ,   469 ,   3673    ,   5477    ,0 };
            const std::uint32_t dim1007JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   15  ,   21  ,   1   ,   45  ,   65  ,   403 ,   129 ,   123 ,   1171    ,   8177    ,0 };
            const std::uint32_t dim1008JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   3   ,   29  ,   25  ,   89  ,   231 ,   81  ,   503 ,   629 ,   1925    ,   2853    ,0 };
            const std::uint32_t dim1009JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   13  ,   9   ,   15  ,   107 ,   81  ,   479 ,   235 ,   1483    ,   3593    ,   2289    ,0 };
            const std::uint32_t dim1010JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   5   ,   9   ,   49  ,   119 ,   161 ,   233 ,   321 ,   1505    ,   3969    ,   3131    ,0 };
            const std::uint32_t dim1011JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   15  ,   9   ,   5   ,   91  ,   57  ,   13  ,   271 ,   999 ,   747 ,   3399    ,0 };
            const std::uint32_t dim1012JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   1   ,   1   ,   21  ,   1   ,   179 ,   449 ,   963 ,   33  ,   2259    ,   259 ,0 };
            const std::uint32_t dim1013JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   13  ,   7   ,   11  ,   81  ,   53  ,   157 ,   373 ,   767 ,   2489    ,   2275    ,0 };
            const std::uint32_t dim1014JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   3   ,   9   ,   55  ,   123 ,   135 ,   9   ,   499 ,   3   ,   2039    ,   2387    ,0 };
            const std::uint32_t dim1015JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   13  ,   7   ,   47  ,   119 ,   81  ,   351 ,   949 ,   1159    ,   859 ,   99  ,0 };
            const std::uint32_t dim1016JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   9   ,   1   ,   5   ,   83  ,   3   ,   387 ,   455 ,   1997    ,   1253    ,   77  ,0 };
            const std::uint32_t dim1017JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   13  ,   13  ,   49  ,   111 ,   133 ,   193 ,   893 ,   1549    ,   4003    ,   3461    ,0 };
            const std::uint32_t dim1018JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   13  ,   21  ,   3   ,   63  ,   209 ,   491 ,   447 ,   1635    ,   2297    ,   7667    ,0 };
            const std::uint32_t dim1019JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   1   ,   3   ,   61  ,   93  ,   115 ,   417 ,   465 ,   1075    ,   2157    ,   861 ,0 };
            const std::uint32_t dim1020JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   1   ,   7   ,   33  ,   7   ,   61  ,   509 ,   539 ,   1579    ,   2089    ,   5633    ,0 };
            const std::uint32_t dim1021JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   1   ,   9   ,   5   ,   75  ,   125 ,   345 ,   133 ,   1699    ,   3183    ,   5403    ,0 };
            const std::uint32_t dim1022JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   15  ,   17  ,   9   ,   115 ,   213 ,   417 ,   713 ,   989 ,   3987    ,   3043    ,0 };
            const std::uint32_t dim1023JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   3   ,   25  ,   9   ,   115 ,   83  ,   255 ,   695 ,   471 ,   1819    ,   2661    ,0 };
            const std::uint32_t dim1024JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   9   ,   31  ,   35  ,   33  ,   197 ,   335 ,   543 ,   323 ,   3241    ,   7039    ,0 };
            const std::uint32_t dim1025JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   7   ,   23  ,   5   ,   23  ,   193 ,   327 ,   3   ,   1425    ,   2787    ,   5659    ,0 };
            const std::uint32_t dim1026JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   9   ,   27  ,   25  ,   37  ,   241 ,   373 ,   411 ,   783 ,   621 ,   2129    ,0 };
            const std::uint32_t dim1027JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   5   ,   13  ,   19  ,   119 ,   39  ,   303 ,   383 ,   1965    ,   725 ,   1909    ,0 };
            const std::uint32_t dim1028JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   15  ,   25  ,   27  ,   121 ,   245 ,   165 ,   985 ,   595 ,   3325    ,   7319    ,0 };
            const std::uint32_t dim1029JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   5   ,   25  ,   7   ,   109 ,   75  ,   277 ,   25  ,   715 ,   495 ,   3911    ,0 };
            const std::uint32_t dim1030JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   9   ,   21  ,   37  ,   13  ,   23  ,   161 ,   907 ,   1551    ,   2453    ,   5323    ,0 };
            const std::uint32_t dim1031JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   9   ,   17  ,   11  ,   101 ,   237 ,   219 ,   735 ,   1865    ,   209 ,   5605    ,0 };
            const std::uint32_t dim1032JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   15  ,   5   ,   63  ,   87  ,   173 ,   299 ,   739 ,   617 ,   1883    ,   2525    ,0 };
            const std::uint32_t dim1033JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   1   ,   11  ,   5   ,   25  ,   207 ,   271 ,   471 ,   921 ,   3819    ,   5627    ,0 };
            const std::uint32_t dim1034JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   13  ,   1   ,   7   ,   27  ,   185 ,   245 ,   629 ,   1329    ,   611 ,   7183    ,0 };
            const std::uint32_t dim1035JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   15  ,   9   ,   21  ,   55  ,   17  ,   157 ,   987 ,   553 ,   3823    ,   6923    ,0 };
            const std::uint32_t dim1036JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   11  ,   19  ,   47  ,   113 ,   149 ,   495 ,   891 ,   1885    ,   2699    ,   6019    ,0 };
            const std::uint32_t dim1037JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   9   ,   23  ,   53  ,   27  ,   241 ,   453 ,   103 ,   1879    ,   289 ,   5195    ,0 };
            const std::uint32_t dim1038JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   3   ,   13  ,   37  ,   125 ,   83  ,   341 ,   793 ,   193 ,   297 ,   3337    ,0 };
            const std::uint32_t dim1039JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   7   ,   13  ,   43  ,   101 ,   121 ,   319 ,   845 ,   601 ,   3357    ,   3037    ,0 };
            const std::uint32_t dim1040JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   1   ,   27  ,   3   ,   53  ,   111 ,   287 ,   791 ,   2017    ,   3869    ,   5105    ,0 };
            const std::uint32_t dim1041JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   1   ,   19  ,   33  ,   107 ,   203 ,   135 ,   783 ,   497 ,   1007    ,   4587    ,0 };
            const std::uint32_t dim1042JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   13  ,   7   ,   41  ,   101 ,   59  ,   407 ,   525 ,   1941    ,   961 ,   7059    ,0 };
            const std::uint32_t dim1043JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   5   ,   17  ,   33  ,   9   ,   217 ,   31  ,   695 ,   1111    ,   391 ,   5617    ,0 };
            const std::uint32_t dim1044JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   5   ,   15  ,   13  ,   107 ,   223 ,   477 ,   91  ,   449 ,   901 ,   3075    ,0 };
            const std::uint32_t dim1045JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   13  ,   31  ,   47  ,   97  ,   49  ,   47  ,   301 ,   305 ,   1159    ,   6977    ,0 };
            const std::uint32_t dim1046JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   9   ,   29  ,   9   ,   17  ,   237 ,   461 ,   593 ,   495 ,   1099    ,   5135    ,0 };
            const std::uint32_t dim1047JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   7   ,   3   ,   51  ,   5   ,   113 ,   409 ,   777 ,   1323    ,   2719    ,   3647    ,0 };
            const std::uint32_t dim1048JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   5   ,   15  ,   45  ,   33  ,   49  ,   167 ,   933 ,   1831    ,   3195    ,   3121    ,0 };
            const std::uint32_t dim1049JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   15  ,   3   ,   33  ,   123 ,   19  ,   173 ,   69  ,   593 ,   3709    ,   7193    ,0 };
            const std::uint32_t dim1050JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   15  ,   9   ,   9   ,   63  ,   81  ,   325 ,   473 ,   1517    ,   3483    ,   7585    ,0 };
            const std::uint32_t dim1051JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   9   ,   31  ,   47  ,   77  ,   67  ,   55  ,   673 ,   1963    ,   111 ,   839 ,0 };
            const std::uint32_t dim1052JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   15  ,   23  ,   45  ,   5   ,   159 ,   225 ,   595 ,   1573    ,   1891    ,   301 ,0 };
            const std::uint32_t dim1053JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   1   ,   3   ,   21  ,   123 ,   29  ,   331 ,   793 ,   1885    ,   3299    ,   3433    ,0 };
            const std::uint32_t dim1054JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   1   ,   23  ,   51  ,   21  ,   23  ,   265 ,   919 ,   853 ,   3969    ,   2043    ,0 };
            const std::uint32_t dim1055JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   3   ,   25  ,   59  ,   111 ,   13  ,   217 ,   893 ,   1005    ,   3795    ,   3233    ,0 };
            const std::uint32_t dim1056JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   7   ,   7   ,   11  ,   69  ,   183 ,   509 ,   51  ,   727 ,   2093    ,   2615    ,0 };
            const std::uint32_t dim1057JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   11  ,   3   ,   13  ,   119 ,   209 ,   365 ,   895 ,   1563    ,   427 ,   5519    ,0 };
            const std::uint32_t dim1058JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   5   ,   23  ,   9   ,   87  ,   29  ,   19  ,   519 ,   763 ,   3553    ,   575 ,0 };
            const std::uint32_t dim1059JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   1   ,   3   ,   21  ,   15  ,   237 ,   501 ,   627 ,   1557    ,   545 ,   2415    ,0 };
            const std::uint32_t dim1060JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   3   ,   7   ,   53  ,   83  ,   19  ,   385 ,   425 ,   1145    ,   1039    ,   6667    ,0 };
            const std::uint32_t dim1061JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   15  ,   31  ,   31  ,   39  ,   51  ,   233 ,   755 ,   1105    ,   925 ,   6113    ,0 };
            const std::uint32_t dim1062JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   13  ,   17  ,   25  ,   45  ,   135 ,   347 ,   707 ,   1035    ,   1405    ,   7105    ,0 };
            const std::uint32_t dim1063JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   9   ,   17  ,   25  ,   119 ,   77  ,   279 ,   467 ,   195 ,   1919    ,   4959    ,0 };
            const std::uint32_t dim1064JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   7   ,   31  ,   41  ,   5   ,   21  ,   349 ,   607 ,   737 ,   2033    ,   2323    ,0 };
            const std::uint32_t dim1065JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   9   ,   29  ,   19  ,   45  ,   223 ,   391 ,   495 ,   1905    ,   735 ,   6309    ,0 };
            const std::uint32_t dim1066JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   15  ,   19  ,   9   ,   93  ,   89  ,   43  ,   297 ,   653 ,   1343    ,   5897    ,0 };
            const std::uint32_t dim1067JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   1   ,   21  ,   7   ,   29  ,   187 ,   115 ,   279 ,   1029    ,   2817    ,   1349    ,0 };
            const std::uint32_t dim1068JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   9   ,   5   ,   61  ,   35  ,   33  ,   151 ,   119 ,   1713    ,   1713    ,   1645    ,0 };
            const std::uint32_t dim1069JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   1   ,   23  ,   21  ,   101 ,   131 ,   355 ,   75  ,   1233    ,   1677    ,   2463    ,0 };
            const std::uint32_t dim1070JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   15  ,   5   ,   57  ,   79  ,   51  ,   299 ,   307 ,   1977    ,   3473    ,   6153    ,0 };
            const std::uint32_t dim1071JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   15  ,   19  ,   1   ,   59  ,   69  ,   175 ,   189 ,   303 ,   43  ,   7561    ,0 };
            const std::uint32_t dim1072JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   1   ,   31  ,   37  ,   117 ,   9   ,   373 ,   279 ,   1187    ,   3501    ,   715 ,0 };
            const std::uint32_t dim1073JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   13  ,   1   ,   29  ,   79  ,   161 ,   223 ,   437 ,   577 ,   921 ,   5535    ,0 };
            const std::uint32_t dim1074JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   1   ,   31  ,   27  ,   93  ,   63  ,   281 ,   187 ,   1739    ,   4085    ,   5669    ,0 };
            const std::uint32_t dim1075JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   7   ,   11  ,   25  ,   87  ,   245 ,   339 ,   741 ,   927 ,   1279    ,   3889    ,0 };
            const std::uint32_t dim1076JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   7   ,   31  ,   5   ,   45  ,   205 ,   289 ,   999 ,   361 ,   3595    ,   569 ,0 };
            const std::uint32_t dim1077JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   13  ,   19  ,   23  ,   103 ,   73  ,   403 ,   85  ,   1623    ,   325 ,   5369    ,0 };
            const std::uint32_t dim1078JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   15  ,   13  ,   23  ,   27  ,   155 ,   359 ,   777 ,   1751    ,   915 ,   949 ,0 };
            const std::uint32_t dim1079JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   11  ,   23  ,   59  ,   57  ,   215 ,   77  ,   581 ,   369 ,   953 ,   6987    ,0 };
            const std::uint32_t dim1080JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   15  ,   27  ,   55  ,   103 ,   173 ,   485 ,   771 ,   1693    ,   1227    ,   3257    ,0 };
            const std::uint32_t dim1081JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   9   ,   5   ,   23  ,   95  ,   121 ,   81  ,   107 ,   1897    ,   1647    ,   3047    ,0 };
            const std::uint32_t dim1082JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   11  ,   17  ,   47  ,   119 ,   83  ,   137 ,   897 ,   1893    ,   653 ,   5031    ,0 };
            const std::uint32_t dim1083JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   13  ,   31  ,   3   ,   73  ,   129 ,   159 ,   529 ,   1433    ,   2313    ,   6143    ,0 };
            const std::uint32_t dim1084JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   15  ,   29  ,   19  ,   123 ,   141 ,   51  ,   427 ,   935 ,   2831    ,   5799    ,0 };
            const std::uint32_t dim1085JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   1   ,   31  ,   3   ,   119 ,   227 ,   37  ,   435 ,   921 ,   3313    ,   2129    ,0 };
            const std::uint32_t dim1086JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   13  ,   1   ,   19  ,   75  ,   35  ,   307 ,   419 ,   813 ,   2217    ,   6603    ,0 };
            const std::uint32_t dim1087JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   3   ,   17  ,   47  ,   79  ,   75  ,   47  ,   835 ,   287 ,   3361    ,   5875    ,0 };
            const std::uint32_t dim1088JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   9   ,   5   ,   5   ,   3   ,   19  ,   341 ,   717 ,   45  ,   1169    ,   1305    ,0 };
            const std::uint32_t dim1089JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   1   ,   3   ,   11  ,   81  ,   233 ,   195 ,   987 ,   593 ,   2495    ,   5213    ,0 };
            const std::uint32_t dim1090JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   1   ,   27  ,   1   ,   29  ,   251 ,   221 ,   267 ,   593 ,   361 ,   5629    ,0 };
            const std::uint32_t dim1091JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   15  ,   21  ,   33  ,   15  ,   37  ,   341 ,   301 ,   293 ,   2787    ,   3531    ,0 };
            const std::uint32_t dim1092JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   7   ,   3   ,   3   ,   9   ,   7   ,   257 ,   509 ,   1545    ,   4095    ,   3309    ,0 };
            const std::uint32_t dim1093JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   5   ,   11  ,   7   ,   27  ,   71  ,   317 ,   221 ,   391 ,   1257    ,   5885    ,0 };
            const std::uint32_t dim1094JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   7   ,   15  ,   51  ,   29  ,   107 ,   461 ,   597 ,   961 ,   3589    ,   2325    ,0 };
            const std::uint32_t dim1095JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   3   ,   29  ,   1   ,   91  ,   181 ,   477 ,   125 ,   1869    ,   3209    ,   3513    ,0 };
            const std::uint32_t dim1096JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   7   ,   13  ,   17  ,   49  ,   145 ,   215 ,   1003    ,   1053    ,   1413    ,   8011    ,0 };
            const std::uint32_t dim1097JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   5   ,   23  ,   63  ,   9   ,   175 ,   159 ,   627 ,   705 ,   2769    ,   2469    ,0 };
            const std::uint32_t dim1098JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   11  ,   27  ,   21  ,   5   ,   61  ,   249 ,   581 ,   829 ,   2195    ,   4241    ,0 };
            const std::uint32_t dim1099JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   11  ,   27  ,   39  ,   67  ,   3   ,   23  ,   819 ,   1879    ,   3775    ,   6949    ,0 };
            const std::uint32_t dim1100JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   5   ,   19  ,   35  ,   93  ,   113 ,   371 ,   511 ,   811 ,   577 ,   1121    ,0 };
            const std::uint32_t dim1101JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   9   ,   9   ,   25  ,   103 ,   139 ,   151 ,   177 ,   557 ,   2123    ,   6677    ,0 };
            const std::uint32_t dim1102JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   5   ,   17  ,   63  ,   61  ,   241 ,   351 ,   371 ,   1745    ,   3133    ,   7663    ,0 };
            const std::uint32_t dim1103JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   11  ,   19  ,   39  ,   105 ,   93  ,   77  ,   445 ,   1433    ,   1793    ,   2957    ,0 };
            const std::uint32_t dim1104JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   15  ,   5   ,   15  ,   29  ,   211 ,   229 ,   887 ,   413 ,   701 ,   737 ,0 };
            const std::uint32_t dim1105JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   13  ,   17  ,   7   ,   69  ,   213 ,   49  ,   91  ,   1143    ,   3743    ,   4385    ,0 };
            const std::uint32_t dim1106JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   7   ,   21  ,   47  ,   41  ,   157 ,   299 ,   29  ,   751 ,   2427    ,   1521    ,0 };
            const std::uint32_t dim1107JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   1   ,   29  ,   45  ,   119 ,   79  ,   141 ,   477 ,   1289    ,   515 ,   8143    ,0 };
            const std::uint32_t dim1108JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   7   ,   3   ,   7   ,   123 ,   197 ,   441 ,   233 ,   1841    ,   267 ,   6553    ,0 };
            const std::uint32_t dim1109JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   15  ,   3   ,   41  ,   33  ,   95  ,   271 ,   461 ,   1505    ,   2989    ,   5503    ,0 };
            const std::uint32_t dim1110JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   11  ,   19  ,   15  ,   1   ,   23  ,   13  ,   737 ,   51  ,   289 ,   6731    ,0 };
            const std::uint32_t dim1111JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   1   ,   15  ,   11  ,   53  ,   241 ,   17  ,   107 ,   1931    ,   3759    ,   5421    ,   1889    ,0 };
            const std::uint32_t dim1112JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   13  ,   15  ,   29  ,   107 ,   163 ,   395 ,   645 ,   299 ,   799 ,   4331    ,   335 ,0 };
            const std::uint32_t dim1113JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   13  ,   5   ,   47  ,   91  ,   41  ,   439 ,   319 ,   1213    ,   763 ,   6101    ,   1543    ,0 };
            const std::uint32_t dim1114JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   15  ,   19  ,   51  ,   117 ,   159 ,   315 ,   767 ,   1957    ,   3655    ,   6573    ,   5419    ,0 };
            const std::uint32_t dim1115JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   11  ,   23  ,   51  ,   115 ,   223 ,   125 ,   633 ,   637 ,   3443    ,   1993    ,   1887    ,0 };
            const std::uint32_t dim1116JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   15  ,   27  ,   59  ,   49  ,   123 ,   49  ,   187 ,   963 ,   3893    ,   3921    ,   14411   ,0 };
            const std::uint32_t dim1117JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   7   ,   29  ,   3   ,   77  ,   3   ,   79  ,   409 ,   1151    ,   3547    ,   3693    ,   8367    ,0 };
            const std::uint32_t dim1118JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   9   ,   23  ,   31  ,   123 ,   133 ,   215 ,   921 ,   329 ,   1449    ,   5535    ,   9725    ,0 };
            const std::uint32_t dim1119JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   5   ,   11  ,   45  ,   109 ,   117 ,   493 ,   743 ,   1473    ,   2073    ,   4771    ,   16321   ,0 };
            const std::uint32_t dim1120JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   9   ,   27  ,   29  ,   25  ,   223 ,   371 ,   113 ,   1183    ,   1723    ,   6127    ,   9949    ,0 };
            const std::uint32_t dim1121JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   15  ,   27  ,   55  ,   119 ,   31  ,   21  ,   849 ,   2001    ,   2541    ,   2611    ,   15429   ,0 };
            const std::uint32_t dim1122JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   7   ,   17  ,   1   ,   93  ,   243 ,   311 ,   175 ,   559 ,   2177    ,   5641    ,   15293   ,0 };
            const std::uint32_t dim1123JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   15  ,   25  ,   31  ,   121 ,   179 ,   169 ,   61  ,   1837    ,   2233    ,   1735    ,   6597    ,0 };
            const std::uint32_t dim1124JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   13  ,   21  ,   59  ,   61  ,   239 ,   501 ,   523 ,   257 ,   573 ,   893 ,   7275    ,0 };
            const std::uint32_t dim1125JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   13  ,   29  ,   33  ,   77  ,   225 ,   81  ,   879 ,   1403    ,   3279    ,   2225    ,   11571   ,0 };
            const std::uint32_t dim1126JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   5   ,   15  ,   5   ,   29  ,   7   ,   157 ,   717 ,   397 ,   2079    ,   5839    ,   13297   ,0 };
            const std::uint32_t dim1127JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   7   ,   17  ,   3   ,   93  ,   241 ,   301 ,   433 ,   2003    ,   2089    ,   5781    ,   15223   ,0 };
            const std::uint32_t dim1128JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   13  ,   5   ,   19  ,   53  ,   189 ,   41  ,   17  ,   897 ,   2327    ,   3481    ,   7185    ,0 };
            const std::uint32_t dim1129JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   3   ,   25  ,   23  ,   23  ,   155 ,   367 ,   391 ,   1001    ,   1179    ,   3781    ,   14225   ,0 };
            const std::uint32_t dim1130JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   7   ,   9   ,   23  ,   63  ,   73  ,   439 ,   361 ,   233 ,   3387    ,   887 ,   5425    ,0 };
            const std::uint32_t dim1131JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   13  ,   5   ,   57  ,   55  ,   35  ,   369 ,   85  ,   1585    ,   2267    ,   2927    ,   13997   ,0 };
            const std::uint32_t dim1132JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   1   ,   7   ,   7   ,   55  ,   109 ,   401 ,   443 ,   1777    ,   3831    ,   6933    ,   3661    ,0 };
            const std::uint32_t dim1133JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   15  ,   17  ,   27  ,   5   ,   17  ,   419 ,   949 ,   1483    ,   791 ,   7353    ,   1425    ,0 };
            const std::uint32_t dim1134JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   9   ,   27  ,   41  ,   67  ,   135 ,   129 ,   863 ,   1679    ,   4001    ,   6841    ,   13561   ,0 };
            const std::uint32_t dim1135JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   3   ,   21  ,   43  ,   45  ,   65  ,   103 ,   141 ,   1261    ,   2865    ,   5621    ,   5131    ,0 };
            const std::uint32_t dim1136JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   15  ,   19  ,   3   ,   97  ,   159 ,   465 ,   31  ,   1757    ,   2765    ,   667 ,   6943    ,0 };
            const std::uint32_t dim1137JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   3   ,   3   ,   5   ,   111 ,   203 ,   313 ,   495 ,   123 ,   1899    ,   7765    ,   2737    ,0 };
            const std::uint32_t dim1138JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   15  ,   19  ,   63  ,   19  ,   233 ,   283 ,   25  ,   1009    ,   2117    ,   6233    ,   5059    ,0 };
            const std::uint32_t dim1139JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   9   ,   29  ,   11  ,   35  ,   111 ,   111 ,   49  ,   1681    ,   3483    ,   2449    ,   13877   ,0 };
            const std::uint32_t dim1140JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   13  ,   7   ,   61  ,   27  ,   217 ,   275 ,   137 ,   2025    ,   2745    ,   5565    ,   7999    ,0 };
            const std::uint32_t dim1141JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   1   ,   13  ,   19  ,   113 ,   169 ,   425 ,   691 ,   1425    ,   1645    ,   1045    ,   9237    ,0 };
            const std::uint32_t dim1142JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   11  ,   23  ,   19  ,   67  ,   5   ,   225 ,   523 ,   1809    ,   341 ,   7919    ,   3675    ,0 };
            const std::uint32_t dim1143JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   7   ,   3   ,   33  ,   25  ,   229 ,   393 ,   141 ,   1953    ,   1433    ,   1593    ,   11569   ,0 };
            const std::uint32_t dim1144JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   1   ,   5   ,   23  ,   53  ,   59  ,   141 ,   385 ,   1765    ,   4079    ,   2901    ,   593 ,0 };
            const std::uint32_t dim1145JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   9   ,   15  ,   43  ,   115 ,   93  ,   121 ,   209 ,   1797    ,   633 ,   2595    ,   5539    ,0 };
            const std::uint32_t dim1146JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   15  ,   5   ,   25  ,   9   ,   141 ,   37  ,   313 ,   1937    ,   2259    ,   1051    ,   8251    ,0 };
            const std::uint32_t dim1147JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   5   ,   17  ,   1   ,   89  ,   173 ,   169 ,   463 ,   2003    ,   4005    ,   6009    ,   4373    ,0 };
            const std::uint32_t dim1148JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   7   ,   17  ,   21  ,   59  ,   207 ,   333 ,   741 ,   1847    ,   683 ,   2847    ,   11007   ,0 };
            const std::uint32_t dim1149JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   5   ,   5   ,   39  ,   111 ,   91  ,   49  ,   559 ,   1937    ,   1311    ,   6157    ,   517 ,0 };
            const std::uint32_t dim1150JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   15  ,   29  ,   1   ,   113 ,   125 ,   343 ,   939 ,   1989    ,   2569    ,   7215    ,   5099    ,0 };
            const std::uint32_t dim1151JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   5   ,   5   ,   55  ,   103 ,   237 ,   313 ,   43  ,   909 ,   201 ,   175 ,   16025   ,0 };
            const std::uint32_t dim1152JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   3   ,   25  ,   29  ,   33  ,   59  ,   127 ,   865 ,   1753    ,   3649    ,   5517    ,   5001    ,0 };
            const std::uint32_t dim1153JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   15  ,   27  ,   31  ,   97  ,   153 ,   451 ,   241 ,   59  ,   515 ,   2869    ,   12909   ,0 };
            const std::uint32_t dim1154JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   3   ,   13  ,   51  ,   3   ,   55  ,   105 ,   497 ,   701 ,   483 ,   5165    ,   4721    ,0 };
            const std::uint32_t dim1155JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   3   ,   19  ,   57  ,   39  ,   55  ,   197 ,   409 ,   199 ,   1635    ,   1965    ,   2489    ,0 };
            const std::uint32_t dim1156JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   9   ,   1   ,   13  ,   123 ,   125 ,   341 ,   981 ,   1957    ,   1619    ,   1973    ,   8641    ,0 };
            const std::uint32_t dim1157JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   1   ,   29  ,   13  ,   31  ,   71  ,   443 ,   867 ,   1755    ,   843 ,   7349    ,   6015    ,0 };
            const std::uint32_t dim1158JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   13  ,   15  ,   39  ,   81  ,   123 ,   9   ,   991 ,   803 ,   3281    ,   7859    ,   15455   ,0 };
            const std::uint32_t dim1159JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   1   ,   3   ,   33  ,   87  ,   81  ,   111 ,   595 ,   483 ,   3273    ,   847 ,   2061    ,0 };
            const std::uint32_t dim1160JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   11  ,   9   ,   21  ,   79  ,   49  ,   453 ,   125 ,   603 ,   1733    ,   7213    ,   7309    ,0 };
            const std::uint32_t dim1161JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   3   ,   29  ,   47  ,   21  ,   99  ,   35  ,   275 ,   69  ,   3773    ,   389 ,   10615   ,0 };
            const std::uint32_t dim1162JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   5   ,   15  ,   21  ,   9   ,   55  ,   293 ,   639 ,   135 ,   903 ,   973 ,   9467    ,0 };
            const std::uint32_t dim1163JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   15  ,   19  ,   63  ,   73  ,   71  ,   397 ,   387 ,   1859    ,   2741    ,   7323    ,   369 ,0 };
            const std::uint32_t dim1164JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   9   ,   21  ,   23  ,   55  ,   129 ,   183 ,   721 ,   1293    ,   3579    ,   3629    ,   13303   ,0 };
            const std::uint32_t dim1165JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   1   ,   21  ,   35  ,   79  ,   255 ,   443 ,   123 ,   551 ,   1113    ,   8133    ,   11621   ,0 };
            const std::uint32_t dim1166JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   7   ,   19  ,   61  ,   35  ,   161 ,   145 ,   291 ,   1503    ,   3085    ,   4589    ,   7971    ,0 };
            const std::uint32_t dim1167JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   15  ,   9   ,   59  ,   119 ,   133 ,   69  ,   413 ,   335 ,   2089    ,   8085    ,   12727   ,0 };
            const std::uint32_t dim1168JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   11  ,   17  ,   5   ,   83  ,   125 ,   161 ,   745 ,   1889    ,   345 ,   8107    ,   10693   ,0 };
            const std::uint32_t dim1169JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   9   ,   5   ,   29  ,   59  ,   69  ,   113 ,   529 ,   199 ,   1565    ,   1611    ,   12297   ,0 };
            const std::uint32_t dim1170JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   15  ,   27  ,   61  ,   49  ,   59  ,   249 ,   121 ,   1569    ,   407 ,   1443    ,   5705    ,0 };
            const std::uint32_t dim1171JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   13  ,   5   ,   3   ,   93  ,   99  ,   417 ,   499 ,   1867    ,   1269    ,   4293    ,   14633   ,0 };
            const std::uint32_t dim1172JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   5   ,   15  ,   37  ,   29  ,   75  ,   191 ,   41  ,   11  ,   339 ,   485 ,   13635   ,0 };
            const std::uint32_t dim1173JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   7   ,   27  ,   53  ,   13  ,   121 ,   209 ,   411 ,   51  ,   1003    ,   6587    ,   8247    ,0 };
            const std::uint32_t dim1174JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   5   ,   13  ,   7   ,   43  ,   155 ,   467 ,   491 ,   1181    ,   1105    ,   2165    ,   16347   ,0 };
            const std::uint32_t dim1175JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   3   ,   21  ,   19  ,   89  ,   25  ,   353 ,   223 ,   1063    ,   111 ,   611 ,   2225    ,0 };
            const std::uint32_t dim1176JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   9   ,   3   ,   41  ,   95  ,   183 ,   135 ,   919 ,   861 ,   2929    ,   7189    ,   5505    ,0 };
            const std::uint32_t dim1177JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   13  ,   13  ,   39  ,   85  ,   135 ,   403 ,   39  ,   1893    ,   3667    ,   2609    ,   9251    ,0 };
            const std::uint32_t dim1178JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   11  ,   25  ,   5   ,   1   ,   179 ,   491 ,   953 ,   393 ,   2005    ,   1401    ,   12589   ,0 };
            const std::uint32_t dim1179JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   7   ,   25  ,   19  ,   25  ,   73  ,   63  ,   897 ,   701 ,   345 ,   4995    ,   2411    ,0 };
            const std::uint32_t dim1180JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   3   ,   31  ,   15  ,   121 ,   161 ,   127 ,   847 ,   1547    ,   3379    ,   4763    ,   8349    ,0 };
            const std::uint32_t dim1181JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   7   ,   25  ,   61  ,   87  ,   235 ,   117 ,   861 ,   977 ,   2979    ,   3333    ,   10911   ,0 };
            const std::uint32_t dim1182JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   9   ,   5   ,   57  ,   33  ,   129 ,   295 ,   225 ,   1497    ,   2367    ,   5379    ,   12721   ,0 };
            const std::uint32_t dim1183JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   11  ,   19  ,   43  ,   43  ,   217 ,   139 ,   637 ,   567 ,   3661    ,   2807    ,   11061   ,0 };
            const std::uint32_t dim1184JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   7   ,   27  ,   41  ,   97  ,   89  ,   53  ,   375 ,   1871    ,   2575    ,   1545    ,   455 ,0 };
            const std::uint32_t dim1185JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   3   ,   13  ,   15  ,   77  ,   229 ,   329 ,   663 ,   1943    ,   1411    ,   5755    ,   16279   ,0 };
            const std::uint32_t dim1186JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   9   ,   1   ,   3   ,   65  ,   21  ,   239 ,   619 ,   1801    ,   233 ,   3441    ,   12777   ,0 };
            const std::uint32_t dim1187JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   5   ,   9   ,   63  ,   9   ,   19  ,   65  ,   759 ,   1871    ,   3537    ,   4453    ,   15443   ,0 };
            const std::uint32_t dim1188JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   5   ,   17  ,   35  ,   43  ,   199 ,   167 ,   507 ,   669 ,   3593    ,   1645    ,   11791   ,0 };
            const std::uint32_t dim1189JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   7   ,   25  ,   21  ,   111 ,   171 ,   349 ,   423 ,   1793    ,   659 ,   5211    ,   3547    ,0 };
            const std::uint32_t dim1190JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   13  ,   23  ,   53  ,   95  ,   81  ,   383 ,   639 ,   1113    ,   2021    ,   7897    ,   4803    ,0 };
            const std::uint32_t dim1191JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   9   ,   19  ,   63  ,   61  ,   165 ,   3   ,   565 ,   829 ,   3071    ,   6605    ,   3625    ,0 };
            const std::uint32_t dim1192JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   15  ,   13  ,   53  ,   89  ,   97  ,   307 ,   555 ,   2039    ,   2753    ,   169 ,   941 ,0 };
            const std::uint32_t dim1193JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   3   ,   9   ,   41  ,   45  ,   89  ,   155 ,   269 ,   51  ,   3791    ,   5563    ,   4757    ,0 };
            const std::uint32_t dim1194JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   7   ,   23  ,   35  ,   19  ,   93  ,   205 ,   51  ,   375 ,   2107    ,   6357    ,   16257   ,0 };
            const std::uint32_t dim1195JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   5   ,   3   ,   45  ,   107 ,   141 ,   315 ,   107 ,   219 ,   51  ,   7629    ,   6865    ,0 };
            const std::uint32_t dim1196JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   1   ,   19  ,   23  ,   17  ,   77  ,   409 ,   59  ,   1649    ,   4029    ,   6541    ,   1075    ,0 };
            const std::uint32_t dim1197JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   11  ,   1   ,   37  ,   13  ,   221 ,   277 ,   61  ,   1509    ,   1713    ,   4597    ,   5907    ,0 };
            const std::uint32_t dim1198JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   1   ,   19  ,   53  ,   109 ,   123 ,   243 ,   1001    ,   291 ,   2265    ,   45  ,   437 ,0 };
            const std::uint32_t dim1199JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   1   ,   17  ,   63  ,   65  ,   67  ,   359 ,   139 ,   699 ,   3037    ,   6123    ,   11885   ,0 };
            const std::uint32_t dim1200JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   1   ,   3   ,   45  ,   125 ,   107 ,   75  ,   631 ,   769 ,   1431    ,   2089    ,   4919    ,0 };
            const std::uint32_t dim1201JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   5   ,   27  ,   31  ,   63  ,   75  ,   265 ,   727 ,   1197    ,   3549    ,   7677    ,   10831   ,0 };
            const std::uint32_t dim1202JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   15  ,   17  ,   61  ,   67  ,   169 ,   325 ,   627 ,   489 ,   729 ,   3585    ,   14253   ,0 };
            const std::uint32_t dim1203JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   5   ,   1   ,   39  ,   23  ,   11  ,   23  ,   3   ,   973 ,   2161    ,   5613    ,   5711    ,0 };
            const std::uint32_t dim1204JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   11  ,   3   ,   33  ,   31  ,   139 ,   275 ,   391 ,   1625    ,   2037    ,   389 ,   3853    ,0 };
            const std::uint32_t dim1205JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   1   ,   17  ,   47  ,   19  ,   171 ,   219 ,   959 ,   1623    ,   1069    ,   1833    ,   4467    ,0 };
            const std::uint32_t dim1206JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   11  ,   3   ,   29  ,   59  ,   159 ,   385 ,   183 ,   1091    ,   491 ,   8087    ,   4047    ,0 };
            const std::uint32_t dim1207JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   5   ,   19  ,   3   ,   121 ,   29  ,   97  ,   345 ,   1573    ,   2993    ,   7987    ,   5397    ,0 };
            const std::uint32_t dim1208JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   1   ,   31  ,   9   ,   57  ,   33  ,   489 ,   389 ,   1065    ,   2715    ,   5955    ,   11267   ,0 };
            const std::uint32_t dim1209JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   1   ,   25  ,   7   ,   67  ,   245 ,   159 ,   987 ,   1297    ,   277 ,   2223    ,   9865    ,0 };
            const std::uint32_t dim1210JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   1   ,   5   ,   11  ,   109 ,   171 ,   181 ,   303 ,   1875    ,   1915    ,   5007    ,   15563   ,0 };
            const std::uint32_t dim1211JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   1   ,   21  ,   7   ,   67  ,   155 ,   503 ,   751 ,   1721    ,   3405    ,   4717    ,   12567   ,0 };
            const std::uint32_t dim1212JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   1   ,   1   ,   51  ,   67  ,   57  ,   373 ,   835 ,   911 ,   3899    ,   7235    ,   5943    ,0 };
            const std::uint32_t dim1213JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   1   ,   21  ,   63  ,   21  ,   209 ,   321 ,   75  ,   551 ,   2741    ,   535 ,   14693   ,0 };
            const std::uint32_t dim1214JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   11  ,   21  ,   53  ,   23  ,   189 ,   463 ,   707 ,   637 ,   4055    ,   851 ,   12377   ,0 };
            const std::uint32_t dim1215JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   3   ,   13  ,   39  ,   17  ,   7   ,   487 ,   731 ,   1965    ,   2395    ,   5129    ,   6677    ,0 };
            const std::uint32_t dim1216JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   9   ,   5   ,   57  ,   15  ,   247 ,   325 ,   789 ,   1771    ,   2811    ,   6453    ,   7031    ,0 };
            const std::uint32_t dim1217JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   13  ,   21  ,   21  ,   27  ,   113 ,   345 ,   999 ,   7   ,   3241    ,   2569    ,   9175    ,0 };
            const std::uint32_t dim1218JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   5   ,   19  ,   41  ,   51  ,   37  ,   409 ,   553 ,   693 ,   1877    ,   4015    ,   1749    ,0 };
            const std::uint32_t dim1219JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   11  ,   3   ,   7   ,   11  ,   197 ,   5   ,   601 ,   451 ,   2117    ,   4519    ,   5913    ,0 };
            const std::uint32_t dim1220JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   7   ,   11  ,   53  ,   81  ,   187 ,   169 ,   419 ,   175 ,   2041    ,   2537    ,   16333   ,0 };
            const std::uint32_t dim1221JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   1   ,   1   ,   9   ,   117 ,   33  ,   233 ,   581 ,   1575    ,   2131    ,   2065    ,   6597    ,0 };
            const std::uint32_t dim1222JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   3   ,   27  ,   7   ,   111 ,   51  ,   311 ,   297 ,   1773    ,   193 ,   5599    ,   271 ,0 };
            const std::uint32_t dim1223JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   7   ,   17  ,   49  ,   85  ,   247 ,   7   ,   1005    ,   1191    ,   399 ,   7775    ,   5635    ,0 };
            const std::uint32_t dim1224JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   9   ,   31  ,   23  ,   9   ,   251 ,   97  ,   835 ,   813 ,   1335    ,   7955    ,   3977    ,0 };
            const std::uint32_t dim1225JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   15  ,   3   ,   39  ,   5   ,   19  ,   111 ,   523 ,   1475    ,   2169    ,   4121    ,   1171    ,0 };
            const std::uint32_t dim1226JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   9   ,   3   ,   19  ,   73  ,   43  ,   45  ,   57  ,   165 ,   3659    ,   7585    ,   8549    ,0 };
            const std::uint32_t dim1227JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   11  ,   25  ,   57  ,   117 ,   15  ,   289 ,   953 ,   1123    ,   2327    ,   7957    ,   6043    ,0 };
            const std::uint32_t dim1228JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   13  ,   7   ,   45  ,   63  ,   39  ,   349 ,   871 ,   1215    ,   2915    ,   1061    ,   7633    ,0 };
            const std::uint32_t dim1229JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   15  ,   1   ,   33  ,   55  ,   213 ,   245 ,   221 ,   259 ,   1679    ,   1507    ,   14275   ,0 };
            const std::uint32_t dim1230JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   3   ,   5   ,   15  ,   59  ,   55  ,   349 ,   121 ,   1471    ,   2119    ,   2559    ,   6379    ,0 };
            const std::uint32_t dim1231JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   3   ,   7   ,   23  ,   125 ,   137 ,   171 ,   775 ,   1069    ,   605 ,   2945    ,   16089   ,0 };
            const std::uint32_t dim1232JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   7   ,   9   ,   9   ,   43  ,   131 ,   385 ,   527 ,   757 ,   1263    ,   5285    ,   16309   ,0 };
            const std::uint32_t dim1233JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   3   ,   3   ,   39  ,   5   ,   163 ,   459 ,   697 ,   715 ,   3827    ,   3295    ,   9163    ,0 };
            const std::uint32_t dim1234JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   15  ,   7   ,   29  ,   7   ,   177 ,   207 ,   465 ,   59  ,   1485    ,   7731    ,   9843    ,0 };
            const std::uint32_t dim1235JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   13  ,   21  ,   57  ,   87  ,   191 ,   399 ,   689 ,   935 ,   2771    ,   1025    ,   715 ,0 };
            const std::uint32_t dim1236JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   1   ,   29  ,   19  ,   107 ,   253 ,   155 ,   163 ,   659 ,   3711    ,   2127    ,   10465   ,0 };
            const std::uint32_t dim1237JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   13  ,   7   ,   43  ,   27  ,   211 ,   407 ,   153 ,   1939    ,   3243    ,   6655    ,   15983   ,0 };
            const std::uint32_t dim1238JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   5   ,   27  ,   21  ,   23  ,   63  ,   271 ,   515 ,   261 ,   1947    ,   6257    ,   12861   ,0 };
            const std::uint32_t dim1239JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   1   ,   19  ,   57  ,   67  ,   221 ,   179 ,   725 ,   1179    ,   3983    ,   1585    ,   5899    ,0 };
            const std::uint32_t dim1240JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   15  ,   7   ,   61  ,   97  ,   131 ,   145 ,   637 ,   733 ,   2533    ,   1993    ,   14399   ,0 };
            const std::uint32_t dim1241JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   15  ,   13  ,   39  ,   83  ,   247 ,   235 ,   621 ,   1557    ,   3075    ,   3165    ,   16027   ,0 };
            const std::uint32_t dim1242JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   15  ,   9   ,   11  ,   111 ,   153 ,   437 ,   687 ,   1845    ,   3547    ,   2097    ,   2219    ,0 };
            const std::uint32_t dim1243JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   13  ,   21  ,   13  ,   43  ,   33  ,   51  ,   1021    ,   1883    ,   1261    ,   2823    ,   12771   ,0 };
            const std::uint32_t dim1244JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   9   ,   3   ,   35  ,   19  ,   127 ,   419 ,   203 ,   1869    ,   1477    ,   5239    ,   6113    ,0 };
            const std::uint32_t dim1245JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   13  ,   31  ,   63  ,   75  ,   185 ,   507 ,   401 ,   1079    ,   67  ,   1621    ,   2849    ,0 };
            const std::uint32_t dim1246JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   1   ,   31  ,   61  ,   125 ,   77  ,   169 ,   51  ,   1115    ,   1625    ,   3533    ,   5953    ,0 };
            const std::uint32_t dim1247JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   15  ,   29  ,   51  ,   23  ,   43  ,   505 ,   313 ,   887 ,   551 ,   4401    ,   2133    ,0 };
            const std::uint32_t dim1248JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   15  ,   11  ,   37  ,   55  ,   161 ,   353 ,   347 ,   1991    ,   4009    ,   2073    ,   12169   ,0 };
            const std::uint32_t dim1249JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   11  ,   29  ,   51  ,   15  ,   13  ,   391 ,   677 ,   225 ,   1467    ,   6615    ,   1895    ,0 };
            const std::uint32_t dim1250JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   3   ,   29  ,   15  ,   93  ,   103 ,   147 ,   323 ,   837 ,   1983    ,   1613    ,   10667   ,0 };
            const std::uint32_t dim1251JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   9   ,   21  ,   11  ,   39  ,   95  ,   473 ,   591 ,   1645    ,   67  ,   2793    ,   11217   ,0 };
            const std::uint32_t dim1252JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   5   ,   9   ,   51  ,   1   ,   243 ,   445 ,   583 ,   375 ,   2289    ,   4911    ,   10511   ,0 };
            const std::uint32_t dim1253JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   7   ,   23  ,   15  ,   111 ,   239 ,   247 ,   511 ,   1723    ,   2911    ,   2627    ,   10549   ,0 };
            const std::uint32_t dim1254JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   9   ,   15  ,   37  ,   31  ,   135 ,   347 ,   599 ,   765 ,   2561    ,   4635    ,   10659   ,0 };
            const std::uint32_t dim1255JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   11  ,   9   ,   49  ,   93  ,   187 ,   415 ,   247 ,   1871    ,   617 ,   6711    ,   3283    ,0 };
            const std::uint32_t dim1256JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   11  ,   25  ,   25  ,   37  ,   97  ,   365 ,   477 ,   1383    ,   1357    ,   693 ,   14743   ,0 };
            const std::uint32_t dim1257JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   11  ,   25  ,   19  ,   109 ,   99  ,   471 ,   661 ,   1633    ,   3773    ,   921 ,   4113    ,0 };
            const std::uint32_t dim1258JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   11  ,   13  ,   61  ,   21  ,   255 ,   161 ,   233 ,   1181    ,   3003    ,   1465    ,   9299    ,0 };
            const std::uint32_t dim1259JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   5   ,   7   ,   59  ,   53  ,   129 ,   127 ,   961 ,   893 ,   499 ,   5265    ,   2299    ,0 };
            const std::uint32_t dim1260JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   9   ,   29  ,   45  ,   85  ,   173 ,   131 ,   775 ,   1527    ,   1899    ,   4833    ,   12763   ,0 };
            const std::uint32_t dim1261JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   3   ,   1   ,   1   ,   115 ,   245 ,   205 ,   609 ,   1729    ,   915 ,   5965    ,   11001   ,0 };
            const std::uint32_t dim1262JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   15  ,   3   ,   61  ,   91  ,   93  ,   363 ,   457 ,   1497    ,   2539    ,   553 ,   7581    ,0 };
            const std::uint32_t dim1263JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   1   ,   29  ,   5   ,   7   ,   171 ,   393 ,   381 ,   935 ,   3467    ,   6199    ,   6625    ,0 };
            const std::uint32_t dim1264JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   13  ,   15  ,   25  ,   65  ,   137 ,   349 ,   61  ,   1035    ,   591 ,   4317    ,   13949   ,0 };
            const std::uint32_t dim1265JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   9   ,   27  ,   17  ,   87  ,   233 ,   227 ,   341 ,   639 ,   1813    ,   871 ,   12871   ,0 };
            const std::uint32_t dim1266JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   13  ,   29  ,   15  ,   31  ,   81  ,   61  ,   857 ,   1305    ,   3631    ,   2919    ,   2093    ,0 };
            const std::uint32_t dim1267JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   3   ,   27  ,   5   ,   49  ,   1   ,   49  ,   745 ,   543 ,   847 ,   2469    ,   3513    ,0 };
            const std::uint32_t dim1268JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   3   ,   15  ,   39  ,   47  ,   73  ,   33  ,   469 ,   1809    ,   2105    ,   7995    ,   11285   ,0 };
            const std::uint32_t dim1269JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   15  ,   9   ,   9   ,   81  ,   211 ,   295 ,   791 ,   1267    ,   2945    ,   5639    ,   6967    ,0 };
            const std::uint32_t dim1270JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   9   ,   13  ,   11  ,   43  ,   221 ,   161 ,   263 ,   905 ,   2767    ,   4491    ,   7605    ,0 };
            const std::uint32_t dim1271JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   15  ,   13  ,   9   ,   91  ,   123 ,   449 ,   21  ,   941 ,   1391    ,   3469    ,   16027   ,0 };
            const std::uint32_t dim1272JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   11  ,   5   ,   13  ,   77  ,   69  ,   245 ,   905 ,   231 ,   547 ,   2933    ,   4307    ,0 };
            const std::uint32_t dim1273JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   1   ,   25  ,   59  ,   49  ,   49  ,   183 ,   213 ,   29  ,   1801    ,   6271    ,   16283   ,0 };
            const std::uint32_t dim1274JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   11  ,   3   ,   15  ,   35  ,   157 ,   87  ,   453 ,   1939    ,   2697    ,   3325    ,   8679    ,0 };
            const std::uint32_t dim1275JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   13  ,   7   ,   45  ,   77  ,   73  ,   203 ,   321 ,   425 ,   581 ,   481 ,   15367   ,0 };
            const std::uint32_t dim1276JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   15  ,   11  ,   51  ,   11  ,   59  ,   355 ,   677 ,   1565    ,   123 ,   2403    ,   12835   ,0 };
            const std::uint32_t dim1277JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   5   ,   7   ,   27  ,   17  ,   81  ,   295 ,   131 ,   955 ,   4065    ,   797 ,   16165   ,0 };
            const std::uint32_t dim1278JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   5   ,   29  ,   63  ,   51  ,   215 ,   269 ,   1013    ,   517 ,   1857    ,   141 ,   4495    ,0 };
            const std::uint32_t dim1279JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   5   ,   17  ,   47  ,   121 ,   199 ,   177 ,   1023    ,   1009    ,   3535    ,   4825    ,   16349   ,0 };
            const std::uint32_t dim1280JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   1   ,   21  ,   25  ,   107 ,   165 ,   43  ,   213 ,   1847    ,   1945    ,   3463    ,   2259    ,0 };
            const std::uint32_t dim1281JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   7   ,   5   ,   5   ,   5   ,   65  ,   493 ,   725 ,   755 ,   111 ,   6673    ,   213 ,0 };
            const std::uint32_t dim1282JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   1   ,   3   ,   29  ,   17  ,   87  ,   207 ,   793 ,   873 ,   2341    ,   3505    ,   5751    ,0 };
            const std::uint32_t dim1283JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   7   ,   27  ,   47  ,   123 ,   157 ,   427 ,   273 ,   139 ,   4043    ,   4083    ,   14121   ,0 };
            const std::uint32_t dim1284JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   9   ,   25  ,   17  ,   41  ,   245 ,   441 ,   47  ,   1   ,   2393    ,   405 ,   4021    ,0 };
            const std::uint32_t dim1285JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   13  ,   31  ,   9   ,   115 ,   165 ,   93  ,   701 ,   255 ,   895 ,   995 ,   12371   ,0 };
            const std::uint32_t dim1286JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   11  ,   23  ,   13  ,   9   ,   141 ,   31  ,   973 ,   441 ,   3335    ,   2567    ,   6993    ,0 };
            const std::uint32_t dim1287JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   13  ,   19  ,   25  ,   61  ,   139 ,   39  ,   987 ,   385 ,   2199    ,   7675    ,   13301   ,0 };
            const std::uint32_t dim1288JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   3   ,   1   ,   35  ,   121 ,   187 ,   273 ,   905 ,   245 ,   1031    ,   6203    ,   8165    ,0 };
            const std::uint32_t dim1289JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   13  ,   31  ,   59  ,   97  ,   45  ,   25  ,   803 ,   1245    ,   2659    ,   7471    ,   8367    ,0 };
            const std::uint32_t dim1290JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   11  ,   21  ,   41  ,   47  ,   183 ,   419 ,   279 ,   1901    ,   1081    ,   3575    ,   8591    ,0 };
            const std::uint32_t dim1291JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   5   ,   11  ,   39  ,   119 ,   245 ,   403 ,   703 ,   1547    ,   743 ,   7957    ,   15123   ,0 };
            const std::uint32_t dim1292JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   11  ,   11  ,   31  ,   71  ,   55  ,   3   ,   961 ,   991 ,   1665    ,   5539    ,   8187    ,0 };
            const std::uint32_t dim1293JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   3   ,   19  ,   7   ,   1   ,   35  ,   463 ,   1003    ,   555 ,   669 ,   2119    ,   10939   ,0 };
            const std::uint32_t dim1294JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   13  ,   17  ,   29  ,   99  ,   133 ,   107 ,   907 ,   7   ,   3047    ,   1263    ,   7497    ,0 };
            const std::uint32_t dim1295JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   15  ,   1   ,   53  ,   39  ,   191 ,   201 ,   189 ,   465 ,   453 ,   1967    ,   1033    ,0 };
            const std::uint32_t dim1296JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   13  ,   25  ,   19  ,   5   ,   155 ,   105 ,   923 ,   2045    ,   2889    ,   7685    ,   13847   ,0 };
            const std::uint32_t dim1297JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   13  ,   7   ,   61  ,   93  ,   41  ,   183 ,   783 ,   2011    ,   2967    ,   2949    ,   10247   ,0 };
            const std::uint32_t dim1298JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   9   ,   3   ,   53  ,   105 ,   63  ,   9   ,   131 ,   897 ,   347 ,   7683    ,   16027   ,0 };
            const std::uint32_t dim1299JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   9   ,   19  ,   37  ,   37  ,   143 ,   37  ,   493 ,   533 ,   733 ,   2295    ,   4203    ,0 };
            const std::uint32_t dim1300JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   5   ,   15  ,   23  ,   83  ,   185 ,   495 ,   1023    ,   1473    ,   1501    ,   373 ,   201 ,0 };
            const std::uint32_t dim1301JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   13  ,   31  ,   51  ,   115 ,   233 ,   289 ,   201 ,   869 ,   3177    ,   4649    ,   16111   ,0 };
            const std::uint32_t dim1302JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   5   ,   23  ,   7   ,   59  ,   233 ,   447 ,   781 ,   1249    ,   71  ,   5857    ,   15481   ,0 };
            const std::uint32_t dim1303JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   11  ,   31  ,   1   ,   67  ,   243 ,   129 ,   737 ,   1443    ,   3647    ,   2391    ,   3635    ,0 };
            const std::uint32_t dim1304JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   1   ,   17  ,   39  ,   117 ,   81  ,   395 ,   119 ,   413 ,   1295    ,   7889    ,   13569   ,0 };
            const std::uint32_t dim1305JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   5   ,   29  ,   5   ,   123 ,   89  ,   143 ,   779 ,   1173    ,   3211    ,   3027    ,   10145   ,0 };
            const std::uint32_t dim1306JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   7   ,   19  ,   53  ,   39  ,   199 ,   487 ,   797 ,   123 ,   871 ,   6335    ,   7957    ,0 };
            const std::uint32_t dim1307JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   7   ,   13  ,   11  ,   105 ,   121 ,   403 ,   283 ,   413 ,   1957    ,   6557    ,   8429    ,0 };
            const std::uint32_t dim1308JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   3   ,   23  ,   21  ,   109 ,   37  ,   463 ,   613 ,   927 ,   1857    ,   7003    ,   3477    ,0 };
            const std::uint32_t dim1309JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   1   ,   15  ,   37  ,   81  ,   27  ,   259 ,   661 ,   287 ,   615 ,   6151    ,   13759   ,0 };
            const std::uint32_t dim1310JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   7   ,   27  ,   59  ,   85  ,   223 ,   499 ,   571 ,   1853    ,   1419    ,   7761    ,   8385    ,0 };
            const std::uint32_t dim1311JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   9   ,   23  ,   57  ,   53  ,   163 ,   437 ,   657 ,   851 ,   3177    ,   6477    ,   13003   ,0 };
            const std::uint32_t dim1312JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   13  ,   3   ,   7   ,   37  ,   167 ,   49  ,   595 ,   1493    ,   369 ,   687 ,   13463   ,0 };
            const std::uint32_t dim1313JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   11  ,   27  ,   63  ,   49  ,   157 ,   379 ,   779 ,   99  ,   3457    ,   4477    ,   6531    ,0 };
            const std::uint32_t dim1314JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   1   ,   5   ,   55  ,   77  ,   159 ,   371 ,   369 ,   743 ,   3571    ,   1877    ,   14767   ,0 };
            const std::uint32_t dim1315JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   15  ,   25  ,   11  ,   65  ,   187 ,   253 ,   437 ,   1301    ,   2871    ,   6219    ,   817 ,0 };
            const std::uint32_t dim1316JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   13  ,   23  ,   33  ,   25  ,   49  ,   491 ,   315 ,   11  ,   2163    ,   6155    ,   23  ,0 };
            const std::uint32_t dim1317JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   7   ,   27  ,   31  ,   81  ,   7   ,   355 ,   289 ,   1481    ,   2969    ,   1067    ,   7399    ,0 };
            const std::uint32_t dim1318JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   7   ,   1   ,   57  ,   39  ,   201 ,   271 ,   223 ,   1117    ,   727 ,   7491    ,   4043    ,0 };
            const std::uint32_t dim1319JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   7   ,   9   ,   57  ,   17  ,   161 ,   221 ,   385 ,   2027    ,   1195    ,   2489    ,   12377   ,0 };
            const std::uint32_t dim1320JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   3   ,   27  ,   59  ,   101 ,   27  ,   177 ,   1005    ,   63  ,   3029    ,   7345    ,   14429   ,0 };
            const std::uint32_t dim1321JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   7   ,   17  ,   5   ,   111 ,   239 ,   85  ,   57  ,   1625    ,   657 ,   5931    ,   4929    ,0 };
            const std::uint32_t dim1322JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   3   ,   7   ,   41  ,   29  ,   9   ,   73  ,   875 ,   1665    ,   325 ,   27  ,   997 ,0 };
            const std::uint32_t dim1323JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   7   ,   21  ,   61  ,   119 ,   247 ,   307 ,   1011    ,   1489    ,   2361    ,   5781    ,   2465    ,0 };
            const std::uint32_t dim1324JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   3   ,   1   ,   21  ,   105 ,   77  ,   57  ,   983 ,   1519    ,   3543    ,   5025    ,   14051   ,0 };
            const std::uint32_t dim1325JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   5   ,   13  ,   39  ,   113 ,   69  ,   81  ,   155 ,   101 ,   427 ,   733 ,   10085   ,0 };
            const std::uint32_t dim1326JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   3   ,   1   ,   25  ,   109 ,   109 ,   303 ,   323 ,   565 ,   2267    ,   2755    ,   9165    ,0 };
            const std::uint32_t dim1327JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   3   ,   15  ,   43  ,   103 ,   163 ,   265 ,   849 ,   1969    ,   2247    ,   4495    ,   7301    ,0 };
            const std::uint32_t dim1328JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   3   ,   23  ,   9   ,   81  ,   103 ,   193 ,   845 ,   1603    ,   2493    ,   4919    ,   10649   ,0 };
            const std::uint32_t dim1329JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   1   ,   9   ,   23  ,   91  ,   33  ,   115 ,   599 ,   1755    ,   53  ,   1757    ,   145 ,0 };
            const std::uint32_t dim1330JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   11  ,   1   ,   39  ,   5   ,   233 ,   399 ,   187 ,   943 ,   2325    ,   437 ,   4421    ,0 };
            const std::uint32_t dim1331JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   13  ,   11  ,   39  ,   29  ,   131 ,   363 ,   885 ,   1921    ,   3703    ,   4197    ,   9703    ,0 };
            const std::uint32_t dim1332JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   5   ,   21  ,   43  ,   27  ,   151 ,   193 ,   211 ,   1229    ,   4031    ,   681 ,   5103    ,0 };
            const std::uint32_t dim1333JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   3   ,   19  ,   23  ,   41  ,   47  ,   315 ,   169 ,   271 ,   1877    ,   6357    ,   7709    ,0 };
            const std::uint32_t dim1334JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   1   ,   11  ,   27  ,   123 ,   33  ,   287 ,   293 ,   335 ,   2331    ,   141 ,   10095   ,0 };
            const std::uint32_t dim1335JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   5   ,   15  ,   33  ,   93  ,   123 ,   277 ,   833 ,   115 ,   3799    ,   1519    ,   153 ,0 };
            const std::uint32_t dim1336JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   15  ,   11  ,   3   ,   97  ,   225 ,   179 ,   601 ,   687 ,   253 ,   2839    ,   10985   ,0 };
            const std::uint32_t dim1337JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   3   ,   11  ,   51  ,   5   ,   141 ,   487 ,   325 ,   1691    ,   1291    ,   4677    ,   9087    ,0 };
            const std::uint32_t dim1338JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   9   ,   5   ,   11  ,   99  ,   195 ,   459 ,   171 ,   361 ,   1621    ,   5377    ,   4651    ,0 };
            const std::uint32_t dim1339JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   3   ,   29  ,   47  ,   5   ,   29  ,   107 ,   751 ,   739 ,   2815    ,   3709    ,   15493   ,0 };
            const std::uint32_t dim1340JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   1   ,   3   ,   63  ,   47  ,   15  ,   433 ,   501 ,   1687    ,   2035    ,   6263    ,   12681   ,0 };
            const std::uint32_t dim1341JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   13  ,   1   ,   57  ,   91  ,   33  ,   217 ,   141 ,   2005    ,   2405    ,   1987    ,   14957   ,0 };
            const std::uint32_t dim1342JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   13  ,   25  ,   23  ,   93  ,   37  ,   129 ,   747 ,   1607    ,   849 ,   2119    ,   11855   ,0 };
            const std::uint32_t dim1343JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   9   ,   15  ,   55  ,   55  ,   125 ,   235 ,   455 ,   2027    ,   1709    ,   7217    ,   10341   ,0 };
            const std::uint32_t dim1344JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   7   ,   1   ,   3   ,   69  ,   167 ,   373 ,   87  ,   901 ,   2333    ,   6751    ,   5809    ,0 };
            const std::uint32_t dim1345JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   9   ,   19  ,   25  ,   67  ,   197 ,   395 ,   735 ,   941 ,   1753    ,   3923    ,   8805    ,0 };
            const std::uint32_t dim1346JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   9   ,   17  ,   29  ,   1   ,   205 ,   511 ,   179 ,   1191    ,   17  ,   3179    ,   6891    ,0 };
            const std::uint32_t dim1347JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   9   ,   9   ,   31  ,   99  ,   133 ,   253 ,   239 ,   1729    ,   4093    ,   5759    ,   15357   ,0 };
            const std::uint32_t dim1348JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   3   ,   31  ,   35  ,   125 ,   167 ,   417 ,   431 ,   709 ,   415 ,   1093    ,   11361   ,0 };
            const std::uint32_t dim1349JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   11  ,   7   ,   59  ,   57  ,   89  ,   119 ,   537 ,   1157    ,   2539    ,   5783    ,   15093   ,0 };
            const std::uint32_t dim1350JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   7   ,   17  ,   41  ,   105 ,   33  ,   301 ,   601 ,   537 ,   3877    ,   797 ,   1319    ,0 };
            const std::uint32_t dim1351JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   7   ,   3   ,   59  ,   79  ,   47  ,   191 ,   985 ,   83  ,   3535    ,   4135    ,   16165   ,0 };
            const std::uint32_t dim1352JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   3   ,   13  ,   61  ,   35  ,   193 ,   141 ,   961 ,   1733    ,   4051    ,   2657    ,   9183    ,0 };
            const std::uint32_t dim1353JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   9   ,   25  ,   49  ,   127 ,   233 ,   291 ,   445 ,   1639    ,   4023    ,   4791    ,   279 ,0 };
            const std::uint32_t dim1354JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   11  ,   15  ,   39  ,   91  ,   81  ,   433 ,   7   ,   1897    ,   2659    ,   7877    ,   15733   ,0 };
            const std::uint32_t dim1355JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   5   ,   19  ,   5   ,   125 ,   181 ,   305 ,   377 ,   1699    ,   2157    ,   4617    ,   7165    ,0 };
            const std::uint32_t dim1356JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   13  ,   11  ,   27  ,   19  ,   217 ,   171 ,   343 ,   61  ,   3799    ,   4923    ,   14279   ,0 };
            const std::uint32_t dim1357JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   15  ,   13  ,   41  ,   19  ,   19  ,   359 ,   101 ,   1795    ,   127 ,   7067    ,   4327    ,0 };
            const std::uint32_t dim1358JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   15  ,   15  ,   5   ,   43  ,   47  ,   103 ,   549 ,   767 ,   2695    ,   1689    ,   5569    ,0 };
            const std::uint32_t dim1359JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   9   ,   7   ,   33  ,   35  ,   105 ,   283 ,   957 ,   1255    ,   2085    ,   6263    ,   4537    ,0 };
            const std::uint32_t dim1360JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   9   ,   27  ,   23  ,   49  ,   169 ,   455 ,   163 ,   301 ,   3107    ,   6859    ,   14477   ,0 };
            const std::uint32_t dim1361JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   15  ,   13  ,   11  ,   25  ,   231 ,   171 ,   173 ,   661 ,   1921    ,   3535    ,   10157   ,0 };
            const std::uint32_t dim1362JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   11  ,   27  ,   19  ,   23  ,   97  ,   409 ,   347 ,   1413    ,   2273    ,   7305    ,   12597   ,0 };
            const std::uint32_t dim1363JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   15  ,   11  ,   63  ,   49  ,   247 ,   459 ,   195 ,   1579    ,   539 ,   6283    ,   14829   ,0 };
            const std::uint32_t dim1364JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   5   ,   19  ,   37  ,   105 ,   31  ,   87  ,   413 ,   511 ,   271 ,   6265    ,   9499    ,0 };
            const std::uint32_t dim1365JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   13  ,   23  ,   39  ,   97  ,   239 ,   397 ,   975 ,   1369    ,   2397    ,   409 ,   3495    ,0 };
            const std::uint32_t dim1366JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   1   ,   25  ,   45  ,   11  ,   81  ,   233 ,   299 ,   1269    ,   1129    ,   1679    ,   10195   ,0 };
            const std::uint32_t dim1367JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   5   ,   13  ,   29  ,   3   ,   189 ,   231 ,   535 ,   1201    ,   1215    ,   1889    ,   6169    ,0 };
            const std::uint32_t dim1368JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   15  ,   31  ,   53  ,   17  ,   197 ,   453 ,   13  ,   181 ,   2663    ,   3869    ,   7269    ,0 };
            const std::uint32_t dim1369JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   5   ,   27  ,   37  ,   71  ,   89  ,   505 ,   769 ,   1359    ,   295 ,   6061    ,   8363    ,0 };
            const std::uint32_t dim1370JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   1   ,   9   ,   1   ,   111 ,   157 ,   89  ,   777 ,   1713    ,   117 ,   285 ,   6353    ,0 };
            const std::uint32_t dim1371JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   11  ,   29  ,   53  ,   57  ,   3   ,   225 ,   885 ,   1445    ,   3673    ,   7857    ,   3843    ,0 };
            const std::uint32_t dim1372JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   11  ,   29  ,   23  ,   43  ,   19  ,   175 ,   573 ,   1709    ,   2303    ,   5607    ,   4347    ,0 };
            const std::uint32_t dim1373JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   7   ,   19  ,   41  ,   93  ,   13  ,   3   ,   483 ,   1365    ,   411 ,   5147    ,   10505   ,0 };
            const std::uint32_t dim1374JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   7   ,   3   ,   17  ,   51  ,   23  ,   19  ,   411 ,   741 ,   877 ,   7121    ,   7639    ,0 };
            const std::uint32_t dim1375JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   3   ,   7   ,   45  ,   103 ,   69  ,   387 ,   803 ,   29  ,   1469    ,   2139    ,   6397    ,0 };
            const std::uint32_t dim1376JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   3   ,   11  ,   43  ,   5   ,   19  ,   441 ,   285 ,   1657    ,   2133    ,   6343    ,   11817   ,0 };
            const std::uint32_t dim1377JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   1   ,   31  ,   31  ,   19  ,   15  ,   475 ,   131 ,   1687    ,   1647    ,   4685    ,   1135    ,0 };
            const std::uint32_t dim1378JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   7   ,   17  ,   59  ,   125 ,   127 ,   63  ,   451 ,   949 ,   4041    ,   6649    ,   12187   ,0 };
            const std::uint32_t dim1379JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   1   ,   25  ,   13  ,   59  ,   159 ,   107 ,   509 ,   787 ,   2517    ,   6679    ,   2809    ,0 };
            const std::uint32_t dim1380JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   5   ,   17  ,   5   ,   87  ,   235 ,   379 ,   599 ,   1971    ,   969 ,   853 ,   10481   ,0 };
            const std::uint32_t dim1381JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   15  ,   7   ,   35  ,   47  ,   113 ,   349 ,   451 ,   1827    ,   2647    ,   367 ,   2581    ,0 };
            const std::uint32_t dim1382JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   9   ,   1   ,   39  ,   29  ,   45  ,   365 ,   317 ,   129 ,   137 ,   5975    ,   3353    ,0 };
            const std::uint32_t dim1383JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   15  ,   17  ,   3   ,   5   ,   61  ,   11  ,   587 ,   769 ,   2127    ,   2625    ,   12545   ,0 };
            const std::uint32_t dim1384JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   7   ,   21  ,   1   ,   127 ,   235 ,   343 ,   807 ,   147 ,   3517    ,   3471    ,   4625    ,0 };
            const std::uint32_t dim1385JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   15  ,   31  ,   23  ,   81  ,   23  ,   171 ,   403 ,   1083    ,   4049    ,   1959    ,   16307   ,0 };
            const std::uint32_t dim1386JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   9   ,   21  ,   37  ,   99  ,   83  ,   33  ,   705 ,   369 ,   2445    ,   3253    ,   16171   ,0 };
            const std::uint32_t dim1387JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   9   ,   17  ,   61  ,   121 ,   75  ,   89  ,   823 ,   1519    ,   1997    ,   6433    ,   5013    ,0 };
            const std::uint32_t dim1388JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   11  ,   7   ,   47  ,   7   ,   71  ,   475 ,   517 ,   1271    ,   3815    ,   5969    ,   607 ,0 };
            const std::uint32_t dim1389JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   3   ,   13  ,   15  ,   37  ,   89  ,   43  ,   489 ,   1853    ,   1195    ,   3097    ,   10297   ,0 };
            const std::uint32_t dim1390JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   11  ,   25  ,   39  ,   95  ,   43  ,   145 ,   231 ,   1859    ,   3201    ,   1377    ,   7091    ,0 };
            const std::uint32_t dim1391JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   3   ,   13  ,   43  ,   117 ,   111 ,   231 ,   101 ,   1801    ,   739 ,   945 ,   15585   ,0 };
            const std::uint32_t dim1392JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   7   ,   23  ,   3   ,   35  ,   167 ,   485 ,   951 ,   1729    ,   1831    ,   2639    ,   6561    ,0 };
            const std::uint32_t dim1393JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   15  ,   5   ,   31  ,   103 ,   85  ,   111 ,   545 ,   789 ,   945 ,   2691    ,   327 ,0 };
            const std::uint32_t dim1394JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   11  ,   29  ,   61  ,   127 ,   59  ,   137 ,   485 ,   1673    ,   3295    ,   4185    ,   6489    ,0 };
            const std::uint32_t dim1395JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   9   ,   31  ,   9   ,   115 ,   11  ,   73  ,   267 ,   195 ,   1445    ,   873 ,   7285    ,0 };
            const std::uint32_t dim1396JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   7   ,   3   ,   19  ,   9   ,   71  ,   287 ,   89  ,   329 ,   953 ,   2237    ,   16341   ,0 };
            const std::uint32_t dim1397JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   13  ,   19  ,   31  ,   5   ,   49  ,   293 ,   65  ,   291 ,   93  ,   2553    ,   8407    ,0 };
            const std::uint32_t dim1398JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   15  ,   17  ,   13  ,   15  ,   111 ,   211 ,   935 ,   1165    ,   2975    ,   339 ,   16333   ,0 };
            const std::uint32_t dim1399JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   3   ,   17  ,   57  ,   9   ,   63  ,   243 ,   431 ,   289 ,   3493    ,   2879    ,   4801    ,0 };
            const std::uint32_t dim1400JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   3   ,   17  ,   15  ,   53  ,   191 ,   439 ,   981 ,   751 ,   4025    ,   7177    ,   4887    ,0 };
            const std::uint32_t dim1401JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   3   ,   11  ,   61  ,   43  ,   103 ,   151 ,   33  ,   421 ,   1949    ,   5915    ,   5515    ,0 };
            const std::uint32_t dim1402JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   3   ,   1   ,   55  ,   45  ,   227 ,   27  ,   491 ,   1479    ,   3323    ,   5485    ,   5493    ,0 };
            const std::uint32_t dim1403JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   1   ,   9   ,   11  ,   1   ,   249 ,   113 ,   415 ,   295 ,   3437    ,   3877    ,   6675    ,0 };
            const std::uint32_t dim1404JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   11  ,   9   ,   43  ,   127 ,   57  ,   115 ,   685 ,   165 ,   973 ,   2707    ,   2503    ,0 };
            const std::uint32_t dim1405JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   7   ,   1   ,   29  ,   125 ,   45  ,   307 ,   625 ,   1477    ,   2565    ,   2949    ,   1729    ,0 };
            const std::uint32_t dim1406JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   1   ,   23  ,   7   ,   45  ,   245 ,   301 ,   531 ,   1419    ,   1795    ,   5757    ,   15219   ,0 };
            const std::uint32_t dim1407JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   7   ,   15  ,   49  ,   71  ,   109 ,   145 ,   79  ,   1333    ,   1589    ,   3851    ,   2879    ,0 };
            const std::uint32_t dim1408JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   5   ,   11  ,   15  ,   37  ,   239 ,   217 ,   193 ,   1687    ,   1721    ,   8059    ,   9027    ,0 };
            const std::uint32_t dim1409JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   13  ,   13  ,   49  ,   57  ,   189 ,   433 ,   569 ,   1285    ,   1891    ,   6079    ,   13469   ,0 };
            const std::uint32_t dim1410JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   1   ,   19  ,   61  ,   27  ,   181 ,   365 ,   121 ,   883 ,   1611    ,   1521    ,   11437   ,0 };
            const std::uint32_t dim1411JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   3   ,   17  ,   37  ,   71  ,   71  ,   495 ,   519 ,   879 ,   2993    ,   6275    ,   14345   ,0 };
            const std::uint32_t dim1412JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   5   ,   29  ,   5   ,   121 ,   29  ,   293 ,   745 ,   1839    ,   2061    ,   2721    ,   11741   ,0 };
            const std::uint32_t dim1413JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   13  ,   23  ,   61  ,   55  ,   99  ,   409 ,   211 ,   783 ,   1841    ,   193 ,   1941    ,0 };
            const std::uint32_t dim1414JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   7   ,   11  ,   49  ,   87  ,   81  ,   225 ,   211 ,   1263    ,   1403    ,   6169    ,   6235    ,0 };
            const std::uint32_t dim1415JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   9   ,   11  ,   35  ,   71  ,   145 ,   417 ,   485 ,   1565    ,   2101    ,   4153    ,   5239    ,0 };
            const std::uint32_t dim1416JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   1   ,   13  ,   41  ,   45  ,   79  ,   157 ,   477 ,   677 ,   3961    ,   1127    ,   1139    ,0 };
            const std::uint32_t dim1417JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   13  ,   27  ,   39  ,   23  ,   197 ,   123 ,   431 ,   273 ,   2723    ,   1303    ,   13271   ,0 };
            const std::uint32_t dim1418JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   9   ,   13  ,   21  ,   59  ,   109 ,   267 ,   173 ,   997 ,   2701    ,   3719    ,   3703    ,0 };
            const std::uint32_t dim1419JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   1   ,   1   ,   5   ,   57  ,   181 ,   241 ,   1   ,   1063    ,   199 ,   8181    ,   12721   ,0 };
            const std::uint32_t dim1420JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   9   ,   15  ,   61  ,   107 ,   231 ,   65  ,   933 ,   677 ,   3883    ,   2621    ,   8821    ,0 };
            const std::uint32_t dim1421JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   1   ,   9   ,   33  ,   41  ,   55  ,   503 ,   683 ,   747 ,   3619    ,   7885    ,   851 ,0 };
            const std::uint32_t dim1422JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   5   ,   9   ,   25  ,   27  ,   123 ,   97  ,   731 ,   583 ,   2535    ,   1267    ,   5921    ,0 };
            const std::uint32_t dim1423JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   15  ,   27  ,   63  ,   69  ,   99  ,   475 ,   709 ,   1239    ,   861 ,   1229    ,   11369   ,0 };
            const std::uint32_t dim1424JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   13  ,   17  ,   47  ,   123 ,   159 ,   57  ,   871 ,   465 ,   783 ,   4093    ,   15277   ,0 };
            const std::uint32_t dim1425JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   9   ,   17  ,   47  ,   89  ,   139 ,   301 ,   45  ,   627 ,   4073    ,   3187    ,   9633    ,0 };
            const std::uint32_t dim1426JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   11  ,   21  ,   43  ,   19  ,   25  ,   457 ,   879 ,   113 ,   847 ,   201 ,   15683   ,0 };
            const std::uint32_t dim1427JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   15  ,   9   ,   47  ,   43  ,   215 ,   407 ,   979 ,   51  ,   635 ,   467 ,   6365    ,0 };
            const std::uint32_t dim1428JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   5   ,   7   ,   11  ,   53  ,   5   ,   471 ,   317 ,   1719    ,   755 ,   5211    ,   7599    ,0 };
            const std::uint32_t dim1429JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   3   ,   11  ,   43  ,   67  ,   203 ,   15  ,   75  ,   1063    ,   1763    ,   3537    ,   13511   ,0 };
            const std::uint32_t dim1430JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   1   ,   17  ,   37  ,   91  ,   55  ,   95  ,   843 ,   751 ,   3501    ,   6203    ,   2999    ,0 };
            const std::uint32_t dim1431JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   13  ,   19  ,   61  ,   37  ,   157 ,   309 ,   361 ,   1499    ,   1845    ,   3675    ,   6221    ,0 };
            const std::uint32_t dim1432JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   11  ,   15  ,   9   ,   25  ,   123 ,   25  ,   525 ,   227 ,   3429    ,   1573    ,   12321   ,0 };
            const std::uint32_t dim1433JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   11  ,   9   ,   17  ,   91  ,   61  ,   263 ,   129 ,   1853    ,   1911    ,   5065    ,   775 ,0 };
            const std::uint32_t dim1434JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   3   ,   31  ,   15  ,   3   ,   207 ,   505 ,   123 ,   477 ,   1285    ,   7007    ,   2873    ,0 };
            const std::uint32_t dim1435JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   7   ,   7   ,   15  ,   123 ,   249 ,   467 ,   229 ,   845 ,   1913    ,   461 ,   6235    ,0 };
            const std::uint32_t dim1436JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   9   ,   15  ,   9   ,   121 ,   211 ,   231 ,   491 ,   521 ,   3621    ,   7285    ,   3165    ,0 };
            const std::uint32_t dim1437JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   15  ,   21  ,   43  ,   1   ,   35  ,   339 ,   671 ,   719 ,   1739    ,   501 ,   9573    ,0 };
            const std::uint32_t dim1438JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   5   ,   13  ,   37  ,   81  ,   1   ,   281 ,   785 ,   831 ,   991 ,   7485    ,   15619   ,0 };
            const std::uint32_t dim1439JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   1   ,   29  ,   47  ,   29  ,   99  ,   311 ,   519 ,   545 ,   1115    ,   6651    ,   793 ,0 };
            const std::uint32_t dim1440JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   11  ,   17  ,   15  ,   17  ,   65  ,   101 ,   411 ,   231 ,   2959    ,   8077    ,   673 ,0 };
            const std::uint32_t dim1441JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   9   ,   27  ,   47  ,   127 ,   237 ,   319 ,   293 ,   1109    ,   3863    ,   213 ,   2149    ,0 };
            const std::uint32_t dim1442JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   13  ,   11  ,   61  ,   27  ,   129 ,   57  ,   743 ,   889 ,   3707    ,   469 ,   11949   ,0 };
            const std::uint32_t dim1443JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   13  ,   23  ,   13  ,   119 ,   125 ,   75  ,   753 ,   1951    ,   1181    ,   291 ,   11737   ,0 };
            const std::uint32_t dim1444JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   5   ,   31  ,   19  ,   43  ,   113 ,   309 ,   721 ,   175 ,   1041    ,   7123    ,   103 ,0 };
            const std::uint32_t dim1445JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   9   ,   21  ,   19  ,   71  ,   175 ,   309 ,   9   ,   807 ,   961 ,   6741    ,   5075    ,0 };
            const std::uint32_t dim1446JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   9   ,   15  ,   27  ,   83  ,   207 ,   67  ,   71  ,   289 ,   2901    ,   7637    ,   9525    ,0 };
            const std::uint32_t dim1447JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   15  ,   21  ,   9   ,   19  ,   67  ,   401 ,   165 ,   1297    ,   3159    ,   2881    ,   15979   ,0 };
            const std::uint32_t dim1448JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   1   ,   11  ,   21  ,   27  ,   33  ,   95  ,   853 ,   1699    ,   875 ,   6519    ,   9109    ,0 };
            const std::uint32_t dim1449JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   3   ,   31  ,   5   ,   123 ,   215 ,   165 ,   405 ,   623 ,   845 ,   4149    ,   5015    ,0 };
            const std::uint32_t dim1450JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   7   ,   31  ,   13  ,   23  ,   55  ,   129 ,   789 ,   803 ,   2077    ,   1885    ,   1669    ,0 };
            const std::uint32_t dim1451JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   11  ,   31  ,   39  ,   93  ,   7   ,   485 ,   571 ,   417 ,   3839    ,   1289    ,   4127    ,0 };
            const std::uint32_t dim1452JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   11  ,   23  ,   63  ,   123 ,   249 ,   75  ,   515 ,   2009    ,   949 ,   3291    ,   727 ,0 };
            const std::uint32_t dim1453JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   13  ,   21  ,   15  ,   57  ,   235 ,   25  ,   507 ,   1055    ,   3161    ,   4351    ,   8855    ,0 };
            const std::uint32_t dim1454JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   7   ,   23  ,   39  ,   71  ,   151 ,   377 ,   469 ,   665 ,   1197    ,   3503    ,   655 ,0 };
            const std::uint32_t dim1455JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   3   ,   5   ,   35  ,   67  ,   203 ,   33  ,   319 ,   925 ,   1021    ,   6869    ,   5145    ,0 };
            const std::uint32_t dim1456JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   3   ,   21  ,   61  ,   119 ,   195 ,   383 ,   573 ,   135 ,   2371    ,   1665    ,   4957    ,0 };
            const std::uint32_t dim1457JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   1   ,   7   ,   47  ,   93  ,   201 ,   269 ,   329 ,   209 ,   1659    ,   1547    ,   4605    ,0 };
            const std::uint32_t dim1458JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   1   ,   9   ,   47  ,   71  ,   13  ,   451 ,   51  ,   1073    ,   3691    ,   6881    ,   14801   ,0 };
            const std::uint32_t dim1459JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   3   ,   13  ,   33  ,   75  ,   155 ,   283 ,   599 ,   517 ,   2251    ,   6217    ,   10487   ,0 };
            const std::uint32_t dim1460JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   3   ,   7   ,   49  ,   65  ,   235 ,   159 ,   733 ,   939 ,   283 ,   6935    ,   14367   ,0 };
            const std::uint32_t dim1461JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   13  ,   7   ,   19  ,   71  ,   227 ,   307 ,   515 ,   1701    ,   747 ,   3475    ,   8165    ,0 };
            const std::uint32_t dim1462JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   11  ,   13  ,   19  ,   1   ,   97  ,   425 ,   739 ,   451 ,   3789    ,   5337    ,   2023    ,0 };
            const std::uint32_t dim1463JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   9   ,   7   ,   27  ,   23  ,   169 ,   137 ,   537 ,   61  ,   2207    ,   917 ,   1209    ,0 };
            const std::uint32_t dim1464JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   3   ,   29  ,   5   ,   121 ,   197 ,   159 ,   467 ,   581 ,   1679    ,   6605    ,   1989    ,0 };
            const std::uint32_t dim1465JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   13  ,   5   ,   33  ,   61  ,   77  ,   383 ,   977 ,   781 ,   175 ,   8151    ,   7979    ,0 };
            const std::uint32_t dim1466JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   13  ,   1   ,   1   ,   3   ,   95  ,   193 ,   453 ,   649 ,   1137    ,   485 ,   14345   ,0 };
            const std::uint32_t dim1467JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   7   ,   1   ,   13  ,   41  ,   159 ,   327 ,   105 ,   1569    ,   475 ,   1295    ,   3767    ,0 };
            const std::uint32_t dim1468JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   3   ,   25  ,   7   ,   73  ,   235 ,   271 ,   491 ,   1385    ,   2567    ,   1463    ,   12731   ,0 };
            const std::uint32_t dim1469JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   1   ,   9   ,   9   ,   37  ,   199 ,   249 ,   9   ,   299 ,   3891    ,   2373    ,   11553   ,0 };
            const std::uint32_t dim1470JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   13  ,   19  ,   47  ,   81  ,   25  ,   125 ,   933 ,   1637    ,   469 ,   6351    ,   4219    ,0 };
            const std::uint32_t dim1471JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   7   ,   31  ,   5   ,   67  ,   13  ,   63  ,   615 ,   1089    ,   2291    ,   3105    ,   7009    ,0 };
            const std::uint32_t dim1472JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   1   ,   1   ,   43  ,   49  ,   141 ,   189 ,   1015    ,   1527    ,   1511    ,   3093    ,   5497    ,0 };
            const std::uint32_t dim1473JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   1   ,   3   ,   51  ,   121 ,   89  ,   161 ,   517 ,   467 ,   2837    ,   2275    ,   4987    ,0 };
            const std::uint32_t dim1474JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   13  ,   9   ,   63  ,   31  ,   109 ,   331 ,   607 ,   1271    ,   3639    ,   617 ,   13177   ,0 };
            const std::uint32_t dim1475JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   15  ,   9   ,   25  ,   73  ,   237 ,   145 ,   885 ,   1945    ,   1871    ,   5401    ,   15403   ,0 };
            const std::uint32_t dim1476JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   5   ,   1   ,   63  ,   29  ,   145 ,   377 ,   429 ,   1663    ,   1643    ,   2713    ,   6621    ,0 };
            const std::uint32_t dim1477JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   5   ,   29  ,   7   ,   87  ,   53  ,   129 ,   503 ,   961 ,   3535    ,   3255    ,   7621    ,0 };
            const std::uint32_t dim1478JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   1   ,   5   ,   47  ,   13  ,   243 ,   155 ,   863 ,   103 ,   1699    ,   5063    ,   8221    ,0 };
            const std::uint32_t dim1479JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   9   ,   31  ,   61  ,   1   ,   253 ,   67  ,   369 ,   521 ,   3429    ,   6935    ,   3383    ,0 };
            const std::uint32_t dim1480JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   3   ,   11  ,   61  ,   11  ,   187 ,   145 ,   7   ,   535 ,   831 ,   933 ,   7779    ,0 };
            const std::uint32_t dim1481JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   1   ,   25  ,   33  ,   117 ,   161 ,   169 ,   33  ,   1415    ,   1493    ,   1599    ,   1109    ,0 };
            const std::uint32_t dim1482JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   3   ,   29  ,   19  ,   75  ,   143 ,   467 ,   785 ,   455 ,   2593    ,   7539    ,   6283    ,0 };
            const std::uint32_t dim1483JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   15  ,   11  ,   5   ,   19  ,   187 ,   357 ,   955 ,   631 ,   3697    ,   4641    ,   14353   ,0 };
            const std::uint32_t dim1484JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   15  ,   3   ,   21  ,   25  ,   79  ,   375 ,   611 ,   915 ,   2491    ,   5691    ,   773 ,0 };
            const std::uint32_t dim1485JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   7   ,   29  ,   23  ,   7   ,   27  ,   207 ,   157 ,   1021    ,   2411    ,   5061    ,   7493    ,0 };
            const std::uint32_t dim1486JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   5   ,   13  ,   7   ,   7   ,   159 ,   393 ,   51  ,   1573    ,   1353    ,   2373    ,   12721   ,0 };
            const std::uint32_t dim1487JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   13  ,   5   ,   55  ,   43  ,   7   ,   411 ,   353 ,   379 ,   2213    ,   6257    ,   5825    ,0 };
            const std::uint32_t dim1488JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   1   ,   5   ,   37  ,   65  ,   69  ,   251 ,   893 ,   1747    ,   4065    ,   3937    ,   1855    ,0 };
            const std::uint32_t dim1489JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   1   ,   3   ,   11  ,   97  ,   111 ,   509 ,   569 ,   839 ,   2431    ,   3475    ,   12283   ,0 };
            const std::uint32_t dim1490JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   11  ,   13  ,   63  ,   85  ,   193 ,   351 ,   491 ,   205 ,   1051    ,   403 ,   1749    ,0 };
            const std::uint32_t dim1491JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   1   ,   27  ,   61  ,   61  ,   169 ,   189 ,   549 ,   1589    ,   3567    ,   7301    ,   12723   ,0 };
            const std::uint32_t dim1492JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   7   ,   13  ,   39  ,   121 ,   75  ,   261 ,   919 ,   1557    ,   635 ,   2123    ,   3771    ,0 };
            const std::uint32_t dim1493JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   13  ,   7   ,   39  ,   107 ,   109 ,   165 ,   91  ,   1049    ,   3897    ,   1395    ,   9573    ,0 };
            const std::uint32_t dim1494JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   5   ,   19  ,   9   ,   61  ,   209 ,   205 ,   363 ,   823 ,   2445    ,   7301    ,   7141    ,0 };
            const std::uint32_t dim1495JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   15  ,   5   ,   31  ,   13  ,   61  ,   153 ,   847 ,   67  ,   2227    ,   4119    ,   9231    ,0 };
            const std::uint32_t dim1496JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   9   ,   13  ,   63  ,   93  ,   199 ,   437 ,   319 ,   735 ,   2015    ,   1719    ,   3253    ,0 };
            const std::uint32_t dim1497JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   5   ,   31  ,   19  ,   27  ,   141 ,   357 ,   647 ,   895 ,   345 ,   5937    ,   15711   ,0 };
            const std::uint32_t dim1498JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   1   ,   15  ,   35  ,   73  ,   69  ,   205 ,   545 ,   387 ,   3487    ,   7391    ,   3337    ,0 };
            const std::uint32_t dim1499JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   5   ,   27  ,   55  ,   51  ,   179 ,   125 ,   1013    ,   35  ,   2741    ,   7793    ,   4347    ,0 };
            const std::uint32_t dim1500JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   9   ,   31  ,   57  ,   55  ,   3   ,   385 ,   421 ,   1543    ,   2809    ,   1887    ,   13709   ,0 };
            const std::uint32_t dim1501JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   7   ,   29  ,   23  ,   115 ,   25  ,   295 ,   267 ,   101 ,   3005    ,   2601    ,   4959    ,0 };
            const std::uint32_t dim1502JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   13  ,   27  ,   11  ,   11  ,   35  ,   257 ,   23  ,   2013    ,   1369    ,   6503    ,   2589    ,0 };
            const std::uint32_t dim1503JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   15  ,   5   ,   43  ,   101 ,   87  ,   231 ,   761 ,   1991    ,   3167    ,   5689    ,   9565    ,0 };
            const std::uint32_t dim1504JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   11  ,   17  ,   37  ,   65  ,   249 ,   119 ,   727 ,   793 ,   929 ,   6275    ,   12173   ,0 };
            const std::uint32_t dim1505JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   9   ,   1   ,   11  ,   93  ,   27  ,   291 ,   411 ,   1069    ,   1283    ,   7593    ,   4335    ,0 };
            const std::uint32_t dim1506JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   1   ,   23  ,   45  ,   51  ,   93  ,   401 ,   515 ,   749 ,   1293    ,   8155    ,   15123   ,0 };
            const std::uint32_t dim1507JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   3   ,   21  ,   17  ,   67  ,   69  ,   371 ,   507 ,   143 ,   2393    ,   6267    ,   7143    ,0 };
            const std::uint32_t dim1508JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   11  ,   1   ,   5   ,   79  ,   75  ,   361 ,   689 ,   339 ,   1855    ,   6863    ,   15841   ,0 };
            const std::uint32_t dim1509JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   13  ,   23  ,   3   ,   43  ,   57  ,   233 ,   927 ,   1095    ,   1827    ,   401 ,   825 ,0 };
            const std::uint32_t dim1510JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   9   ,   31  ,   7   ,   67  ,   201 ,   27  ,   699 ,   535 ,   3073    ,   6895    ,   3021    ,0 };
            const std::uint32_t dim1511JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   13  ,   1   ,   19  ,   13  ,   83  ,   221 ,   727 ,   745 ,   2131    ,   3757    ,   1493    ,0 };
            const std::uint32_t dim1512JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   9   ,   13  ,   29  ,   101 ,   255 ,   243 ,   763 ,   535 ,   169 ,   1987    ,   4071    ,0 };
            const std::uint32_t dim1513JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   3   ,   21  ,   33  ,   117 ,   213 ,   143 ,   351 ,   1735    ,   1651    ,   5781    ,   8803    ,0 };
            const std::uint32_t dim1514JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   7   ,   17  ,   39  ,   57  ,   209 ,   141 ,   865 ,   1731    ,   3349    ,   7107    ,   15983   ,0 };
            const std::uint32_t dim1515JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   3   ,   21  ,   33  ,   117 ,   201 ,   481 ,   711 ,   1207    ,   1971    ,   3353    ,   5827    ,0 };
            const std::uint32_t dim1516JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   13  ,   13  ,   1   ,   121 ,   115 ,   449 ,   801 ,   1507    ,   2323    ,   6709    ,   5533    ,0 };
            const std::uint32_t dim1517JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   7   ,   5   ,   5   ,   35  ,   81  ,   469 ,   691 ,   443 ,   501 ,   6745    ,   421 ,0 };
            const std::uint32_t dim1518JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   13  ,   27  ,   41  ,   83  ,   39  ,   349 ,   585 ,   551 ,   643 ,   6659    ,   61  ,0 };
            const std::uint32_t dim1519JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   3   ,   25  ,   41  ,   45  ,   203 ,   89  ,   305 ,   1433    ,   1879    ,   6703    ,   14323   ,0 };
            const std::uint32_t dim1520JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   15  ,   27  ,   37  ,   97  ,   117 ,   431 ,   197 ,   807 ,   1841    ,   8075    ,   4613    ,0 };
            const std::uint32_t dim1521JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   3   ,   23  ,   47  ,   69  ,   129 ,   451 ,   113 ,   1397    ,   3005    ,   7599    ,   101 ,0 };
            const std::uint32_t dim1522JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   1   ,   11  ,   47  ,   117 ,   181 ,   85  ,   545 ,   571 ,   3227    ,   4097    ,   7937    ,0 };
            const std::uint32_t dim1523JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   9   ,   27  ,   53  ,   11  ,   181 ,   177 ,   121 ,   363 ,   2751    ,   4799    ,   14215   ,0 };
            const std::uint32_t dim1524JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   15  ,   27  ,   15  ,   101 ,   229 ,   411 ,   947 ,   189 ,   119 ,   6707    ,   5177    ,0 };
            const std::uint32_t dim1525JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   7   ,   29  ,   39  ,   65  ,   149 ,   185 ,   915 ,   889 ,   1651    ,   5977    ,   273 ,0 };
            const std::uint32_t dim1526JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   7   ,   7   ,   45  ,   113 ,   203 ,   459 ,   747 ,   1577    ,   2247    ,   5005    ,   2375    ,0 };
            const std::uint32_t dim1527JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   9   ,   9   ,   5   ,   63  ,   83  ,   193 ,   363 ,   257 ,   4075    ,   7497    ,   4579    ,0 };
            const std::uint32_t dim1528JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   15  ,   1   ,   55  ,   107 ,   161 ,   471 ,   245 ,   1303    ,   1821    ,   3395    ,   8957    ,0 };
            const std::uint32_t dim1529JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   15  ,   5   ,   17  ,   83  ,   215 ,   467 ,   489 ,   827 ,   1951    ,   3753    ,   13333   ,0 };
            const std::uint32_t dim1530JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   11  ,   27  ,   31  ,   89  ,   55  ,   445 ,   489 ,   1171    ,   107 ,   1479    ,   1389    ,0 };
            const std::uint32_t dim1531JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   15  ,   21  ,   23  ,   51  ,   21  ,   129 ,   349 ,   195 ,   2177    ,   529 ,   5479    ,0 };
            const std::uint32_t dim1532JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   5   ,   15  ,   31  ,   99  ,   169 ,   299 ,   21  ,   1379    ,   3845    ,   4991    ,   8755    ,0 };
            const std::uint32_t dim1533JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   3   ,   23  ,   29  ,   47  ,   219 ,   289 ,   559 ,   393 ,   793 ,   3217    ,   12103   ,0 };
            const std::uint32_t dim1534JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   15  ,   5   ,   13  ,   107 ,   119 ,   159 ,   421 ,   243 ,   3231    ,   5331    ,   14511   ,0 };
            const std::uint32_t dim1535JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   13  ,   13  ,   9   ,   1   ,   99  ,   7   ,   743 ,   1125    ,   2969    ,   1205    ,   2963    ,0 };
            const std::uint32_t dim1536JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   15  ,   5   ,   1   ,   25  ,   101 ,   397 ,   75  ,   141 ,   3503    ,   3003    ,   11363   ,0 };
            const std::uint32_t dim1537JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   1   ,   21  ,   25  ,   55  ,   7   ,   189 ,   599 ,   1071    ,   343 ,   2877    ,   5131    ,0 };
            const std::uint32_t dim1538JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   7   ,   13  ,   25  ,   113 ,   175 ,   31  ,   265 ,   1901    ,   1779    ,   1787    ,   14551   ,0 };
            const std::uint32_t dim1539JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   13  ,   31  ,   53  ,   69  ,   49  ,   281 ,   57  ,   1865    ,   3211    ,   5545    ,   12597   ,0 };
            const std::uint32_t dim1540JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   11  ,   3   ,   51  ,   99  ,   23  ,   303 ,   455 ,   2021    ,   2903    ,   2521    ,   10211   ,0 };
            const std::uint32_t dim1541JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   3   ,   17  ,   49  ,   55  ,   147 ,   177 ,   515 ,   1333    ,   3357    ,   6483    ,   4599    ,0 };
            const std::uint32_t dim1542JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   1   ,   31  ,   3   ,   1   ,   15  ,   263 ,   1007    ,   1377    ,   1245    ,   313 ,   10227   ,0 };
            const std::uint32_t dim1543JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   3   ,   21  ,   7   ,   61  ,   201 ,   95  ,   407 ,   661 ,   2159    ,   3255    ,   5749    ,0 };
            const std::uint32_t dim1544JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   9   ,   13  ,   31  ,   65  ,   135 ,   117 ,   737 ,   1165    ,   2305    ,   5347    ,   2739    ,0 };
            const std::uint32_t dim1545JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   3   ,   25  ,   49  ,   63  ,   115 ,   65  ,   693 ,   1211    ,   763 ,   6949    ,   11655   ,0 };
            const std::uint32_t dim1546JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   5   ,   13  ,   37  ,   15  ,   61  ,   175 ,   377 ,   765 ,   269 ,   1363    ,   8199    ,0 };
            const std::uint32_t dim1547JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   7   ,   27  ,   27  ,   113 ,   131 ,   207 ,   921 ,   1051    ,   2205    ,   1197    ,   16233   ,0 };
            const std::uint32_t dim1548JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   7   ,   5   ,   19  ,   115 ,   95  ,   93  ,   87  ,   1379    ,   3295    ,   5211    ,   9113    ,0 };
            const std::uint32_t dim1549JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   11  ,   21  ,   19  ,   9   ,   39  ,   101 ,   5   ,   1903    ,   1067    ,   2845    ,   2025    ,0 };
            const std::uint32_t dim1550JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   9   ,   31  ,   5   ,   39  ,   23  ,   505 ,   563 ,   1445    ,   1177    ,   1485    ,   13551   ,0 };
            const std::uint32_t dim1551JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   3   ,   31  ,   57  ,   107 ,   241 ,   361 ,   353 ,   699 ,   171 ,   5211    ,   2235    ,0 };
            const std::uint32_t dim1552JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   5   ,   15  ,   7   ,   115 ,   119 ,   157 ,   293 ,   827 ,   3249    ,   3463    ,   11873   ,0 };
            const std::uint32_t dim1553JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   3   ,   11  ,   15  ,   17  ,   195 ,   257 ,   31  ,   1207    ,   549 ,   7807    ,   14135   ,0 };
            const std::uint32_t dim1554JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   7   ,   25  ,   59  ,   37  ,   205 ,   507 ,   855 ,   303 ,   683 ,   4277    ,   9387    ,0 };
            const std::uint32_t dim1555JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   1   ,   25  ,   1   ,   121 ,   29  ,   485 ,   707 ,   319 ,   3717    ,   2741    ,   5241    ,0 };
            const std::uint32_t dim1556JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   3   ,   15  ,   55  ,   107 ,   227 ,   129 ,   1011    ,   319 ,   713 ,   5263    ,   7865    ,0 };
            const std::uint32_t dim1557JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   5   ,   17  ,   11  ,   7   ,   107 ,   21  ,   349 ,   1101    ,   3279    ,   5541    ,   12485   ,0 };
            const std::uint32_t dim1558JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   13  ,   25  ,   9   ,   45  ,   149 ,   187 ,   229 ,   671 ,   1219    ,   5171    ,   2073    ,0 };
            const std::uint32_t dim1559JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   11  ,   17  ,   49  ,   23  ,   7   ,   219 ,   639 ,   1497    ,   3103    ,   3047    ,   7723    ,0 };
            const std::uint32_t dim1560JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   5   ,   13  ,   5   ,   3   ,   249 ,   429 ,   289 ,   625 ,   325 ,   1257    ,   16251   ,0 };
            const std::uint32_t dim1561JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   1   ,   17  ,   21  ,   31  ,   11  ,   189 ,   73  ,   583 ,   2843    ,   1873    ,   1215    ,0 };
            const std::uint32_t dim1562JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   9   ,   25  ,   61  ,   123 ,   251 ,   485 ,   543 ,   1851    ,   2827    ,   397 ,   7313    ,0 };
            const std::uint32_t dim1563JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   9   ,   29  ,   59  ,   103 ,   159 ,   295 ,   227 ,   1127    ,   1905    ,   4121    ,   3233    ,0 };
            const std::uint32_t dim1564JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   15  ,   17  ,   55  ,   7   ,   1   ,   381 ,   33  ,   39  ,   485 ,   3967    ,   4401    ,0 };
            const std::uint32_t dim1565JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   3   ,   5   ,   29  ,   7   ,   95  ,   191 ,   23  ,   1205    ,   2427    ,   5439    ,   12585   ,0 };
            const std::uint32_t dim1566JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   9   ,   27  ,   9   ,   73  ,   195 ,   225 ,   597 ,   683 ,   3335    ,   6341    ,   10527   ,0 };
            const std::uint32_t dim1567JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   5   ,   13  ,   15  ,   83  ,   41  ,   241 ,   833 ,   1253    ,   3389    ,   2927    ,   2629    ,0 };
            const std::uint32_t dim1568JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   11  ,   25  ,   55  ,   23  ,   249 ,   151 ,   123 ,   667 ,   3835    ,   2215    ,   6189    ,0 };
            const std::uint32_t dim1569JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   13  ,   31  ,   43  ,   91  ,   181 ,   509 ,   453 ,   171 ,   2883    ,   1247    ,   5105    ,0 };
            const std::uint32_t dim1570JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   15  ,   3   ,   17  ,   59  ,   127 ,   173 ,   343 ,   901 ,   3419    ,   4755    ,   12367   ,0 };
            const std::uint32_t dim1571JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   9   ,   15  ,   49  ,   119 ,   1   ,   183 ,   1021    ,   561 ,   2405    ,   4093    ,   963 ,0 };
            const std::uint32_t dim1572JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   15  ,   21  ,   61  ,   63  ,   119 ,   11  ,   695 ,   1591    ,   2175    ,   5143    ,   10491   ,0 };
            const std::uint32_t dim1573JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   15  ,   27  ,   23  ,   91  ,   131 ,   23  ,   891 ,   1033    ,   1341    ,   1747    ,   12085   ,0 };
            const std::uint32_t dim1574JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   9   ,   11  ,   1   ,   35  ,   189 ,   131 ,   617 ,   417 ,   3347    ,   3995    ,   11723   ,0 };
            const std::uint32_t dim1575JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   3   ,   31  ,   35  ,   113 ,   83  ,   27  ,   399 ,   1615    ,   47  ,   1455    ,   4163    ,0 };
            const std::uint32_t dim1576JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   5   ,   29  ,   61  ,   103 ,   105 ,   495 ,   495 ,   1751    ,   2035    ,   7827    ,   11193   ,0 };
            const std::uint32_t dim1577JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   11  ,   29  ,   35  ,   125 ,   193 ,   59  ,   15  ,   1319    ,   1169    ,   3789    ,   2003    ,0 };
            const std::uint32_t dim1578JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   9   ,   27  ,   9   ,   33  ,   197 ,   65  ,   191 ,   783 ,   3685    ,   7505    ,   13407   ,0 };
            const std::uint32_t dim1579JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   1   ,   1   ,   35  ,   97  ,   55  ,   259 ,   477 ,   1835    ,   3083    ,   7879    ,   4701    ,0 };
            const std::uint32_t dim1580JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   11  ,   5   ,   31  ,   5   ,   125 ,   393 ,   317 ,   1577    ,   3741    ,   3823    ,   12447   ,0 };
            const std::uint32_t dim1581JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   13  ,   9   ,   59  ,   81  ,   85  ,   233 ,   465 ,   239 ,   1525    ,   3095    ,   5793    ,0 };
            const std::uint32_t dim1582JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   1   ,   9   ,   49  ,   49  ,   239 ,   81  ,   475 ,   799 ,   2999    ,   2985    ,   11587   ,0 };
            const std::uint32_t dim1583JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   5   ,   27  ,   55  ,   43  ,   149 ,   191 ,   325 ,   2035    ,   1645    ,   2153    ,   13237   ,0 };
            const std::uint32_t dim1584JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   15  ,   27  ,   59  ,   5   ,   49  ,   277 ,   75  ,   1759    ,   2753    ,   95  ,   2959    ,0 };
            const std::uint32_t dim1585JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   1   ,   21  ,   57  ,   119 ,   35  ,   457 ,   137 ,   1877    ,   2613    ,   4209    ,   9669    ,0 };
            const std::uint32_t dim1586JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   1   ,   25  ,   21  ,   51  ,   65  ,   155 ,   37  ,   783 ,   3427    ,   2763    ,   14361   ,0 };
            const std::uint32_t dim1587JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   7   ,   23  ,   11  ,   53  ,   181 ,   267 ,   285 ,   1927    ,   3591    ,   3735    ,   11471   ,0 };
            const std::uint32_t dim1588JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   1   ,   5   ,   25  ,   51  ,   31  ,   201 ,   851 ,   871 ,   3665    ,   193 ,   10929   ,0 };
            const std::uint32_t dim1589JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   5   ,   1   ,   25  ,   35  ,   133 ,   459 ,   45  ,   525 ,   3171    ,   1123    ,   5679    ,0 };
            const std::uint32_t dim1590JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   5   ,   29  ,   47  ,   123 ,   75  ,   101 ,   89  ,   1949    ,   1801    ,   3859    ,   6557    ,0 };
            const std::uint32_t dim1591JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   3   ,   25  ,   1   ,   93  ,   205 ,   447 ,   865 ,   1309    ,   3009    ,   945 ,   6961    ,0 };
            const std::uint32_t dim1592JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   11  ,   21  ,   47  ,   91  ,   9   ,   23  ,   607 ,   1905    ,   2291    ,   5315    ,   6673    ,0 };
            const std::uint32_t dim1593JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   13  ,   3   ,   33  ,   83  ,   27  ,   491 ,   467 ,   1819    ,   3295    ,   1589    ,   4771    ,0 };
            const std::uint32_t dim1594JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   15  ,   17  ,   57  ,   73  ,   49  ,   69  ,   821 ,   1773    ,   459 ,   7945    ,   14471   ,0 };
            const std::uint32_t dim1595JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   1   ,   19  ,   29  ,   9   ,   181 ,   311 ,   353 ,   2045    ,   2873    ,   7417    ,   15243   ,0 };
            const std::uint32_t dim1596JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   7   ,   29  ,   45  ,   43  ,   17  ,   237 ,   915 ,   1069    ,   1429    ,   5629    ,   4501    ,0 };
            const std::uint32_t dim1597JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   9   ,   9   ,   53  ,   57  ,   55  ,   275 ,   233 ,   1697    ,   2857    ,   919 ,   4507    ,0 };
            const std::uint32_t dim1598JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   13  ,   17  ,   45  ,   81  ,   101 ,   209 ,   769 ,   783 ,   1949    ,   5933    ,   137 ,0 };
            const std::uint32_t dim1599JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   7   ,   1   ,   33  ,   17  ,   87  ,   35  ,   927 ,   1595    ,   2443    ,   285 ,   12821   ,0 };
            const std::uint32_t dim1600JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   9   ,   3   ,   33  ,   113 ,   243 ,   51  ,   203 ,   1683    ,   389 ,   2789    ,   9255    ,0 };
            const std::uint32_t dim1601JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   3   ,   9   ,   1   ,   7   ,   227 ,   27  ,   773 ,   621 ,   3743    ,   6591    ,   407 ,0 };
            const std::uint32_t dim1602JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   5   ,   29  ,   51  ,   113 ,   99  ,   305 ,   267 ,   907 ,   3861    ,   5335    ,   10851   ,0 };
            const std::uint32_t dim1603JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   9   ,   27  ,   63  ,   65  ,   249 ,   87  ,   105 ,   2023    ,   1383    ,   4267    ,   8995    ,0 };
            const std::uint32_t dim1604JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   13  ,   15  ,   11  ,   77  ,   9   ,   365 ,   711 ,   1367    ,   2101    ,   5833    ,   9799    ,0 };
            const std::uint32_t dim1605JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   3   ,   7   ,   29  ,   13  ,   157 ,   259 ,   455 ,   389 ,   3177    ,   4243    ,   7615    ,0 };
            const std::uint32_t dim1606JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   3   ,   25  ,   27  ,   31  ,   91  ,   195 ,   109 ,   1767    ,   987 ,   2715    ,   7613    ,0 };
            const std::uint32_t dim1607JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   7   ,   23  ,   51  ,   89  ,   127 ,   485 ,   361 ,   1555    ,   441 ,   4963    ,   3371    ,0 };
            const std::uint32_t dim1608JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   7   ,   27  ,   31  ,   25  ,   249 ,   35  ,   115 ,   1021    ,   1051    ,   3449    ,   3395    ,0 };
            const std::uint32_t dim1609JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   3   ,   17  ,   41  ,   117 ,   173 ,   491 ,   281 ,   885 ,   471 ,   6665    ,   10041   ,0 };
            const std::uint32_t dim1610JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   3   ,   7   ,   53  ,   117 ,   117 ,   479 ,   449 ,   569 ,   4049    ,   2747    ,   12963   ,0 };
            const std::uint32_t dim1611JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   7   ,   11  ,   13  ,   107 ,   171 ,   7   ,   547 ,   1635    ,   1697    ,   1005    ,   11137   ,0 };
            const std::uint32_t dim1612JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   13  ,   17  ,   51  ,   109 ,   81  ,   111 ,   395 ,   349 ,   1467    ,   1399    ,   15545   ,0 };
            const std::uint32_t dim1613JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   9   ,   13  ,   47  ,   79  ,   119 ,   31  ,   239 ,   41  ,   2043    ,   2849    ,   16079   ,0 };
            const std::uint32_t dim1614JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   1   ,   17  ,   41  ,   95  ,   193 ,   511 ,   879 ,   1223    ,   3133    ,   1675    ,   3929    ,0 };
            const std::uint32_t dim1615JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   3   ,   15  ,   55  ,   21  ,   143 ,   279 ,   11  ,   717 ,   3021    ,   6207    ,   4499    ,0 };
            const std::uint32_t dim1616JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   3   ,   3   ,   25  ,   37  ,   91  ,   227 ,   619 ,   1873    ,   1991    ,   793 ,   10021   ,0 };
            const std::uint32_t dim1617JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   11  ,   17  ,   39  ,   75  ,   191 ,   117 ,   997 ,   735 ,   3771    ,   4243    ,   2491    ,0 };
            const std::uint32_t dim1618JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   7   ,   19  ,   9   ,   71  ,   89  ,   427 ,   791 ,   623 ,   903 ,   6685    ,   9029    ,0 };
            const std::uint32_t dim1619JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   3   ,   13  ,   49  ,   13  ,   151 ,   389 ,   677 ,   727 ,   3135    ,   1029    ,   12669   ,0 };
            const std::uint32_t dim1620JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   11  ,   27  ,   31  ,   119 ,   219 ,   491 ,   819 ,   755 ,   3529    ,   3071    ,   16095   ,0 };
            const std::uint32_t dim1621JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   9   ,   1   ,   57  ,   127 ,   171 ,   481 ,   467 ,   1131    ,   1481    ,   2491    ,   2717    ,0 };
            const std::uint32_t dim1622JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   15  ,   7   ,   25  ,   55  ,   87  ,   225 ,   363 ,   843 ,   3581    ,   2511    ,   6685    ,0 };
            const std::uint32_t dim1623JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   3   ,   29  ,   21  ,   91  ,   251 ,   403 ,   1007    ,   307 ,   2869    ,   6033    ,   14169   ,0 };
            const std::uint32_t dim1624JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   13  ,   31  ,   43  ,   77  ,   71  ,   101 ,   995 ,   625 ,   2763    ,   7537    ,   1213    ,0 };
            const std::uint32_t dim1625JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   5   ,   9   ,   45  ,   11  ,   235 ,   59  ,   561 ,   547 ,   815 ,   6123    ,   8173    ,0 };
            const std::uint32_t dim1626JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   3   ,   25  ,   19  ,   107 ,   47  ,   103 ,   467 ,   1889    ,   2021    ,   2861    ,   7617    ,0 };
            const std::uint32_t dim1627JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   9   ,   9   ,   3   ,   11  ,   231 ,   217 ,   213 ,   1497    ,   3125    ,   7421    ,   6221    ,0 };
            const std::uint32_t dim1628JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   7   ,   27  ,   57  ,   27  ,   9   ,   507 ,   191 ,   1297    ,   3307    ,   4687    ,   13299   ,0 };
            const std::uint32_t dim1629JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   1   ,   25  ,   17  ,   109 ,   57  ,   231 ,   123 ,   1297    ,   77  ,   785 ,   13731   ,0 };
            const std::uint32_t dim1630JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   3   ,   25  ,   5   ,   85  ,   177 ,   365 ,   301 ,   655 ,   1743    ,   2009    ,   7759    ,0 };
            const std::uint32_t dim1631JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   7   ,   19  ,   29  ,   105 ,   57  ,   469 ,   735 ,   875 ,   3749    ,   619 ,   15569   ,0 };
            const std::uint32_t dim1632JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   1   ,   19  ,   21  ,   105 ,   19  ,   83  ,   117 ,   1599    ,   655 ,   63  ,   12143   ,0 };
            const std::uint32_t dim1633JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   7   ,   9   ,   35  ,   123 ,   195 ,   109 ,   321 ,   1713    ,   793 ,   8067    ,   6903    ,0 };
            const std::uint32_t dim1634JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   9   ,   1   ,   41  ,   43  ,   41  ,   51  ,   711 ,   1713    ,   3063    ,   6427    ,   3577    ,0 };
            const std::uint32_t dim1635JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   11  ,   17  ,   3   ,   95  ,   159 ,   23  ,   605 ,   1431    ,   1289    ,   2225    ,   1689    ,0 };
            const std::uint32_t dim1636JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   15  ,   19  ,   3   ,   83  ,   61  ,   133 ,   707 ,   453 ,   2487    ,   551 ,   13605   ,0 };
            const std::uint32_t dim1637JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   5   ,   31  ,   37  ,   51  ,   157 ,   51  ,   423 ,   2021    ,   1837    ,   1873    ,   2919    ,0 };
            const std::uint32_t dim1638JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   13  ,   3   ,   17  ,   19  ,   19  ,   181 ,   961 ,   669 ,   47  ,   7513    ,   7551    ,0 };
            const std::uint32_t dim1639JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   1   ,   9   ,   7   ,   61  ,   219 ,   347 ,   21  ,   467 ,   955 ,   3255    ,   275 ,0 };
            const std::uint32_t dim1640JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   1   ,   31  ,   57  ,   51  ,   9   ,   49  ,   491 ,   119 ,   1155    ,   3641    ,   16095   ,0 };
            const std::uint32_t dim1641JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   1   ,   15  ,   37  ,   93  ,   27  ,   205 ,   889 ,   1463    ,   1567    ,   453 ,   13757   ,0 };
            const std::uint32_t dim1642JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   15  ,   27  ,   51  ,   43  ,   189 ,   357 ,   591 ,   1783    ,   549 ,   761 ,   8683    ,0 };
            const std::uint32_t dim1643JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   15  ,   13  ,   27  ,   25  ,   67  ,   145 ,   471 ,   1589    ,   2395    ,   6625    ,   3837    ,0 };
            const std::uint32_t dim1644JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   15  ,   25  ,   61  ,   111 ,   125 ,   475 ,   489 ,   15  ,   3835    ,   5077    ,   14487   ,0 };
            const std::uint32_t dim1645JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   9   ,   15  ,   55  ,   35  ,   169 ,   267 ,   135 ,   383 ,   733 ,   6913    ,   14153   ,0 };
            const std::uint32_t dim1646JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   1   ,   19  ,   55  ,   89  ,   61  ,   175 ,   467 ,   1243    ,   1431    ,   1743    ,   8641    ,0 };
            const std::uint32_t dim1647JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   7   ,   19  ,   41  ,   13  ,   45  ,   503 ,   285 ,   1727    ,   587 ,   5073    ,   13053   ,0 };
            const std::uint32_t dim1648JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   3   ,   11  ,   39  ,   93  ,   167 ,   385 ,   165 ,   881 ,   1037    ,   1471    ,   14527   ,0 };
            const std::uint32_t dim1649JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   15  ,   9   ,   7   ,   49  ,   163 ,   219 ,   955 ,   1083    ,   2723    ,   3749    ,   15415   ,0 };
            const std::uint32_t dim1650JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   3   ,   7   ,   43  ,   67  ,   87  ,   375 ,   405 ,   1663    ,   1263    ,   1895    ,   2229    ,0 };
            const std::uint32_t dim1651JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   1   ,   27  ,   47  ,   77  ,   147 ,   417 ,   843 ,   1829    ,   3451    ,   2973    ,   7313    ,0 };
            const std::uint32_t dim1652JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   1   ,   3   ,   25  ,   69  ,   255 ,   413 ,   43  ,   837 ,   957 ,   261 ,   8663    ,0 };
            const std::uint32_t dim1653JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   7   ,   29  ,   35  ,   9   ,   57  ,   421 ,   751 ,   593 ,   3745    ,   3203    ,   14179   ,0 };
            const std::uint32_t dim1654JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   3   ,   13  ,   25  ,   109 ,   169 ,   331 ,   537 ,   69  ,   2089    ,   7263    ,   15133   ,0 };
            const std::uint32_t dim1655JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   5   ,   21  ,   21  ,   21  ,   145 ,   223 ,   167 ,   1297    ,   3257    ,   7465    ,   1557    ,0 };
            const std::uint32_t dim1656JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   3   ,   11  ,   7   ,   31  ,   205 ,   97  ,   737 ,   79  ,   4083    ,   5601    ,   8411    ,0 };
            const std::uint32_t dim1657JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   3   ,   7   ,   39  ,   117 ,   203 ,   225 ,   801 ,   741 ,   1861    ,   8091    ,   3169    ,0 };
            const std::uint32_t dim1658JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   3   ,   15  ,   49  ,   109 ,   171 ,   109 ,   845 ,   1757    ,   2687    ,   5643    ,   3967    ,0 };
            const std::uint32_t dim1659JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   13  ,   7   ,   41  ,   93  ,   165 ,   127 ,   629 ,   959 ,   1483    ,   3837    ,   2093    ,0 };
            const std::uint32_t dim1660JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   5   ,   9   ,   39  ,   115 ,   153 ,   395 ,   777 ,   1601    ,   3443    ,   3581    ,   1419    ,0 };
            const std::uint32_t dim1661JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   3   ,   23  ,   61  ,   87  ,   179 ,   463 ,   55  ,   1727    ,   99  ,   7527    ,   15281   ,0 };
            const std::uint32_t dim1662JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   9   ,   9   ,   49  ,   27  ,   103 ,   221 ,   277 ,   1093    ,   3547    ,   8009    ,   8711    ,0 };
            const std::uint32_t dim1663JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   7   ,   15  ,   59  ,   79  ,   59  ,   451 ,   763 ,   1687    ,   389 ,   1665    ,   12149   ,0 };
            const std::uint32_t dim1664JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   9   ,   25  ,   25  ,   37  ,   53  ,   173 ,   1003    ,   1175    ,   3881    ,   4355    ,   6247    ,0 };
            const std::uint32_t dim1665JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   3   ,   15  ,   31  ,   123 ,   133 ,   79  ,   581 ,   405 ,   2869    ,   2759    ,   2295    ,0 };
            const std::uint32_t dim1666JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   13  ,   19  ,   3   ,   35  ,   135 ,   287 ,   433 ,   205 ,   2119    ,   6293    ,   2931    ,0 };
            const std::uint32_t dim1667JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   13  ,   21  ,   29  ,   69  ,   109 ,   401 ,   753 ,   1371    ,   3777    ,   5473    ,   8357    ,0 };
            const std::uint32_t dim1668JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   7   ,   11  ,   27  ,   101 ,   153 ,   483 ,   639 ,   687 ,   2325    ,   329 ,   12427   ,0 };
            const std::uint32_t dim1669JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   13  ,   31  ,   41  ,   93  ,   83  ,   121 ,   645 ,   479 ,   1417    ,   1967    ,   2807    ,0 };
            const std::uint32_t dim1670JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   5   ,   3   ,   29  ,   41  ,   115 ,   41  ,   81  ,   5   ,   1063    ,   943 ,   10151   ,0 };
            const std::uint32_t dim1671JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   13  ,   5   ,   33  ,   79  ,   245 ,   271 ,   373 ,   1339    ,   1471    ,   4695    ,   12791   ,0 };
            const std::uint32_t dim1672JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   3   ,   5   ,   5   ,   19  ,   101 ,   109 ,   429 ,   1587    ,   3453    ,   4549    ,   8173    ,0 };
            const std::uint32_t dim1673JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   7   ,   5   ,   33  ,   5   ,   15  ,   183 ,   241 ,   871 ,   1263    ,   85  ,   13525   ,0 };
            const std::uint32_t dim1674JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   1   ,   15  ,   5   ,   115 ,   165 ,   451 ,   789 ,   515 ,   3359    ,   1231    ,   3129    ,0 };
            const std::uint32_t dim1675JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   3   ,   5   ,   45  ,   109 ,   233 ,   369 ,   819 ,   987 ,   3157    ,   5961    ,   5705    ,0 };
            const std::uint32_t dim1676JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   11  ,   7   ,   63  ,   43  ,   249 ,   95  ,   853 ,   917 ,   1749    ,   4275    ,   10109   ,0 };
            const std::uint32_t dim1677JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   9   ,   21  ,   5   ,   53  ,   249 ,   3   ,   11  ,   1171    ,   3289    ,   6659    ,   6555    ,0 };
            const std::uint32_t dim1678JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   11  ,   9   ,   19  ,   35  ,   253 ,   13  ,   229 ,   149 ,   3153    ,   3833    ,   11635   ,0 };
            const std::uint32_t dim1679JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   11  ,   1   ,   19  ,   127 ,   119 ,   405 ,   19  ,   589 ,   2613    ,   399 ,   3869    ,0 };
            const std::uint32_t dim1680JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   1   ,   3   ,   11  ,   35  ,   147 ,   11  ,   765 ,   237 ,   2451    ,   5041    ,   4919    ,0 };
            const std::uint32_t dim1681JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   11  ,   15  ,   7   ,   91  ,   7   ,   5   ,   223 ,   1505    ,   3513    ,   185 ,   2767    ,0 };
            const std::uint32_t dim1682JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   7   ,   27  ,   17  ,   81  ,   181 ,   11  ,   803 ,   319 ,   3891    ,   4505    ,   6035    ,0 };
            const std::uint32_t dim1683JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   15  ,   29  ,   13  ,   47  ,   137 ,   301 ,   975 ,   77  ,   3351    ,   6307    ,   2613    ,0 };
            const std::uint32_t dim1684JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   5   ,   15  ,   41  ,   99  ,   171 ,   465 ,   145 ,   1859    ,   2949    ,   7915    ,   7755    ,0 };
            const std::uint32_t dim1685JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   5   ,   3   ,   25  ,   123 ,   251 ,   423 ,   921 ,   987 ,   793 ,   2199    ,   1255    ,0 };
            const std::uint32_t dim1686JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   3   ,   1   ,   63  ,   75  ,   101 ,   219 ,   1013    ,   1761    ,   2171    ,   2763    ,   11185   ,0 };
            const std::uint32_t dim1687JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   13  ,   13  ,   15  ,   33  ,   147 ,   5   ,   915 ,   1903    ,   2607    ,   3847    ,   167 ,0 };
            const std::uint32_t dim1688JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   1   ,   23  ,   27  ,   71  ,   17  ,   381 ,   269 ,   603 ,   2303    ,   1399    ,   13795   ,0 };
            const std::uint32_t dim1689JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   5   ,   29  ,   5   ,   51  ,   151 ,   271 ,   369 ,   595 ,   531 ,   7155    ,   15871   ,0 };
            const std::uint32_t dim1690JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   13  ,   9   ,   49  ,   49  ,   119 ,   191 ,   105 ,   1203    ,   3431    ,   7063    ,   10831   ,0 };
            const std::uint32_t dim1691JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   15  ,   31  ,   49  ,   37  ,   147 ,   155 ,   865 ,   339 ,   257 ,   4065    ,   7249    ,0 };
            const std::uint32_t dim1692JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   11  ,   3   ,   23  ,   127 ,   19  ,   363 ,   733 ,   1059    ,   3693    ,   4623    ,   2853    ,0 };
            const std::uint32_t dim1693JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   3   ,   3   ,   55  ,   13  ,   177 ,   453 ,   447 ,   183 ,   3247    ,   5923    ,   15485   ,0 };
            const std::uint32_t dim1694JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   7   ,   3   ,   57  ,   93  ,   13  ,   347 ,   225 ,   535 ,   3187    ,   6047    ,   11315   ,0 };
            const std::uint32_t dim1695JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   9   ,   17  ,   5   ,   121 ,   35  ,   35  ,   393 ,   1941    ,   1901    ,   7099    ,   2639    ,0 };
            const std::uint32_t dim1696JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   13  ,   13  ,   43  ,   61  ,   143 ,   291 ,   667 ,   103 ,   3679    ,   7899    ,   3603    ,0 };
            const std::uint32_t dim1697JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   15  ,   31  ,   57  ,   41  ,   101 ,   455 ,   541 ,   1001    ,   1879    ,   1879    ,   7411    ,0 };
            const std::uint32_t dim1698JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   7   ,   13  ,   29  ,   113 ,   151 ,   305 ,   593 ,   147 ,   737 ,   6643    ,   14463   ,0 };
            const std::uint32_t dim1699JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   3   ,   17  ,   55  ,   3   ,   179 ,   277 ,   873 ,   1915    ,   2541    ,   4245    ,   4357    ,0 };
            const std::uint32_t dim1700JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   11  ,   21  ,   43  ,   97  ,   251 ,   15  ,   443 ,   957 ,   923 ,   7497    ,   9377    ,0 };
            const std::uint32_t dim1701JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   7   ,   23  ,   19  ,   27  ,   3   ,   35  ,   407 ,   451 ,   3653    ,   813 ,   8833    ,0 };
            const std::uint32_t dim1702JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   5   ,   15  ,   25  ,   5   ,   165 ,   231 ,   221 ,   1325    ,   641 ,   4545    ,   7667    ,0 };
            const std::uint32_t dim1703JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   1   ,   13  ,   17  ,   25  ,   225 ,   237 ,   289 ,   187 ,   2881    ,   4723    ,   15579   ,0 };
            const std::uint32_t dim1704JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   3   ,   15  ,   43  ,   53  ,   241 ,   163 ,   853 ,   491 ,   2497    ,   761 ,   1707    ,0 };
            const std::uint32_t dim1705JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   3   ,   13  ,   19  ,   83  ,   97  ,   7   ,   639 ,   1985    ,   3553    ,   3971    ,   10661   ,0 };
            const std::uint32_t dim1706JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   1   ,   15  ,   37  ,   21  ,   139 ,   33  ,   643 ,   63  ,   2213    ,   1807    ,   14483   ,0 };
            const std::uint32_t dim1707JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   11  ,   3   ,   55  ,   67  ,   45  ,   313 ,   539 ,   1057    ,   455 ,   6473    ,   1499    ,0 };
            const std::uint32_t dim1708JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   9   ,   1   ,   29  ,   91  ,   133 ,   461 ,   301 ,   539 ,   2001    ,   8189    ,   2009    ,0 };
            const std::uint32_t dim1709JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   9   ,   17  ,   5   ,   77  ,   221 ,   423 ,   505 ,   419 ,   1987    ,   8171    ,   12985   ,0 };
            const std::uint32_t dim1710JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   13  ,   21  ,   11  ,   69  ,   53  ,   43  ,   819 ,   1513    ,   1767    ,   2981    ,   4333    ,0 };
            const std::uint32_t dim1711JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   9   ,   9   ,   29  ,   83  ,   183 ,   9   ,   815 ,   1051    ,   819 ,   2089    ,   13917   ,0 };
            const std::uint32_t dim1712JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   1   ,   21  ,   41  ,   87  ,   133 ,   149 ,   847 ,   205 ,   1511    ,   2441    ,   13537   ,0 };
            const std::uint32_t dim1713JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   3   ,   23  ,   1   ,   121 ,   89  ,   349 ,   355 ,   1919    ,   2045    ,   1723    ,   11859   ,0 };
            const std::uint32_t dim1714JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   1   ,   21  ,   47  ,   111 ,   65  ,   367 ,   505 ,   805 ,   2823    ,   5807    ,   6221    ,0 };
            const std::uint32_t dim1715JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   7   ,   7   ,   39  ,   35  ,   35  ,   497 ,   411 ,   387 ,   203 ,   1513    ,   15385   ,0 };
            const std::uint32_t dim1716JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   7   ,   3   ,   7   ,   23  ,   195 ,   353 ,   241 ,   327 ,   1041    ,   4667    ,   4333    ,0 };
            const std::uint32_t dim1717JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   9   ,   31  ,   51  ,   45  ,   243 ,   485 ,   785 ,   419 ,   1107    ,   7691    ,   2303    ,0 };
            const std::uint32_t dim1718JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   7   ,   31  ,   1   ,   121 ,   79  ,   263 ,   153 ,   695 ,   3617    ,   7435    ,   11587   ,0 };
            const std::uint32_t dim1719JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   7   ,   27  ,   33  ,   43  ,   223 ,   153 ,   755 ,   1151    ,   3343    ,   2795    ,   7781    ,0 };
            const std::uint32_t dim1720JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   15  ,   5   ,   41  ,   39  ,   181 ,   485 ,   129 ,   529 ,   2335    ,   6843    ,   7733    ,0 };
            const std::uint32_t dim1721JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   11  ,   31  ,   55  ,   117 ,   157 ,   227 ,   125 ,   557 ,   315 ,   3031    ,   8671    ,0 };
            const std::uint32_t dim1722JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   7   ,   15  ,   5   ,   117 ,   149 ,   239 ,   85  ,   341 ,   995 ,   1709    ,   9303    ,0 };
            const std::uint32_t dim1723JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   9   ,   3   ,   23  ,   17  ,   87  ,   327 ,   929 ,   519 ,   3441    ,   7599    ,   15021   ,0 };
            const std::uint32_t dim1724JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   9   ,   23  ,   31  ,   81  ,   37  ,   493 ,   451 ,   603 ,   1943    ,   1055    ,   3959    ,0 };
            const std::uint32_t dim1725JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   13  ,   7   ,   61  ,   61  ,   127 ,   303 ,   675 ,   955 ,   249 ,   7653    ,   8441    ,0 };
            const std::uint32_t dim1726JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   5   ,   23  ,   1   ,   95  ,   109 ,   155 ,   853 ,   1567    ,   4007    ,   4205    ,   7839    ,0 };
            const std::uint32_t dim1727JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   1   ,   11  ,   27  ,   57  ,   167 ,   285 ,   421 ,   143 ,   3937    ,   4865    ,   10581   ,0 };
            const std::uint32_t dim1728JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   11  ,   15  ,   19  ,   49  ,   39  ,   383 ,   549 ,   1563    ,   2499    ,   7889    ,   239 ,0 };
            const std::uint32_t dim1729JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   7   ,   13  ,   47  ,   61  ,   77  ,   443 ,   961 ,   1979    ,   931 ,   433 ,   6457    ,0 };
            const std::uint32_t dim1730JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   5   ,   5   ,   1   ,   49  ,   137 ,   417 ,   579 ,   1079    ,   1511    ,   1611    ,   16083   ,0 };
            const std::uint32_t dim1731JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   11  ,   7   ,   51  ,   43  ,   29  ,   199 ,   525 ,   801 ,   3887    ,   619 ,   3389    ,0 };
            const std::uint32_t dim1732JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   11  ,   25  ,   23  ,   65  ,   65  ,   201 ,   875 ,   787 ,   3747    ,   7275    ,   6191    ,0 };
            const std::uint32_t dim1733JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   1   ,   19  ,   21  ,   117 ,   169 ,   39  ,   901 ,   3   ,   3579    ,   6119    ,   2057    ,0 };
            const std::uint32_t dim1734JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   9   ,   13  ,   59  ,   33  ,   43  ,   237 ,   767 ,   819 ,   3555    ,   1337    ,   13469   ,0 };
            const std::uint32_t dim1735JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   1   ,   25  ,   51  ,   59  ,   11  ,   427 ,   353 ,   1601    ,   3905    ,   6975    ,   1065    ,0 };
            const std::uint32_t dim1736JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   5   ,   19  ,   35  ,   43  ,   137 ,   227 ,   17  ,   803 ,   919 ,   6651    ,   3339    ,0 };
            const std::uint32_t dim1737JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   15  ,   21  ,   21  ,   41  ,   197 ,   373 ,   849 ,   1753    ,   515 ,   4093    ,   15407   ,0 };
            const std::uint32_t dim1738JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   3   ,   11  ,   5   ,   49  ,   223 ,   351 ,   349 ,   987 ,   1785    ,   269 ,   3037    ,0 };
            const std::uint32_t dim1739JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   9   ,   3   ,   47  ,   103 ,   225 ,   21  ,   285 ,   1529    ,   399 ,   4951    ,   10767   ,0 };
            const std::uint32_t dim1740JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   11  ,   25  ,   27  ,   97  ,   87  ,   487 ,   613 ,   607 ,   1905    ,   6019    ,   423 ,0 };
            const std::uint32_t dim1741JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   3   ,   23  ,   53  ,   23  ,   147 ,   69  ,   781 ,   373 ,   1261    ,   8011    ,   9611    ,0 };
            const std::uint32_t dim1742JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   11  ,   21  ,   43  ,   67  ,   87  ,   173 ,   57  ,   1147    ,   1841    ,   6031    ,   11261   ,0 };
            const std::uint32_t dim1743JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   7   ,   29  ,   23  ,   15  ,   113 ,   485 ,   699 ,   259 ,   1175    ,   7489    ,   5119    ,0 };
            const std::uint32_t dim1744JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   13  ,   15  ,   13  ,   85  ,   219 ,   107 ,   811 ,   1599    ,   2267    ,   8047    ,   12427   ,0 };
            const std::uint32_t dim1745JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   11  ,   9   ,   7   ,   127 ,   201 ,   275 ,   293 ,   1313    ,   3251    ,   3745    ,   15237   ,0 };
            const std::uint32_t dim1746JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   15  ,   1   ,   3   ,   57  ,   235 ,   509 ,   353 ,   513 ,   467 ,   1409    ,   4733    ,0 };
            const std::uint32_t dim1747JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   7   ,   13  ,   43  ,   9   ,   41  ,   39  ,   919 ,   1545    ,   43  ,   8029    ,   1413    ,0 };
            const std::uint32_t dim1748JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   3   ,   21  ,   7   ,   33  ,   41  ,   161 ,   53  ,   1635    ,   787 ,   6197    ,   4841    ,0 };
            const std::uint32_t dim1749JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   9   ,   29  ,   41  ,   19  ,   161 ,   205 ,   1003    ,   1899    ,   7   ,   4329    ,   11151   ,0 };
            const std::uint32_t dim1750JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   7   ,   23  ,   23  ,   27  ,   145 ,   375 ,   433 ,   1729    ,   3787    ,   4985    ,   2167    ,0 };
            const std::uint32_t dim1751JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   5   ,   15  ,   21  ,   77  ,   13  ,   33  ,   227 ,   837 ,   1373    ,   2745    ,   2339    ,0 };
            const std::uint32_t dim1752JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   13  ,   17  ,   57  ,   31  ,   83  ,   135 ,   535 ,   693 ,   803 ,   1459    ,   319 ,0 };
            const std::uint32_t dim1753JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   15  ,   11  ,   39  ,   105 ,   111 ,   247 ,   901 ,   395 ,   573 ,   3359    ,   8955    ,0 };
            const std::uint32_t dim1754JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   5   ,   23  ,   27  ,   99  ,   83  ,   277 ,   229 ,   429 ,   1451    ,   4755    ,   13951   ,0 };
            const std::uint32_t dim1755JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   15  ,   27  ,   17  ,   37  ,   81  ,   83  ,   991 ,   1509    ,   1931    ,   7389    ,   6053    ,0 };
            const std::uint32_t dim1756JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   13  ,   27  ,   55  ,   117 ,   93  ,   55  ,   65  ,   155 ,   3933    ,   3159    ,   9507    ,0 };
            const std::uint32_t dim1757JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   7   ,   15  ,   47  ,   109 ,   79  ,   379 ,   175 ,   419 ,   3285    ,   3207    ,   1675    ,0 };
            const std::uint32_t dim1758JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   15  ,   31  ,   19  ,   123 ,   229 ,   151 ,   549 ,   1329    ,   3835    ,   511 ,   14679   ,0 };
            const std::uint32_t dim1759JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   5   ,   25  ,   43  ,   89  ,   145 ,   419 ,   5   ,   1131    ,   2143    ,   7473    ,   14101   ,0 };
            const std::uint32_t dim1760JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   11  ,   21  ,   43  ,   7   ,   123 ,   15  ,   743 ,   241 ,   1737    ,   2239    ,   11007   ,0 };
            const std::uint32_t dim1761JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   15  ,   27  ,   3   ,   119 ,   157 ,   361 ,   471 ,   1673    ,   1873    ,   4555    ,   16337   ,0 };
            const std::uint32_t dim1762JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   7   ,   15  ,   39  ,   95  ,   189 ,   353 ,   605 ,   349 ,   2763    ,   5125    ,   7943    ,0 };
            const std::uint32_t dim1763JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   13  ,   13  ,   1   ,   45  ,   69  ,   191 ,   183 ,   1967    ,   2455    ,   3879    ,   2397    ,0 };
            const std::uint32_t dim1764JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   1   ,   3   ,   23  ,   109 ,   123 ,   127 ,   813 ,   1499    ,   39  ,   1991    ,   9767    ,0 };
            const std::uint32_t dim1765JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   1   ,   7   ,   3   ,   125 ,   93  ,   279 ,   803 ,   1203    ,   3623    ,   4359    ,   4251    ,0 };
            const std::uint32_t dim1766JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   15  ,   25  ,   57  ,   61  ,   103 ,   219 ,   983 ,   957 ,   895 ,   4077    ,   11799   ,0 };
            const std::uint32_t dim1767JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   9   ,   21  ,   11  ,   15  ,   137 ,   491 ,   643 ,   1737    ,   3459    ,   4367    ,   5727    ,0 };
            const std::uint32_t dim1768JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   9   ,   25  ,   57  ,   111 ,   129 ,   101 ,   807 ,   1481    ,   3703    ,   2713    ,   6375    ,0 };
            const std::uint32_t dim1769JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   1   ,   31  ,   59  ,   75  ,   173 ,   209 ,   273 ,   121 ,   747 ,   257 ,   9713    ,0 };
            const std::uint32_t dim1770JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   11  ,   5   ,   31  ,   107 ,   243 ,   189 ,   407 ,   773 ,   503 ,   6197    ,   9455    ,0 };
            const std::uint32_t dim1771JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   5   ,   29  ,   25  ,   31  ,   169 ,   393 ,   857 ,   1739    ,   883 ,   2147    ,   15569   ,0 };
            const std::uint32_t dim1772JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   11  ,   31  ,   47  ,   17  ,   119 ,   499 ,   595 ,   207 ,   1709    ,   4585    ,   12855   ,0 };
            const std::uint32_t dim1773JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   3   ,   21  ,   33  ,   55  ,   197 ,   349 ,   41  ,   453 ,   1913    ,   2301    ,   6461    ,0 };
            const std::uint32_t dim1774JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   13  ,   27  ,   37  ,   105 ,   217 ,   145 ,   1007    ,   259 ,   2681    ,   477 ,   15931   ,0 };
            const std::uint32_t dim1775JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   13  ,   3   ,   39  ,   9   ,   231 ,   395 ,   735 ,   501 ,   1631    ,   2931    ,   11947   ,0 };
            const std::uint32_t dim1776JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   11  ,   13  ,   61  ,   113 ,   113 ,   473 ,   591 ,   499 ,   2169    ,   6419    ,   10619   ,0 };
            const std::uint32_t dim1777JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   5   ,   29  ,   63  ,   43  ,   127 ,   243 ,   647 ,   1633    ,   1361    ,   3755    ,   11315   ,0 };
            const std::uint32_t dim1778JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   1   ,   13  ,   31  ,   111 ,   63  ,   69  ,   1005    ,   1955    ,   339 ,   2415    ,   4855    ,0 };
            const std::uint32_t dim1779JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   13  ,   25  ,   11  ,   21  ,   1   ,   343 ,   259 ,   1359    ,   597 ,   7029    ,   16229   ,0 };
            const std::uint32_t dim1780JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   7   ,   27  ,   13  ,   17  ,   43  ,   509 ,   105 ,   347 ,   443 ,   5939    ,   12173   ,0 };
            const std::uint32_t dim1781JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   13  ,   15  ,   25  ,   93  ,   199 ,   305 ,   725 ,   597 ,   1497    ,   313 ,   10677   ,0 };
            const std::uint32_t dim1782JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   15  ,   17  ,   7   ,   103 ,   95  ,   83  ,   433 ,   441 ,   2587    ,   3365    ,   14771   ,0 };
            const std::uint32_t dim1783JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   1   ,   17  ,   7   ,   55  ,   189 ,   451 ,   729 ,   817 ,   243 ,   4089    ,   6569    ,0 };
            const std::uint32_t dim1784JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   1   ,   5   ,   7   ,   19  ,   113 ,   191 ,   211 ,   1205    ,   4005    ,   3221    ,   7521    ,0 };
            const std::uint32_t dim1785JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   15  ,   25  ,   49  ,   77  ,   187 ,   105 ,   87  ,   955 ,   2381    ,   1243    ,   11335   ,0 };
            const std::uint32_t dim1786JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   1   ,   19  ,   63  ,   113 ,   3   ,   7   ,   105 ,   185 ,   1499    ,   6885    ,   9063    ,0 };
            const std::uint32_t dim1787JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   11  ,   31  ,   47  ,   37  ,   107 ,   31  ,   691 ,   1049    ,   2273    ,   1595    ,   4431    ,0 };
            const std::uint32_t dim1788JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   3   ,   23  ,   57  ,   51  ,   17  ,   225 ,   551 ,   965 ,   3497    ,   2549    ,   1153    ,0 };
            const std::uint32_t dim1789JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   5   ,   25  ,   41  ,   123 ,   143 ,   13  ,   437 ,   1081    ,   1625    ,   147 ,   6239    ,0 };
            const std::uint32_t dim1790JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   3   ,   31  ,   49  ,   17  ,   119 ,   315 ,   155 ,   37  ,   1125    ,   1223    ,   341 ,0 };
            const std::uint32_t dim1791JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   7   ,   9   ,   49  ,   35  ,   223 ,   449 ,   147 ,   317 ,   29  ,   4651    ,   15995   ,0 };
            const std::uint32_t dim1792JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   3   ,   9   ,   23  ,   97  ,   209 ,   343 ,   279 ,   1947    ,   3465    ,   7775    ,   5779    ,0 };
            const std::uint32_t dim1793JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   1   ,   7   ,   61  ,   111 ,   135 ,   473 ,   105 ,   1529    ,   2855    ,   3457    ,   7053    ,0 };
            const std::uint32_t dim1794JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   7   ,   29  ,   3   ,   63  ,   25  ,   115 ,   423 ,   1425    ,   1363    ,   77  ,   11485   ,0 };
            const std::uint32_t dim1795JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   15  ,   23  ,   59  ,   101 ,   87  ,   319 ,   785 ,   1639    ,   3427    ,   3165    ,   11273   ,0 };
            const std::uint32_t dim1796JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   13  ,   23  ,   7   ,   47  ,   221 ,   137 ,   775 ,   329 ,   1777    ,   3091    ,   4693    ,0 };
            const std::uint32_t dim1797JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   13  ,   1   ,   33  ,   31  ,   177 ,   481 ,   865 ,   739 ,   97  ,   5113    ,   16371   ,0 };
            const std::uint32_t dim1798JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   9   ,   31  ,   57  ,   99  ,   241 ,   465 ,   915 ,   1181    ,   225 ,   6795    ,   5743    ,0 };
            const std::uint32_t dim1799JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   3   ,   13  ,   25  ,   71  ,   119 ,   31  ,   169 ,   1745    ,   4085    ,   2945    ,   13357   ,0 };
            const std::uint32_t dim1800JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   5   ,   31  ,   61  ,   123 ,   71  ,   375 ,   1003    ,   1303    ,   2149    ,   5867    ,   10523   ,0 };
            const std::uint32_t dim1801JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   11  ,   21  ,   13  ,   25  ,   147 ,   147 ,   591 ,   259 ,   1707    ,   1777    ,   5869    ,0 };
            const std::uint32_t dim1802JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   13  ,   7   ,   13  ,   87  ,   227 ,   305 ,   235 ,   1263    ,   953 ,   4509    ,   11375   ,0 };
            const std::uint32_t dim1803JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   1   ,   11  ,   23  ,   103 ,   177 ,   9   ,   329 ,   1519    ,   2393    ,   6627    ,   14631   ,0 };
            const std::uint32_t dim1804JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   9   ,   25  ,   19  ,   75  ,   87  ,   361 ,   741 ,   1745    ,   3281    ,   6771    ,   3111    ,0 };
            const std::uint32_t dim1805JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   5   ,   23  ,   5   ,   1   ,   247 ,   43  ,   61  ,   1489    ,   3537    ,   5079    ,   11545   ,0 };
            const std::uint32_t dim1806JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   15  ,   9   ,   43  ,   49  ,   213 ,   191 ,   567 ,   1237    ,   681 ,   6715    ,   6471    ,0 };
            const std::uint32_t dim1807JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   1   ,   31  ,   53  ,   83  ,   53  ,   117 ,   1001    ,   525 ,   841 ,   2891    ,   4281    ,0 };
            const std::uint32_t dim1808JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   9   ,   21  ,   49  ,   21  ,   215 ,   209 ,   611 ,   1849    ,   969 ,   3081    ,   9485    ,0 };
            const std::uint32_t dim1809JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   15  ,   13  ,   25  ,   37  ,   31  ,   357 ,   611 ,   83  ,   1615    ,   8137    ,   14505   ,0 };
            const std::uint32_t dim1810JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   11  ,   29  ,   31  ,   9   ,   27  ,   427 ,   883 ,   555 ,   2559    ,   7039    ,   11345   ,0 };
            const std::uint32_t dim1811JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   11  ,   3   ,   17  ,   9   ,   251 ,   493 ,   977 ,   1713    ,   2711    ,   4377    ,   3171    ,0 };
            const std::uint32_t dim1812JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   7   ,   9   ,   1   ,   27  ,   179 ,   345 ,   425 ,   413 ,   2101    ,   3417    ,   1497    ,0 };
            const std::uint32_t dim1813JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   3   ,   13  ,   33  ,   121 ,   81  ,   247 ,   1003    ,   1405    ,   2769    ,   1919    ,   10807   ,0 };
            const std::uint32_t dim1814JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   15  ,   29  ,   51  ,   13  ,   101 ,   237 ,   165 ,   1483    ,   3961    ,   2389    ,   8379    ,0 };
            const std::uint32_t dim1815JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   11  ,   17  ,   3   ,   51  ,   141 ,   295 ,   165 ,   1089    ,   3889    ,   6415    ,   4969    ,0 };
            const std::uint32_t dim1816JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   3   ,   25  ,   47  ,   1   ,   17  ,   499 ,   409 ,   1417    ,   2975    ,   3935    ,   13363   ,0 };
            const std::uint32_t dim1817JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   13  ,   7   ,   55  ,   91  ,   121 ,   509 ,   675 ,   1203    ,   795 ,   1225    ,   15329   ,0 };
            const std::uint32_t dim1818JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   5   ,   3   ,   29  ,   19  ,   103 ,   11  ,   511 ,   799 ,   773 ,   515 ,   9931    ,0 };
            const std::uint32_t dim1819JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   3   ,   27  ,   63  ,   19  ,   83  ,   213 ,   977 ,   1923    ,   999 ,   7935    ,   2081    ,0 };
            const std::uint32_t dim1820JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   3   ,   19  ,   17  ,   127 ,   251 ,   417 ,   711 ,   85  ,   2757    ,   6461    ,   83  ,0 };
            const std::uint32_t dim1821JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   9   ,   11  ,   7   ,   113 ,   127 ,   287 ,   647 ,   1775    ,   3201    ,   2551    ,   13389   ,0 };
            const std::uint32_t dim1822JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   15  ,   31  ,   33  ,   81  ,   53  ,   207 ,   361 ,   665 ,   2073    ,   4249    ,   6699    ,0 };
            const std::uint32_t dim1823JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   11  ,   25  ,   43  ,   83  ,   159 ,   31  ,   693 ,   1315    ,   2043    ,   3463    ,   15771   ,0 };
            const std::uint32_t dim1824JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   15  ,   9   ,   1   ,   93  ,   207 ,   97  ,   293 ,   67  ,   2411    ,   1241    ,   10819   ,0 };
            const std::uint32_t dim1825JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   15  ,   17  ,   41  ,   113 ,   153 ,   7   ,   499 ,   131 ,   737 ,   7881    ,   2691    ,0 };
            const std::uint32_t dim1826JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   11  ,   5   ,   3   ,   125 ,   49  ,   63  ,   375 ,   811 ,   3295    ,   7997    ,   1063    ,0 };
            const std::uint32_t dim1827JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   5   ,   1   ,   27  ,   37  ,   101 ,   179 ,   975 ,   421 ,   2785    ,   8093    ,   11803   ,0 };
            const std::uint32_t dim1828JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   3   ,   27  ,   35  ,   89  ,   111 ,   481 ,   821 ,   223 ,   2983    ,   2369    ,   4861    ,0 };
            const std::uint32_t dim1829JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   3   ,   21  ,   59  ,   25  ,   237 ,   73  ,   451 ,   309 ,   241 ,   4955    ,   9889    ,0 };
            const std::uint32_t dim1830JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   15  ,   25  ,   37  ,   85  ,   29  ,   103 ,   893 ,   337 ,   2831    ,   6679    ,   15171   ,0 };
            const std::uint32_t dim1831JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   3   ,   13  ,   1   ,   101 ,   109 ,   223 ,   243 ,   1749    ,   3611    ,   4097    ,   14439   ,0 };
            const std::uint32_t dim1832JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   11  ,   31  ,   49  ,   97  ,   181 ,   269 ,   567 ,   1801    ,   3129    ,   2697    ,   15167   ,0 };
            const std::uint32_t dim1833JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   5   ,   11  ,   11  ,   105 ,   161 ,   163 ,   363 ,   187 ,   3671    ,   6793    ,   4197    ,0 };
            const std::uint32_t dim1834JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   1   ,   23  ,   61  ,   127 ,   9   ,   101 ,   493 ,   1875    ,   3943    ,   3501    ,   1685    ,0 };
            const std::uint32_t dim1835JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   3   ,   29  ,   13  ,   11  ,   185 ,   437 ,   151 ,   927 ,   199 ,   7739    ,   14771   ,0 };
            const std::uint32_t dim1836JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   5   ,   17  ,   17  ,   35  ,   147 ,   387 ,   401 ,   1385    ,   1993    ,   1551    ,   2421    ,0 };
            const std::uint32_t dim1837JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   7   ,   25  ,   27  ,   1   ,   43  ,   407 ,   503 ,   1917    ,   23  ,   3459    ,   7653    ,0 };
            const std::uint32_t dim1838JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   1   ,   29  ,   37  ,   69  ,   193 ,   359 ,   901 ,   1661    ,   4049    ,   2923    ,   15553   ,0 };
            const std::uint32_t dim1839JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   11  ,   31  ,   53  ,   45  ,   5   ,   143 ,   823 ,   483 ,   669 ,   8037    ,   14021   ,0 };
            const std::uint32_t dim1840JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   15  ,   23  ,   47  ,   105 ,   185 ,   267 ,   347 ,   85  ,   3121    ,   5811    ,   6229    ,0 };
            const std::uint32_t dim1841JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   5   ,   27  ,   43  ,   25  ,   143 ,   197 ,   425 ,   1537    ,   1701    ,   6061    ,   12125   ,0 };
            const std::uint32_t dim1842JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   1   ,   31  ,   57  ,   21  ,   21  ,   301 ,   573 ,   947 ,   2087    ,   3135    ,   1767    ,0 };
            const std::uint32_t dim1843JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   15  ,   23  ,   35  ,   35  ,   191 ,   195 ,   131 ,   1669    ,   3311    ,   4107    ,   9311    ,0 };
            const std::uint32_t dim1844JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   5   ,   23  ,   13  ,   111 ,   165 ,   283 ,   949 ,   1575    ,   2359    ,   5891    ,   9911    ,0 };
            const std::uint32_t dim1845JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   13  ,   17  ,   31  ,   31  ,   179 ,   45  ,   475 ,   975 ,   251 ,   353 ,   6331    ,0 };
            const std::uint32_t dim1846JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   13  ,   15  ,   9   ,   127 ,   35  ,   463 ,   711 ,   1783    ,   837 ,   7859    ,   14299   ,0 };
            const std::uint32_t dim1847JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   5   ,   31  ,   57  ,   79  ,   7   ,   319 ,   517 ,   677 ,   3923    ,   1363    ,   11355   ,0 };
            const std::uint32_t dim1848JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   3   ,   17  ,   17  ,   49  ,   171 ,   95  ,   519 ,   775 ,   2265    ,   7953    ,   617 ,0 };
            const std::uint32_t dim1849JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   9   ,   3   ,   35  ,   87  ,   185 ,   369 ,   795 ,   1171    ,   3777    ,   4983    ,   1153    ,0 };
            const std::uint32_t dim1850JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   3   ,   9   ,   3   ,   1   ,   131 ,   275 ,   921 ,   507 ,   1877    ,   1573    ,   6231    ,0 };
            const std::uint32_t dim1851JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   15  ,   7   ,   53  ,   77  ,   255 ,   329 ,   449 ,   1859    ,   3625    ,   7027    ,   9921    ,0 };
            const std::uint32_t dim1852JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   7   ,   1   ,   47  ,   57  ,   111 ,   303 ,   749 ,   689 ,   2963    ,   8085    ,   9097    ,0 };
            const std::uint32_t dim1853JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   11  ,   19  ,   47  ,   61  ,   3   ,   481 ,   371 ,   1737    ,   287 ,   5485    ,   15433   ,0 };
            const std::uint32_t dim1854JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   13  ,   23  ,   45  ,   33  ,   83  ,   483 ,   411 ,   257 ,   749 ,   3959    ,   10269   ,0 };
            const std::uint32_t dim1855JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   5   ,   25  ,   15  ,   11  ,   181 ,   131 ,   943 ,   125 ,   3367    ,   2429    ,   2151    ,0 };
            const std::uint32_t dim1856JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   15  ,   25  ,   35  ,   37  ,   163 ,   399 ,   575 ,   843 ,   1567    ,   4401    ,   14757   ,0 };
            const std::uint32_t dim1857JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   1   ,   5   ,   3   ,   31  ,   199 ,   479 ,   525 ,   973 ,   2843    ,   7831    ,   6693    ,0 };
            const std::uint32_t dim1858JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   3   ,   21  ,   7   ,   123 ,   31  ,   207 ,   741 ,   425 ,   2139    ,   2965    ,   1017    ,0 };
            const std::uint32_t dim1859JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   11  ,   3   ,   31  ,   61  ,   85  ,   303 ,   627 ,   1995    ,   3211    ,   5747    ,   14897   ,0 };
            const std::uint32_t dim1860JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   7   ,   9   ,   25  ,   45  ,   73  ,   427 ,   945 ,   1505    ,   1121    ,   7585    ,   13115   ,0 };
            const std::uint32_t dim1861JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   1   ,   9   ,   43  ,   75  ,   63  ,   445 ,   709 ,   645 ,   1105    ,   1375    ,   12303   ,0 };
            const std::uint32_t dim1862JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   5   ,   25  ,   37  ,   101 ,   209 ,   239 ,   429 ,   1455    ,   3587    ,   4231    ,   6501    ,0 };
            const std::uint32_t dim1863JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   1   ,   21  ,   23  ,   113 ,   227 ,   151 ,   97  ,   367 ,   889 ,   7675    ,   14093   ,0 };
            const std::uint32_t dim1864JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   11  ,   13  ,   31  ,   63  ,   7   ,   31  ,   973 ,   1935    ,   53  ,   4941    ,   9057    ,0 };
            const std::uint32_t dim1865JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   13  ,   21  ,   23  ,   79  ,   43  ,   255 ,   1003    ,   1741    ,   1003    ,   355 ,   3839    ,0 };
            const std::uint32_t dim1866JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   9   ,   31  ,   17  ,   45  ,   235 ,   271 ,   711 ,   61  ,   235 ,   513 ,   11321   ,0 };
            const std::uint32_t dim1867JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   9   ,   29  ,   35  ,   43  ,   115 ,   9   ,   787 ,   325 ,   625 ,   7905    ,   8191    ,   29233   ,0 };
            const std::uint32_t dim1868JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   13  ,   5   ,   17  ,   67  ,   161 ,   357 ,   163 ,   1129    ,   3819    ,   3601    ,   5961    ,   9259    ,0 };
            const std::uint32_t dim1869JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   13  ,   25  ,   17  ,   83  ,   41  ,   463 ,   879 ,   1881    ,   1107    ,   4337    ,   409 ,   8633    ,0 };
            const std::uint32_t dim1870JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   1   ,   17  ,   45  ,   127 ,   213 ,   285 ,   791 ,   479 ,   3153    ,   3001    ,   16207   ,   32669   ,0 };
            const std::uint32_t dim1871JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   11  ,   23  ,   41  ,   103 ,   209 ,   81  ,   903 ,   1787    ,   907 ,   161 ,   15739   ,   17367   ,0 };
            const std::uint32_t dim1872JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   11  ,   17  ,   61  ,   69  ,   251 ,   321 ,   361 ,   905 ,   1081    ,   5749    ,   2639    ,   21195   ,0 };
            const std::uint32_t dim1873JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   13  ,   27  ,   39  ,   61  ,   161 ,   139 ,   837 ,   579 ,   1979    ,   4413    ,   8701    ,   16301   ,0 };
            const std::uint32_t dim1874JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   7   ,   3   ,   49  ,   111 ,   77  ,   423 ,   491 ,   1489    ,   2615    ,   4997    ,   3695    ,   15109   ,0 };
            const std::uint32_t dim1875JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   7   ,   31  ,   3   ,   53  ,   113 ,   45  ,   767 ,   1561    ,   2925    ,   605 ,   3211    ,   8413    ,0 };
            const std::uint32_t dim1876JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   15  ,   31  ,   29  ,   65  ,   13  ,   19  ,   159 ,   639 ,   2155    ,   2699    ,   7001    ,   15575   ,0 };
            const std::uint32_t dim1877JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   1   ,   3   ,   33  ,   37  ,   89  ,   189 ,   661 ,   1685    ,   503 ,   6037    ,   12993   ,   9571    ,0 };
            const std::uint32_t dim1878JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   13  ,   31  ,   13  ,   41  ,   35  ,   217 ,   193 ,   1273    ,   443 ,   1385    ,   13661   ,   14873   ,0 };
            const std::uint32_t dim1879JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   15  ,   3   ,   9   ,   123 ,   251 ,   155 ,   545 ,   813 ,   317 ,   5127    ,   15305   ,   5571    ,0 };
            const std::uint32_t dim1880JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   15  ,   3   ,   39  ,   41  ,   39  ,   273 ,   881 ,   809 ,   1643    ,   687 ,   5525    ,   3473    ,0 };
            const std::uint32_t dim1881JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   11  ,   7   ,   25  ,   25  ,   27  ,   263 ,   773 ,   155 ,   1541    ,   7545    ,   873 ,   32713   ,0 };
            const std::uint32_t dim1882JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   9   ,   1   ,   49  ,   57  ,   17  ,   433 ,   73  ,   635 ,   1073    ,   7459    ,   15653   ,   47  ,0 };
            const std::uint32_t dim1883JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   13  ,   1   ,   5   ,   65  ,   105 ,   353 ,   361 ,   339 ,   3983    ,   2707    ,   10165   ,   20883   ,0 };
            const std::uint32_t dim1884JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   3   ,   23  ,   29  ,   125 ,   223 ,   463 ,   493 ,   1989    ,   1583    ,   8153    ,   13475   ,   5789    ,0 };
            const std::uint32_t dim1885JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   7   ,   27  ,   39  ,   61  ,   127 ,   387 ,   215 ,   1769    ,   2279    ,   7883    ,   1491    ,   29625   ,0 };
            const std::uint32_t dim1886JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   5   ,   5   ,   13  ,   11  ,   47  ,   409 ,   673 ,   1927    ,   1277    ,   6971    ,   8195    ,   22663   ,0 };
            const std::uint32_t dim1887JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   13  ,   1   ,   53  ,   123 ,   187 ,   25  ,   29  ,   1107    ,   1929    ,   6995    ,   5081    ,   8861    ,0 };
            const std::uint32_t dim1888JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   5   ,   25  ,   27  ,   53  ,   65  ,   239 ,   299 ,   21  ,   3389    ,   1587    ,   1437    ,   26209   ,0 };
            const std::uint32_t dim1889JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   7   ,   15  ,   35  ,   37  ,   105 ,   169 ,   843 ,   623 ,   3763    ,   7101    ,   5245    ,   17203   ,0 };
            const std::uint32_t dim1890JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   15  ,   21  ,   7   ,   29  ,   29  ,   465 ,   149 ,   189 ,   1115    ,   6471    ,   11275   ,   28769   ,0 };
            const std::uint32_t dim1891JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   9   ,   31  ,   1   ,   99  ,   101 ,   321 ,   675 ,   1631    ,   1371    ,   7733    ,   1697    ,   4437    ,0 };
            const std::uint32_t dim1892JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   9   ,   7   ,   27  ,   47  ,   207 ,   295 ,   787 ,   1539    ,   2233    ,   7849    ,   15843   ,   11149   ,0 };
            const std::uint32_t dim1893JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   3   ,   17  ,   29  ,   61  ,   143 ,   289 ,   939 ,   729 ,   297 ,   1513    ,   4387    ,   3347    ,0 };
            const std::uint32_t dim1894JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   13  ,   15  ,   25  ,   125 ,   13  ,   157 ,   377 ,   317 ,   827 ,   5137    ,   829 ,   21215   ,0 };
            const std::uint32_t dim1895JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   13  ,   17  ,   37  ,   79  ,   87  ,   163 ,   847 ,   1009    ,   2259    ,   6543    ,   8697    ,   4837    ,0 };
            const std::uint32_t dim1896JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   11  ,   29  ,   7   ,   13  ,   91  ,   279 ,   439 ,   691 ,   4047    ,   159 ,   9403    ,   27735   ,0 };
            const std::uint32_t dim1897JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   5   ,   23  ,   61  ,   53  ,   93  ,   343 ,   349 ,   355 ,   1275    ,   3573    ,   12847   ,   8969    ,0 };
            const std::uint32_t dim1898JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   11  ,   1   ,   49  ,   47  ,   255 ,   371 ,   511 ,   579 ,   2385    ,   2237    ,   2015    ,   23973   ,0 };
            const std::uint32_t dim1899JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   11  ,   15  ,   31  ,   13  ,   121 ,   399 ,   957 ,   731 ,   3743    ,   1573    ,   2293    ,   27755   ,0 };
            const std::uint32_t dim1900JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   5   ,   23  ,   19  ,   57  ,   211 ,   133 ,   197 ,   379 ,   1037    ,   625 ,   9405    ,   11547   ,0 };
            const std::uint32_t dim1901JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   15  ,   7   ,   13  ,   75  ,   93  ,   415 ,   551 ,   1885    ,   2259    ,   23  ,   14321   ,   21509   ,0 };
            const std::uint32_t dim1902JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   5   ,   29  ,   37  ,   23  ,   59  ,   199 ,   559 ,   1761    ,   821 ,   5077    ,   12017   ,   16505   ,0 };
            const std::uint32_t dim1903JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   7   ,   19  ,   29  ,   31  ,   101 ,   121 ,   605 ,   1679    ,   2317    ,   3359    ,   13557   ,   17567   ,0 };
            const std::uint32_t dim1904JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   15  ,   3   ,   5   ,   45  ,   201 ,   401 ,   689 ,   1775    ,   3615    ,   2641    ,   14149   ,   29241   ,0 };
            const std::uint32_t dim1905JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   5   ,   9   ,   13  ,   51  ,   101 ,   41  ,   347 ,   57  ,   613 ,   5813    ,   3753    ,   22007   ,0 };
            const std::uint32_t dim1906JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   15  ,   19  ,   59  ,   57  ,   57  ,   405 ,   647 ,   1943    ,   353 ,   1691    ,   9287    ,   29567   ,0 };
            const std::uint32_t dim1907JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   13  ,   29  ,   11  ,   51  ,   137 ,   163 ,   365 ,   153 ,   3791    ,   5367    ,   4649    ,   11255   ,0 };
            const std::uint32_t dim1908JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   1   ,   27  ,   37  ,   99  ,   211 ,   377 ,   543 ,   649 ,   2107    ,   3511    ,   10385   ,   1093    ,0 };
            const std::uint32_t dim1909JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   9   ,   29  ,   25  ,   85  ,   75  ,   55  ,   75  ,   825 ,   2129    ,   6867    ,   9053    ,   22687   ,0 };
            const std::uint32_t dim1910JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   1   ,   19  ,   57  ,   29  ,   99  ,   369 ,   107 ,   1187    ,   2919    ,   6163    ,   15209   ,   7911    ,0 };
            const std::uint32_t dim1911JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   11  ,   25  ,   55  ,   111 ,   197 ,   329 ,   307 ,   1531    ,   1753    ,   1275    ,   5543    ,   23411   ,0 };
            const std::uint32_t dim1912JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   9   ,   21  ,   59  ,   97  ,   211 ,   117 ,   331 ,   1919    ,   1763    ,   1755    ,   12517   ,   16579   ,0 };
            const std::uint32_t dim1913JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   11  ,   5   ,   37  ,   21  ,   229 ,   109 ,   341 ,   421 ,   2413    ,   785 ,   3251    ,   10245   ,0 };
            const std::uint32_t dim1914JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   11  ,   27  ,   3   ,   89  ,   15  ,   455 ,   53  ,   1447    ,   137 ,   681 ,   7811    ,   16817   ,0 };
            const std::uint32_t dim1915JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   13  ,   9   ,   57  ,   45  ,   101 ,   459 ,   801 ,   409 ,   911 ,   749 ,   11875   ,   6039    ,0 };
            const std::uint32_t dim1916JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   13  ,   23  ,   31  ,   49  ,   105 ,   255 ,   485 ,   1587    ,   1137    ,   2113    ,   16313   ,   19073   ,0 };
            const std::uint32_t dim1917JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   9   ,   31  ,   59  ,   117 ,   213 ,   293 ,   195 ,   991 ,   3531    ,   157 ,   1747    ,   20883   ,0 };
            const std::uint32_t dim1918JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   11  ,   17  ,   31  ,   63  ,   33  ,   415 ,   341 ,   779 ,   423 ,   5661    ,   2533    ,   23031   ,0 };
            const std::uint32_t dim1919JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   3   ,   11  ,   41  ,   69  ,   117 ,   441 ,   3   ,   885 ,   3387    ,   4291    ,   497 ,   9991    ,0 };
            const std::uint32_t dim1920JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   15  ,   27  ,   29  ,   17  ,   109 ,   315 ,   433 ,   291 ,   577 ,   3209    ,   3305    ,   6759    ,0 };
            const std::uint32_t dim1921JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   1   ,   29  ,   37  ,   75  ,   139 ,   243 ,   217 ,   319 ,   1025    ,   2415    ,   5957    ,   8303    ,0 };
            const std::uint32_t dim1922JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   9   ,   15  ,   41  ,   19  ,   21  ,   279 ,   563 ,   893 ,   1391    ,   4907    ,   14381   ,   7165    ,0 };
            const std::uint32_t dim1923JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   13  ,   21  ,   35  ,   23  ,   139 ,   441 ,   463 ,   563 ,   155 ,   2009    ,   14887   ,   30943   ,0 };
            const std::uint32_t dim1924JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   3   ,   23  ,   23  ,   13  ,   157 ,   511 ,   401 ,   1573    ,   3019    ,   1791    ,   587 ,   10927   ,0 };
            const std::uint32_t dim1925JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   5   ,   1   ,   45  ,   127 ,   85  ,   27  ,   729 ,   993 ,   1487    ,   5577    ,   14113   ,   23163   ,0 };
            const std::uint32_t dim1926JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   5   ,   31  ,   15  ,   19  ,   7   ,   503 ,   359 ,   595 ,   1471    ,   2587    ,   7827    ,   31497   ,0 };
            const std::uint32_t dim1927JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   1   ,   13  ,   29  ,   35  ,   49  ,   381 ,   677 ,   407 ,   2681    ,   7923    ,   2917    ,   4001    ,0 };
            const std::uint32_t dim1928JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   5   ,   25  ,   51  ,   3   ,   33  ,   229 ,   105 ,   1449    ,   417 ,   2577    ,   5185    ,   18737   ,0 };
            const std::uint32_t dim1929JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   9   ,   29  ,   17  ,   9   ,   185 ,   253 ,   929 ,   1267    ,   2559    ,   2271    ,   10501   ,   21687   ,0 };
            const std::uint32_t dim1930JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   13  ,   9   ,   29  ,   89  ,   193 ,   309 ,   385 ,   73  ,   1835    ,   5193    ,   10235   ,   29827   ,0 };
            const std::uint32_t dim1931JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   7   ,   29  ,   23  ,   9   ,   119 ,   325 ,   277 ,   1883    ,   613 ,   6299    ,   10799   ,   16271   ,0 };
            const std::uint32_t dim1932JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   11  ,   29  ,   55  ,   71  ,   5   ,   99  ,   303 ,   1853    ,   2225    ,   3047    ,   16019   ,   23257   ,0 };
            const std::uint32_t dim1933JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   1   ,   19  ,   19  ,   35  ,   39  ,   389 ,   737 ,   433 ,   1489    ,   5903    ,   10181   ,   11249   ,0 };
            const std::uint32_t dim1934JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   13  ,   15  ,   13  ,   21  ,   191 ,   369 ,   939 ,   1353    ,   2645    ,   221 ,   49  ,   14783   ,0 };
            const std::uint32_t dim1935JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   1   ,   17  ,   5   ,   21  ,   121 ,   359 ,   863 ,   893 ,   2887    ,   4431    ,   5245    ,   20865   ,0 };
            const std::uint32_t dim1936JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   11  ,   15  ,   25  ,   59  ,   37  ,   263 ,   425 ,   1143    ,   3843    ,   4955    ,   6639    ,   8411    ,0 };
            const std::uint32_t dim1937JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   15  ,   3   ,   5   ,   123 ,   131 ,   229 ,   93  ,   113 ,   3609    ,   2007    ,   7709    ,   32141   ,0 };
            const std::uint32_t dim1938JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   11  ,   25  ,   43  ,   103 ,   199 ,   243 ,   533 ,   1947    ,   683 ,   1013    ,   13155   ,   29877   ,0 };
            const std::uint32_t dim1939JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   9   ,   17  ,   41  ,   57  ,   99  ,   137 ,   839 ,   1437    ,   3997    ,   2473    ,   10169   ,   20253   ,0 };
            const std::uint32_t dim1940JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   5   ,   19  ,   49  ,   55  ,   185 ,   175 ,   319 ,   1173    ,   1049    ,   5289    ,   3297    ,   23755   ,0 };
            const std::uint32_t dim1941JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   5   ,   25  ,   7   ,   81  ,   119 ,   319 ,   743 ,   1655    ,   3719    ,   5731    ,   11015   ,   11309   ,0 };
            const std::uint32_t dim1942JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   9   ,   31  ,   53  ,   61  ,   119 ,   207 ,   689 ,   81  ,   367 ,   2495    ,   1965    ,   15559   ,0 };
            const std::uint32_t dim1943JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   3   ,   21  ,   47  ,   9   ,   199 ,   273 ,   397 ,   1293    ,   2709    ,   3687    ,   5755    ,   6015    ,0 };
            const std::uint32_t dim1944JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   15  ,   1   ,   7   ,   55  ,   55  ,   343 ,   363 ,   1207    ,   3731    ,   7489    ,   2365    ,   25301   ,0 };
            const std::uint32_t dim1945JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   7   ,   3   ,   31  ,   87  ,   15  ,   327 ,   479 ,   177 ,   1261    ,   913 ,   4189    ,   4565    ,0 };
            const std::uint32_t dim1946JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   9   ,   19  ,   37  ,   29  ,   17  ,   185 ,   827 ,   239 ,   281 ,   287 ,   16105   ,   23549   ,0 };
            const std::uint32_t dim1947JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   3   ,   23  ,   17  ,   73  ,   123 ,   287 ,   665 ,   297 ,   215 ,   359 ,   11741   ,   29159   ,0 };
            const std::uint32_t dim1948JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   11  ,   13  ,   45  ,   35  ,   81  ,   211 ,   257 ,   655 ,   911 ,   5949    ,   9597    ,   11677   ,0 };
            const std::uint32_t dim1949JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   15  ,   7   ,   39  ,   31  ,   103 ,   341 ,   871 ,   299 ,   635 ,   951 ,   13669   ,   30083   ,0 };
            const std::uint32_t dim1950JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   7   ,   7   ,   15  ,   55  ,   45  ,   375 ,   711 ,   1339    ,   3045    ,   4691    ,   13247   ,   14611   ,0 };
            const std::uint32_t dim1951JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   9   ,   19  ,   33  ,   67  ,   91  ,   83  ,   541 ,   1229    ,   3209    ,   2783    ,   11519   ,   10729   ,0 };
            const std::uint32_t dim1952JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   7   ,   15  ,   15  ,   89  ,   7   ,   173 ,   809 ,   1229    ,   117 ,   2323    ,   15145   ,   2863    ,0 };
            const std::uint32_t dim1953JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   13  ,   1   ,   55  ,   39  ,   187 ,   491 ,   675 ,   1357    ,   1109    ,   2701    ,   14891   ,   17061   ,0 };
            const std::uint32_t dim1954JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   5   ,   7   ,   47  ,   127 ,   111 ,   481 ,   177 ,   1553    ,   2949    ,   6403    ,   1993    ,   26227   ,0 };
            const std::uint32_t dim1955JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   11  ,   31  ,   3   ,   111 ,   193 ,   445 ,   359 ,   1039    ,   667 ,   7463    ,   7983    ,   10901   ,0 };
            const std::uint32_t dim1956JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   15  ,   29  ,   17  ,   15  ,   69  ,   111 ,   27  ,   647 ,   3377    ,   185 ,   12083   ,   21197   ,0 };
            const std::uint32_t dim1957JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   5   ,   17  ,   57  ,   5   ,   189 ,   383 ,   407 ,   145 ,   1185    ,   3307    ,   12373   ,   28531   ,0 };
            const std::uint32_t dim1958JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   9   ,   23  ,   43  ,   41  ,   19  ,   127 ,   687 ,   1841    ,   3707    ,   4983    ,   14585   ,   15253   ,0 };
            const std::uint32_t dim1959JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   9   ,   13  ,   61  ,   13  ,   113 ,   43  ,   423 ,   1073    ,   1843    ,   1071    ,   7869    ,   21137   ,0 };
            const std::uint32_t dim1960JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   3   ,   7   ,   43  ,   87  ,   185 ,   375 ,   699 ,   283 ,   3265    ,   4905    ,   9317    ,   3055    ,0 };
            const std::uint32_t dim1961JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   9   ,   17  ,   15  ,   47  ,   73  ,   211 ,   37  ,   427 ,   3841    ,   2801    ,   12131   ,   19619   ,0 };
            const std::uint32_t dim1962JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   7   ,   17  ,   35  ,   53  ,   67  ,   221 ,   97  ,   199 ,   2825    ,   1997    ,   9903    ,   3003    ,0 };
            const std::uint32_t dim1963JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   9   ,   23  ,   53  ,   69  ,   225 ,   413 ,   307 ,   553 ,   2631    ,   6499    ,   6277    ,   30337   ,0 };
            const std::uint32_t dim1964JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   13  ,   5   ,   23  ,   85  ,   193 ,   437 ,   607 ,   397 ,   2003    ,   4345    ,   3575    ,   27939   ,0 };
            const std::uint32_t dim1965JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   13  ,   13  ,   45  ,   117 ,   191 ,   143 ,   477 ,   473 ,   3051    ,   5903    ,   6253    ,   22679   ,0 };
            const std::uint32_t dim1966JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   13  ,   31  ,   49  ,   31  ,   217 ,   119 ,   893 ,   1415    ,   1633    ,   7573    ,   8353    ,   32231   ,0 };
            const std::uint32_t dim1967JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   5   ,   29  ,   47  ,   25  ,   3   ,   425 ,   883 ,   1461    ,   3679    ,   6635    ,   9103    ,   26793   ,0 };
            const std::uint32_t dim1968JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   15  ,   11  ,   27  ,   87  ,   31  ,   153 ,   115 ,   1573    ,   745 ,   6515    ,   14321   ,   21301   ,0 };
            const std::uint32_t dim1969JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   11  ,   15  ,   57  ,   41  ,   157 ,   147 ,   867 ,   1959    ,   943 ,   6431    ,   14581   ,   9579    ,0 };
            const std::uint32_t dim1970JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   9   ,   5   ,   13  ,   1   ,   203 ,   317 ,   185 ,   1569    ,   3621    ,   4873    ,   13249   ,   19153   ,0 };
            const std::uint32_t dim1971JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   5   ,   5   ,   29  ,   41  ,   3   ,   37  ,   919 ,   1037    ,   237 ,   4699    ,   12011   ,   18669   ,0 };
            const std::uint32_t dim1972JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   1   ,   21  ,   1   ,   55  ,   195 ,   289 ,   635 ,   981 ,   1395    ,   1827    ,   7481    ,   19163   ,0 };
            const std::uint32_t dim1973JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   13  ,   15  ,   15  ,   89  ,   109 ,   17  ,   111 ,   815 ,   2637    ,   6917    ,   7973    ,   9471    ,0 };
            const std::uint32_t dim1974JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   15  ,   9   ,   25  ,   73  ,   101 ,   417 ,   519 ,   1697    ,   2861    ,   2281    ,   10959   ,   30433   ,0 };
            const std::uint32_t dim1975JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   3   ,   21  ,   51  ,   89  ,   157 ,   181 ,   307 ,   355 ,   661 ,   4885    ,   12411   ,   23473   ,0 };
            const std::uint32_t dim1976JoeKuoD5Init[]   =   {   1   ,   1   ,   1   ,   15  ,   17  ,   37  ,   19  ,   139 ,   205 ,   73  ,   97  ,   2463    ,   2785    ,   9355    ,   23989   ,0 };
            const std::uint32_t dim1977JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   1   ,   7   ,   39  ,   117 ,   191 ,   395 ,   539 ,   1823    ,   2333    ,   1205    ,   14131   ,   2301    ,0 };
            const std::uint32_t dim1978JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   13  ,   21  ,   11  ,   49  ,   43  ,   381 ,   15  ,   1743    ,   641 ,   95  ,   10581   ,   15437   ,0 };
            const std::uint32_t dim1979JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   7   ,   5   ,   53  ,   55  ,   23  ,   265 ,   163 ,   173 ,   1399    ,   7257    ,   15097   ,   13491   ,0 };
            const std::uint32_t dim1980JoeKuoD5Init[]   =   {   1   ,   3   ,   3   ,   13  ,   27  ,   55  ,   97  ,   51  ,   469 ,   7   ,   871 ,   3213    ,   5719    ,   871 ,   11669   ,0 };
            const std::uint32_t dim1981JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   3   ,   29  ,   35  ,   47  ,   31  ,   77  ,   335 ,   537 ,   1695    ,   461 ,   14417   ,   23945   ,0 };
            const std::uint32_t dim1982JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   13  ,   1   ,   47  ,   97  ,   113 ,   235 ,   593 ,   1437    ,   3893    ,   5299    ,   857 ,   451 ,0 };
            const std::uint32_t dim1983JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   3   ,   3   ,   53  ,   51  ,   203 ,   177 ,   205 ,   773 ,   281 ,   7689    ,   8039    ,   7275    ,0 };
            const std::uint32_t dim1984JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   3   ,   3   ,   37  ,   33  ,   113 ,   429 ,   791 ,   1593    ,   3259    ,   1275    ,   11113   ,   16001   ,0 };
            const std::uint32_t dim1985JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   7   ,   27  ,   9   ,   109 ,   229 ,   453 ,   633 ,   2047    ,   1803    ,   4127    ,   3453    ,   15625   ,0 };
            const std::uint32_t dim1986JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   15  ,   17  ,   59  ,   15  ,   73  ,   105 ,   627 ,   1181    ,   2925    ,   2077    ,   16067   ,   15829   ,0 };
            const std::uint32_t dim1987JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   1   ,   15  ,   41  ,   1   ,   143 ,   493 ,   261 ,   845 ,   737 ,   6249    ,   7663    ,   32439   ,0 };
            const std::uint32_t dim1988JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   9   ,   11  ,   45  ,   101 ,   227 ,   227 ,   211 ,   243 ,   2817    ,   179 ,   3361    ,   20535   ,0 };
            const std::uint32_t dim1989JoeKuoD5Init[]   =   {   1   ,   3   ,   1   ,   3   ,   11  ,   25  ,   105 ,   173 ,   249 ,   465 ,   853 ,   2365    ,   5035    ,   11541   ,   5481    ,0 };
            const std::uint32_t dim1990JoeKuoD5Init[]   =   {   1   ,   3   ,   5   ,   9   ,   21  ,   29  ,   77  ,   245 ,   311 ,   879 ,   1007    ,   2545    ,   1561    ,   2949    ,   24855   ,0 };
            const std::uint32_t dim1991JoeKuoD5Init[]   =   {   1   ,   1   ,   5   ,   13  ,   1   ,   31  ,   105 ,   151 ,   127 ,   413 ,   553 ,   645 ,   863 ,   15943   ,   32731   ,0 };
            const std::uint32_t dim1992JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   11  ,   21  ,   13  ,   71  ,   229 ,   283 ,   493 ,   1445    ,   15  ,   4681    ,   3137    ,   18199   ,0 };
            const std::uint32_t dim1993JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   15  ,   27  ,   17  ,   37  ,   213 ,   253 ,   117 ,   205 ,   1489    ,   2997    ,   6483    ,   17201   ,0 };
            const std::uint32_t dim1994JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   13  ,   3   ,   29  ,   83  ,   109 ,   503 ,   139 ,   1119    ,   59  ,   5259    ,   8289    ,   7717    ,0 };
            const std::uint32_t dim1995JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   13  ,   13  ,   5   ,   65  ,   231 ,   117 ,   1009    ,   163 ,   21  ,   7639    ,   16275   ,   10661   ,0 };
            const std::uint32_t dim1996JoeKuoD5Init[]   =   {   1   ,   3   ,   7   ,   7   ,   19  ,   63  ,   31  ,   211 ,   487 ,   277 ,   27  ,   3685    ,   5371    ,   8157    ,   29735   ,0 };
            const std::uint32_t dim1997JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   1   ,   11  ,   49  ,   113 ,   191 ,   3   ,   923 ,   797 ,   2055    ,   3999    ,   8511    ,   23931   ,0 };
            const std::uint32_t dim1998JoeKuoD5Init[]   =   {   1   ,   1   ,   7   ,   7   ,   13  ,   27  ,   87  ,   43  ,   433 ,   401 ,   1441    ,   1301    ,   2639    ,   5773    ,   12431   ,0 };
            const std::uint32_t dim1999JoeKuoD5Init[]   =   {   1   ,   1   ,   3   ,   15  ,   21  ,   55  ,   17  ,   57  ,   449 ,   811 ,   519 ,   2329    ,   7607    ,   4255    ,   2845    ,0 };

            const std::uint32_t * const JoeKuoD5initializers[1999]
            =
            {
                dim1JoeKuoD5Init,
                dim2JoeKuoD5Init,
                dim3JoeKuoD5Init,
                dim4JoeKuoD5Init,
                dim5JoeKuoD5Init,
                dim6JoeKuoD5Init,
                dim7JoeKuoD5Init,
                dim8JoeKuoD5Init,
                dim9JoeKuoD5Init,
                dim10JoeKuoD5Init,
                dim11JoeKuoD5Init,
                dim12JoeKuoD5Init,
                dim13JoeKuoD5Init,
                dim14JoeKuoD5Init,
                dim15JoeKuoD5Init,
                dim16JoeKuoD5Init,
                dim17JoeKuoD5Init,
                dim18JoeKuoD5Init,
                dim19JoeKuoD5Init,
                dim20JoeKuoD5Init,
                dim21JoeKuoD5Init,
                dim22JoeKuoD5Init,
                dim23JoeKuoD5Init,
                dim24JoeKuoD5Init,
                dim25JoeKuoD5Init,
                dim26JoeKuoD5Init,
                dim27JoeKuoD5Init,
                dim28JoeKuoD5Init,
                dim29JoeKuoD5Init,
                dim30JoeKuoD5Init,
                dim31JoeKuoD5Init,
                dim32JoeKuoD5Init,
                dim33JoeKuoD5Init,
                dim34JoeKuoD5Init,
                dim35JoeKuoD5Init,
                dim36JoeKuoD5Init,
                dim37JoeKuoD5Init,
                dim38JoeKuoD5Init,
                dim39JoeKuoD5Init,
                dim40JoeKuoD5Init,
                dim41JoeKuoD5Init,
                dim42JoeKuoD5Init,
                dim43JoeKuoD5Init,
                dim44JoeKuoD5Init,
                dim45JoeKuoD5Init,
                dim46JoeKuoD5Init,
                dim47JoeKuoD5Init,
                dim48JoeKuoD5Init,
                dim49JoeKuoD5Init,
                dim50JoeKuoD5Init,
                dim51JoeKuoD5Init,
                dim52JoeKuoD5Init,
                dim53JoeKuoD5Init,
                dim54JoeKuoD5Init,
                dim55JoeKuoD5Init,
                dim56JoeKuoD5Init,
                dim57JoeKuoD5Init,
                dim58JoeKuoD5Init,
                dim59JoeKuoD5Init,
                dim60JoeKuoD5Init,
                dim61JoeKuoD5Init,
                dim62JoeKuoD5Init,
                dim63JoeKuoD5Init,
                dim64JoeKuoD5Init,
                dim65JoeKuoD5Init,
                dim66JoeKuoD5Init,
                dim67JoeKuoD5Init,
                dim68JoeKuoD5Init,
                dim69JoeKuoD5Init,
                dim70JoeKuoD5Init,
                dim71JoeKuoD5Init,
                dim72JoeKuoD5Init,
                dim73JoeKuoD5Init,
                dim74JoeKuoD5Init,
                dim75JoeKuoD5Init,
                dim76JoeKuoD5Init,
                dim77JoeKuoD5Init,
                dim78JoeKuoD5Init,
                dim79JoeKuoD5Init,
                dim80JoeKuoD5Init,
                dim81JoeKuoD5Init,
                dim82JoeKuoD5Init,
                dim83JoeKuoD5Init,
                dim84JoeKuoD5Init,
                dim85JoeKuoD5Init,
                dim86JoeKuoD5Init,
                dim87JoeKuoD5Init,
                dim88JoeKuoD5Init,
                dim89JoeKuoD5Init,
                dim90JoeKuoD5Init,
                dim91JoeKuoD5Init,
                dim92JoeKuoD5Init,
                dim93JoeKuoD5Init,
                dim94JoeKuoD5Init,
                dim95JoeKuoD5Init,
                dim96JoeKuoD5Init,
                dim97JoeKuoD5Init,
                dim98JoeKuoD5Init,
                dim99JoeKuoD5Init,
                dim100JoeKuoD5Init,
                dim101JoeKuoD5Init,
                dim102JoeKuoD5Init,
                dim103JoeKuoD5Init,
                dim104JoeKuoD5Init,
                dim105JoeKuoD5Init,
                dim106JoeKuoD5Init,
                dim107JoeKuoD5Init,
                dim108JoeKuoD5Init,
                dim109JoeKuoD5Init,
                dim110JoeKuoD5Init,
                dim111JoeKuoD5Init,
                dim112JoeKuoD5Init,
                dim113JoeKuoD5Init,
                dim114JoeKuoD5Init,
                dim115JoeKuoD5Init,
                dim116JoeKuoD5Init,
                dim117JoeKuoD5Init,
                dim118JoeKuoD5Init,
                dim119JoeKuoD5Init,
                dim120JoeKuoD5Init,
                dim121JoeKuoD5Init,
                dim122JoeKuoD5Init,
                dim123JoeKuoD5Init,
                dim124JoeKuoD5Init,
                dim125JoeKuoD5Init,
                dim126JoeKuoD5Init,
                dim127JoeKuoD5Init,
                dim128JoeKuoD5Init,
                dim129JoeKuoD5Init,
                dim130JoeKuoD5Init,
                dim131JoeKuoD5Init,
                dim132JoeKuoD5Init,
                dim133JoeKuoD5Init,
                dim134JoeKuoD5Init,
                dim135JoeKuoD5Init,
                dim136JoeKuoD5Init,
                dim137JoeKuoD5Init,
                dim138JoeKuoD5Init,
                dim139JoeKuoD5Init,
                dim140JoeKuoD5Init,
                dim141JoeKuoD5Init,
                dim142JoeKuoD5Init,
                dim143JoeKuoD5Init,
                dim144JoeKuoD5Init,
                dim145JoeKuoD5Init,
                dim146JoeKuoD5Init,
                dim147JoeKuoD5Init,
                dim148JoeKuoD5Init,
                dim149JoeKuoD5Init,
                dim150JoeKuoD5Init,
                dim151JoeKuoD5Init,
                dim152JoeKuoD5Init,
                dim153JoeKuoD5Init,
                dim154JoeKuoD5Init,
                dim155JoeKuoD5Init,
                dim156JoeKuoD5Init,
                dim157JoeKuoD5Init,
                dim158JoeKuoD5Init,
                dim159JoeKuoD5Init,
                dim160JoeKuoD5Init,
                dim161JoeKuoD5Init,
                dim162JoeKuoD5Init,
                dim163JoeKuoD5Init,
                dim164JoeKuoD5Init,
                dim165JoeKuoD5Init,
                dim166JoeKuoD5Init,
                dim167JoeKuoD5Init,
                dim168JoeKuoD5Init,
                dim169JoeKuoD5Init,
                dim170JoeKuoD5Init,
                dim171JoeKuoD5Init,
                dim172JoeKuoD5Init,
                dim173JoeKuoD5Init,
                dim174JoeKuoD5Init,
                dim175JoeKuoD5Init,
                dim176JoeKuoD5Init,
                dim177JoeKuoD5Init,
                dim178JoeKuoD5Init,
                dim179JoeKuoD5Init,
                dim180JoeKuoD5Init,
                dim181JoeKuoD5Init,
                dim182JoeKuoD5Init,
                dim183JoeKuoD5Init,
                dim184JoeKuoD5Init,
                dim185JoeKuoD5Init,
                dim186JoeKuoD5Init,
                dim187JoeKuoD5Init,
                dim188JoeKuoD5Init,
                dim189JoeKuoD5Init,
                dim190JoeKuoD5Init,
                dim191JoeKuoD5Init,
                dim192JoeKuoD5Init,
                dim193JoeKuoD5Init,
                dim194JoeKuoD5Init,
                dim195JoeKuoD5Init,
                dim196JoeKuoD5Init,
                dim197JoeKuoD5Init,
                dim198JoeKuoD5Init,
                dim199JoeKuoD5Init,
                dim200JoeKuoD5Init,
                dim201JoeKuoD5Init,
                dim202JoeKuoD5Init,
                dim203JoeKuoD5Init,
                dim204JoeKuoD5Init,
                dim205JoeKuoD5Init,
                dim206JoeKuoD5Init,
                dim207JoeKuoD5Init,
                dim208JoeKuoD5Init,
                dim209JoeKuoD5Init,
                dim210JoeKuoD5Init,
                dim211JoeKuoD5Init,
                dim212JoeKuoD5Init,
                dim213JoeKuoD5Init,
                dim214JoeKuoD5Init,
                dim215JoeKuoD5Init,
                dim216JoeKuoD5Init,
                dim217JoeKuoD5Init,
                dim218JoeKuoD5Init,
                dim219JoeKuoD5Init,
                dim220JoeKuoD5Init,
                dim221JoeKuoD5Init,
                dim222JoeKuoD5Init,
                dim223JoeKuoD5Init,
                dim224JoeKuoD5Init,
                dim225JoeKuoD5Init,
                dim226JoeKuoD5Init,
                dim227JoeKuoD5Init,
                dim228JoeKuoD5Init,
                dim229JoeKuoD5Init,
                dim230JoeKuoD5Init,
                dim231JoeKuoD5Init,
                dim232JoeKuoD5Init,
                dim233JoeKuoD5Init,
                dim234JoeKuoD5Init,
                dim235JoeKuoD5Init,
                dim236JoeKuoD5Init,
                dim237JoeKuoD5Init,
                dim238JoeKuoD5Init,
                dim239JoeKuoD5Init,
                dim240JoeKuoD5Init,
                dim241JoeKuoD5Init,
                dim242JoeKuoD5Init,
                dim243JoeKuoD5Init,
                dim244JoeKuoD5Init,
                dim245JoeKuoD5Init,
                dim246JoeKuoD5Init,
                dim247JoeKuoD5Init,
                dim248JoeKuoD5Init,
                dim249JoeKuoD5Init,
                dim250JoeKuoD5Init,
                dim251JoeKuoD5Init,
                dim252JoeKuoD5Init,
                dim253JoeKuoD5Init,
                dim254JoeKuoD5Init,
                dim255JoeKuoD5Init,
                dim256JoeKuoD5Init,
                dim257JoeKuoD5Init,
                dim258JoeKuoD5Init,
                dim259JoeKuoD5Init,
                dim260JoeKuoD5Init,
                dim261JoeKuoD5Init,
                dim262JoeKuoD5Init,
                dim263JoeKuoD5Init,
                dim264JoeKuoD5Init,
                dim265JoeKuoD5Init,
                dim266JoeKuoD5Init,
                dim267JoeKuoD5Init,
                dim268JoeKuoD5Init,
                dim269JoeKuoD5Init,
                dim270JoeKuoD5Init,
                dim271JoeKuoD5Init,
                dim272JoeKuoD5Init,
                dim273JoeKuoD5Init,
                dim274JoeKuoD5Init,
                dim275JoeKuoD5Init,
                dim276JoeKuoD5Init,
                dim277JoeKuoD5Init,
                dim278JoeKuoD5Init,
                dim279JoeKuoD5Init,
                dim280JoeKuoD5Init,
                dim281JoeKuoD5Init,
                dim282JoeKuoD5Init,
                dim283JoeKuoD5Init,
                dim284JoeKuoD5Init,
                dim285JoeKuoD5Init,
                dim286JoeKuoD5Init,
                dim287JoeKuoD5Init,
                dim288JoeKuoD5Init,
                dim289JoeKuoD5Init,
                dim290JoeKuoD5Init,
                dim291JoeKuoD5Init,
                dim292JoeKuoD5Init,
                dim293JoeKuoD5Init,
                dim294JoeKuoD5Init,
                dim295JoeKuoD5Init,
                dim296JoeKuoD5Init,
                dim297JoeKuoD5Init,
                dim298JoeKuoD5Init,
                dim299JoeKuoD5Init,
                dim300JoeKuoD5Init,
                dim301JoeKuoD5Init,
                dim302JoeKuoD5Init,
                dim303JoeKuoD5Init,
                dim304JoeKuoD5Init,
                dim305JoeKuoD5Init,
                dim306JoeKuoD5Init,
                dim307JoeKuoD5Init,
                dim308JoeKuoD5Init,
                dim309JoeKuoD5Init,
                dim310JoeKuoD5Init,
                dim311JoeKuoD5Init,
                dim312JoeKuoD5Init,
                dim313JoeKuoD5Init,
                dim314JoeKuoD5Init,
                dim315JoeKuoD5Init,
                dim316JoeKuoD5Init,
                dim317JoeKuoD5Init,
                dim318JoeKuoD5Init,
                dim319JoeKuoD5Init,
                dim320JoeKuoD5Init,
                dim321JoeKuoD5Init,
                dim322JoeKuoD5Init,
                dim323JoeKuoD5Init,
                dim324JoeKuoD5Init,
                dim325JoeKuoD5Init,
                dim326JoeKuoD5Init,
                dim327JoeKuoD5Init,
                dim328JoeKuoD5Init,
                dim329JoeKuoD5Init,
                dim330JoeKuoD5Init,
                dim331JoeKuoD5Init,
                dim332JoeKuoD5Init,
                dim333JoeKuoD5Init,
                dim334JoeKuoD5Init,
                dim335JoeKuoD5Init,
                dim336JoeKuoD5Init,
                dim337JoeKuoD5Init,
                dim338JoeKuoD5Init,
                dim339JoeKuoD5Init,
                dim340JoeKuoD5Init,
                dim341JoeKuoD5Init,
                dim342JoeKuoD5Init,
                dim343JoeKuoD5Init,
                dim344JoeKuoD5Init,
                dim345JoeKuoD5Init,
                dim346JoeKuoD5Init,
                dim347JoeKuoD5Init,
                dim348JoeKuoD5Init,
                dim349JoeKuoD5Init,
                dim350JoeKuoD5Init,
                dim351JoeKuoD5Init,
                dim352JoeKuoD5Init,
                dim353JoeKuoD5Init,
                dim354JoeKuoD5Init,
                dim355JoeKuoD5Init,
                dim356JoeKuoD5Init,
                dim357JoeKuoD5Init,
                dim358JoeKuoD5Init,
                dim359JoeKuoD5Init,
                dim360JoeKuoD5Init,
                dim361JoeKuoD5Init,
                dim362JoeKuoD5Init,
                dim363JoeKuoD5Init,
                dim364JoeKuoD5Init,
                dim365JoeKuoD5Init,
                dim366JoeKuoD5Init,
                dim367JoeKuoD5Init,
                dim368JoeKuoD5Init,
                dim369JoeKuoD5Init,
                dim370JoeKuoD5Init,
                dim371JoeKuoD5Init,
                dim372JoeKuoD5Init,
                dim373JoeKuoD5Init,
                dim374JoeKuoD5Init,
                dim375JoeKuoD5Init,
                dim376JoeKuoD5Init,
                dim377JoeKuoD5Init,
                dim378JoeKuoD5Init,
                dim379JoeKuoD5Init,
                dim380JoeKuoD5Init,
                dim381JoeKuoD5Init,
                dim382JoeKuoD5Init,
                dim383JoeKuoD5Init,
                dim384JoeKuoD5Init,
                dim385JoeKuoD5Init,
                dim386JoeKuoD5Init,
                dim387JoeKuoD5Init,
                dim388JoeKuoD5Init,
                dim389JoeKuoD5Init,
                dim390JoeKuoD5Init,
                dim391JoeKuoD5Init,
                dim392JoeKuoD5Init,
                dim393JoeKuoD5Init,
                dim394JoeKuoD5Init,
                dim395JoeKuoD5Init,
                dim396JoeKuoD5Init,
                dim397JoeKuoD5Init,
                dim398JoeKuoD5Init,
                dim399JoeKuoD5Init,
                dim400JoeKuoD5Init,
                dim401JoeKuoD5Init,
                dim402JoeKuoD5Init,
                dim403JoeKuoD5Init,
                dim404JoeKuoD5Init,
                dim405JoeKuoD5Init,
                dim406JoeKuoD5Init,
                dim407JoeKuoD5Init,
                dim408JoeKuoD5Init,
                dim409JoeKuoD5Init,
                dim410JoeKuoD5Init,
                dim411JoeKuoD5Init,
                dim412JoeKuoD5Init,
                dim413JoeKuoD5Init,
                dim414JoeKuoD5Init,
                dim415JoeKuoD5Init,
                dim416JoeKuoD5Init,
                dim417JoeKuoD5Init,
                dim418JoeKuoD5Init,
                dim419JoeKuoD5Init,
                dim420JoeKuoD5Init,
                dim421JoeKuoD5Init,
                dim422JoeKuoD5Init,
                dim423JoeKuoD5Init,
                dim424JoeKuoD5Init,
                dim425JoeKuoD5Init,
                dim426JoeKuoD5Init,
                dim427JoeKuoD5Init,
                dim428JoeKuoD5Init,
                dim429JoeKuoD5Init,
                dim430JoeKuoD5Init,
                dim431JoeKuoD5Init,
                dim432JoeKuoD5Init,
                dim433JoeKuoD5Init,
                dim434JoeKuoD5Init,
                dim435JoeKuoD5Init,
                dim436JoeKuoD5Init,
                dim437JoeKuoD5Init,
                dim438JoeKuoD5Init,
                dim439JoeKuoD5Init,
                dim440JoeKuoD5Init,
                dim441JoeKuoD5Init,
                dim442JoeKuoD5Init,
                dim443JoeKuoD5Init,
                dim444JoeKuoD5Init,
                dim445JoeKuoD5Init,
                dim446JoeKuoD5Init,
                dim447JoeKuoD5Init,
                dim448JoeKuoD5Init,
                dim449JoeKuoD5Init,
                dim450JoeKuoD5Init,
                dim451JoeKuoD5Init,
                dim452JoeKuoD5Init,
                dim453JoeKuoD5Init,
                dim454JoeKuoD5Init,
                dim455JoeKuoD5Init,
                dim456JoeKuoD5Init,
                dim457JoeKuoD5Init,
                dim458JoeKuoD5Init,
                dim459JoeKuoD5Init,
                dim460JoeKuoD5Init,
                dim461JoeKuoD5Init,
                dim462JoeKuoD5Init,
                dim463JoeKuoD5Init,
                dim464JoeKuoD5Init,
                dim465JoeKuoD5Init,
                dim466JoeKuoD5Init,
                dim467JoeKuoD5Init,
                dim468JoeKuoD5Init,
                dim469JoeKuoD5Init,
                dim470JoeKuoD5Init,
                dim471JoeKuoD5Init,
                dim472JoeKuoD5Init,
                dim473JoeKuoD5Init,
                dim474JoeKuoD5Init,
                dim475JoeKuoD5Init,
                dim476JoeKuoD5Init,
                dim477JoeKuoD5Init,
                dim478JoeKuoD5Init,
                dim479JoeKuoD5Init,
                dim480JoeKuoD5Init,
                dim481JoeKuoD5Init,
                dim482JoeKuoD5Init,
                dim483JoeKuoD5Init,
                dim484JoeKuoD5Init,
                dim485JoeKuoD5Init,
                dim486JoeKuoD5Init,
                dim487JoeKuoD5Init,
                dim488JoeKuoD5Init,
                dim489JoeKuoD5Init,
                dim490JoeKuoD5Init,
                dim491JoeKuoD5Init,
                dim492JoeKuoD5Init,
                dim493JoeKuoD5Init,
                dim494JoeKuoD5Init,
                dim495JoeKuoD5Init,
                dim496JoeKuoD5Init,
                dim497JoeKuoD5Init,
                dim498JoeKuoD5Init,
                dim499JoeKuoD5Init,
                dim500JoeKuoD5Init,
                dim501JoeKuoD5Init,
                dim502JoeKuoD5Init,
                dim503JoeKuoD5Init,
                dim504JoeKuoD5Init,
                dim505JoeKuoD5Init,
                dim506JoeKuoD5Init,
                dim507JoeKuoD5Init,
                dim508JoeKuoD5Init,
                dim509JoeKuoD5Init,
                dim510JoeKuoD5Init,
                dim511JoeKuoD5Init,
                dim512JoeKuoD5Init,
                dim513JoeKuoD5Init,
                dim514JoeKuoD5Init,
                dim515JoeKuoD5Init,
                dim516JoeKuoD5Init,
                dim517JoeKuoD5Init,
                dim518JoeKuoD5Init,
                dim519JoeKuoD5Init,
                dim520JoeKuoD5Init,
                dim521JoeKuoD5Init,
                dim522JoeKuoD5Init,
                dim523JoeKuoD5Init,
                dim524JoeKuoD5Init,
                dim525JoeKuoD5Init,
                dim526JoeKuoD5Init,
                dim527JoeKuoD5Init,
                dim528JoeKuoD5Init,
                dim529JoeKuoD5Init,
                dim530JoeKuoD5Init,
                dim531JoeKuoD5Init,
                dim532JoeKuoD5Init,
                dim533JoeKuoD5Init,
                dim534JoeKuoD5Init,
                dim535JoeKuoD5Init,
                dim536JoeKuoD5Init,
                dim537JoeKuoD5Init,
                dim538JoeKuoD5Init,
                dim539JoeKuoD5Init,
                dim540JoeKuoD5Init,
                dim541JoeKuoD5Init,
                dim542JoeKuoD5Init,
                dim543JoeKuoD5Init,
                dim544JoeKuoD5Init,
                dim545JoeKuoD5Init,
                dim546JoeKuoD5Init,
                dim547JoeKuoD5Init,
                dim548JoeKuoD5Init,
                dim549JoeKuoD5Init,
                dim550JoeKuoD5Init,
                dim551JoeKuoD5Init,
                dim552JoeKuoD5Init,
                dim553JoeKuoD5Init,
                dim554JoeKuoD5Init,
                dim555JoeKuoD5Init,
                dim556JoeKuoD5Init,
                dim557JoeKuoD5Init,
                dim558JoeKuoD5Init,
                dim559JoeKuoD5Init,
                dim560JoeKuoD5Init,
                dim561JoeKuoD5Init,
                dim562JoeKuoD5Init,
                dim563JoeKuoD5Init,
                dim564JoeKuoD5Init,
                dim565JoeKuoD5Init,
                dim566JoeKuoD5Init,
                dim567JoeKuoD5Init,
                dim568JoeKuoD5Init,
                dim569JoeKuoD5Init,
                dim570JoeKuoD5Init,
                dim571JoeKuoD5Init,
                dim572JoeKuoD5Init,
                dim573JoeKuoD5Init,
                dim574JoeKuoD5Init,
                dim575JoeKuoD5Init,
                dim576JoeKuoD5Init,
                dim577JoeKuoD5Init,
                dim578JoeKuoD5Init,
                dim579JoeKuoD5Init,
                dim580JoeKuoD5Init,
                dim581JoeKuoD5Init,
                dim582JoeKuoD5Init,
                dim583JoeKuoD5Init,
                dim584JoeKuoD5Init,
                dim585JoeKuoD5Init,
                dim586JoeKuoD5Init,
                dim587JoeKuoD5Init,
                dim588JoeKuoD5Init,
                dim589JoeKuoD5Init,
                dim590JoeKuoD5Init,
                dim591JoeKuoD5Init,
                dim592JoeKuoD5Init,
                dim593JoeKuoD5Init,
                dim594JoeKuoD5Init,
                dim595JoeKuoD5Init,
                dim596JoeKuoD5Init,
                dim597JoeKuoD5Init,
                dim598JoeKuoD5Init,
                dim599JoeKuoD5Init,
                dim600JoeKuoD5Init,
                dim601JoeKuoD5Init,
                dim602JoeKuoD5Init,
                dim603JoeKuoD5Init,
                dim604JoeKuoD5Init,
                dim605JoeKuoD5Init,
                dim606JoeKuoD5Init,
                dim607JoeKuoD5Init,
                dim608JoeKuoD5Init,
                dim609JoeKuoD5Init,
                dim610JoeKuoD5Init,
                dim611JoeKuoD5Init,
                dim612JoeKuoD5Init,
                dim613JoeKuoD5Init,
                dim614JoeKuoD5Init,
                dim615JoeKuoD5Init,
                dim616JoeKuoD5Init,
                dim617JoeKuoD5Init,
                dim618JoeKuoD5Init,
                dim619JoeKuoD5Init,
                dim620JoeKuoD5Init,
                dim621JoeKuoD5Init,
                dim622JoeKuoD5Init,
                dim623JoeKuoD5Init,
                dim624JoeKuoD5Init,
                dim625JoeKuoD5Init,
                dim626JoeKuoD5Init,
                dim627JoeKuoD5Init,
                dim628JoeKuoD5Init,
                dim629JoeKuoD5Init,
                dim630JoeKuoD5Init,
                dim631JoeKuoD5Init,
                dim632JoeKuoD5Init,
                dim633JoeKuoD5Init,
                dim634JoeKuoD5Init,
                dim635JoeKuoD5Init,
                dim636JoeKuoD5Init,
                dim637JoeKuoD5Init,
                dim638JoeKuoD5Init,
                dim639JoeKuoD5Init,
                dim640JoeKuoD5Init,
                dim641JoeKuoD5Init,
                dim642JoeKuoD5Init,
                dim643JoeKuoD5Init,
                dim644JoeKuoD5Init,
                dim645JoeKuoD5Init,
                dim646JoeKuoD5Init,
                dim647JoeKuoD5Init,
                dim648JoeKuoD5Init,
                dim649JoeKuoD5Init,
                dim650JoeKuoD5Init,
                dim651JoeKuoD5Init,
                dim652JoeKuoD5Init,
                dim653JoeKuoD5Init,
                dim654JoeKuoD5Init,
                dim655JoeKuoD5Init,
                dim656JoeKuoD5Init,
                dim657JoeKuoD5Init,
                dim658JoeKuoD5Init,
                dim659JoeKuoD5Init,
                dim660JoeKuoD5Init,
                dim661JoeKuoD5Init,
                dim662JoeKuoD5Init,
                dim663JoeKuoD5Init,
                dim664JoeKuoD5Init,
                dim665JoeKuoD5Init,
                dim666JoeKuoD5Init,
                dim667JoeKuoD5Init,
                dim668JoeKuoD5Init,
                dim669JoeKuoD5Init,
                dim670JoeKuoD5Init,
                dim671JoeKuoD5Init,
                dim672JoeKuoD5Init,
                dim673JoeKuoD5Init,
                dim674JoeKuoD5Init,
                dim675JoeKuoD5Init,
                dim676JoeKuoD5Init,
                dim677JoeKuoD5Init,
                dim678JoeKuoD5Init,
                dim679JoeKuoD5Init,
                dim680JoeKuoD5Init,
                dim681JoeKuoD5Init,
                dim682JoeKuoD5Init,
                dim683JoeKuoD5Init,
                dim684JoeKuoD5Init,
                dim685JoeKuoD5Init,
                dim686JoeKuoD5Init,
                dim687JoeKuoD5Init,
                dim688JoeKuoD5Init,
                dim689JoeKuoD5Init,
                dim690JoeKuoD5Init,
                dim691JoeKuoD5Init,
                dim692JoeKuoD5Init,
                dim693JoeKuoD5Init,
                dim694JoeKuoD5Init,
                dim695JoeKuoD5Init,
                dim696JoeKuoD5Init,
                dim697JoeKuoD5Init,
                dim698JoeKuoD5Init,
                dim699JoeKuoD5Init,
                dim700JoeKuoD5Init,
                dim701JoeKuoD5Init,
                dim702JoeKuoD5Init,
                dim703JoeKuoD5Init,
                dim704JoeKuoD5Init,
                dim705JoeKuoD5Init,
                dim706JoeKuoD5Init,
                dim707JoeKuoD5Init,
                dim708JoeKuoD5Init,
                dim709JoeKuoD5Init,
                dim710JoeKuoD5Init,
                dim711JoeKuoD5Init,
                dim712JoeKuoD5Init,
                dim713JoeKuoD5Init,
                dim714JoeKuoD5Init,
                dim715JoeKuoD5Init,
                dim716JoeKuoD5Init,
                dim717JoeKuoD5Init,
                dim718JoeKuoD5Init,
                dim719JoeKuoD5Init,
                dim720JoeKuoD5Init,
                dim721JoeKuoD5Init,
                dim722JoeKuoD5Init,
                dim723JoeKuoD5Init,
                dim724JoeKuoD5Init,
                dim725JoeKuoD5Init,
                dim726JoeKuoD5Init,
                dim727JoeKuoD5Init,
                dim728JoeKuoD5Init,
                dim729JoeKuoD5Init,
                dim730JoeKuoD5Init,
                dim731JoeKuoD5Init,
                dim732JoeKuoD5Init,
                dim733JoeKuoD5Init,
                dim734JoeKuoD5Init,
                dim735JoeKuoD5Init,
                dim736JoeKuoD5Init,
                dim737JoeKuoD5Init,
                dim738JoeKuoD5Init,
                dim739JoeKuoD5Init,
                dim740JoeKuoD5Init,
                dim741JoeKuoD5Init,
                dim742JoeKuoD5Init,
                dim743JoeKuoD5Init,
                dim744JoeKuoD5Init,
                dim745JoeKuoD5Init,
                dim746JoeKuoD5Init,
                dim747JoeKuoD5Init,
                dim748JoeKuoD5Init,
                dim749JoeKuoD5Init,
                dim750JoeKuoD5Init,
                dim751JoeKuoD5Init,
                dim752JoeKuoD5Init,
                dim753JoeKuoD5Init,
                dim754JoeKuoD5Init,
                dim755JoeKuoD5Init,
                dim756JoeKuoD5Init,
                dim757JoeKuoD5Init,
                dim758JoeKuoD5Init,
                dim759JoeKuoD5Init,
                dim760JoeKuoD5Init,
                dim761JoeKuoD5Init,
                dim762JoeKuoD5Init,
                dim763JoeKuoD5Init,
                dim764JoeKuoD5Init,
                dim765JoeKuoD5Init,
                dim766JoeKuoD5Init,
                dim767JoeKuoD5Init,
                dim768JoeKuoD5Init,
                dim769JoeKuoD5Init,
                dim770JoeKuoD5Init,
                dim771JoeKuoD5Init,
                dim772JoeKuoD5Init,
                dim773JoeKuoD5Init,
                dim774JoeKuoD5Init,
                dim775JoeKuoD5Init,
                dim776JoeKuoD5Init,
                dim777JoeKuoD5Init,
                dim778JoeKuoD5Init,
                dim779JoeKuoD5Init,
                dim780JoeKuoD5Init,
                dim781JoeKuoD5Init,
                dim782JoeKuoD5Init,
                dim783JoeKuoD5Init,
                dim784JoeKuoD5Init,
                dim785JoeKuoD5Init,
                dim786JoeKuoD5Init,
                dim787JoeKuoD5Init,
                dim788JoeKuoD5Init,
                dim789JoeKuoD5Init,
                dim790JoeKuoD5Init,
                dim791JoeKuoD5Init,
                dim792JoeKuoD5Init,
                dim793JoeKuoD5Init,
                dim794JoeKuoD5Init,
                dim795JoeKuoD5Init,
                dim796JoeKuoD5Init,
                dim797JoeKuoD5Init,
                dim798JoeKuoD5Init,
                dim799JoeKuoD5Init,
                dim800JoeKuoD5Init,
                dim801JoeKuoD5Init,
                dim802JoeKuoD5Init,
                dim803JoeKuoD5Init,
                dim804JoeKuoD5Init,
                dim805JoeKuoD5Init,
                dim806JoeKuoD5Init,
                dim807JoeKuoD5Init,
                dim808JoeKuoD5Init,
                dim809JoeKuoD5Init,
                dim810JoeKuoD5Init,
                dim811JoeKuoD5Init,
                dim812JoeKuoD5Init,
                dim813JoeKuoD5Init,
                dim814JoeKuoD5Init,
                dim815JoeKuoD5Init,
                dim816JoeKuoD5Init,
                dim817JoeKuoD5Init,
                dim818JoeKuoD5Init,
                dim819JoeKuoD5Init,
                dim820JoeKuoD5Init,
                dim821JoeKuoD5Init,
                dim822JoeKuoD5Init,
                dim823JoeKuoD5Init,
                dim824JoeKuoD5Init,
                dim825JoeKuoD5Init,
                dim826JoeKuoD5Init,
                dim827JoeKuoD5Init,
                dim828JoeKuoD5Init,
                dim829JoeKuoD5Init,
                dim830JoeKuoD5Init,
                dim831JoeKuoD5Init,
                dim832JoeKuoD5Init,
                dim833JoeKuoD5Init,
                dim834JoeKuoD5Init,
                dim835JoeKuoD5Init,
                dim836JoeKuoD5Init,
                dim837JoeKuoD5Init,
                dim838JoeKuoD5Init,
                dim839JoeKuoD5Init,
                dim840JoeKuoD5Init,
                dim841JoeKuoD5Init,
                dim842JoeKuoD5Init,
                dim843JoeKuoD5Init,
                dim844JoeKuoD5Init,
                dim845JoeKuoD5Init,
                dim846JoeKuoD5Init,
                dim847JoeKuoD5Init,
                dim848JoeKuoD5Init,
                dim849JoeKuoD5Init,
                dim850JoeKuoD5Init,
                dim851JoeKuoD5Init,
                dim852JoeKuoD5Init,
                dim853JoeKuoD5Init,
                dim854JoeKuoD5Init,
                dim855JoeKuoD5Init,
                dim856JoeKuoD5Init,
                dim857JoeKuoD5Init,
                dim858JoeKuoD5Init,
                dim859JoeKuoD5Init,
                dim860JoeKuoD5Init,
                dim861JoeKuoD5Init,
                dim862JoeKuoD5Init,
                dim863JoeKuoD5Init,
                dim864JoeKuoD5Init,
                dim865JoeKuoD5Init,
                dim866JoeKuoD5Init,
                dim867JoeKuoD5Init,
                dim868JoeKuoD5Init,
                dim869JoeKuoD5Init,
                dim870JoeKuoD5Init,
                dim871JoeKuoD5Init,
                dim872JoeKuoD5Init,
                dim873JoeKuoD5Init,
                dim874JoeKuoD5Init,
                dim875JoeKuoD5Init,
                dim876JoeKuoD5Init,
                dim877JoeKuoD5Init,
                dim878JoeKuoD5Init,
                dim879JoeKuoD5Init,
                dim880JoeKuoD5Init,
                dim881JoeKuoD5Init,
                dim882JoeKuoD5Init,
                dim883JoeKuoD5Init,
                dim884JoeKuoD5Init,
                dim885JoeKuoD5Init,
                dim886JoeKuoD5Init,
                dim887JoeKuoD5Init,
                dim888JoeKuoD5Init,
                dim889JoeKuoD5Init,
                dim890JoeKuoD5Init,
                dim891JoeKuoD5Init,
                dim892JoeKuoD5Init,
                dim893JoeKuoD5Init,
                dim894JoeKuoD5Init,
                dim895JoeKuoD5Init,
                dim896JoeKuoD5Init,
                dim897JoeKuoD5Init,
                dim898JoeKuoD5Init,
                dim899JoeKuoD5Init,
                dim900JoeKuoD5Init,
                dim901JoeKuoD5Init,
                dim902JoeKuoD5Init,
                dim903JoeKuoD5Init,
                dim904JoeKuoD5Init,
                dim905JoeKuoD5Init,
                dim906JoeKuoD5Init,
                dim907JoeKuoD5Init,
                dim908JoeKuoD5Init,
                dim909JoeKuoD5Init,
                dim910JoeKuoD5Init,
                dim911JoeKuoD5Init,
                dim912JoeKuoD5Init,
                dim913JoeKuoD5Init,
                dim914JoeKuoD5Init,
                dim915JoeKuoD5Init,
                dim916JoeKuoD5Init,
                dim917JoeKuoD5Init,
                dim918JoeKuoD5Init,
                dim919JoeKuoD5Init,
                dim920JoeKuoD5Init,
                dim921JoeKuoD5Init,
                dim922JoeKuoD5Init,
                dim923JoeKuoD5Init,
                dim924JoeKuoD5Init,
                dim925JoeKuoD5Init,
                dim926JoeKuoD5Init,
                dim927JoeKuoD5Init,
                dim928JoeKuoD5Init,
                dim929JoeKuoD5Init,
                dim930JoeKuoD5Init,
                dim931JoeKuoD5Init,
                dim932JoeKuoD5Init,
                dim933JoeKuoD5Init,
                dim934JoeKuoD5Init,
                dim935JoeKuoD5Init,
                dim936JoeKuoD5Init,
                dim937JoeKuoD5Init,
                dim938JoeKuoD5Init,
                dim939JoeKuoD5Init,
                dim940JoeKuoD5Init,
                dim941JoeKuoD5Init,
                dim942JoeKuoD5Init,
                dim943JoeKuoD5Init,
                dim944JoeKuoD5Init,
                dim945JoeKuoD5Init,
                dim946JoeKuoD5Init,
                dim947JoeKuoD5Init,
                dim948JoeKuoD5Init,
                dim949JoeKuoD5Init,
                dim950JoeKuoD5Init,
                dim951JoeKuoD5Init,
                dim952JoeKuoD5Init,
                dim953JoeKuoD5Init,
                dim954JoeKuoD5Init,
                dim955JoeKuoD5Init,
                dim956JoeKuoD5Init,
                dim957JoeKuoD5Init,
                dim958JoeKuoD5Init,
                dim959JoeKuoD5Init,
                dim960JoeKuoD5Init,
                dim961JoeKuoD5Init,
                dim962JoeKuoD5Init,
                dim963JoeKuoD5Init,
                dim964JoeKuoD5Init,
                dim965JoeKuoD5Init,
                dim966JoeKuoD5Init,
                dim967JoeKuoD5Init,
                dim968JoeKuoD5Init,
                dim969JoeKuoD5Init,
                dim970JoeKuoD5Init,
                dim971JoeKuoD5Init,
                dim972JoeKuoD5Init,
                dim973JoeKuoD5Init,
                dim974JoeKuoD5Init,
                dim975JoeKuoD5Init,
                dim976JoeKuoD5Init,
                dim977JoeKuoD5Init,
                dim978JoeKuoD5Init,
                dim979JoeKuoD5Init,
                dim980JoeKuoD5Init,
                dim981JoeKuoD5Init,
                dim982JoeKuoD5Init,
                dim983JoeKuoD5Init,
                dim984JoeKuoD5Init,
                dim985JoeKuoD5Init,
                dim986JoeKuoD5Init,
                dim987JoeKuoD5Init,
                dim988JoeKuoD5Init,
                dim989JoeKuoD5Init,
                dim990JoeKuoD5Init,
                dim991JoeKuoD5Init,
                dim992JoeKuoD5Init,
                dim993JoeKuoD5Init,
                dim994JoeKuoD5Init,
                dim995JoeKuoD5Init,
                dim996JoeKuoD5Init,
                dim997JoeKuoD5Init,
                dim998JoeKuoD5Init,
                dim999JoeKuoD5Init,
                dim1000JoeKuoD5Init,
                dim1001JoeKuoD5Init,
                dim1002JoeKuoD5Init,
                dim1003JoeKuoD5Init,
                dim1004JoeKuoD5Init,
                dim1005JoeKuoD5Init,
                dim1006JoeKuoD5Init,
                dim1007JoeKuoD5Init,
                dim1008JoeKuoD5Init,
                dim1009JoeKuoD5Init,
                dim1010JoeKuoD5Init,
                dim1011JoeKuoD5Init,
                dim1012JoeKuoD5Init,
                dim1013JoeKuoD5Init,
                dim1014JoeKuoD5Init,
                dim1015JoeKuoD5Init,
                dim1016JoeKuoD5Init,
                dim1017JoeKuoD5Init,
                dim1018JoeKuoD5Init,
                dim1019JoeKuoD5Init,
                dim1020JoeKuoD5Init,
                dim1021JoeKuoD5Init,
                dim1022JoeKuoD5Init,
                dim1023JoeKuoD5Init,
                dim1024JoeKuoD5Init,
                dim1025JoeKuoD5Init,
                dim1026JoeKuoD5Init,
                dim1027JoeKuoD5Init,
                dim1028JoeKuoD5Init,
                dim1029JoeKuoD5Init,
                dim1030JoeKuoD5Init,
                dim1031JoeKuoD5Init,
                dim1032JoeKuoD5Init,
                dim1033JoeKuoD5Init,
                dim1034JoeKuoD5Init,
                dim1035JoeKuoD5Init,
                dim1036JoeKuoD5Init,
                dim1037JoeKuoD5Init,
                dim1038JoeKuoD5Init,
                dim1039JoeKuoD5Init,
                dim1040JoeKuoD5Init,
                dim1041JoeKuoD5Init,
                dim1042JoeKuoD5Init,
                dim1043JoeKuoD5Init,
                dim1044JoeKuoD5Init,
                dim1045JoeKuoD5Init,
                dim1046JoeKuoD5Init,
                dim1047JoeKuoD5Init,
                dim1048JoeKuoD5Init,
                dim1049JoeKuoD5Init,
                dim1050JoeKuoD5Init,
                dim1051JoeKuoD5Init,
                dim1052JoeKuoD5Init,
                dim1053JoeKuoD5Init,
                dim1054JoeKuoD5Init,
                dim1055JoeKuoD5Init,
                dim1056JoeKuoD5Init,
                dim1057JoeKuoD5Init,
                dim1058JoeKuoD5Init,
                dim1059JoeKuoD5Init,
                dim1060JoeKuoD5Init,
                dim1061JoeKuoD5Init,
                dim1062JoeKuoD5Init,
                dim1063JoeKuoD5Init,
                dim1064JoeKuoD5Init,
                dim1065JoeKuoD5Init,
                dim1066JoeKuoD5Init,
                dim1067JoeKuoD5Init,
                dim1068JoeKuoD5Init,
                dim1069JoeKuoD5Init,
                dim1070JoeKuoD5Init,
                dim1071JoeKuoD5Init,
                dim1072JoeKuoD5Init,
                dim1073JoeKuoD5Init,
                dim1074JoeKuoD5Init,
                dim1075JoeKuoD5Init,
                dim1076JoeKuoD5Init,
                dim1077JoeKuoD5Init,
                dim1078JoeKuoD5Init,
                dim1079JoeKuoD5Init,
                dim1080JoeKuoD5Init,
                dim1081JoeKuoD5Init,
                dim1082JoeKuoD5Init,
                dim1083JoeKuoD5Init,
                dim1084JoeKuoD5Init,
                dim1085JoeKuoD5Init,
                dim1086JoeKuoD5Init,
                dim1087JoeKuoD5Init,
                dim1088JoeKuoD5Init,
                dim1089JoeKuoD5Init,
                dim1090JoeKuoD5Init,
                dim1091JoeKuoD5Init,
                dim1092JoeKuoD5Init,
                dim1093JoeKuoD5Init,
                dim1094JoeKuoD5Init,
                dim1095JoeKuoD5Init,
                dim1096JoeKuoD5Init,
                dim1097JoeKuoD5Init,
                dim1098JoeKuoD5Init,
                dim1099JoeKuoD5Init,
                dim1100JoeKuoD5Init,
                dim1101JoeKuoD5Init,
                dim1102JoeKuoD5Init,
                dim1103JoeKuoD5Init,
                dim1104JoeKuoD5Init,
                dim1105JoeKuoD5Init,
                dim1106JoeKuoD5Init,
                dim1107JoeKuoD5Init,
                dim1108JoeKuoD5Init,
                dim1109JoeKuoD5Init,
                dim1110JoeKuoD5Init,
                dim1111JoeKuoD5Init,
                dim1112JoeKuoD5Init,
                dim1113JoeKuoD5Init,
                dim1114JoeKuoD5Init,
                dim1115JoeKuoD5Init,
                dim1116JoeKuoD5Init,
                dim1117JoeKuoD5Init,
                dim1118JoeKuoD5Init,
                dim1119JoeKuoD5Init,
                dim1120JoeKuoD5Init,
                dim1121JoeKuoD5Init,
                dim1122JoeKuoD5Init,
                dim1123JoeKuoD5Init,
                dim1124JoeKuoD5Init,
                dim1125JoeKuoD5Init,
                dim1126JoeKuoD5Init,
                dim1127JoeKuoD5Init,
                dim1128JoeKuoD5Init,
                dim1129JoeKuoD5Init,
                dim1130JoeKuoD5Init,
                dim1131JoeKuoD5Init,
                dim1132JoeKuoD5Init,
                dim1133JoeKuoD5Init,
                dim1134JoeKuoD5Init,
                dim1135JoeKuoD5Init,
                dim1136JoeKuoD5Init,
                dim1137JoeKuoD5Init,
                dim1138JoeKuoD5Init,
                dim1139JoeKuoD5Init,
                dim1140JoeKuoD5Init,
                dim1141JoeKuoD5Init,
                dim1142JoeKuoD5Init,
                dim1143JoeKuoD5Init,
                dim1144JoeKuoD5Init,
                dim1145JoeKuoD5Init,
                dim1146JoeKuoD5Init,
                dim1147JoeKuoD5Init,
                dim1148JoeKuoD5Init,
                dim1149JoeKuoD5Init,
                dim1150JoeKuoD5Init,
                dim1151JoeKuoD5Init,
                dim1152JoeKuoD5Init,
                dim1153JoeKuoD5Init,
                dim1154JoeKuoD5Init,
                dim1155JoeKuoD5Init,
                dim1156JoeKuoD5Init,
                dim1157JoeKuoD5Init,
                dim1158JoeKuoD5Init,
                dim1159JoeKuoD5Init,
                dim1160JoeKuoD5Init,
                dim1161JoeKuoD5Init,
                dim1162JoeKuoD5Init,
                dim1163JoeKuoD5Init,
                dim1164JoeKuoD5Init,
                dim1165JoeKuoD5Init,
                dim1166JoeKuoD5Init,
                dim1167JoeKuoD5Init,
                dim1168JoeKuoD5Init,
                dim1169JoeKuoD5Init,
                dim1170JoeKuoD5Init,
                dim1171JoeKuoD5Init,
                dim1172JoeKuoD5Init,
                dim1173JoeKuoD5Init,
                dim1174JoeKuoD5Init,
                dim1175JoeKuoD5Init,
                dim1176JoeKuoD5Init,
                dim1177JoeKuoD5Init,
                dim1178JoeKuoD5Init,
                dim1179JoeKuoD5Init,
                dim1180JoeKuoD5Init,
                dim1181JoeKuoD5Init,
                dim1182JoeKuoD5Init,
                dim1183JoeKuoD5Init,
                dim1184JoeKuoD5Init,
                dim1185JoeKuoD5Init,
                dim1186JoeKuoD5Init,
                dim1187JoeKuoD5Init,
                dim1188JoeKuoD5Init,
                dim1189JoeKuoD5Init,
                dim1190JoeKuoD5Init,
                dim1191JoeKuoD5Init,
                dim1192JoeKuoD5Init,
                dim1193JoeKuoD5Init,
                dim1194JoeKuoD5Init,
                dim1195JoeKuoD5Init,
                dim1196JoeKuoD5Init,
                dim1197JoeKuoD5Init,
                dim1198JoeKuoD5Init,
                dim1199JoeKuoD5Init,
                dim1200JoeKuoD5Init,
                dim1201JoeKuoD5Init,
                dim1202JoeKuoD5Init,
                dim1203JoeKuoD5Init,
                dim1204JoeKuoD5Init,
                dim1205JoeKuoD5Init,
                dim1206JoeKuoD5Init,
                dim1207JoeKuoD5Init,
                dim1208JoeKuoD5Init,
                dim1209JoeKuoD5Init,
                dim1210JoeKuoD5Init,
                dim1211JoeKuoD5Init,
                dim1212JoeKuoD5Init,
                dim1213JoeKuoD5Init,
                dim1214JoeKuoD5Init,
                dim1215JoeKuoD5Init,
                dim1216JoeKuoD5Init,
                dim1217JoeKuoD5Init,
                dim1218JoeKuoD5Init,
                dim1219JoeKuoD5Init,
                dim1220JoeKuoD5Init,
                dim1221JoeKuoD5Init,
                dim1222JoeKuoD5Init,
                dim1223JoeKuoD5Init,
                dim1224JoeKuoD5Init,
                dim1225JoeKuoD5Init,
                dim1226JoeKuoD5Init,
                dim1227JoeKuoD5Init,
                dim1228JoeKuoD5Init,
                dim1229JoeKuoD5Init,
                dim1230JoeKuoD5Init,
                dim1231JoeKuoD5Init,
                dim1232JoeKuoD5Init,
                dim1233JoeKuoD5Init,
                dim1234JoeKuoD5Init,
                dim1235JoeKuoD5Init,
                dim1236JoeKuoD5Init,
                dim1237JoeKuoD5Init,
                dim1238JoeKuoD5Init,
                dim1239JoeKuoD5Init,
                dim1240JoeKuoD5Init,
                dim1241JoeKuoD5Init,
                dim1242JoeKuoD5Init,
                dim1243JoeKuoD5Init,
                dim1244JoeKuoD5Init,
                dim1245JoeKuoD5Init,
                dim1246JoeKuoD5Init,
                dim1247JoeKuoD5Init,
                dim1248JoeKuoD5Init,
                dim1249JoeKuoD5Init,
                dim1250JoeKuoD5Init,
                dim1251JoeKuoD5Init,
                dim1252JoeKuoD5Init,
                dim1253JoeKuoD5Init,
                dim1254JoeKuoD5Init,
                dim1255JoeKuoD5Init,
                dim1256JoeKuoD5Init,
                dim1257JoeKuoD5Init,
                dim1258JoeKuoD5Init,
                dim1259JoeKuoD5Init,
                dim1260JoeKuoD5Init,
                dim1261JoeKuoD5Init,
                dim1262JoeKuoD5Init,
                dim1263JoeKuoD5Init,
                dim1264JoeKuoD5Init,
                dim1265JoeKuoD5Init,
                dim1266JoeKuoD5Init,
                dim1267JoeKuoD5Init,
                dim1268JoeKuoD5Init,
                dim1269JoeKuoD5Init,
                dim1270JoeKuoD5Init,
                dim1271JoeKuoD5Init,
                dim1272JoeKuoD5Init,
                dim1273JoeKuoD5Init,
                dim1274JoeKuoD5Init,
                dim1275JoeKuoD5Init,
                dim1276JoeKuoD5Init,
                dim1277JoeKuoD5Init,
                dim1278JoeKuoD5Init,
                dim1279JoeKuoD5Init,
                dim1280JoeKuoD5Init,
                dim1281JoeKuoD5Init,
                dim1282JoeKuoD5Init,
                dim1283JoeKuoD5Init,
                dim1284JoeKuoD5Init,
                dim1285JoeKuoD5Init,
                dim1286JoeKuoD5Init,
                dim1287JoeKuoD5Init,
                dim1288JoeKuoD5Init,
                dim1289JoeKuoD5Init,
                dim1290JoeKuoD5Init,
                dim1291JoeKuoD5Init,
                dim1292JoeKuoD5Init,
                dim1293JoeKuoD5Init,
                dim1294JoeKuoD5Init,
                dim1295JoeKuoD5Init,
                dim1296JoeKuoD5Init,
                dim1297JoeKuoD5Init,
                dim1298JoeKuoD5Init,
                dim1299JoeKuoD5Init,
                dim1300JoeKuoD5Init,
                dim1301JoeKuoD5Init,
                dim1302JoeKuoD5Init,
                dim1303JoeKuoD5Init,
                dim1304JoeKuoD5Init,
                dim1305JoeKuoD5Init,
                dim1306JoeKuoD5Init,
                dim1307JoeKuoD5Init,
                dim1308JoeKuoD5Init,
                dim1309JoeKuoD5Init,
                dim1310JoeKuoD5Init,
                dim1311JoeKuoD5Init,
                dim1312JoeKuoD5Init,
                dim1313JoeKuoD5Init,
                dim1314JoeKuoD5Init,
                dim1315JoeKuoD5Init,
                dim1316JoeKuoD5Init,
                dim1317JoeKuoD5Init,
                dim1318JoeKuoD5Init,
                dim1319JoeKuoD5Init,
                dim1320JoeKuoD5Init,
                dim1321JoeKuoD5Init,
                dim1322JoeKuoD5Init,
                dim1323JoeKuoD5Init,
                dim1324JoeKuoD5Init,
                dim1325JoeKuoD5Init,
                dim1326JoeKuoD5Init,
                dim1327JoeKuoD5Init,
                dim1328JoeKuoD5Init,
                dim1329JoeKuoD5Init,
                dim1330JoeKuoD5Init,
                dim1331JoeKuoD5Init,
                dim1332JoeKuoD5Init,
                dim1333JoeKuoD5Init,
                dim1334JoeKuoD5Init,
                dim1335JoeKuoD5Init,
                dim1336JoeKuoD5Init,
                dim1337JoeKuoD5Init,
                dim1338JoeKuoD5Init,
                dim1339JoeKuoD5Init,
                dim1340JoeKuoD5Init,
                dim1341JoeKuoD5Init,
                dim1342JoeKuoD5Init,
                dim1343JoeKuoD5Init,
                dim1344JoeKuoD5Init,
                dim1345JoeKuoD5Init,
                dim1346JoeKuoD5Init,
                dim1347JoeKuoD5Init,
                dim1348JoeKuoD5Init,
                dim1349JoeKuoD5Init,
                dim1350JoeKuoD5Init,
                dim1351JoeKuoD5Init,
                dim1352JoeKuoD5Init,
                dim1353JoeKuoD5Init,
                dim1354JoeKuoD5Init,
                dim1355JoeKuoD5Init,
                dim1356JoeKuoD5Init,
                dim1357JoeKuoD5Init,
                dim1358JoeKuoD5Init,
                dim1359JoeKuoD5Init,
                dim1360JoeKuoD5Init,
                dim1361JoeKuoD5Init,
                dim1362JoeKuoD5Init,
                dim1363JoeKuoD5Init,
                dim1364JoeKuoD5Init,
                dim1365JoeKuoD5Init,
                dim1366JoeKuoD5Init,
                dim1367JoeKuoD5Init,
                dim1368JoeKuoD5Init,
                dim1369JoeKuoD5Init,
                dim1370JoeKuoD5Init,
                dim1371JoeKuoD5Init,
                dim1372JoeKuoD5Init,
                dim1373JoeKuoD5Init,
                dim1374JoeKuoD5Init,
                dim1375JoeKuoD5Init,
                dim1376JoeKuoD5Init,
                dim1377JoeKuoD5Init,
                dim1378JoeKuoD5Init,
                dim1379JoeKuoD5Init,
                dim1380JoeKuoD5Init,
                dim1381JoeKuoD5Init,
                dim1382JoeKuoD5Init,
                dim1383JoeKuoD5Init,
                dim1384JoeKuoD5Init,
                dim1385JoeKuoD5Init,
                dim1386JoeKuoD5Init,
                dim1387JoeKuoD5Init,
                dim1388JoeKuoD5Init,
                dim1389JoeKuoD5Init,
                dim1390JoeKuoD5Init,
                dim1391JoeKuoD5Init,
                dim1392JoeKuoD5Init,
                dim1393JoeKuoD5Init,
                dim1394JoeKuoD5Init,
                dim1395JoeKuoD5Init,
                dim1396JoeKuoD5Init,
                dim1397JoeKuoD5Init,
                dim1398JoeKuoD5Init,
                dim1399JoeKuoD5Init,
                dim1400JoeKuoD5Init,
                dim1401JoeKuoD5Init,
                dim1402JoeKuoD5Init,
                dim1403JoeKuoD5Init,
                dim1404JoeKuoD5Init,
                dim1405JoeKuoD5Init,
                dim1406JoeKuoD5Init,
                dim1407JoeKuoD5Init,
                dim1408JoeKuoD5Init,
                dim1409JoeKuoD5Init,
                dim1410JoeKuoD5Init,
                dim1411JoeKuoD5Init,
                dim1412JoeKuoD5Init,
                dim1413JoeKuoD5Init,
                dim1414JoeKuoD5Init,
                dim1415JoeKuoD5Init,
                dim1416JoeKuoD5Init,
                dim1417JoeKuoD5Init,
                dim1418JoeKuoD5Init,
                dim1419JoeKuoD5Init,
                dim1420JoeKuoD5Init,
                dim1421JoeKuoD5Init,
                dim1422JoeKuoD5Init,
                dim1423JoeKuoD5Init,
                dim1424JoeKuoD5Init,
                dim1425JoeKuoD5Init,
                dim1426JoeKuoD5Init,
                dim1427JoeKuoD5Init,
                dim1428JoeKuoD5Init,
                dim1429JoeKuoD5Init,
                dim1430JoeKuoD5Init,
                dim1431JoeKuoD5Init,
                dim1432JoeKuoD5Init,
                dim1433JoeKuoD5Init,
                dim1434JoeKuoD5Init,
                dim1435JoeKuoD5Init,
                dim1436JoeKuoD5Init,
                dim1437JoeKuoD5Init,
                dim1438JoeKuoD5Init,
                dim1439JoeKuoD5Init,
                dim1440JoeKuoD5Init,
                dim1441JoeKuoD5Init,
                dim1442JoeKuoD5Init,
                dim1443JoeKuoD5Init,
                dim1444JoeKuoD5Init,
                dim1445JoeKuoD5Init,
                dim1446JoeKuoD5Init,
                dim1447JoeKuoD5Init,
                dim1448JoeKuoD5Init,
                dim1449JoeKuoD5Init,
                dim1450JoeKuoD5Init,
                dim1451JoeKuoD5Init,
                dim1452JoeKuoD5Init,
                dim1453JoeKuoD5Init,
                dim1454JoeKuoD5Init,
                dim1455JoeKuoD5Init,
                dim1456JoeKuoD5Init,
                dim1457JoeKuoD5Init,
                dim1458JoeKuoD5Init,
                dim1459JoeKuoD5Init,
                dim1460JoeKuoD5Init,
                dim1461JoeKuoD5Init,
                dim1462JoeKuoD5Init,
                dim1463JoeKuoD5Init,
                dim1464JoeKuoD5Init,
                dim1465JoeKuoD5Init,
                dim1466JoeKuoD5Init,
                dim1467JoeKuoD5Init,
                dim1468JoeKuoD5Init,
                dim1469JoeKuoD5Init,
                dim1470JoeKuoD5Init,
                dim1471JoeKuoD5Init,
                dim1472JoeKuoD5Init,
                dim1473JoeKuoD5Init,
                dim1474JoeKuoD5Init,
                dim1475JoeKuoD5Init,
                dim1476JoeKuoD5Init,
                dim1477JoeKuoD5Init,
                dim1478JoeKuoD5Init,
                dim1479JoeKuoD5Init,
                dim1480JoeKuoD5Init,
                dim1481JoeKuoD5Init,
                dim1482JoeKuoD5Init,
                dim1483JoeKuoD5Init,
                dim1484JoeKuoD5Init,
                dim1485JoeKuoD5Init,
                dim1486JoeKuoD5Init,
                dim1487JoeKuoD5Init,
                dim1488JoeKuoD5Init,
                dim1489JoeKuoD5Init,
                dim1490JoeKuoD5Init,
                dim1491JoeKuoD5Init,
                dim1492JoeKuoD5Init,
                dim1493JoeKuoD5Init,
                dim1494JoeKuoD5Init,
                dim1495JoeKuoD5Init,
                dim1496JoeKuoD5Init,
                dim1497JoeKuoD5Init,
                dim1498JoeKuoD5Init,
                dim1499JoeKuoD5Init,
                dim1500JoeKuoD5Init,
                dim1501JoeKuoD5Init,
                dim1502JoeKuoD5Init,
                dim1503JoeKuoD5Init,
                dim1504JoeKuoD5Init,
                dim1505JoeKuoD5Init,
                dim1506JoeKuoD5Init,
                dim1507JoeKuoD5Init,
                dim1508JoeKuoD5Init,
                dim1509JoeKuoD5Init,
                dim1510JoeKuoD5Init,
                dim1511JoeKuoD5Init,
                dim1512JoeKuoD5Init,
                dim1513JoeKuoD5Init,
                dim1514JoeKuoD5Init,
                dim1515JoeKuoD5Init,
                dim1516JoeKuoD5Init,
                dim1517JoeKuoD5Init,
                dim1518JoeKuoD5Init,
                dim1519JoeKuoD5Init,
                dim1520JoeKuoD5Init,
                dim1521JoeKuoD5Init,
                dim1522JoeKuoD5Init,
                dim1523JoeKuoD5Init,
                dim1524JoeKuoD5Init,
                dim1525JoeKuoD5Init,
                dim1526JoeKuoD5Init,
                dim1527JoeKuoD5Init,
                dim1528JoeKuoD5Init,
                dim1529JoeKuoD5Init,
                dim1530JoeKuoD5Init,
                dim1531JoeKuoD5Init,
                dim1532JoeKuoD5Init,
                dim1533JoeKuoD5Init,
                dim1534JoeKuoD5Init,
                dim1535JoeKuoD5Init,
                dim1536JoeKuoD5Init,
                dim1537JoeKuoD5Init,
                dim1538JoeKuoD5Init,
                dim1539JoeKuoD5Init,
                dim1540JoeKuoD5Init,
                dim1541JoeKuoD5Init,
                dim1542JoeKuoD5Init,
                dim1543JoeKuoD5Init,
                dim1544JoeKuoD5Init,
                dim1545JoeKuoD5Init,
                dim1546JoeKuoD5Init,
                dim1547JoeKuoD5Init,
                dim1548JoeKuoD5Init,
                dim1549JoeKuoD5Init,
                dim1550JoeKuoD5Init,
                dim1551JoeKuoD5Init,
                dim1552JoeKuoD5Init,
                dim1553JoeKuoD5Init,
                dim1554JoeKuoD5Init,
                dim1555JoeKuoD5Init,
                dim1556JoeKuoD5Init,
                dim1557JoeKuoD5Init,
                dim1558JoeKuoD5Init,
                dim1559JoeKuoD5Init,
                dim1560JoeKuoD5Init,
                dim1561JoeKuoD5Init,
                dim1562JoeKuoD5Init,
                dim1563JoeKuoD5Init,
                dim1564JoeKuoD5Init,
                dim1565JoeKuoD5Init,
                dim1566JoeKuoD5Init,
                dim1567JoeKuoD5Init,
                dim1568JoeKuoD5Init,
                dim1569JoeKuoD5Init,
                dim1570JoeKuoD5Init,
                dim1571JoeKuoD5Init,
                dim1572JoeKuoD5Init,
                dim1573JoeKuoD5Init,
                dim1574JoeKuoD5Init,
                dim1575JoeKuoD5Init,
                dim1576JoeKuoD5Init,
                dim1577JoeKuoD5Init,
                dim1578JoeKuoD5Init,
                dim1579JoeKuoD5Init,
                dim1580JoeKuoD5Init,
                dim1581JoeKuoD5Init,
                dim1582JoeKuoD5Init,
                dim1583JoeKuoD5Init,
                dim1584JoeKuoD5Init,
                dim1585JoeKuoD5Init,
                dim1586JoeKuoD5Init,
                dim1587JoeKuoD5Init,
                dim1588JoeKuoD5Init,
                dim1589JoeKuoD5Init,
                dim1590JoeKuoD5Init,
                dim1591JoeKuoD5Init,
                dim1592JoeKuoD5Init,
                dim1593JoeKuoD5Init,
                dim1594JoeKuoD5Init,
                dim1595JoeKuoD5Init,
                dim1596JoeKuoD5Init,
                dim1597JoeKuoD5Init,
                dim1598JoeKuoD5Init,
                dim1599JoeKuoD5Init,
                dim1600JoeKuoD5Init,
                dim1601JoeKuoD5Init,
                dim1602JoeKuoD5Init,
                dim1603JoeKuoD5Init,
                dim1604JoeKuoD5Init,
                dim1605JoeKuoD5Init,
                dim1606JoeKuoD5Init,
                dim1607JoeKuoD5Init,
                dim1608JoeKuoD5Init,
                dim1609JoeKuoD5Init,
                dim1610JoeKuoD5Init,
                dim1611JoeKuoD5Init,
                dim1612JoeKuoD5Init,
                dim1613JoeKuoD5Init,
                dim1614JoeKuoD5Init,
                dim1615JoeKuoD5Init,
                dim1616JoeKuoD5Init,
                dim1617JoeKuoD5Init,
                dim1618JoeKuoD5Init,
                dim1619JoeKuoD5Init,
                dim1620JoeKuoD5Init,
                dim1621JoeKuoD5Init,
                dim1622JoeKuoD5Init,
                dim1623JoeKuoD5Init,
                dim1624JoeKuoD5Init,
                dim1625JoeKuoD5Init,
                dim1626JoeKuoD5Init,
                dim1627JoeKuoD5Init,
                dim1628JoeKuoD5Init,
                dim1629JoeKuoD5Init,
                dim1630JoeKuoD5Init,
                dim1631JoeKuoD5Init,
                dim1632JoeKuoD5Init,
                dim1633JoeKuoD5Init,
                dim1634JoeKuoD5Init,
                dim1635JoeKuoD5Init,
                dim1636JoeKuoD5Init,
                dim1637JoeKuoD5Init,
                dim1638JoeKuoD5Init,
                dim1639JoeKuoD5Init,
                dim1640JoeKuoD5Init,
                dim1641JoeKuoD5Init,
                dim1642JoeKuoD5Init,
                dim1643JoeKuoD5Init,
                dim1644JoeKuoD5Init,
                dim1645JoeKuoD5Init,
                dim1646JoeKuoD5Init,
                dim1647JoeKuoD5Init,
                dim1648JoeKuoD5Init,
                dim1649JoeKuoD5Init,
                dim1650JoeKuoD5Init,
                dim1651JoeKuoD5Init,
                dim1652JoeKuoD5Init,
                dim1653JoeKuoD5Init,
                dim1654JoeKuoD5Init,
                dim1655JoeKuoD5Init,
                dim1656JoeKuoD5Init,
                dim1657JoeKuoD5Init,
                dim1658JoeKuoD5Init,
                dim1659JoeKuoD5Init,
                dim1660JoeKuoD5Init,
                dim1661JoeKuoD5Init,
                dim1662JoeKuoD5Init,
                dim1663JoeKuoD5Init,
                dim1664JoeKuoD5Init,
                dim1665JoeKuoD5Init,
                dim1666JoeKuoD5Init,
                dim1667JoeKuoD5Init,
                dim1668JoeKuoD5Init,
                dim1669JoeKuoD5Init,
                dim1670JoeKuoD5Init,
                dim1671JoeKuoD5Init,
                dim1672JoeKuoD5Init,
                dim1673JoeKuoD5Init,
                dim1674JoeKuoD5Init,
                dim1675JoeKuoD5Init,
                dim1676JoeKuoD5Init,
                dim1677JoeKuoD5Init,
                dim1678JoeKuoD5Init,
                dim1679JoeKuoD5Init,
                dim1680JoeKuoD5Init,
                dim1681JoeKuoD5Init,
                dim1682JoeKuoD5Init,
                dim1683JoeKuoD5Init,
                dim1684JoeKuoD5Init,
                dim1685JoeKuoD5Init,
                dim1686JoeKuoD5Init,
                dim1687JoeKuoD5Init,
                dim1688JoeKuoD5Init,
                dim1689JoeKuoD5Init,
                dim1690JoeKuoD5Init,
                dim1691JoeKuoD5Init,
                dim1692JoeKuoD5Init,
                dim1693JoeKuoD5Init,
                dim1694JoeKuoD5Init,
                dim1695JoeKuoD5Init,
                dim1696JoeKuoD5Init,
                dim1697JoeKuoD5Init,
                dim1698JoeKuoD5Init,
                dim1699JoeKuoD5Init,
                dim1700JoeKuoD5Init,
                dim1701JoeKuoD5Init,
                dim1702JoeKuoD5Init,
                dim1703JoeKuoD5Init,
                dim1704JoeKuoD5Init,
                dim1705JoeKuoD5Init,
                dim1706JoeKuoD5Init,
                dim1707JoeKuoD5Init,
                dim1708JoeKuoD5Init,
                dim1709JoeKuoD5Init,
                dim1710JoeKuoD5Init,
                dim1711JoeKuoD5Init,
                dim1712JoeKuoD5Init,
                dim1713JoeKuoD5Init,
                dim1714JoeKuoD5Init,
                dim1715JoeKuoD5Init,
                dim1716JoeKuoD5Init,
                dim1717JoeKuoD5Init,
                dim1718JoeKuoD5Init,
                dim1719JoeKuoD5Init,
                dim1720JoeKuoD5Init,
                dim1721JoeKuoD5Init,
                dim1722JoeKuoD5Init,
                dim1723JoeKuoD5Init,
                dim1724JoeKuoD5Init,
                dim1725JoeKuoD5Init,
                dim1726JoeKuoD5Init,
                dim1727JoeKuoD5Init,
                dim1728JoeKuoD5Init,
                dim1729JoeKuoD5Init,
                dim1730JoeKuoD5Init,
                dim1731JoeKuoD5Init,
                dim1732JoeKuoD5Init,
                dim1733JoeKuoD5Init,
                dim1734JoeKuoD5Init,
                dim1735JoeKuoD5Init,
                dim1736JoeKuoD5Init,
                dim1737JoeKuoD5Init,
                dim1738JoeKuoD5Init,
                dim1739JoeKuoD5Init,
                dim1740JoeKuoD5Init,
                dim1741JoeKuoD5Init,
                dim1742JoeKuoD5Init,
                dim1743JoeKuoD5Init,
                dim1744JoeKuoD5Init,
                dim1745JoeKuoD5Init,
                dim1746JoeKuoD5Init,
                dim1747JoeKuoD5Init,
                dim1748JoeKuoD5Init,
                dim1749JoeKuoD5Init,
                dim1750JoeKuoD5Init,
                dim1751JoeKuoD5Init,
                dim1752JoeKuoD5Init,
                dim1753JoeKuoD5Init,
                dim1754JoeKuoD5Init,
                dim1755JoeKuoD5Init,
                dim1756JoeKuoD5Init,
                dim1757JoeKuoD5Init,
                dim1758JoeKuoD5Init,
                dim1759JoeKuoD5Init,
                dim1760JoeKuoD5Init,
                dim1761JoeKuoD5Init,
                dim1762JoeKuoD5Init,
                dim1763JoeKuoD5Init,
                dim1764JoeKuoD5Init,
                dim1765JoeKuoD5Init,
                dim1766JoeKuoD5Init,
                dim1767JoeKuoD5Init,
                dim1768JoeKuoD5Init,
                dim1769JoeKuoD5Init,
                dim1770JoeKuoD5Init,
                dim1771JoeKuoD5Init,
                dim1772JoeKuoD5Init,
                dim1773JoeKuoD5Init,
                dim1774JoeKuoD5Init,
                dim1775JoeKuoD5Init,
                dim1776JoeKuoD5Init,
                dim1777JoeKuoD5Init,
                dim1778JoeKuoD5Init,
                dim1779JoeKuoD5Init,
                dim1780JoeKuoD5Init,
                dim1781JoeKuoD5Init,
                dim1782JoeKuoD5Init,
                dim1783JoeKuoD5Init,
                dim1784JoeKuoD5Init,
                dim1785JoeKuoD5Init,
                dim1786JoeKuoD5Init,
                dim1787JoeKuoD5Init,
                dim1788JoeKuoD5Init,
                dim1789JoeKuoD5Init,
                dim1790JoeKuoD5Init,
                dim1791JoeKuoD5Init,
                dim1792JoeKuoD5Init,
                dim1793JoeKuoD5Init,
                dim1794JoeKuoD5Init,
                dim1795JoeKuoD5Init,
                dim1796JoeKuoD5Init,
                dim1797JoeKuoD5Init,
                dim1798JoeKuoD5Init,
                dim1799JoeKuoD5Init,
                dim1800JoeKuoD5Init,
                dim1801JoeKuoD5Init,
                dim1802JoeKuoD5Init,
                dim1803JoeKuoD5Init,
                dim1804JoeKuoD5Init,
                dim1805JoeKuoD5Init,
                dim1806JoeKuoD5Init,
                dim1807JoeKuoD5Init,
                dim1808JoeKuoD5Init,
                dim1809JoeKuoD5Init,
                dim1810JoeKuoD5Init,
                dim1811JoeKuoD5Init,
                dim1812JoeKuoD5Init,
                dim1813JoeKuoD5Init,
                dim1814JoeKuoD5Init,
                dim1815JoeKuoD5Init,
                dim1816JoeKuoD5Init,
                dim1817JoeKuoD5Init,
                dim1818JoeKuoD5Init,
                dim1819JoeKuoD5Init,
                dim1820JoeKuoD5Init,
                dim1821JoeKuoD5Init,
                dim1822JoeKuoD5Init,
                dim1823JoeKuoD5Init,
                dim1824JoeKuoD5Init,
                dim1825JoeKuoD5Init,
                dim1826JoeKuoD5Init,
                dim1827JoeKuoD5Init,
                dim1828JoeKuoD5Init,
                dim1829JoeKuoD5Init,
                dim1830JoeKuoD5Init,
                dim1831JoeKuoD5Init,
                dim1832JoeKuoD5Init,
                dim1833JoeKuoD5Init,
                dim1834JoeKuoD5Init,
                dim1835JoeKuoD5Init,
                dim1836JoeKuoD5Init,
                dim1837JoeKuoD5Init,
                dim1838JoeKuoD5Init,
                dim1839JoeKuoD5Init,
                dim1840JoeKuoD5Init,
                dim1841JoeKuoD5Init,
                dim1842JoeKuoD5Init,
                dim1843JoeKuoD5Init,
                dim1844JoeKuoD5Init,
                dim1845JoeKuoD5Init,
                dim1846JoeKuoD5Init,
                dim1847JoeKuoD5Init,
                dim1848JoeKuoD5Init,
                dim1849JoeKuoD5Init,
                dim1850JoeKuoD5Init,
                dim1851JoeKuoD5Init,
                dim1852JoeKuoD5Init,
                dim1853JoeKuoD5Init,
                dim1854JoeKuoD5Init,
                dim1855JoeKuoD5Init,
                dim1856JoeKuoD5Init,
                dim1857JoeKuoD5Init,
                dim1858JoeKuoD5Init,
                dim1859JoeKuoD5Init,
                dim1860JoeKuoD5Init,
                dim1861JoeKuoD5Init,
                dim1862JoeKuoD5Init,
                dim1863JoeKuoD5Init,
                dim1864JoeKuoD5Init,
                dim1865JoeKuoD5Init,
                dim1866JoeKuoD5Init,
                dim1867JoeKuoD5Init,
                dim1868JoeKuoD5Init,
                dim1869JoeKuoD5Init,
                dim1870JoeKuoD5Init,
                dim1871JoeKuoD5Init,
                dim1872JoeKuoD5Init,
                dim1873JoeKuoD5Init,
                dim1874JoeKuoD5Init,
                dim1875JoeKuoD5Init,
                dim1876JoeKuoD5Init,
                dim1877JoeKuoD5Init,
                dim1878JoeKuoD5Init,
                dim1879JoeKuoD5Init,
                dim1880JoeKuoD5Init,
                dim1881JoeKuoD5Init,
                dim1882JoeKuoD5Init,
                dim1883JoeKuoD5Init,
                dim1884JoeKuoD5Init,
                dim1885JoeKuoD5Init,
                dim1886JoeKuoD5Init,
                dim1887JoeKuoD5Init,
                dim1888JoeKuoD5Init,
                dim1889JoeKuoD5Init,
                dim1890JoeKuoD5Init,
                dim1891JoeKuoD5Init,
                dim1892JoeKuoD5Init,
                dim1893JoeKuoD5Init,
                dim1894JoeKuoD5Init,
                dim1895JoeKuoD5Init,
                dim1896JoeKuoD5Init,
                dim1897JoeKuoD5Init,
                dim1898JoeKuoD5Init,
                dim1899JoeKuoD5Init,
                dim1900JoeKuoD5Init,
                dim1901JoeKuoD5Init,
                dim1902JoeKuoD5Init,
                dim1903JoeKuoD5Init,
                dim1904JoeKuoD5Init,
                dim1905JoeKuoD5Init,
                dim1906JoeKuoD5Init,
                dim1907JoeKuoD5Init,
                dim1908JoeKuoD5Init,
                dim1909JoeKuoD5Init,
                dim1910JoeKuoD5Init,
                dim1911JoeKuoD5Init,
                dim1912JoeKuoD5Init,
                dim1913JoeKuoD5Init,
                dim1914JoeKuoD5Init,
                dim1915JoeKuoD5Init,
                dim1916JoeKuoD5Init,
                dim1917JoeKuoD5Init,
                dim1918JoeKuoD5Init,
                dim1919JoeKuoD5Init,
                dim1920JoeKuoD5Init,
                dim1921JoeKuoD5Init,
                dim1922JoeKuoD5Init,
                dim1923JoeKuoD5Init,
                dim1924JoeKuoD5Init,
                dim1925JoeKuoD5Init,
                dim1926JoeKuoD5Init,
                dim1927JoeKuoD5Init,
                dim1928JoeKuoD5Init,
                dim1929JoeKuoD5Init,
                dim1930JoeKuoD5Init,
                dim1931JoeKuoD5Init,
                dim1932JoeKuoD5Init,
                dim1933JoeKuoD5Init,
                dim1934JoeKuoD5Init,
                dim1935JoeKuoD5Init,
                dim1936JoeKuoD5Init,
                dim1937JoeKuoD5Init,
                dim1938JoeKuoD5Init,
                dim1939JoeKuoD5Init,
                dim1940JoeKuoD5Init,
                dim1941JoeKuoD5Init,
                dim1942JoeKuoD5Init,
                dim1943JoeKuoD5Init,
                dim1944JoeKuoD5Init,
                dim1945JoeKuoD5Init,
                dim1946JoeKuoD5Init,
                dim1947JoeKuoD5Init,
                dim1948JoeKuoD5Init,
                dim1949JoeKuoD5Init,
                dim1950JoeKuoD5Init,
                dim1951JoeKuoD5Init,
                dim1952JoeKuoD5Init,
                dim1953JoeKuoD5Init,
                dim1954JoeKuoD5Init,
                dim1955JoeKuoD5Init,
                dim1956JoeKuoD5Init,
                dim1957JoeKuoD5Init,
                dim1958JoeKuoD5Init,
                dim1959JoeKuoD5Init,
                dim1960JoeKuoD5Init,
                dim1961JoeKuoD5Init,
                dim1962JoeKuoD5Init,
                dim1963JoeKuoD5Init,
                dim1964JoeKuoD5Init,
                dim1965JoeKuoD5Init,
                dim1966JoeKuoD5Init,
                dim1967JoeKuoD5Init,
                dim1968JoeKuoD5Init,
                dim1969JoeKuoD5Init,
                dim1970JoeKuoD5Init,
                dim1971JoeKuoD5Init,
                dim1972JoeKuoD5Init,
                dim1973JoeKuoD5Init,
                dim1974JoeKuoD5Init,
                dim1975JoeKuoD5Init,
                dim1976JoeKuoD5Init,
                dim1977JoeKuoD5Init,
                dim1978JoeKuoD5Init,
                dim1979JoeKuoD5Init,
                dim1980JoeKuoD5Init,
                dim1981JoeKuoD5Init,
                dim1982JoeKuoD5Init,
                dim1983JoeKuoD5Init,
                dim1984JoeKuoD5Init,
                dim1985JoeKuoD5Init,
                dim1986JoeKuoD5Init,
                dim1987JoeKuoD5Init,
                dim1988JoeKuoD5Init,
                dim1989JoeKuoD5Init,
                dim1990JoeKuoD5Init,
                dim1991JoeKuoD5Init,
                dim1992JoeKuoD5Init,
                dim1993JoeKuoD5Init,
                dim1994JoeKuoD5Init,
                dim1995JoeKuoD5Init,
                dim1996JoeKuoD5Init,
                dim1997JoeKuoD5Init,
                dim1998JoeKuoD5Init,
                dim1999JoeKuoD5Init
            };

    }

    SobolRsg::SobolRsg(Size dimensionality,
                       unsigned long seed,
                       DirectionIntegers directionIntegers,
                       bool useGrayCode)
    : dimensionality_(dimensionality), sequence_(std::vector<Real>(dimensionality), 1.0),
      integerSequence_(dimensionality, 0),
      directionIntegers_(dimensionality, std::vector<std::uint32_t>(32)),
      useGrayCode_(useGrayCode) {

        QL_REQUIRE(dimensionality>0,
                   "dimensionality must be greater than 0");
        QL_REQUIRE(dimensionality<=PPMT_MAX_DIM,
                   "dimensionality " << dimensionality
                   << " exceeds the number of available "
                   << "primitive polynomials modulo two ("
                   << PPMT_MAX_DIM << ")");

        // initializes coefficient array of the k-th primitive polynomial
        // and degree of the k-th primitive polynomial
        std::vector<unsigned int> degree(dimensionality_);
        std::vector<long> ppmt(dimensionality_);

        bool useAltPolynomials = false;

        if (directionIntegers == Kuo || directionIntegers == Kuo2 || directionIntegers == Kuo3
            || directionIntegers == SobolLevitan || directionIntegers == SobolLevitanLemieux)
            useAltPolynomials = true;

        // degree 0 is not used
        ppmt[0]=0;
        degree[0]=0;
        Size k, index;
        unsigned int currentDegree=1;
        k=1;
        index=0;

        unsigned int altDegree = useAltPolynomials ? maxAltDegree : 0;

        for (; k<std::min<Size>(dimensionality_,altDegree); k++,index++)
        {
            ppmt[k] = AltPrimitivePolynomials[currentDegree-1][index];
            if (ppmt[k]==-1)
            {
                ++currentDegree;
                index=0;
                ppmt[k] = AltPrimitivePolynomials[currentDegree-1][index];
            }

            degree[k] = currentDegree;
        }



        for (; k<dimensionality_; k++,index++)
        {
            ppmt[k] = PrimitivePolynomials[currentDegree-1][index];
            if (ppmt[k]==-1)
            {
                ++currentDegree;
                index=0;
                ppmt[k] = PrimitivePolynomials[currentDegree-1][index];
            }
            degree[k] = currentDegree;

        }

        // initializes 32 direction integers for each dimension
        // and store them into directionIntegers_[dimensionality_][32]
        //
        // In each dimension k with its associated primitive polynomial,
        // the first degree_[k] direction integers can be chosen freely
        // provided that only the l leftmost bits can be non-zero, and
        // that the l-th leftmost bit must be set

        // degenerate (no free direction integers) first dimension
        int j;
        for (j=0; j<32; j++)
            directionIntegers_[0][j] = (1UL<<(32-j-1));


        Size maxTabulated = 0;
        // dimensions from 2 (k=1) to maxTabulated (k=maxTabulated-1) included
        // are initialized from tabulated coefficients
        switch (directionIntegers) {
            case Unit:
                maxTabulated=dimensionality_;
                for (k=1; k<maxTabulated; k++) {
                    for (Size l=1; l<=degree[k]; l++) {
                        directionIntegers_[k][l-1] = 1UL;
                        directionIntegers_[k][l-1] <<= (32-l);
                    }
                }
                break;
            case Jaeckel:
                // maxTabulated=32
                maxTabulated = sizeof(initializers)/sizeof(std::uint32_t *)+1;
                for (k=1; k<std::min(dimensionality_, maxTabulated); k++) {
                    j = 0;
                    // 0UL marks coefficients' end for a given dimension
                    while (initializers[k-1][j] != 0UL) {
                        directionIntegers_[k][j] = initializers[k-1][j];
                        directionIntegers_[k][j] <<= (32-j-1);
                        j++;
                    }
                }
                break;
            case SobolLevitan:
                // maxTabulated=40
                maxTabulated = sizeof(SLinitializers)/sizeof(std::uint32_t *)+1;
                for (k=1; k<std::min(dimensionality_, maxTabulated); k++) {
                    j = 0;
                    // 0UL marks coefficients' end for a given dimension
                    while (SLinitializers[k-1][j] != 0UL) {
                        directionIntegers_[k][j] = SLinitializers[k-1][j];
                        directionIntegers_[k][j] <<= (32-j-1);
                        j++;
                    }
                }
                break;
            case SobolLevitanLemieux:
                // maxTabulated=360
                maxTabulated = sizeof(Linitializers)/sizeof(std::uint32_t *)+1;
                for (k=1; k<std::min(dimensionality_, maxTabulated); k++) {
                    j = 0;
                    // 0UL marks coefficients' end for a given dimension
                    while (Linitializers[k-1][j] != 0UL) {
                        directionIntegers_[k][j] = Linitializers[k-1][j];
                        directionIntegers_[k][j] <<= (32-j-1);
                        j++;
                    }
                }
                break;
            case JoeKuoD5:
                // maxTabulated=1898
                maxTabulated = sizeof(JoeKuoD5initializers)/sizeof(std::uint32_t *)+1;
                for (k=1; k<std::min(dimensionality_, maxTabulated); k++) {
                    j = 0;
                    // 0UL marks coefficients' end for a given dimension
                    while (JoeKuoD5initializers[k-1][j] != 0UL) {
                        directionIntegers_[k][j] = JoeKuoD5initializers[k-1][j];
                        directionIntegers_[k][j] <<= (32-j-1);
                        j++;
                    }
                }
                break;
            case JoeKuoD6:
                // maxTabulated=1799
                maxTabulated = sizeof(JoeKuoD6initializers)/sizeof(std::uint32_t *)+1;
                for (k=1; k<std::min(dimensionality_, maxTabulated); k++) {
                    j = 0;
                    // 0UL marks coefficients' end for a given dimension
                    while (JoeKuoD6initializers[k-1][j] != 0UL) {
                        directionIntegers_[k][j] = JoeKuoD6initializers[k-1][j];
                        directionIntegers_[k][j] <<= (32-j-1);
                        j++;
                    }
                }
                break;
            case JoeKuoD7:
                // maxTabulated=1898
                maxTabulated = sizeof(JoeKuoD7initializers)/sizeof(std::uint32_t *)+1;
                for (k=1; k<std::min(dimensionality_, maxTabulated); k++) {
                    j = 0;
                    // 0UL marks coefficients' end for a given dimension
                    while (JoeKuoD7initializers[k-1][j] != 0UL) {
                        directionIntegers_[k][j] = JoeKuoD7initializers[k-1][j];
                        directionIntegers_[k][j] <<= (32-j-1);
                        j++;
                    }
                }
                break;



            case Kuo:
                // maxTabulated=4925
                maxTabulated = sizeof(Kuoinitializers)/sizeof(std::uint32_t *)+1;
                for (k=1; k<std::min(dimensionality_, maxTabulated); k++) {
                    j = 0;
                    // 0UL marks coefficients' end for a given dimension
                    while (Kuoinitializers[k-1][j] != 0UL) {
                        directionIntegers_[k][j] = Kuoinitializers[k-1][j];
                        directionIntegers_[k][j] <<= (32-j-1);
                        j++;
                    }
                }
                break;
            case Kuo2:
                // maxTabulated=3946
                maxTabulated = sizeof(Kuo2initializers)/sizeof(std::uint32_t *)+1;
                for (k=1; k<std::min(dimensionality_, maxTabulated); k++) {
                    j = 0;
                    // 0UL marks coefficients' end for a given dimension
                    while (Kuo2initializers[k-1][j] != 0UL) {
                        directionIntegers_[k][j] = Kuo2initializers[k-1][j];
                        directionIntegers_[k][j] <<= (32-j-1);
                        j++;
                    }
                }
                break;

            case Kuo3:
                // maxTabulated=4585
                maxTabulated = sizeof(Kuo3initializers)/sizeof(std::uint32_t *)+1;
                for (k=1; k<std::min(dimensionality_, maxTabulated); k++) {
                    j = 0;
                    // 0UL marks coefficients' end for a given dimension
                    while (Kuo3initializers[k-1][j] != 0UL) {
                        directionIntegers_[k][j] = Kuo3initializers[k-1][j];
                        directionIntegers_[k][j] <<= (32-j-1);
                        j++;
                    }
                }
                break;

            default:
                break;
        }

        // random initialization for higher dimensions
        if (dimensionality_>maxTabulated) {
            MersenneTwisterUniformRng uniformRng(seed);
            for (k=maxTabulated; k<dimensionality_; k++) {
                for (Size l=1; l<=degree[k]; l++) {
                    do {
                        // u is in (0,1)
                        Real u = uniformRng.next().value;
                        // the direction integer has at most the
                        // rightmost l bits non-zero
                        directionIntegers_[k][l-1] =
                            (std::uint32_t)(u*(1UL<<l));
                    } while ((directionIntegers_[k][l - 1] & 1UL) == 0U);
                    // iterate until the direction integer is odd
                    // that is it has the rightmost bit set

                    // shifting 32-l bits to the left
                    // we are guaranteed that the l-th leftmost bit
                    // is set, and only the first l leftmost bit
                    // can be non-zero
                    directionIntegers_[k][l-1] <<= (32-l);
                }
            }
        }

        // computation of directionIntegers_[k][l] for l>=degree_[k]
        // by recurrence relation
        for (k=1; k<dimensionality_; k++) {
            unsigned int gk = degree[k];
            for (int l=gk; l<32; l++) {
                // eq. 8.19 "Monte Carlo Methods in Finance" by P. J�ckel
                std::uint32_t n = (directionIntegers_[k][l-gk]>>gk);
                // a[k][j] are the coefficients of the monomials in ppmt[k]
                // The highest order coefficient a[k][0] is not actually
                // used in the recurrence relation, and the lowest order
                // coefficient a[k][gk] is always set: this is the reason
                // why the highest and lowest coefficient of
                // the polynomial ppmt[k] are not included in its encoding,
                // provided that its degree is known.
                // That is: a[k][j] = ppmt[k] >> (gk-j-1)
                for (Size j=1; j<gk; j++) {
                    // XORed with a selection of (unshifted) direction
                    // integers controlled by which of the a[k][j] are set
                    if (((ppmt[k] >> (gk - j - 1)) & 1UL) != 0U)
                        n ^= directionIntegers_[k][l-j];
                }
                // a[k][gk] is always set, so directionIntegers_[k][l-gk]
                // will always enter
                n ^= directionIntegers_[k][l-gk];
                directionIntegers_[k][l]=n;
            }
        }

        // in case one needs to check the directionIntegers used
        /* bool printDirectionIntegers = false;
           if (printDirectionIntegers) {
               std::ofstream outStream("directionIntegers.txt");
               for (k=0; k<std::min(32UL,dimensionality_); k++) {
                   outStream << std::endl << k+1       << "\t"
                                          << degree[k] << "\t"
                                          << ppmt[k]   << "\t";
                   for (j=0; j<10; j++) {
                       outStream << io::power_of_two(
                           directionIntegers_[k][j]) << "\t";
                   }
               }
               outStream.close();
           }
        */

        // initialize the Sobol integer/double vectors
        // first draw, this is only needed if Gray code is used
        if (useGrayCode_) {
            for (k = 0; k < dimensionality_; k++) {
                integerSequence_[k] = directionIntegers_[k][0];
            }
        }
    }

    const std::vector<std::uint32_t>& SobolRsg::skipTo(std::uint32_t skip) const {
        std::uint32_t N = skip + 1;

        if (useGrayCode_) {
            unsigned int ops = (unsigned int)(std::log((double)N) / M_LN2) + 1;

            // Convert to Gray code
            std::uint32_t G = N ^ (N >> 1);
            for (Size k = 0; k < dimensionality_; k++) {
                integerSequence_[k] = 0;
                for (Size index = 0; index < ops; index++) {
                    if ((G >> index & 1) != 0U)
                        integerSequence_[k] ^= directionIntegers_[k][index];
                }
            }
        } else {
            std::fill(integerSequence_.begin(), integerSequence_.end(), 0U);
            std::uint32_t mask = 1;
            for (Size index = 0; index < 32; index++) {
                if ((N & mask) != 0U) {
                    for (Size k = 0; k < dimensionality_; k++) {
                        integerSequence_[k] ^= directionIntegers_[k][index];
                    }
                }
                mask = mask << 1;
            }
        }

        sequenceCounter_ = skip;
        return integerSequence_;
    }

    const std::vector<std::uint32_t>& SobolRsg::nextInt32Sequence() const
    {

        if (!useGrayCode_) {
            skipTo(sequenceCounter_);
            if (firstDraw_) {
                firstDraw_ = false;
            } else {
                ++sequenceCounter_;
                QL_REQUIRE(sequenceCounter_ != 0, "period exceeded");
            }
            return integerSequence_;
        }

        if (firstDraw_) {
            // it was precomputed in the constructor
            firstDraw_ = false;
            return integerSequence_;
        }
        // increment the counter
        sequenceCounter_++;
        // did we overflow?
        QL_REQUIRE(sequenceCounter_ != 0, "period exceeded");

        // instead of using the counter n as new unique generating integer
        // for the n-th draw use the Gray code G(n) as proposed
        // by Antonov and Saleev
        std::uint32_t n = sequenceCounter_;
        // Find rightmost zero bit of n
        int j = 0;
        while ((n & 1) != 0U) {
            n >>= 1;
            j++;
        }
        for (Size k=0; k<dimensionality_; k++) {
            // XOR the appropriate direction number into each component of
            // the integer sequence to obtain a new Sobol integer for that
            // component
            integerSequence_[k] ^= directionIntegers_[k][j];
        }
        return integerSequence_;
    }

}
